/*!
 * Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * 
 * Neither the name of Anaconda nor the names of any contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
(function(root, factory) {
  const bokeh = factory();
  bokeh.__bokeh__ = true;
  if (typeof root.Bokeh === "undefined" || typeof root.Bokeh.__bokeh__ === "undefined") {
    root.Bokeh = bokeh;
  }
  const Bokeh = root.Bokeh;
  Bokeh[bokeh.version] = bokeh;
})(this, function() {
  let define;
  const parent_require = typeof require === "function" && require
  return (function(modules, entry, aliases, externals) {
  if (aliases === undefined) aliases = {};
  if (externals === undefined) externals = {};

  const cache = {};

  const normalize = function(name) {
    if (typeof name === "number")
      return name;

    if (name === "bokehjs")
      return entry;

    if (!externals[name]) {
      const prefix = "@bokehjs/"
      if (name.slice(0, prefix.length) === prefix)
        name = name.slice(prefix.length)
    }

    const alias = aliases[name]
    if (alias != null)
      return alias;

    const trailing = name.length > 0 && name[name.lenght-1] === "/";
    const index = aliases[name + (trailing ? "" : "/") + "index"];
    if (index != null)
      return index;

    return name;
  }

  const require = function(name) {
    let mod = cache[name];
    if (!mod) {
      const id = normalize(name);

      mod = cache[id];
      if (!mod) {
        if (!modules[id]) {
          if (externals[id] === false || (externals[id] == true && parent_require)) {
            try {
              mod = {exports: externals[id] ? parent_require(id) : {}};
              cache[id] = cache[name] = mod;
              return mod.exports;
            } catch (e) {}
          }

          const err = new Error("Cannot find module '" + name + "'");
          err.code = 'MODULE_NOT_FOUND';
          throw err;
        }

        mod = {exports: {}};
        cache[id] = cache[name] = mod;

        function __esModule() {
          Object.defineProperty(mod.exports, "__esModule", {value: true});
        }

        function __esExport(name, value) {
          Object.defineProperty(mod.exports, name, {
            enumerable: true, get: function () { return value; }
          });
        }

        modules[id].call(mod.exports, require, mod, mod.exports, __esModule, __esExport);
      } else {
        cache[name] = mod;
      }
    }

    return mod.exports;
  }
  require.resolve = function(name) {
    return ""
  }

  const main = require(entry);
  main.require = require;

  if (typeof Proxy !== "undefined") {
    // allow Bokeh.loader["@bokehjs/module/name"] syntax
    main.loader = new Proxy({}, {
      get: function(_obj, module) {
        return require(module);
      }
    });
  }

  main.register_plugin = function(plugin_modules, plugin_entry, plugin_aliases, plugin_externals) {
    if (plugin_aliases === undefined) plugin_aliases = {};
    if (plugin_externals === undefined) plugin_externals = {};

    for (let name in plugin_modules) {
      modules[name] = plugin_modules[name];
    }

    for (let name in plugin_aliases) {
      aliases[name] = plugin_aliases[name];
    }

    for (let name in plugin_externals) {
      externals[name] = plugin_externals[name];
    }

    const plugin = require(plugin_entry);

    for (let name in plugin) {
      main[name] = plugin[name];
    }

    return plugin;
  }

  return main;
})
([
/* main.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const yargs_1 = require(1) /* yargs */;
    const path_1 = require("path");
    const sys_1 = require(20) /* ./sys */;
    const build_1 = require(35) /* ./build */;
    const compile_1 = require(1297) /* ./compile */;
    async function read_stdin() {
        const stdin = process.stdin;
        stdin.setEncoding("utf-8");
        stdin.resume();
        let data = "";
        for await (const chunk of stdin) {
            data += chunk;
        }
        return data;
    }
    function reply(data) {
        process.stdout.write(JSON.stringify(data));
        process.stdout.write("\n");
    }
    async function compile() {
        const input = await (async () => {
            if (yargs_1.argv.file != null) {
                return {
                    code: yargs_1.argv.code != null ? yargs_1.argv.code : (0, sys_1.read)(yargs_1.argv.file),
                    lang: yargs_1.argv.lang ?? "typescript",
                    file: yargs_1.argv.file,
                    bokehjs_dir: yargs_1.argv.bokehjsDir ?? "./build", // this is what bokeh.settings defaults to
                };
            }
            else {
                return JSON.parse(await read_stdin());
            }
        })();
        return await (0, compile_1.compile_and_resolve_deps)(input);
    }
    async function main() {
        const cmd = yargs_1.argv._[0];
        if (cmd == "build") {
            try {
                const base_dir = (0, path_1.resolve)(yargs_1.argv.baseDir);
                const bokehjs_dir = (0, path_1.resolve)(yargs_1.argv.bokehjsDir);
                const rebuild = yargs_1.argv.rebuild;
                const bokeh_version = yargs_1.argv.bokehVersion;
                const result = await (0, build_1.build)(base_dir, bokehjs_dir, { rebuild, bokeh_version });
                process.exit(result ? 0 : 1);
            }
            catch (error) {
                const msg = error instanceof Error && error.stack != null ? error.stack : `${error}`;
                console.log(msg);
                process.exit(1);
            }
        }
        else if (cmd == "init") {
            try {
                const base_dir = (0, path_1.resolve)(yargs_1.argv.baseDir);
                const bokehjs_dir = (0, path_1.resolve)(yargs_1.argv.bokehjsDir);
                const interactive = yargs_1.argv.interactive;
                const bokehjs_version = yargs_1.argv.bokehjsVersion;
                const bokeh_version = yargs_1.argv.bokehVersion;
                const result = await (0, build_1.init)(base_dir, bokehjs_dir, { interactive, bokehjs_version, bokeh_version });
                process.exit(result ? 0 : 1);
            }
            catch (error) {
                const msg = error instanceof Error && error.stack != null ? error.stack : `${error}`;
                console.log(msg);
                process.exit(1);
            }
        }
        else {
            try {
                reply(await compile());
            }
            catch (error) {
                const msg = error instanceof Error && error.stack != null ? error.stack : `${error}`;
                reply({ error: msg });
            }
        }
    }
    main();
    
},
/* yargs/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    // classic singleton yargs API, to use yargs
    // without running as a singleton do:
    // require('yargs/yargs')(process.argv.slice(2))
    const { Yargs, processArgv } = require(2) /* ./build/index.cjs */;
    Argv(processArgv.hideBin(process.argv));
    module.exports = Argv;
    function Argv(processArgs, cwd) {
        const argv = Yargs(processArgs, cwd, require);
        singletonify(argv);
        // TODO(bcoe): warn if argv.parse() or argv.argv is used directly.
        return argv;
    }
    function defineGetter(obj, key, getter) {
        Object.defineProperty(obj, key, {
            configurable: true,
            enumerable: true,
            get: getter,
        });
    }
    function lookupGetter(obj, key) {
        const desc = Object.getOwnPropertyDescriptor(obj, key);
        if (typeof desc !== 'undefined') {
            return desc.get;
        }
    }
    /*  Hack an instance of Argv with process.argv into Argv
        so people can do
        require('yargs')(['--beeble=1','-z','zizzle']).argv
        to parse a list of args and
        require('yargs').argv
        to get a parsed version of process.argv.
    */
    function singletonify(inst) {
        [
            ...Object.keys(inst),
            ...Object.getOwnPropertyNames(inst.constructor.prototype),
        ].forEach(key => {
            if (key === 'argv') {
                defineGetter(Argv, key, lookupGetter(inst, key));
            }
            else if (typeof inst[key] === 'function') {
                Argv[key] = inst[key].bind(inst);
            }
            else {
                defineGetter(Argv, '$0', () => inst.$0);
                defineGetter(Argv, 'parsed', () => inst.parsed);
            }
        });
    }
},
/* yargs/build/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var t = require("assert");
    class e extends Error {
        constructor(t) { super(t || "yargs error"), this.name = "YError", Error.captureStackTrace && Error.captureStackTrace(this, e); }
    }
    let s, i = [];
    function n(t, o, a, h) { s = h; let l = {}; if (Object.prototype.hasOwnProperty.call(t, "extends")) {
        if ("string" != typeof t.extends)
            return l;
        const r = /\.json|\..*rc$/.test(t.extends);
        let h = null;
        if (r)
            h = function (t, e) { return s.path.resolve(t, e); }(o, t.extends);
        else
            try {
                h = require.resolve(t.extends);
            }
            catch (e) {
                return t;
            }
        !function (t) { if (i.indexOf(t) > -1)
            throw new e(`Circular extended configurations: '${t}'.`); }(h), i.push(h), l = r ? JSON.parse(s.readFileSync(h, "utf8")) : require(t.extends), delete t.extends, l = n(l, s.path.dirname(h), a, s);
    } return i = [], a ? r(l, t) : Object.assign({}, l, t); }
    function r(t, e) { const s = {}; function i(t) { return t && "object" == typeof t && !Array.isArray(t); } Object.assign(s, t); for (const n of Object.keys(e))
        i(e[n]) && i(s[n]) ? s[n] = r(t[n], e[n]) : s[n] = e[n]; return s; }
    function o(t) { const e = t.replace(/\s{2,}/g, " ").split(/\s+(?![^[]*]|[^<]*>)/), s = /\.*[\][<>]/g, i = e.shift(); if (!i)
        throw new Error(`No command found in: ${t}`); const n = { cmd: i.replace(s, ""), demanded: [], optional: [] }; return e.forEach(((t, i) => { let r = !1; t = t.replace(/\s/g, ""), /\.+[\]>]/.test(t) && i === e.length - 1 && (r = !0), /^\[/.test(t) ? n.optional.push({ cmd: t.replace(s, "").split("|"), variadic: r }) : n.demanded.push({ cmd: t.replace(s, "").split("|"), variadic: r }); })), n; }
    const a = ["first", "second", "third", "fourth", "fifth", "sixth"];
    function h(t, s, i) { try {
        let n = 0;
        const [r, a, h] = "object" == typeof t ? [{ demanded: [], optional: [] }, t, s] : [o(`cmd ${t}`), s, i], f = [].slice.call(a);
        for (; f.length && void 0 === f[f.length - 1];)
            f.pop();
        const d = h || f.length;
        if (d < r.demanded.length)
            throw new e(`Not enough arguments provided. Expected ${r.demanded.length} but received ${f.length}.`);
        const u = r.demanded.length + r.optional.length;
        if (d > u)
            throw new e(`Too many arguments provided. Expected max ${u} but received ${d}.`);
        r.demanded.forEach((t => { const e = l(f.shift()); 0 === t.cmd.filter((t => t === e || "*" === t)).length && c(e, t.cmd, n), n += 1; })), r.optional.forEach((t => { if (0 === f.length)
            return; const e = l(f.shift()); 0 === t.cmd.filter((t => t === e || "*" === t)).length && c(e, t.cmd, n), n += 1; }));
    }
    catch (t) {
        console.warn(t.stack);
    } }
    function l(t) { return Array.isArray(t) ? "array" : null === t ? "null" : typeof t; }
    function c(t, s, i) { throw new e(`Invalid ${a[i] || "manyith"} argument. Expected ${s.join(" or ")} but received ${t}.`); }
    function f(t) { return !!t && !!t.then && "function" == typeof t.then; }
    function d(t, e, s, i) { s.assert.notStrictEqual(t, e, i); }
    function u(t, e) { e.assert.strictEqual(typeof t, "string"); }
    function p(t) { return Object.keys(t); }
    function g(t = {}, e = (() => !0)) { const s = {}; return p(t).forEach((i => { e(i, t[i]) && (s[i] = t[i]); })), s; }
    function m() { return process.versions.electron && !process.defaultApp ? 0 : 1; }
    function y() { return process.argv[m()]; }
    var b = Object.freeze({ __proto__: null, hideBin: function (t) { return t.slice(m() + 1); }, getProcessArgvBin: y });
    function v(t, e, s, i) { if ("a" === s && !i)
        throw new TypeError("Private accessor was defined without a getter"); if ("function" == typeof e ? t !== e || !i : !e.has(t))
        throw new TypeError("Cannot read private member from an object whose class did not declare it"); return "m" === s ? i : "a" === s ? i.call(t) : i ? i.value : e.get(t); }
    function O(t, e, s, i, n) { if ("m" === i)
        throw new TypeError("Private method is not writable"); if ("a" === i && !n)
        throw new TypeError("Private accessor was defined without a setter"); if ("function" == typeof e ? t !== e || !n : !e.has(t))
        throw new TypeError("Cannot write private member to an object whose class did not declare it"); return "a" === i ? n.call(t, s) : n ? n.value = s : e.set(t, s), s; }
    class w {
        constructor(t) { this.globalMiddleware = [], this.frozens = [], this.yargs = t; }
        addMiddleware(t, e, s = !0, i = !1) { if (h("<array|function> [boolean] [boolean] [boolean]", [t, e, s], arguments.length), Array.isArray(t)) {
            for (let i = 0; i < t.length; i++) {
                if ("function" != typeof t[i])
                    throw Error("middleware must be a function");
                const n = t[i];
                n.applyBeforeValidation = e, n.global = s;
            }
            Array.prototype.push.apply(this.globalMiddleware, t);
        }
        else if ("function" == typeof t) {
            const n = t;
            n.applyBeforeValidation = e, n.global = s, n.mutates = i, this.globalMiddleware.push(t);
        } return this.yargs; }
        addCoerceMiddleware(t, e) { const s = this.yargs.getAliases(); return this.globalMiddleware = this.globalMiddleware.filter((t => { const i = [...s[e] || [], e]; return !t.option || !i.includes(t.option); })), t.option = e, this.addMiddleware(t, !0, !0, !0); }
        getMiddleware() { return this.globalMiddleware; }
        freeze() { this.frozens.push([...this.globalMiddleware]); }
        unfreeze() { const t = this.frozens.pop(); void 0 !== t && (this.globalMiddleware = t); }
        reset() { this.globalMiddleware = this.globalMiddleware.filter((t => t.global)); }
    }
    function C(t, e, s, i) { return s.reduce(((t, s) => { if (s.applyBeforeValidation !== i)
        return t; if (s.mutates) {
        if (s.applied)
            return t;
        s.applied = !0;
    } if (f(t))
        return t.then((t => Promise.all([t, s(t, e)]))).then((([t, e]) => Object.assign(t, e))); {
        const i = s(t, e);
        return f(i) ? i.then((e => Object.assign(t, e))) : Object.assign(t, i);
    } }), t); }
    function j(t, e, s = (t => { throw t; })) { try {
        const s = "function" == typeof t ? t() : t;
        return f(s) ? s.then((t => e(t))) : e(s);
    }
    catch (t) {
        return s(t);
    } }
    const M = /(^\*)|(^\$0)/;
    class _ {
        constructor(t, e, s, i) { this.requireCache = new Set, this.handlers = {}, this.aliasMap = {}, this.frozens = [], this.shim = i, this.usage = t, this.globalMiddleware = s, this.validation = e; }
        addDirectory(t, e, s, i) { "boolean" != typeof (i = i || {}).recurse && (i.recurse = !1), Array.isArray(i.extensions) || (i.extensions = ["js"]); const n = "function" == typeof i.visit ? i.visit : t => t; i.visit = (t, e, s) => { const i = n(t, e, s); if (i) {
            if (this.requireCache.has(e))
                return i;
            this.requireCache.add(e), this.addHandler(i);
        } return i; }, this.shim.requireDirectory({ require: e, filename: s }, t, i); }
        addHandler(t, e, s, i, n, r) { let a = []; const h = function (t) { return t ? t.map((t => (t.applyBeforeValidation = !1, t))) : []; }(n); if (i = i || (() => { }), Array.isArray(t))
            if (function (t) { return t.every((t => "string" == typeof t)); }(t))
                [t, ...a] = t;
            else
                for (const e of t)
                    this.addHandler(e);
        else {
            if (function (t) { return "object" == typeof t && !Array.isArray(t); }(t)) {
                let e = Array.isArray(t.command) || "string" == typeof t.command ? t.command : this.moduleName(t);
                return t.aliases && (e = [].concat(e).concat(t.aliases)), void this.addHandler(e, this.extractDesc(t), t.builder, t.handler, t.middlewares, t.deprecated);
            }
            if (k(s))
                return void this.addHandler([t].concat(a), e, s.builder, s.handler, s.middlewares, s.deprecated);
        } if ("string" == typeof t) {
            const n = o(t);
            a = a.map((t => o(t).cmd));
            let l = !1;
            const c = [n.cmd].concat(a).filter((t => !M.test(t) || (l = !0, !1)));
            0 === c.length && l && c.push("$0"), l && (n.cmd = c[0], a = c.slice(1), t = t.replace(M, n.cmd)), a.forEach((t => { this.aliasMap[t] = n.cmd; })), !1 !== e && this.usage.command(t, e, l, a, r), this.handlers[n.cmd] = { original: t, description: e, handler: i, builder: s || {}, middlewares: h, deprecated: r, demanded: n.demanded, optional: n.optional }, l && (this.defaultCommand = this.handlers[n.cmd]);
        } }
        getCommandHandlers() { return this.handlers; }
        getCommands() { return Object.keys(this.handlers).concat(Object.keys(this.aliasMap)); }
        hasDefaultCommand() { return !!this.defaultCommand; }
        runCommand(t, e, s, i, n, r) { const o = this.handlers[t] || this.handlers[this.aliasMap[t]] || this.defaultCommand, a = e.getInternalMethods().getContext(), h = a.commands.slice(), l = !t; t && (a.commands.push(t), a.fullCommands.push(o.original)); const c = this.applyBuilderUpdateUsageAndParse(l, o, e, s.aliases, h, i, n, r); return f(c) ? c.then((t => this.applyMiddlewareAndGetResult(l, o, t.innerArgv, a, n, t.aliases, e))) : this.applyMiddlewareAndGetResult(l, o, c.innerArgv, a, n, c.aliases, e); }
        applyBuilderUpdateUsageAndParse(t, e, s, i, n, r, o, a) { const h = e.builder; let l = s; if (x(h)) {
            s.getInternalMethods().getUsageInstance().freeze();
            const c = h(s.getInternalMethods().reset(i), a);
            if (f(c))
                return c.then((i => { var a; return l = (a = i) && "function" == typeof a.getInternalMethods ? i : s, this.parseAndUpdateUsage(t, e, l, n, r, o); }));
        }
        else
            (function (t) { return "object" == typeof t; })(h) && (s.getInternalMethods().getUsageInstance().freeze(), l = s.getInternalMethods().reset(i), Object.keys(e.builder).forEach((t => { l.option(t, h[t]); }))); return this.parseAndUpdateUsage(t, e, l, n, r, o); }
        parseAndUpdateUsage(t, e, s, i, n, r) { t && s.getInternalMethods().getUsageInstance().unfreeze(!0), this.shouldUpdateUsage(s) && s.getInternalMethods().getUsageInstance().usage(this.usageFromParentCommandsCommandHandler(i, e), e.description); const o = s.getInternalMethods().runYargsParserAndExecuteCommands(null, void 0, !0, n, r); return f(o) ? o.then((t => ({ aliases: s.parsed.aliases, innerArgv: t }))) : { aliases: s.parsed.aliases, innerArgv: o }; }
        shouldUpdateUsage(t) { return !t.getInternalMethods().getUsageInstance().getUsageDisabled() && 0 === t.getInternalMethods().getUsageInstance().getUsage().length; }
        usageFromParentCommandsCommandHandler(t, e) { const s = M.test(e.original) ? e.original.replace(M, "").trim() : e.original, i = t.filter((t => !M.test(t))); return i.push(s), `$0 ${i.join(" ")}`; }
        handleValidationAndGetResult(t, e, s, i, n, r, o, a) { if (!r.getInternalMethods().getHasOutput()) {
            const e = r.getInternalMethods().runValidation(n, a, r.parsed.error, t);
            s = j(s, (t => (e(t), t)));
        } if (e.handler && !r.getInternalMethods().getHasOutput()) {
            r.getInternalMethods().setHasOutput();
            const i = !!r.getOptions().configuration["populate--"];
            r.getInternalMethods().postProcess(s, i, !1, !1), s = j(s = C(s, r, o, !1), (t => { const s = e.handler(t); return f(s) ? s.then((() => t)) : t; })), t || r.getInternalMethods().getUsageInstance().cacheHelpMessage(), f(s) && !r.getInternalMethods().hasParseCallback() && s.catch((t => { try {
                r.getInternalMethods().getUsageInstance().fail(null, t);
            }
            catch (t) { } }));
        } return t || (i.commands.pop(), i.fullCommands.pop()), s; }
        applyMiddlewareAndGetResult(t, e, s, i, n, r, o) { let a = {}; if (n)
            return s; o.getInternalMethods().getHasOutput() || (a = this.populatePositionals(e, s, i, o)); const h = this.globalMiddleware.getMiddleware().slice(0).concat(e.middlewares), l = C(s, o, h, !0); return f(l) ? l.then((s => this.handleValidationAndGetResult(t, e, s, i, r, o, h, a))) : this.handleValidationAndGetResult(t, e, l, i, r, o, h, a); }
        populatePositionals(t, e, s, i) { e._ = e._.slice(s.commands.length); const n = t.demanded.slice(0), r = t.optional.slice(0), o = {}; for (this.validation.positionalCount(n.length, e._.length); n.length;) {
            const t = n.shift();
            this.populatePositional(t, e, o);
        } for (; r.length;) {
            const t = r.shift();
            this.populatePositional(t, e, o);
        } return e._ = s.commands.concat(e._.map((t => "" + t))), this.postProcessPositionals(e, o, this.cmdToParseOptions(t.original), i), o; }
        populatePositional(t, e, s) { const i = t.cmd[0]; t.variadic ? s[i] = e._.splice(0).map(String) : e._.length && (s[i] = [String(e._.shift())]); }
        cmdToParseOptions(t) { const e = { array: [], default: {}, alias: {}, demand: {} }, s = o(t); return s.demanded.forEach((t => { const [s, ...i] = t.cmd; t.variadic && (e.array.push(s), e.default[s] = []), e.alias[s] = i, e.demand[s] = !0; })), s.optional.forEach((t => { const [s, ...i] = t.cmd; t.variadic && (e.array.push(s), e.default[s] = []), e.alias[s] = i; })), e; }
        postProcessPositionals(t, e, s, i) { const n = Object.assign({}, i.getOptions()); n.default = Object.assign(s.default, n.default); for (const t of Object.keys(s.alias))
            n.alias[t] = (n.alias[t] || []).concat(s.alias[t]); n.array = n.array.concat(s.array), n.config = {}; const r = []; if (Object.keys(e).forEach((t => { e[t].map((e => { n.configuration["unknown-options-as-args"] && (n.key[t] = !0), r.push(`--${t}`), r.push(e); })); })), !r.length)
            return; const o = Object.assign({}, n.configuration, { "populate--": !1 }), a = this.shim.Parser.detailed(r, Object.assign({}, n, { configuration: o })); if (a.error)
            i.getInternalMethods().getUsageInstance().fail(a.error.message, a.error);
        else {
            const s = Object.keys(e);
            Object.keys(e).forEach((t => { s.push(...a.aliases[t]); })), Object.keys(a.argv).forEach((n => { s.includes(n) && (e[n] || (e[n] = a.argv[n]), !this.isInConfigs(i, n) && !this.isDefaulted(i, n) && Object.prototype.hasOwnProperty.call(t, n) && Object.prototype.hasOwnProperty.call(a.argv, n) && (Array.isArray(t[n]) || Array.isArray(a.argv[n])) ? t[n] = [].concat(t[n], a.argv[n]) : t[n] = a.argv[n]); }));
        } }
        isDefaulted(t, e) { const { default: s } = t.getOptions(); return Object.prototype.hasOwnProperty.call(s, e) || Object.prototype.hasOwnProperty.call(s, this.shim.Parser.camelCase(e)); }
        isInConfigs(t, e) { const { configObjects: s } = t.getOptions(); return s.some((t => Object.prototype.hasOwnProperty.call(t, e))) || s.some((t => Object.prototype.hasOwnProperty.call(t, this.shim.Parser.camelCase(e)))); }
        runDefaultBuilderOn(t) { if (!this.defaultCommand)
            return; if (this.shouldUpdateUsage(t)) {
            const e = M.test(this.defaultCommand.original) ? this.defaultCommand.original : this.defaultCommand.original.replace(/^[^[\]<>]*/, "$0 ");
            t.getInternalMethods().getUsageInstance().usage(e, this.defaultCommand.description);
        } const e = this.defaultCommand.builder; if (x(e))
            return e(t, !0); k(e) || Object.keys(e).forEach((s => { t.option(s, e[s]); })); }
        moduleName(t) { const e = function (t) { if ("undefined" == typeof require)
            return null; for (let e, s = 0, i = Object.keys(require.cache); s < i.length; s++)
            if (e = require.cache[i[s]], e.exports === t)
                return e; return null; }(t); if (!e)
            throw new Error(`No command name given for module: ${this.shim.inspect(t)}`); return this.commandFromFilename(e.filename); }
        commandFromFilename(t) { return this.shim.path.basename(t, this.shim.path.extname(t)); }
        extractDesc({ describe: t, description: e, desc: s }) { for (const i of [t, e, s]) {
            if ("string" == typeof i || !1 === i)
                return i;
            d(i, !0, this.shim);
        } return !1; }
        freeze() { this.frozens.push({ handlers: this.handlers, aliasMap: this.aliasMap, defaultCommand: this.defaultCommand }); }
        unfreeze() { const t = this.frozens.pop(); d(t, void 0, this.shim), ({ handlers: this.handlers, aliasMap: this.aliasMap, defaultCommand: this.defaultCommand } = t); }
        reset() { return this.handlers = {}, this.aliasMap = {}, this.defaultCommand = void 0, this.requireCache = new Set, this; }
    }
    function k(t) { return "object" == typeof t && !!t.builder && "function" == typeof t.handler; }
    function x(t) { return "function" == typeof t; }
    function E(t) { "undefined" != typeof process && [process.stdout, process.stderr].forEach((e => { const s = e; s._handle && s.isTTY && "function" == typeof s._handle.setBlocking && s._handle.setBlocking(t); })); }
    function A(t) { return "boolean" == typeof t; }
    function P(t, s) { const i = s.y18n.__, n = {}, r = []; n.failFn = function (t) { r.push(t); }; let o = null, a = null, h = !0; n.showHelpOnFail = function (e = !0, s) { const [i, r] = "string" == typeof e ? [!0, e] : [e, s]; return t.getInternalMethods().isGlobalContext() && (a = r), o = r, h = i, n; }; let l = !1; n.fail = function (s, i) { const c = t.getInternalMethods().getLoggerInstance(); if (!r.length) {
        if (t.getExitProcess() && E(!0), !l) {
            l = !0, h && (t.showHelp("error"), c.error()), (s || i) && c.error(s || i);
            const e = o || a;
            e && ((s || i) && c.error(""), c.error(e));
        }
        if (i = i || new e(s), t.getExitProcess())
            return t.exit(1);
        if (t.getInternalMethods().hasParseCallback())
            return t.exit(1, i);
        throw i;
    } for (let t = r.length - 1; t >= 0; --t) {
        const e = r[t];
        if (A(e)) {
            if (i)
                throw i;
            if (s)
                throw Error(s);
        }
        else
            e(s, i, n);
    } }; let c = [], f = !1; n.usage = (t, e) => null === t ? (f = !0, c = [], n) : (f = !1, c.push([t, e || ""]), n), n.getUsage = () => c, n.getUsageDisabled = () => f, n.getPositionalGroupName = () => i("Positionals:"); let d = []; n.example = (t, e) => { d.push([t, e || ""]); }; let u = []; n.command = function (t, e, s, i, n = !1) { s && (u = u.map((t => (t[2] = !1, t)))), u.push([t, e || "", s, i, n]); }, n.getCommands = () => u; let p = {}; n.describe = function (t, e) { Array.isArray(t) ? t.forEach((t => { n.describe(t, e); })) : "object" == typeof t ? Object.keys(t).forEach((e => { n.describe(e, t[e]); })) : p[t] = e; }, n.getDescriptions = () => p; let m = []; n.epilog = t => { m.push(t); }; let y, b = !1; n.wrap = t => { b = !0, y = t; }, n.getWrap = () => s.getEnv("YARGS_DISABLE_WRAP") ? null : (b || (y = function () { const t = 80; return s.process.stdColumns ? Math.min(t, s.process.stdColumns) : t; }(), b = !0), y); const v = "__yargsString__:"; function O(t, e, i) { let n = 0; return Array.isArray(t) || (t = Object.values(t).map((t => [t]))), t.forEach((t => { n = Math.max(s.stringWidth(i ? `${i} ${I(t[0])}` : I(t[0])) + $(t[0]), n); })), e && (n = Math.min(n, parseInt((.5 * e).toString(), 10))), n; } let w; function C(e) { return t.getOptions().hiddenOptions.indexOf(e) < 0 || t.parsed.argv[t.getOptions().showHiddenOpt]; } function j(t, e) { let s = `[${i("default:")} `; if (void 0 === t && !e)
        return null; if (e)
        s += e;
    else
        switch (typeof t) {
            case "string":
                s += `"${t}"`;
                break;
            case "object":
                s += JSON.stringify(t);
                break;
            default: s += t;
        } return `${s}]`; } n.deferY18nLookup = t => v + t, n.help = function () { if (w)
        return w; !function () { const e = t.getDemandedOptions(), s = t.getOptions(); (Object.keys(s.alias) || []).forEach((i => { s.alias[i].forEach((r => { p[r] && n.describe(i, p[r]), r in e && t.demandOption(i, e[r]), s.boolean.includes(r) && t.boolean(i), s.count.includes(r) && t.count(i), s.string.includes(r) && t.string(i), s.normalize.includes(r) && t.normalize(i), s.array.includes(r) && t.array(i), s.number.includes(r) && t.number(i); })); })); }(); const e = t.customScriptName ? t.$0 : s.path.basename(t.$0), r = t.getDemandedOptions(), o = t.getDemandedCommands(), a = t.getDeprecatedOptions(), h = t.getGroups(), l = t.getOptions(); let g = []; g = g.concat(Object.keys(p)), g = g.concat(Object.keys(r)), g = g.concat(Object.keys(o)), g = g.concat(Object.keys(l.default)), g = g.filter(C), g = Object.keys(g.reduce(((t, e) => ("_" !== e && (t[e] = !0), t)), {})); const y = n.getWrap(), b = s.cliui({ width: y, wrap: !!y }); if (!f)
        if (c.length)
            c.forEach((t => { b.div({ text: `${t[0].replace(/\$0/g, e)}` }), t[1] && b.div({ text: `${t[1]}`, padding: [1, 0, 0, 0] }); })), b.div();
        else if (u.length) {
            let t = null;
            t = o._ ? `${e} <${i("command")}>\n` : `${e} [${i("command")}]\n`, b.div(`${t}`);
        } if (u.length > 1 || 1 === u.length && !u[0][2]) {
        b.div(i("Commands:"));
        const s = t.getInternalMethods().getContext(), n = s.commands.length ? `${s.commands.join(" ")} ` : "";
        !0 === t.getInternalMethods().getParserConfiguration()["sort-commands"] && (u = u.sort(((t, e) => t[0].localeCompare(e[0]))));
        const r = e ? `${e} ` : "";
        u.forEach((t => { const s = `${r}${n}${t[0].replace(/^\$0 ?/, "")}`; b.span({ text: s, padding: [0, 2, 0, 2], width: O(u, y, `${e}${n}`) + 4 }, { text: t[1] }); const o = []; t[2] && o.push(`[${i("default")}]`), t[3] && t[3].length && o.push(`[${i("aliases:")} ${t[3].join(", ")}]`), t[4] && ("string" == typeof t[4] ? o.push(`[${i("deprecated: %s", t[4])}]`) : o.push(`[${i("deprecated")}]`)), o.length ? b.div({ text: o.join(" "), padding: [0, 0, 0, 2], align: "right" }) : b.div(); })), b.div();
    } const M = (Object.keys(l.alias) || []).concat(Object.keys(t.parsed.newAliases) || []); g = g.filter((e => !t.parsed.newAliases[e] && M.every((t => -1 === (l.alias[t] || []).indexOf(e))))); const _ = i("Options:"); h[_] || (h[_] = []), function (t, e, s, i) { let n = [], r = null; Object.keys(s).forEach((t => { n = n.concat(s[t]); })), t.forEach((t => { r = [t].concat(e[t]), r.some((t => -1 !== n.indexOf(t))) || s[i].push(t); })); }(g, l.alias, h, _); const k = t => /^--/.test(I(t)), x = Object.keys(h).filter((t => h[t].length > 0)).map((t => ({ groupName: t, normalizedKeys: h[t].filter(C).map((t => { if (M.includes(t))
            return t; for (let e, s = 0; void 0 !== (e = M[s]); s++)
            if ((l.alias[e] || []).includes(t))
                return e; return t; })) }))).filter((({ normalizedKeys: t }) => t.length > 0)).map((({ groupName: t, normalizedKeys: e }) => { const s = e.reduce(((e, s) => (e[s] = [s].concat(l.alias[s] || []).map((e => t === n.getPositionalGroupName() ? e : (/^[0-9]$/.test(e) ? l.boolean.includes(s) ? "-" : "--" : e.length > 1 ? "--" : "-") + e)).sort(((t, e) => k(t) === k(e) ? 0 : k(t) ? 1 : -1)).join(", "), e)), {}); return { groupName: t, normalizedKeys: e, switches: s }; })); if (x.filter((({ groupName: t }) => t !== n.getPositionalGroupName())).some((({ normalizedKeys: t, switches: e }) => !t.every((t => k(e[t]))))) && x.filter((({ groupName: t }) => t !== n.getPositionalGroupName())).forEach((({ normalizedKeys: t, switches: e }) => { t.forEach((t => { var s, i; k(e[t]) && (e[t] = (s = e[t], i = "-x, ".length, S(s) ? { text: s.text, indentation: s.indentation + i } : { text: s, indentation: i })); })); })), x.forEach((({ groupName: e, normalizedKeys: s, switches: o }) => { b.div(e), s.forEach((e => { const s = o[e]; let h = p[e] || "", c = null; h.includes(v) && (h = i(h.substring(v.length))), l.boolean.includes(e) && (c = `[${i("boolean")}]`), l.count.includes(e) && (c = `[${i("count")}]`), l.string.includes(e) && (c = `[${i("string")}]`), l.normalize.includes(e) && (c = `[${i("string")}]`), l.array.includes(e) && (c = `[${i("array")}]`), l.number.includes(e) && (c = `[${i("number")}]`); const f = [e in a ? (d = a[e], "string" == typeof d ? `[${i("deprecated: %s", d)}]` : `[${i("deprecated")}]`) : null, c, e in r ? `[${i("required")}]` : null, l.choices && l.choices[e] ? `[${i("choices:")} ${n.stringifiedValues(l.choices[e])}]` : null, j(l.default[e], l.defaultDescription[e])].filter(Boolean).join(" "); var d; b.span({ text: I(s), padding: [0, 2, 0, 2 + $(s)], width: O(o, y) + 4 }, h); const u = !0 === t.getInternalMethods().getUsageConfiguration()["hide-types"]; f && !u ? b.div({ text: f, padding: [0, 0, 0, 2], align: "right" }) : b.div(); })), b.div(); })), d.length && (b.div(i("Examples:")), d.forEach((t => { t[0] = t[0].replace(/\$0/g, e); })), d.forEach((t => { "" === t[1] ? b.div({ text: t[0], padding: [0, 2, 0, 2] }) : b.div({ text: t[0], padding: [0, 2, 0, 2], width: O(d, y) + 4 }, { text: t[1] }); })), b.div()), m.length > 0) {
        const t = m.map((t => t.replace(/\$0/g, e))).join("\n");
        b.div(`${t}\n`);
    } return b.toString().replace(/\s*$/, ""); }, n.cacheHelpMessage = function () { w = this.help(); }, n.clearCachedHelpMessage = function () { w = void 0; }, n.hasCachedHelpMessage = function () { return !!w; }, n.showHelp = e => { const s = t.getInternalMethods().getLoggerInstance(); e || (e = "error"); ("function" == typeof e ? e : s[e])(n.help()); }, n.functionDescription = t => ["(", t.name ? s.Parser.decamelize(t.name, "-") : i("generated-value"), ")"].join(""), n.stringifiedValues = function (t, e) { let s = ""; const i = e || ", ", n = [].concat(t); return t && n.length ? (n.forEach((t => { s.length && (s += i), s += JSON.stringify(t); })), s) : s; }; let M = null; n.version = t => { M = t; }, n.showVersion = e => { const s = t.getInternalMethods().getLoggerInstance(); e || (e = "error"); ("function" == typeof e ? e : s[e])(M); }, n.reset = function (t) { return o = null, l = !1, c = [], f = !1, m = [], d = [], u = [], p = g(p, (e => !t[e])), n; }; const _ = []; return n.freeze = function () { _.push({ failMessage: o, failureOutput: l, usages: c, usageDisabled: f, epilogs: m, examples: d, commands: u, descriptions: p }); }, n.unfreeze = function (t = !1) { const e = _.pop(); e && (t ? (p = { ...e.descriptions, ...p }, u = [...e.commands, ...u], c = [...e.usages, ...c], d = [...e.examples, ...d], m = [...e.epilogs, ...m]) : ({ failMessage: o, failureOutput: l, usages: c, usageDisabled: f, epilogs: m, examples: d, commands: u, descriptions: p } = e)); }, n; }
    function S(t) { return "object" == typeof t; }
    function $(t) { return S(t) ? t.indentation : 0; }
    function I(t) { return S(t) ? t.text : t; }
    class D {
        constructor(t, e, s, i) { var n, r, o; this.yargs = t, this.usage = e, this.command = s, this.shim = i, this.completionKey = "get-yargs-completions", this.aliases = null, this.customCompletionFunction = null, this.indexAfterLastReset = 0, this.zshShell = null !== (o = (null === (n = this.shim.getEnv("SHELL")) || void 0 === n ? void 0 : n.includes("zsh")) || (null === (r = this.shim.getEnv("ZSH_NAME")) || void 0 === r ? void 0 : r.includes("zsh"))) && void 0 !== o && o; }
        defaultCompletion(t, e, s, i) { const n = this.command.getCommandHandlers(); for (let e = 0, s = t.length; e < s; ++e)
            if (n[t[e]] && n[t[e]].builder) {
                const s = n[t[e]].builder;
                if (x(s)) {
                    this.indexAfterLastReset = e + 1;
                    const t = this.yargs.getInternalMethods().reset();
                    return s(t, !0), t.argv;
                }
            } const r = []; this.commandCompletions(r, t, s), this.optionCompletions(r, t, e, s), this.choicesFromOptionsCompletions(r, t, e, s), this.choicesFromPositionalsCompletions(r, t, e, s), i(null, r); }
        commandCompletions(t, e, s) { const i = this.yargs.getInternalMethods().getContext().commands; s.match(/^-/) || i[i.length - 1] === s || this.previousArgHasChoices(e) || this.usage.getCommands().forEach((s => { const i = o(s[0]).cmd; if (-1 === e.indexOf(i))
            if (this.zshShell) {
                const e = s[1] || "";
                t.push(i.replace(/:/g, "\\:") + ":" + e);
            }
            else
                t.push(i); })); }
        optionCompletions(t, e, s, i) { if ((i.match(/^-/) || "" === i && 0 === t.length) && !this.previousArgHasChoices(e)) {
            const s = this.yargs.getOptions(), n = this.yargs.getGroups()[this.usage.getPositionalGroupName()] || [];
            Object.keys(s.key).forEach((r => { const o = !!s.configuration["boolean-negation"] && s.boolean.includes(r); n.includes(r) || s.hiddenOptions.includes(r) || this.argsContainKey(e, r, o) || (this.completeOptionKey(r, t, i), o && s.default[r] && this.completeOptionKey(`no-${r}`, t, i)); }));
        } }
        choicesFromOptionsCompletions(t, e, s, i) { if (this.previousArgHasChoices(e)) {
            const s = this.getPreviousArgChoices(e);
            s && s.length > 0 && t.push(...s.map((t => t.replace(/:/g, "\\:"))));
        } }
        choicesFromPositionalsCompletions(t, e, s, i) { if ("" === i && t.length > 0 && this.previousArgHasChoices(e))
            return; const n = this.yargs.getGroups()[this.usage.getPositionalGroupName()] || [], r = Math.max(this.indexAfterLastReset, this.yargs.getInternalMethods().getContext().commands.length + 1), o = n[s._.length - r - 1]; if (!o)
            return; const a = this.yargs.getOptions().choices[o] || []; for (const e of a)
            e.startsWith(i) && t.push(e.replace(/:/g, "\\:")); }
        getPreviousArgChoices(t) { if (t.length < 1)
            return; let e = t[t.length - 1], s = ""; if (!e.startsWith("-") && t.length > 1 && (s = e, e = t[t.length - 2]), !e.startsWith("-"))
            return; const i = e.replace(/^-+/, ""), n = this.yargs.getOptions(), r = [i, ...this.yargs.getAliases()[i] || []]; let o; for (const t of r)
            if (Object.prototype.hasOwnProperty.call(n.key, t) && Array.isArray(n.choices[t])) {
                o = n.choices[t];
                break;
            } return o ? o.filter((t => !s || t.startsWith(s))) : void 0; }
        previousArgHasChoices(t) { const e = this.getPreviousArgChoices(t); return void 0 !== e && e.length > 0; }
        argsContainKey(t, e, s) { const i = e => -1 !== t.indexOf((/^[^0-9]$/.test(e) ? "-" : "--") + e); if (i(e))
            return !0; if (s && i(`no-${e}`))
            return !0; if (this.aliases)
            for (const t of this.aliases[e])
                if (i(t))
                    return !0; return !1; }
        completeOptionKey(t, e, s) { var i, n, r; const o = this.usage.getDescriptions(), a = !/^--/.test(s) && (t => /^[^0-9]$/.test(t))(t) ? "-" : "--"; if (this.zshShell) {
            const s = null === (i = null == this ? void 0 : this.aliases) || void 0 === i ? void 0 : i[t].find((t => { const e = o[t]; return "string" == typeof e && e.length > 0; })), h = s ? o[s] : void 0, l = null !== (r = null !== (n = o[t]) && void 0 !== n ? n : h) && void 0 !== r ? r : "";
            e.push(a + `${t.replace(/:/g, "\\:")}:${l.replace("__yargsString__:", "").replace(/(\r\n|\n|\r)/gm, " ")}`);
        }
        else
            e.push(a + t); }
        customCompletion(t, e, s, i) { if (d(this.customCompletionFunction, null, this.shim), this.customCompletionFunction.length < 3) {
            const t = this.customCompletionFunction(s, e);
            return f(t) ? t.then((t => { this.shim.process.nextTick((() => { i(null, t); })); })).catch((t => { this.shim.process.nextTick((() => { i(t, void 0); })); })) : i(null, t);
        } return function (t) { return t.length > 3; }(this.customCompletionFunction) ? this.customCompletionFunction(s, e, ((n = i) => this.defaultCompletion(t, e, s, n)), (t => { i(null, t); })) : this.customCompletionFunction(s, e, (t => { i(null, t); })); }
        getCompletion(t, e) { const s = t.length ? t[t.length - 1] : "", i = this.yargs.parse(t, !0), n = this.customCompletionFunction ? i => this.customCompletion(t, i, s, e) : i => this.defaultCompletion(t, i, s, e); return f(i) ? i.then(n) : n(i); }
        generateCompletionScript(t, e) { let s = this.zshShell ? '#compdef {{app_name}}\n###-begin-{{app_name}}-completions-###\n#\n# yargs command completion script\n#\n# Installation: {{app_path}} {{completion_command}} >> ~/.zshrc\n#    or {{app_path}} {{completion_command}} >> ~/.zprofile on OSX.\n#\n_{{app_name}}_yargs_completions()\n{\n  local reply\n  local si=$IFS\n  IFS=$\'\n\' reply=($(COMP_CWORD="$((CURRENT-1))" COMP_LINE="$BUFFER" COMP_POINT="$CURSOR" {{app_path}} --get-yargs-completions "${words[@]}"))\n  IFS=$si\n  _describe \'values\' reply\n}\ncompdef _{{app_name}}_yargs_completions {{app_name}}\n###-end-{{app_name}}-completions-###\n' : '###-begin-{{app_name}}-completions-###\n#\n# yargs command completion script\n#\n# Installation: {{app_path}} {{completion_command}} >> ~/.bashrc\n#    or {{app_path}} {{completion_command}} >> ~/.bash_profile on OSX.\n#\n_{{app_name}}_yargs_completions()\n{\n    local cur_word args type_list\n\n    cur_word="${COMP_WORDS[COMP_CWORD]}"\n    args=("${COMP_WORDS[@]}")\n\n    # ask yargs to generate completions.\n    type_list=$({{app_path}} --get-yargs-completions "${args[@]}")\n\n    COMPREPLY=( $(compgen -W "${type_list}" -- ${cur_word}) )\n\n    # if no match was found, fall back to filename completion\n    if [ ${#COMPREPLY[@]} -eq 0 ]; then\n      COMPREPLY=()\n    fi\n\n    return 0\n}\ncomplete -o bashdefault -o default -F _{{app_name}}_yargs_completions {{app_name}}\n###-end-{{app_name}}-completions-###\n'; const i = this.shim.path.basename(t); return t.match(/\.js$/) && (t = `./${t}`), s = s.replace(/{{app_name}}/g, i), s = s.replace(/{{completion_command}}/g, e), s.replace(/{{app_path}}/g, t); }
        registerFunction(t) { this.customCompletionFunction = t; }
        setParsed(t) { this.aliases = t.aliases; }
    }
    function N(t, e) { if (0 === t.length)
        return e.length; if (0 === e.length)
        return t.length; const s = []; let i, n; for (i = 0; i <= e.length; i++)
        s[i] = [i]; for (n = 0; n <= t.length; n++)
        s[0][n] = n; for (i = 1; i <= e.length; i++)
        for (n = 1; n <= t.length; n++)
            e.charAt(i - 1) === t.charAt(n - 1) ? s[i][n] = s[i - 1][n - 1] : i > 1 && n > 1 && e.charAt(i - 2) === t.charAt(n - 1) && e.charAt(i - 1) === t.charAt(n - 2) ? s[i][n] = s[i - 2][n - 2] + 1 : s[i][n] = Math.min(s[i - 1][n - 1] + 1, Math.min(s[i][n - 1] + 1, s[i - 1][n] + 1)); return s[e.length][t.length]; }
    const H = ["$0", "--", "_"];
    var z, W, q, U, F, L, V, G, R, T, B, K, Y, J, Z, X, Q, tt, et, st, it, nt, rt, ot, at, ht, lt, ct, ft, dt, ut, pt, gt, mt, yt;
    const bt = Symbol("copyDoubleDash"), vt = Symbol("copyDoubleDash"), Ot = Symbol("deleteFromParserHintObject"), wt = Symbol("emitWarning"), Ct = Symbol("freeze"), jt = Symbol("getDollarZero"), Mt = Symbol("getParserConfiguration"), _t = Symbol("getUsageConfiguration"), kt = Symbol("guessLocale"), xt = Symbol("guessVersion"), Et = Symbol("parsePositionalNumbers"), At = Symbol("pkgUp"), Pt = Symbol("populateParserHintArray"), St = Symbol("populateParserHintSingleValueDictionary"), $t = Symbol("populateParserHintArrayDictionary"), It = Symbol("populateParserHintDictionary"), Dt = Symbol("sanitizeKey"), Nt = Symbol("setKey"), Ht = Symbol("unfreeze"), zt = Symbol("validateAsync"), Wt = Symbol("getCommandInstance"), qt = Symbol("getContext"), Ut = Symbol("getHasOutput"), Ft = Symbol("getLoggerInstance"), Lt = Symbol("getParseContext"), Vt = Symbol("getUsageInstance"), Gt = Symbol("getValidationInstance"), Rt = Symbol("hasParseCallback"), Tt = Symbol("isGlobalContext"), Bt = Symbol("postProcess"), Kt = Symbol("rebase"), Yt = Symbol("reset"), Jt = Symbol("runYargsParserAndExecuteCommands"), Zt = Symbol("runValidation"), Xt = Symbol("setHasOutput"), Qt = Symbol("kTrackManuallySetKeys");
    class te {
        constructor(t = [], e, s, i) { this.customScriptName = !1, this.parsed = !1, z.set(this, void 0), W.set(this, void 0), q.set(this, { commands: [], fullCommands: [] }), U.set(this, null), F.set(this, null), L.set(this, "show-hidden"), V.set(this, null), G.set(this, !0), R.set(this, {}), T.set(this, !0), B.set(this, []), K.set(this, void 0), Y.set(this, {}), J.set(this, !1), Z.set(this, null), X.set(this, !0), Q.set(this, void 0), tt.set(this, ""), et.set(this, void 0), st.set(this, void 0), it.set(this, {}), nt.set(this, null), rt.set(this, null), ot.set(this, {}), at.set(this, {}), ht.set(this, void 0), lt.set(this, !1), ct.set(this, void 0), ft.set(this, !1), dt.set(this, !1), ut.set(this, !1), pt.set(this, void 0), gt.set(this, {}), mt.set(this, null), yt.set(this, void 0), O(this, ct, i, "f"), O(this, ht, t, "f"), O(this, W, e, "f"), O(this, st, s, "f"), O(this, K, new w(this), "f"), this.$0 = this[jt](), this[Yt](), O(this, z, v(this, z, "f"), "f"), O(this, pt, v(this, pt, "f"), "f"), O(this, yt, v(this, yt, "f"), "f"), O(this, et, v(this, et, "f"), "f"), v(this, et, "f").showHiddenOpt = v(this, L, "f"), O(this, Q, this[vt](), "f"); }
        addHelpOpt(t, e) { return h("[string|boolean] [string]", [t, e], arguments.length), v(this, Z, "f") && (this[Ot](v(this, Z, "f")), O(this, Z, null, "f")), !1 === t && void 0 === e || (O(this, Z, "string" == typeof t ? t : "help", "f"), this.boolean(v(this, Z, "f")), this.describe(v(this, Z, "f"), e || v(this, pt, "f").deferY18nLookup("Show help"))), this; }
        help(t, e) { return this.addHelpOpt(t, e); }
        addShowHiddenOpt(t, e) { if (h("[string|boolean] [string]", [t, e], arguments.length), !1 === t && void 0 === e)
            return this; const s = "string" == typeof t ? t : v(this, L, "f"); return this.boolean(s), this.describe(s, e || v(this, pt, "f").deferY18nLookup("Show hidden options")), v(this, et, "f").showHiddenOpt = s, this; }
        showHidden(t, e) { return this.addShowHiddenOpt(t, e); }
        alias(t, e) { return h("<object|string|array> [string|array]", [t, e], arguments.length), this[$t](this.alias.bind(this), "alias", t, e), this; }
        array(t) { return h("<array|string>", [t], arguments.length), this[Pt]("array", t), this[Qt](t), this; }
        boolean(t) { return h("<array|string>", [t], arguments.length), this[Pt]("boolean", t), this[Qt](t), this; }
        check(t, e) { return h("<function> [boolean]", [t, e], arguments.length), this.middleware(((e, s) => j((() => t(e, s.getOptions())), (s => (s ? ("string" == typeof s || s instanceof Error) && v(this, pt, "f").fail(s.toString(), s) : v(this, pt, "f").fail(v(this, ct, "f").y18n.__("Argument check failed: %s", t.toString())), e)), (t => (v(this, pt, "f").fail(t.message ? t.message : t.toString(), t), e)))), !1, e), this; }
        choices(t, e) { return h("<object|string|array> [string|array]", [t, e], arguments.length), this[$t](this.choices.bind(this), "choices", t, e), this; }
        coerce(t, s) { if (h("<object|string|array> [function]", [t, s], arguments.length), Array.isArray(t)) {
            if (!s)
                throw new e("coerce callback must be provided");
            for (const e of t)
                this.coerce(e, s);
            return this;
        } if ("object" == typeof t) {
            for (const e of Object.keys(t))
                this.coerce(e, t[e]);
            return this;
        } if (!s)
            throw new e("coerce callback must be provided"); return v(this, et, "f").key[t] = !0, v(this, K, "f").addCoerceMiddleware(((i, n) => { let r; return Object.prototype.hasOwnProperty.call(i, t) ? j((() => (r = n.getAliases(), s(i[t]))), (e => { i[t] = e; const s = n.getInternalMethods().getParserConfiguration()["strip-aliased"]; if (r[t] && !0 !== s)
            for (const s of r[t])
                i[s] = e; return i; }), (t => { throw new e(t.message); })) : i; }), t), this; }
        conflicts(t, e) { return h("<string|object> [string|array]", [t, e], arguments.length), v(this, yt, "f").conflicts(t, e), this; }
        config(t = "config", e, s) { return h("[object|string] [string|function] [function]", [t, e, s], arguments.length), "object" != typeof t || Array.isArray(t) ? ("function" == typeof e && (s = e, e = void 0), this.describe(t, e || v(this, pt, "f").deferY18nLookup("Path to JSON config file")), (Array.isArray(t) ? t : [t]).forEach((t => { v(this, et, "f").config[t] = s || !0; })), this) : (t = n(t, v(this, W, "f"), this[Mt]()["deep-merge-config"] || !1, v(this, ct, "f")), v(this, et, "f").configObjects = (v(this, et, "f").configObjects || []).concat(t), this); }
        completion(t, e, s) { return h("[string] [string|boolean|function] [function]", [t, e, s], arguments.length), "function" == typeof e && (s = e, e = void 0), O(this, F, t || v(this, F, "f") || "completion", "f"), e || !1 === e || (e = "generate completion script"), this.command(v(this, F, "f"), e), s && v(this, U, "f").registerFunction(s), this; }
        command(t, e, s, i, n, r) { return h("<string|array|object> [string|boolean] [function|object] [function] [array] [boolean|string]", [t, e, s, i, n, r], arguments.length), v(this, z, "f").addHandler(t, e, s, i, n, r), this; }
        commands(t, e, s, i, n, r) { return this.command(t, e, s, i, n, r); }
        commandDir(t, e) { h("<string> [object]", [t, e], arguments.length); const s = v(this, st, "f") || v(this, ct, "f").require; return v(this, z, "f").addDirectory(t, s, v(this, ct, "f").getCallerFile(), e), this; }
        count(t) { return h("<array|string>", [t], arguments.length), this[Pt]("count", t), this[Qt](t), this; }
        default(t, e, s) { return h("<object|string|array> [*] [string]", [t, e, s], arguments.length), s && (u(t, v(this, ct, "f")), v(this, et, "f").defaultDescription[t] = s), "function" == typeof e && (u(t, v(this, ct, "f")), v(this, et, "f").defaultDescription[t] || (v(this, et, "f").defaultDescription[t] = v(this, pt, "f").functionDescription(e)), e = e.call()), this[St](this.default.bind(this), "default", t, e), this; }
        defaults(t, e, s) { return this.default(t, e, s); }
        demandCommand(t = 1, e, s, i) { return h("[number] [number|string] [string|null|undefined] [string|null|undefined]", [t, e, s, i], arguments.length), "number" != typeof e && (s = e, e = 1 / 0), this.global("_", !1), v(this, et, "f").demandedCommands._ = { min: t, max: e, minMsg: s, maxMsg: i }, this; }
        demand(t, e, s) { return Array.isArray(e) ? (e.forEach((t => { d(s, !0, v(this, ct, "f")), this.demandOption(t, s); })), e = 1 / 0) : "number" != typeof e && (s = e, e = 1 / 0), "number" == typeof t ? (d(s, !0, v(this, ct, "f")), this.demandCommand(t, e, s, s)) : Array.isArray(t) ? t.forEach((t => { d(s, !0, v(this, ct, "f")), this.demandOption(t, s); })) : "string" == typeof s ? this.demandOption(t, s) : !0 !== s && void 0 !== s || this.demandOption(t), this; }
        demandOption(t, e) { return h("<object|string|array> [string]", [t, e], arguments.length), this[St](this.demandOption.bind(this), "demandedOptions", t, e), this; }
        deprecateOption(t, e) { return h("<string> [string|boolean]", [t, e], arguments.length), v(this, et, "f").deprecatedOptions[t] = e, this; }
        describe(t, e) { return h("<object|string|array> [string]", [t, e], arguments.length), this[Nt](t, !0), v(this, pt, "f").describe(t, e), this; }
        detectLocale(t) { return h("<boolean>", [t], arguments.length), O(this, G, t, "f"), this; }
        env(t) { return h("[string|boolean]", [t], arguments.length), !1 === t ? delete v(this, et, "f").envPrefix : v(this, et, "f").envPrefix = t || "", this; }
        epilogue(t) { return h("<string>", [t], arguments.length), v(this, pt, "f").epilog(t), this; }
        epilog(t) { return this.epilogue(t); }
        example(t, e) { return h("<string|array> [string]", [t, e], arguments.length), Array.isArray(t) ? t.forEach((t => this.example(...t))) : v(this, pt, "f").example(t, e), this; }
        exit(t, e) { O(this, J, !0, "f"), O(this, V, e, "f"), v(this, T, "f") && v(this, ct, "f").process.exit(t); }
        exitProcess(t = !0) { return h("[boolean]", [t], arguments.length), O(this, T, t, "f"), this; }
        fail(t) { if (h("<function|boolean>", [t], arguments.length), "boolean" == typeof t && !1 !== t)
            throw new e("Invalid first argument. Expected function or boolean 'false'"); return v(this, pt, "f").failFn(t), this; }
        getAliases() { return this.parsed ? this.parsed.aliases : {}; }
        async getCompletion(t, e) { return h("<array> [function]", [t, e], arguments.length), e ? v(this, U, "f").getCompletion(t, e) : new Promise(((e, s) => { v(this, U, "f").getCompletion(t, ((t, i) => { t ? s(t) : e(i); })); })); }
        getDemandedOptions() { return h([], 0), v(this, et, "f").demandedOptions; }
        getDemandedCommands() { return h([], 0), v(this, et, "f").demandedCommands; }
        getDeprecatedOptions() { return h([], 0), v(this, et, "f").deprecatedOptions; }
        getDetectLocale() { return v(this, G, "f"); }
        getExitProcess() { return v(this, T, "f"); }
        getGroups() { return Object.assign({}, v(this, Y, "f"), v(this, at, "f")); }
        getHelp() { if (O(this, J, !0, "f"), !v(this, pt, "f").hasCachedHelpMessage()) {
            if (!this.parsed) {
                const t = this[Jt](v(this, ht, "f"), void 0, void 0, 0, !0);
                if (f(t))
                    return t.then((() => v(this, pt, "f").help()));
            }
            const t = v(this, z, "f").runDefaultBuilderOn(this);
            if (f(t))
                return t.then((() => v(this, pt, "f").help()));
        } return Promise.resolve(v(this, pt, "f").help()); }
        getOptions() { return v(this, et, "f"); }
        getStrict() { return v(this, ft, "f"); }
        getStrictCommands() { return v(this, dt, "f"); }
        getStrictOptions() { return v(this, ut, "f"); }
        global(t, e) { return h("<string|array> [boolean]", [t, e], arguments.length), t = [].concat(t), !1 !== e ? v(this, et, "f").local = v(this, et, "f").local.filter((e => -1 === t.indexOf(e))) : t.forEach((t => { v(this, et, "f").local.includes(t) || v(this, et, "f").local.push(t); })), this; }
        group(t, e) { h("<string|array> <string>", [t, e], arguments.length); const s = v(this, at, "f")[e] || v(this, Y, "f")[e]; v(this, at, "f")[e] && delete v(this, at, "f")[e]; const i = {}; return v(this, Y, "f")[e] = (s || []).concat(t).filter((t => !i[t] && (i[t] = !0))), this; }
        hide(t) { return h("<string>", [t], arguments.length), v(this, et, "f").hiddenOptions.push(t), this; }
        implies(t, e) { return h("<string|object> [number|string|array]", [t, e], arguments.length), v(this, yt, "f").implies(t, e), this; }
        locale(t) { return h("[string]", [t], arguments.length), void 0 === t ? (this[kt](), v(this, ct, "f").y18n.getLocale()) : (O(this, G, !1, "f"), v(this, ct, "f").y18n.setLocale(t), this); }
        middleware(t, e, s) { return v(this, K, "f").addMiddleware(t, !!e, s); }
        nargs(t, e) { return h("<string|object|array> [number]", [t, e], arguments.length), this[St](this.nargs.bind(this), "narg", t, e), this; }
        normalize(t) { return h("<array|string>", [t], arguments.length), this[Pt]("normalize", t), this; }
        number(t) { return h("<array|string>", [t], arguments.length), this[Pt]("number", t), this[Qt](t), this; }
        option(t, e) { if (h("<string|object> [object]", [t, e], arguments.length), "object" == typeof t)
            Object.keys(t).forEach((e => { this.options(e, t[e]); }));
        else {
            "object" != typeof e && (e = {}), this[Qt](t), !v(this, mt, "f") || "version" !== t && "version" !== (null == e ? void 0 : e.alias) || this[wt](['"version" is a reserved word.', "Please do one of the following:", '- Disable version with `yargs.version(false)` if using "version" as an option', "- Use the built-in `yargs.version` method instead (if applicable)", "- Use a different option key", "https://yargs.js.org/docs/#api-reference-version"].join("\n"), void 0, "versionWarning"), v(this, et, "f").key[t] = !0, e.alias && this.alias(t, e.alias);
            const s = e.deprecate || e.deprecated;
            s && this.deprecateOption(t, s);
            const i = e.demand || e.required || e.require;
            i && this.demand(t, i), e.demandOption && this.demandOption(t, "string" == typeof e.demandOption ? e.demandOption : void 0), e.conflicts && this.conflicts(t, e.conflicts), "default" in e && this.default(t, e.default), void 0 !== e.implies && this.implies(t, e.implies), void 0 !== e.nargs && this.nargs(t, e.nargs), e.config && this.config(t, e.configParser), e.normalize && this.normalize(t), e.choices && this.choices(t, e.choices), e.coerce && this.coerce(t, e.coerce), e.group && this.group(t, e.group), (e.boolean || "boolean" === e.type) && (this.boolean(t), e.alias && this.boolean(e.alias)), (e.array || "array" === e.type) && (this.array(t), e.alias && this.array(e.alias)), (e.number || "number" === e.type) && (this.number(t), e.alias && this.number(e.alias)), (e.string || "string" === e.type) && (this.string(t), e.alias && this.string(e.alias)), (e.count || "count" === e.type) && this.count(t), "boolean" == typeof e.global && this.global(t, e.global), e.defaultDescription && (v(this, et, "f").defaultDescription[t] = e.defaultDescription), e.skipValidation && this.skipValidation(t);
            const n = e.describe || e.description || e.desc, r = v(this, pt, "f").getDescriptions();
            Object.prototype.hasOwnProperty.call(r, t) && "string" != typeof n || this.describe(t, n), e.hidden && this.hide(t), e.requiresArg && this.requiresArg(t);
        } return this; }
        options(t, e) { return this.option(t, e); }
        parse(t, e, s) { h("[string|array] [function|boolean|object] [function]", [t, e, s], arguments.length), this[Ct](), void 0 === t && (t = v(this, ht, "f")), "object" == typeof e && (O(this, rt, e, "f"), e = s), "function" == typeof e && (O(this, nt, e, "f"), e = !1), e || O(this, ht, t, "f"), v(this, nt, "f") && O(this, T, !1, "f"); const i = this[Jt](t, !!e), n = this.parsed; return v(this, U, "f").setParsed(this.parsed), f(i) ? i.then((t => (v(this, nt, "f") && v(this, nt, "f").call(this, v(this, V, "f"), t, v(this, tt, "f")), t))).catch((t => { throw v(this, nt, "f") && v(this, nt, "f")(t, this.parsed.argv, v(this, tt, "f")), t; })).finally((() => { this[Ht](), this.parsed = n; })) : (v(this, nt, "f") && v(this, nt, "f").call(this, v(this, V, "f"), i, v(this, tt, "f")), this[Ht](), this.parsed = n, i); }
        parseAsync(t, e, s) { const i = this.parse(t, e, s); return f(i) ? i : Promise.resolve(i); }
        parseSync(t, s, i) { const n = this.parse(t, s, i); if (f(n))
            throw new e(".parseSync() must not be used with asynchronous builders, handlers, or middleware"); return n; }
        parserConfiguration(t) { return h("<object>", [t], arguments.length), O(this, it, t, "f"), this; }
        pkgConf(t, e) { h("<string> [string]", [t, e], arguments.length); let s = null; const i = this[At](e || v(this, W, "f")); return i[t] && "object" == typeof i[t] && (s = n(i[t], e || v(this, W, "f"), this[Mt]()["deep-merge-config"] || !1, v(this, ct, "f")), v(this, et, "f").configObjects = (v(this, et, "f").configObjects || []).concat(s)), this; }
        positional(t, e) { h("<string> <object>", [t, e], arguments.length); const s = ["default", "defaultDescription", "implies", "normalize", "choices", "conflicts", "coerce", "type", "describe", "desc", "description", "alias"]; e = g(e, ((t, e) => !("type" === t && !["string", "number", "boolean"].includes(e)) && s.includes(t))); const i = v(this, q, "f").fullCommands[v(this, q, "f").fullCommands.length - 1], n = i ? v(this, z, "f").cmdToParseOptions(i) : { array: [], alias: {}, default: {}, demand: {} }; return p(n).forEach((s => { const i = n[s]; Array.isArray(i) ? -1 !== i.indexOf(t) && (e[s] = !0) : i[t] && !(s in e) && (e[s] = i[t]); })), this.group(t, v(this, pt, "f").getPositionalGroupName()), this.option(t, e); }
        recommendCommands(t = !0) { return h("[boolean]", [t], arguments.length), O(this, lt, t, "f"), this; }
        required(t, e, s) { return this.demand(t, e, s); }
        require(t, e, s) { return this.demand(t, e, s); }
        requiresArg(t) { return h("<array|string|object> [number]", [t], arguments.length), "string" == typeof t && v(this, et, "f").narg[t] || this[St](this.requiresArg.bind(this), "narg", t, NaN), this; }
        showCompletionScript(t, e) { return h("[string] [string]", [t, e], arguments.length), t = t || this.$0, v(this, Q, "f").log(v(this, U, "f").generateCompletionScript(t, e || v(this, F, "f") || "completion")), this; }
        showHelp(t) { if (h("[string|function]", [t], arguments.length), O(this, J, !0, "f"), !v(this, pt, "f").hasCachedHelpMessage()) {
            if (!this.parsed) {
                const e = this[Jt](v(this, ht, "f"), void 0, void 0, 0, !0);
                if (f(e))
                    return e.then((() => { v(this, pt, "f").showHelp(t); })), this;
            }
            const e = v(this, z, "f").runDefaultBuilderOn(this);
            if (f(e))
                return e.then((() => { v(this, pt, "f").showHelp(t); })), this;
        } return v(this, pt, "f").showHelp(t), this; }
        scriptName(t) { return this.customScriptName = !0, this.$0 = t, this; }
        showHelpOnFail(t, e) { return h("[boolean|string] [string]", [t, e], arguments.length), v(this, pt, "f").showHelpOnFail(t, e), this; }
        showVersion(t) { return h("[string|function]", [t], arguments.length), v(this, pt, "f").showVersion(t), this; }
        skipValidation(t) { return h("<array|string>", [t], arguments.length), this[Pt]("skipValidation", t), this; }
        strict(t) { return h("[boolean]", [t], arguments.length), O(this, ft, !1 !== t, "f"), this; }
        strictCommands(t) { return h("[boolean]", [t], arguments.length), O(this, dt, !1 !== t, "f"), this; }
        strictOptions(t) { return h("[boolean]", [t], arguments.length), O(this, ut, !1 !== t, "f"), this; }
        string(t) { return h("<array|string>", [t], arguments.length), this[Pt]("string", t), this[Qt](t), this; }
        terminalWidth() { return h([], 0), v(this, ct, "f").process.stdColumns; }
        updateLocale(t) { return this.updateStrings(t); }
        updateStrings(t) { return h("<object>", [t], arguments.length), O(this, G, !1, "f"), v(this, ct, "f").y18n.updateLocale(t), this; }
        usage(t, s, i, n) { if (h("<string|null|undefined> [string|boolean] [function|object] [function]", [t, s, i, n], arguments.length), void 0 !== s) {
            if (d(t, null, v(this, ct, "f")), (t || "").match(/^\$0( |$)/))
                return this.command(t, s, i, n);
            throw new e(".usage() description must start with $0 if being used as alias for .command()");
        } return v(this, pt, "f").usage(t), this; }
        usageConfiguration(t) { return h("<object>", [t], arguments.length), O(this, gt, t, "f"), this; }
        version(t, e, s) { const i = "version"; if (h("[boolean|string] [string] [string]", [t, e, s], arguments.length), v(this, mt, "f") && (this[Ot](v(this, mt, "f")), v(this, pt, "f").version(void 0), O(this, mt, null, "f")), 0 === arguments.length)
            s = this[xt](), t = i;
        else if (1 === arguments.length) {
            if (!1 === t)
                return this;
            s = t, t = i;
        }
        else
            2 === arguments.length && (s = e, e = void 0); return O(this, mt, "string" == typeof t ? t : i, "f"), e = e || v(this, pt, "f").deferY18nLookup("Show version number"), v(this, pt, "f").version(s || void 0), this.boolean(v(this, mt, "f")), this.describe(v(this, mt, "f"), e), this; }
        wrap(t) { return h("<number|null|undefined>", [t], arguments.length), v(this, pt, "f").wrap(t), this; }
        [(z = new WeakMap, W = new WeakMap, q = new WeakMap, U = new WeakMap, F = new WeakMap, L = new WeakMap, V = new WeakMap, G = new WeakMap, R = new WeakMap, T = new WeakMap, B = new WeakMap, K = new WeakMap, Y = new WeakMap, J = new WeakMap, Z = new WeakMap, X = new WeakMap, Q = new WeakMap, tt = new WeakMap, et = new WeakMap, st = new WeakMap, it = new WeakMap, nt = new WeakMap, rt = new WeakMap, ot = new WeakMap, at = new WeakMap, ht = new WeakMap, lt = new WeakMap, ct = new WeakMap, ft = new WeakMap, dt = new WeakMap, ut = new WeakMap, pt = new WeakMap, gt = new WeakMap, mt = new WeakMap, yt = new WeakMap, bt)](t) { if (!t._ || !t["--"])
            return t; t._.push.apply(t._, t["--"]); try {
            delete t["--"];
        }
        catch (t) { } return t; }
        [vt]() { return { log: (...t) => { this[Rt]() || console.log(...t), O(this, J, !0, "f"), v(this, tt, "f").length && O(this, tt, v(this, tt, "f") + "\n", "f"), O(this, tt, v(this, tt, "f") + t.join(" "), "f"); }, error: (...t) => { this[Rt]() || console.error(...t), O(this, J, !0, "f"), v(this, tt, "f").length && O(this, tt, v(this, tt, "f") + "\n", "f"), O(this, tt, v(this, tt, "f") + t.join(" "), "f"); } }; }
        [Ot](t) { p(v(this, et, "f")).forEach((e => { if ("configObjects" === e)
            return; const s = v(this, et, "f")[e]; Array.isArray(s) ? s.includes(t) && s.splice(s.indexOf(t), 1) : "object" == typeof s && delete s[t]; })), delete v(this, pt, "f").getDescriptions()[t]; }
        [wt](t, e, s) { v(this, R, "f")[s] || (v(this, ct, "f").process.emitWarning(t, e), v(this, R, "f")[s] = !0); }
        [Ct]() { v(this, B, "f").push({ options: v(this, et, "f"), configObjects: v(this, et, "f").configObjects.slice(0), exitProcess: v(this, T, "f"), groups: v(this, Y, "f"), strict: v(this, ft, "f"), strictCommands: v(this, dt, "f"), strictOptions: v(this, ut, "f"), completionCommand: v(this, F, "f"), output: v(this, tt, "f"), exitError: v(this, V, "f"), hasOutput: v(this, J, "f"), parsed: this.parsed, parseFn: v(this, nt, "f"), parseContext: v(this, rt, "f") }), v(this, pt, "f").freeze(), v(this, yt, "f").freeze(), v(this, z, "f").freeze(), v(this, K, "f").freeze(); }
        [jt]() { let t, e = ""; return t = /\b(node|iojs|electron)(\.exe)?$/.test(v(this, ct, "f").process.argv()[0]) ? v(this, ct, "f").process.argv().slice(1, 2) : v(this, ct, "f").process.argv().slice(0, 1), e = t.map((t => { const e = this[Kt](v(this, W, "f"), t); return t.match(/^(\/|([a-zA-Z]:)?\\)/) && e.length < t.length ? e : t; })).join(" ").trim(), v(this, ct, "f").getEnv("_") && v(this, ct, "f").getProcessArgvBin() === v(this, ct, "f").getEnv("_") && (e = v(this, ct, "f").getEnv("_").replace(`${v(this, ct, "f").path.dirname(v(this, ct, "f").process.execPath())}/`, "")), e; }
        [Mt]() { return v(this, it, "f"); }
        [_t]() { return v(this, gt, "f"); }
        [kt]() { if (!v(this, G, "f"))
            return; const t = v(this, ct, "f").getEnv("LC_ALL") || v(this, ct, "f").getEnv("LC_MESSAGES") || v(this, ct, "f").getEnv("LANG") || v(this, ct, "f").getEnv("LANGUAGE") || "en_US"; this.locale(t.replace(/[.:].*/, "")); }
        [xt]() { return this[At]().version || "unknown"; }
        [Et](t) { const e = t["--"] ? t["--"] : t._; for (let t, s = 0; void 0 !== (t = e[s]); s++)
            v(this, ct, "f").Parser.looksLikeNumber(t) && Number.isSafeInteger(Math.floor(parseFloat(`${t}`))) && (e[s] = Number(t)); return t; }
        [At](t) { const e = t || "*"; if (v(this, ot, "f")[e])
            return v(this, ot, "f")[e]; let s = {}; try {
            let e = t || v(this, ct, "f").mainFilename;
            !t && v(this, ct, "f").path.extname(e) && (e = v(this, ct, "f").path.dirname(e));
            const i = v(this, ct, "f").findUp(e, ((t, e) => e.includes("package.json") ? "package.json" : void 0));
            d(i, void 0, v(this, ct, "f")), s = JSON.parse(v(this, ct, "f").readFileSync(i, "utf8"));
        }
        catch (t) { } return v(this, ot, "f")[e] = s || {}, v(this, ot, "f")[e]; }
        [Pt](t, e) { (e = [].concat(e)).forEach((e => { e = this[Dt](e), v(this, et, "f")[t].push(e); })); }
        [St](t, e, s, i) { this[It](t, e, s, i, ((t, e, s) => { v(this, et, "f")[t][e] = s; })); }
        [$t](t, e, s, i) { this[It](t, e, s, i, ((t, e, s) => { v(this, et, "f")[t][e] = (v(this, et, "f")[t][e] || []).concat(s); })); }
        [It](t, e, s, i, n) { if (Array.isArray(s))
            s.forEach((e => { t(e, i); }));
        else if ((t => "object" == typeof t)(s))
            for (const e of p(s))
                t(e, s[e]);
        else
            n(e, this[Dt](s), i); }
        [Dt](t) { return "__proto__" === t ? "___proto___" : t; }
        [Nt](t, e) { return this[St](this[Nt].bind(this), "key", t, e), this; }
        [Ht]() { var t, e, s, i, n, r, o, a, h, l, c, f; const u = v(this, B, "f").pop(); let p; d(u, void 0, v(this, ct, "f")), t = this, e = this, s = this, i = this, n = this, r = this, o = this, a = this, h = this, l = this, c = this, f = this, ({ options: { set value(e) { O(t, et, e, "f"); } }.value, configObjects: p, exitProcess: { set value(t) { O(e, T, t, "f"); } }.value, groups: { set value(t) { O(s, Y, t, "f"); } }.value, output: { set value(t) { O(i, tt, t, "f"); } }.value, exitError: { set value(t) { O(n, V, t, "f"); } }.value, hasOutput: { set value(t) { O(r, J, t, "f"); } }.value, parsed: this.parsed, strict: { set value(t) { O(o, ft, t, "f"); } }.value, strictCommands: { set value(t) { O(a, dt, t, "f"); } }.value, strictOptions: { set value(t) { O(h, ut, t, "f"); } }.value, completionCommand: { set value(t) { O(l, F, t, "f"); } }.value, parseFn: { set value(t) { O(c, nt, t, "f"); } }.value, parseContext: { set value(t) { O(f, rt, t, "f"); } }.value } = u), v(this, et, "f").configObjects = p, v(this, pt, "f").unfreeze(), v(this, yt, "f").unfreeze(), v(this, z, "f").unfreeze(), v(this, K, "f").unfreeze(); }
        [zt](t, e) { return j(e, (e => (t(e), e))); }
        getInternalMethods() { return { getCommandInstance: this[Wt].bind(this), getContext: this[qt].bind(this), getHasOutput: this[Ut].bind(this), getLoggerInstance: this[Ft].bind(this), getParseContext: this[Lt].bind(this), getParserConfiguration: this[Mt].bind(this), getUsageConfiguration: this[_t].bind(this), getUsageInstance: this[Vt].bind(this), getValidationInstance: this[Gt].bind(this), hasParseCallback: this[Rt].bind(this), isGlobalContext: this[Tt].bind(this), postProcess: this[Bt].bind(this), reset: this[Yt].bind(this), runValidation: this[Zt].bind(this), runYargsParserAndExecuteCommands: this[Jt].bind(this), setHasOutput: this[Xt].bind(this) }; }
        [Wt]() { return v(this, z, "f"); }
        [qt]() { return v(this, q, "f"); }
        [Ut]() { return v(this, J, "f"); }
        [Ft]() { return v(this, Q, "f"); }
        [Lt]() { return v(this, rt, "f") || {}; }
        [Vt]() { return v(this, pt, "f"); }
        [Gt]() { return v(this, yt, "f"); }
        [Rt]() { return !!v(this, nt, "f"); }
        [Tt]() { return v(this, X, "f"); }
        [Bt](t, e, s, i) { if (s)
            return t; if (f(t))
            return t; e || (t = this[bt](t)); return (this[Mt]()["parse-positional-numbers"] || void 0 === this[Mt]()["parse-positional-numbers"]) && (t = this[Et](t)), i && (t = C(t, this, v(this, K, "f").getMiddleware(), !1)), t; }
        [Yt](t = {}) { O(this, et, v(this, et, "f") || {}, "f"); const e = {}; e.local = v(this, et, "f").local || [], e.configObjects = v(this, et, "f").configObjects || []; const s = {}; e.local.forEach((e => { s[e] = !0, (t[e] || []).forEach((t => { s[t] = !0; })); })), Object.assign(v(this, at, "f"), Object.keys(v(this, Y, "f")).reduce(((t, e) => { const i = v(this, Y, "f")[e].filter((t => !(t in s))); return i.length > 0 && (t[e] = i), t; }), {})), O(this, Y, {}, "f"); return ["array", "boolean", "string", "skipValidation", "count", "normalize", "number", "hiddenOptions"].forEach((t => { e[t] = (v(this, et, "f")[t] || []).filter((t => !s[t])); })), ["narg", "key", "alias", "default", "defaultDescription", "config", "choices", "demandedOptions", "demandedCommands", "deprecatedOptions"].forEach((t => { e[t] = g(v(this, et, "f")[t], (t => !s[t])); })), e.envPrefix = v(this, et, "f").envPrefix, O(this, et, e, "f"), O(this, pt, v(this, pt, "f") ? v(this, pt, "f").reset(s) : P(this, v(this, ct, "f")), "f"), O(this, yt, v(this, yt, "f") ? v(this, yt, "f").reset(s) : function (t, e, s) { const i = s.y18n.__, n = s.y18n.__n, r = { nonOptionCount: function (s) { const i = t.getDemandedCommands(), r = s._.length + (s["--"] ? s["--"].length : 0) - t.getInternalMethods().getContext().commands.length; i._ && (r < i._.min || r > i._.max) && (r < i._.min ? void 0 !== i._.minMsg ? e.fail(i._.minMsg ? i._.minMsg.replace(/\$0/g, r.toString()).replace(/\$1/, i._.min.toString()) : null) : e.fail(n("Not enough non-option arguments: got %s, need at least %s", "Not enough non-option arguments: got %s, need at least %s", r, r.toString(), i._.min.toString())) : r > i._.max && (void 0 !== i._.maxMsg ? e.fail(i._.maxMsg ? i._.maxMsg.replace(/\$0/g, r.toString()).replace(/\$1/, i._.max.toString()) : null) : e.fail(n("Too many non-option arguments: got %s, maximum of %s", "Too many non-option arguments: got %s, maximum of %s", r, r.toString(), i._.max.toString())))); }, positionalCount: function (t, s) { s < t && e.fail(n("Not enough non-option arguments: got %s, need at least %s", "Not enough non-option arguments: got %s, need at least %s", s, s + "", t + "")); }, requiredArguments: function (t, s) { let i = null; for (const e of Object.keys(s))
                Object.prototype.hasOwnProperty.call(t, e) && void 0 !== t[e] || (i = i || {}, i[e] = s[e]); if (i) {
                const t = [];
                for (const e of Object.keys(i)) {
                    const s = i[e];
                    s && t.indexOf(s) < 0 && t.push(s);
                }
                const s = t.length ? `\n${t.join("\n")}` : "";
                e.fail(n("Missing required argument: %s", "Missing required arguments: %s", Object.keys(i).length, Object.keys(i).join(", ") + s));
            } }, unknownArguments: function (s, i, o, a, h = !0) { var l; const c = t.getInternalMethods().getCommandInstance().getCommands(), f = [], d = t.getInternalMethods().getContext(); if (Object.keys(s).forEach((e => { H.includes(e) || Object.prototype.hasOwnProperty.call(o, e) || Object.prototype.hasOwnProperty.call(t.getInternalMethods().getParseContext(), e) || r.isValidAndSomeAliasIsNotNew(e, i) || f.push(e); })), h && (d.commands.length > 0 || c.length > 0 || a) && s._.slice(d.commands.length).forEach((t => { c.includes("" + t) || f.push("" + t); })), h) {
                const e = (null === (l = t.getDemandedCommands()._) || void 0 === l ? void 0 : l.max) || 0, i = d.commands.length + e;
                i < s._.length && s._.slice(i).forEach((t => { t = String(t), d.commands.includes(t) || f.includes(t) || f.push(t); }));
            } f.length && e.fail(n("Unknown argument: %s", "Unknown arguments: %s", f.length, f.map((t => t.trim() ? t : `"${t}"`)).join(", "))); }, unknownCommands: function (s) { const i = t.getInternalMethods().getCommandInstance().getCommands(), r = [], o = t.getInternalMethods().getContext(); return (o.commands.length > 0 || i.length > 0) && s._.slice(o.commands.length).forEach((t => { i.includes("" + t) || r.push("" + t); })), r.length > 0 && (e.fail(n("Unknown command: %s", "Unknown commands: %s", r.length, r.join(", "))), !0); }, isValidAndSomeAliasIsNotNew: function (e, s) { if (!Object.prototype.hasOwnProperty.call(s, e))
                return !1; const i = t.parsed.newAliases; return [e, ...s[e]].some((t => !Object.prototype.hasOwnProperty.call(i, t) || !i[e])); }, limitedChoices: function (s) { const n = t.getOptions(), r = {}; if (!Object.keys(n.choices).length)
                return; Object.keys(s).forEach((t => { -1 === H.indexOf(t) && Object.prototype.hasOwnProperty.call(n.choices, t) && [].concat(s[t]).forEach((e => { -1 === n.choices[t].indexOf(e) && void 0 !== e && (r[t] = (r[t] || []).concat(e)); })); })); const o = Object.keys(r); if (!o.length)
                return; let a = i("Invalid values:"); o.forEach((t => { a += `\n  ${i("Argument: %s, Given: %s, Choices: %s", t, e.stringifiedValues(r[t]), e.stringifiedValues(n.choices[t]))}`; })), e.fail(a); } }; let o = {}; function a(t, e) { const s = Number(e); return "number" == typeof (e = isNaN(s) ? e : s) ? e = t._.length >= e : e.match(/^--no-.+/) ? (e = e.match(/^--no-(.+)/)[1], e = !Object.prototype.hasOwnProperty.call(t, e)) : e = Object.prototype.hasOwnProperty.call(t, e), e; } r.implies = function (e, i) { h("<string|object> [array|number|string]", [e, i], arguments.length), "object" == typeof e ? Object.keys(e).forEach((t => { r.implies(t, e[t]); })) : (t.global(e), o[e] || (o[e] = []), Array.isArray(i) ? i.forEach((t => r.implies(e, t))) : (d(i, void 0, s), o[e].push(i))); }, r.getImplied = function () { return o; }, r.implications = function (t) { const s = []; if (Object.keys(o).forEach((e => { const i = e; (o[e] || []).forEach((e => { let n = i; const r = e; n = a(t, n), e = a(t, e), n && !e && s.push(` ${i} -> ${r}`); })); })), s.length) {
            let t = `${i("Implications failed:")}\n`;
            s.forEach((e => { t += e; })), e.fail(t);
        } }; let l = {}; r.conflicts = function (e, s) { h("<string|object> [array|string]", [e, s], arguments.length), "object" == typeof e ? Object.keys(e).forEach((t => { r.conflicts(t, e[t]); })) : (t.global(e), l[e] || (l[e] = []), Array.isArray(s) ? s.forEach((t => r.conflicts(e, t))) : l[e].push(s)); }, r.getConflicting = () => l, r.conflicting = function (n) { Object.keys(n).forEach((t => { l[t] && l[t].forEach((s => { s && void 0 !== n[t] && void 0 !== n[s] && e.fail(i("Arguments %s and %s are mutually exclusive", t, s)); })); })), t.getInternalMethods().getParserConfiguration()["strip-dashed"] && Object.keys(l).forEach((t => { l[t].forEach((r => { r && void 0 !== n[s.Parser.camelCase(t)] && void 0 !== n[s.Parser.camelCase(r)] && e.fail(i("Arguments %s and %s are mutually exclusive", t, r)); })); })); }, r.recommendCommands = function (t, s) { s = s.sort(((t, e) => e.length - t.length)); let n = null, r = 1 / 0; for (let e, i = 0; void 0 !== (e = s[i]); i++) {
            const s = N(t, e);
            s <= 3 && s < r && (r = s, n = e);
        } n && e.fail(i("Did you mean %s?", n)); }, r.reset = function (t) { return o = g(o, (e => !t[e])), l = g(l, (e => !t[e])), r; }; const c = []; return r.freeze = function () { c.push({ implied: o, conflicting: l }); }, r.unfreeze = function () { const t = c.pop(); d(t, void 0, s), ({ implied: o, conflicting: l } = t); }, r; }(this, v(this, pt, "f"), v(this, ct, "f")), "f"), O(this, z, v(this, z, "f") ? v(this, z, "f").reset() : function (t, e, s, i) { return new _(t, e, s, i); }(v(this, pt, "f"), v(this, yt, "f"), v(this, K, "f"), v(this, ct, "f")), "f"), v(this, U, "f") || O(this, U, function (t, e, s, i) { return new D(t, e, s, i); }(this, v(this, pt, "f"), v(this, z, "f"), v(this, ct, "f")), "f"), v(this, K, "f").reset(), O(this, F, null, "f"), O(this, tt, "", "f"), O(this, V, null, "f"), O(this, J, !1, "f"), this.parsed = !1, this; }
        [Kt](t, e) { return v(this, ct, "f").path.relative(t, e); }
        [Jt](t, s, i, n = 0, r = !1) { let o = !!i || r; t = t || v(this, ht, "f"), v(this, et, "f").__ = v(this, ct, "f").y18n.__, v(this, et, "f").configuration = this[Mt](); const a = !!v(this, et, "f").configuration["populate--"], h = Object.assign({}, v(this, et, "f").configuration, { "populate--": !0 }), l = v(this, ct, "f").Parser.detailed(t, Object.assign({}, v(this, et, "f"), { configuration: { "parse-positional-numbers": !1, ...h } })), c = Object.assign(l.argv, v(this, rt, "f")); let d; const u = l.aliases; let p = !1, g = !1; Object.keys(c).forEach((t => { t === v(this, Z, "f") && c[t] ? p = !0 : t === v(this, mt, "f") && c[t] && (g = !0); })), c.$0 = this.$0, this.parsed = l, 0 === n && v(this, pt, "f").clearCachedHelpMessage(); try {
            if (this[kt](), s)
                return this[Bt](c, a, !!i, !1);
            if (v(this, Z, "f")) {
                [v(this, Z, "f")].concat(u[v(this, Z, "f")] || []).filter((t => t.length > 1)).includes("" + c._[c._.length - 1]) && (c._.pop(), p = !0);
            }
            O(this, X, !1, "f");
            const h = v(this, z, "f").getCommands(), m = v(this, U, "f").completionKey in c, y = p || m || r;
            if (c._.length) {
                if (h.length) {
                    let t;
                    for (let e, s = n || 0; void 0 !== c._[s]; s++) {
                        if (e = String(c._[s]), h.includes(e) && e !== v(this, F, "f")) {
                            const t = v(this, z, "f").runCommand(e, this, l, s + 1, r, p || g || r);
                            return this[Bt](t, a, !!i, !1);
                        }
                        if (!t && e !== v(this, F, "f")) {
                            t = e;
                            break;
                        }
                    }
                    !v(this, z, "f").hasDefaultCommand() && v(this, lt, "f") && t && !y && v(this, yt, "f").recommendCommands(t, h);
                }
                v(this, F, "f") && c._.includes(v(this, F, "f")) && !m && (v(this, T, "f") && E(!0), this.showCompletionScript(), this.exit(0));
            }
            if (v(this, z, "f").hasDefaultCommand() && !y) {
                const t = v(this, z, "f").runCommand(null, this, l, 0, r, p || g || r);
                return this[Bt](t, a, !!i, !1);
            }
            if (m) {
                v(this, T, "f") && E(!0);
                const s = (t = [].concat(t)).slice(t.indexOf(`--${v(this, U, "f").completionKey}`) + 1);
                return v(this, U, "f").getCompletion(s, ((t, s) => { if (t)
                    throw new e(t.message); (s || []).forEach((t => { v(this, Q, "f").log(t); })), this.exit(0); })), this[Bt](c, !a, !!i, !1);
            }
            if (v(this, J, "f") || (p ? (v(this, T, "f") && E(!0), o = !0, this.showHelp("log"), this.exit(0)) : g && (v(this, T, "f") && E(!0), o = !0, v(this, pt, "f").showVersion("log"), this.exit(0))), !o && v(this, et, "f").skipValidation.length > 0 && (o = Object.keys(c).some((t => v(this, et, "f").skipValidation.indexOf(t) >= 0 && !0 === c[t]))), !o) {
                if (l.error)
                    throw new e(l.error.message);
                if (!m) {
                    const t = this[Zt](u, {}, l.error);
                    i || (d = C(c, this, v(this, K, "f").getMiddleware(), !0)), d = this[zt](t, null != d ? d : c), f(d) && !i && (d = d.then((() => C(c, this, v(this, K, "f").getMiddleware(), !1))));
                }
            }
        }
        catch (t) {
            if (!(t instanceof e))
                throw t;
            v(this, pt, "f").fail(t.message, t);
        } return this[Bt](null != d ? d : c, a, !!i, !0); }
        [Zt](t, s, i, n) { const r = { ...this.getDemandedOptions() }; return o => { if (i)
            throw new e(i.message); v(this, yt, "f").nonOptionCount(o), v(this, yt, "f").requiredArguments(o, r); let a = !1; v(this, dt, "f") && (a = v(this, yt, "f").unknownCommands(o)), v(this, ft, "f") && !a ? v(this, yt, "f").unknownArguments(o, t, s, !!n) : v(this, ut, "f") && v(this, yt, "f").unknownArguments(o, t, {}, !1, !1), v(this, yt, "f").limitedChoices(o), v(this, yt, "f").implications(o), v(this, yt, "f").conflicting(o); }; }
        [Xt]() { O(this, J, !0, "f"); }
        [Qt](t) { if ("string" == typeof t)
            v(this, et, "f").key[t] = !0;
        else
            for (const e of t)
                v(this, et, "f").key[e] = !0; }
    }
    var ee, se;
    const { readFileSync: ie } = require("fs"), { inspect: ne } = require("util"), { resolve: re } = require("path"), oe = require(3) /* y18n */, ae = require(4) /* yargs-parser */;
    var he, le = { assert: { notStrictEqual: t.notStrictEqual, strictEqual: t.strictEqual }, cliui: require(5) /* cliui */, findUp: require(17) /* escalade/sync */, getEnv: t => process.env[t], getCallerFile: require(18) /* get-caller-file */, getProcessArgvBin: y, inspect: ne, mainFilename: null !== (se = null === (ee = null === require || void 0 === require ? void 0 : require.main) || void 0 === ee ? void 0 : ee.filename) && void 0 !== se ? se : process.cwd(), Parser: ae, path: require("path"), process: { argv: () => process.argv, cwd: process.cwd, emitWarning: (t, e) => process.emitWarning(t, e), execPath: () => process.execPath, exit: t => { process.exit(t); }, nextTick: process.nextTick, stdColumns: void 0 !== process.stdout.columns ? process.stdout.columns : null }, readFileSync: ie, require: require, requireDirectory: require(19) /* require-directory */, stringWidth: require(6) /* string-width */, y18n: oe({ directory: re(__dirname, "../locales"), updateFiles: !1 }) };
    const ce = (null === (he = null === process || void 0 === process ? void 0 : process.env) || void 0 === he ? void 0 : he.YARGS_MIN_NODE_VERSION) ? Number(process.env.YARGS_MIN_NODE_VERSION) : 12;
    if (process && process.version) {
        if (Number(process.version.match(/v([^.]+)/)[1]) < ce)
            throw Error(`yargs supports a minimum Node.js version of ${ce}. Read our version support policy: https://github.com/yargs/yargs#supported-nodejs-versions`);
    }
    const fe = require(4) /* yargs-parser */;
    var de, ue = { applyExtends: n, cjsPlatformShim: le, Yargs: (de = le, (t = [], e = de.process.cwd(), s) => { const i = new te(t, e, s, de); return Object.defineProperty(i, "argv", { get: () => i.parse(), enumerable: !0 }), i.help(), i.version(), i; }), argsert: h, isPromise: f, objFilter: g, parseCommand: o, Parser: fe, processArgv: b, YError: e };
    module.exports = ue;
},
/* y18n/build/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var fs = require('fs');
    var util = require('util');
    var path = require('path');
    let shim;
    class Y18N {
        constructor(opts) {
            // configurable options.
            opts = opts || {};
            this.directory = opts.directory || './locales';
            this.updateFiles = typeof opts.updateFiles === 'boolean' ? opts.updateFiles : true;
            this.locale = opts.locale || 'en';
            this.fallbackToLanguage = typeof opts.fallbackToLanguage === 'boolean' ? opts.fallbackToLanguage : true;
            // internal stuff.
            this.cache = Object.create(null);
            this.writeQueue = [];
        }
        __(...args) {
            if (typeof arguments[0] !== 'string') {
                return this._taggedLiteral(arguments[0], ...arguments);
            }
            const str = args.shift();
            let cb = function () { }; // start with noop.
            if (typeof args[args.length - 1] === 'function')
                cb = args.pop();
            cb = cb || function () { }; // noop.
            if (!this.cache[this.locale])
                this._readLocaleFile();
            // we've observed a new string, update the language file.
            if (!this.cache[this.locale][str] && this.updateFiles) {
                this.cache[this.locale][str] = str;
                // include the current directory and locale,
                // since these values could change before the
                // write is performed.
                this._enqueueWrite({
                    directory: this.directory,
                    locale: this.locale,
                    cb
                });
            }
            else {
                cb();
            }
            return shim.format.apply(shim.format, [this.cache[this.locale][str] || str].concat(args));
        }
        __n() {
            const args = Array.prototype.slice.call(arguments);
            const singular = args.shift();
            const plural = args.shift();
            const quantity = args.shift();
            let cb = function () { }; // start with noop.
            if (typeof args[args.length - 1] === 'function')
                cb = args.pop();
            if (!this.cache[this.locale])
                this._readLocaleFile();
            let str = quantity === 1 ? singular : plural;
            if (this.cache[this.locale][singular]) {
                const entry = this.cache[this.locale][singular];
                str = entry[quantity === 1 ? 'one' : 'other'];
            }
            // we've observed a new string, update the language file.
            if (!this.cache[this.locale][singular] && this.updateFiles) {
                this.cache[this.locale][singular] = {
                    one: singular,
                    other: plural
                };
                // include the current directory and locale,
                // since these values could change before the
                // write is performed.
                this._enqueueWrite({
                    directory: this.directory,
                    locale: this.locale,
                    cb
                });
            }
            else {
                cb();
            }
            // if a %d placeholder is provided, add quantity
            // to the arguments expanded by util.format.
            const values = [str];
            if (~str.indexOf('%d'))
                values.push(quantity);
            return shim.format.apply(shim.format, values.concat(args));
        }
        setLocale(locale) {
            this.locale = locale;
        }
        getLocale() {
            return this.locale;
        }
        updateLocale(obj) {
            if (!this.cache[this.locale])
                this._readLocaleFile();
            for (const key in obj) {
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    this.cache[this.locale][key] = obj[key];
                }
            }
        }
        _taggedLiteral(parts, ...args) {
            let str = '';
            parts.forEach(function (part, i) {
                const arg = args[i + 1];
                str += part;
                if (typeof arg !== 'undefined') {
                    str += '%s';
                }
            });
            return this.__.apply(this, [str].concat([].slice.call(args, 1)));
        }
        _enqueueWrite(work) {
            this.writeQueue.push(work);
            if (this.writeQueue.length === 1)
                this._processWriteQueue();
        }
        _processWriteQueue() {
            const _this = this;
            const work = this.writeQueue[0];
            // destructure the enqueued work.
            const directory = work.directory;
            const locale = work.locale;
            const cb = work.cb;
            const languageFile = this._resolveLocaleFile(directory, locale);
            const serializedLocale = JSON.stringify(this.cache[locale], null, 2);
            shim.fs.writeFile(languageFile, serializedLocale, 'utf-8', function (err) {
                _this.writeQueue.shift();
                if (_this.writeQueue.length > 0)
                    _this._processWriteQueue();
                cb(err);
            });
        }
        _readLocaleFile() {
            let localeLookup = {};
            const languageFile = this._resolveLocaleFile(this.directory, this.locale);
            try {
                // When using a bundler such as webpack, readFileSync may not be defined:
                if (shim.fs.readFileSync) {
                    localeLookup = JSON.parse(shim.fs.readFileSync(languageFile, 'utf-8'));
                }
            }
            catch (err) {
                if (err instanceof SyntaxError) {
                    err.message = 'syntax error in ' + languageFile;
                }
                if (err.code === 'ENOENT')
                    localeLookup = {};
                else
                    throw err;
            }
            this.cache[this.locale] = localeLookup;
        }
        _resolveLocaleFile(directory, locale) {
            let file = shim.resolve(directory, './', locale + '.json');
            if (this.fallbackToLanguage && !this._fileExistsSync(file) && ~locale.lastIndexOf('_')) {
                // attempt fallback to language only
                const languageFile = shim.resolve(directory, './', locale.split('_')[0] + '.json');
                if (this._fileExistsSync(languageFile))
                    file = languageFile;
            }
            return file;
        }
        _fileExistsSync(file) {
            return shim.exists(file);
        }
    }
    function y18n$1(opts, _shim) {
        shim = _shim;
        const y18n = new Y18N(opts);
        return {
            __: y18n.__.bind(y18n),
            __n: y18n.__n.bind(y18n),
            setLocale: y18n.setLocale.bind(y18n),
            getLocale: y18n.getLocale.bind(y18n),
            updateLocale: y18n.updateLocale.bind(y18n),
            locale: y18n.locale
        };
    }
    var nodePlatformShim = {
        fs: {
            readFileSync: fs.readFileSync,
            writeFile: fs.writeFile
        },
        format: util.format,
        resolve: path.resolve,
        exists: (file) => {
            try {
                return fs.statSync(file).isFile();
            }
            catch (err) {
                return false;
            }
        }
    };
    const y18n = (opts) => {
        return y18n$1(opts, nodePlatformShim);
    };
    module.exports = y18n;
},
/* yargs-parser/build/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var util = require('util');
    var path = require('path');
    var fs = require('fs');
    function camelCase(str) {
        const isCamelCase = str !== str.toLowerCase() && str !== str.toUpperCase();
        if (!isCamelCase) {
            str = str.toLowerCase();
        }
        if (str.indexOf('-') === -1 && str.indexOf('_') === -1) {
            return str;
        }
        else {
            let camelcase = '';
            let nextChrUpper = false;
            const leadingHyphens = str.match(/^-+/);
            for (let i = leadingHyphens ? leadingHyphens[0].length : 0; i < str.length; i++) {
                let chr = str.charAt(i);
                if (nextChrUpper) {
                    nextChrUpper = false;
                    chr = chr.toUpperCase();
                }
                if (i !== 0 && (chr === '-' || chr === '_')) {
                    nextChrUpper = true;
                }
                else if (chr !== '-' && chr !== '_') {
                    camelcase += chr;
                }
            }
            return camelcase;
        }
    }
    function decamelize(str, joinString) {
        const lowercase = str.toLowerCase();
        joinString = joinString || '-';
        let notCamelcase = '';
        for (let i = 0; i < str.length; i++) {
            const chrLower = lowercase.charAt(i);
            const chrString = str.charAt(i);
            if (chrLower !== chrString && i > 0) {
                notCamelcase += `${joinString}${lowercase.charAt(i)}`;
            }
            else {
                notCamelcase += chrString;
            }
        }
        return notCamelcase;
    }
    function looksLikeNumber(x) {
        if (x === null || x === undefined)
            return false;
        if (typeof x === 'number')
            return true;
        if (/^0x[0-9a-f]+$/i.test(x))
            return true;
        if (/^0[^.]/.test(x))
            return false;
        return /^[-]?(?:\d+(?:\.\d*)?|\.\d+)(e[-+]?\d+)?$/.test(x);
    }
    function tokenizeArgString(argString) {
        if (Array.isArray(argString)) {
            return argString.map(e => typeof e !== 'string' ? e + '' : e);
        }
        argString = argString.trim();
        let i = 0;
        let prevC = null;
        let c = null;
        let opening = null;
        const args = [];
        for (let ii = 0; ii < argString.length; ii++) {
            prevC = c;
            c = argString.charAt(ii);
            if (c === ' ' && !opening) {
                if (!(prevC === ' ')) {
                    i++;
                }
                continue;
            }
            if (c === opening) {
                opening = null;
            }
            else if ((c === "'" || c === '"') && !opening) {
                opening = c;
            }
            if (!args[i])
                args[i] = '';
            args[i] += c;
        }
        return args;
    }
    var DefaultValuesForTypeKey;
    (function (DefaultValuesForTypeKey) {
        DefaultValuesForTypeKey["BOOLEAN"] = "boolean";
        DefaultValuesForTypeKey["STRING"] = "string";
        DefaultValuesForTypeKey["NUMBER"] = "number";
        DefaultValuesForTypeKey["ARRAY"] = "array";
    })(DefaultValuesForTypeKey || (DefaultValuesForTypeKey = {}));
    let mixin;
    class YargsParser {
        constructor(_mixin) {
            mixin = _mixin;
        }
        parse(argsInput, options) {
            const opts = Object.assign({
                alias: undefined,
                array: undefined,
                boolean: undefined,
                config: undefined,
                configObjects: undefined,
                configuration: undefined,
                coerce: undefined,
                count: undefined,
                default: undefined,
                envPrefix: undefined,
                narg: undefined,
                normalize: undefined,
                string: undefined,
                number: undefined,
                __: undefined,
                key: undefined
            }, options);
            const args = tokenizeArgString(argsInput);
            const inputIsString = typeof argsInput === 'string';
            const aliases = combineAliases(Object.assign(Object.create(null), opts.alias));
            const configuration = Object.assign({
                'boolean-negation': true,
                'camel-case-expansion': true,
                'combine-arrays': false,
                'dot-notation': true,
                'duplicate-arguments-array': true,
                'flatten-duplicate-arrays': true,
                'greedy-arrays': true,
                'halt-at-non-option': false,
                'nargs-eats-options': false,
                'negation-prefix': 'no-',
                'parse-numbers': true,
                'parse-positional-numbers': true,
                'populate--': false,
                'set-placeholder-key': false,
                'short-option-groups': true,
                'strip-aliased': false,
                'strip-dashed': false,
                'unknown-options-as-args': false
            }, opts.configuration);
            const defaults = Object.assign(Object.create(null), opts.default);
            const configObjects = opts.configObjects || [];
            const envPrefix = opts.envPrefix;
            const notFlagsOption = configuration['populate--'];
            const notFlagsArgv = notFlagsOption ? '--' : '_';
            const newAliases = Object.create(null);
            const defaulted = Object.create(null);
            const __ = opts.__ || mixin.format;
            const flags = {
                aliases: Object.create(null),
                arrays: Object.create(null),
                bools: Object.create(null),
                strings: Object.create(null),
                numbers: Object.create(null),
                counts: Object.create(null),
                normalize: Object.create(null),
                configs: Object.create(null),
                nargs: Object.create(null),
                coercions: Object.create(null),
                keys: []
            };
            const negative = /^-([0-9]+(\.[0-9]+)?|\.[0-9]+)$/;
            const negatedBoolean = new RegExp('^--' + configuration['negation-prefix'] + '(.+)');
            [].concat(opts.array || []).filter(Boolean).forEach(function (opt) {
                const key = typeof opt === 'object' ? opt.key : opt;
                const assignment = Object.keys(opt).map(function (key) {
                    const arrayFlagKeys = {
                        boolean: 'bools',
                        string: 'strings',
                        number: 'numbers'
                    };
                    return arrayFlagKeys[key];
                }).filter(Boolean).pop();
                if (assignment) {
                    flags[assignment][key] = true;
                }
                flags.arrays[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.boolean || []).filter(Boolean).forEach(function (key) {
                flags.bools[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.string || []).filter(Boolean).forEach(function (key) {
                flags.strings[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.number || []).filter(Boolean).forEach(function (key) {
                flags.numbers[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.count || []).filter(Boolean).forEach(function (key) {
                flags.counts[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.normalize || []).filter(Boolean).forEach(function (key) {
                flags.normalize[key] = true;
                flags.keys.push(key);
            });
            if (typeof opts.narg === 'object') {
                Object.entries(opts.narg).forEach(([key, value]) => {
                    if (typeof value === 'number') {
                        flags.nargs[key] = value;
                        flags.keys.push(key);
                    }
                });
            }
            if (typeof opts.coerce === 'object') {
                Object.entries(opts.coerce).forEach(([key, value]) => {
                    if (typeof value === 'function') {
                        flags.coercions[key] = value;
                        flags.keys.push(key);
                    }
                });
            }
            if (typeof opts.config !== 'undefined') {
                if (Array.isArray(opts.config) || typeof opts.config === 'string') {
                    [].concat(opts.config).filter(Boolean).forEach(function (key) {
                        flags.configs[key] = true;
                    });
                }
                else if (typeof opts.config === 'object') {
                    Object.entries(opts.config).forEach(([key, value]) => {
                        if (typeof value === 'boolean' || typeof value === 'function') {
                            flags.configs[key] = value;
                        }
                    });
                }
            }
            extendAliases(opts.key, aliases, opts.default, flags.arrays);
            Object.keys(defaults).forEach(function (key) {
                (flags.aliases[key] || []).forEach(function (alias) {
                    defaults[alias] = defaults[key];
                });
            });
            let error = null;
            checkConfiguration();
            let notFlags = [];
            const argv = Object.assign(Object.create(null), { _: [] });
            const argvReturn = {};
            for (let i = 0; i < args.length; i++) {
                const arg = args[i];
                const truncatedArg = arg.replace(/^-{3,}/, '---');
                let broken;
                let key;
                let letters;
                let m;
                let next;
                let value;
                if (arg !== '--' && /^-/.test(arg) && isUnknownOptionAsArg(arg)) {
                    pushPositional(arg);
                }
                else if (truncatedArg.match(/^---+(=|$)/)) {
                    pushPositional(arg);
                    continue;
                }
                else if (arg.match(/^--.+=/) || (!configuration['short-option-groups'] && arg.match(/^-.+=/))) {
                    m = arg.match(/^--?([^=]+)=([\s\S]*)$/);
                    if (m !== null && Array.isArray(m) && m.length >= 3) {
                        if (checkAllAliases(m[1], flags.arrays)) {
                            i = eatArray(i, m[1], args, m[2]);
                        }
                        else if (checkAllAliases(m[1], flags.nargs) !== false) {
                            i = eatNargs(i, m[1], args, m[2]);
                        }
                        else {
                            setArg(m[1], m[2], true);
                        }
                    }
                }
                else if (arg.match(negatedBoolean) && configuration['boolean-negation']) {
                    m = arg.match(negatedBoolean);
                    if (m !== null && Array.isArray(m) && m.length >= 2) {
                        key = m[1];
                        setArg(key, checkAllAliases(key, flags.arrays) ? [false] : false);
                    }
                }
                else if (arg.match(/^--.+/) || (!configuration['short-option-groups'] && arg.match(/^-[^-]+/))) {
                    m = arg.match(/^--?(.+)/);
                    if (m !== null && Array.isArray(m) && m.length >= 2) {
                        key = m[1];
                        if (checkAllAliases(key, flags.arrays)) {
                            i = eatArray(i, key, args);
                        }
                        else if (checkAllAliases(key, flags.nargs) !== false) {
                            i = eatNargs(i, key, args);
                        }
                        else {
                            next = args[i + 1];
                            if (next !== undefined && (!next.match(/^-/) ||
                                next.match(negative)) &&
                                !checkAllAliases(key, flags.bools) &&
                                !checkAllAliases(key, flags.counts)) {
                                setArg(key, next);
                                i++;
                            }
                            else if (/^(true|false)$/.test(next)) {
                                setArg(key, next);
                                i++;
                            }
                            else {
                                setArg(key, defaultValue(key));
                            }
                        }
                    }
                }
                else if (arg.match(/^-.\..+=/)) {
                    m = arg.match(/^-([^=]+)=([\s\S]*)$/);
                    if (m !== null && Array.isArray(m) && m.length >= 3) {
                        setArg(m[1], m[2]);
                    }
                }
                else if (arg.match(/^-.\..+/) && !arg.match(negative)) {
                    next = args[i + 1];
                    m = arg.match(/^-(.\..+)/);
                    if (m !== null && Array.isArray(m) && m.length >= 2) {
                        key = m[1];
                        if (next !== undefined && !next.match(/^-/) &&
                            !checkAllAliases(key, flags.bools) &&
                            !checkAllAliases(key, flags.counts)) {
                            setArg(key, next);
                            i++;
                        }
                        else {
                            setArg(key, defaultValue(key));
                        }
                    }
                }
                else if (arg.match(/^-[^-]+/) && !arg.match(negative)) {
                    letters = arg.slice(1, -1).split('');
                    broken = false;
                    for (let j = 0; j < letters.length; j++) {
                        next = arg.slice(j + 2);
                        if (letters[j + 1] && letters[j + 1] === '=') {
                            value = arg.slice(j + 3);
                            key = letters[j];
                            if (checkAllAliases(key, flags.arrays)) {
                                i = eatArray(i, key, args, value);
                            }
                            else if (checkAllAliases(key, flags.nargs) !== false) {
                                i = eatNargs(i, key, args, value);
                            }
                            else {
                                setArg(key, value);
                            }
                            broken = true;
                            break;
                        }
                        if (next === '-') {
                            setArg(letters[j], next);
                            continue;
                        }
                        if (/[A-Za-z]/.test(letters[j]) &&
                            /^-?\d+(\.\d*)?(e-?\d+)?$/.test(next) &&
                            checkAllAliases(next, flags.bools) === false) {
                            setArg(letters[j], next);
                            broken = true;
                            break;
                        }
                        if (letters[j + 1] && letters[j + 1].match(/\W/)) {
                            setArg(letters[j], next);
                            broken = true;
                            break;
                        }
                        else {
                            setArg(letters[j], defaultValue(letters[j]));
                        }
                    }
                    key = arg.slice(-1)[0];
                    if (!broken && key !== '-') {
                        if (checkAllAliases(key, flags.arrays)) {
                            i = eatArray(i, key, args);
                        }
                        else if (checkAllAliases(key, flags.nargs) !== false) {
                            i = eatNargs(i, key, args);
                        }
                        else {
                            next = args[i + 1];
                            if (next !== undefined && (!/^(-|--)[^-]/.test(next) ||
                                next.match(negative)) &&
                                !checkAllAliases(key, flags.bools) &&
                                !checkAllAliases(key, flags.counts)) {
                                setArg(key, next);
                                i++;
                            }
                            else if (/^(true|false)$/.test(next)) {
                                setArg(key, next);
                                i++;
                            }
                            else {
                                setArg(key, defaultValue(key));
                            }
                        }
                    }
                }
                else if (arg.match(/^-[0-9]$/) &&
                    arg.match(negative) &&
                    checkAllAliases(arg.slice(1), flags.bools)) {
                    key = arg.slice(1);
                    setArg(key, defaultValue(key));
                }
                else if (arg === '--') {
                    notFlags = args.slice(i + 1);
                    break;
                }
                else if (configuration['halt-at-non-option']) {
                    notFlags = args.slice(i);
                    break;
                }
                else {
                    pushPositional(arg);
                }
            }
            applyEnvVars(argv, true);
            applyEnvVars(argv, false);
            setConfig(argv);
            setConfigObjects();
            applyDefaultsAndAliases(argv, flags.aliases, defaults, true);
            applyCoercions(argv);
            if (configuration['set-placeholder-key'])
                setPlaceholderKeys(argv);
            Object.keys(flags.counts).forEach(function (key) {
                if (!hasKey(argv, key.split('.')))
                    setArg(key, 0);
            });
            if (notFlagsOption && notFlags.length)
                argv[notFlagsArgv] = [];
            notFlags.forEach(function (key) {
                argv[notFlagsArgv].push(key);
            });
            if (configuration['camel-case-expansion'] && configuration['strip-dashed']) {
                Object.keys(argv).filter(key => key !== '--' && key.includes('-')).forEach(key => {
                    delete argv[key];
                });
            }
            if (configuration['strip-aliased']) {
                [].concat(...Object.keys(aliases).map(k => aliases[k])).forEach(alias => {
                    if (configuration['camel-case-expansion'] && alias.includes('-')) {
                        delete argv[alias.split('.').map(prop => camelCase(prop)).join('.')];
                    }
                    delete argv[alias];
                });
            }
            function pushPositional(arg) {
                const maybeCoercedNumber = maybeCoerceNumber('_', arg);
                if (typeof maybeCoercedNumber === 'string' || typeof maybeCoercedNumber === 'number') {
                    argv._.push(maybeCoercedNumber);
                }
            }
            function eatNargs(i, key, args, argAfterEqualSign) {
                let ii;
                let toEat = checkAllAliases(key, flags.nargs);
                toEat = typeof toEat !== 'number' || isNaN(toEat) ? 1 : toEat;
                if (toEat === 0) {
                    if (!isUndefined(argAfterEqualSign)) {
                        error = Error(__('Argument unexpected for: %s', key));
                    }
                    setArg(key, defaultValue(key));
                    return i;
                }
                let available = isUndefined(argAfterEqualSign) ? 0 : 1;
                if (configuration['nargs-eats-options']) {
                    if (args.length - (i + 1) + available < toEat) {
                        error = Error(__('Not enough arguments following: %s', key));
                    }
                    available = toEat;
                }
                else {
                    for (ii = i + 1; ii < args.length; ii++) {
                        if (!args[ii].match(/^-[^0-9]/) || args[ii].match(negative) || isUnknownOptionAsArg(args[ii]))
                            available++;
                        else
                            break;
                    }
                    if (available < toEat)
                        error = Error(__('Not enough arguments following: %s', key));
                }
                let consumed = Math.min(available, toEat);
                if (!isUndefined(argAfterEqualSign) && consumed > 0) {
                    setArg(key, argAfterEqualSign);
                    consumed--;
                }
                for (ii = i + 1; ii < (consumed + i + 1); ii++) {
                    setArg(key, args[ii]);
                }
                return (i + consumed);
            }
            function eatArray(i, key, args, argAfterEqualSign) {
                let argsToSet = [];
                let next = argAfterEqualSign || args[i + 1];
                const nargsCount = checkAllAliases(key, flags.nargs);
                if (checkAllAliases(key, flags.bools) && !(/^(true|false)$/.test(next))) {
                    argsToSet.push(true);
                }
                else if (isUndefined(next) ||
                    (isUndefined(argAfterEqualSign) && /^-/.test(next) && !negative.test(next) && !isUnknownOptionAsArg(next))) {
                    if (defaults[key] !== undefined) {
                        const defVal = defaults[key];
                        argsToSet = Array.isArray(defVal) ? defVal : [defVal];
                    }
                }
                else {
                    if (!isUndefined(argAfterEqualSign)) {
                        argsToSet.push(processValue(key, argAfterEqualSign, true));
                    }
                    for (let ii = i + 1; ii < args.length; ii++) {
                        if ((!configuration['greedy-arrays'] && argsToSet.length > 0) ||
                            (nargsCount && typeof nargsCount === 'number' && argsToSet.length >= nargsCount))
                            break;
                        next = args[ii];
                        if (/^-/.test(next) && !negative.test(next) && !isUnknownOptionAsArg(next))
                            break;
                        i = ii;
                        argsToSet.push(processValue(key, next, inputIsString));
                    }
                }
                if (typeof nargsCount === 'number' && ((nargsCount && argsToSet.length < nargsCount) ||
                    (isNaN(nargsCount) && argsToSet.length === 0))) {
                    error = Error(__('Not enough arguments following: %s', key));
                }
                setArg(key, argsToSet);
                return i;
            }
            function setArg(key, val, shouldStripQuotes = inputIsString) {
                if (/-/.test(key) && configuration['camel-case-expansion']) {
                    const alias = key.split('.').map(function (prop) {
                        return camelCase(prop);
                    }).join('.');
                    addNewAlias(key, alias);
                }
                const value = processValue(key, val, shouldStripQuotes);
                const splitKey = key.split('.');
                setKey(argv, splitKey, value);
                if (flags.aliases[key]) {
                    flags.aliases[key].forEach(function (x) {
                        const keyProperties = x.split('.');
                        setKey(argv, keyProperties, value);
                    });
                }
                if (splitKey.length > 1 && configuration['dot-notation']) {
                    (flags.aliases[splitKey[0]] || []).forEach(function (x) {
                        let keyProperties = x.split('.');
                        const a = [].concat(splitKey);
                        a.shift();
                        keyProperties = keyProperties.concat(a);
                        if (!(flags.aliases[key] || []).includes(keyProperties.join('.'))) {
                            setKey(argv, keyProperties, value);
                        }
                    });
                }
                if (checkAllAliases(key, flags.normalize) && !checkAllAliases(key, flags.arrays)) {
                    const keys = [key].concat(flags.aliases[key] || []);
                    keys.forEach(function (key) {
                        Object.defineProperty(argvReturn, key, {
                            enumerable: true,
                            get() {
                                return val;
                            },
                            set(value) {
                                val = typeof value === 'string' ? mixin.normalize(value) : value;
                            }
                        });
                    });
                }
            }
            function addNewAlias(key, alias) {
                if (!(flags.aliases[key] && flags.aliases[key].length)) {
                    flags.aliases[key] = [alias];
                    newAliases[alias] = true;
                }
                if (!(flags.aliases[alias] && flags.aliases[alias].length)) {
                    addNewAlias(alias, key);
                }
            }
            function processValue(key, val, shouldStripQuotes) {
                if (shouldStripQuotes) {
                    val = stripQuotes(val);
                }
                if (checkAllAliases(key, flags.bools) || checkAllAliases(key, flags.counts)) {
                    if (typeof val === 'string')
                        val = val === 'true';
                }
                let value = Array.isArray(val)
                    ? val.map(function (v) { return maybeCoerceNumber(key, v); })
                    : maybeCoerceNumber(key, val);
                if (checkAllAliases(key, flags.counts) && (isUndefined(value) || typeof value === 'boolean')) {
                    value = increment();
                }
                if (checkAllAliases(key, flags.normalize) && checkAllAliases(key, flags.arrays)) {
                    if (Array.isArray(val))
                        value = val.map((val) => { return mixin.normalize(val); });
                    else
                        value = mixin.normalize(val);
                }
                return value;
            }
            function maybeCoerceNumber(key, value) {
                if (!configuration['parse-positional-numbers'] && key === '_')
                    return value;
                if (!checkAllAliases(key, flags.strings) && !checkAllAliases(key, flags.bools) && !Array.isArray(value)) {
                    const shouldCoerceNumber = looksLikeNumber(value) && configuration['parse-numbers'] && (Number.isSafeInteger(Math.floor(parseFloat(`${value}`))));
                    if (shouldCoerceNumber || (!isUndefined(value) && checkAllAliases(key, flags.numbers))) {
                        value = Number(value);
                    }
                }
                return value;
            }
            function setConfig(argv) {
                const configLookup = Object.create(null);
                applyDefaultsAndAliases(configLookup, flags.aliases, defaults);
                Object.keys(flags.configs).forEach(function (configKey) {
                    const configPath = argv[configKey] || configLookup[configKey];
                    if (configPath) {
                        try {
                            let config = null;
                            const resolvedConfigPath = mixin.resolve(mixin.cwd(), configPath);
                            const resolveConfig = flags.configs[configKey];
                            if (typeof resolveConfig === 'function') {
                                try {
                                    config = resolveConfig(resolvedConfigPath);
                                }
                                catch (e) {
                                    config = e;
                                }
                                if (config instanceof Error) {
                                    error = config;
                                    return;
                                }
                            }
                            else {
                                config = mixin.require(resolvedConfigPath);
                            }
                            setConfigObject(config);
                        }
                        catch (ex) {
                            if (ex.name === 'PermissionDenied')
                                error = ex;
                            else if (argv[configKey])
                                error = Error(__('Invalid JSON config file: %s', configPath));
                        }
                    }
                });
            }
            function setConfigObject(config, prev) {
                Object.keys(config).forEach(function (key) {
                    const value = config[key];
                    const fullKey = prev ? prev + '.' + key : key;
                    if (typeof value === 'object' && value !== null && !Array.isArray(value) && configuration['dot-notation']) {
                        setConfigObject(value, fullKey);
                    }
                    else {
                        if (!hasKey(argv, fullKey.split('.')) || (checkAllAliases(fullKey, flags.arrays) && configuration['combine-arrays'])) {
                            setArg(fullKey, value);
                        }
                    }
                });
            }
            function setConfigObjects() {
                if (typeof configObjects !== 'undefined') {
                    configObjects.forEach(function (configObject) {
                        setConfigObject(configObject);
                    });
                }
            }
            function applyEnvVars(argv, configOnly) {
                if (typeof envPrefix === 'undefined')
                    return;
                const prefix = typeof envPrefix === 'string' ? envPrefix : '';
                const env = mixin.env();
                Object.keys(env).forEach(function (envVar) {
                    if (prefix === '' || envVar.lastIndexOf(prefix, 0) === 0) {
                        const keys = envVar.split('__').map(function (key, i) {
                            if (i === 0) {
                                key = key.substring(prefix.length);
                            }
                            return camelCase(key);
                        });
                        if (((configOnly && flags.configs[keys.join('.')]) || !configOnly) && !hasKey(argv, keys)) {
                            setArg(keys.join('.'), env[envVar]);
                        }
                    }
                });
            }
            function applyCoercions(argv) {
                let coerce;
                const applied = new Set();
                Object.keys(argv).forEach(function (key) {
                    if (!applied.has(key)) {
                        coerce = checkAllAliases(key, flags.coercions);
                        if (typeof coerce === 'function') {
                            try {
                                const value = maybeCoerceNumber(key, coerce(argv[key]));
                                ([].concat(flags.aliases[key] || [], key)).forEach(ali => {
                                    applied.add(ali);
                                    argv[ali] = value;
                                });
                            }
                            catch (err) {
                                error = err;
                            }
                        }
                    }
                });
            }
            function setPlaceholderKeys(argv) {
                flags.keys.forEach((key) => {
                    if (~key.indexOf('.'))
                        return;
                    if (typeof argv[key] === 'undefined')
                        argv[key] = undefined;
                });
                return argv;
            }
            function applyDefaultsAndAliases(obj, aliases, defaults, canLog = false) {
                Object.keys(defaults).forEach(function (key) {
                    if (!hasKey(obj, key.split('.'))) {
                        setKey(obj, key.split('.'), defaults[key]);
                        if (canLog)
                            defaulted[key] = true;
                        (aliases[key] || []).forEach(function (x) {
                            if (hasKey(obj, x.split('.')))
                                return;
                            setKey(obj, x.split('.'), defaults[key]);
                        });
                    }
                });
            }
            function hasKey(obj, keys) {
                let o = obj;
                if (!configuration['dot-notation'])
                    keys = [keys.join('.')];
                keys.slice(0, -1).forEach(function (key) {
                    o = (o[key] || {});
                });
                const key = keys[keys.length - 1];
                if (typeof o !== 'object')
                    return false;
                else
                    return key in o;
            }
            function setKey(obj, keys, value) {
                let o = obj;
                if (!configuration['dot-notation'])
                    keys = [keys.join('.')];
                keys.slice(0, -1).forEach(function (key) {
                    key = sanitizeKey(key);
                    if (typeof o === 'object' && o[key] === undefined) {
                        o[key] = {};
                    }
                    if (typeof o[key] !== 'object' || Array.isArray(o[key])) {
                        if (Array.isArray(o[key])) {
                            o[key].push({});
                        }
                        else {
                            o[key] = [o[key], {}];
                        }
                        o = o[key][o[key].length - 1];
                    }
                    else {
                        o = o[key];
                    }
                });
                const key = sanitizeKey(keys[keys.length - 1]);
                const isTypeArray = checkAllAliases(keys.join('.'), flags.arrays);
                const isValueArray = Array.isArray(value);
                let duplicate = configuration['duplicate-arguments-array'];
                if (!duplicate && checkAllAliases(key, flags.nargs)) {
                    duplicate = true;
                    if ((!isUndefined(o[key]) && flags.nargs[key] === 1) || (Array.isArray(o[key]) && o[key].length === flags.nargs[key])) {
                        o[key] = undefined;
                    }
                }
                if (value === increment()) {
                    o[key] = increment(o[key]);
                }
                else if (Array.isArray(o[key])) {
                    if (duplicate && isTypeArray && isValueArray) {
                        o[key] = configuration['flatten-duplicate-arrays'] ? o[key].concat(value) : (Array.isArray(o[key][0]) ? o[key] : [o[key]]).concat([value]);
                    }
                    else if (!duplicate && Boolean(isTypeArray) === Boolean(isValueArray)) {
                        o[key] = value;
                    }
                    else {
                        o[key] = o[key].concat([value]);
                    }
                }
                else if (o[key] === undefined && isTypeArray) {
                    o[key] = isValueArray ? value : [value];
                }
                else if (duplicate && !(o[key] === undefined ||
                    checkAllAliases(key, flags.counts) ||
                    checkAllAliases(key, flags.bools))) {
                    o[key] = [o[key], value];
                }
                else {
                    o[key] = value;
                }
            }
            function extendAliases(...args) {
                args.forEach(function (obj) {
                    Object.keys(obj || {}).forEach(function (key) {
                        if (flags.aliases[key])
                            return;
                        flags.aliases[key] = [].concat(aliases[key] || []);
                        flags.aliases[key].concat(key).forEach(function (x) {
                            if (/-/.test(x) && configuration['camel-case-expansion']) {
                                const c = camelCase(x);
                                if (c !== key && flags.aliases[key].indexOf(c) === -1) {
                                    flags.aliases[key].push(c);
                                    newAliases[c] = true;
                                }
                            }
                        });
                        flags.aliases[key].concat(key).forEach(function (x) {
                            if (x.length > 1 && /[A-Z]/.test(x) && configuration['camel-case-expansion']) {
                                const c = decamelize(x, '-');
                                if (c !== key && flags.aliases[key].indexOf(c) === -1) {
                                    flags.aliases[key].push(c);
                                    newAliases[c] = true;
                                }
                            }
                        });
                        flags.aliases[key].forEach(function (x) {
                            flags.aliases[x] = [key].concat(flags.aliases[key].filter(function (y) {
                                return x !== y;
                            }));
                        });
                    });
                });
            }
            function checkAllAliases(key, flag) {
                const toCheck = [].concat(flags.aliases[key] || [], key);
                const keys = Object.keys(flag);
                const setAlias = toCheck.find(key => keys.includes(key));
                return setAlias ? flag[setAlias] : false;
            }
            function hasAnyFlag(key) {
                const flagsKeys = Object.keys(flags);
                const toCheck = [].concat(flagsKeys.map(k => flags[k]));
                return toCheck.some(function (flag) {
                    return Array.isArray(flag) ? flag.includes(key) : flag[key];
                });
            }
            function hasFlagsMatching(arg, ...patterns) {
                const toCheck = [].concat(...patterns);
                return toCheck.some(function (pattern) {
                    const match = arg.match(pattern);
                    return match && hasAnyFlag(match[1]);
                });
            }
            function hasAllShortFlags(arg) {
                if (arg.match(negative) || !arg.match(/^-[^-]+/)) {
                    return false;
                }
                let hasAllFlags = true;
                let next;
                const letters = arg.slice(1).split('');
                for (let j = 0; j < letters.length; j++) {
                    next = arg.slice(j + 2);
                    if (!hasAnyFlag(letters[j])) {
                        hasAllFlags = false;
                        break;
                    }
                    if ((letters[j + 1] && letters[j + 1] === '=') ||
                        next === '-' ||
                        (/[A-Za-z]/.test(letters[j]) && /^-?\d+(\.\d*)?(e-?\d+)?$/.test(next)) ||
                        (letters[j + 1] && letters[j + 1].match(/\W/))) {
                        break;
                    }
                }
                return hasAllFlags;
            }
            function isUnknownOptionAsArg(arg) {
                return configuration['unknown-options-as-args'] && isUnknownOption(arg);
            }
            function isUnknownOption(arg) {
                arg = arg.replace(/^-{3,}/, '--');
                if (arg.match(negative)) {
                    return false;
                }
                if (hasAllShortFlags(arg)) {
                    return false;
                }
                const flagWithEquals = /^-+([^=]+?)=[\s\S]*$/;
                const normalFlag = /^-+([^=]+?)$/;
                const flagEndingInHyphen = /^-+([^=]+?)-$/;
                const flagEndingInDigits = /^-+([^=]+?\d+)$/;
                const flagEndingInNonWordCharacters = /^-+([^=]+?)\W+.*$/;
                return !hasFlagsMatching(arg, flagWithEquals, negatedBoolean, normalFlag, flagEndingInHyphen, flagEndingInDigits, flagEndingInNonWordCharacters);
            }
            function defaultValue(key) {
                if (!checkAllAliases(key, flags.bools) &&
                    !checkAllAliases(key, flags.counts) &&
                    `${key}` in defaults) {
                    return defaults[key];
                }
                else {
                    return defaultForType(guessType(key));
                }
            }
            function defaultForType(type) {
                const def = {
                    [DefaultValuesForTypeKey.BOOLEAN]: true,
                    [DefaultValuesForTypeKey.STRING]: '',
                    [DefaultValuesForTypeKey.NUMBER]: undefined,
                    [DefaultValuesForTypeKey.ARRAY]: []
                };
                return def[type];
            }
            function guessType(key) {
                let type = DefaultValuesForTypeKey.BOOLEAN;
                if (checkAllAliases(key, flags.strings))
                    type = DefaultValuesForTypeKey.STRING;
                else if (checkAllAliases(key, flags.numbers))
                    type = DefaultValuesForTypeKey.NUMBER;
                else if (checkAllAliases(key, flags.bools))
                    type = DefaultValuesForTypeKey.BOOLEAN;
                else if (checkAllAliases(key, flags.arrays))
                    type = DefaultValuesForTypeKey.ARRAY;
                return type;
            }
            function isUndefined(num) {
                return num === undefined;
            }
            function checkConfiguration() {
                Object.keys(flags.counts).find(key => {
                    if (checkAllAliases(key, flags.arrays)) {
                        error = Error(__('Invalid configuration: %s, opts.count excludes opts.array.', key));
                        return true;
                    }
                    else if (checkAllAliases(key, flags.nargs)) {
                        error = Error(__('Invalid configuration: %s, opts.count excludes opts.narg.', key));
                        return true;
                    }
                    return false;
                });
            }
            return {
                aliases: Object.assign({}, flags.aliases),
                argv: Object.assign(argvReturn, argv),
                configuration: configuration,
                defaulted: Object.assign({}, defaulted),
                error: error,
                newAliases: Object.assign({}, newAliases)
            };
        }
    }
    function combineAliases(aliases) {
        const aliasArrays = [];
        const combined = Object.create(null);
        let change = true;
        Object.keys(aliases).forEach(function (key) {
            aliasArrays.push([].concat(aliases[key], key));
        });
        while (change) {
            change = false;
            for (let i = 0; i < aliasArrays.length; i++) {
                for (let ii = i + 1; ii < aliasArrays.length; ii++) {
                    const intersect = aliasArrays[i].filter(function (v) {
                        return aliasArrays[ii].indexOf(v) !== -1;
                    });
                    if (intersect.length) {
                        aliasArrays[i] = aliasArrays[i].concat(aliasArrays[ii]);
                        aliasArrays.splice(ii, 1);
                        change = true;
                        break;
                    }
                }
            }
        }
        aliasArrays.forEach(function (aliasArray) {
            aliasArray = aliasArray.filter(function (v, i, self) {
                return self.indexOf(v) === i;
            });
            const lastAlias = aliasArray.pop();
            if (lastAlias !== undefined && typeof lastAlias === 'string') {
                combined[lastAlias] = aliasArray;
            }
        });
        return combined;
    }
    function increment(orig) {
        return orig !== undefined ? orig + 1 : 1;
    }
    function sanitizeKey(key) {
        if (key === '__proto__')
            return '___proto___';
        return key;
    }
    function stripQuotes(val) {
        return (typeof val === 'string' &&
            (val[0] === "'" || val[0] === '"') &&
            val[val.length - 1] === val[0])
            ? val.substring(1, val.length - 1)
            : val;
    }
    var _a, _b, _c;
    const minNodeVersion = (process && process.env && process.env.YARGS_MIN_NODE_VERSION)
        ? Number(process.env.YARGS_MIN_NODE_VERSION)
        : 12;
    const nodeVersion = (_b = (_a = process === null || process === void 0 ? void 0 : process.versions) === null || _a === void 0 ? void 0 : _a.node) !== null && _b !== void 0 ? _b : (_c = process === null || process === void 0 ? void 0 : process.version) === null || _c === void 0 ? void 0 : _c.slice(1);
    if (nodeVersion) {
        const major = Number(nodeVersion.match(/^([^.]+)/)[1]);
        if (major < minNodeVersion) {
            throw Error(`yargs parser supports a minimum Node.js version of ${minNodeVersion}. Read our version support policy: https://github.com/yargs/yargs-parser#supported-nodejs-versions`);
        }
    }
    const env = process ? process.env : {};
    const parser = new YargsParser({
        cwd: process.cwd,
        env: () => {
            return env;
        },
        format: util.format,
        normalize: path.normalize,
        resolve: path.resolve,
        require: (path) => {
            if (typeof require !== 'undefined') {
                return require(path);
            }
            else if (path.match(/\.json$/)) {
                return JSON.parse(fs.readFileSync(path, 'utf8'));
            }
            else {
                throw Error('only .json config files are supported in ESM');
            }
        }
    });
    const yargsParser = function Parser(args, opts) {
        const result = parser.parse(args.slice(), opts);
        return result.argv;
    };
    yargsParser.detailed = function (args, opts) {
        return parser.parse(args.slice(), opts);
    };
    yargsParser.camelCase = camelCase;
    yargsParser.decamelize = decamelize;
    yargsParser.looksLikeNumber = looksLikeNumber;
    module.exports = yargsParser;
},
/* cliui/build/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const align = {
        right: alignRight,
        center: alignCenter
    };
    const top = 0;
    const right = 1;
    const bottom = 2;
    const left = 3;
    class UI {
        constructor(opts) {
            var _a;
            this.width = opts.width;
            this.wrap = (_a = opts.wrap) !== null && _a !== void 0 ? _a : true;
            this.rows = [];
        }
        span(...args) {
            const cols = this.div(...args);
            cols.span = true;
        }
        resetOutput() {
            this.rows = [];
        }
        div(...args) {
            if (args.length === 0) {
                this.div('');
            }
            if (this.wrap && this.shouldApplyLayoutDSL(...args) && typeof args[0] === 'string') {
                return this.applyLayoutDSL(args[0]);
            }
            const cols = args.map(arg => {
                if (typeof arg === 'string') {
                    return this.colFromString(arg);
                }
                return arg;
            });
            this.rows.push(cols);
            return cols;
        }
        shouldApplyLayoutDSL(...args) {
            return args.length === 1 && typeof args[0] === 'string' &&
                /[\t\n]/.test(args[0]);
        }
        applyLayoutDSL(str) {
            const rows = str.split('\n').map(row => row.split('\t'));
            let leftColumnWidth = 0;
            // simple heuristic for layout, make sure the
            // second column lines up along the left-hand.
            // don't allow the first column to take up more
            // than 50% of the screen.
            rows.forEach(columns => {
                if (columns.length > 1 && mixin.stringWidth(columns[0]) > leftColumnWidth) {
                    leftColumnWidth = Math.min(Math.floor(this.width * 0.5), mixin.stringWidth(columns[0]));
                }
            });
            // generate a table:
            //  replacing ' ' with padding calculations.
            //  using the algorithmically generated width.
            rows.forEach(columns => {
                this.div(...columns.map((r, i) => {
                    return {
                        text: r.trim(),
                        padding: this.measurePadding(r),
                        width: (i === 0 && columns.length > 1) ? leftColumnWidth : undefined
                    };
                }));
            });
            return this.rows[this.rows.length - 1];
        }
        colFromString(text) {
            return {
                text,
                padding: this.measurePadding(text)
            };
        }
        measurePadding(str) {
            // measure padding without ansi escape codes
            const noAnsi = mixin.stripAnsi(str);
            return [0, noAnsi.match(/\s*$/)[0].length, 0, noAnsi.match(/^\s*/)[0].length];
        }
        toString() {
            const lines = [];
            this.rows.forEach(row => {
                this.rowToString(row, lines);
            });
            // don't display any lines with the
            // hidden flag set.
            return lines
                .filter(line => !line.hidden)
                .map(line => line.text)
                .join('\n');
        }
        rowToString(row, lines) {
            this.rasterize(row).forEach((rrow, r) => {
                let str = '';
                rrow.forEach((col, c) => {
                    const { width } = row[c]; // the width with padding.
                    const wrapWidth = this.negatePadding(row[c]); // the width without padding.
                    let ts = col; // temporary string used during alignment/padding.
                    if (wrapWidth > mixin.stringWidth(col)) {
                        ts += ' '.repeat(wrapWidth - mixin.stringWidth(col));
                    }
                    // align the string within its column.
                    if (row[c].align && row[c].align !== 'left' && this.wrap) {
                        const fn = align[row[c].align];
                        ts = fn(ts, wrapWidth);
                        if (mixin.stringWidth(ts) < wrapWidth) {
                            ts += ' '.repeat((width || 0) - mixin.stringWidth(ts) - 1);
                        }
                    }
                    // apply border and padding to string.
                    const padding = row[c].padding || [0, 0, 0, 0];
                    if (padding[left]) {
                        str += ' '.repeat(padding[left]);
                    }
                    str += addBorder(row[c], ts, '| ');
                    str += ts;
                    str += addBorder(row[c], ts, ' |');
                    if (padding[right]) {
                        str += ' '.repeat(padding[right]);
                    }
                    // if prior row is span, try to render the
                    // current row on the prior line.
                    if (r === 0 && lines.length > 0) {
                        str = this.renderInline(str, lines[lines.length - 1]);
                    }
                });
                // remove trailing whitespace.
                lines.push({
                    text: str.replace(/ +$/, ''),
                    span: row.span
                });
            });
            return lines;
        }
        // if the full 'source' can render in
        // the target line, do so.
        renderInline(source, previousLine) {
            const match = source.match(/^ */);
            const leadingWhitespace = match ? match[0].length : 0;
            const target = previousLine.text;
            const targetTextWidth = mixin.stringWidth(target.trimRight());
            if (!previousLine.span) {
                return source;
            }
            // if we're not applying wrapping logic,
            // just always append to the span.
            if (!this.wrap) {
                previousLine.hidden = true;
                return target + source;
            }
            if (leadingWhitespace < targetTextWidth) {
                return source;
            }
            previousLine.hidden = true;
            return target.trimRight() + ' '.repeat(leadingWhitespace - targetTextWidth) + source.trimLeft();
        }
        rasterize(row) {
            const rrows = [];
            const widths = this.columnWidths(row);
            let wrapped;
            // word wrap all columns, and create
            // a data-structure that is easy to rasterize.
            row.forEach((col, c) => {
                // leave room for left and right padding.
                col.width = widths[c];
                if (this.wrap) {
                    wrapped = mixin.wrap(col.text, this.negatePadding(col), { hard: true }).split('\n');
                }
                else {
                    wrapped = col.text.split('\n');
                }
                if (col.border) {
                    wrapped.unshift('.' + '-'.repeat(this.negatePadding(col) + 2) + '.');
                    wrapped.push("'" + '-'.repeat(this.negatePadding(col) + 2) + "'");
                }
                // add top and bottom padding.
                if (col.padding) {
                    wrapped.unshift(...new Array(col.padding[top] || 0).fill(''));
                    wrapped.push(...new Array(col.padding[bottom] || 0).fill(''));
                }
                wrapped.forEach((str, r) => {
                    if (!rrows[r]) {
                        rrows.push([]);
                    }
                    const rrow = rrows[r];
                    for (let i = 0; i < c; i++) {
                        if (rrow[i] === undefined) {
                            rrow.push('');
                        }
                    }
                    rrow.push(str);
                });
            });
            return rrows;
        }
        negatePadding(col) {
            let wrapWidth = col.width || 0;
            if (col.padding) {
                wrapWidth -= (col.padding[left] || 0) + (col.padding[right] || 0);
            }
            if (col.border) {
                wrapWidth -= 4;
            }
            return wrapWidth;
        }
        columnWidths(row) {
            if (!this.wrap) {
                return row.map(col => {
                    return col.width || mixin.stringWidth(col.text);
                });
            }
            let unset = row.length;
            let remainingWidth = this.width;
            // column widths can be set in config.
            const widths = row.map(col => {
                if (col.width) {
                    unset--;
                    remainingWidth -= col.width;
                    return col.width;
                }
                return undefined;
            });
            // any unset widths should be calculated.
            const unsetWidth = unset ? Math.floor(remainingWidth / unset) : 0;
            return widths.map((w, i) => {
                if (w === undefined) {
                    return Math.max(unsetWidth, _minWidth(row[i]));
                }
                return w;
            });
        }
    }
    function addBorder(col, ts, style) {
        if (col.border) {
            if (/[.']-+[.']/.test(ts)) {
                return '';
            }
            if (ts.trim().length !== 0) {
                return style;
            }
            return '  ';
        }
        return '';
    }
    // calculates the minimum width of
    // a column, based on padding preferences.
    function _minWidth(col) {
        const padding = col.padding || [];
        const minWidth = 1 + (padding[left] || 0) + (padding[right] || 0);
        if (col.border) {
            return minWidth + 4;
        }
        return minWidth;
    }
    function getWindowWidth() {
        /* istanbul ignore next: depends on terminal */
        if (typeof process === 'object' && process.stdout && process.stdout.columns) {
            return process.stdout.columns;
        }
        return 80;
    }
    function alignRight(str, width) {
        str = str.trim();
        const strWidth = mixin.stringWidth(str);
        if (strWidth < width) {
            return ' '.repeat(width - strWidth) + str;
        }
        return str;
    }
    function alignCenter(str, width) {
        str = str.trim();
        const strWidth = mixin.stringWidth(str);
        /* istanbul ignore next */
        if (strWidth >= width) {
            return str;
        }
        return ' '.repeat((width - strWidth) >> 1) + str;
    }
    let mixin;
    function cliui(opts, _mixin) {
        mixin = _mixin;
        return new UI({
            width: (opts === null || opts === void 0 ? void 0 : opts.width) || getWindowWidth(),
            wrap: opts === null || opts === void 0 ? void 0 : opts.wrap
        });
    }
    // Bootstrap cliui with CommonJS dependencies:
    const stringWidth = require(6) /* string-width */;
    const stripAnsi = require(7) /* strip-ansi */;
    const wrap = require(11) /* wrap-ansi */;
    function ui(opts) {
        return cliui(opts, {
            stringWidth,
            stripAnsi,
            wrap
        });
    }
    module.exports = ui;
},
/* string-width/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const stripAnsi = require(7) /* strip-ansi */;
    const isFullwidthCodePoint = require(9) /* is-fullwidth-code-point */;
    const emojiRegex = require(10) /* emoji-regex */;
    const stringWidth = string => {
        if (typeof string !== 'string' || string.length === 0) {
            return 0;
        }
        string = stripAnsi(string);
        if (string.length === 0) {
            return 0;
        }
        string = string.replace(emojiRegex(), '  ');
        let width = 0;
        for (let i = 0; i < string.length; i++) {
            const code = string.codePointAt(i);
            // Ignore control characters
            if (code <= 0x1F || (code >= 0x7F && code <= 0x9F)) {
                continue;
            }
            // Ignore combining characters
            if (code >= 0x300 && code <= 0x36F) {
                continue;
            }
            // Surrogates
            if (code > 0xFFFF) {
                i++;
            }
            width += isFullwidthCodePoint(code) ? 2 : 1;
        }
        return width;
    };
    module.exports = stringWidth;
    // TODO: remove this in the next major version
    module.exports.default = stringWidth;
},
/* strip-ansi/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const ansiRegex = require(8) /* ansi-regex */;
    module.exports = string => typeof string === 'string' ? string.replace(ansiRegex(), '') : string;
},
/* ansi-regex/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = ({ onlyFirst = false } = {}) => {
        const pattern = [
            '[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]+)*|[a-zA-Z\\d]+(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)',
            '(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))'
        ].join('|');
        return new RegExp(pattern, onlyFirst ? undefined : 'g');
    };
},
/* is-fullwidth-code-point/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /* eslint-disable yoda */
    'use strict';
    const isFullwidthCodePoint = codePoint => {
        if (Number.isNaN(codePoint)) {
            return false;
        }
        // Code points are derived from:
        // http://www.unix.org/Public/UNIDATA/EastAsianWidth.txt
        if (codePoint >= 0x1100 && (codePoint <= 0x115F || // Hangul Jamo
            codePoint === 0x2329 || // LEFT-POINTING ANGLE BRACKET
            codePoint === 0x232A || // RIGHT-POINTING ANGLE BRACKET
            // CJK Radicals Supplement .. Enclosed CJK Letters and Months
            (0x2E80 <= codePoint && codePoint <= 0x3247 && codePoint !== 0x303F) ||
            // Enclosed CJK Letters and Months .. CJK Unified Ideographs Extension A
            (0x3250 <= codePoint && codePoint <= 0x4DBF) ||
            // CJK Unified Ideographs .. Yi Radicals
            (0x4E00 <= codePoint && codePoint <= 0xA4C6) ||
            // Hangul Jamo Extended-A
            (0xA960 <= codePoint && codePoint <= 0xA97C) ||
            // Hangul Syllables
            (0xAC00 <= codePoint && codePoint <= 0xD7A3) ||
            // CJK Compatibility Ideographs
            (0xF900 <= codePoint && codePoint <= 0xFAFF) ||
            // Vertical Forms
            (0xFE10 <= codePoint && codePoint <= 0xFE19) ||
            // CJK Compatibility Forms .. Small Form Variants
            (0xFE30 <= codePoint && codePoint <= 0xFE6B) ||
            // Halfwidth and Fullwidth Forms
            (0xFF01 <= codePoint && codePoint <= 0xFF60) ||
            (0xFFE0 <= codePoint && codePoint <= 0xFFE6) ||
            // Kana Supplement
            (0x1B000 <= codePoint && codePoint <= 0x1B001) ||
            // Enclosed Ideographic Supplement
            (0x1F200 <= codePoint && codePoint <= 0x1F251) ||
            // CJK Unified Ideographs Extension B .. Tertiary Ideographic Plane
            (0x20000 <= codePoint && codePoint <= 0x3FFFD))) {
            return true;
        }
        return false;
    };
    module.exports = isFullwidthCodePoint;
    module.exports.default = isFullwidthCodePoint;
},
/* emoji-regex/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    module.exports = function () {
        // https://mths.be/emoji
        return /\uD83C\uDFF4\uDB40\uDC67\uDB40\uDC62(?:\uDB40\uDC65\uDB40\uDC6E\uDB40\uDC67|\uDB40\uDC73\uDB40\uDC63\uDB40\uDC74|\uDB40\uDC77\uDB40\uDC6C\uDB40\uDC73)\uDB40\uDC7F|\uD83D\uDC68(?:\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68\uD83C\uDFFB|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFE])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83D\uDC68|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D[\uDC66\uDC67])|[\u2695\u2696\u2708]\uFE0F|\uD83D[\uDC66\uDC67]|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|(?:\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708])\uFE0F|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C[\uDFFB-\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFB\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)\uD83C\uDFFB|\uD83E\uDDD1(?:\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])|\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1)|(?:\uD83E\uDDD1\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFE])|(?:\uD83E\uDDD1\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)(?:\uD83C[\uDFFB\uDFFC])|\uD83D\uDC69(?:\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFC-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|(?:\uD83E\uDDD1\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)(?:\uD83C[\uDFFB-\uDFFD])|\uD83D\uDC69\u200D\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8|\uD83D\uDC69(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|(?:(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)\uFE0F|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF])\u200D[\u2640\u2642]|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD6-\uDDDD])(?:(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|\u200D[\u2640\u2642])|\uD83C\uDFF4\u200D\u2620)\uFE0F|\uD83D\uDC69\u200D\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83C\uDFF3\uFE0F\u200D\uD83C\uDF08|\uD83D\uDC15\u200D\uD83E\uDDBA|\uD83D\uDC69\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC67|\uD83C\uDDFD\uD83C\uDDF0|\uD83C\uDDF4\uD83C\uDDF2|\uD83C\uDDF6\uD83C\uDDE6|[#\*0-9]\uFE0F\u20E3|\uD83C\uDDE7(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEF\uDDF1-\uDDF4\uDDF6-\uDDF9\uDDFB\uDDFC\uDDFE\uDDFF])|\uD83C\uDDF9(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDED\uDDEF-\uDDF4\uDDF7\uDDF9\uDDFB\uDDFC\uDDFF])|\uD83C\uDDEA(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDED\uDDF7-\uDDFA])|\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])|\uD83C\uDDF7(?:\uD83C[\uDDEA\uDDF4\uDDF8\uDDFA\uDDFC])|\uD83D\uDC69(?:\uD83C[\uDFFB-\uDFFF])|\uD83C\uDDF2(?:\uD83C[\uDDE6\uDDE8-\uDDED\uDDF0-\uDDFF])|\uD83C\uDDE6(?:\uD83C[\uDDE8-\uDDEC\uDDEE\uDDF1\uDDF2\uDDF4\uDDF6-\uDDFA\uDDFC\uDDFD\uDDFF])|\uD83C\uDDF0(?:\uD83C[\uDDEA\uDDEC-\uDDEE\uDDF2\uDDF3\uDDF5\uDDF7\uDDFC\uDDFE\uDDFF])|\uD83C\uDDED(?:\uD83C[\uDDF0\uDDF2\uDDF3\uDDF7\uDDF9\uDDFA])|\uD83C\uDDE9(?:\uD83C[\uDDEA\uDDEC\uDDEF\uDDF0\uDDF2\uDDF4\uDDFF])|\uD83C\uDDFE(?:\uD83C[\uDDEA\uDDF9])|\uD83C\uDDEC(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEE\uDDF1-\uDDF3\uDDF5-\uDDFA\uDDFC\uDDFE])|\uD83C\uDDF8(?:\uD83C[\uDDE6-\uDDEA\uDDEC-\uDDF4\uDDF7-\uDDF9\uDDFB\uDDFD-\uDDFF])|\uD83C\uDDEB(?:\uD83C[\uDDEE-\uDDF0\uDDF2\uDDF4\uDDF7])|\uD83C\uDDF5(?:\uD83C[\uDDE6\uDDEA-\uDDED\uDDF0-\uDDF3\uDDF7-\uDDF9\uDDFC\uDDFE])|\uD83C\uDDFB(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDEE\uDDF3\uDDFA])|\uD83C\uDDF3(?:\uD83C[\uDDE6\uDDE8\uDDEA-\uDDEC\uDDEE\uDDF1\uDDF4\uDDF5\uDDF7\uDDFA\uDDFF])|\uD83C\uDDE8(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDEE\uDDF0-\uDDF5\uDDF7\uDDFA-\uDDFF])|\uD83C\uDDF1(?:\uD83C[\uDDE6-\uDDE8\uDDEE\uDDF0\uDDF7-\uDDFB\uDDFE])|\uD83C\uDDFF(?:\uD83C[\uDDE6\uDDF2\uDDFC])|\uD83C\uDDFC(?:\uD83C[\uDDEB\uDDF8])|\uD83C\uDDFA(?:\uD83C[\uDDE6\uDDEC\uDDF2\uDDF3\uDDF8\uDDFE\uDDFF])|\uD83C\uDDEE(?:\uD83C[\uDDE8-\uDDEA\uDDF1-\uDDF4\uDDF6-\uDDF9])|\uD83C\uDDEF(?:\uD83C[\uDDEA\uDDF2\uDDF4\uDDF5])|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u261D\u270A-\u270D]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC70\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDCAA\uDD74\uDD7A\uDD90\uDD95\uDD96\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD36\uDDB5\uDDB6\uDDBB\uDDD2-\uDDD5])(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u270A\u270B\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF93\uDFA0-\uDFCA\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF4\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC3E\uDC40\uDC42-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDD7A\uDD95\uDD96\uDDA4\uDDFB-\uDE4F\uDE80-\uDEC5\uDECC\uDED0-\uDED2\uDED5\uDEEB\uDEEC\uDEF4-\uDEFA\uDFE0-\uDFEB]|\uD83E[\uDD0D-\uDD3A\uDD3C-\uDD45\uDD47-\uDD71\uDD73-\uDD76\uDD7A-\uDDA2\uDDA5-\uDDAA\uDDAE-\uDDCA\uDDCD-\uDDFF\uDE70-\uDE73\uDE78-\uDE7A\uDE80-\uDE82\uDE90-\uDE95])|(?:[#\*0-9\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u231A\u231B\u2328\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u2648-\u2653\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u267F\u2692-\u2697\u2699\u269B\u269C\u26A0\u26A1\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753-\u2755\u2757\u2763\u2764\u2795-\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05-\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]|\uD83C[\uDC04\uDCCF\uDD70\uDD71\uDD7E\uDD7F\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE02\uDE1A\uDE2F\uDE32-\uDE3A\uDE50\uDE51\uDF00-\uDF21\uDF24-\uDF93\uDF96\uDF97\uDF99-\uDF9B\uDF9E-\uDFF0\uDFF3-\uDFF5\uDFF7-\uDFFF]|\uD83D[\uDC00-\uDCFD\uDCFF-\uDD3D\uDD49-\uDD4E\uDD50-\uDD67\uDD6F\uDD70\uDD73-\uDD7A\uDD87\uDD8A-\uDD8D\uDD90\uDD95\uDD96\uDDA4\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA-\uDE4F\uDE80-\uDEC5\uDECB-\uDED2\uDED5\uDEE0-\uDEE5\uDEE9\uDEEB\uDEEC\uDEF0\uDEF3-\uDEFA\uDFE0-\uDFEB]|\uD83E[\uDD0D-\uDD3A\uDD3C-\uDD45\uDD47-\uDD71\uDD73-\uDD76\uDD7A-\uDDA2\uDDA5-\uDDAA\uDDAE-\uDDCA\uDDCD-\uDDFF\uDE70-\uDE73\uDE78-\uDE7A\uDE80-\uDE82\uDE90-\uDE95])\uFE0F|(?:[\u261D\u26F9\u270A-\u270D]|\uD83C[\uDF85\uDFC2-\uDFC4\uDFC7\uDFCA-\uDFCC]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66-\uDC78\uDC7C\uDC81-\uDC83\uDC85-\uDC87\uDC8F\uDC91\uDCAA\uDD74\uDD75\uDD7A\uDD90\uDD95\uDD96\uDE45-\uDE47\uDE4B-\uDE4F\uDEA3\uDEB4-\uDEB6\uDEC0\uDECC]|\uD83E[\uDD0F\uDD18-\uDD1F\uDD26\uDD30-\uDD39\uDD3C-\uDD3E\uDDB5\uDDB6\uDDB8\uDDB9\uDDBB\uDDCD-\uDDCF\uDDD1-\uDDDD])/g;
    };
},
/* wrap-ansi/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const stringWidth = require(6) /* string-width */;
    const stripAnsi = require(7) /* strip-ansi */;
    const ansiStyles = require(12) /* ansi-styles */;
    const ESCAPES = new Set([
        '\u001B',
        '\u009B'
    ]);
    const END_CODE = 39;
    const ANSI_ESCAPE_BELL = '\u0007';
    const ANSI_CSI = '[';
    const ANSI_OSC = ']';
    const ANSI_SGR_TERMINATOR = 'm';
    const ANSI_ESCAPE_LINK = `${ANSI_OSC}8;;`;
    const wrapAnsi = code => `${ESCAPES.values().next().value}${ANSI_CSI}${code}${ANSI_SGR_TERMINATOR}`;
    const wrapAnsiHyperlink = uri => `${ESCAPES.values().next().value}${ANSI_ESCAPE_LINK}${uri}${ANSI_ESCAPE_BELL}`;
    // Calculate the length of words split on ' ', ignoring
    // the extra characters added by ansi escape codes
    const wordLengths = string => string.split(' ').map(character => stringWidth(character));
    // Wrap a long word across multiple rows
    // Ansi escape codes do not count towards length
    const wrapWord = (rows, word, columns) => {
        const characters = [...word];
        let isInsideEscape = false;
        let isInsideLinkEscape = false;
        let visible = stringWidth(stripAnsi(rows[rows.length - 1]));
        for (const [index, character] of characters.entries()) {
            const characterLength = stringWidth(character);
            if (visible + characterLength <= columns) {
                rows[rows.length - 1] += character;
            }
            else {
                rows.push(character);
                visible = 0;
            }
            if (ESCAPES.has(character)) {
                isInsideEscape = true;
                isInsideLinkEscape = characters.slice(index + 1).join('').startsWith(ANSI_ESCAPE_LINK);
            }
            if (isInsideEscape) {
                if (isInsideLinkEscape) {
                    if (character === ANSI_ESCAPE_BELL) {
                        isInsideEscape = false;
                        isInsideLinkEscape = false;
                    }
                }
                else if (character === ANSI_SGR_TERMINATOR) {
                    isInsideEscape = false;
                }
                continue;
            }
            visible += characterLength;
            if (visible === columns && index < characters.length - 1) {
                rows.push('');
                visible = 0;
            }
        }
        // It's possible that the last row we copy over is only
        // ansi escape characters, handle this edge-case
        if (!visible && rows[rows.length - 1].length > 0 && rows.length > 1) {
            rows[rows.length - 2] += rows.pop();
        }
    };
    // Trims spaces from a string ignoring invisible sequences
    const stringVisibleTrimSpacesRight = string => {
        const words = string.split(' ');
        let last = words.length;
        while (last > 0) {
            if (stringWidth(words[last - 1]) > 0) {
                break;
            }
            last--;
        }
        if (last === words.length) {
            return string;
        }
        return words.slice(0, last).join(' ') + words.slice(last).join('');
    };
    // The wrap-ansi module can be invoked in either 'hard' or 'soft' wrap mode
    //
    // 'hard' will never allow a string to take up more than columns characters
    //
    // 'soft' allows long words to expand past the column length
    const exec = (string, columns, options = {}) => {
        if (options.trim !== false && string.trim() === '') {
            return '';
        }
        let returnValue = '';
        let escapeCode;
        let escapeUrl;
        const lengths = wordLengths(string);
        let rows = [''];
        for (const [index, word] of string.split(' ').entries()) {
            if (options.trim !== false) {
                rows[rows.length - 1] = rows[rows.length - 1].trimStart();
            }
            let rowLength = stringWidth(rows[rows.length - 1]);
            if (index !== 0) {
                if (rowLength >= columns && (options.wordWrap === false || options.trim === false)) {
                    // If we start with a new word but the current row length equals the length of the columns, add a new row
                    rows.push('');
                    rowLength = 0;
                }
                if (rowLength > 0 || options.trim === false) {
                    rows[rows.length - 1] += ' ';
                    rowLength++;
                }
            }
            // In 'hard' wrap mode, the length of a line is never allowed to extend past 'columns'
            if (options.hard && lengths[index] > columns) {
                const remainingColumns = (columns - rowLength);
                const breaksStartingThisLine = 1 + Math.floor((lengths[index] - remainingColumns - 1) / columns);
                const breaksStartingNextLine = Math.floor((lengths[index] - 1) / columns);
                if (breaksStartingNextLine < breaksStartingThisLine) {
                    rows.push('');
                }
                wrapWord(rows, word, columns);
                continue;
            }
            if (rowLength + lengths[index] > columns && rowLength > 0 && lengths[index] > 0) {
                if (options.wordWrap === false && rowLength < columns) {
                    wrapWord(rows, word, columns);
                    continue;
                }
                rows.push('');
            }
            if (rowLength + lengths[index] > columns && options.wordWrap === false) {
                wrapWord(rows, word, columns);
                continue;
            }
            rows[rows.length - 1] += word;
        }
        if (options.trim !== false) {
            rows = rows.map(stringVisibleTrimSpacesRight);
        }
        const pre = [...rows.join('\n')];
        for (const [index, character] of pre.entries()) {
            returnValue += character;
            if (ESCAPES.has(character)) {
                const { groups } = new RegExp(`(?:\\${ANSI_CSI}(?<code>\\d+)m|\\${ANSI_ESCAPE_LINK}(?<uri>.*)${ANSI_ESCAPE_BELL})`).exec(pre.slice(index).join('')) || { groups: {} };
                if (groups.code !== undefined) {
                    const code = Number.parseFloat(groups.code);
                    escapeCode = code === END_CODE ? undefined : code;
                }
                else if (groups.uri !== undefined) {
                    escapeUrl = groups.uri.length === 0 ? undefined : groups.uri;
                }
            }
            const code = ansiStyles.codes.get(Number(escapeCode));
            if (pre[index + 1] === '\n') {
                if (escapeUrl) {
                    returnValue += wrapAnsiHyperlink('');
                }
                if (escapeCode && code) {
                    returnValue += wrapAnsi(code);
                }
            }
            else if (character === '\n') {
                if (escapeCode && code) {
                    returnValue += wrapAnsi(escapeCode);
                }
                if (escapeUrl) {
                    returnValue += wrapAnsiHyperlink(escapeUrl);
                }
            }
        }
        return returnValue;
    };
    // For each newline, invoke the method separately
    module.exports = (string, columns, options) => {
        return String(string)
            .normalize()
            .replace(/\r\n/g, '\n')
            .split('\n')
            .map(line => exec(line, columns, options))
            .join('\n');
    };
},
/* ansi-styles/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const wrapAnsi16 = (fn, offset) => (...args) => {
        const code = fn(...args);
        return `\u001B[${code + offset}m`;
    };
    const wrapAnsi256 = (fn, offset) => (...args) => {
        const code = fn(...args);
        return `\u001B[${38 + offset};5;${code}m`;
    };
    const wrapAnsi16m = (fn, offset) => (...args) => {
        const rgb = fn(...args);
        return `\u001B[${38 + offset};2;${rgb[0]};${rgb[1]};${rgb[2]}m`;
    };
    const ansi2ansi = n => n;
    const rgb2rgb = (r, g, b) => [r, g, b];
    const setLazyProperty = (object, property, get) => {
        Object.defineProperty(object, property, {
            get: () => {
                const value = get();
                Object.defineProperty(object, property, {
                    value,
                    enumerable: true,
                    configurable: true
                });
                return value;
            },
            enumerable: true,
            configurable: true
        });
    };
    /** @type {typeof import('color-convert')} */
    let colorConvert;
    const makeDynamicStyles = (wrap, targetSpace, identity, isBackground) => {
        if (colorConvert === undefined) {
            colorConvert = require(13) /* color-convert */;
        }
        const offset = isBackground ? 10 : 0;
        const styles = {};
        for (const [sourceSpace, suite] of Object.entries(colorConvert)) {
            const name = sourceSpace === 'ansi16' ? 'ansi' : sourceSpace;
            if (sourceSpace === targetSpace) {
                styles[name] = wrap(identity, offset);
            }
            else if (typeof suite === 'object') {
                styles[name] = wrap(suite[targetSpace], offset);
            }
        }
        return styles;
    };
    function assembleStyles() {
        const codes = new Map();
        const styles = {
            modifier: {
                reset: [0, 0],
                // 21 isn't widely supported and 22 does the same thing
                bold: [1, 22],
                dim: [2, 22],
                italic: [3, 23],
                underline: [4, 24],
                inverse: [7, 27],
                hidden: [8, 28],
                strikethrough: [9, 29]
            },
            color: {
                black: [30, 39],
                red: [31, 39],
                green: [32, 39],
                yellow: [33, 39],
                blue: [34, 39],
                magenta: [35, 39],
                cyan: [36, 39],
                white: [37, 39],
                // Bright color
                blackBright: [90, 39],
                redBright: [91, 39],
                greenBright: [92, 39],
                yellowBright: [93, 39],
                blueBright: [94, 39],
                magentaBright: [95, 39],
                cyanBright: [96, 39],
                whiteBright: [97, 39]
            },
            bgColor: {
                bgBlack: [40, 49],
                bgRed: [41, 49],
                bgGreen: [42, 49],
                bgYellow: [43, 49],
                bgBlue: [44, 49],
                bgMagenta: [45, 49],
                bgCyan: [46, 49],
                bgWhite: [47, 49],
                // Bright color
                bgBlackBright: [100, 49],
                bgRedBright: [101, 49],
                bgGreenBright: [102, 49],
                bgYellowBright: [103, 49],
                bgBlueBright: [104, 49],
                bgMagentaBright: [105, 49],
                bgCyanBright: [106, 49],
                bgWhiteBright: [107, 49]
            }
        };
        // Alias bright black as gray (and grey)
        styles.color.gray = styles.color.blackBright;
        styles.bgColor.bgGray = styles.bgColor.bgBlackBright;
        styles.color.grey = styles.color.blackBright;
        styles.bgColor.bgGrey = styles.bgColor.bgBlackBright;
        for (const [groupName, group] of Object.entries(styles)) {
            for (const [styleName, style] of Object.entries(group)) {
                styles[styleName] = {
                    open: `\u001B[${style[0]}m`,
                    close: `\u001B[${style[1]}m`
                };
                group[styleName] = styles[styleName];
                codes.set(style[0], style[1]);
            }
            Object.defineProperty(styles, groupName, {
                value: group,
                enumerable: false
            });
        }
        Object.defineProperty(styles, 'codes', {
            value: codes,
            enumerable: false
        });
        styles.color.close = '\u001B[39m';
        styles.bgColor.close = '\u001B[49m';
        setLazyProperty(styles.color, 'ansi', () => makeDynamicStyles(wrapAnsi16, 'ansi16', ansi2ansi, false));
        setLazyProperty(styles.color, 'ansi256', () => makeDynamicStyles(wrapAnsi256, 'ansi256', ansi2ansi, false));
        setLazyProperty(styles.color, 'ansi16m', () => makeDynamicStyles(wrapAnsi16m, 'rgb', rgb2rgb, false));
        setLazyProperty(styles.bgColor, 'ansi', () => makeDynamicStyles(wrapAnsi16, 'ansi16', ansi2ansi, true));
        setLazyProperty(styles.bgColor, 'ansi256', () => makeDynamicStyles(wrapAnsi256, 'ansi256', ansi2ansi, true));
        setLazyProperty(styles.bgColor, 'ansi16m', () => makeDynamicStyles(wrapAnsi16m, 'rgb', rgb2rgb, true));
        return styles;
    }
    // Make the export immutable
    Object.defineProperty(module, 'exports', {
        enumerable: true,
        get: assembleStyles
    });
},
/* color-convert/index.js */ function _(require, module, exports, __esModule, __esExport) {
    const conversions = require(14) /* ./conversions */;
    const route = require(16) /* ./route */;
    const convert = {};
    const models = Object.keys(conversions);
    function wrapRaw(fn) {
        const wrappedFn = function (...args) {
            const arg0 = args[0];
            if (arg0 === undefined || arg0 === null) {
                return arg0;
            }
            if (arg0.length > 1) {
                args = arg0;
            }
            return fn(args);
        };
        // Preserve .conversion property if there is one
        if ('conversion' in fn) {
            wrappedFn.conversion = fn.conversion;
        }
        return wrappedFn;
    }
    function wrapRounded(fn) {
        const wrappedFn = function (...args) {
            const arg0 = args[0];
            if (arg0 === undefined || arg0 === null) {
                return arg0;
            }
            if (arg0.length > 1) {
                args = arg0;
            }
            const result = fn(args);
            // We're assuming the result is an array here.
            // see notice in conversions.js; don't use box types
            // in conversion functions.
            if (typeof result === 'object') {
                for (let len = result.length, i = 0; i < len; i++) {
                    result[i] = Math.round(result[i]);
                }
            }
            return result;
        };
        // Preserve .conversion property if there is one
        if ('conversion' in fn) {
            wrappedFn.conversion = fn.conversion;
        }
        return wrappedFn;
    }
    models.forEach(fromModel => {
        convert[fromModel] = {};
        Object.defineProperty(convert[fromModel], 'channels', { value: conversions[fromModel].channels });
        Object.defineProperty(convert[fromModel], 'labels', { value: conversions[fromModel].labels });
        const routes = route(fromModel);
        const routeModels = Object.keys(routes);
        routeModels.forEach(toModel => {
            const fn = routes[toModel];
            convert[fromModel][toModel] = wrapRounded(fn);
            convert[fromModel][toModel].raw = wrapRaw(fn);
        });
    });
    module.exports = convert;
},
/* color-convert/conversions.js */ function _(require, module, exports, __esModule, __esExport) {
    /* MIT license */
    /* eslint-disable no-mixed-operators */
    const cssKeywords = require(15) /* color-name */;
    // NOTE: conversions should only return primitive values (i.e. arrays, or
    //       values that give correct `typeof` results).
    //       do not use box values types (i.e. Number(), String(), etc.)
    const reverseKeywords = {};
    for (const key of Object.keys(cssKeywords)) {
        reverseKeywords[cssKeywords[key]] = key;
    }
    const convert = {
        rgb: { channels: 3, labels: 'rgb' },
        hsl: { channels: 3, labels: 'hsl' },
        hsv: { channels: 3, labels: 'hsv' },
        hwb: { channels: 3, labels: 'hwb' },
        cmyk: { channels: 4, labels: 'cmyk' },
        xyz: { channels: 3, labels: 'xyz' },
        lab: { channels: 3, labels: 'lab' },
        lch: { channels: 3, labels: 'lch' },
        hex: { channels: 1, labels: ['hex'] },
        keyword: { channels: 1, labels: ['keyword'] },
        ansi16: { channels: 1, labels: ['ansi16'] },
        ansi256: { channels: 1, labels: ['ansi256'] },
        hcg: { channels: 3, labels: ['h', 'c', 'g'] },
        apple: { channels: 3, labels: ['r16', 'g16', 'b16'] },
        gray: { channels: 1, labels: ['gray'] }
    };
    module.exports = convert;
    // Hide .channels and .labels properties
    for (const model of Object.keys(convert)) {
        if (!('channels' in convert[model])) {
            throw new Error('missing channels property: ' + model);
        }
        if (!('labels' in convert[model])) {
            throw new Error('missing channel labels property: ' + model);
        }
        if (convert[model].labels.length !== convert[model].channels) {
            throw new Error('channel and label counts mismatch: ' + model);
        }
        const { channels, labels } = convert[model];
        delete convert[model].channels;
        delete convert[model].labels;
        Object.defineProperty(convert[model], 'channels', { value: channels });
        Object.defineProperty(convert[model], 'labels', { value: labels });
    }
    convert.rgb.hsl = function (rgb) {
        const r = rgb[0] / 255;
        const g = rgb[1] / 255;
        const b = rgb[2] / 255;
        const min = Math.min(r, g, b);
        const max = Math.max(r, g, b);
        const delta = max - min;
        let h;
        let s;
        if (max === min) {
            h = 0;
        }
        else if (r === max) {
            h = (g - b) / delta;
        }
        else if (g === max) {
            h = 2 + (b - r) / delta;
        }
        else if (b === max) {
            h = 4 + (r - g) / delta;
        }
        h = Math.min(h * 60, 360);
        if (h < 0) {
            h += 360;
        }
        const l = (min + max) / 2;
        if (max === min) {
            s = 0;
        }
        else if (l <= 0.5) {
            s = delta / (max + min);
        }
        else {
            s = delta / (2 - max - min);
        }
        return [h, s * 100, l * 100];
    };
    convert.rgb.hsv = function (rgb) {
        let rdif;
        let gdif;
        let bdif;
        let h;
        let s;
        const r = rgb[0] / 255;
        const g = rgb[1] / 255;
        const b = rgb[2] / 255;
        const v = Math.max(r, g, b);
        const diff = v - Math.min(r, g, b);
        const diffc = function (c) {
            return (v - c) / 6 / diff + 1 / 2;
        };
        if (diff === 0) {
            h = 0;
            s = 0;
        }
        else {
            s = diff / v;
            rdif = diffc(r);
            gdif = diffc(g);
            bdif = diffc(b);
            if (r === v) {
                h = bdif - gdif;
            }
            else if (g === v) {
                h = (1 / 3) + rdif - bdif;
            }
            else if (b === v) {
                h = (2 / 3) + gdif - rdif;
            }
            if (h < 0) {
                h += 1;
            }
            else if (h > 1) {
                h -= 1;
            }
        }
        return [
            h * 360,
            s * 100,
            v * 100
        ];
    };
    convert.rgb.hwb = function (rgb) {
        const r = rgb[0];
        const g = rgb[1];
        let b = rgb[2];
        const h = convert.rgb.hsl(rgb)[0];
        const w = 1 / 255 * Math.min(r, Math.min(g, b));
        b = 1 - 1 / 255 * Math.max(r, Math.max(g, b));
        return [h, w * 100, b * 100];
    };
    convert.rgb.cmyk = function (rgb) {
        const r = rgb[0] / 255;
        const g = rgb[1] / 255;
        const b = rgb[2] / 255;
        const k = Math.min(1 - r, 1 - g, 1 - b);
        const c = (1 - r - k) / (1 - k) || 0;
        const m = (1 - g - k) / (1 - k) || 0;
        const y = (1 - b - k) / (1 - k) || 0;
        return [c * 100, m * 100, y * 100, k * 100];
    };
    function comparativeDistance(x, y) {
        /*
            See https://en.m.wikipedia.org/wiki/Euclidean_distance#Squared_Euclidean_distance
        */
        return (((x[0] - y[0]) ** 2) +
            ((x[1] - y[1]) ** 2) +
            ((x[2] - y[2]) ** 2));
    }
    convert.rgb.keyword = function (rgb) {
        const reversed = reverseKeywords[rgb];
        if (reversed) {
            return reversed;
        }
        let currentClosestDistance = Infinity;
        let currentClosestKeyword;
        for (const keyword of Object.keys(cssKeywords)) {
            const value = cssKeywords[keyword];
            // Compute comparative distance
            const distance = comparativeDistance(rgb, value);
            // Check if its less, if so set as closest
            if (distance < currentClosestDistance) {
                currentClosestDistance = distance;
                currentClosestKeyword = keyword;
            }
        }
        return currentClosestKeyword;
    };
    convert.keyword.rgb = function (keyword) {
        return cssKeywords[keyword];
    };
    convert.rgb.xyz = function (rgb) {
        let r = rgb[0] / 255;
        let g = rgb[1] / 255;
        let b = rgb[2] / 255;
        // Assume sRGB
        r = r > 0.04045 ? (((r + 0.055) / 1.055) ** 2.4) : (r / 12.92);
        g = g > 0.04045 ? (((g + 0.055) / 1.055) ** 2.4) : (g / 12.92);
        b = b > 0.04045 ? (((b + 0.055) / 1.055) ** 2.4) : (b / 12.92);
        const x = (r * 0.4124) + (g * 0.3576) + (b * 0.1805);
        const y = (r * 0.2126) + (g * 0.7152) + (b * 0.0722);
        const z = (r * 0.0193) + (g * 0.1192) + (b * 0.9505);
        return [x * 100, y * 100, z * 100];
    };
    convert.rgb.lab = function (rgb) {
        const xyz = convert.rgb.xyz(rgb);
        let x = xyz[0];
        let y = xyz[1];
        let z = xyz[2];
        x /= 95.047;
        y /= 100;
        z /= 108.883;
        x = x > 0.008856 ? (x ** (1 / 3)) : (7.787 * x) + (16 / 116);
        y = y > 0.008856 ? (y ** (1 / 3)) : (7.787 * y) + (16 / 116);
        z = z > 0.008856 ? (z ** (1 / 3)) : (7.787 * z) + (16 / 116);
        const l = (116 * y) - 16;
        const a = 500 * (x - y);
        const b = 200 * (y - z);
        return [l, a, b];
    };
    convert.hsl.rgb = function (hsl) {
        const h = hsl[0] / 360;
        const s = hsl[1] / 100;
        const l = hsl[2] / 100;
        let t2;
        let t3;
        let val;
        if (s === 0) {
            val = l * 255;
            return [val, val, val];
        }
        if (l < 0.5) {
            t2 = l * (1 + s);
        }
        else {
            t2 = l + s - l * s;
        }
        const t1 = 2 * l - t2;
        const rgb = [0, 0, 0];
        for (let i = 0; i < 3; i++) {
            t3 = h + 1 / 3 * -(i - 1);
            if (t3 < 0) {
                t3++;
            }
            if (t3 > 1) {
                t3--;
            }
            if (6 * t3 < 1) {
                val = t1 + (t2 - t1) * 6 * t3;
            }
            else if (2 * t3 < 1) {
                val = t2;
            }
            else if (3 * t3 < 2) {
                val = t1 + (t2 - t1) * (2 / 3 - t3) * 6;
            }
            else {
                val = t1;
            }
            rgb[i] = val * 255;
        }
        return rgb;
    };
    convert.hsl.hsv = function (hsl) {
        const h = hsl[0];
        let s = hsl[1] / 100;
        let l = hsl[2] / 100;
        let smin = s;
        const lmin = Math.max(l, 0.01);
        l *= 2;
        s *= (l <= 1) ? l : 2 - l;
        smin *= lmin <= 1 ? lmin : 2 - lmin;
        const v = (l + s) / 2;
        const sv = l === 0 ? (2 * smin) / (lmin + smin) : (2 * s) / (l + s);
        return [h, sv * 100, v * 100];
    };
    convert.hsv.rgb = function (hsv) {
        const h = hsv[0] / 60;
        const s = hsv[1] / 100;
        let v = hsv[2] / 100;
        const hi = Math.floor(h) % 6;
        const f = h - Math.floor(h);
        const p = 255 * v * (1 - s);
        const q = 255 * v * (1 - (s * f));
        const t = 255 * v * (1 - (s * (1 - f)));
        v *= 255;
        switch (hi) {
            case 0:
                return [v, t, p];
            case 1:
                return [q, v, p];
            case 2:
                return [p, v, t];
            case 3:
                return [p, q, v];
            case 4:
                return [t, p, v];
            case 5:
                return [v, p, q];
        }
    };
    convert.hsv.hsl = function (hsv) {
        const h = hsv[0];
        const s = hsv[1] / 100;
        const v = hsv[2] / 100;
        const vmin = Math.max(v, 0.01);
        let sl;
        let l;
        l = (2 - s) * v;
        const lmin = (2 - s) * vmin;
        sl = s * vmin;
        sl /= (lmin <= 1) ? lmin : 2 - lmin;
        sl = sl || 0;
        l /= 2;
        return [h, sl * 100, l * 100];
    };
    // http://dev.w3.org/csswg/css-color/#hwb-to-rgb
    convert.hwb.rgb = function (hwb) {
        const h = hwb[0] / 360;
        let wh = hwb[1] / 100;
        let bl = hwb[2] / 100;
        const ratio = wh + bl;
        let f;
        // Wh + bl cant be > 1
        if (ratio > 1) {
            wh /= ratio;
            bl /= ratio;
        }
        const i = Math.floor(6 * h);
        const v = 1 - bl;
        f = 6 * h - i;
        if ((i & 0x01) !== 0) {
            f = 1 - f;
        }
        const n = wh + f * (v - wh); // Linear interpolation
        let r;
        let g;
        let b;
        /* eslint-disable max-statements-per-line,no-multi-spaces */
        switch (i) {
            default:
            case 6:
            case 0:
                r = v;
                g = n;
                b = wh;
                break;
            case 1:
                r = n;
                g = v;
                b = wh;
                break;
            case 2:
                r = wh;
                g = v;
                b = n;
                break;
            case 3:
                r = wh;
                g = n;
                b = v;
                break;
            case 4:
                r = n;
                g = wh;
                b = v;
                break;
            case 5:
                r = v;
                g = wh;
                b = n;
                break;
        }
        /* eslint-enable max-statements-per-line,no-multi-spaces */
        return [r * 255, g * 255, b * 255];
    };
    convert.cmyk.rgb = function (cmyk) {
        const c = cmyk[0] / 100;
        const m = cmyk[1] / 100;
        const y = cmyk[2] / 100;
        const k = cmyk[3] / 100;
        const r = 1 - Math.min(1, c * (1 - k) + k);
        const g = 1 - Math.min(1, m * (1 - k) + k);
        const b = 1 - Math.min(1, y * (1 - k) + k);
        return [r * 255, g * 255, b * 255];
    };
    convert.xyz.rgb = function (xyz) {
        const x = xyz[0] / 100;
        const y = xyz[1] / 100;
        const z = xyz[2] / 100;
        let r;
        let g;
        let b;
        r = (x * 3.2406) + (y * -1.5372) + (z * -0.4986);
        g = (x * -0.9689) + (y * 1.8758) + (z * 0.0415);
        b = (x * 0.0557) + (y * -0.2040) + (z * 1.0570);
        // Assume sRGB
        r = r > 0.0031308
            ? ((1.055 * (r ** (1.0 / 2.4))) - 0.055)
            : r * 12.92;
        g = g > 0.0031308
            ? ((1.055 * (g ** (1.0 / 2.4))) - 0.055)
            : g * 12.92;
        b = b > 0.0031308
            ? ((1.055 * (b ** (1.0 / 2.4))) - 0.055)
            : b * 12.92;
        r = Math.min(Math.max(0, r), 1);
        g = Math.min(Math.max(0, g), 1);
        b = Math.min(Math.max(0, b), 1);
        return [r * 255, g * 255, b * 255];
    };
    convert.xyz.lab = function (xyz) {
        let x = xyz[0];
        let y = xyz[1];
        let z = xyz[2];
        x /= 95.047;
        y /= 100;
        z /= 108.883;
        x = x > 0.008856 ? (x ** (1 / 3)) : (7.787 * x) + (16 / 116);
        y = y > 0.008856 ? (y ** (1 / 3)) : (7.787 * y) + (16 / 116);
        z = z > 0.008856 ? (z ** (1 / 3)) : (7.787 * z) + (16 / 116);
        const l = (116 * y) - 16;
        const a = 500 * (x - y);
        const b = 200 * (y - z);
        return [l, a, b];
    };
    convert.lab.xyz = function (lab) {
        const l = lab[0];
        const a = lab[1];
        const b = lab[2];
        let x;
        let y;
        let z;
        y = (l + 16) / 116;
        x = a / 500 + y;
        z = y - b / 200;
        const y2 = y ** 3;
        const x2 = x ** 3;
        const z2 = z ** 3;
        y = y2 > 0.008856 ? y2 : (y - 16 / 116) / 7.787;
        x = x2 > 0.008856 ? x2 : (x - 16 / 116) / 7.787;
        z = z2 > 0.008856 ? z2 : (z - 16 / 116) / 7.787;
        x *= 95.047;
        y *= 100;
        z *= 108.883;
        return [x, y, z];
    };
    convert.lab.lch = function (lab) {
        const l = lab[0];
        const a = lab[1];
        const b = lab[2];
        let h;
        const hr = Math.atan2(b, a);
        h = hr * 360 / 2 / Math.PI;
        if (h < 0) {
            h += 360;
        }
        const c = Math.sqrt(a * a + b * b);
        return [l, c, h];
    };
    convert.lch.lab = function (lch) {
        const l = lch[0];
        const c = lch[1];
        const h = lch[2];
        const hr = h / 360 * 2 * Math.PI;
        const a = c * Math.cos(hr);
        const b = c * Math.sin(hr);
        return [l, a, b];
    };
    convert.rgb.ansi16 = function (args, saturation = null) {
        const [r, g, b] = args;
        let value = saturation === null ? convert.rgb.hsv(args)[2] : saturation; // Hsv -> ansi16 optimization
        value = Math.round(value / 50);
        if (value === 0) {
            return 30;
        }
        let ansi = 30
            + ((Math.round(b / 255) << 2)
                | (Math.round(g / 255) << 1)
                | Math.round(r / 255));
        if (value === 2) {
            ansi += 60;
        }
        return ansi;
    };
    convert.hsv.ansi16 = function (args) {
        // Optimization here; we already know the value and don't need to get
        // it converted for us.
        return convert.rgb.ansi16(convert.hsv.rgb(args), args[2]);
    };
    convert.rgb.ansi256 = function (args) {
        const r = args[0];
        const g = args[1];
        const b = args[2];
        // We use the extended greyscale palette here, with the exception of
        // black and white. normal palette only has 4 greyscale shades.
        if (r === g && g === b) {
            if (r < 8) {
                return 16;
            }
            if (r > 248) {
                return 231;
            }
            return Math.round(((r - 8) / 247) * 24) + 232;
        }
        const ansi = 16
            + (36 * Math.round(r / 255 * 5))
            + (6 * Math.round(g / 255 * 5))
            + Math.round(b / 255 * 5);
        return ansi;
    };
    convert.ansi16.rgb = function (args) {
        let color = args % 10;
        // Handle greyscale
        if (color === 0 || color === 7) {
            if (args > 50) {
                color += 3.5;
            }
            color = color / 10.5 * 255;
            return [color, color, color];
        }
        const mult = (~~(args > 50) + 1) * 0.5;
        const r = ((color & 1) * mult) * 255;
        const g = (((color >> 1) & 1) * mult) * 255;
        const b = (((color >> 2) & 1) * mult) * 255;
        return [r, g, b];
    };
    convert.ansi256.rgb = function (args) {
        // Handle greyscale
        if (args >= 232) {
            const c = (args - 232) * 10 + 8;
            return [c, c, c];
        }
        args -= 16;
        let rem;
        const r = Math.floor(args / 36) / 5 * 255;
        const g = Math.floor((rem = args % 36) / 6) / 5 * 255;
        const b = (rem % 6) / 5 * 255;
        return [r, g, b];
    };
    convert.rgb.hex = function (args) {
        const integer = ((Math.round(args[0]) & 0xFF) << 16)
            + ((Math.round(args[1]) & 0xFF) << 8)
            + (Math.round(args[2]) & 0xFF);
        const string = integer.toString(16).toUpperCase();
        return '000000'.substring(string.length) + string;
    };
    convert.hex.rgb = function (args) {
        const match = args.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);
        if (!match) {
            return [0, 0, 0];
        }
        let colorString = match[0];
        if (match[0].length === 3) {
            colorString = colorString.split('').map(char => {
                return char + char;
            }).join('');
        }
        const integer = parseInt(colorString, 16);
        const r = (integer >> 16) & 0xFF;
        const g = (integer >> 8) & 0xFF;
        const b = integer & 0xFF;
        return [r, g, b];
    };
    convert.rgb.hcg = function (rgb) {
        const r = rgb[0] / 255;
        const g = rgb[1] / 255;
        const b = rgb[2] / 255;
        const max = Math.max(Math.max(r, g), b);
        const min = Math.min(Math.min(r, g), b);
        const chroma = (max - min);
        let grayscale;
        let hue;
        if (chroma < 1) {
            grayscale = min / (1 - chroma);
        }
        else {
            grayscale = 0;
        }
        if (chroma <= 0) {
            hue = 0;
        }
        else if (max === r) {
            hue = ((g - b) / chroma) % 6;
        }
        else if (max === g) {
            hue = 2 + (b - r) / chroma;
        }
        else {
            hue = 4 + (r - g) / chroma;
        }
        hue /= 6;
        hue %= 1;
        return [hue * 360, chroma * 100, grayscale * 100];
    };
    convert.hsl.hcg = function (hsl) {
        const s = hsl[1] / 100;
        const l = hsl[2] / 100;
        const c = l < 0.5 ? (2.0 * s * l) : (2.0 * s * (1.0 - l));
        let f = 0;
        if (c < 1.0) {
            f = (l - 0.5 * c) / (1.0 - c);
        }
        return [hsl[0], c * 100, f * 100];
    };
    convert.hsv.hcg = function (hsv) {
        const s = hsv[1] / 100;
        const v = hsv[2] / 100;
        const c = s * v;
        let f = 0;
        if (c < 1.0) {
            f = (v - c) / (1 - c);
        }
        return [hsv[0], c * 100, f * 100];
    };
    convert.hcg.rgb = function (hcg) {
        const h = hcg[0] / 360;
        const c = hcg[1] / 100;
        const g = hcg[2] / 100;
        if (c === 0.0) {
            return [g * 255, g * 255, g * 255];
        }
        const pure = [0, 0, 0];
        const hi = (h % 1) * 6;
        const v = hi % 1;
        const w = 1 - v;
        let mg = 0;
        /* eslint-disable max-statements-per-line */
        switch (Math.floor(hi)) {
            case 0:
                pure[0] = 1;
                pure[1] = v;
                pure[2] = 0;
                break;
            case 1:
                pure[0] = w;
                pure[1] = 1;
                pure[2] = 0;
                break;
            case 2:
                pure[0] = 0;
                pure[1] = 1;
                pure[2] = v;
                break;
            case 3:
                pure[0] = 0;
                pure[1] = w;
                pure[2] = 1;
                break;
            case 4:
                pure[0] = v;
                pure[1] = 0;
                pure[2] = 1;
                break;
            default:
                pure[0] = 1;
                pure[1] = 0;
                pure[2] = w;
        }
        /* eslint-enable max-statements-per-line */
        mg = (1.0 - c) * g;
        return [
            (c * pure[0] + mg) * 255,
            (c * pure[1] + mg) * 255,
            (c * pure[2] + mg) * 255
        ];
    };
    convert.hcg.hsv = function (hcg) {
        const c = hcg[1] / 100;
        const g = hcg[2] / 100;
        const v = c + g * (1.0 - c);
        let f = 0;
        if (v > 0.0) {
            f = c / v;
        }
        return [hcg[0], f * 100, v * 100];
    };
    convert.hcg.hsl = function (hcg) {
        const c = hcg[1] / 100;
        const g = hcg[2] / 100;
        const l = g * (1.0 - c) + 0.5 * c;
        let s = 0;
        if (l > 0.0 && l < 0.5) {
            s = c / (2 * l);
        }
        else if (l >= 0.5 && l < 1.0) {
            s = c / (2 * (1 - l));
        }
        return [hcg[0], s * 100, l * 100];
    };
    convert.hcg.hwb = function (hcg) {
        const c = hcg[1] / 100;
        const g = hcg[2] / 100;
        const v = c + g * (1.0 - c);
        return [hcg[0], (v - c) * 100, (1 - v) * 100];
    };
    convert.hwb.hcg = function (hwb) {
        const w = hwb[1] / 100;
        const b = hwb[2] / 100;
        const v = 1 - b;
        const c = v - w;
        let g = 0;
        if (c < 1) {
            g = (v - c) / (1 - c);
        }
        return [hwb[0], c * 100, g * 100];
    };
    convert.apple.rgb = function (apple) {
        return [(apple[0] / 65535) * 255, (apple[1] / 65535) * 255, (apple[2] / 65535) * 255];
    };
    convert.rgb.apple = function (rgb) {
        return [(rgb[0] / 255) * 65535, (rgb[1] / 255) * 65535, (rgb[2] / 255) * 65535];
    };
    convert.gray.rgb = function (args) {
        return [args[0] / 100 * 255, args[0] / 100 * 255, args[0] / 100 * 255];
    };
    convert.gray.hsl = function (args) {
        return [0, 0, args[0]];
    };
    convert.gray.hsv = convert.gray.hsl;
    convert.gray.hwb = function (gray) {
        return [0, 100, gray[0]];
    };
    convert.gray.cmyk = function (gray) {
        return [0, 0, 0, gray[0]];
    };
    convert.gray.lab = function (gray) {
        return [gray[0], 0, 0];
    };
    convert.gray.hex = function (gray) {
        const val = Math.round(gray[0] / 100 * 255) & 0xFF;
        const integer = (val << 16) + (val << 8) + val;
        const string = integer.toString(16).toUpperCase();
        return '000000'.substring(string.length) + string;
    };
    convert.rgb.gray = function (rgb) {
        const val = (rgb[0] + rgb[1] + rgb[2]) / 3;
        return [val / 255 * 100];
    };
},
/* color-name/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = {
        "aliceblue": [240, 248, 255],
        "antiquewhite": [250, 235, 215],
        "aqua": [0, 255, 255],
        "aquamarine": [127, 255, 212],
        "azure": [240, 255, 255],
        "beige": [245, 245, 220],
        "bisque": [255, 228, 196],
        "black": [0, 0, 0],
        "blanchedalmond": [255, 235, 205],
        "blue": [0, 0, 255],
        "blueviolet": [138, 43, 226],
        "brown": [165, 42, 42],
        "burlywood": [222, 184, 135],
        "cadetblue": [95, 158, 160],
        "chartreuse": [127, 255, 0],
        "chocolate": [210, 105, 30],
        "coral": [255, 127, 80],
        "cornflowerblue": [100, 149, 237],
        "cornsilk": [255, 248, 220],
        "crimson": [220, 20, 60],
        "cyan": [0, 255, 255],
        "darkblue": [0, 0, 139],
        "darkcyan": [0, 139, 139],
        "darkgoldenrod": [184, 134, 11],
        "darkgray": [169, 169, 169],
        "darkgreen": [0, 100, 0],
        "darkgrey": [169, 169, 169],
        "darkkhaki": [189, 183, 107],
        "darkmagenta": [139, 0, 139],
        "darkolivegreen": [85, 107, 47],
        "darkorange": [255, 140, 0],
        "darkorchid": [153, 50, 204],
        "darkred": [139, 0, 0],
        "darksalmon": [233, 150, 122],
        "darkseagreen": [143, 188, 143],
        "darkslateblue": [72, 61, 139],
        "darkslategray": [47, 79, 79],
        "darkslategrey": [47, 79, 79],
        "darkturquoise": [0, 206, 209],
        "darkviolet": [148, 0, 211],
        "deeppink": [255, 20, 147],
        "deepskyblue": [0, 191, 255],
        "dimgray": [105, 105, 105],
        "dimgrey": [105, 105, 105],
        "dodgerblue": [30, 144, 255],
        "firebrick": [178, 34, 34],
        "floralwhite": [255, 250, 240],
        "forestgreen": [34, 139, 34],
        "fuchsia": [255, 0, 255],
        "gainsboro": [220, 220, 220],
        "ghostwhite": [248, 248, 255],
        "gold": [255, 215, 0],
        "goldenrod": [218, 165, 32],
        "gray": [128, 128, 128],
        "green": [0, 128, 0],
        "greenyellow": [173, 255, 47],
        "grey": [128, 128, 128],
        "honeydew": [240, 255, 240],
        "hotpink": [255, 105, 180],
        "indianred": [205, 92, 92],
        "indigo": [75, 0, 130],
        "ivory": [255, 255, 240],
        "khaki": [240, 230, 140],
        "lavender": [230, 230, 250],
        "lavenderblush": [255, 240, 245],
        "lawngreen": [124, 252, 0],
        "lemonchiffon": [255, 250, 205],
        "lightblue": [173, 216, 230],
        "lightcoral": [240, 128, 128],
        "lightcyan": [224, 255, 255],
        "lightgoldenrodyellow": [250, 250, 210],
        "lightgray": [211, 211, 211],
        "lightgreen": [144, 238, 144],
        "lightgrey": [211, 211, 211],
        "lightpink": [255, 182, 193],
        "lightsalmon": [255, 160, 122],
        "lightseagreen": [32, 178, 170],
        "lightskyblue": [135, 206, 250],
        "lightslategray": [119, 136, 153],
        "lightslategrey": [119, 136, 153],
        "lightsteelblue": [176, 196, 222],
        "lightyellow": [255, 255, 224],
        "lime": [0, 255, 0],
        "limegreen": [50, 205, 50],
        "linen": [250, 240, 230],
        "magenta": [255, 0, 255],
        "maroon": [128, 0, 0],
        "mediumaquamarine": [102, 205, 170],
        "mediumblue": [0, 0, 205],
        "mediumorchid": [186, 85, 211],
        "mediumpurple": [147, 112, 219],
        "mediumseagreen": [60, 179, 113],
        "mediumslateblue": [123, 104, 238],
        "mediumspringgreen": [0, 250, 154],
        "mediumturquoise": [72, 209, 204],
        "mediumvioletred": [199, 21, 133],
        "midnightblue": [25, 25, 112],
        "mintcream": [245, 255, 250],
        "mistyrose": [255, 228, 225],
        "moccasin": [255, 228, 181],
        "navajowhite": [255, 222, 173],
        "navy": [0, 0, 128],
        "oldlace": [253, 245, 230],
        "olive": [128, 128, 0],
        "olivedrab": [107, 142, 35],
        "orange": [255, 165, 0],
        "orangered": [255, 69, 0],
        "orchid": [218, 112, 214],
        "palegoldenrod": [238, 232, 170],
        "palegreen": [152, 251, 152],
        "paleturquoise": [175, 238, 238],
        "palevioletred": [219, 112, 147],
        "papayawhip": [255, 239, 213],
        "peachpuff": [255, 218, 185],
        "peru": [205, 133, 63],
        "pink": [255, 192, 203],
        "plum": [221, 160, 221],
        "powderblue": [176, 224, 230],
        "purple": [128, 0, 128],
        "rebeccapurple": [102, 51, 153],
        "red": [255, 0, 0],
        "rosybrown": [188, 143, 143],
        "royalblue": [65, 105, 225],
        "saddlebrown": [139, 69, 19],
        "salmon": [250, 128, 114],
        "sandybrown": [244, 164, 96],
        "seagreen": [46, 139, 87],
        "seashell": [255, 245, 238],
        "sienna": [160, 82, 45],
        "silver": [192, 192, 192],
        "skyblue": [135, 206, 235],
        "slateblue": [106, 90, 205],
        "slategray": [112, 128, 144],
        "slategrey": [112, 128, 144],
        "snow": [255, 250, 250],
        "springgreen": [0, 255, 127],
        "steelblue": [70, 130, 180],
        "tan": [210, 180, 140],
        "teal": [0, 128, 128],
        "thistle": [216, 191, 216],
        "tomato": [255, 99, 71],
        "turquoise": [64, 224, 208],
        "violet": [238, 130, 238],
        "wheat": [245, 222, 179],
        "white": [255, 255, 255],
        "whitesmoke": [245, 245, 245],
        "yellow": [255, 255, 0],
        "yellowgreen": [154, 205, 50]
    };
},
/* color-convert/route.js */ function _(require, module, exports, __esModule, __esExport) {
    const conversions = require(14) /* ./conversions */;
    /*
        This function routes a model to all other models.
    
        all functions that are routed have a property `.conversion` attached
        to the returned synthetic function. This property is an array
        of strings, each with the steps in between the 'from' and 'to'
        color models (inclusive).
    
        conversions that are not possible simply are not included.
    */
    function buildGraph() {
        const graph = {};
        // https://jsperf.com/object-keys-vs-for-in-with-closure/3
        const models = Object.keys(conversions);
        for (let len = models.length, i = 0; i < len; i++) {
            graph[models[i]] = {
                // http://jsperf.com/1-vs-infinity
                // micro-opt, but this is simple.
                distance: -1,
                parent: null
            };
        }
        return graph;
    }
    // https://en.wikipedia.org/wiki/Breadth-first_search
    function deriveBFS(fromModel) {
        const graph = buildGraph();
        const queue = [fromModel]; // Unshift -> queue -> pop
        graph[fromModel].distance = 0;
        while (queue.length) {
            const current = queue.pop();
            const adjacents = Object.keys(conversions[current]);
            for (let len = adjacents.length, i = 0; i < len; i++) {
                const adjacent = adjacents[i];
                const node = graph[adjacent];
                if (node.distance === -1) {
                    node.distance = graph[current].distance + 1;
                    node.parent = current;
                    queue.unshift(adjacent);
                }
            }
        }
        return graph;
    }
    function link(from, to) {
        return function (args) {
            return to(from(args));
        };
    }
    function wrapConversion(toModel, graph) {
        const path = [graph[toModel].parent, toModel];
        let fn = conversions[graph[toModel].parent][toModel];
        let cur = graph[toModel].parent;
        while (graph[cur].parent) {
            path.unshift(graph[cur].parent);
            fn = link(conversions[graph[cur].parent][cur], fn);
            cur = graph[cur].parent;
        }
        fn.conversion = path;
        return fn;
    }
    module.exports = function (fromModel) {
        const graph = deriveBFS(fromModel);
        const conversion = {};
        const models = Object.keys(graph);
        for (let len = models.length, i = 0; i < len; i++) {
            const toModel = models[i];
            const node = graph[toModel];
            if (node.parent === null) {
                // No possible conversion, or this node is the source model.
                continue;
            }
            conversion[toModel] = wrapConversion(toModel, graph);
        }
        return conversion;
    };
},
/* escalade/sync/index.js */ function _(require, module, exports, __esModule, __esExport) {
    const { dirname, resolve } = require('path');
    const { readdirSync, statSync } = require('fs');
    module.exports = function (start, callback) {
        let dir = resolve('.', start);
        let tmp, stats = statSync(dir);
        if (!stats.isDirectory()) {
            dir = dirname(dir);
        }
        while (true) {
            tmp = callback(dir, readdirSync(dir));
            if (tmp)
                return resolve(dir, tmp);
            dir = dirname(tmp = dir);
            if (tmp === dir)
                break;
        }
    };
},
/* get-caller-file/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Call this function in a another function to find out the file from
    // which that function was called from. (Inspects the v8 stack trace)
    //
    // Inspired by http://stackoverflow.com/questions/13227489
    module.exports = function getCallerFile(position) {
        if (position === void 0) {
            position = 2;
        }
        if (position >= Error.stackTraceLimit) {
            throw new TypeError('getCallerFile(position) requires position be less then Error.stackTraceLimit but position was: `' + position + '` and Error.stackTraceLimit was: `' + Error.stackTraceLimit + '`');
        }
        var oldPrepareStackTrace = Error.prepareStackTrace;
        Error.prepareStackTrace = function (_, stack) { return stack; };
        var stack = new Error().stack;
        Error.prepareStackTrace = oldPrepareStackTrace;
        if (stack !== null && typeof stack === 'object') {
            // stack[0] holds this file
            // stack[1] holds where this function was called
            // stack[2] holds the file we're interested in
            return stack[position] ? stack[position].getFileName() : undefined;
        }
    };
    
},
/* require-directory/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var fs = require('fs'), join = require('path').join, resolve = require('path').resolve, dirname = require('path').dirname, defaultOptions = {
        extensions: ['js', 'json', 'coffee'],
        recurse: true,
        rename: function (name) {
            return name;
        },
        visit: function (obj) {
            return obj;
        }
    };
    function checkFileInclusion(path, filename, options) {
        return (
        // verify file has valid extension
        (new RegExp('\\.(' + options.extensions.join('|') + ')$', 'i').test(filename)) &&
            // if options.include is a RegExp, evaluate it and make sure the path passes
            !(options.include && options.include instanceof RegExp && !options.include.test(path)) &&
            // if options.include is a function, evaluate it and make sure the path passes
            !(options.include && typeof options.include === 'function' && !options.include(path, filename)) &&
            // if options.exclude is a RegExp, evaluate it and make sure the path doesn't pass
            !(options.exclude && options.exclude instanceof RegExp && options.exclude.test(path)) &&
            // if options.exclude is a function, evaluate it and make sure the path doesn't pass
            !(options.exclude && typeof options.exclude === 'function' && options.exclude(path, filename)));
    }
    function requireDirectory(m, path, options) {
        var retval = {};
        // path is optional
        if (path && !options && typeof path !== 'string') {
            options = path;
            path = null;
        }
        // default options
        options = options || {};
        for (var prop in defaultOptions) {
            if (typeof options[prop] === 'undefined') {
                options[prop] = defaultOptions[prop];
            }
        }
        // if no path was passed in, assume the equivelant of __dirname from caller
        // otherwise, resolve path relative to the equivalent of __dirname
        path = !path ? dirname(m.filename) : resolve(dirname(m.filename), path);
        // get the path of each file in specified directory, append to current tree node, recurse
        fs.readdirSync(path).forEach(function (filename) {
            var joined = join(path, filename), files, key, obj;
            if (fs.statSync(joined).isDirectory() && options.recurse) {
                // this node is a directory; recurse
                files = requireDirectory(m, joined, options);
                // exclude empty directories
                if (Object.keys(files).length) {
                    retval[options.rename(filename, joined, filename)] = files;
                }
            }
            else {
                if (joined !== m.filename && checkFileInclusion(joined, filename, options)) {
                    // hash node key shouldn't include file extension
                    key = filename.substring(0, filename.lastIndexOf('.'));
                    obj = m.require(joined);
                    retval[options.rename(key, joined, filename)] = options.visit(obj, joined, filename) || obj;
                }
            }
        });
        return retval;
    }
    module.exports = requireDirectory;
    module.exports.defaults = defaultOptions;
},
/* sys.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.read_json = exports.hash_file = exports.hash = exports.rename = exports.directory_exists = exports.file_exists = exports.write = exports.read = exports.glob = exports.scan = void 0;
    const ts = __importStar(require(21) /* typescript */);
    const crypto_1 = __importDefault(require("crypto"));
    const path_1 = require("path");
    function scan(path, extensions, exclude, include, depth) {
        return ts.sys.readDirectory(path, extensions, exclude, include, depth).map((p) => (0, path_1.normalize)(p));
    }
    exports.scan = scan;
    function glob(...patterns) {
        return scan(".", undefined, undefined, patterns);
    }
    exports.glob = glob;
    exports.read = ts.sys.readFile;
    exports.write = ts.sys.writeFile;
    exports.file_exists = ts.sys.fileExists;
    exports.directory_exists = ts.sys.directoryExists;
    function rename(path, options) {
        let { dir, name, ext } = (0, path_1.parse)(path);
        if (options.dir != null) {
            if (options.base != null)
                dir = dir.replace(options.base, options.dir);
            else
                dir = options.dir;
        }
        if (options.name != null)
            name = options.name(name);
        if (options.ext != null)
            ext = options.ext;
        return (0, path_1.format)({ dir, name, ext });
    }
    exports.rename = rename;
    function hash(data) {
        return crypto_1.default.createHash("sha256").update(data).digest("hex");
    }
    exports.hash = hash;
    function hash_file(path) {
        const contents = (0, exports.read)(path);
        return contents != null ? hash(contents) : null;
    }
    exports.hash_file = hash_file;
    function read_json(path) {
        const data = (0, exports.read)(path);
        if (data == null)
            return undefined;
        else {
            try {
                return JSON.parse(data);
            }
            catch {
                return undefined;
            }
        }
    }
    exports.read_json = read_json;
    
},
/* typescript/lib/typescript.js */ function _(require, module, exports, __esModule, __esExport) {/*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0
    
    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.
    
    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */
    "use strict";
    var ts = (() => {
        var __defProp = Object.defineProperty;
        var __getOwnPropNames = Object.getOwnPropertyNames;
        var __esm = (fn, res) => function __init() {
            return fn && (res = (0, fn[__getOwnPropNames(fn)[0]])(fn = 0)), res;
        };
        var __commonJS = (cb, mod) => function __require() {
            return mod || (0, cb[__getOwnPropNames(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
        };
        var __export = (target, all) => {
            for (var name in all)
                __defProp(target, name, { get: all[name], enumerable: true });
        };
        // src/compiler/corePublic.ts
        var versionMajorMinor, version, Comparison;
        var init_corePublic = __esm({
            "src/compiler/corePublic.ts"() {
                "use strict";
                versionMajorMinor = "5.0";
                version = "5.0.4";
                Comparison = /* @__PURE__ */ ((Comparison3) => {
                    Comparison3[Comparison3["LessThan"] = -1] = "LessThan";
                    Comparison3[Comparison3["EqualTo"] = 0] = "EqualTo";
                    Comparison3[Comparison3["GreaterThan"] = 1] = "GreaterThan";
                    return Comparison3;
                })(Comparison || {});
            }
        });
        // src/compiler/core.ts
        function length(array) {
            return array ? array.length : 0;
        }
        function forEach(array, callback) {
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const result = callback(array[i], i);
                    if (result) {
                        return result;
                    }
                }
            }
            return void 0;
        }
        function forEachRight(array, callback) {
            if (array) {
                for (let i = array.length - 1; i >= 0; i--) {
                    const result = callback(array[i], i);
                    if (result) {
                        return result;
                    }
                }
            }
            return void 0;
        }
        function firstDefined(array, callback) {
            if (array === void 0) {
                return void 0;
            }
            for (let i = 0; i < array.length; i++) {
                const result = callback(array[i], i);
                if (result !== void 0) {
                    return result;
                }
            }
            return void 0;
        }
        function firstDefinedIterator(iter, callback) {
            for (const value of iter) {
                const result = callback(value);
                if (result !== void 0) {
                    return result;
                }
            }
            return void 0;
        }
        function reduceLeftIterator(iterator, f, initial) {
            let result = initial;
            if (iterator) {
                let pos = 0;
                for (const value of iterator) {
                    result = f(result, value, pos);
                    pos++;
                }
            }
            return result;
        }
        function zipWith(arrayA, arrayB, callback) {
            const result = [];
            Debug.assertEqual(arrayA.length, arrayB.length);
            for (let i = 0; i < arrayA.length; i++) {
                result.push(callback(arrayA[i], arrayB[i], i));
            }
            return result;
        }
        function intersperse(input, element) {
            if (input.length <= 1) {
                return input;
            }
            const result = [];
            for (let i = 0, n = input.length; i < n; i++) {
                if (i)
                    result.push(element);
                result.push(input[i]);
            }
            return result;
        }
        function every(array, callback) {
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    if (!callback(array[i], i)) {
                        return false;
                    }
                }
            }
            return true;
        }
        function find(array, predicate, startIndex) {
            if (array === void 0)
                return void 0;
            for (let i = startIndex != null ? startIndex : 0; i < array.length; i++) {
                const value = array[i];
                if (predicate(value, i)) {
                    return value;
                }
            }
            return void 0;
        }
        function findLast(array, predicate, startIndex) {
            if (array === void 0)
                return void 0;
            for (let i = startIndex != null ? startIndex : array.length - 1; i >= 0; i--) {
                const value = array[i];
                if (predicate(value, i)) {
                    return value;
                }
            }
            return void 0;
        }
        function findIndex(array, predicate, startIndex) {
            if (array === void 0)
                return -1;
            for (let i = startIndex != null ? startIndex : 0; i < array.length; i++) {
                if (predicate(array[i], i)) {
                    return i;
                }
            }
            return -1;
        }
        function findLastIndex(array, predicate, startIndex) {
            if (array === void 0)
                return -1;
            for (let i = startIndex != null ? startIndex : array.length - 1; i >= 0; i--) {
                if (predicate(array[i], i)) {
                    return i;
                }
            }
            return -1;
        }
        function findMap(array, callback) {
            for (let i = 0; i < array.length; i++) {
                const result = callback(array[i], i);
                if (result) {
                    return result;
                }
            }
            return Debug.fail();
        }
        function contains(array, value, equalityComparer = equateValues) {
            if (array) {
                for (const v of array) {
                    if (equalityComparer(v, value)) {
                        return true;
                    }
                }
            }
            return false;
        }
        function arraysEqual(a, b, equalityComparer = equateValues) {
            return a.length === b.length && a.every((x, i) => equalityComparer(x, b[i]));
        }
        function indexOfAnyCharCode(text, charCodes, start) {
            for (let i = start || 0; i < text.length; i++) {
                if (contains(charCodes, text.charCodeAt(i))) {
                    return i;
                }
            }
            return -1;
        }
        function countWhere(array, predicate) {
            let count = 0;
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const v = array[i];
                    if (predicate(v, i)) {
                        count++;
                    }
                }
            }
            return count;
        }
        function filter(array, f) {
            if (array) {
                const len = array.length;
                let i = 0;
                while (i < len && f(array[i]))
                    i++;
                if (i < len) {
                    const result = array.slice(0, i);
                    i++;
                    while (i < len) {
                        const item = array[i];
                        if (f(item)) {
                            result.push(item);
                        }
                        i++;
                    }
                    return result;
                }
            }
            return array;
        }
        function filterMutate(array, f) {
            let outIndex = 0;
            for (let i = 0; i < array.length; i++) {
                if (f(array[i], i, array)) {
                    array[outIndex] = array[i];
                    outIndex++;
                }
            }
            array.length = outIndex;
        }
        function clear(array) {
            array.length = 0;
        }
        function map(array, f) {
            let result;
            if (array) {
                result = [];
                for (let i = 0; i < array.length; i++) {
                    result.push(f(array[i], i));
                }
            }
            return result;
        }
        function* mapIterator(iter, mapFn) {
            for (const x of iter) {
                yield mapFn(x);
            }
        }
        function sameMap(array, f) {
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const item = array[i];
                    const mapped = f(item, i);
                    if (item !== mapped) {
                        const result = array.slice(0, i);
                        result.push(mapped);
                        for (i++; i < array.length; i++) {
                            result.push(f(array[i], i));
                        }
                        return result;
                    }
                }
            }
            return array;
        }
        function flatten(array) {
            const result = [];
            for (const v of array) {
                if (v) {
                    if (isArray(v)) {
                        addRange(result, v);
                    }
                    else {
                        result.push(v);
                    }
                }
            }
            return result;
        }
        function flatMap(array, mapfn) {
            let result;
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const v = mapfn(array[i], i);
                    if (v) {
                        if (isArray(v)) {
                            result = addRange(result, v);
                        }
                        else {
                            result = append(result, v);
                        }
                    }
                }
            }
            return result || emptyArray;
        }
        function flatMapToMutable(array, mapfn) {
            const result = [];
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const v = mapfn(array[i], i);
                    if (v) {
                        if (isArray(v)) {
                            addRange(result, v);
                        }
                        else {
                            result.push(v);
                        }
                    }
                }
            }
            return result;
        }
        function* flatMapIterator(iter, mapfn) {
            for (const x of iter) {
                const iter2 = mapfn(x);
                if (!iter2)
                    continue;
                yield* iter2;
            }
        }
        function sameFlatMap(array, mapfn) {
            let result;
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const item = array[i];
                    const mapped = mapfn(item, i);
                    if (result || item !== mapped || isArray(mapped)) {
                        if (!result) {
                            result = array.slice(0, i);
                        }
                        if (isArray(mapped)) {
                            addRange(result, mapped);
                        }
                        else {
                            result.push(mapped);
                        }
                    }
                }
            }
            return result || array;
        }
        function mapAllOrFail(array, mapFn) {
            const result = [];
            for (let i = 0; i < array.length; i++) {
                const mapped = mapFn(array[i], i);
                if (mapped === void 0) {
                    return void 0;
                }
                result.push(mapped);
            }
            return result;
        }
        function mapDefined(array, mapFn) {
            const result = [];
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const mapped = mapFn(array[i], i);
                    if (mapped !== void 0) {
                        result.push(mapped);
                    }
                }
            }
            return result;
        }
        function* mapDefinedIterator(iter, mapFn) {
            for (const x of iter) {
                const value = mapFn(x);
                if (value !== void 0) {
                    yield value;
                }
            }
        }
        function mapDefinedEntries(map2, f) {
            if (!map2) {
                return void 0;
            }
            const result = /* @__PURE__ */ new Map();
            map2.forEach((value, key) => {
                const entry = f(key, value);
                if (entry !== void 0) {
                    const [newKey, newValue] = entry;
                    if (newKey !== void 0 && newValue !== void 0) {
                        result.set(newKey, newValue);
                    }
                }
            });
            return result;
        }
        function getOrUpdate(map2, key, callback) {
            if (map2.has(key)) {
                return map2.get(key);
            }
            const value = callback();
            map2.set(key, value);
            return value;
        }
        function tryAddToSet(set, value) {
            if (!set.has(value)) {
                set.add(value);
                return true;
            }
            return false;
        }
        function* singleIterator(value) {
            yield value;
        }
        function spanMap(array, keyfn, mapfn) {
            let result;
            if (array) {
                result = [];
                const len = array.length;
                let previousKey;
                let key;
                let start = 0;
                let pos = 0;
                while (start < len) {
                    while (pos < len) {
                        const value = array[pos];
                        key = keyfn(value, pos);
                        if (pos === 0) {
                            previousKey = key;
                        }
                        else if (key !== previousKey) {
                            break;
                        }
                        pos++;
                    }
                    if (start < pos) {
                        const v = mapfn(array.slice(start, pos), previousKey, start, pos);
                        if (v) {
                            result.push(v);
                        }
                        start = pos;
                    }
                    previousKey = key;
                    pos++;
                }
            }
            return result;
        }
        function mapEntries(map2, f) {
            if (!map2) {
                return void 0;
            }
            const result = /* @__PURE__ */ new Map();
            map2.forEach((value, key) => {
                const [newKey, newValue] = f(key, value);
                result.set(newKey, newValue);
            });
            return result;
        }
        function some(array, predicate) {
            if (array) {
                if (predicate) {
                    for (const v of array) {
                        if (predicate(v)) {
                            return true;
                        }
                    }
                }
                else {
                    return array.length > 0;
                }
            }
            return false;
        }
        function getRangesWhere(arr, pred, cb) {
            let start;
            for (let i = 0; i < arr.length; i++) {
                if (pred(arr[i])) {
                    start = start === void 0 ? i : start;
                }
                else {
                    if (start !== void 0) {
                        cb(start, i);
                        start = void 0;
                    }
                }
            }
            if (start !== void 0)
                cb(start, arr.length);
        }
        function concatenate(array1, array2) {
            if (!some(array2))
                return array1;
            if (!some(array1))
                return array2;
            return [...array1, ...array2];
        }
        function selectIndex(_, i) {
            return i;
        }
        function indicesOf(array) {
            return array.map(selectIndex);
        }
        function deduplicateRelational(array, equalityComparer, comparer) {
            const indices = indicesOf(array);
            stableSortIndices(array, indices, comparer);
            let last2 = array[indices[0]];
            const deduplicated = [indices[0]];
            for (let i = 1; i < indices.length; i++) {
                const index = indices[i];
                const item = array[index];
                if (!equalityComparer(last2, item)) {
                    deduplicated.push(index);
                    last2 = item;
                }
            }
            deduplicated.sort();
            return deduplicated.map((i) => array[i]);
        }
        function deduplicateEquality(array, equalityComparer) {
            const result = [];
            for (const item of array) {
                pushIfUnique(result, item, equalityComparer);
            }
            return result;
        }
        function deduplicate(array, equalityComparer, comparer) {
            return array.length === 0 ? [] : array.length === 1 ? array.slice() : comparer ? deduplicateRelational(array, equalityComparer, comparer) : deduplicateEquality(array, equalityComparer);
        }
        function deduplicateSorted(array, comparer) {
            if (array.length === 0)
                return emptyArray;
            let last2 = array[0];
            const deduplicated = [last2];
            for (let i = 1; i < array.length; i++) {
                const next = array[i];
                switch (comparer(next, last2)) {
                    case true:
                    case 0 /* EqualTo */:
                        continue;
                    case -1 /* LessThan */:
                        return Debug.fail("Array is unsorted.");
                }
                deduplicated.push(last2 = next);
            }
            return deduplicated;
        }
        function createSortedArray() {
            return [];
        }
        function insertSorted(array, insert, compare, allowDuplicates) {
            if (array.length === 0) {
                array.push(insert);
                return true;
            }
            const insertIndex = binarySearch(array, insert, identity, compare);
            if (insertIndex < 0) {
                array.splice(~insertIndex, 0, insert);
                return true;
            }
            if (allowDuplicates) {
                array.splice(insertIndex, 0, insert);
                return true;
            }
            return false;
        }
        function sortAndDeduplicate(array, comparer, equalityComparer) {
            return deduplicateSorted(sort(array, comparer), equalityComparer || comparer || compareStringsCaseSensitive);
        }
        function arrayIsSorted(array, comparer) {
            if (array.length < 2)
                return true;
            for (let i = 1, len = array.length; i < len; i++) {
                if (comparer(array[i - 1], array[i]) === 1 /* GreaterThan */) {
                    return false;
                }
            }
            return true;
        }
        function detectSortCaseSensitivity(array, getString, compareStringsCaseSensitive2, compareStringsCaseInsensitive2) {
            let kind = 3 /* Both */;
            if (array.length < 2)
                return kind;
            let prevElement = getString(array[0]);
            for (let i = 1, len = array.length; i < len && kind !== 0 /* None */; i++) {
                const element = getString(array[i]);
                if (kind & 1 /* CaseSensitive */ && compareStringsCaseSensitive2(prevElement, element) > 0) {
                    kind &= ~1 /* CaseSensitive */;
                }
                if (kind & 2 /* CaseInsensitive */ && compareStringsCaseInsensitive2(prevElement, element) > 0) {
                    kind &= ~2 /* CaseInsensitive */;
                }
                prevElement = element;
            }
            return kind;
        }
        function arrayIsEqualTo(array1, array2, equalityComparer = equateValues) {
            if (!array1 || !array2) {
                return array1 === array2;
            }
            if (array1.length !== array2.length) {
                return false;
            }
            for (let i = 0; i < array1.length; i++) {
                if (!equalityComparer(array1[i], array2[i], i)) {
                    return false;
                }
            }
            return true;
        }
        function compact(array) {
            let result;
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const v = array[i];
                    if (result || !v) {
                        if (!result) {
                            result = array.slice(0, i);
                        }
                        if (v) {
                            result.push(v);
                        }
                    }
                }
            }
            return result || array;
        }
        function relativeComplement(arrayA, arrayB, comparer) {
            if (!arrayB || !arrayA || arrayB.length === 0 || arrayA.length === 0)
                return arrayB;
            const result = [];
            loopB: for (let offsetA = 0, offsetB = 0; offsetB < arrayB.length; offsetB++) {
                if (offsetB > 0) {
                    Debug.assertGreaterThanOrEqual(comparer(arrayB[offsetB], arrayB[offsetB - 1]), 0 /* EqualTo */);
                }
                loopA: for (const startA = offsetA; offsetA < arrayA.length; offsetA++) {
                    if (offsetA > startA) {
                        Debug.assertGreaterThanOrEqual(comparer(arrayA[offsetA], arrayA[offsetA - 1]), 0 /* EqualTo */);
                    }
                    switch (comparer(arrayB[offsetB], arrayA[offsetA])) {
                        case -1 /* LessThan */:
                            result.push(arrayB[offsetB]);
                            continue loopB;
                        case 0 /* EqualTo */:
                            continue loopB;
                        case 1 /* GreaterThan */:
                            continue loopA;
                    }
                }
            }
            return result;
        }
        function append(to, value) {
            if (value === void 0)
                return to;
            if (to === void 0)
                return [value];
            to.push(value);
            return to;
        }
        function combine(xs, ys) {
            if (xs === void 0)
                return ys;
            if (ys === void 0)
                return xs;
            if (isArray(xs))
                return isArray(ys) ? concatenate(xs, ys) : append(xs, ys);
            if (isArray(ys))
                return append(ys, xs);
            return [xs, ys];
        }
        function toOffset(array, offset) {
            return offset < 0 ? array.length + offset : offset;
        }
        function addRange(to, from, start, end) {
            if (from === void 0 || from.length === 0)
                return to;
            if (to === void 0)
                return from.slice(start, end);
            start = start === void 0 ? 0 : toOffset(from, start);
            end = end === void 0 ? from.length : toOffset(from, end);
            for (let i = start; i < end && i < from.length; i++) {
                if (from[i] !== void 0) {
                    to.push(from[i]);
                }
            }
            return to;
        }
        function pushIfUnique(array, toAdd, equalityComparer) {
            if (contains(array, toAdd, equalityComparer)) {
                return false;
            }
            else {
                array.push(toAdd);
                return true;
            }
        }
        function appendIfUnique(array, toAdd, equalityComparer) {
            if (array) {
                pushIfUnique(array, toAdd, equalityComparer);
                return array;
            }
            else {
                return [toAdd];
            }
        }
        function stableSortIndices(array, indices, comparer) {
            indices.sort((x, y) => comparer(array[x], array[y]) || compareValues(x, y));
        }
        function sort(array, comparer) {
            return array.length === 0 ? array : array.slice().sort(comparer);
        }
        function* arrayReverseIterator(array) {
            for (let i = array.length - 1; i >= 0; i--) {
                yield array[i];
            }
        }
        function stableSort(array, comparer) {
            const indices = indicesOf(array);
            stableSortIndices(array, indices, comparer);
            return indices.map((i) => array[i]);
        }
        function rangeEquals(array1, array2, pos, end) {
            while (pos < end) {
                if (array1[pos] !== array2[pos]) {
                    return false;
                }
                pos++;
            }
            return true;
        }
        function firstOrUndefined(array) {
            return array === void 0 || array.length === 0 ? void 0 : array[0];
        }
        function firstOrUndefinedIterator(iter) {
            if (iter) {
                for (const value of iter) {
                    return value;
                }
            }
            return void 0;
        }
        function first(array) {
            Debug.assert(array.length !== 0);
            return array[0];
        }
        function firstIterator(iter) {
            for (const value of iter) {
                return value;
            }
            Debug.fail("iterator is empty");
        }
        function lastOrUndefined(array) {
            return array === void 0 || array.length === 0 ? void 0 : array[array.length - 1];
        }
        function last(array) {
            Debug.assert(array.length !== 0);
            return array[array.length - 1];
        }
        function singleOrUndefined(array) {
            return array && array.length === 1 ? array[0] : void 0;
        }
        function single(array) {
            return Debug.checkDefined(singleOrUndefined(array));
        }
        function singleOrMany(array) {
            return array && array.length === 1 ? array[0] : array;
        }
        function replaceElement(array, index, value) {
            const result = array.slice(0);
            result[index] = value;
            return result;
        }
        function binarySearch(array, value, keySelector, keyComparer, offset) {
            return binarySearchKey(array, keySelector(value), keySelector, keyComparer, offset);
        }
        function binarySearchKey(array, key, keySelector, keyComparer, offset) {
            if (!some(array)) {
                return -1;
            }
            let low = offset || 0;
            let high = array.length - 1;
            while (low <= high) {
                const middle = low + (high - low >> 1);
                const midKey = keySelector(array[middle], middle);
                switch (keyComparer(midKey, key)) {
                    case -1 /* LessThan */:
                        low = middle + 1;
                        break;
                    case 0 /* EqualTo */:
                        return middle;
                    case 1 /* GreaterThan */:
                        high = middle - 1;
                        break;
                }
            }
            return ~low;
        }
        function reduceLeft(array, f, initial, start, count) {
            if (array && array.length > 0) {
                const size = array.length;
                if (size > 0) {
                    let pos = start === void 0 || start < 0 ? 0 : start;
                    const end = count === void 0 || pos + count > size - 1 ? size - 1 : pos + count;
                    let result;
                    if (arguments.length <= 2) {
                        result = array[pos];
                        pos++;
                    }
                    else {
                        result = initial;
                    }
                    while (pos <= end) {
                        result = f(result, array[pos], pos);
                        pos++;
                    }
                    return result;
                }
            }
            return initial;
        }
        function hasProperty(map2, key) {
            return hasOwnProperty.call(map2, key);
        }
        function getProperty(map2, key) {
            return hasOwnProperty.call(map2, key) ? map2[key] : void 0;
        }
        function getOwnKeys(map2) {
            const keys = [];
            for (const key in map2) {
                if (hasOwnProperty.call(map2, key)) {
                    keys.push(key);
                }
            }
            return keys;
        }
        function getAllKeys(obj) {
            const result = [];
            do {
                const names = Object.getOwnPropertyNames(obj);
                for (const name of names) {
                    pushIfUnique(result, name);
                }
            } while (obj = Object.getPrototypeOf(obj));
            return result;
        }
        function getOwnValues(collection) {
            const values = [];
            for (const key in collection) {
                if (hasOwnProperty.call(collection, key)) {
                    values.push(collection[key]);
                }
            }
            return values;
        }
        function arrayOf(count, f) {
            const result = new Array(count);
            for (let i = 0; i < count; i++) {
                result[i] = f(i);
            }
            return result;
        }
        function arrayFrom(iterator, map2) {
            const result = [];
            for (const value of iterator) {
                result.push(map2 ? map2(value) : value);
            }
            return result;
        }
        function assign(t, ...args) {
            for (const arg of args) {
                if (arg === void 0)
                    continue;
                for (const p in arg) {
                    if (hasProperty(arg, p)) {
                        t[p] = arg[p];
                    }
                }
            }
            return t;
        }
        function equalOwnProperties(left, right, equalityComparer = equateValues) {
            if (left === right)
                return true;
            if (!left || !right)
                return false;
            for (const key in left) {
                if (hasOwnProperty.call(left, key)) {
                    if (!hasOwnProperty.call(right, key))
                        return false;
                    if (!equalityComparer(left[key], right[key]))
                        return false;
                }
            }
            for (const key in right) {
                if (hasOwnProperty.call(right, key)) {
                    if (!hasOwnProperty.call(left, key))
                        return false;
                }
            }
            return true;
        }
        function arrayToMap(array, makeKey, makeValue = identity) {
            const result = /* @__PURE__ */ new Map();
            for (const value of array) {
                const key = makeKey(value);
                if (key !== void 0)
                    result.set(key, makeValue(value));
            }
            return result;
        }
        function arrayToNumericMap(array, makeKey, makeValue = identity) {
            const result = [];
            for (const value of array) {
                result[makeKey(value)] = makeValue(value);
            }
            return result;
        }
        function arrayToMultiMap(values, makeKey, makeValue = identity) {
            const result = createMultiMap();
            for (const value of values) {
                result.add(makeKey(value), makeValue(value));
            }
            return result;
        }
        function group(values, getGroupId, resultSelector = identity) {
            return arrayFrom(arrayToMultiMap(values, getGroupId).values(), resultSelector);
        }
        function groupBy(values, keySelector) {
            var _a2;
            const result = {};
            if (values) {
                for (const value of values) {
                    const key = `${keySelector(value)}`;
                    const array = (_a2 = result[key]) != null ? _a2 : result[key] = [];
                    array.push(value);
                }
            }
            return result;
        }
        function clone(object) {
            const result = {};
            for (const id in object) {
                if (hasOwnProperty.call(object, id)) {
                    result[id] = object[id];
                }
            }
            return result;
        }
        function extend(first2, second) {
            const result = {};
            for (const id in second) {
                if (hasOwnProperty.call(second, id)) {
                    result[id] = second[id];
                }
            }
            for (const id in first2) {
                if (hasOwnProperty.call(first2, id)) {
                    result[id] = first2[id];
                }
            }
            return result;
        }
        function copyProperties(first2, second) {
            for (const id in second) {
                if (hasOwnProperty.call(second, id)) {
                    first2[id] = second[id];
                }
            }
        }
        function maybeBind(obj, fn) {
            return fn ? fn.bind(obj) : void 0;
        }
        function createMultiMap() {
            const map2 = /* @__PURE__ */ new Map();
            map2.add = multiMapAdd;
            map2.remove = multiMapRemove;
            return map2;
        }
        function multiMapAdd(key, value) {
            let values = this.get(key);
            if (values) {
                values.push(value);
            }
            else {
                this.set(key, values = [value]);
            }
            return values;
        }
        function multiMapRemove(key, value) {
            const values = this.get(key);
            if (values) {
                unorderedRemoveItem(values, value);
                if (!values.length) {
                    this.delete(key);
                }
            }
        }
        function createUnderscoreEscapedMultiMap() {
            return createMultiMap();
        }
        function createQueue(items) {
            const elements = (items == null ? void 0 : items.slice()) || [];
            let headIndex = 0;
            function isEmpty() {
                return headIndex === elements.length;
            }
            function enqueue(...items2) {
                elements.push(...items2);
            }
            function dequeue() {
                if (isEmpty()) {
                    throw new Error("Queue is empty");
                }
                const result = elements[headIndex];
                elements[headIndex] = void 0;
                headIndex++;
                if (headIndex > 100 && headIndex > elements.length >> 1) {
                    const newLength = elements.length - headIndex;
                    elements.copyWithin(
                    /*target*/
                    0, 
                    /*start*/
                    headIndex);
                    elements.length = newLength;
                    headIndex = 0;
                }
                return result;
            }
            return {
                enqueue,
                dequeue,
                isEmpty
            };
        }
        function createSet(getHashCode, equals) {
            const multiMap = /* @__PURE__ */ new Map();
            let size = 0;
            function* getElementIterator() {
                for (const value of multiMap.values()) {
                    if (isArray(value)) {
                        yield* value;
                    }
                    else {
                        yield value;
                    }
                }
            }
            const set = {
                has(element) {
                    const hash = getHashCode(element);
                    if (!multiMap.has(hash))
                        return false;
                    const candidates = multiMap.get(hash);
                    if (!isArray(candidates))
                        return equals(candidates, element);
                    for (const candidate of candidates) {
                        if (equals(candidate, element)) {
                            return true;
                        }
                    }
                    return false;
                },
                add(element) {
                    const hash = getHashCode(element);
                    if (multiMap.has(hash)) {
                        const values = multiMap.get(hash);
                        if (isArray(values)) {
                            if (!contains(values, element, equals)) {
                                values.push(element);
                                size++;
                            }
                        }
                        else {
                            const value = values;
                            if (!equals(value, element)) {
                                multiMap.set(hash, [value, element]);
                                size++;
                            }
                        }
                    }
                    else {
                        multiMap.set(hash, element);
                        size++;
                    }
                    return this;
                },
                delete(element) {
                    const hash = getHashCode(element);
                    if (!multiMap.has(hash))
                        return false;
                    const candidates = multiMap.get(hash);
                    if (isArray(candidates)) {
                        for (let i = 0; i < candidates.length; i++) {
                            if (equals(candidates[i], element)) {
                                if (candidates.length === 1) {
                                    multiMap.delete(hash);
                                }
                                else if (candidates.length === 2) {
                                    multiMap.set(hash, candidates[1 - i]);
                                }
                                else {
                                    unorderedRemoveItemAt(candidates, i);
                                }
                                size--;
                                return true;
                            }
                        }
                    }
                    else {
                        const candidate = candidates;
                        if (equals(candidate, element)) {
                            multiMap.delete(hash);
                            size--;
                            return true;
                        }
                    }
                    return false;
                },
                clear() {
                    multiMap.clear();
                    size = 0;
                },
                get size() {
                    return size;
                },
                forEach(action) {
                    for (const elements of arrayFrom(multiMap.values())) {
                        if (isArray(elements)) {
                            for (const element of elements) {
                                action(element, element, set);
                            }
                        }
                        else {
                            const element = elements;
                            action(element, element, set);
                        }
                    }
                },
                keys() {
                    return getElementIterator();
                },
                values() {
                    return getElementIterator();
                },
                *entries() {
                    for (const value of getElementIterator()) {
                        yield [value, value];
                    }
                },
                [Symbol.iterator]: () => {
                    return getElementIterator();
                },
                [Symbol.toStringTag]: multiMap[Symbol.toStringTag]
            };
            return set;
        }
        function isArray(value) {
            return Array.isArray(value);
        }
        function toArray(value) {
            return isArray(value) ? value : [value];
        }
        function isString(text) {
            return typeof text === "string";
        }
        function isNumber(x) {
            return typeof x === "number";
        }
        function tryCast(value, test) {
            return value !== void 0 && test(value) ? value : void 0;
        }
        function cast(value, test) {
            if (value !== void 0 && test(value))
                return value;
            return Debug.fail(`Invalid cast. The supplied value ${value} did not pass the test '${Debug.getFunctionName(test)}'.`);
        }
        function noop(_) {
        }
        function returnFalse() {
            return false;
        }
        function returnTrue() {
            return true;
        }
        function returnUndefined() {
            return void 0;
        }
        function identity(x) {
            return x;
        }
        function toLowerCase(x) {
            return x.toLowerCase();
        }
        function toFileNameLowerCase(x) {
            return fileNameLowerCaseRegExp.test(x) ? x.replace(fileNameLowerCaseRegExp, toLowerCase) : x;
        }
        function notImplemented() {
            throw new Error("Not implemented");
        }
        function memoize(callback) {
            let value;
            return () => {
                if (callback) {
                    value = callback();
                    callback = void 0;
                }
                return value;
            };
        }
        function memoizeOne(callback) {
            const map2 = /* @__PURE__ */ new Map();
            return (arg) => {
                const key = `${typeof arg}:${arg}`;
                let value = map2.get(key);
                if (value === void 0 && !map2.has(key)) {
                    value = callback(arg);
                    map2.set(key, value);
                }
                return value;
            };
        }
        function memoizeWeak(callback) {
            const map2 = /* @__PURE__ */ new WeakMap();
            return (arg) => {
                let value = map2.get(arg);
                if (value === void 0 && !map2.has(arg)) {
                    value = callback(arg);
                    map2.set(arg, value);
                }
                return value;
            };
        }
        function memoizeCached(callback, cache) {
            return (...args) => {
                let value = cache.get(args);
                if (value === void 0 && !cache.has(args)) {
                    value = callback(...args);
                    cache.set(args, value);
                }
                return value;
            };
        }
        function compose(a, b, c, d, e) {
            if (!!e) {
                const args = [];
                for (let i = 0; i < arguments.length; i++) {
                    args[i] = arguments[i];
                }
                return (t) => reduceLeft(args, (u, f) => f(u), t);
            }
            else if (d) {
                return (t) => d(c(b(a(t))));
            }
            else if (c) {
                return (t) => c(b(a(t)));
            }
            else if (b) {
                return (t) => b(a(t));
            }
            else if (a) {
                return (t) => a(t);
            }
            else {
                return (t) => t;
            }
        }
        function equateValues(a, b) {
            return a === b;
        }
        function equateStringsCaseInsensitive(a, b) {
            return a === b || a !== void 0 && b !== void 0 && a.toUpperCase() === b.toUpperCase();
        }
        function equateStringsCaseSensitive(a, b) {
            return equateValues(a, b);
        }
        function compareComparableValues(a, b) {
            return a === b ? 0 /* EqualTo */ : a === void 0 ? -1 /* LessThan */ : b === void 0 ? 1 /* GreaterThan */ : a < b ? -1 /* LessThan */ : 1 /* GreaterThan */;
        }
        function compareValues(a, b) {
            return compareComparableValues(a, b);
        }
        function compareTextSpans(a, b) {
            return compareValues(a == null ? void 0 : a.start, b == null ? void 0 : b.start) || compareValues(a == null ? void 0 : a.length, b == null ? void 0 : b.length);
        }
        function min(items, compare) {
            return reduceLeft(items, (x, y) => compare(x, y) === -1 /* LessThan */ ? x : y);
        }
        function compareStringsCaseInsensitive(a, b) {
            if (a === b)
                return 0 /* EqualTo */;
            if (a === void 0)
                return -1 /* LessThan */;
            if (b === void 0)
                return 1 /* GreaterThan */;
            a = a.toUpperCase();
            b = b.toUpperCase();
            return a < b ? -1 /* LessThan */ : a > b ? 1 /* GreaterThan */ : 0 /* EqualTo */;
        }
        function compareStringsCaseInsensitiveEslintCompatible(a, b) {
            if (a === b)
                return 0 /* EqualTo */;
            if (a === void 0)
                return -1 /* LessThan */;
            if (b === void 0)
                return 1 /* GreaterThan */;
            a = a.toLowerCase();
            b = b.toLowerCase();
            return a < b ? -1 /* LessThan */ : a > b ? 1 /* GreaterThan */ : 0 /* EqualTo */;
        }
        function compareStringsCaseSensitive(a, b) {
            return compareComparableValues(a, b);
        }
        function getStringComparer(ignoreCase) {
            return ignoreCase ? compareStringsCaseInsensitive : compareStringsCaseSensitive;
        }
        function getUILocale() {
            return uiLocale;
        }
        function setUILocale(value) {
            if (uiLocale !== value) {
                uiLocale = value;
                uiComparerCaseSensitive = void 0;
            }
        }
        function compareStringsCaseSensitiveUI(a, b) {
            const comparer = uiComparerCaseSensitive || (uiComparerCaseSensitive = createUIStringComparer(uiLocale));
            return comparer(a, b);
        }
        function compareProperties(a, b, key, comparer) {
            return a === b ? 0 /* EqualTo */ : a === void 0 ? -1 /* LessThan */ : b === void 0 ? 1 /* GreaterThan */ : comparer(a[key], b[key]);
        }
        function compareBooleans(a, b) {
            return compareValues(a ? 1 : 0, b ? 1 : 0);
        }
        function getSpellingSuggestion(name, candidates, getName) {
            const maximumLengthDifference = Math.max(2, Math.floor(name.length * 0.34));
            let bestDistance = Math.floor(name.length * 0.4) + 1;
            let bestCandidate;
            for (const candidate of candidates) {
                const candidateName = getName(candidate);
                if (candidateName !== void 0 && Math.abs(candidateName.length - name.length) <= maximumLengthDifference) {
                    if (candidateName === name) {
                        continue;
                    }
                    if (candidateName.length < 3 && candidateName.toLowerCase() !== name.toLowerCase()) {
                        continue;
                    }
                    const distance = levenshteinWithMax(name, candidateName, bestDistance - 0.1);
                    if (distance === void 0) {
                        continue;
                    }
                    Debug.assert(distance < bestDistance);
                    bestDistance = distance;
                    bestCandidate = candidate;
                }
            }
            return bestCandidate;
        }
        function levenshteinWithMax(s1, s2, max) {
            let previous = new Array(s2.length + 1);
            let current = new Array(s2.length + 1);
            const big = max + 0.01;
            for (let i = 0; i <= s2.length; i++) {
                previous[i] = i;
            }
            for (let i = 1; i <= s1.length; i++) {
                const c1 = s1.charCodeAt(i - 1);
                const minJ = Math.ceil(i > max ? i - max : 1);
                const maxJ = Math.floor(s2.length > max + i ? max + i : s2.length);
                current[0] = i;
                let colMin = i;
                for (let j = 1; j < minJ; j++) {
                    current[j] = big;
                }
                for (let j = minJ; j <= maxJ; j++) {
                    const substitutionDistance = s1[i - 1].toLowerCase() === s2[j - 1].toLowerCase() ? previous[j - 1] + 0.1 : previous[j - 1] + 2;
                    const dist = c1 === s2.charCodeAt(j - 1) ? previous[j - 1] : Math.min(
                    /*delete*/
                    previous[j] + 1, 
                    /*insert*/
                    current[j - 1] + 1, 
                    /*substitute*/
                    substitutionDistance);
                    current[j] = dist;
                    colMin = Math.min(colMin, dist);
                }
                for (let j = maxJ + 1; j <= s2.length; j++) {
                    current[j] = big;
                }
                if (colMin > max) {
                    return void 0;
                }
                const temp = previous;
                previous = current;
                current = temp;
            }
            const res = previous[s2.length];
            return res > max ? void 0 : res;
        }
        function endsWith(str, suffix) {
            const expectedPos = str.length - suffix.length;
            return expectedPos >= 0 && str.indexOf(suffix, expectedPos) === expectedPos;
        }
        function removeSuffix(str, suffix) {
            return endsWith(str, suffix) ? str.slice(0, str.length - suffix.length) : str;
        }
        function tryRemoveSuffix(str, suffix) {
            return endsWith(str, suffix) ? str.slice(0, str.length - suffix.length) : void 0;
        }
        function stringContains(str, substring) {
            return str.indexOf(substring) !== -1;
        }
        function removeMinAndVersionNumbers(fileName) {
            let end = fileName.length;
            for (let pos = end - 1; pos > 0; pos--) {
                let ch = fileName.charCodeAt(pos);
                if (ch >= 48 /* _0 */ && ch <= 57 /* _9 */) {
                    do {
                        --pos;
                        ch = fileName.charCodeAt(pos);
                    } while (pos > 0 && ch >= 48 /* _0 */ && ch <= 57 /* _9 */);
                }
                else if (pos > 4 && (ch === 110 /* n */ || ch === 78 /* N */)) {
                    --pos;
                    ch = fileName.charCodeAt(pos);
                    if (ch !== 105 /* i */ && ch !== 73 /* I */) {
                        break;
                    }
                    --pos;
                    ch = fileName.charCodeAt(pos);
                    if (ch !== 109 /* m */ && ch !== 77 /* M */) {
                        break;
                    }
                    --pos;
                    ch = fileName.charCodeAt(pos);
                }
                else {
                    break;
                }
                if (ch !== 45 /* minus */ && ch !== 46 /* dot */) {
                    break;
                }
                end = pos;
            }
            return end === fileName.length ? fileName : fileName.slice(0, end);
        }
        function orderedRemoveItem(array, item) {
            for (let i = 0; i < array.length; i++) {
                if (array[i] === item) {
                    orderedRemoveItemAt(array, i);
                    return true;
                }
            }
            return false;
        }
        function orderedRemoveItemAt(array, index) {
            for (let i = index; i < array.length - 1; i++) {
                array[i] = array[i + 1];
            }
            array.pop();
        }
        function unorderedRemoveItemAt(array, index) {
            array[index] = array[array.length - 1];
            array.pop();
        }
        function unorderedRemoveItem(array, item) {
            return unorderedRemoveFirstItemWhere(array, (element) => element === item);
        }
        function unorderedRemoveFirstItemWhere(array, predicate) {
            for (let i = 0; i < array.length; i++) {
                if (predicate(array[i])) {
                    unorderedRemoveItemAt(array, i);
                    return true;
                }
            }
            return false;
        }
        function createGetCanonicalFileName(useCaseSensitiveFileNames) {
            return useCaseSensitiveFileNames ? identity : toFileNameLowerCase;
        }
        function patternText({ prefix, suffix }) {
            return `${prefix}*${suffix}`;
        }
        function matchedText(pattern, candidate) {
            Debug.assert(isPatternMatch(pattern, candidate));
            return candidate.substring(pattern.prefix.length, candidate.length - pattern.suffix.length);
        }
        function findBestPatternMatch(values, getPattern, candidate) {
            let matchedValue;
            let longestMatchPrefixLength = -1;
            for (const v of values) {
                const pattern = getPattern(v);
                if (isPatternMatch(pattern, candidate) && pattern.prefix.length > longestMatchPrefixLength) {
                    longestMatchPrefixLength = pattern.prefix.length;
                    matchedValue = v;
                }
            }
            return matchedValue;
        }
        function startsWith(str, prefix) {
            return str.lastIndexOf(prefix, 0) === 0;
        }
        function removePrefix(str, prefix) {
            return startsWith(str, prefix) ? str.substr(prefix.length) : str;
        }
        function tryRemovePrefix(str, prefix, getCanonicalFileName = identity) {
            return startsWith(getCanonicalFileName(str), getCanonicalFileName(prefix)) ? str.substring(prefix.length) : void 0;
        }
        function isPatternMatch({ prefix, suffix }, candidate) {
            return candidate.length >= prefix.length + suffix.length && startsWith(candidate, prefix) && endsWith(candidate, suffix);
        }
        function and(f, g) {
            return (arg) => f(arg) && g(arg);
        }
        function or(...fs) {
            return (...args) => {
                let lastResult;
                for (const f of fs) {
                    lastResult = f(...args);
                    if (lastResult) {
                        return lastResult;
                    }
                }
                return lastResult;
            };
        }
        function not(fn) {
            return (...args) => !fn(...args);
        }
        function assertType(_) {
        }
        function singleElementArray(t) {
            return t === void 0 ? void 0 : [t];
        }
        function enumerateInsertsAndDeletes(newItems, oldItems, comparer, inserted, deleted, unchanged) {
            unchanged = unchanged || noop;
            let newIndex = 0;
            let oldIndex = 0;
            const newLen = newItems.length;
            const oldLen = oldItems.length;
            let hasChanges = false;
            while (newIndex < newLen && oldIndex < oldLen) {
                const newItem = newItems[newIndex];
                const oldItem = oldItems[oldIndex];
                const compareResult = comparer(newItem, oldItem);
                if (compareResult === -1 /* LessThan */) {
                    inserted(newItem);
                    newIndex++;
                    hasChanges = true;
                }
                else if (compareResult === 1 /* GreaterThan */) {
                    deleted(oldItem);
                    oldIndex++;
                    hasChanges = true;
                }
                else {
                    unchanged(oldItem, newItem);
                    newIndex++;
                    oldIndex++;
                }
            }
            while (newIndex < newLen) {
                inserted(newItems[newIndex++]);
                hasChanges = true;
            }
            while (oldIndex < oldLen) {
                deleted(oldItems[oldIndex++]);
                hasChanges = true;
            }
            return hasChanges;
        }
        function cartesianProduct(arrays) {
            const result = [];
            cartesianProductWorker(arrays, result, 
            /*outer*/
            void 0, 0);
            return result;
        }
        function cartesianProductWorker(arrays, result, outer, index) {
            for (const element of arrays[index]) {
                let inner;
                if (outer) {
                    inner = outer.slice();
                    inner.push(element);
                }
                else {
                    inner = [element];
                }
                if (index === arrays.length - 1) {
                    result.push(inner);
                }
                else {
                    cartesianProductWorker(arrays, result, inner, index + 1);
                }
            }
        }
        function padLeft(s, length2, padString = " ") {
            return length2 <= s.length ? s : padString.repeat(length2 - s.length) + s;
        }
        function padRight(s, length2, padString = " ") {
            return length2 <= s.length ? s : s + padString.repeat(length2 - s.length);
        }
        function takeWhile(array, predicate) {
            if (array) {
                const len = array.length;
                let index = 0;
                while (index < len && predicate(array[index])) {
                    index++;
                }
                return array.slice(0, index);
            }
        }
        function skipWhile(array, predicate) {
            if (array) {
                const len = array.length;
                let index = 0;
                while (index < len && predicate(array[index])) {
                    index++;
                }
                return array.slice(index);
            }
        }
        function trimEndImpl(s) {
            let end = s.length - 1;
            while (end >= 0) {
                if (!isWhiteSpaceLike(s.charCodeAt(end)))
                    break;
                end--;
            }
            return s.slice(0, end + 1);
        }
        function isNodeLikeSystem() {
            return typeof process !== "undefined" && process.nextTick && !process.browser && typeof module === "object";
        }
        var emptyArray, emptyMap, emptySet, SortKind, elementAt, hasOwnProperty, noopPush, fileNameLowerCaseRegExp, AssertionLevel, createUIStringComparer, uiComparerCaseSensitive, uiLocale, trimString, trimStringEnd, trimStringStart;
        var init_core = __esm({
            "src/compiler/core.ts"() {
                "use strict";
                init_ts2();
                emptyArray = [];
                emptyMap = /* @__PURE__ */ new Map();
                emptySet = /* @__PURE__ */ new Set();
                SortKind = /* @__PURE__ */ ((SortKind2) => {
                    SortKind2[SortKind2["None"] = 0] = "None";
                    SortKind2[SortKind2["CaseSensitive"] = 1] = "CaseSensitive";
                    SortKind2[SortKind2["CaseInsensitive"] = 2] = "CaseInsensitive";
                    SortKind2[SortKind2["Both"] = 3] = "Both";
                    return SortKind2;
                })(SortKind || {});
                elementAt = !!Array.prototype.at ? (array, offset) => array == null ? void 0 : array.at(offset) : (array, offset) => {
                    if (array) {
                        offset = toOffset(array, offset);
                        if (offset < array.length) {
                            return array[offset];
                        }
                    }
                    return void 0;
                };
                hasOwnProperty = Object.prototype.hasOwnProperty;
                noopPush = {
                    push: noop,
                    length: 0
                };
                fileNameLowerCaseRegExp = /[^\u0130\u0131\u00DFa-z0-9\\/:\-_\. ]+/g;
                AssertionLevel = /* @__PURE__ */ ((AssertionLevel2) => {
                    AssertionLevel2[AssertionLevel2["None"] = 0] = "None";
                    AssertionLevel2[AssertionLevel2["Normal"] = 1] = "Normal";
                    AssertionLevel2[AssertionLevel2["Aggressive"] = 2] = "Aggressive";
                    AssertionLevel2[AssertionLevel2["VeryAggressive"] = 3] = "VeryAggressive";
                    return AssertionLevel2;
                })(AssertionLevel || {});
                createUIStringComparer = (() => {
                    let defaultComparer;
                    let enUSComparer;
                    const stringComparerFactory = getStringComparerFactory();
                    return createStringComparer;
                    function compareWithCallback(a, b, comparer) {
                        if (a === b)
                            return 0 /* EqualTo */;
                        if (a === void 0)
                            return -1 /* LessThan */;
                        if (b === void 0)
                            return 1 /* GreaterThan */;
                        const value = comparer(a, b);
                        return value < 0 ? -1 /* LessThan */ : value > 0 ? 1 /* GreaterThan */ : 0 /* EqualTo */;
                    }
                    function createIntlCollatorStringComparer(locale) {
                        const comparer = new Intl.Collator(locale, { usage: "sort", sensitivity: "variant" }).compare;
                        return (a, b) => compareWithCallback(a, b, comparer);
                    }
                    function createLocaleCompareStringComparer(locale) {
                        if (locale !== void 0)
                            return createFallbackStringComparer();
                        return (a, b) => compareWithCallback(a, b, compareStrings);
                        function compareStrings(a, b) {
                            return a.localeCompare(b);
                        }
                    }
                    function createFallbackStringComparer() {
                        return (a, b) => compareWithCallback(a, b, compareDictionaryOrder);
                        function compareDictionaryOrder(a, b) {
                            return compareStrings(a.toUpperCase(), b.toUpperCase()) || compareStrings(a, b);
                        }
                        function compareStrings(a, b) {
                            return a < b ? -1 /* LessThan */ : a > b ? 1 /* GreaterThan */ : 0 /* EqualTo */;
                        }
                    }
                    function getStringComparerFactory() {
                        if (typeof Intl === "object" && typeof Intl.Collator === "function") {
                            return createIntlCollatorStringComparer;
                        }
                        if (typeof String.prototype.localeCompare === "function" && typeof String.prototype.toLocaleUpperCase === "function" && "a".localeCompare("B") < 0) {
                            return createLocaleCompareStringComparer;
                        }
                        return createFallbackStringComparer;
                    }
                    function createStringComparer(locale) {
                        if (locale === void 0) {
                            return defaultComparer || (defaultComparer = stringComparerFactory(locale));
                        }
                        else if (locale === "en-US") {
                            return enUSComparer || (enUSComparer = stringComparerFactory(locale));
                        }
                        else {
                            return stringComparerFactory(locale);
                        }
                    }
                })();
                trimString = !!String.prototype.trim ? (s) => s.trim() : (s) => trimStringEnd(trimStringStart(s));
                trimStringEnd = !!String.prototype.trimEnd ? (s) => s.trimEnd() : trimEndImpl;
                trimStringStart = !!String.prototype.trimStart ? (s) => s.trimStart() : (s) => s.replace(/^\s+/g, "");
            }
        });
        // src/compiler/debug.ts
        var LogLevel, Debug;
        var init_debug = __esm({
            "src/compiler/debug.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
                LogLevel = /* @__PURE__ */ ((LogLevel2) => {
                    LogLevel2[LogLevel2["Off"] = 0] = "Off";
                    LogLevel2[LogLevel2["Error"] = 1] = "Error";
                    LogLevel2[LogLevel2["Warning"] = 2] = "Warning";
                    LogLevel2[LogLevel2["Info"] = 3] = "Info";
                    LogLevel2[LogLevel2["Verbose"] = 4] = "Verbose";
                    return LogLevel2;
                })(LogLevel || {});
                ((Debug2) => {
                    let currentAssertionLevel = 0 /* None */;
                    Debug2.currentLogLevel = 2 /* Warning */;
                    Debug2.isDebugging = false;
                    function shouldLog(level) {
                        return Debug2.currentLogLevel <= level;
                    }
                    Debug2.shouldLog = shouldLog;
                    function logMessage(level, s) {
                        if (Debug2.loggingHost && shouldLog(level)) {
                            Debug2.loggingHost.log(level, s);
                        }
                    }
                    function log(s) {
                        logMessage(3 /* Info */, s);
                    }
                    Debug2.log = log;
                    ((_log) => {
                        function error(s) {
                            logMessage(1 /* Error */, s);
                        }
                        _log.error = error;
                        function warn(s) {
                            logMessage(2 /* Warning */, s);
                        }
                        _log.warn = warn;
                        function log2(s) {
                            logMessage(3 /* Info */, s);
                        }
                        _log.log = log2;
                        function trace2(s) {
                            logMessage(4 /* Verbose */, s);
                        }
                        _log.trace = trace2;
                    })(log = Debug2.log || (Debug2.log = {}));
                    const assertionCache = {};
                    function getAssertionLevel() {
                        return currentAssertionLevel;
                    }
                    Debug2.getAssertionLevel = getAssertionLevel;
                    function setAssertionLevel(level) {
                        const prevAssertionLevel = currentAssertionLevel;
                        currentAssertionLevel = level;
                        if (level > prevAssertionLevel) {
                            for (const key of getOwnKeys(assertionCache)) {
                                const cachedFunc = assertionCache[key];
                                if (cachedFunc !== void 0 && Debug2[key] !== cachedFunc.assertion && level >= cachedFunc.level) {
                                    Debug2[key] = cachedFunc;
                                    assertionCache[key] = void 0;
                                }
                            }
                        }
                    }
                    Debug2.setAssertionLevel = setAssertionLevel;
                    function shouldAssert(level) {
                        return currentAssertionLevel >= level;
                    }
                    Debug2.shouldAssert = shouldAssert;
                    function shouldAssertFunction(level, name) {
                        if (!shouldAssert(level)) {
                            assertionCache[name] = { level, assertion: Debug2[name] };
                            Debug2[name] = noop;
                            return false;
                        }
                        return true;
                    }
                    function fail(message, stackCrawlMark) {
                        debugger;
                        const e = new Error(message ? `Debug Failure. ${message}` : "Debug Failure.");
                        if (Error.captureStackTrace) {
                            Error.captureStackTrace(e, stackCrawlMark || fail);
                        }
                        throw e;
                    }
                    Debug2.fail = fail;
                    function failBadSyntaxKind(node, message, stackCrawlMark) {
                        return fail(`${message || "Unexpected node."}\r
Node ${formatSyntaxKind(node.kind)} was unexpected.`, stackCrawlMark || failBadSyntaxKind);
                    }
                    Debug2.failBadSyntaxKind = failBadSyntaxKind;
                    function assert(expression, message, verboseDebugInfo, stackCrawlMark) {
                        if (!expression) {
                            message = message ? `False expression: ${message}` : "False expression.";
                            if (verboseDebugInfo) {
                                message += "\r\nVerbose Debug Information: " + (typeof verboseDebugInfo === "string" ? verboseDebugInfo : verboseDebugInfo());
                            }
                            fail(message, stackCrawlMark || assert);
                        }
                    }
                    Debug2.assert = assert;
                    function assertEqual(a, b, msg, msg2, stackCrawlMark) {
                        if (a !== b) {
                            const message = msg ? msg2 ? `${msg} ${msg2}` : msg : "";
                            fail(`Expected ${a} === ${b}. ${message}`, stackCrawlMark || assertEqual);
                        }
                    }
                    Debug2.assertEqual = assertEqual;
                    function assertLessThan(a, b, msg, stackCrawlMark) {
                        if (a >= b) {
                            fail(`Expected ${a} < ${b}. ${msg || ""}`, stackCrawlMark || assertLessThan);
                        }
                    }
                    Debug2.assertLessThan = assertLessThan;
                    function assertLessThanOrEqual(a, b, stackCrawlMark) {
                        if (a > b) {
                            fail(`Expected ${a} <= ${b}`, stackCrawlMark || assertLessThanOrEqual);
                        }
                    }
                    Debug2.assertLessThanOrEqual = assertLessThanOrEqual;
                    function assertGreaterThanOrEqual(a, b, stackCrawlMark) {
                        if (a < b) {
                            fail(`Expected ${a} >= ${b}`, stackCrawlMark || assertGreaterThanOrEqual);
                        }
                    }
                    Debug2.assertGreaterThanOrEqual = assertGreaterThanOrEqual;
                    function assertIsDefined(value, message, stackCrawlMark) {
                        if (value === void 0 || value === null) {
                            fail(message, stackCrawlMark || assertIsDefined);
                        }
                    }
                    Debug2.assertIsDefined = assertIsDefined;
                    function checkDefined(value, message, stackCrawlMark) {
                        assertIsDefined(value, message, stackCrawlMark || checkDefined);
                        return value;
                    }
                    Debug2.checkDefined = checkDefined;
                    function assertEachIsDefined(value, message, stackCrawlMark) {
                        for (const v of value) {
                            assertIsDefined(v, message, stackCrawlMark || assertEachIsDefined);
                        }
                    }
                    Debug2.assertEachIsDefined = assertEachIsDefined;
                    function checkEachDefined(value, message, stackCrawlMark) {
                        assertEachIsDefined(value, message, stackCrawlMark || checkEachDefined);
                        return value;
                    }
                    Debug2.checkEachDefined = checkEachDefined;
                    function assertNever(member, message = "Illegal value:", stackCrawlMark) {
                        const detail = typeof member === "object" && hasProperty(member, "kind") && hasProperty(member, "pos") ? "SyntaxKind: " + formatSyntaxKind(member.kind) : JSON.stringify(member);
                        return fail(`${message} ${detail}`, stackCrawlMark || assertNever);
                    }
                    Debug2.assertNever = assertNever;
                    function assertEachNode(nodes, test, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertEachNode")) {
                            assert(test === void 0 || every(nodes, test), message || "Unexpected node.", () => `Node array did not pass test '${getFunctionName(test)}'.`, stackCrawlMark || assertEachNode);
                        }
                    }
                    Debug2.assertEachNode = assertEachNode;
                    function assertNode(node, test, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertNode")) {
                            assert(node !== void 0 && (test === void 0 || test(node)), message || "Unexpected node.", () => `Node ${formatSyntaxKind(node == null ? void 0 : node.kind)} did not pass test '${getFunctionName(test)}'.`, stackCrawlMark || assertNode);
                        }
                    }
                    Debug2.assertNode = assertNode;
                    function assertNotNode(node, test, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertNotNode")) {
                            assert(node === void 0 || test === void 0 || !test(node), message || "Unexpected node.", () => `Node ${formatSyntaxKind(node.kind)} should not have passed test '${getFunctionName(test)}'.`, stackCrawlMark || assertNotNode);
                        }
                    }
                    Debug2.assertNotNode = assertNotNode;
                    function assertOptionalNode(node, test, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertOptionalNode")) {
                            assert(test === void 0 || node === void 0 || test(node), message || "Unexpected node.", () => `Node ${formatSyntaxKind(node == null ? void 0 : node.kind)} did not pass test '${getFunctionName(test)}'.`, stackCrawlMark || assertOptionalNode);
                        }
                    }
                    Debug2.assertOptionalNode = assertOptionalNode;
                    function assertOptionalToken(node, kind, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertOptionalToken")) {
                            assert(kind === void 0 || node === void 0 || node.kind === kind, message || "Unexpected node.", () => `Node ${formatSyntaxKind(node == null ? void 0 : node.kind)} was not a '${formatSyntaxKind(kind)}' token.`, stackCrawlMark || assertOptionalToken);
                        }
                    }
                    Debug2.assertOptionalToken = assertOptionalToken;
                    function assertMissingNode(node, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertMissingNode")) {
                            assert(node === void 0, message || "Unexpected node.", () => `Node ${formatSyntaxKind(node.kind)} was unexpected'.`, stackCrawlMark || assertMissingNode);
                        }
                    }
                    Debug2.assertMissingNode = assertMissingNode;
                    function type(_value) {
                    }
                    Debug2.type = type;
                    function getFunctionName(func) {
                        if (typeof func !== "function") {
                            return "";
                        }
                        else if (hasProperty(func, "name")) {
                            return func.name;
                        }
                        else {
                            const text = Function.prototype.toString.call(func);
                            const match = /^function\s+([\w\$]+)\s*\(/.exec(text);
                            return match ? match[1] : "";
                        }
                    }
                    Debug2.getFunctionName = getFunctionName;
                    function formatSymbol(symbol) {
                        return `{ name: ${unescapeLeadingUnderscores(symbol.escapedName)}; flags: ${formatSymbolFlags(symbol.flags)}; declarations: ${map(symbol.declarations, (node) => formatSyntaxKind(node.kind))} }`;
                    }
                    Debug2.formatSymbol = formatSymbol;
                    function formatEnum(value = 0, enumObject, isFlags) {
                        const members = getEnumMembers(enumObject);
                        if (value === 0) {
                            return members.length > 0 && members[0][0] === 0 ? members[0][1] : "0";
                        }
                        if (isFlags) {
                            const result = [];
                            let remainingFlags = value;
                            for (const [enumValue, enumName] of members) {
                                if (enumValue > value) {
                                    break;
                                }
                                if (enumValue !== 0 && enumValue & value) {
                                    result.push(enumName);
                                    remainingFlags &= ~enumValue;
                                }
                            }
                            if (remainingFlags === 0) {
                                return result.join("|");
                            }
                        }
                        else {
                            for (const [enumValue, enumName] of members) {
                                if (enumValue === value) {
                                    return enumName;
                                }
                            }
                        }
                        return value.toString();
                    }
                    Debug2.formatEnum = formatEnum;
                    const enumMemberCache = /* @__PURE__ */ new Map();
                    function getEnumMembers(enumObject) {
                        const existing = enumMemberCache.get(enumObject);
                        if (existing) {
                            return existing;
                        }
                        const result = [];
                        for (const name in enumObject) {
                            const value = enumObject[name];
                            if (typeof value === "number") {
                                result.push([value, name]);
                            }
                        }
                        const sorted = stableSort(result, (x, y) => compareValues(x[0], y[0]));
                        enumMemberCache.set(enumObject, sorted);
                        return sorted;
                    }
                    function formatSyntaxKind(kind) {
                        return formatEnum(kind, SyntaxKind, 
                        /*isFlags*/
                        false);
                    }
                    Debug2.formatSyntaxKind = formatSyntaxKind;
                    function formatSnippetKind(kind) {
                        return formatEnum(kind, SnippetKind, 
                        /*isFlags*/
                        false);
                    }
                    Debug2.formatSnippetKind = formatSnippetKind;
                    function formatNodeFlags(flags) {
                        return formatEnum(flags, NodeFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatNodeFlags = formatNodeFlags;
                    function formatModifierFlags(flags) {
                        return formatEnum(flags, ModifierFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatModifierFlags = formatModifierFlags;
                    function formatTransformFlags(flags) {
                        return formatEnum(flags, TransformFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatTransformFlags = formatTransformFlags;
                    function formatEmitFlags(flags) {
                        return formatEnum(flags, EmitFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatEmitFlags = formatEmitFlags;
                    function formatSymbolFlags(flags) {
                        return formatEnum(flags, SymbolFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatSymbolFlags = formatSymbolFlags;
                    function formatTypeFlags(flags) {
                        return formatEnum(flags, TypeFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatTypeFlags = formatTypeFlags;
                    function formatSignatureFlags(flags) {
                        return formatEnum(flags, SignatureFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatSignatureFlags = formatSignatureFlags;
                    function formatObjectFlags(flags) {
                        return formatEnum(flags, ObjectFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatObjectFlags = formatObjectFlags;
                    function formatFlowFlags(flags) {
                        return formatEnum(flags, FlowFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatFlowFlags = formatFlowFlags;
                    function formatRelationComparisonResult(result) {
                        return formatEnum(result, RelationComparisonResult, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatRelationComparisonResult = formatRelationComparisonResult;
                    function formatCheckMode(mode) {
                        return formatEnum(mode, CheckMode, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatCheckMode = formatCheckMode;
                    function formatSignatureCheckMode(mode) {
                        return formatEnum(mode, SignatureCheckMode, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatSignatureCheckMode = formatSignatureCheckMode;
                    function formatTypeFacts(facts) {
                        return formatEnum(facts, TypeFacts, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatTypeFacts = formatTypeFacts;
                    let isDebugInfoEnabled = false;
                    let flowNodeProto;
                    function attachFlowNodeDebugInfoWorker(flowNode) {
                        if (!("__debugFlowFlags" in flowNode)) {
                            Object.defineProperties(flowNode, {
                                // for use with vscode-js-debug's new customDescriptionGenerator in launch.json
                                __tsDebuggerDisplay: {
                                    value() {
                                        const flowHeader = this.flags & 2 /* Start */ ? "FlowStart" : this.flags & 4 /* BranchLabel */ ? "FlowBranchLabel" : this.flags & 8 /* LoopLabel */ ? "FlowLoopLabel" : this.flags & 16 /* Assignment */ ? "FlowAssignment" : this.flags & 32 /* TrueCondition */ ? "FlowTrueCondition" : this.flags & 64 /* FalseCondition */ ? "FlowFalseCondition" : this.flags & 128 /* SwitchClause */ ? "FlowSwitchClause" : this.flags & 256 /* ArrayMutation */ ? "FlowArrayMutation" : this.flags & 512 /* Call */ ? "FlowCall" : this.flags & 1024 /* ReduceLabel */ ? "FlowReduceLabel" : this.flags & 1 /* Unreachable */ ? "FlowUnreachable" : "UnknownFlow";
                                        const remainingFlags = this.flags & ~(2048 /* Referenced */ - 1);
                                        return `${flowHeader}${remainingFlags ? ` (${formatFlowFlags(remainingFlags)})` : ""}`;
                                    }
                                },
                                __debugFlowFlags: { get() {
                                        return formatEnum(this.flags, FlowFlags, 
                                        /*isFlags*/
                                        true);
                                    } },
                                __debugToString: { value() {
                                        return formatControlFlowGraph(this);
                                    } }
                            });
                        }
                    }
                    function attachFlowNodeDebugInfo(flowNode) {
                        if (isDebugInfoEnabled) {
                            if (typeof Object.setPrototypeOf === "function") {
                                if (!flowNodeProto) {
                                    flowNodeProto = Object.create(Object.prototype);
                                    attachFlowNodeDebugInfoWorker(flowNodeProto);
                                }
                                Object.setPrototypeOf(flowNode, flowNodeProto);
                            }
                            else {
                                attachFlowNodeDebugInfoWorker(flowNode);
                            }
                        }
                    }
                    Debug2.attachFlowNodeDebugInfo = attachFlowNodeDebugInfo;
                    let nodeArrayProto;
                    function attachNodeArrayDebugInfoWorker(array) {
                        if (!("__tsDebuggerDisplay" in array)) {
                            Object.defineProperties(array, {
                                __tsDebuggerDisplay: {
                                    value(defaultValue) {
                                        defaultValue = String(defaultValue).replace(/(?:,[\s\w\d_]+:[^,]+)+\]$/, "]");
                                        return `NodeArray ${defaultValue}`;
                                    }
                                }
                            });
                        }
                    }
                    function attachNodeArrayDebugInfo(array) {
                        if (isDebugInfoEnabled) {
                            if (typeof Object.setPrototypeOf === "function") {
                                if (!nodeArrayProto) {
                                    nodeArrayProto = Object.create(Array.prototype);
                                    attachNodeArrayDebugInfoWorker(nodeArrayProto);
                                }
                                Object.setPrototypeOf(array, nodeArrayProto);
                            }
                            else {
                                attachNodeArrayDebugInfoWorker(array);
                            }
                        }
                    }
                    Debug2.attachNodeArrayDebugInfo = attachNodeArrayDebugInfo;
                    function enableDebugInfo() {
                        if (isDebugInfoEnabled)
                            return;
                        const weakTypeTextMap = /* @__PURE__ */ new WeakMap();
                        const weakNodeTextMap = /* @__PURE__ */ new WeakMap();
                        Object.defineProperties(objectAllocator.getSymbolConstructor().prototype, {
                            // for use with vscode-js-debug's new customDescriptionGenerator in launch.json
                            __tsDebuggerDisplay: {
                                value() {
                                    const symbolHeader = this.flags & 33554432 /* Transient */ ? "TransientSymbol" : "Symbol";
                                    const remainingSymbolFlags = this.flags & ~33554432 /* Transient */;
                                    return `${symbolHeader} '${symbolName(this)}'${remainingSymbolFlags ? ` (${formatSymbolFlags(remainingSymbolFlags)})` : ""}`;
                                }
                            },
                            __debugFlags: { get() {
                                    return formatSymbolFlags(this.flags);
                                } }
                        });
                        Object.defineProperties(objectAllocator.getTypeConstructor().prototype, {
                            // for use with vscode-js-debug's new customDescriptionGenerator in launch.json
                            __tsDebuggerDisplay: {
                                value() {
                                    const typeHeader = this.flags & 98304 /* Nullable */ ? "NullableType" : this.flags & 384 /* StringOrNumberLiteral */ ? `LiteralType ${JSON.stringify(this.value)}` : this.flags & 2048 /* BigIntLiteral */ ? `LiteralType ${this.value.negative ? "-" : ""}${this.value.base10Value}n` : this.flags & 8192 /* UniqueESSymbol */ ? "UniqueESSymbolType" : this.flags & 32 /* Enum */ ? "EnumType" : this.flags & 67359327 /* Intrinsic */ ? `IntrinsicType ${this.intrinsicName}` : this.flags & 1048576 /* Union */ ? "UnionType" : this.flags & 2097152 /* Intersection */ ? "IntersectionType" : this.flags & 4194304 /* Index */ ? "IndexType" : this.flags & 8388608 /* IndexedAccess */ ? "IndexedAccessType" : this.flags & 16777216 /* Conditional */ ? "ConditionalType" : this.flags & 33554432 /* Substitution */ ? "SubstitutionType" : this.flags & 262144 /* TypeParameter */ ? "TypeParameter" : this.flags & 524288 /* Object */ ? this.objectFlags & 3 /* ClassOrInterface */ ? "InterfaceType" : this.objectFlags & 4 /* Reference */ ? "TypeReference" : this.objectFlags & 8 /* Tuple */ ? "TupleType" : this.objectFlags & 16 /* Anonymous */ ? "AnonymousType" : this.objectFlags & 32 /* Mapped */ ? "MappedType" : this.objectFlags & 1024 /* ReverseMapped */ ? "ReverseMappedType" : this.objectFlags & 256 /* EvolvingArray */ ? "EvolvingArrayType" : "ObjectType" : "Type";
                                    const remainingObjectFlags = this.flags & 524288 /* Object */ ? this.objectFlags & ~1343 /* ObjectTypeKindMask */ : 0;
                                    return `${typeHeader}${this.symbol ? ` '${symbolName(this.symbol)}'` : ""}${remainingObjectFlags ? ` (${formatObjectFlags(remainingObjectFlags)})` : ""}`;
                                }
                            },
                            __debugFlags: { get() {
                                    return formatTypeFlags(this.flags);
                                } },
                            __debugObjectFlags: { get() {
                                    return this.flags & 524288 /* Object */ ? formatObjectFlags(this.objectFlags) : "";
                                } },
                            __debugTypeToString: {
                                value() {
                                    let text = weakTypeTextMap.get(this);
                                    if (text === void 0) {
                                        text = this.checker.typeToString(this);
                                        weakTypeTextMap.set(this, text);
                                    }
                                    return text;
                                }
                            }
                        });
                        Object.defineProperties(objectAllocator.getSignatureConstructor().prototype, {
                            __debugFlags: { get() {
                                    return formatSignatureFlags(this.flags);
                                } },
                            __debugSignatureToString: { value() {
                                    var _a2;
                                    return (_a2 = this.checker) == null ? void 0 : _a2.signatureToString(this);
                                } }
                        });
                        const nodeConstructors = [
                            objectAllocator.getNodeConstructor(),
                            objectAllocator.getIdentifierConstructor(),
                            objectAllocator.getTokenConstructor(),
                            objectAllocator.getSourceFileConstructor()
                        ];
                        for (const ctor of nodeConstructors) {
                            if (!hasProperty(ctor.prototype, "__debugKind")) {
                                Object.defineProperties(ctor.prototype, {
                                    // for use with vscode-js-debug's new customDescriptionGenerator in launch.json
                                    __tsDebuggerDisplay: {
                                        value() {
                                            const nodeHeader = isGeneratedIdentifier(this) ? "GeneratedIdentifier" : isIdentifier(this) ? `Identifier '${idText(this)}'` : isPrivateIdentifier(this) ? `PrivateIdentifier '${idText(this)}'` : isStringLiteral(this) ? `StringLiteral ${JSON.stringify(this.text.length < 10 ? this.text : this.text.slice(10) + "...")}` : isNumericLiteral(this) ? `NumericLiteral ${this.text}` : isBigIntLiteral(this) ? `BigIntLiteral ${this.text}n` : isTypeParameterDeclaration(this) ? "TypeParameterDeclaration" : isParameter(this) ? "ParameterDeclaration" : isConstructorDeclaration(this) ? "ConstructorDeclaration" : isGetAccessorDeclaration(this) ? "GetAccessorDeclaration" : isSetAccessorDeclaration(this) ? "SetAccessorDeclaration" : isCallSignatureDeclaration(this) ? "CallSignatureDeclaration" : isConstructSignatureDeclaration(this) ? "ConstructSignatureDeclaration" : isIndexSignatureDeclaration(this) ? "IndexSignatureDeclaration" : isTypePredicateNode(this) ? "TypePredicateNode" : isTypeReferenceNode(this) ? "TypeReferenceNode" : isFunctionTypeNode(this) ? "FunctionTypeNode" : isConstructorTypeNode(this) ? "ConstructorTypeNode" : isTypeQueryNode(this) ? "TypeQueryNode" : isTypeLiteralNode(this) ? "TypeLiteralNode" : isArrayTypeNode(this) ? "ArrayTypeNode" : isTupleTypeNode(this) ? "TupleTypeNode" : isOptionalTypeNode(this) ? "OptionalTypeNode" : isRestTypeNode(this) ? "RestTypeNode" : isUnionTypeNode(this) ? "UnionTypeNode" : isIntersectionTypeNode(this) ? "IntersectionTypeNode" : isConditionalTypeNode(this) ? "ConditionalTypeNode" : isInferTypeNode(this) ? "InferTypeNode" : isParenthesizedTypeNode(this) ? "ParenthesizedTypeNode" : isThisTypeNode(this) ? "ThisTypeNode" : isTypeOperatorNode(this) ? "TypeOperatorNode" : isIndexedAccessTypeNode(this) ? "IndexedAccessTypeNode" : isMappedTypeNode(this) ? "MappedTypeNode" : isLiteralTypeNode(this) ? "LiteralTypeNode" : isNamedTupleMember(this) ? "NamedTupleMember" : isImportTypeNode(this) ? "ImportTypeNode" : formatSyntaxKind(this.kind);
                                            return `${nodeHeader}${this.flags ? ` (${formatNodeFlags(this.flags)})` : ""}`;
                                        }
                                    },
                                    __debugKind: { get() {
                                            return formatSyntaxKind(this.kind);
                                        } },
                                    __debugNodeFlags: { get() {
                                            return formatNodeFlags(this.flags);
                                        } },
                                    __debugModifierFlags: { get() {
                                            return formatModifierFlags(getEffectiveModifierFlagsNoCache(this));
                                        } },
                                    __debugTransformFlags: { get() {
                                            return formatTransformFlags(this.transformFlags);
                                        } },
                                    __debugIsParseTreeNode: { get() {
                                            return isParseTreeNode(this);
                                        } },
                                    __debugEmitFlags: { get() {
                                            return formatEmitFlags(getEmitFlags(this));
                                        } },
                                    __debugGetText: {
                                        value(includeTrivia) {
                                            if (nodeIsSynthesized(this))
                                                return "";
                                            let text = weakNodeTextMap.get(this);
                                            if (text === void 0) {
                                                const parseNode = getParseTreeNode(this);
                                                const sourceFile = parseNode && getSourceFileOfNode(parseNode);
                                                text = sourceFile ? getSourceTextOfNodeFromSourceFile(sourceFile, parseNode, includeTrivia) : "";
                                                weakNodeTextMap.set(this, text);
                                            }
                                            return text;
                                        }
                                    }
                                });
                            }
                        }
                        isDebugInfoEnabled = true;
                    }
                    Debug2.enableDebugInfo = enableDebugInfo;
                    function formatVariance(varianceFlags) {
                        const variance = varianceFlags & 7 /* VarianceMask */;
                        let result = variance === 0 /* Invariant */ ? "in out" : variance === 3 /* Bivariant */ ? "[bivariant]" : variance === 2 /* Contravariant */ ? "in" : variance === 1 /* Covariant */ ? "out" : variance === 4 /* Independent */ ? "[independent]" : "";
                        if (varianceFlags & 8 /* Unmeasurable */) {
                            result += " (unmeasurable)";
                        }
                        else if (varianceFlags & 16 /* Unreliable */) {
                            result += " (unreliable)";
                        }
                        return result;
                    }
                    Debug2.formatVariance = formatVariance;
                    class DebugTypeMapper {
                        __debugToString() {
                            var _a2;
                            type(this);
                            switch (this.kind) {
                                case 3 /* Function */:
                                    return ((_a2 = this.debugInfo) == null ? void 0 : _a2.call(this)) || "(function mapper)";
                                case 0 /* Simple */:
                                    return `${this.source.__debugTypeToString()} -> ${this.target.__debugTypeToString()}`;
                                case 1 /* Array */:
                                    return zipWith(this.sources, this.targets || map(this.sources, () => "any"), (s, t) => `${s.__debugTypeToString()} -> ${typeof t === "string" ? t : t.__debugTypeToString()}`).join(", ");
                                case 2 /* Deferred */:
                                    return zipWith(this.sources, this.targets, (s, t) => `${s.__debugTypeToString()} -> ${t().__debugTypeToString()}`).join(", ");
                                case 5 /* Merged */:
                                case 4 /* Composite */:
                                    return `m1: ${this.mapper1.__debugToString().split("\n").join("\n    ")}
m2: ${this.mapper2.__debugToString().split("\n").join("\n    ")}`;
                                default:
                                    return assertNever(this);
                            }
                        }
                    }
                    Debug2.DebugTypeMapper = DebugTypeMapper;
                    function attachDebugPrototypeIfDebug(mapper) {
                        if (Debug2.isDebugging) {
                            return Object.setPrototypeOf(mapper, DebugTypeMapper.prototype);
                        }
                        return mapper;
                    }
                    Debug2.attachDebugPrototypeIfDebug = attachDebugPrototypeIfDebug;
                    function printControlFlowGraph(flowNode) {
                        return console.log(formatControlFlowGraph(flowNode));
                    }
                    Debug2.printControlFlowGraph = printControlFlowGraph;
                    function formatControlFlowGraph(flowNode) {
                        let nextDebugFlowId = -1;
                        function getDebugFlowNodeId(f) {
                            if (!f.id) {
                                f.id = nextDebugFlowId;
                                nextDebugFlowId--;
                            }
                            return f.id;
                        }
                        let BoxCharacter;
                        ((BoxCharacter2) => {
                            BoxCharacter2["lr"] = "\u2500";
                            BoxCharacter2["ud"] = "\u2502";
                            BoxCharacter2["dr"] = "\u256D";
                            BoxCharacter2["dl"] = "\u256E";
                            BoxCharacter2["ul"] = "\u256F";
                            BoxCharacter2["ur"] = "\u2570";
                            BoxCharacter2["udr"] = "\u251C";
                            BoxCharacter2["udl"] = "\u2524";
                            BoxCharacter2["dlr"] = "\u252C";
                            BoxCharacter2["ulr"] = "\u2534";
                            BoxCharacter2["udlr"] = "\u256B";
                        })(BoxCharacter || (BoxCharacter = {}));
                        let Connection;
                        ((Connection2) => {
                            Connection2[Connection2["None"] = 0] = "None";
                            Connection2[Connection2["Up"] = 1] = "Up";
                            Connection2[Connection2["Down"] = 2] = "Down";
                            Connection2[Connection2["Left"] = 4] = "Left";
                            Connection2[Connection2["Right"] = 8] = "Right";
                            Connection2[Connection2["UpDown"] = 3] = "UpDown";
                            Connection2[Connection2["LeftRight"] = 12] = "LeftRight";
                            Connection2[Connection2["UpLeft"] = 5] = "UpLeft";
                            Connection2[Connection2["UpRight"] = 9] = "UpRight";
                            Connection2[Connection2["DownLeft"] = 6] = "DownLeft";
                            Connection2[Connection2["DownRight"] = 10] = "DownRight";
                            Connection2[Connection2["UpDownLeft"] = 7] = "UpDownLeft";
                            Connection2[Connection2["UpDownRight"] = 11] = "UpDownRight";
                            Connection2[Connection2["UpLeftRight"] = 13] = "UpLeftRight";
                            Connection2[Connection2["DownLeftRight"] = 14] = "DownLeftRight";
                            Connection2[Connection2["UpDownLeftRight"] = 15] = "UpDownLeftRight";
                            Connection2[Connection2["NoChildren"] = 16] = "NoChildren";
                        })(Connection || (Connection = {}));
                        const hasAntecedentFlags = 16 /* Assignment */ | 96 /* Condition */ | 128 /* SwitchClause */ | 256 /* ArrayMutation */ | 512 /* Call */ | 1024 /* ReduceLabel */;
                        const hasNodeFlags = 2 /* Start */ | 16 /* Assignment */ | 512 /* Call */ | 96 /* Condition */ | 256 /* ArrayMutation */;
                        const links = /* @__PURE__ */ Object.create(
                        /*o*/
                        null);
                        const nodes = [];
                        const edges = [];
                        const root = buildGraphNode(flowNode, /* @__PURE__ */ new Set());
                        for (const node of nodes) {
                            node.text = renderFlowNode(node.flowNode, node.circular);
                            computeLevel(node);
                        }
                        const height = computeHeight(root);
                        const columnWidths = computeColumnWidths(height);
                        computeLanes(root, 0);
                        return renderGraph();
                        function isFlowSwitchClause(f) {
                            return !!(f.flags & 128 /* SwitchClause */);
                        }
                        function hasAntecedents(f) {
                            return !!(f.flags & 12 /* Label */) && !!f.antecedents;
                        }
                        function hasAntecedent(f) {
                            return !!(f.flags & hasAntecedentFlags);
                        }
                        function hasNode(f) {
                            return !!(f.flags & hasNodeFlags);
                        }
                        function getChildren(node) {
                            const children = [];
                            for (const edge of node.edges) {
                                if (edge.source === node) {
                                    children.push(edge.target);
                                }
                            }
                            return children;
                        }
                        function getParents(node) {
                            const parents = [];
                            for (const edge of node.edges) {
                                if (edge.target === node) {
                                    parents.push(edge.source);
                                }
                            }
                            return parents;
                        }
                        function buildGraphNode(flowNode2, seen) {
                            const id = getDebugFlowNodeId(flowNode2);
                            let graphNode = links[id];
                            if (graphNode && seen.has(flowNode2)) {
                                graphNode.circular = true;
                                graphNode = {
                                    id: -1,
                                    flowNode: flowNode2,
                                    edges: [],
                                    text: "",
                                    lane: -1,
                                    endLane: -1,
                                    level: -1,
                                    circular: "circularity"
                                };
                                nodes.push(graphNode);
                                return graphNode;
                            }
                            seen.add(flowNode2);
                            if (!graphNode) {
                                links[id] = graphNode = { id, flowNode: flowNode2, edges: [], text: "", lane: -1, endLane: -1, level: -1, circular: false };
                                nodes.push(graphNode);
                                if (hasAntecedents(flowNode2)) {
                                    for (const antecedent of flowNode2.antecedents) {
                                        buildGraphEdge(graphNode, antecedent, seen);
                                    }
                                }
                                else if (hasAntecedent(flowNode2)) {
                                    buildGraphEdge(graphNode, flowNode2.antecedent, seen);
                                }
                            }
                            seen.delete(flowNode2);
                            return graphNode;
                        }
                        function buildGraphEdge(source, antecedent, seen) {
                            const target = buildGraphNode(antecedent, seen);
                            const edge = { source, target };
                            edges.push(edge);
                            source.edges.push(edge);
                            target.edges.push(edge);
                        }
                        function computeLevel(node) {
                            if (node.level !== -1) {
                                return node.level;
                            }
                            let level = 0;
                            for (const parent2 of getParents(node)) {
                                level = Math.max(level, computeLevel(parent2) + 1);
                            }
                            return node.level = level;
                        }
                        function computeHeight(node) {
                            let height2 = 0;
                            for (const child of getChildren(node)) {
                                height2 = Math.max(height2, computeHeight(child));
                            }
                            return height2 + 1;
                        }
                        function computeColumnWidths(height2) {
                            const columns = fill(Array(height2), 0);
                            for (const node of nodes) {
                                columns[node.level] = Math.max(columns[node.level], node.text.length);
                            }
                            return columns;
                        }
                        function computeLanes(node, lane) {
                            if (node.lane === -1) {
                                node.lane = lane;
                                node.endLane = lane;
                                const children = getChildren(node);
                                for (let i = 0; i < children.length; i++) {
                                    if (i > 0)
                                        lane++;
                                    const child = children[i];
                                    computeLanes(child, lane);
                                    if (child.endLane > node.endLane) {
                                        lane = child.endLane;
                                    }
                                }
                                node.endLane = lane;
                            }
                        }
                        function getHeader(flags) {
                            if (flags & 2 /* Start */)
                                return "Start";
                            if (flags & 4 /* BranchLabel */)
                                return "Branch";
                            if (flags & 8 /* LoopLabel */)
                                return "Loop";
                            if (flags & 16 /* Assignment */)
                                return "Assignment";
                            if (flags & 32 /* TrueCondition */)
                                return "True";
                            if (flags & 64 /* FalseCondition */)
                                return "False";
                            if (flags & 128 /* SwitchClause */)
                                return "SwitchClause";
                            if (flags & 256 /* ArrayMutation */)
                                return "ArrayMutation";
                            if (flags & 512 /* Call */)
                                return "Call";
                            if (flags & 1024 /* ReduceLabel */)
                                return "ReduceLabel";
                            if (flags & 1 /* Unreachable */)
                                return "Unreachable";
                            throw new Error();
                        }
                        function getNodeText(node) {
                            const sourceFile = getSourceFileOfNode(node);
                            return getSourceTextOfNodeFromSourceFile(sourceFile, node, 
                            /*includeTrivia*/
                            false);
                        }
                        function renderFlowNode(flowNode2, circular) {
                            let text = getHeader(flowNode2.flags);
                            if (circular) {
                                text = `${text}#${getDebugFlowNodeId(flowNode2)}`;
                            }
                            if (hasNode(flowNode2)) {
                                if (flowNode2.node) {
                                    text += ` (${getNodeText(flowNode2.node)})`;
                                }
                            }
                            else if (isFlowSwitchClause(flowNode2)) {
                                const clauses = [];
                                for (let i = flowNode2.clauseStart; i < flowNode2.clauseEnd; i++) {
                                    const clause = flowNode2.switchStatement.caseBlock.clauses[i];
                                    if (isDefaultClause(clause)) {
                                        clauses.push("default");
                                    }
                                    else {
                                        clauses.push(getNodeText(clause.expression));
                                    }
                                }
                                text += ` (${clauses.join(", ")})`;
                            }
                            return circular === "circularity" ? `Circular(${text})` : text;
                        }
                        function renderGraph() {
                            const columnCount = columnWidths.length;
                            const laneCount = nodes.reduce((x, n) => Math.max(x, n.lane), 0) + 1;
                            const lanes = fill(Array(laneCount), "");
                            const grid = columnWidths.map(() => Array(laneCount));
                            const connectors = columnWidths.map(() => fill(Array(laneCount), 0));
                            for (const node of nodes) {
                                grid[node.level][node.lane] = node;
                                const children = getChildren(node);
                                for (let i = 0; i < children.length; i++) {
                                    const child = children[i];
                                    let connector = 8 /* Right */;
                                    if (child.lane === node.lane)
                                        connector |= 4 /* Left */;
                                    if (i > 0)
                                        connector |= 1 /* Up */;
                                    if (i < children.length - 1)
                                        connector |= 2 /* Down */;
                                    connectors[node.level][child.lane] |= connector;
                                }
                                if (children.length === 0) {
                                    connectors[node.level][node.lane] |= 16 /* NoChildren */;
                                }
                                const parents = getParents(node);
                                for (let i = 0; i < parents.length; i++) {
                                    const parent2 = parents[i];
                                    let connector = 4 /* Left */;
                                    if (i > 0)
                                        connector |= 1 /* Up */;
                                    if (i < parents.length - 1)
                                        connector |= 2 /* Down */;
                                    connectors[node.level - 1][parent2.lane] |= connector;
                                }
                            }
                            for (let column = 0; column < columnCount; column++) {
                                for (let lane = 0; lane < laneCount; lane++) {
                                    const left = column > 0 ? connectors[column - 1][lane] : 0;
                                    const above = lane > 0 ? connectors[column][lane - 1] : 0;
                                    let connector = connectors[column][lane];
                                    if (!connector) {
                                        if (left & 8 /* Right */)
                                            connector |= 12 /* LeftRight */;
                                        if (above & 2 /* Down */)
                                            connector |= 3 /* UpDown */;
                                        connectors[column][lane] = connector;
                                    }
                                }
                            }
                            for (let column = 0; column < columnCount; column++) {
                                for (let lane = 0; lane < lanes.length; lane++) {
                                    const connector = connectors[column][lane];
                                    const fill2 = connector & 4 /* Left */ ? "\u2500" /* lr */ : " ";
                                    const node = grid[column][lane];
                                    if (!node) {
                                        if (column < columnCount - 1) {
                                            writeLane(lane, repeat(fill2, columnWidths[column] + 1));
                                        }
                                    }
                                    else {
                                        writeLane(lane, node.text);
                                        if (column < columnCount - 1) {
                                            writeLane(lane, " ");
                                            writeLane(lane, repeat(fill2, columnWidths[column] - node.text.length));
                                        }
                                    }
                                    writeLane(lane, getBoxCharacter(connector));
                                    writeLane(lane, connector & 8 /* Right */ && column < columnCount - 1 && !grid[column + 1][lane] ? "\u2500" /* lr */ : " ");
                                }
                            }
                            return `
${lanes.join("\n")}
`;
                            function writeLane(lane, text) {
                                lanes[lane] += text;
                            }
                        }
                        function getBoxCharacter(connector) {
                            switch (connector) {
                                case 3 /* UpDown */:
                                    return "\u2502" /* ud */;
                                case 12 /* LeftRight */:
                                    return "\u2500" /* lr */;
                                case 5 /* UpLeft */:
                                    return "\u256F" /* ul */;
                                case 9 /* UpRight */:
                                    return "\u2570" /* ur */;
                                case 6 /* DownLeft */:
                                    return "\u256E" /* dl */;
                                case 10 /* DownRight */:
                                    return "\u256D" /* dr */;
                                case 7 /* UpDownLeft */:
                                    return "\u2524" /* udl */;
                                case 11 /* UpDownRight */:
                                    return "\u251C" /* udr */;
                                case 13 /* UpLeftRight */:
                                    return "\u2534" /* ulr */;
                                case 14 /* DownLeftRight */:
                                    return "\u252C" /* dlr */;
                                case 15 /* UpDownLeftRight */:
                                    return "\u256B" /* udlr */;
                            }
                            return " ";
                        }
                        function fill(array, value) {
                            if (array.fill) {
                                array.fill(value);
                            }
                            else {
                                for (let i = 0; i < array.length; i++) {
                                    array[i] = value;
                                }
                            }
                            return array;
                        }
                        function repeat(ch, length2) {
                            if (ch.repeat) {
                                return length2 > 0 ? ch.repeat(length2) : "";
                            }
                            let s = "";
                            while (s.length < length2) {
                                s += ch;
                            }
                            return s;
                        }
                    }
                    Debug2.formatControlFlowGraph = formatControlFlowGraph;
                })(Debug || (Debug = {}));
            }
        });
        // src/compiler/semver.ts
        function tryParseComponents(text) {
            const match = versionRegExp.exec(text);
            if (!match)
                return void 0;
            const [, major, minor = "0", patch = "0", prerelease = "", build2 = ""] = match;
            if (prerelease && !prereleaseRegExp.test(prerelease))
                return void 0;
            if (build2 && !buildRegExp.test(build2))
                return void 0;
            return {
                major: parseInt(major, 10),
                minor: parseInt(minor, 10),
                patch: parseInt(patch, 10),
                prerelease,
                build: build2
            };
        }
        function comparePrereleaseIdentifiers(left, right) {
            if (left === right)
                return 0 /* EqualTo */;
            if (left.length === 0)
                return right.length === 0 ? 0 /* EqualTo */ : 1 /* GreaterThan */;
            if (right.length === 0)
                return -1 /* LessThan */;
            const length2 = Math.min(left.length, right.length);
            for (let i = 0; i < length2; i++) {
                const leftIdentifier = left[i];
                const rightIdentifier = right[i];
                if (leftIdentifier === rightIdentifier)
                    continue;
                const leftIsNumeric = numericIdentifierRegExp.test(leftIdentifier);
                const rightIsNumeric = numericIdentifierRegExp.test(rightIdentifier);
                if (leftIsNumeric || rightIsNumeric) {
                    if (leftIsNumeric !== rightIsNumeric)
                        return leftIsNumeric ? -1 /* LessThan */ : 1 /* GreaterThan */;
                    const result = compareValues(+leftIdentifier, +rightIdentifier);
                    if (result)
                        return result;
                }
                else {
                    const result = compareStringsCaseSensitive(leftIdentifier, rightIdentifier);
                    if (result)
                        return result;
                }
            }
            return compareValues(left.length, right.length);
        }
        function parseRange(text) {
            const alternatives = [];
            for (let range of trimString(text).split(logicalOrRegExp)) {
                if (!range)
                    continue;
                const comparators = [];
                range = trimString(range);
                const match = hyphenRegExp.exec(range);
                if (match) {
                    if (!parseHyphen(match[1], match[2], comparators))
                        return void 0;
                }
                else {
                    for (const simple of range.split(whitespaceRegExp)) {
                        const match2 = rangeRegExp.exec(trimString(simple));
                        if (!match2 || !parseComparator(match2[1], match2[2], comparators))
                            return void 0;
                    }
                }
                alternatives.push(comparators);
            }
            return alternatives;
        }
        function parsePartial(text) {
            const match = partialRegExp.exec(text);
            if (!match)
                return void 0;
            const [, major, minor = "*", patch = "*", prerelease, build2] = match;
            const version2 = new Version(isWildcard(major) ? 0 : parseInt(major, 10), isWildcard(major) || isWildcard(minor) ? 0 : parseInt(minor, 10), isWildcard(major) || isWildcard(minor) || isWildcard(patch) ? 0 : parseInt(patch, 10), prerelease, build2);
            return { version: version2, major, minor, patch };
        }
        function parseHyphen(left, right, comparators) {
            const leftResult = parsePartial(left);
            if (!leftResult)
                return false;
            const rightResult = parsePartial(right);
            if (!rightResult)
                return false;
            if (!isWildcard(leftResult.major)) {
                comparators.push(createComparator(">=", leftResult.version));
            }
            if (!isWildcard(rightResult.major)) {
                comparators.push(isWildcard(rightResult.minor) ? createComparator("<", rightResult.version.increment("major")) : isWildcard(rightResult.patch) ? createComparator("<", rightResult.version.increment("minor")) : createComparator("<=", rightResult.version));
            }
            return true;
        }
        function parseComparator(operator, text, comparators) {
            const result = parsePartial(text);
            if (!result)
                return false;
            const { version: version2, major, minor, patch } = result;
            if (!isWildcard(major)) {
                switch (operator) {
                    case "~":
                        comparators.push(createComparator(">=", version2));
                        comparators.push(createComparator("<", version2.increment(isWildcard(minor) ? "major" : "minor")));
                        break;
                    case "^":
                        comparators.push(createComparator(">=", version2));
                        comparators.push(createComparator("<", version2.increment(version2.major > 0 || isWildcard(minor) ? "major" : version2.minor > 0 || isWildcard(patch) ? "minor" : "patch")));
                        break;
                    case "<":
                    case ">=":
                        comparators.push(isWildcard(minor) || isWildcard(patch) ? createComparator(operator, version2.with({ prerelease: "0" })) : createComparator(operator, version2));
                        break;
                    case "<=":
                    case ">":
                        comparators.push(isWildcard(minor) ? createComparator(operator === "<=" ? "<" : ">=", version2.increment("major").with({ prerelease: "0" })) : isWildcard(patch) ? createComparator(operator === "<=" ? "<" : ">=", version2.increment("minor").with({ prerelease: "0" })) : createComparator(operator, version2));
                        break;
                    case "=":
                    case void 0:
                        if (isWildcard(minor) || isWildcard(patch)) {
                            comparators.push(createComparator(">=", version2.with({ prerelease: "0" })));
                            comparators.push(createComparator("<", version2.increment(isWildcard(minor) ? "major" : "minor").with({ prerelease: "0" })));
                        }
                        else {
                            comparators.push(createComparator("=", version2));
                        }
                        break;
                    default:
                        return false;
                }
            }
            else if (operator === "<" || operator === ">") {
                comparators.push(createComparator("<", Version.zero));
            }
            return true;
        }
        function isWildcard(part) {
            return part === "*" || part === "x" || part === "X";
        }
        function createComparator(operator, operand) {
            return { operator, operand };
        }
        function testDisjunction(version2, alternatives) {
            if (alternatives.length === 0)
                return true;
            for (const alternative of alternatives) {
                if (testAlternative(version2, alternative))
                    return true;
            }
            return false;
        }
        function testAlternative(version2, comparators) {
            for (const comparator of comparators) {
                if (!testComparator(version2, comparator.operator, comparator.operand))
                    return false;
            }
            return true;
        }
        function testComparator(version2, operator, operand) {
            const cmp = version2.compareTo(operand);
            switch (operator) {
                case "<":
                    return cmp < 0;
                case "<=":
                    return cmp <= 0;
                case ">":
                    return cmp > 0;
                case ">=":
                    return cmp >= 0;
                case "=":
                    return cmp === 0;
                default:
                    return Debug.assertNever(operator);
            }
        }
        function formatDisjunction(alternatives) {
            return map(alternatives, formatAlternative).join(" || ") || "*";
        }
        function formatAlternative(comparators) {
            return map(comparators, formatComparator).join(" ");
        }
        function formatComparator(comparator) {
            return `${comparator.operator}${comparator.operand}`;
        }
        var versionRegExp, prereleaseRegExp, prereleasePartRegExp, buildRegExp, buildPartRegExp, numericIdentifierRegExp, _Version, Version, VersionRange, logicalOrRegExp, whitespaceRegExp, partialRegExp, hyphenRegExp, rangeRegExp;
        var init_semver = __esm({
            "src/compiler/semver.ts"() {
                "use strict";
                init_ts2();
                versionRegExp = /^(0|[1-9]\d*)(?:\.(0|[1-9]\d*)(?:\.(0|[1-9]\d*)(?:\-([a-z0-9-.]+))?(?:\+([a-z0-9-.]+))?)?)?$/i;
                prereleaseRegExp = /^(?:0|[1-9]\d*|[a-z-][a-z0-9-]*)(?:\.(?:0|[1-9]\d*|[a-z-][a-z0-9-]*))*$/i;
                prereleasePartRegExp = /^(?:0|[1-9]\d*|[a-z-][a-z0-9-]*)$/i;
                buildRegExp = /^[a-z0-9-]+(?:\.[a-z0-9-]+)*$/i;
                buildPartRegExp = /^[a-z0-9-]+$/i;
                numericIdentifierRegExp = /^(0|[1-9]\d*)$/;
                _Version = class {
                    constructor(major, minor = 0, patch = 0, prerelease = "", build2 = "") {
                        if (typeof major === "string") {
                            const result = Debug.checkDefined(tryParseComponents(major), "Invalid version");
                            ({ major, minor, patch, prerelease, build: build2 } = result);
                        }
                        Debug.assert(major >= 0, "Invalid argument: major");
                        Debug.assert(minor >= 0, "Invalid argument: minor");
                        Debug.assert(patch >= 0, "Invalid argument: patch");
                        const prereleaseArray = prerelease ? isArray(prerelease) ? prerelease : prerelease.split(".") : emptyArray;
                        const buildArray = build2 ? isArray(build2) ? build2 : build2.split(".") : emptyArray;
                        Debug.assert(every(prereleaseArray, (s) => prereleasePartRegExp.test(s)), "Invalid argument: prerelease");
                        Debug.assert(every(buildArray, (s) => buildPartRegExp.test(s)), "Invalid argument: build");
                        this.major = major;
                        this.minor = minor;
                        this.patch = patch;
                        this.prerelease = prereleaseArray;
                        this.build = buildArray;
                    }
                    static tryParse(text) {
                        const result = tryParseComponents(text);
                        if (!result)
                            return void 0;
                        const { major, minor, patch, prerelease, build: build2 } = result;
                        return new _Version(major, minor, patch, prerelease, build2);
                    }
                    compareTo(other) {
                        if (this === other)
                            return 0 /* EqualTo */;
                        if (other === void 0)
                            return 1 /* GreaterThan */;
                        return compareValues(this.major, other.major) || compareValues(this.minor, other.minor) || compareValues(this.patch, other.patch) || comparePrereleaseIdentifiers(this.prerelease, other.prerelease);
                    }
                    increment(field) {
                        switch (field) {
                            case "major":
                                return new _Version(this.major + 1, 0, 0);
                            case "minor":
                                return new _Version(this.major, this.minor + 1, 0);
                            case "patch":
                                return new _Version(this.major, this.minor, this.patch + 1);
                            default:
                                return Debug.assertNever(field);
                        }
                    }
                    with(fields) {
                        const { major = this.major, minor = this.minor, patch = this.patch, prerelease = this.prerelease, build: build2 = this.build } = fields;
                        return new _Version(major, minor, patch, prerelease, build2);
                    }
                    toString() {
                        let result = `${this.major}.${this.minor}.${this.patch}`;
                        if (some(this.prerelease))
                            result += `-${this.prerelease.join(".")}`;
                        if (some(this.build))
                            result += `+${this.build.join(".")}`;
                        return result;
                    }
                };
                Version = _Version;
                Version.zero = new _Version(0, 0, 0, ["0"]);
                VersionRange = class {
                    constructor(spec) {
                        this._alternatives = spec ? Debug.checkDefined(parseRange(spec), "Invalid range spec.") : emptyArray;
                    }
                    static tryParse(text) {
                        const sets = parseRange(text);
                        if (sets) {
                            const range = new VersionRange("");
                            range._alternatives = sets;
                            return range;
                        }
                        return void 0;
                    }
                    /**
                     * Tests whether a version matches the range. This is equivalent to `satisfies(version, range, { includePrerelease: true })`.
                     * in `node-semver`.
                     */
                    test(version2) {
                        if (typeof version2 === "string")
                            version2 = new Version(version2);
                        return testDisjunction(version2, this._alternatives);
                    }
                    toString() {
                        return formatDisjunction(this._alternatives);
                    }
                };
                logicalOrRegExp = /\|\|/g;
                whitespaceRegExp = /\s+/g;
                partialRegExp = /^([xX*0]|[1-9]\d*)(?:\.([xX*0]|[1-9]\d*)(?:\.([xX*0]|[1-9]\d*)(?:-([a-z0-9-.]+))?(?:\+([a-z0-9-.]+))?)?)?$/i;
                hyphenRegExp = /^\s*([a-z0-9-+.*]+)\s+-\s+([a-z0-9-+.*]+)\s*$/i;
                rangeRegExp = /^(~|\^|<|<=|>|>=|=)?\s*([a-z0-9-+.*]+)$/i;
            }
        });
        // src/compiler/performanceCore.ts
        function hasRequiredAPI(performance2, PerformanceObserver2) {
            return typeof performance2 === "object" && typeof performance2.timeOrigin === "number" && typeof performance2.mark === "function" && typeof performance2.measure === "function" && typeof performance2.now === "function" && typeof performance2.clearMarks === "function" && typeof performance2.clearMeasures === "function" && typeof PerformanceObserver2 === "function";
        }
        function tryGetWebPerformanceHooks() {
            if (typeof performance === "object" && typeof PerformanceObserver === "function" && hasRequiredAPI(performance, PerformanceObserver)) {
                return {
                    // For now we always write native performance events when running in the browser. We may
                    // make this conditional in the future if we find that native web performance hooks
                    // in the browser also slow down compilation.
                    shouldWriteNativeEvents: true,
                    performance,
                    PerformanceObserver
                };
            }
        }
        function tryGetNodePerformanceHooks() {
            if (isNodeLikeSystem()) {
                try {
                    let performance2;
                    const { performance: nodePerformance, PerformanceObserver: PerformanceObserver2 } = require("perf_hooks");
                    if (hasRequiredAPI(nodePerformance, PerformanceObserver2)) {
                        performance2 = nodePerformance;
                        const version2 = new Version(process.versions.node);
                        const range = new VersionRange("<12.16.3 || 13 <13.13");
                        if (range.test(version2)) {
                            performance2 = {
                                get timeOrigin() {
                                    return nodePerformance.timeOrigin;
                                },
                                now() {
                                    return nodePerformance.now();
                                },
                                mark(name) {
                                    return nodePerformance.mark(name);
                                },
                                measure(name, start = "nodeStart", end) {
                                    if (end === void 0) {
                                        end = "__performance.measure-fix__";
                                        nodePerformance.mark(end);
                                    }
                                    nodePerformance.measure(name, start, end);
                                    if (end === "__performance.measure-fix__") {
                                        nodePerformance.clearMarks("__performance.measure-fix__");
                                    }
                                },
                                clearMarks(name) {
                                    return nodePerformance.clearMarks(name);
                                },
                                clearMeasures(name) {
                                    return nodePerformance.clearMeasures(name);
                                }
                            };
                        }
                        return {
                            // By default, only write native events when generating a cpu profile or using the v8 profiler.
                            shouldWriteNativeEvents: false,
                            performance: performance2,
                            PerformanceObserver: PerformanceObserver2
                        };
                    }
                }
                catch (e) {
                }
            }
        }
        function tryGetNativePerformanceHooks() {
            return nativePerformanceHooks;
        }
        var nativePerformanceHooks, nativePerformance, timestamp;
        var init_performanceCore = __esm({
            "src/compiler/performanceCore.ts"() {
                "use strict";
                init_ts2();
                nativePerformanceHooks = tryGetWebPerformanceHooks() || tryGetNodePerformanceHooks();
                nativePerformance = nativePerformanceHooks == null ? void 0 : nativePerformanceHooks.performance;
                timestamp = nativePerformance ? () => nativePerformance.now() : Date.now ? Date.now : () => +new Date();
            }
        });
        // src/compiler/perfLogger.ts
        var nullLogger, etwModule, _a, perfLogger;
        var init_perfLogger = __esm({
            "src/compiler/perfLogger.ts"() {
                "use strict";
                init_ts2();
                nullLogger = {
                    logEvent: noop,
                    logErrEvent: noop,
                    logPerfEvent: noop,
                    logInfoEvent: noop,
                    logStartCommand: noop,
                    logStopCommand: noop,
                    logStartUpdateProgram: noop,
                    logStopUpdateProgram: noop,
                    logStartUpdateGraph: noop,
                    logStopUpdateGraph: noop,
                    logStartResolveModule: noop,
                    logStopResolveModule: noop,
                    logStartParseSourceFile: noop,
                    logStopParseSourceFile: noop,
                    logStartReadFile: noop,
                    logStopReadFile: noop,
                    logStartBindFile: noop,
                    logStopBindFile: noop,
                    logStartScheduledOperation: noop,
                    logStopScheduledOperation: noop
                };
                try {
                    const etwModulePath = (_a = process.env.TS_ETW_MODULE_PATH) != null ? _a : "./node_modules/@microsoft/typescript-etw";
                    etwModule = require(etwModulePath);
                }
                catch (e) {
                    etwModule = void 0;
                }
                perfLogger = (etwModule == null ? void 0 : etwModule.logEvent) ? etwModule : nullLogger;
            }
        });
        // src/compiler/performance.ts
        function createTimerIf(condition, measureName, startMarkName, endMarkName) {
            return condition ? createTimer(measureName, startMarkName, endMarkName) : nullTimer;
        }
        function createTimer(measureName, startMarkName, endMarkName) {
            let enterCount = 0;
            return {
                enter,
                exit
            };
            function enter() {
                if (++enterCount === 1) {
                    mark(startMarkName);
                }
            }
            function exit() {
                if (--enterCount === 0) {
                    mark(endMarkName);
                    measure(measureName, startMarkName, endMarkName);
                }
                else if (enterCount < 0) {
                    Debug.fail("enter/exit count does not match.");
                }
            }
        }
        function mark(markName) {
            var _a2;
            if (enabled) {
                const count = (_a2 = counts.get(markName)) != null ? _a2 : 0;
                counts.set(markName, count + 1);
                marks.set(markName, timestamp());
                performanceImpl == null ? void 0 : performanceImpl.mark(markName);
                if (typeof onProfilerEvent === "function") {
                    onProfilerEvent(markName);
                }
            }
        }
        function measure(measureName, startMarkName, endMarkName) {
            var _a2, _b;
            if (enabled) {
                const end = (_a2 = endMarkName !== void 0 ? marks.get(endMarkName) : void 0) != null ? _a2 : timestamp();
                const start = (_b = startMarkName !== void 0 ? marks.get(startMarkName) : void 0) != null ? _b : timeorigin;
                const previousDuration = durations.get(measureName) || 0;
                durations.set(measureName, previousDuration + (end - start));
                performanceImpl == null ? void 0 : performanceImpl.measure(measureName, startMarkName, endMarkName);
            }
        }
        function getCount(markName) {
            return counts.get(markName) || 0;
        }
        function getDuration(measureName) {
            return durations.get(measureName) || 0;
        }
        function forEachMeasure(cb) {
            durations.forEach((duration, measureName) => cb(measureName, duration));
        }
        function forEachMark(cb) {
            marks.forEach((_time, markName) => cb(markName));
        }
        function clearMeasures(name) {
            if (name !== void 0)
                durations.delete(name);
            else
                durations.clear();
            performanceImpl == null ? void 0 : performanceImpl.clearMeasures(name);
        }
        function clearMarks(name) {
            if (name !== void 0) {
                counts.delete(name);
                marks.delete(name);
            }
            else {
                counts.clear();
                marks.clear();
            }
            performanceImpl == null ? void 0 : performanceImpl.clearMarks(name);
        }
        function isEnabled() {
            return enabled;
        }
        function enable(system = sys) {
            var _a2;
            if (!enabled) {
                enabled = true;
                perfHooks || (perfHooks = tryGetNativePerformanceHooks());
                if (perfHooks) {
                    timeorigin = perfHooks.performance.timeOrigin;
                    if (perfHooks.shouldWriteNativeEvents || ((_a2 = system == null ? void 0 : system.cpuProfilingEnabled) == null ? void 0 : _a2.call(system)) || (system == null ? void 0 : system.debugMode)) {
                        performanceImpl = perfHooks.performance;
                    }
                }
            }
            return true;
        }
        function disable() {
            if (enabled) {
                marks.clear();
                counts.clear();
                durations.clear();
                performanceImpl = void 0;
                enabled = false;
            }
        }
        var perfHooks, performanceImpl, nullTimer, enabled, timeorigin, marks, counts, durations;
        var init_performance = __esm({
            "src/compiler/performance.ts"() {
                "use strict";
                init_ts2();
                nullTimer = { enter: noop, exit: noop };
                enabled = false;
                timeorigin = timestamp();
                marks = /* @__PURE__ */ new Map();
                counts = /* @__PURE__ */ new Map();
                durations = /* @__PURE__ */ new Map();
            }
        });
        // src/compiler/_namespaces/ts.performance.ts
        var ts_performance_exports = {};
        __export(ts_performance_exports, {
            clearMarks: () => clearMarks,
            clearMeasures: () => clearMeasures,
            createTimer: () => createTimer,
            createTimerIf: () => createTimerIf,
            disable: () => disable,
            enable: () => enable,
            forEachMark: () => forEachMark,
            forEachMeasure: () => forEachMeasure,
            getCount: () => getCount,
            getDuration: () => getDuration,
            isEnabled: () => isEnabled,
            mark: () => mark,
            measure: () => measure,
            nullTimer: () => nullTimer
        });
        var init_ts_performance = __esm({
            "src/compiler/_namespaces/ts.performance.ts"() {
                "use strict";
                init_performance();
            }
        });
        // src/compiler/tracing.ts
        var tracing, tracingEnabled, startTracing, dumpTracingLegend;
        var init_tracing = __esm({
            "src/compiler/tracing.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                ((tracingEnabled2) => {
                    let fs;
                    let traceCount = 0;
                    let traceFd = 0;
                    let mode;
                    const typeCatalog = [];
                    let legendPath;
                    const legend = [];
                    function startTracing2(tracingMode, traceDir, configFilePath) {
                        Debug.assert(!tracing, "Tracing already started");
                        if (fs === void 0) {
                            try {
                                fs = require("fs");
                            }
                            catch (e) {
                                throw new Error(`tracing requires having fs
(original error: ${e.message || e})`);
                            }
                        }
                        mode = tracingMode;
                        typeCatalog.length = 0;
                        if (legendPath === void 0) {
                            legendPath = combinePaths(traceDir, "legend.json");
                        }
                        if (!fs.existsSync(traceDir)) {
                            fs.mkdirSync(traceDir, { recursive: true });
                        }
                        const countPart = mode === "build" ? `.${process.pid}-${++traceCount}` : mode === "server" ? `.${process.pid}` : ``;
                        const tracePath = combinePaths(traceDir, `trace${countPart}.json`);
                        const typesPath = combinePaths(traceDir, `types${countPart}.json`);
                        legend.push({
                            configFilePath,
                            tracePath,
                            typesPath
                        });
                        traceFd = fs.openSync(tracePath, "w");
                        tracing = tracingEnabled2;
                        const meta = { cat: "__metadata", ph: "M", ts: 1e3 * timestamp(), pid: 1, tid: 1 };
                        fs.writeSync(traceFd, "[\n" + [
                            { name: "process_name", args: { name: "tsc" }, ...meta },
                            { name: "thread_name", args: { name: "Main" }, ...meta },
                            { name: "TracingStartedInBrowser", ...meta, cat: "disabled-by-default-devtools.timeline" }
                        ].map((v) => JSON.stringify(v)).join(",\n"));
                    }
                    tracingEnabled2.startTracing = startTracing2;
                    function stopTracing() {
                        Debug.assert(tracing, "Tracing is not in progress");
                        Debug.assert(!!typeCatalog.length === (mode !== "server"));
                        fs.writeSync(traceFd, `
]
`);
                        fs.closeSync(traceFd);
                        tracing = void 0;
                        if (typeCatalog.length) {
                            dumpTypes(typeCatalog);
                        }
                        else {
                            legend[legend.length - 1].typesPath = void 0;
                        }
                    }
                    tracingEnabled2.stopTracing = stopTracing;
                    function recordType(type) {
                        if (mode !== "server") {
                            typeCatalog.push(type);
                        }
                    }
                    tracingEnabled2.recordType = recordType;
                    let Phase;
                    ((Phase2) => {
                        Phase2["Parse"] = "parse";
                        Phase2["Program"] = "program";
                        Phase2["Bind"] = "bind";
                        Phase2["Check"] = "check";
                        Phase2["CheckTypes"] = "checkTypes";
                        Phase2["Emit"] = "emit";
                        Phase2["Session"] = "session";
                    })(Phase = tracingEnabled2.Phase || (tracingEnabled2.Phase = {}));
                    function instant(phase, name, args) {
                        writeEvent("I", phase, name, args, `"s":"g"`);
                    }
                    tracingEnabled2.instant = instant;
                    const eventStack = [];
                    function push(phase, name, args, separateBeginAndEnd = false) {
                        if (separateBeginAndEnd) {
                            writeEvent("B", phase, name, args);
                        }
                        eventStack.push({ phase, name, args, time: 1e3 * timestamp(), separateBeginAndEnd });
                    }
                    tracingEnabled2.push = push;
                    function pop(results) {
                        Debug.assert(eventStack.length > 0);
                        writeStackEvent(eventStack.length - 1, 1e3 * timestamp(), results);
                        eventStack.length--;
                    }
                    tracingEnabled2.pop = pop;
                    function popAll() {
                        const endTime = 1e3 * timestamp();
                        for (let i = eventStack.length - 1; i >= 0; i--) {
                            writeStackEvent(i, endTime);
                        }
                        eventStack.length = 0;
                    }
                    tracingEnabled2.popAll = popAll;
                    const sampleInterval = 1e3 * 10;
                    function writeStackEvent(index, endTime, results) {
                        const { phase, name, args, time, separateBeginAndEnd } = eventStack[index];
                        if (separateBeginAndEnd) {
                            Debug.assert(!results, "`results` are not supported for events with `separateBeginAndEnd`");
                            writeEvent("E", phase, name, args, 
                            /*extras*/
                            void 0, endTime);
                        }
                        else if (sampleInterval - time % sampleInterval <= endTime - time) {
                            writeEvent("X", phase, name, { ...args, results }, `"dur":${endTime - time}`, time);
                        }
                    }
                    function writeEvent(eventType, phase, name, args, extras, time = 1e3 * timestamp()) {
                        if (mode === "server" && phase === "checkTypes" /* CheckTypes */)
                            return;
                        mark("beginTracing");
                        fs.writeSync(traceFd, `,
{"pid":1,"tid":1,"ph":"${eventType}","cat":"${phase}","ts":${time},"name":"${name}"`);
                        if (extras)
                            fs.writeSync(traceFd, `,${extras}`);
                        if (args)
                            fs.writeSync(traceFd, `,"args":${JSON.stringify(args)}`);
                        fs.writeSync(traceFd, `}`);
                        mark("endTracing");
                        measure("Tracing", "beginTracing", "endTracing");
                    }
                    function getLocation(node) {
                        const file = getSourceFileOfNode(node);
                        return !file ? void 0 : {
                            path: file.path,
                            start: indexFromOne(getLineAndCharacterOfPosition(file, node.pos)),
                            end: indexFromOne(getLineAndCharacterOfPosition(file, node.end))
                        };
                        function indexFromOne(lc) {
                            return {
                                line: lc.line + 1,
                                character: lc.character + 1
                            };
                        }
                    }
                    function dumpTypes(types) {
                        var _a2, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n, _o, _p, _q, _r, _s, _t, _u, _v;
                        mark("beginDumpTypes");
                        const typesPath = legend[legend.length - 1].typesPath;
                        const typesFd = fs.openSync(typesPath, "w");
                        const recursionIdentityMap = /* @__PURE__ */ new Map();
                        fs.writeSync(typesFd, "[");
                        const numTypes = types.length;
                        for (let i = 0; i < numTypes; i++) {
                            const type = types[i];
                            const objectFlags = type.objectFlags;
                            const symbol = (_a2 = type.aliasSymbol) != null ? _a2 : type.symbol;
                            let display;
                            if (objectFlags & 16 /* Anonymous */ | type.flags & 2944 /* Literal */) {
                                try {
                                    display = (_b = type.checker) == null ? void 0 : _b.typeToString(type);
                                }
                                catch (e) {
                                    display = void 0;
                                }
                            }
                            let indexedAccessProperties = {};
                            if (type.flags & 8388608 /* IndexedAccess */) {
                                const indexedAccessType = type;
                                indexedAccessProperties = {
                                    indexedAccessObjectType: (_c = indexedAccessType.objectType) == null ? void 0 : _c.id,
                                    indexedAccessIndexType: (_d = indexedAccessType.indexType) == null ? void 0 : _d.id
                                };
                            }
                            let referenceProperties = {};
                            if (objectFlags & 4 /* Reference */) {
                                const referenceType = type;
                                referenceProperties = {
                                    instantiatedType: (_e = referenceType.target) == null ? void 0 : _e.id,
                                    typeArguments: (_f = referenceType.resolvedTypeArguments) == null ? void 0 : _f.map((t) => t.id),
                                    referenceLocation: getLocation(referenceType.node)
                                };
                            }
                            let conditionalProperties = {};
                            if (type.flags & 16777216 /* Conditional */) {
                                const conditionalType = type;
                                conditionalProperties = {
                                    conditionalCheckType: (_g = conditionalType.checkType) == null ? void 0 : _g.id,
                                    conditionalExtendsType: (_h = conditionalType.extendsType) == null ? void 0 : _h.id,
                                    conditionalTrueType: (_j = (_i = conditionalType.resolvedTrueType) == null ? void 0 : _i.id) != null ? _j : -1,
                                    conditionalFalseType: (_l = (_k = conditionalType.resolvedFalseType) == null ? void 0 : _k.id) != null ? _l : -1
                                };
                            }
                            let substitutionProperties = {};
                            if (type.flags & 33554432 /* Substitution */) {
                                const substitutionType = type;
                                substitutionProperties = {
                                    substitutionBaseType: (_m = substitutionType.baseType) == null ? void 0 : _m.id,
                                    constraintType: (_n = substitutionType.constraint) == null ? void 0 : _n.id
                                };
                            }
                            let reverseMappedProperties = {};
                            if (objectFlags & 1024 /* ReverseMapped */) {
                                const reverseMappedType = type;
                                reverseMappedProperties = {
                                    reverseMappedSourceType: (_o = reverseMappedType.source) == null ? void 0 : _o.id,
                                    reverseMappedMappedType: (_p = reverseMappedType.mappedType) == null ? void 0 : _p.id,
                                    reverseMappedConstraintType: (_q = reverseMappedType.constraintType) == null ? void 0 : _q.id
                                };
                            }
                            let evolvingArrayProperties = {};
                            if (objectFlags & 256 /* EvolvingArray */) {
                                const evolvingArrayType = type;
                                evolvingArrayProperties = {
                                    evolvingArrayElementType: evolvingArrayType.elementType.id,
                                    evolvingArrayFinalType: (_r = evolvingArrayType.finalArrayType) == null ? void 0 : _r.id
                                };
                            }
                            let recursionToken;
                            const recursionIdentity = type.checker.getRecursionIdentity(type);
                            if (recursionIdentity) {
                                recursionToken = recursionIdentityMap.get(recursionIdentity);
                                if (!recursionToken) {
                                    recursionToken = recursionIdentityMap.size;
                                    recursionIdentityMap.set(recursionIdentity, recursionToken);
                                }
                            }
                            const descriptor = {
                                id: type.id,
                                intrinsicName: type.intrinsicName,
                                symbolName: (symbol == null ? void 0 : symbol.escapedName) && unescapeLeadingUnderscores(symbol.escapedName),
                                recursionId: recursionToken,
                                isTuple: objectFlags & 8 /* Tuple */ ? true : void 0,
                                unionTypes: type.flags & 1048576 /* Union */ ? (_s = type.types) == null ? void 0 : _s.map((t) => t.id) : void 0,
                                intersectionTypes: type.flags & 2097152 /* Intersection */ ? type.types.map((t) => t.id) : void 0,
                                aliasTypeArguments: (_t = type.aliasTypeArguments) == null ? void 0 : _t.map((t) => t.id),
                                keyofType: type.flags & 4194304 /* Index */ ? (_u = type.type) == null ? void 0 : _u.id : void 0,
                                ...indexedAccessProperties,
                                ...referenceProperties,
                                ...conditionalProperties,
                                ...substitutionProperties,
                                ...reverseMappedProperties,
                                ...evolvingArrayProperties,
                                destructuringPattern: getLocation(type.pattern),
                                firstDeclaration: getLocation((_v = symbol == null ? void 0 : symbol.declarations) == null ? void 0 : _v[0]),
                                flags: Debug.formatTypeFlags(type.flags).split("|"),
                                display
                            };
                            fs.writeSync(typesFd, JSON.stringify(descriptor));
                            if (i < numTypes - 1) {
                                fs.writeSync(typesFd, ",\n");
                            }
                        }
                        fs.writeSync(typesFd, "]\n");
                        fs.closeSync(typesFd);
                        mark("endDumpTypes");
                        measure("Dump types", "beginDumpTypes", "endDumpTypes");
                    }
                    function dumpLegend() {
                        if (!legendPath) {
                            return;
                        }
                        fs.writeFileSync(legendPath, JSON.stringify(legend));
                    }
                    tracingEnabled2.dumpLegend = dumpLegend;
                })(tracingEnabled || (tracingEnabled = {}));
                startTracing = tracingEnabled.startTracing;
                dumpTracingLegend = tracingEnabled.dumpLegend;
            }
        });
        // src/compiler/types.ts
        function diagnosticCategoryName(d, lowerCase = true) {
            const name = DiagnosticCategory[d.category];
            return lowerCase ? name.toLowerCase() : name;
        }
        var SyntaxKind, NodeFlags, ModifierFlags, JsxFlags, RelationComparisonResult, GeneratedIdentifierFlags, TokenFlags, FlowFlags, CommentDirectiveType, OperationCanceledException, FileIncludeKind, FilePreprocessingDiagnosticsKind, EmitOnly, StructureIsReused, ExitStatus, MemberOverrideStatus, UnionReduction, ContextFlags, NodeBuilderFlags, TypeFormatFlags, SymbolFormatFlags, SymbolAccessibility, SyntheticSymbolKind, TypePredicateKind, TypeReferenceSerializationKind, SymbolFlags, EnumKind, CheckFlags, InternalSymbolName, NodeCheckFlags, TypeFlags, ObjectFlags, VarianceFlags, ElementFlags, AccessFlags, JsxReferenceKind, SignatureKind, SignatureFlags, IndexKind, TypeMapKind, InferencePriority, InferenceFlags, Ternary, AssignmentDeclarationKind, DiagnosticCategory, ModuleResolutionKind, ModuleDetectionKind, WatchFileKind, WatchDirectoryKind, PollingWatchKind, ModuleKind, JsxEmit, ImportsNotUsedAsValues, NewLineKind, ScriptKind, ScriptTarget, LanguageVariant, WatchDirectoryFlags, CharacterCodes, Extension, TransformFlags, SnippetKind, EmitFlags, InternalEmitFlags, ExternalEmitHelpers, EmitHint, OuterExpressionKinds, LexicalEnvironmentFlags, BundleFileSectionKind, ListFormat, PragmaKindFlags, commentPragmas;
        var init_types = __esm({
            "src/compiler/types.ts"() {
                "use strict";
                SyntaxKind = /* @__PURE__ */ ((SyntaxKind5) => {
                    SyntaxKind5[SyntaxKind5["Unknown"] = 0] = "Unknown";
                    SyntaxKind5[SyntaxKind5["EndOfFileToken"] = 1] = "EndOfFileToken";
                    SyntaxKind5[SyntaxKind5["SingleLineCommentTrivia"] = 2] = "SingleLineCommentTrivia";
                    SyntaxKind5[SyntaxKind5["MultiLineCommentTrivia"] = 3] = "MultiLineCommentTrivia";
                    SyntaxKind5[SyntaxKind5["NewLineTrivia"] = 4] = "NewLineTrivia";
                    SyntaxKind5[SyntaxKind5["WhitespaceTrivia"] = 5] = "WhitespaceTrivia";
                    SyntaxKind5[SyntaxKind5["ShebangTrivia"] = 6] = "ShebangTrivia";
                    SyntaxKind5[SyntaxKind5["ConflictMarkerTrivia"] = 7] = "ConflictMarkerTrivia";
                    SyntaxKind5[SyntaxKind5["NumericLiteral"] = 8] = "NumericLiteral";
                    SyntaxKind5[SyntaxKind5["BigIntLiteral"] = 9] = "BigIntLiteral";
                    SyntaxKind5[SyntaxKind5["StringLiteral"] = 10] = "StringLiteral";
                    SyntaxKind5[SyntaxKind5["JsxText"] = 11] = "JsxText";
                    SyntaxKind5[SyntaxKind5["JsxTextAllWhiteSpaces"] = 12] = "JsxTextAllWhiteSpaces";
                    SyntaxKind5[SyntaxKind5["RegularExpressionLiteral"] = 13] = "RegularExpressionLiteral";
                    SyntaxKind5[SyntaxKind5["NoSubstitutionTemplateLiteral"] = 14] = "NoSubstitutionTemplateLiteral";
                    SyntaxKind5[SyntaxKind5["TemplateHead"] = 15] = "TemplateHead";
                    SyntaxKind5[SyntaxKind5["TemplateMiddle"] = 16] = "TemplateMiddle";
                    SyntaxKind5[SyntaxKind5["TemplateTail"] = 17] = "TemplateTail";
                    SyntaxKind5[SyntaxKind5["OpenBraceToken"] = 18] = "OpenBraceToken";
                    SyntaxKind5[SyntaxKind5["CloseBraceToken"] = 19] = "CloseBraceToken";
                    SyntaxKind5[SyntaxKind5["OpenParenToken"] = 20] = "OpenParenToken";
                    SyntaxKind5[SyntaxKind5["CloseParenToken"] = 21] = "CloseParenToken";
                    SyntaxKind5[SyntaxKind5["OpenBracketToken"] = 22] = "OpenBracketToken";
                    SyntaxKind5[SyntaxKind5["CloseBracketToken"] = 23] = "CloseBracketToken";
                    SyntaxKind5[SyntaxKind5["DotToken"] = 24] = "DotToken";
                    SyntaxKind5[SyntaxKind5["DotDotDotToken"] = 25] = "DotDotDotToken";
                    SyntaxKind5[SyntaxKind5["SemicolonToken"] = 26] = "SemicolonToken";
                    SyntaxKind5[SyntaxKind5["CommaToken"] = 27] = "CommaToken";
                    SyntaxKind5[SyntaxKind5["QuestionDotToken"] = 28] = "QuestionDotToken";
                    SyntaxKind5[SyntaxKind5["LessThanToken"] = 29] = "LessThanToken";
                    SyntaxKind5[SyntaxKind5["LessThanSlashToken"] = 30] = "LessThanSlashToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanToken"] = 31] = "GreaterThanToken";
                    SyntaxKind5[SyntaxKind5["LessThanEqualsToken"] = 32] = "LessThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanEqualsToken"] = 33] = "GreaterThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["EqualsEqualsToken"] = 34] = "EqualsEqualsToken";
                    SyntaxKind5[SyntaxKind5["ExclamationEqualsToken"] = 35] = "ExclamationEqualsToken";
                    SyntaxKind5[SyntaxKind5["EqualsEqualsEqualsToken"] = 36] = "EqualsEqualsEqualsToken";
                    SyntaxKind5[SyntaxKind5["ExclamationEqualsEqualsToken"] = 37] = "ExclamationEqualsEqualsToken";
                    SyntaxKind5[SyntaxKind5["EqualsGreaterThanToken"] = 38] = "EqualsGreaterThanToken";
                    SyntaxKind5[SyntaxKind5["PlusToken"] = 39] = "PlusToken";
                    SyntaxKind5[SyntaxKind5["MinusToken"] = 40] = "MinusToken";
                    SyntaxKind5[SyntaxKind5["AsteriskToken"] = 41] = "AsteriskToken";
                    SyntaxKind5[SyntaxKind5["AsteriskAsteriskToken"] = 42] = "AsteriskAsteriskToken";
                    SyntaxKind5[SyntaxKind5["SlashToken"] = 43] = "SlashToken";
                    SyntaxKind5[SyntaxKind5["PercentToken"] = 44] = "PercentToken";
                    SyntaxKind5[SyntaxKind5["PlusPlusToken"] = 45] = "PlusPlusToken";
                    SyntaxKind5[SyntaxKind5["MinusMinusToken"] = 46] = "MinusMinusToken";
                    SyntaxKind5[SyntaxKind5["LessThanLessThanToken"] = 47] = "LessThanLessThanToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanGreaterThanToken"] = 48] = "GreaterThanGreaterThanToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanGreaterThanGreaterThanToken"] = 49] = "GreaterThanGreaterThanGreaterThanToken";
                    SyntaxKind5[SyntaxKind5["AmpersandToken"] = 50] = "AmpersandToken";
                    SyntaxKind5[SyntaxKind5["BarToken"] = 51] = "BarToken";
                    SyntaxKind5[SyntaxKind5["CaretToken"] = 52] = "CaretToken";
                    SyntaxKind5[SyntaxKind5["ExclamationToken"] = 53] = "ExclamationToken";
                    SyntaxKind5[SyntaxKind5["TildeToken"] = 54] = "TildeToken";
                    SyntaxKind5[SyntaxKind5["AmpersandAmpersandToken"] = 55] = "AmpersandAmpersandToken";
                    SyntaxKind5[SyntaxKind5["BarBarToken"] = 56] = "BarBarToken";
                    SyntaxKind5[SyntaxKind5["QuestionToken"] = 57] = "QuestionToken";
                    SyntaxKind5[SyntaxKind5["ColonToken"] = 58] = "ColonToken";
                    SyntaxKind5[SyntaxKind5["AtToken"] = 59] = "AtToken";
                    SyntaxKind5[SyntaxKind5["QuestionQuestionToken"] = 60] = "QuestionQuestionToken";
                    SyntaxKind5[SyntaxKind5["BacktickToken"] = 61] = "BacktickToken";
                    SyntaxKind5[SyntaxKind5["HashToken"] = 62] = "HashToken";
                    SyntaxKind5[SyntaxKind5["EqualsToken"] = 63] = "EqualsToken";
                    SyntaxKind5[SyntaxKind5["PlusEqualsToken"] = 64] = "PlusEqualsToken";
                    SyntaxKind5[SyntaxKind5["MinusEqualsToken"] = 65] = "MinusEqualsToken";
                    SyntaxKind5[SyntaxKind5["AsteriskEqualsToken"] = 66] = "AsteriskEqualsToken";
                    SyntaxKind5[SyntaxKind5["AsteriskAsteriskEqualsToken"] = 67] = "AsteriskAsteriskEqualsToken";
                    SyntaxKind5[SyntaxKind5["SlashEqualsToken"] = 68] = "SlashEqualsToken";
                    SyntaxKind5[SyntaxKind5["PercentEqualsToken"] = 69] = "PercentEqualsToken";
                    SyntaxKind5[SyntaxKind5["LessThanLessThanEqualsToken"] = 70] = "LessThanLessThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanGreaterThanEqualsToken"] = 71] = "GreaterThanGreaterThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanGreaterThanGreaterThanEqualsToken"] = 72] = "GreaterThanGreaterThanGreaterThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["AmpersandEqualsToken"] = 73] = "AmpersandEqualsToken";
                    SyntaxKind5[SyntaxKind5["BarEqualsToken"] = 74] = "BarEqualsToken";
                    SyntaxKind5[SyntaxKind5["BarBarEqualsToken"] = 75] = "BarBarEqualsToken";
                    SyntaxKind5[SyntaxKind5["AmpersandAmpersandEqualsToken"] = 76] = "AmpersandAmpersandEqualsToken";
                    SyntaxKind5[SyntaxKind5["QuestionQuestionEqualsToken"] = 77] = "QuestionQuestionEqualsToken";
                    SyntaxKind5[SyntaxKind5["CaretEqualsToken"] = 78] = "CaretEqualsToken";
                    SyntaxKind5[SyntaxKind5["Identifier"] = 79] = "Identifier";
                    SyntaxKind5[SyntaxKind5["PrivateIdentifier"] = 80] = "PrivateIdentifier";
                    SyntaxKind5[SyntaxKind5["BreakKeyword"] = 81] = "BreakKeyword";
                    SyntaxKind5[SyntaxKind5["CaseKeyword"] = 82] = "CaseKeyword";
                    SyntaxKind5[SyntaxKind5["CatchKeyword"] = 83] = "CatchKeyword";
                    SyntaxKind5[SyntaxKind5["ClassKeyword"] = 84] = "ClassKeyword";
                    SyntaxKind5[SyntaxKind5["ConstKeyword"] = 85] = "ConstKeyword";
                    SyntaxKind5[SyntaxKind5["ContinueKeyword"] = 86] = "ContinueKeyword";
                    SyntaxKind5[SyntaxKind5["DebuggerKeyword"] = 87] = "DebuggerKeyword";
                    SyntaxKind5[SyntaxKind5["DefaultKeyword"] = 88] = "DefaultKeyword";
                    SyntaxKind5[SyntaxKind5["DeleteKeyword"] = 89] = "DeleteKeyword";
                    SyntaxKind5[SyntaxKind5["DoKeyword"] = 90] = "DoKeyword";
                    SyntaxKind5[SyntaxKind5["ElseKeyword"] = 91] = "ElseKeyword";
                    SyntaxKind5[SyntaxKind5["EnumKeyword"] = 92] = "EnumKeyword";
                    SyntaxKind5[SyntaxKind5["ExportKeyword"] = 93] = "ExportKeyword";
                    SyntaxKind5[SyntaxKind5["ExtendsKeyword"] = 94] = "ExtendsKeyword";
                    SyntaxKind5[SyntaxKind5["FalseKeyword"] = 95] = "FalseKeyword";
                    SyntaxKind5[SyntaxKind5["FinallyKeyword"] = 96] = "FinallyKeyword";
                    SyntaxKind5[SyntaxKind5["ForKeyword"] = 97] = "ForKeyword";
                    SyntaxKind5[SyntaxKind5["FunctionKeyword"] = 98] = "FunctionKeyword";
                    SyntaxKind5[SyntaxKind5["IfKeyword"] = 99] = "IfKeyword";
                    SyntaxKind5[SyntaxKind5["ImportKeyword"] = 100] = "ImportKeyword";
                    SyntaxKind5[SyntaxKind5["InKeyword"] = 101] = "InKeyword";
                    SyntaxKind5[SyntaxKind5["InstanceOfKeyword"] = 102] = "InstanceOfKeyword";
                    SyntaxKind5[SyntaxKind5["NewKeyword"] = 103] = "NewKeyword";
                    SyntaxKind5[SyntaxKind5["NullKeyword"] = 104] = "NullKeyword";
                    SyntaxKind5[SyntaxKind5["ReturnKeyword"] = 105] = "ReturnKeyword";
                    SyntaxKind5[SyntaxKind5["SuperKeyword"] = 106] = "SuperKeyword";
                    SyntaxKind5[SyntaxKind5["SwitchKeyword"] = 107] = "SwitchKeyword";
                    SyntaxKind5[SyntaxKind5["ThisKeyword"] = 108] = "ThisKeyword";
                    SyntaxKind5[SyntaxKind5["ThrowKeyword"] = 109] = "ThrowKeyword";
                    SyntaxKind5[SyntaxKind5["TrueKeyword"] = 110] = "TrueKeyword";
                    SyntaxKind5[SyntaxKind5["TryKeyword"] = 111] = "TryKeyword";
                    SyntaxKind5[SyntaxKind5["TypeOfKeyword"] = 112] = "TypeOfKeyword";
                    SyntaxKind5[SyntaxKind5["VarKeyword"] = 113] = "VarKeyword";
                    SyntaxKind5[SyntaxKind5["VoidKeyword"] = 114] = "VoidKeyword";
                    SyntaxKind5[SyntaxKind5["WhileKeyword"] = 115] = "WhileKeyword";
                    SyntaxKind5[SyntaxKind5["WithKeyword"] = 116] = "WithKeyword";
                    SyntaxKind5[SyntaxKind5["ImplementsKeyword"] = 117] = "ImplementsKeyword";
                    SyntaxKind5[SyntaxKind5["InterfaceKeyword"] = 118] = "InterfaceKeyword";
                    SyntaxKind5[SyntaxKind5["LetKeyword"] = 119] = "LetKeyword";
                    SyntaxKind5[SyntaxKind5["PackageKeyword"] = 120] = "PackageKeyword";
                    SyntaxKind5[SyntaxKind5["PrivateKeyword"] = 121] = "PrivateKeyword";
                    SyntaxKind5[SyntaxKind5["ProtectedKeyword"] = 122] = "ProtectedKeyword";
                    SyntaxKind5[SyntaxKind5["PublicKeyword"] = 123] = "PublicKeyword";
                    SyntaxKind5[SyntaxKind5["StaticKeyword"] = 124] = "StaticKeyword";
                    SyntaxKind5[SyntaxKind5["YieldKeyword"] = 125] = "YieldKeyword";
                    SyntaxKind5[SyntaxKind5["AbstractKeyword"] = 126] = "AbstractKeyword";
                    SyntaxKind5[SyntaxKind5["AccessorKeyword"] = 127] = "AccessorKeyword";
                    SyntaxKind5[SyntaxKind5["AsKeyword"] = 128] = "AsKeyword";
                    SyntaxKind5[SyntaxKind5["AssertsKeyword"] = 129] = "AssertsKeyword";
                    SyntaxKind5[SyntaxKind5["AssertKeyword"] = 130] = "AssertKeyword";
                    SyntaxKind5[SyntaxKind5["AnyKeyword"] = 131] = "AnyKeyword";
                    SyntaxKind5[SyntaxKind5["AsyncKeyword"] = 132] = "AsyncKeyword";
                    SyntaxKind5[SyntaxKind5["AwaitKeyword"] = 133] = "AwaitKeyword";
                    SyntaxKind5[SyntaxKind5["BooleanKeyword"] = 134] = "BooleanKeyword";
                    SyntaxKind5[SyntaxKind5["ConstructorKeyword"] = 135] = "ConstructorKeyword";
                    SyntaxKind5[SyntaxKind5["DeclareKeyword"] = 136] = "DeclareKeyword";
                    SyntaxKind5[SyntaxKind5["GetKeyword"] = 137] = "GetKeyword";
                    SyntaxKind5[SyntaxKind5["InferKeyword"] = 138] = "InferKeyword";
                    SyntaxKind5[SyntaxKind5["IntrinsicKeyword"] = 139] = "IntrinsicKeyword";
                    SyntaxKind5[SyntaxKind5["IsKeyword"] = 140] = "IsKeyword";
                    SyntaxKind5[SyntaxKind5["KeyOfKeyword"] = 141] = "KeyOfKeyword";
                    SyntaxKind5[SyntaxKind5["ModuleKeyword"] = 142] = "ModuleKeyword";
                    SyntaxKind5[SyntaxKind5["NamespaceKeyword"] = 143] = "NamespaceKeyword";
                    SyntaxKind5[SyntaxKind5["NeverKeyword"] = 144] = "NeverKeyword";
                    SyntaxKind5[SyntaxKind5["OutKeyword"] = 145] = "OutKeyword";
                    SyntaxKind5[SyntaxKind5["ReadonlyKeyword"] = 146] = "ReadonlyKeyword";
                    SyntaxKind5[SyntaxKind5["RequireKeyword"] = 147] = "RequireKeyword";
                    SyntaxKind5[SyntaxKind5["NumberKeyword"] = 148] = "NumberKeyword";
                    SyntaxKind5[SyntaxKind5["ObjectKeyword"] = 149] = "ObjectKeyword";
                    SyntaxKind5[SyntaxKind5["SatisfiesKeyword"] = 150] = "SatisfiesKeyword";
                    SyntaxKind5[SyntaxKind5["SetKeyword"] = 151] = "SetKeyword";
                    SyntaxKind5[SyntaxKind5["StringKeyword"] = 152] = "StringKeyword";
                    SyntaxKind5[SyntaxKind5["SymbolKeyword"] = 153] = "SymbolKeyword";
                    SyntaxKind5[SyntaxKind5["TypeKeyword"] = 154] = "TypeKeyword";
                    SyntaxKind5[SyntaxKind5["UndefinedKeyword"] = 155] = "UndefinedKeyword";
                    SyntaxKind5[SyntaxKind5["UniqueKeyword"] = 156] = "UniqueKeyword";
                    SyntaxKind5[SyntaxKind5["UnknownKeyword"] = 157] = "UnknownKeyword";
                    SyntaxKind5[SyntaxKind5["FromKeyword"] = 158] = "FromKeyword";
                    SyntaxKind5[SyntaxKind5["GlobalKeyword"] = 159] = "GlobalKeyword";
                    SyntaxKind5[SyntaxKind5["BigIntKeyword"] = 160] = "BigIntKeyword";
                    SyntaxKind5[SyntaxKind5["OverrideKeyword"] = 161] = "OverrideKeyword";
                    SyntaxKind5[SyntaxKind5["OfKeyword"] = 162] = "OfKeyword";
                    SyntaxKind5[SyntaxKind5["QualifiedName"] = 163] = "QualifiedName";
                    SyntaxKind5[SyntaxKind5["ComputedPropertyName"] = 164] = "ComputedPropertyName";
                    SyntaxKind5[SyntaxKind5["TypeParameter"] = 165] = "TypeParameter";
                    SyntaxKind5[SyntaxKind5["Parameter"] = 166] = "Parameter";
                    SyntaxKind5[SyntaxKind5["Decorator"] = 167] = "Decorator";
                    SyntaxKind5[SyntaxKind5["PropertySignature"] = 168] = "PropertySignature";
                    SyntaxKind5[SyntaxKind5["PropertyDeclaration"] = 169] = "PropertyDeclaration";
                    SyntaxKind5[SyntaxKind5["MethodSignature"] = 170] = "MethodSignature";
                    SyntaxKind5[SyntaxKind5["MethodDeclaration"] = 171] = "MethodDeclaration";
                    SyntaxKind5[SyntaxKind5["ClassStaticBlockDeclaration"] = 172] = "ClassStaticBlockDeclaration";
                    SyntaxKind5[SyntaxKind5["Constructor"] = 173] = "Constructor";
                    SyntaxKind5[SyntaxKind5["GetAccessor"] = 174] = "GetAccessor";
                    SyntaxKind5[SyntaxKind5["SetAccessor"] = 175] = "SetAccessor";
                    SyntaxKind5[SyntaxKind5["CallSignature"] = 176] = "CallSignature";
                    SyntaxKind5[SyntaxKind5["ConstructSignature"] = 177] = "ConstructSignature";
                    SyntaxKind5[SyntaxKind5["IndexSignature"] = 178] = "IndexSignature";
                    SyntaxKind5[SyntaxKind5["TypePredicate"] = 179] = "TypePredicate";
                    SyntaxKind5[SyntaxKind5["TypeReference"] = 180] = "TypeReference";
                    SyntaxKind5[SyntaxKind5["FunctionType"] = 181] = "FunctionType";
                    SyntaxKind5[SyntaxKind5["ConstructorType"] = 182] = "ConstructorType";
                    SyntaxKind5[SyntaxKind5["TypeQuery"] = 183] = "TypeQuery";
                    SyntaxKind5[SyntaxKind5["TypeLiteral"] = 184] = "TypeLiteral";
                    SyntaxKind5[SyntaxKind5["ArrayType"] = 185] = "ArrayType";
                    SyntaxKind5[SyntaxKind5["TupleType"] = 186] = "TupleType";
                    SyntaxKind5[SyntaxKind5["OptionalType"] = 187] = "OptionalType";
                    SyntaxKind5[SyntaxKind5["RestType"] = 188] = "RestType";
                    SyntaxKind5[SyntaxKind5["UnionType"] = 189] = "UnionType";
                    SyntaxKind5[SyntaxKind5["IntersectionType"] = 190] = "IntersectionType";
                    SyntaxKind5[SyntaxKind5["ConditionalType"] = 191] = "ConditionalType";
                    SyntaxKind5[SyntaxKind5["InferType"] = 192] = "InferType";
                    SyntaxKind5[SyntaxKind5["ParenthesizedType"] = 193] = "ParenthesizedType";
                    SyntaxKind5[SyntaxKind5["ThisType"] = 194] = "ThisType";
                    SyntaxKind5[SyntaxKind5["TypeOperator"] = 195] = "TypeOperator";
                    SyntaxKind5[SyntaxKind5["IndexedAccessType"] = 196] = "IndexedAccessType";
                    SyntaxKind5[SyntaxKind5["MappedType"] = 197] = "MappedType";
                    SyntaxKind5[SyntaxKind5["LiteralType"] = 198] = "LiteralType";
                    SyntaxKind5[SyntaxKind5["NamedTupleMember"] = 199] = "NamedTupleMember";
                    SyntaxKind5[SyntaxKind5["TemplateLiteralType"] = 200] = "TemplateLiteralType";
                    SyntaxKind5[SyntaxKind5["TemplateLiteralTypeSpan"] = 201] = "TemplateLiteralTypeSpan";
                    SyntaxKind5[SyntaxKind5["ImportType"] = 202] = "ImportType";
                    SyntaxKind5[SyntaxKind5["ObjectBindingPattern"] = 203] = "ObjectBindingPattern";
                    SyntaxKind5[SyntaxKind5["ArrayBindingPattern"] = 204] = "ArrayBindingPattern";
                    SyntaxKind5[SyntaxKind5["BindingElement"] = 205] = "BindingElement";
                    SyntaxKind5[SyntaxKind5["ArrayLiteralExpression"] = 206] = "ArrayLiteralExpression";
                    SyntaxKind5[SyntaxKind5["ObjectLiteralExpression"] = 207] = "ObjectLiteralExpression";
                    SyntaxKind5[SyntaxKind5["PropertyAccessExpression"] = 208] = "PropertyAccessExpression";
                    SyntaxKind5[SyntaxKind5["ElementAccessExpression"] = 209] = "ElementAccessExpression";
                    SyntaxKind5[SyntaxKind5["CallExpression"] = 210] = "CallExpression";
                    SyntaxKind5[SyntaxKind5["NewExpression"] = 211] = "NewExpression";
                    SyntaxKind5[SyntaxKind5["TaggedTemplateExpression"] = 212] = "TaggedTemplateExpression";
                    SyntaxKind5[SyntaxKind5["TypeAssertionExpression"] = 213] = "TypeAssertionExpression";
                    SyntaxKind5[SyntaxKind5["ParenthesizedExpression"] = 214] = "ParenthesizedExpression";
                    SyntaxKind5[SyntaxKind5["FunctionExpression"] = 215] = "FunctionExpression";
                    SyntaxKind5[SyntaxKind5["ArrowFunction"] = 216] = "ArrowFunction";
                    SyntaxKind5[SyntaxKind5["DeleteExpression"] = 217] = "DeleteExpression";
                    SyntaxKind5[SyntaxKind5["TypeOfExpression"] = 218] = "TypeOfExpression";
                    SyntaxKind5[SyntaxKind5["VoidExpression"] = 219] = "VoidExpression";
                    SyntaxKind5[SyntaxKind5["AwaitExpression"] = 220] = "AwaitExpression";
                    SyntaxKind5[SyntaxKind5["PrefixUnaryExpression"] = 221] = "PrefixUnaryExpression";
                    SyntaxKind5[SyntaxKind5["PostfixUnaryExpression"] = 222] = "PostfixUnaryExpression";
                    SyntaxKind5[SyntaxKind5["BinaryExpression"] = 223] = "BinaryExpression";
                    SyntaxKind5[SyntaxKind5["ConditionalExpression"] = 224] = "ConditionalExpression";
                    SyntaxKind5[SyntaxKind5["TemplateExpression"] = 225] = "TemplateExpression";
                    SyntaxKind5[SyntaxKind5["YieldExpression"] = 226] = "YieldExpression";
                    SyntaxKind5[SyntaxKind5["SpreadElement"] = 227] = "SpreadElement";
                    SyntaxKind5[SyntaxKind5["ClassExpression"] = 228] = "ClassExpression";
                    SyntaxKind5[SyntaxKind5["OmittedExpression"] = 229] = "OmittedExpression";
                    SyntaxKind5[SyntaxKind5["ExpressionWithTypeArguments"] = 230] = "ExpressionWithTypeArguments";
                    SyntaxKind5[SyntaxKind5["AsExpression"] = 231] = "AsExpression";
                    SyntaxKind5[SyntaxKind5["NonNullExpression"] = 232] = "NonNullExpression";
                    SyntaxKind5[SyntaxKind5["MetaProperty"] = 233] = "MetaProperty";
                    SyntaxKind5[SyntaxKind5["SyntheticExpression"] = 234] = "SyntheticExpression";
                    SyntaxKind5[SyntaxKind5["SatisfiesExpression"] = 235] = "SatisfiesExpression";
                    SyntaxKind5[SyntaxKind5["TemplateSpan"] = 236] = "TemplateSpan";
                    SyntaxKind5[SyntaxKind5["SemicolonClassElement"] = 237] = "SemicolonClassElement";
                    SyntaxKind5[SyntaxKind5["Block"] = 238] = "Block";
                    SyntaxKind5[SyntaxKind5["EmptyStatement"] = 239] = "EmptyStatement";
                    SyntaxKind5[SyntaxKind5["VariableStatement"] = 240] = "VariableStatement";
                    SyntaxKind5[SyntaxKind5["ExpressionStatement"] = 241] = "ExpressionStatement";
                    SyntaxKind5[SyntaxKind5["IfStatement"] = 242] = "IfStatement";
                    SyntaxKind5[SyntaxKind5["DoStatement"] = 243] = "DoStatement";
                    SyntaxKind5[SyntaxKind5["WhileStatement"] = 244] = "WhileStatement";
                    SyntaxKind5[SyntaxKind5["ForStatement"] = 245] = "ForStatement";
                    SyntaxKind5[SyntaxKind5["ForInStatement"] = 246] = "ForInStatement";
                    SyntaxKind5[SyntaxKind5["ForOfStatement"] = 247] = "ForOfStatement";
                    SyntaxKind5[SyntaxKind5["ContinueStatement"] = 248] = "ContinueStatement";
                    SyntaxKind5[SyntaxKind5["BreakStatement"] = 249] = "BreakStatement";
                    SyntaxKind5[SyntaxKind5["ReturnStatement"] = 250] = "ReturnStatement";
                    SyntaxKind5[SyntaxKind5["WithStatement"] = 251] = "WithStatement";
                    SyntaxKind5[SyntaxKind5["SwitchStatement"] = 252] = "SwitchStatement";
                    SyntaxKind5[SyntaxKind5["LabeledStatement"] = 253] = "LabeledStatement";
                    SyntaxKind5[SyntaxKind5["ThrowStatement"] = 254] = "ThrowStatement";
                    SyntaxKind5[SyntaxKind5["TryStatement"] = 255] = "TryStatement";
                    SyntaxKind5[SyntaxKind5["DebuggerStatement"] = 256] = "DebuggerStatement";
                    SyntaxKind5[SyntaxKind5["VariableDeclaration"] = 257] = "VariableDeclaration";
                    SyntaxKind5[SyntaxKind5["VariableDeclarationList"] = 258] = "VariableDeclarationList";
                    SyntaxKind5[SyntaxKind5["FunctionDeclaration"] = 259] = "FunctionDeclaration";
                    SyntaxKind5[SyntaxKind5["ClassDeclaration"] = 260] = "ClassDeclaration";
                    SyntaxKind5[SyntaxKind5["InterfaceDeclaration"] = 261] = "InterfaceDeclaration";
                    SyntaxKind5[SyntaxKind5["TypeAliasDeclaration"] = 262] = "TypeAliasDeclaration";
                    SyntaxKind5[SyntaxKind5["EnumDeclaration"] = 263] = "EnumDeclaration";
                    SyntaxKind5[SyntaxKind5["ModuleDeclaration"] = 264] = "ModuleDeclaration";
                    SyntaxKind5[SyntaxKind5["ModuleBlock"] = 265] = "ModuleBlock";
                    SyntaxKind5[SyntaxKind5["CaseBlock"] = 266] = "CaseBlock";
                    SyntaxKind5[SyntaxKind5["NamespaceExportDeclaration"] = 267] = "NamespaceExportDeclaration";
                    SyntaxKind5[SyntaxKind5["ImportEqualsDeclaration"] = 268] = "ImportEqualsDeclaration";
                    SyntaxKind5[SyntaxKind5["ImportDeclaration"] = 269] = "ImportDeclaration";
                    SyntaxKind5[SyntaxKind5["ImportClause"] = 270] = "ImportClause";
                    SyntaxKind5[SyntaxKind5["NamespaceImport"] = 271] = "NamespaceImport";
                    SyntaxKind5[SyntaxKind5["NamedImports"] = 272] = "NamedImports";
                    SyntaxKind5[SyntaxKind5["ImportSpecifier"] = 273] = "ImportSpecifier";
                    SyntaxKind5[SyntaxKind5["ExportAssignment"] = 274] = "ExportAssignment";
                    SyntaxKind5[SyntaxKind5["ExportDeclaration"] = 275] = "ExportDeclaration";
                    SyntaxKind5[SyntaxKind5["NamedExports"] = 276] = "NamedExports";
                    SyntaxKind5[SyntaxKind5["NamespaceExport"] = 277] = "NamespaceExport";
                    SyntaxKind5[SyntaxKind5["ExportSpecifier"] = 278] = "ExportSpecifier";
                    SyntaxKind5[SyntaxKind5["MissingDeclaration"] = 279] = "MissingDeclaration";
                    SyntaxKind5[SyntaxKind5["ExternalModuleReference"] = 280] = "ExternalModuleReference";
                    SyntaxKind5[SyntaxKind5["JsxElement"] = 281] = "JsxElement";
                    SyntaxKind5[SyntaxKind5["JsxSelfClosingElement"] = 282] = "JsxSelfClosingElement";
                    SyntaxKind5[SyntaxKind5["JsxOpeningElement"] = 283] = "JsxOpeningElement";
                    SyntaxKind5[SyntaxKind5["JsxClosingElement"] = 284] = "JsxClosingElement";
                    SyntaxKind5[SyntaxKind5["JsxFragment"] = 285] = "JsxFragment";
                    SyntaxKind5[SyntaxKind5["JsxOpeningFragment"] = 286] = "JsxOpeningFragment";
                    SyntaxKind5[SyntaxKind5["JsxClosingFragment"] = 287] = "JsxClosingFragment";
                    SyntaxKind5[SyntaxKind5["JsxAttribute"] = 288] = "JsxAttribute";
                    SyntaxKind5[SyntaxKind5["JsxAttributes"] = 289] = "JsxAttributes";
                    SyntaxKind5[SyntaxKind5["JsxSpreadAttribute"] = 290] = "JsxSpreadAttribute";
                    SyntaxKind5[SyntaxKind5["JsxExpression"] = 291] = "JsxExpression";
                    SyntaxKind5[SyntaxKind5["CaseClause"] = 292] = "CaseClause";
                    SyntaxKind5[SyntaxKind5["DefaultClause"] = 293] = "DefaultClause";
                    SyntaxKind5[SyntaxKind5["HeritageClause"] = 294] = "HeritageClause";
                    SyntaxKind5[SyntaxKind5["CatchClause"] = 295] = "CatchClause";
                    SyntaxKind5[SyntaxKind5["AssertClause"] = 296] = "AssertClause";
                    SyntaxKind5[SyntaxKind5["AssertEntry"] = 297] = "AssertEntry";
                    SyntaxKind5[SyntaxKind5["ImportTypeAssertionContainer"] = 298] = "ImportTypeAssertionContainer";
                    SyntaxKind5[SyntaxKind5["PropertyAssignment"] = 299] = "PropertyAssignment";
                    SyntaxKind5[SyntaxKind5["ShorthandPropertyAssignment"] = 300] = "ShorthandPropertyAssignment";
                    SyntaxKind5[SyntaxKind5["SpreadAssignment"] = 301] = "SpreadAssignment";
                    SyntaxKind5[SyntaxKind5["EnumMember"] = 302] = "EnumMember";
                    SyntaxKind5[SyntaxKind5["UnparsedPrologue"] = 303] = "UnparsedPrologue";
                    SyntaxKind5[SyntaxKind5["UnparsedPrepend"] = 304] = "UnparsedPrepend";
                    SyntaxKind5[SyntaxKind5["UnparsedText"] = 305] = "UnparsedText";
                    SyntaxKind5[SyntaxKind5["UnparsedInternalText"] = 306] = "UnparsedInternalText";
                    SyntaxKind5[SyntaxKind5["UnparsedSyntheticReference"] = 307] = "UnparsedSyntheticReference";
                    SyntaxKind5[SyntaxKind5["SourceFile"] = 308] = "SourceFile";
                    SyntaxKind5[SyntaxKind5["Bundle"] = 309] = "Bundle";
                    SyntaxKind5[SyntaxKind5["UnparsedSource"] = 310] = "UnparsedSource";
                    SyntaxKind5[SyntaxKind5["InputFiles"] = 311] = "InputFiles";
                    SyntaxKind5[SyntaxKind5["JSDocTypeExpression"] = 312] = "JSDocTypeExpression";
                    SyntaxKind5[SyntaxKind5["JSDocNameReference"] = 313] = "JSDocNameReference";
                    SyntaxKind5[SyntaxKind5["JSDocMemberName"] = 314] = "JSDocMemberName";
                    SyntaxKind5[SyntaxKind5["JSDocAllType"] = 315] = "JSDocAllType";
                    SyntaxKind5[SyntaxKind5["JSDocUnknownType"] = 316] = "JSDocUnknownType";
                    SyntaxKind5[SyntaxKind5["JSDocNullableType"] = 317] = "JSDocNullableType";
                    SyntaxKind5[SyntaxKind5["JSDocNonNullableType"] = 318] = "JSDocNonNullableType";
                    SyntaxKind5[SyntaxKind5["JSDocOptionalType"] = 319] = "JSDocOptionalType";
                    SyntaxKind5[SyntaxKind5["JSDocFunctionType"] = 320] = "JSDocFunctionType";
                    SyntaxKind5[SyntaxKind5["JSDocVariadicType"] = 321] = "JSDocVariadicType";
                    SyntaxKind5[SyntaxKind5["JSDocNamepathType"] = 322] = "JSDocNamepathType";
                    SyntaxKind5[SyntaxKind5["JSDoc"] = 323] = "JSDoc";
                    SyntaxKind5[SyntaxKind5["JSDocComment"] = 323 /* JSDoc */] = "JSDocComment";
                    SyntaxKind5[SyntaxKind5["JSDocText"] = 324] = "JSDocText";
                    SyntaxKind5[SyntaxKind5["JSDocTypeLiteral"] = 325] = "JSDocTypeLiteral";
                    SyntaxKind5[SyntaxKind5["JSDocSignature"] = 326] = "JSDocSignature";
                    SyntaxKind5[SyntaxKind5["JSDocLink"] = 327] = "JSDocLink";
                    SyntaxKind5[SyntaxKind5["JSDocLinkCode"] = 328] = "JSDocLinkCode";
                    SyntaxKind5[SyntaxKind5["JSDocLinkPlain"] = 329] = "JSDocLinkPlain";
                    SyntaxKind5[SyntaxKind5["JSDocTag"] = 330] = "JSDocTag";
                    SyntaxKind5[SyntaxKind5["JSDocAugmentsTag"] = 331] = "JSDocAugmentsTag";
                    SyntaxKind5[SyntaxKind5["JSDocImplementsTag"] = 332] = "JSDocImplementsTag";
                    SyntaxKind5[SyntaxKind5["JSDocAuthorTag"] = 333] = "JSDocAuthorTag";
                    SyntaxKind5[SyntaxKind5["JSDocDeprecatedTag"] = 334] = "JSDocDeprecatedTag";
                    SyntaxKind5[SyntaxKind5["JSDocClassTag"] = 335] = "JSDocClassTag";
                    SyntaxKind5[SyntaxKind5["JSDocPublicTag"] = 336] = "JSDocPublicTag";
                    SyntaxKind5[SyntaxKind5["JSDocPrivateTag"] = 337] = "JSDocPrivateTag";
                    SyntaxKind5[SyntaxKind5["JSDocProtectedTag"] = 338] = "JSDocProtectedTag";
                    SyntaxKind5[SyntaxKind5["JSDocReadonlyTag"] = 339] = "JSDocReadonlyTag";
                    SyntaxKind5[SyntaxKind5["JSDocOverrideTag"] = 340] = "JSDocOverrideTag";
                    SyntaxKind5[SyntaxKind5["JSDocCallbackTag"] = 341] = "JSDocCallbackTag";
                    SyntaxKind5[SyntaxKind5["JSDocOverloadTag"] = 342] = "JSDocOverloadTag";
                    SyntaxKind5[SyntaxKind5["JSDocEnumTag"] = 343] = "JSDocEnumTag";
                    SyntaxKind5[SyntaxKind5["JSDocParameterTag"] = 344] = "JSDocParameterTag";
                    SyntaxKind5[SyntaxKind5["JSDocReturnTag"] = 345] = "JSDocReturnTag";
                    SyntaxKind5[SyntaxKind5["JSDocThisTag"] = 346] = "JSDocThisTag";
                    SyntaxKind5[SyntaxKind5["JSDocTypeTag"] = 347] = "JSDocTypeTag";
                    SyntaxKind5[SyntaxKind5["JSDocTemplateTag"] = 348] = "JSDocTemplateTag";
                    SyntaxKind5[SyntaxKind5["JSDocTypedefTag"] = 349] = "JSDocTypedefTag";
                    SyntaxKind5[SyntaxKind5["JSDocSeeTag"] = 350] = "JSDocSeeTag";
                    SyntaxKind5[SyntaxKind5["JSDocPropertyTag"] = 351] = "JSDocPropertyTag";
                    SyntaxKind5[SyntaxKind5["JSDocThrowsTag"] = 352] = "JSDocThrowsTag";
                    SyntaxKind5[SyntaxKind5["JSDocSatisfiesTag"] = 353] = "JSDocSatisfiesTag";
                    SyntaxKind5[SyntaxKind5["SyntaxList"] = 354] = "SyntaxList";
                    SyntaxKind5[SyntaxKind5["NotEmittedStatement"] = 355] = "NotEmittedStatement";
                    SyntaxKind5[SyntaxKind5["PartiallyEmittedExpression"] = 356] = "PartiallyEmittedExpression";
                    SyntaxKind5[SyntaxKind5["CommaListExpression"] = 357] = "CommaListExpression";
                    SyntaxKind5[SyntaxKind5["MergeDeclarationMarker"] = 358] = "MergeDeclarationMarker";
                    SyntaxKind5[SyntaxKind5["EndOfDeclarationMarker"] = 359] = "EndOfDeclarationMarker";
                    SyntaxKind5[SyntaxKind5["SyntheticReferenceExpression"] = 360] = "SyntheticReferenceExpression";
                    SyntaxKind5[SyntaxKind5["Count"] = 361] = "Count";
                    SyntaxKind5[SyntaxKind5["FirstAssignment"] = 63 /* EqualsToken */] = "FirstAssignment";
                    SyntaxKind5[SyntaxKind5["LastAssignment"] = 78 /* CaretEqualsToken */] = "LastAssignment";
                    SyntaxKind5[SyntaxKind5["FirstCompoundAssignment"] = 64 /* PlusEqualsToken */] = "FirstCompoundAssignment";
                    SyntaxKind5[SyntaxKind5["LastCompoundAssignment"] = 78 /* CaretEqualsToken */] = "LastCompoundAssignment";
                    SyntaxKind5[SyntaxKind5["FirstReservedWord"] = 81 /* BreakKeyword */] = "FirstReservedWord";
                    SyntaxKind5[SyntaxKind5["LastReservedWord"] = 116 /* WithKeyword */] = "LastReservedWord";
                    SyntaxKind5[SyntaxKind5["FirstKeyword"] = 81 /* BreakKeyword */] = "FirstKeyword";
                    SyntaxKind5[SyntaxKind5["LastKeyword"] = 162 /* OfKeyword */] = "LastKeyword";
                    SyntaxKind5[SyntaxKind5["FirstFutureReservedWord"] = 117 /* ImplementsKeyword */] = "FirstFutureReservedWord";
                    SyntaxKind5[SyntaxKind5["LastFutureReservedWord"] = 125 /* YieldKeyword */] = "LastFutureReservedWord";
                    SyntaxKind5[SyntaxKind5["FirstTypeNode"] = 179 /* TypePredicate */] = "FirstTypeNode";
                    SyntaxKind5[SyntaxKind5["LastTypeNode"] = 202 /* ImportType */] = "LastTypeNode";
                    SyntaxKind5[SyntaxKind5["FirstPunctuation"] = 18 /* OpenBraceToken */] = "FirstPunctuation";
                    SyntaxKind5[SyntaxKind5["LastPunctuation"] = 78 /* CaretEqualsToken */] = "LastPunctuation";
                    SyntaxKind5[SyntaxKind5["FirstToken"] = 0 /* Unknown */] = "FirstToken";
                    SyntaxKind5[SyntaxKind5["LastToken"] = 162 /* LastKeyword */] = "LastToken";
                    SyntaxKind5[SyntaxKind5["FirstTriviaToken"] = 2 /* SingleLineCommentTrivia */] = "FirstTriviaToken";
                    SyntaxKind5[SyntaxKind5["LastTriviaToken"] = 7 /* ConflictMarkerTrivia */] = "LastTriviaToken";
                    SyntaxKind5[SyntaxKind5["FirstLiteralToken"] = 8 /* NumericLiteral */] = "FirstLiteralToken";
                    SyntaxKind5[SyntaxKind5["LastLiteralToken"] = 14 /* NoSubstitutionTemplateLiteral */] = "LastLiteralToken";
                    SyntaxKind5[SyntaxKind5["FirstTemplateToken"] = 14 /* NoSubstitutionTemplateLiteral */] = "FirstTemplateToken";
                    SyntaxKind5[SyntaxKind5["LastTemplateToken"] = 17 /* TemplateTail */] = "LastTemplateToken";
                    SyntaxKind5[SyntaxKind5["FirstBinaryOperator"] = 29 /* LessThanToken */] = "FirstBinaryOperator";
                    SyntaxKind5[SyntaxKind5["LastBinaryOperator"] = 78 /* CaretEqualsToken */] = "LastBinaryOperator";
                    SyntaxKind5[SyntaxKind5["FirstStatement"] = 240 /* VariableStatement */] = "FirstStatement";
                    SyntaxKind5[SyntaxKind5["LastStatement"] = 256 /* DebuggerStatement */] = "LastStatement";
                    SyntaxKind5[SyntaxKind5["FirstNode"] = 163 /* QualifiedName */] = "FirstNode";
                    SyntaxKind5[SyntaxKind5["FirstJSDocNode"] = 312 /* JSDocTypeExpression */] = "FirstJSDocNode";
                    SyntaxKind5[SyntaxKind5["LastJSDocNode"] = 353 /* JSDocSatisfiesTag */] = "LastJSDocNode";
                    SyntaxKind5[SyntaxKind5["FirstJSDocTagNode"] = 330 /* JSDocTag */] = "FirstJSDocTagNode";
                    SyntaxKind5[SyntaxKind5["LastJSDocTagNode"] = 353 /* JSDocSatisfiesTag */] = "LastJSDocTagNode";
                    SyntaxKind5[SyntaxKind5["FirstContextualKeyword"] = 126 /* AbstractKeyword */] = "FirstContextualKeyword";
                    SyntaxKind5[SyntaxKind5["LastContextualKeyword"] = 162 /* OfKeyword */] = "LastContextualKeyword";
                    return SyntaxKind5;
                })(SyntaxKind || {});
                NodeFlags = /* @__PURE__ */ ((NodeFlags3) => {
                    NodeFlags3[NodeFlags3["None"] = 0] = "None";
                    NodeFlags3[NodeFlags3["Let"] = 1] = "Let";
                    NodeFlags3[NodeFlags3["Const"] = 2] = "Const";
                    NodeFlags3[NodeFlags3["NestedNamespace"] = 4] = "NestedNamespace";
                    NodeFlags3[NodeFlags3["Synthesized"] = 8] = "Synthesized";
                    NodeFlags3[NodeFlags3["Namespace"] = 16] = "Namespace";
                    NodeFlags3[NodeFlags3["OptionalChain"] = 32] = "OptionalChain";
                    NodeFlags3[NodeFlags3["ExportContext"] = 64] = "ExportContext";
                    NodeFlags3[NodeFlags3["ContainsThis"] = 128] = "ContainsThis";
                    NodeFlags3[NodeFlags3["HasImplicitReturn"] = 256] = "HasImplicitReturn";
                    NodeFlags3[NodeFlags3["HasExplicitReturn"] = 512] = "HasExplicitReturn";
                    NodeFlags3[NodeFlags3["GlobalAugmentation"] = 1024] = "GlobalAugmentation";
                    NodeFlags3[NodeFlags3["HasAsyncFunctions"] = 2048] = "HasAsyncFunctions";
                    NodeFlags3[NodeFlags3["DisallowInContext"] = 4096] = "DisallowInContext";
                    NodeFlags3[NodeFlags3["YieldContext"] = 8192] = "YieldContext";
                    NodeFlags3[NodeFlags3["DecoratorContext"] = 16384] = "DecoratorContext";
                    NodeFlags3[NodeFlags3["AwaitContext"] = 32768] = "AwaitContext";
                    NodeFlags3[NodeFlags3["DisallowConditionalTypesContext"] = 65536] = "DisallowConditionalTypesContext";
                    NodeFlags3[NodeFlags3["ThisNodeHasError"] = 131072] = "ThisNodeHasError";
                    NodeFlags3[NodeFlags3["JavaScriptFile"] = 262144] = "JavaScriptFile";
                    NodeFlags3[NodeFlags3["ThisNodeOrAnySubNodesHasError"] = 524288] = "ThisNodeOrAnySubNodesHasError";
                    NodeFlags3[NodeFlags3["HasAggregatedChildData"] = 1048576] = "HasAggregatedChildData";
                    NodeFlags3[NodeFlags3["PossiblyContainsDynamicImport"] = 2097152] = "PossiblyContainsDynamicImport";
                    NodeFlags3[NodeFlags3["PossiblyContainsImportMeta"] = 4194304] = "PossiblyContainsImportMeta";
                    NodeFlags3[NodeFlags3["JSDoc"] = 8388608] = "JSDoc";
                    NodeFlags3[NodeFlags3["Ambient"] = 16777216] = "Ambient";
                    NodeFlags3[NodeFlags3["InWithStatement"] = 33554432] = "InWithStatement";
                    NodeFlags3[NodeFlags3["JsonFile"] = 67108864] = "JsonFile";
                    NodeFlags3[NodeFlags3["TypeCached"] = 134217728] = "TypeCached";
                    NodeFlags3[NodeFlags3["Deprecated"] = 268435456] = "Deprecated";
                    NodeFlags3[NodeFlags3["BlockScoped"] = 3] = "BlockScoped";
                    NodeFlags3[NodeFlags3["ReachabilityCheckFlags"] = 768] = "ReachabilityCheckFlags";
                    NodeFlags3[NodeFlags3["ReachabilityAndEmitFlags"] = 2816] = "ReachabilityAndEmitFlags";
                    NodeFlags3[NodeFlags3["ContextFlags"] = 50720768] = "ContextFlags";
                    NodeFlags3[NodeFlags3["TypeExcludesFlags"] = 40960] = "TypeExcludesFlags";
                    NodeFlags3[NodeFlags3["PermanentlySetIncrementalFlags"] = 6291456] = "PermanentlySetIncrementalFlags";
                    NodeFlags3[NodeFlags3["IdentifierHasExtendedUnicodeEscape"] = 128 /* ContainsThis */] = "IdentifierHasExtendedUnicodeEscape";
                    NodeFlags3[NodeFlags3["IdentifierIsInJSDocNamespace"] = 2048 /* HasAsyncFunctions */] = "IdentifierIsInJSDocNamespace";
                    return NodeFlags3;
                })(NodeFlags || {});
                ModifierFlags = /* @__PURE__ */ ((ModifierFlags3) => {
                    ModifierFlags3[ModifierFlags3["None"] = 0] = "None";
                    ModifierFlags3[ModifierFlags3["Export"] = 1] = "Export";
                    ModifierFlags3[ModifierFlags3["Ambient"] = 2] = "Ambient";
                    ModifierFlags3[ModifierFlags3["Public"] = 4] = "Public";
                    ModifierFlags3[ModifierFlags3["Private"] = 8] = "Private";
                    ModifierFlags3[ModifierFlags3["Protected"] = 16] = "Protected";
                    ModifierFlags3[ModifierFlags3["Static"] = 32] = "Static";
                    ModifierFlags3[ModifierFlags3["Readonly"] = 64] = "Readonly";
                    ModifierFlags3[ModifierFlags3["Accessor"] = 128] = "Accessor";
                    ModifierFlags3[ModifierFlags3["Abstract"] = 256] = "Abstract";
                    ModifierFlags3[ModifierFlags3["Async"] = 512] = "Async";
                    ModifierFlags3[ModifierFlags3["Default"] = 1024] = "Default";
                    ModifierFlags3[ModifierFlags3["Const"] = 2048] = "Const";
                    ModifierFlags3[ModifierFlags3["HasComputedJSDocModifiers"] = 4096] = "HasComputedJSDocModifiers";
                    ModifierFlags3[ModifierFlags3["Deprecated"] = 8192] = "Deprecated";
                    ModifierFlags3[ModifierFlags3["Override"] = 16384] = "Override";
                    ModifierFlags3[ModifierFlags3["In"] = 32768] = "In";
                    ModifierFlags3[ModifierFlags3["Out"] = 65536] = "Out";
                    ModifierFlags3[ModifierFlags3["Decorator"] = 131072] = "Decorator";
                    ModifierFlags3[ModifierFlags3["HasComputedFlags"] = 536870912] = "HasComputedFlags";
                    ModifierFlags3[ModifierFlags3["AccessibilityModifier"] = 28] = "AccessibilityModifier";
                    ModifierFlags3[ModifierFlags3["ParameterPropertyModifier"] = 16476] = "ParameterPropertyModifier";
                    ModifierFlags3[ModifierFlags3["NonPublicAccessibilityModifier"] = 24] = "NonPublicAccessibilityModifier";
                    ModifierFlags3[ModifierFlags3["TypeScriptModifier"] = 117086] = "TypeScriptModifier";
                    ModifierFlags3[ModifierFlags3["ExportDefault"] = 1025] = "ExportDefault";
                    ModifierFlags3[ModifierFlags3["All"] = 258047] = "All";
                    ModifierFlags3[ModifierFlags3["Modifier"] = 126975] = "Modifier";
                    return ModifierFlags3;
                })(ModifierFlags || {});
                JsxFlags = /* @__PURE__ */ ((JsxFlags2) => {
                    JsxFlags2[JsxFlags2["None"] = 0] = "None";
                    JsxFlags2[JsxFlags2["IntrinsicNamedElement"] = 1] = "IntrinsicNamedElement";
                    JsxFlags2[JsxFlags2["IntrinsicIndexedElement"] = 2] = "IntrinsicIndexedElement";
                    JsxFlags2[JsxFlags2["IntrinsicElement"] = 3] = "IntrinsicElement";
                    return JsxFlags2;
                })(JsxFlags || {});
                RelationComparisonResult = /* @__PURE__ */ ((RelationComparisonResult3) => {
                    RelationComparisonResult3[RelationComparisonResult3["Succeeded"] = 1] = "Succeeded";
                    RelationComparisonResult3[RelationComparisonResult3["Failed"] = 2] = "Failed";
                    RelationComparisonResult3[RelationComparisonResult3["Reported"] = 4] = "Reported";
                    RelationComparisonResult3[RelationComparisonResult3["ReportsUnmeasurable"] = 8] = "ReportsUnmeasurable";
                    RelationComparisonResult3[RelationComparisonResult3["ReportsUnreliable"] = 16] = "ReportsUnreliable";
                    RelationComparisonResult3[RelationComparisonResult3["ReportsMask"] = 24] = "ReportsMask";
                    return RelationComparisonResult3;
                })(RelationComparisonResult || {});
                GeneratedIdentifierFlags = /* @__PURE__ */ ((GeneratedIdentifierFlags2) => {
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["None"] = 0] = "None";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Auto"] = 1] = "Auto";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Loop"] = 2] = "Loop";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Unique"] = 3] = "Unique";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Node"] = 4] = "Node";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["KindMask"] = 7] = "KindMask";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["ReservedInNestedScopes"] = 8] = "ReservedInNestedScopes";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Optimistic"] = 16] = "Optimistic";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["FileLevel"] = 32] = "FileLevel";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["AllowNameSubstitution"] = 64] = "AllowNameSubstitution";
                    return GeneratedIdentifierFlags2;
                })(GeneratedIdentifierFlags || {});
                TokenFlags = /* @__PURE__ */ ((TokenFlags2) => {
                    TokenFlags2[TokenFlags2["None"] = 0] = "None";
                    TokenFlags2[TokenFlags2["PrecedingLineBreak"] = 1] = "PrecedingLineBreak";
                    TokenFlags2[TokenFlags2["PrecedingJSDocComment"] = 2] = "PrecedingJSDocComment";
                    TokenFlags2[TokenFlags2["Unterminated"] = 4] = "Unterminated";
                    TokenFlags2[TokenFlags2["ExtendedUnicodeEscape"] = 8] = "ExtendedUnicodeEscape";
                    TokenFlags2[TokenFlags2["Scientific"] = 16] = "Scientific";
                    TokenFlags2[TokenFlags2["Octal"] = 32] = "Octal";
                    TokenFlags2[TokenFlags2["HexSpecifier"] = 64] = "HexSpecifier";
                    TokenFlags2[TokenFlags2["BinarySpecifier"] = 128] = "BinarySpecifier";
                    TokenFlags2[TokenFlags2["OctalSpecifier"] = 256] = "OctalSpecifier";
                    TokenFlags2[TokenFlags2["ContainsSeparator"] = 512] = "ContainsSeparator";
                    TokenFlags2[TokenFlags2["UnicodeEscape"] = 1024] = "UnicodeEscape";
                    TokenFlags2[TokenFlags2["ContainsInvalidEscape"] = 2048] = "ContainsInvalidEscape";
                    TokenFlags2[TokenFlags2["BinaryOrOctalSpecifier"] = 384] = "BinaryOrOctalSpecifier";
                    TokenFlags2[TokenFlags2["NumericLiteralFlags"] = 1008] = "NumericLiteralFlags";
                    TokenFlags2[TokenFlags2["TemplateLiteralLikeFlags"] = 2048 /* ContainsInvalidEscape */] = "TemplateLiteralLikeFlags";
                    return TokenFlags2;
                })(TokenFlags || {});
                FlowFlags = /* @__PURE__ */ ((FlowFlags2) => {
                    FlowFlags2[FlowFlags2["Unreachable"] = 1] = "Unreachable";
                    FlowFlags2[FlowFlags2["Start"] = 2] = "Start";
                    FlowFlags2[FlowFlags2["BranchLabel"] = 4] = "BranchLabel";
                    FlowFlags2[FlowFlags2["LoopLabel"] = 8] = "LoopLabel";
                    FlowFlags2[FlowFlags2["Assignment"] = 16] = "Assignment";
                    FlowFlags2[FlowFlags2["TrueCondition"] = 32] = "TrueCondition";
                    FlowFlags2[FlowFlags2["FalseCondition"] = 64] = "FalseCondition";
                    FlowFlags2[FlowFlags2["SwitchClause"] = 128] = "SwitchClause";
                    FlowFlags2[FlowFlags2["ArrayMutation"] = 256] = "ArrayMutation";
                    FlowFlags2[FlowFlags2["Call"] = 512] = "Call";
                    FlowFlags2[FlowFlags2["ReduceLabel"] = 1024] = "ReduceLabel";
                    FlowFlags2[FlowFlags2["Referenced"] = 2048] = "Referenced";
                    FlowFlags2[FlowFlags2["Shared"] = 4096] = "Shared";
                    FlowFlags2[FlowFlags2["Label"] = 12] = "Label";
                    FlowFlags2[FlowFlags2["Condition"] = 96] = "Condition";
                    return FlowFlags2;
                })(FlowFlags || {});
                CommentDirectiveType = /* @__PURE__ */ ((CommentDirectiveType2) => {
                    CommentDirectiveType2[CommentDirectiveType2["ExpectError"] = 0] = "ExpectError";
                    CommentDirectiveType2[CommentDirectiveType2["Ignore"] = 1] = "Ignore";
                    return CommentDirectiveType2;
                })(CommentDirectiveType || {});
                OperationCanceledException = class {
                };
                FileIncludeKind = /* @__PURE__ */ ((FileIncludeKind2) => {
                    FileIncludeKind2[FileIncludeKind2["RootFile"] = 0] = "RootFile";
                    FileIncludeKind2[FileIncludeKind2["SourceFromProjectReference"] = 1] = "SourceFromProjectReference";
                    FileIncludeKind2[FileIncludeKind2["OutputFromProjectReference"] = 2] = "OutputFromProjectReference";
                    FileIncludeKind2[FileIncludeKind2["Import"] = 3] = "Import";
                    FileIncludeKind2[FileIncludeKind2["ReferenceFile"] = 4] = "ReferenceFile";
                    FileIncludeKind2[FileIncludeKind2["TypeReferenceDirective"] = 5] = "TypeReferenceDirective";
                    FileIncludeKind2[FileIncludeKind2["LibFile"] = 6] = "LibFile";
                    FileIncludeKind2[FileIncludeKind2["LibReferenceDirective"] = 7] = "LibReferenceDirective";
                    FileIncludeKind2[FileIncludeKind2["AutomaticTypeDirectiveFile"] = 8] = "AutomaticTypeDirectiveFile";
                    return FileIncludeKind2;
                })(FileIncludeKind || {});
                FilePreprocessingDiagnosticsKind = /* @__PURE__ */ ((FilePreprocessingDiagnosticsKind2) => {
                    FilePreprocessingDiagnosticsKind2[FilePreprocessingDiagnosticsKind2["FilePreprocessingReferencedDiagnostic"] = 0] = "FilePreprocessingReferencedDiagnostic";
                    FilePreprocessingDiagnosticsKind2[FilePreprocessingDiagnosticsKind2["FilePreprocessingFileExplainingDiagnostic"] = 1] = "FilePreprocessingFileExplainingDiagnostic";
                    FilePreprocessingDiagnosticsKind2[FilePreprocessingDiagnosticsKind2["ResolutionDiagnostics"] = 2] = "ResolutionDiagnostics";
                    return FilePreprocessingDiagnosticsKind2;
                })(FilePreprocessingDiagnosticsKind || {});
                EmitOnly = /* @__PURE__ */ ((EmitOnly4) => {
                    EmitOnly4[EmitOnly4["Js"] = 0] = "Js";
                    EmitOnly4[EmitOnly4["Dts"] = 1] = "Dts";
                    return EmitOnly4;
                })(EmitOnly || {});
                StructureIsReused = /* @__PURE__ */ ((StructureIsReused2) => {
                    StructureIsReused2[StructureIsReused2["Not"] = 0] = "Not";
                    StructureIsReused2[StructureIsReused2["SafeModules"] = 1] = "SafeModules";
                    StructureIsReused2[StructureIsReused2["Completely"] = 2] = "Completely";
                    return StructureIsReused2;
                })(StructureIsReused || {});
                ExitStatus = /* @__PURE__ */ ((ExitStatus2) => {
                    ExitStatus2[ExitStatus2["Success"] = 0] = "Success";
                    ExitStatus2[ExitStatus2["DiagnosticsPresent_OutputsSkipped"] = 1] = "DiagnosticsPresent_OutputsSkipped";
                    ExitStatus2[ExitStatus2["DiagnosticsPresent_OutputsGenerated"] = 2] = "DiagnosticsPresent_OutputsGenerated";
                    ExitStatus2[ExitStatus2["InvalidProject_OutputsSkipped"] = 3] = "InvalidProject_OutputsSkipped";
                    ExitStatus2[ExitStatus2["ProjectReferenceCycle_OutputsSkipped"] = 4] = "ProjectReferenceCycle_OutputsSkipped";
                    return ExitStatus2;
                })(ExitStatus || {});
                MemberOverrideStatus = /* @__PURE__ */ ((MemberOverrideStatus2) => {
                    MemberOverrideStatus2[MemberOverrideStatus2["Ok"] = 0] = "Ok";
                    MemberOverrideStatus2[MemberOverrideStatus2["NeedsOverride"] = 1] = "NeedsOverride";
                    MemberOverrideStatus2[MemberOverrideStatus2["HasInvalidOverride"] = 2] = "HasInvalidOverride";
                    return MemberOverrideStatus2;
                })(MemberOverrideStatus || {});
                UnionReduction = /* @__PURE__ */ ((UnionReduction2) => {
                    UnionReduction2[UnionReduction2["None"] = 0] = "None";
                    UnionReduction2[UnionReduction2["Literal"] = 1] = "Literal";
                    UnionReduction2[UnionReduction2["Subtype"] = 2] = "Subtype";
                    return UnionReduction2;
                })(UnionReduction || {});
                ContextFlags = /* @__PURE__ */ ((ContextFlags3) => {
                    ContextFlags3[ContextFlags3["None"] = 0] = "None";
                    ContextFlags3[ContextFlags3["Signature"] = 1] = "Signature";
                    ContextFlags3[ContextFlags3["NoConstraints"] = 2] = "NoConstraints";
                    ContextFlags3[ContextFlags3["Completions"] = 4] = "Completions";
                    ContextFlags3[ContextFlags3["SkipBindingPatterns"] = 8] = "SkipBindingPatterns";
                    return ContextFlags3;
                })(ContextFlags || {});
                NodeBuilderFlags = /* @__PURE__ */ ((NodeBuilderFlags2) => {
                    NodeBuilderFlags2[NodeBuilderFlags2["None"] = 0] = "None";
                    NodeBuilderFlags2[NodeBuilderFlags2["NoTruncation"] = 1] = "NoTruncation";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteArrayAsGenericType"] = 2] = "WriteArrayAsGenericType";
                    NodeBuilderFlags2[NodeBuilderFlags2["GenerateNamesForShadowedTypeParams"] = 4] = "GenerateNamesForShadowedTypeParams";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseStructuralFallback"] = 8] = "UseStructuralFallback";
                    NodeBuilderFlags2[NodeBuilderFlags2["ForbidIndexedAccessSymbolReferences"] = 16] = "ForbidIndexedAccessSymbolReferences";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteTypeArgumentsOfSignature"] = 32] = "WriteTypeArgumentsOfSignature";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseFullyQualifiedType"] = 64] = "UseFullyQualifiedType";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseOnlyExternalAliasing"] = 128] = "UseOnlyExternalAliasing";
                    NodeBuilderFlags2[NodeBuilderFlags2["SuppressAnyReturnType"] = 256] = "SuppressAnyReturnType";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteTypeParametersInQualifiedName"] = 512] = "WriteTypeParametersInQualifiedName";
                    NodeBuilderFlags2[NodeBuilderFlags2["MultilineObjectLiterals"] = 1024] = "MultilineObjectLiterals";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteClassExpressionAsTypeLiteral"] = 2048] = "WriteClassExpressionAsTypeLiteral";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseTypeOfFunction"] = 4096] = "UseTypeOfFunction";
                    NodeBuilderFlags2[NodeBuilderFlags2["OmitParameterModifiers"] = 8192] = "OmitParameterModifiers";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseAliasDefinedOutsideCurrentScope"] = 16384] = "UseAliasDefinedOutsideCurrentScope";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseSingleQuotesForStringLiteralType"] = 268435456] = "UseSingleQuotesForStringLiteralType";
                    NodeBuilderFlags2[NodeBuilderFlags2["NoTypeReduction"] = 536870912] = "NoTypeReduction";
                    NodeBuilderFlags2[NodeBuilderFlags2["OmitThisParameter"] = 33554432] = "OmitThisParameter";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowThisInObjectLiteral"] = 32768] = "AllowThisInObjectLiteral";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowQualifiedNameInPlaceOfIdentifier"] = 65536] = "AllowQualifiedNameInPlaceOfIdentifier";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowAnonymousIdentifier"] = 131072] = "AllowAnonymousIdentifier";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowEmptyUnionOrIntersection"] = 262144] = "AllowEmptyUnionOrIntersection";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowEmptyTuple"] = 524288] = "AllowEmptyTuple";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowUniqueESSymbolType"] = 1048576] = "AllowUniqueESSymbolType";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowEmptyIndexInfoType"] = 2097152] = "AllowEmptyIndexInfoType";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteComputedProps"] = 1073741824] = "WriteComputedProps";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowNodeModulesRelativePaths"] = 67108864] = "AllowNodeModulesRelativePaths";
                    NodeBuilderFlags2[NodeBuilderFlags2["DoNotIncludeSymbolChain"] = 134217728] = "DoNotIncludeSymbolChain";
                    NodeBuilderFlags2[NodeBuilderFlags2["IgnoreErrors"] = 70221824] = "IgnoreErrors";
                    NodeBuilderFlags2[NodeBuilderFlags2["InObjectTypeLiteral"] = 4194304] = "InObjectTypeLiteral";
                    NodeBuilderFlags2[NodeBuilderFlags2["InTypeAlias"] = 8388608] = "InTypeAlias";
                    NodeBuilderFlags2[NodeBuilderFlags2["InInitialEntityName"] = 16777216] = "InInitialEntityName";
                    return NodeBuilderFlags2;
                })(NodeBuilderFlags || {});
                TypeFormatFlags = /* @__PURE__ */ ((TypeFormatFlags2) => {
                    TypeFormatFlags2[TypeFormatFlags2["None"] = 0] = "None";
                    TypeFormatFlags2[TypeFormatFlags2["NoTruncation"] = 1] = "NoTruncation";
                    TypeFormatFlags2[TypeFormatFlags2["WriteArrayAsGenericType"] = 2] = "WriteArrayAsGenericType";
                    TypeFormatFlags2[TypeFormatFlags2["UseStructuralFallback"] = 8] = "UseStructuralFallback";
                    TypeFormatFlags2[TypeFormatFlags2["WriteTypeArgumentsOfSignature"] = 32] = "WriteTypeArgumentsOfSignature";
                    TypeFormatFlags2[TypeFormatFlags2["UseFullyQualifiedType"] = 64] = "UseFullyQualifiedType";
                    TypeFormatFlags2[TypeFormatFlags2["SuppressAnyReturnType"] = 256] = "SuppressAnyReturnType";
                    TypeFormatFlags2[TypeFormatFlags2["MultilineObjectLiterals"] = 1024] = "MultilineObjectLiterals";
                    TypeFormatFlags2[TypeFormatFlags2["WriteClassExpressionAsTypeLiteral"] = 2048] = "WriteClassExpressionAsTypeLiteral";
                    TypeFormatFlags2[TypeFormatFlags2["UseTypeOfFunction"] = 4096] = "UseTypeOfFunction";
                    TypeFormatFlags2[TypeFormatFlags2["OmitParameterModifiers"] = 8192] = "OmitParameterModifiers";
                    TypeFormatFlags2[TypeFormatFlags2["UseAliasDefinedOutsideCurrentScope"] = 16384] = "UseAliasDefinedOutsideCurrentScope";
                    TypeFormatFlags2[TypeFormatFlags2["UseSingleQuotesForStringLiteralType"] = 268435456] = "UseSingleQuotesForStringLiteralType";
                    TypeFormatFlags2[TypeFormatFlags2["NoTypeReduction"] = 536870912] = "NoTypeReduction";
                    TypeFormatFlags2[TypeFormatFlags2["OmitThisParameter"] = 33554432] = "OmitThisParameter";
                    TypeFormatFlags2[TypeFormatFlags2["AllowUniqueESSymbolType"] = 1048576] = "AllowUniqueESSymbolType";
                    TypeFormatFlags2[TypeFormatFlags2["AddUndefined"] = 131072] = "AddUndefined";
                    TypeFormatFlags2[TypeFormatFlags2["WriteArrowStyleSignature"] = 262144] = "WriteArrowStyleSignature";
                    TypeFormatFlags2[TypeFormatFlags2["InArrayType"] = 524288] = "InArrayType";
                    TypeFormatFlags2[TypeFormatFlags2["InElementType"] = 2097152] = "InElementType";
                    TypeFormatFlags2[TypeFormatFlags2["InFirstTypeArgument"] = 4194304] = "InFirstTypeArgument";
                    TypeFormatFlags2[TypeFormatFlags2["InTypeAlias"] = 8388608] = "InTypeAlias";
                    TypeFormatFlags2[TypeFormatFlags2["NodeBuilderFlagsMask"] = 848330091] = "NodeBuilderFlagsMask";
                    return TypeFormatFlags2;
                })(TypeFormatFlags || {});
                SymbolFormatFlags = /* @__PURE__ */ ((SymbolFormatFlags2) => {
                    SymbolFormatFlags2[SymbolFormatFlags2["None"] = 0] = "None";
                    SymbolFormatFlags2[SymbolFormatFlags2["WriteTypeParametersOrArguments"] = 1] = "WriteTypeParametersOrArguments";
                    SymbolFormatFlags2[SymbolFormatFlags2["UseOnlyExternalAliasing"] = 2] = "UseOnlyExternalAliasing";
                    SymbolFormatFlags2[SymbolFormatFlags2["AllowAnyNodeKind"] = 4] = "AllowAnyNodeKind";
                    SymbolFormatFlags2[SymbolFormatFlags2["UseAliasDefinedOutsideCurrentScope"] = 8] = "UseAliasDefinedOutsideCurrentScope";
                    SymbolFormatFlags2[SymbolFormatFlags2["WriteComputedProps"] = 16] = "WriteComputedProps";
                    SymbolFormatFlags2[SymbolFormatFlags2["DoNotIncludeSymbolChain"] = 32] = "DoNotIncludeSymbolChain";
                    return SymbolFormatFlags2;
                })(SymbolFormatFlags || {});
                SymbolAccessibility = /* @__PURE__ */ ((SymbolAccessibility2) => {
                    SymbolAccessibility2[SymbolAccessibility2["Accessible"] = 0] = "Accessible";
                    SymbolAccessibility2[SymbolAccessibility2["NotAccessible"] = 1] = "NotAccessible";
                    SymbolAccessibility2[SymbolAccessibility2["CannotBeNamed"] = 2] = "CannotBeNamed";
                    return SymbolAccessibility2;
                })(SymbolAccessibility || {});
                SyntheticSymbolKind = /* @__PURE__ */ ((SyntheticSymbolKind2) => {
                    SyntheticSymbolKind2[SyntheticSymbolKind2["UnionOrIntersection"] = 0] = "UnionOrIntersection";
                    SyntheticSymbolKind2[SyntheticSymbolKind2["Spread"] = 1] = "Spread";
                    return SyntheticSymbolKind2;
                })(SyntheticSymbolKind || {});
                TypePredicateKind = /* @__PURE__ */ ((TypePredicateKind2) => {
                    TypePredicateKind2[TypePredicateKind2["This"] = 0] = "This";
                    TypePredicateKind2[TypePredicateKind2["Identifier"] = 1] = "Identifier";
                    TypePredicateKind2[TypePredicateKind2["AssertsThis"] = 2] = "AssertsThis";
                    TypePredicateKind2[TypePredicateKind2["AssertsIdentifier"] = 3] = "AssertsIdentifier";
                    return TypePredicateKind2;
                })(TypePredicateKind || {});
                TypeReferenceSerializationKind = /* @__PURE__ */ ((TypeReferenceSerializationKind2) => {
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["Unknown"] = 0] = "Unknown";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["TypeWithConstructSignatureAndValue"] = 1] = "TypeWithConstructSignatureAndValue";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["VoidNullableOrNeverType"] = 2] = "VoidNullableOrNeverType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["NumberLikeType"] = 3] = "NumberLikeType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["BigIntLikeType"] = 4] = "BigIntLikeType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["StringLikeType"] = 5] = "StringLikeType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["BooleanType"] = 6] = "BooleanType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["ArrayLikeType"] = 7] = "ArrayLikeType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["ESSymbolType"] = 8] = "ESSymbolType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["Promise"] = 9] = "Promise";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["TypeWithCallSignature"] = 10] = "TypeWithCallSignature";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["ObjectType"] = 11] = "ObjectType";
                    return TypeReferenceSerializationKind2;
                })(TypeReferenceSerializationKind || {});
                SymbolFlags = /* @__PURE__ */ ((SymbolFlags3) => {
                    SymbolFlags3[SymbolFlags3["None"] = 0] = "None";
                    SymbolFlags3[SymbolFlags3["FunctionScopedVariable"] = 1] = "FunctionScopedVariable";
                    SymbolFlags3[SymbolFlags3["BlockScopedVariable"] = 2] = "BlockScopedVariable";
                    SymbolFlags3[SymbolFlags3["Property"] = 4] = "Property";
                    SymbolFlags3[SymbolFlags3["EnumMember"] = 8] = "EnumMember";
                    SymbolFlags3[SymbolFlags3["Function"] = 16] = "Function";
                    SymbolFlags3[SymbolFlags3["Class"] = 32] = "Class";
                    SymbolFlags3[SymbolFlags3["Interface"] = 64] = "Interface";
                    SymbolFlags3[SymbolFlags3["ConstEnum"] = 128] = "ConstEnum";
                    SymbolFlags3[SymbolFlags3["RegularEnum"] = 256] = "RegularEnum";
                    SymbolFlags3[SymbolFlags3["ValueModule"] = 512] = "ValueModule";
                    SymbolFlags3[SymbolFlags3["NamespaceModule"] = 1024] = "NamespaceModule";
                    SymbolFlags3[SymbolFlags3["TypeLiteral"] = 2048] = "TypeLiteral";
                    SymbolFlags3[SymbolFlags3["ObjectLiteral"] = 4096] = "ObjectLiteral";
                    SymbolFlags3[SymbolFlags3["Method"] = 8192] = "Method";
                    SymbolFlags3[SymbolFlags3["Constructor"] = 16384] = "Constructor";
                    SymbolFlags3[SymbolFlags3["GetAccessor"] = 32768] = "GetAccessor";
                    SymbolFlags3[SymbolFlags3["SetAccessor"] = 65536] = "SetAccessor";
                    SymbolFlags3[SymbolFlags3["Signature"] = 131072] = "Signature";
                    SymbolFlags3[SymbolFlags3["TypeParameter"] = 262144] = "TypeParameter";
                    SymbolFlags3[SymbolFlags3["TypeAlias"] = 524288] = "TypeAlias";
                    SymbolFlags3[SymbolFlags3["ExportValue"] = 1048576] = "ExportValue";
                    SymbolFlags3[SymbolFlags3["Alias"] = 2097152] = "Alias";
                    SymbolFlags3[SymbolFlags3["Prototype"] = 4194304] = "Prototype";
                    SymbolFlags3[SymbolFlags3["ExportStar"] = 8388608] = "ExportStar";
                    SymbolFlags3[SymbolFlags3["Optional"] = 16777216] = "Optional";
                    SymbolFlags3[SymbolFlags3["Transient"] = 33554432] = "Transient";
                    SymbolFlags3[SymbolFlags3["Assignment"] = 67108864] = "Assignment";
                    SymbolFlags3[SymbolFlags3["ModuleExports"] = 134217728] = "ModuleExports";
                    SymbolFlags3[SymbolFlags3["All"] = 67108863] = "All";
                    SymbolFlags3[SymbolFlags3["Enum"] = 384] = "Enum";
                    SymbolFlags3[SymbolFlags3["Variable"] = 3] = "Variable";
                    SymbolFlags3[SymbolFlags3["Value"] = 111551] = "Value";
                    SymbolFlags3[SymbolFlags3["Type"] = 788968] = "Type";
                    SymbolFlags3[SymbolFlags3["Namespace"] = 1920] = "Namespace";
                    SymbolFlags3[SymbolFlags3["Module"] = 1536] = "Module";
                    SymbolFlags3[SymbolFlags3["Accessor"] = 98304] = "Accessor";
                    SymbolFlags3[SymbolFlags3["FunctionScopedVariableExcludes"] = 111550] = "FunctionScopedVariableExcludes";
                    SymbolFlags3[SymbolFlags3["BlockScopedVariableExcludes"] = 111551 /* Value */] = "BlockScopedVariableExcludes";
                    SymbolFlags3[SymbolFlags3["ParameterExcludes"] = 111551 /* Value */] = "ParameterExcludes";
                    SymbolFlags3[SymbolFlags3["PropertyExcludes"] = 0 /* None */] = "PropertyExcludes";
                    SymbolFlags3[SymbolFlags3["EnumMemberExcludes"] = 900095] = "EnumMemberExcludes";
                    SymbolFlags3[SymbolFlags3["FunctionExcludes"] = 110991] = "FunctionExcludes";
                    SymbolFlags3[SymbolFlags3["ClassExcludes"] = 899503] = "ClassExcludes";
                    SymbolFlags3[SymbolFlags3["InterfaceExcludes"] = 788872] = "InterfaceExcludes";
                    SymbolFlags3[SymbolFlags3["RegularEnumExcludes"] = 899327] = "RegularEnumExcludes";
                    SymbolFlags3[SymbolFlags3["ConstEnumExcludes"] = 899967] = "ConstEnumExcludes";
                    SymbolFlags3[SymbolFlags3["ValueModuleExcludes"] = 110735] = "ValueModuleExcludes";
                    SymbolFlags3[SymbolFlags3["NamespaceModuleExcludes"] = 0] = "NamespaceModuleExcludes";
                    SymbolFlags3[SymbolFlags3["MethodExcludes"] = 103359] = "MethodExcludes";
                    SymbolFlags3[SymbolFlags3["GetAccessorExcludes"] = 46015] = "GetAccessorExcludes";
                    SymbolFlags3[SymbolFlags3["SetAccessorExcludes"] = 78783] = "SetAccessorExcludes";
                    SymbolFlags3[SymbolFlags3["AccessorExcludes"] = 13247] = "AccessorExcludes";
                    SymbolFlags3[SymbolFlags3["TypeParameterExcludes"] = 526824] = "TypeParameterExcludes";
                    SymbolFlags3[SymbolFlags3["TypeAliasExcludes"] = 788968 /* Type */] = "TypeAliasExcludes";
                    SymbolFlags3[SymbolFlags3["AliasExcludes"] = 2097152 /* Alias */] = "AliasExcludes";
                    SymbolFlags3[SymbolFlags3["ModuleMember"] = 2623475] = "ModuleMember";
                    SymbolFlags3[SymbolFlags3["ExportHasLocal"] = 944] = "ExportHasLocal";
                    SymbolFlags3[SymbolFlags3["BlockScoped"] = 418] = "BlockScoped";
                    SymbolFlags3[SymbolFlags3["PropertyOrAccessor"] = 98308] = "PropertyOrAccessor";
                    SymbolFlags3[SymbolFlags3["ClassMember"] = 106500] = "ClassMember";
                    SymbolFlags3[SymbolFlags3["ExportSupportsDefaultModifier"] = 112] = "ExportSupportsDefaultModifier";
                    SymbolFlags3[SymbolFlags3["ExportDoesNotSupportDefaultModifier"] = -113] = "ExportDoesNotSupportDefaultModifier";
                    SymbolFlags3[SymbolFlags3["Classifiable"] = 2885600] = "Classifiable";
                    SymbolFlags3[SymbolFlags3["LateBindingContainer"] = 6256] = "LateBindingContainer";
                    return SymbolFlags3;
                })(SymbolFlags || {});
                EnumKind = /* @__PURE__ */ ((EnumKind2) => {
                    EnumKind2[EnumKind2["Numeric"] = 0] = "Numeric";
                    EnumKind2[EnumKind2["Literal"] = 1] = "Literal";
                    return EnumKind2;
                })(EnumKind || {});
                CheckFlags = /* @__PURE__ */ ((CheckFlags2) => {
                    CheckFlags2[CheckFlags2["None"] = 0] = "None";
                    CheckFlags2[CheckFlags2["Instantiated"] = 1] = "Instantiated";
                    CheckFlags2[CheckFlags2["SyntheticProperty"] = 2] = "SyntheticProperty";
                    CheckFlags2[CheckFlags2["SyntheticMethod"] = 4] = "SyntheticMethod";
                    CheckFlags2[CheckFlags2["Readonly"] = 8] = "Readonly";
                    CheckFlags2[CheckFlags2["ReadPartial"] = 16] = "ReadPartial";
                    CheckFlags2[CheckFlags2["WritePartial"] = 32] = "WritePartial";
                    CheckFlags2[CheckFlags2["HasNonUniformType"] = 64] = "HasNonUniformType";
                    CheckFlags2[CheckFlags2["HasLiteralType"] = 128] = "HasLiteralType";
                    CheckFlags2[CheckFlags2["ContainsPublic"] = 256] = "ContainsPublic";
                    CheckFlags2[CheckFlags2["ContainsProtected"] = 512] = "ContainsProtected";
                    CheckFlags2[CheckFlags2["ContainsPrivate"] = 1024] = "ContainsPrivate";
                    CheckFlags2[CheckFlags2["ContainsStatic"] = 2048] = "ContainsStatic";
                    CheckFlags2[CheckFlags2["Late"] = 4096] = "Late";
                    CheckFlags2[CheckFlags2["ReverseMapped"] = 8192] = "ReverseMapped";
                    CheckFlags2[CheckFlags2["OptionalParameter"] = 16384] = "OptionalParameter";
                    CheckFlags2[CheckFlags2["RestParameter"] = 32768] = "RestParameter";
                    CheckFlags2[CheckFlags2["DeferredType"] = 65536] = "DeferredType";
                    CheckFlags2[CheckFlags2["HasNeverType"] = 131072] = "HasNeverType";
                    CheckFlags2[CheckFlags2["Mapped"] = 262144] = "Mapped";
                    CheckFlags2[CheckFlags2["StripOptional"] = 524288] = "StripOptional";
                    CheckFlags2[CheckFlags2["Unresolved"] = 1048576] = "Unresolved";
                    CheckFlags2[CheckFlags2["Synthetic"] = 6] = "Synthetic";
                    CheckFlags2[CheckFlags2["Discriminant"] = 192] = "Discriminant";
                    CheckFlags2[CheckFlags2["Partial"] = 48] = "Partial";
                    return CheckFlags2;
                })(CheckFlags || {});
                InternalSymbolName = /* @__PURE__ */ ((InternalSymbolName2) => {
                    InternalSymbolName2["Call"] = "__call";
                    InternalSymbolName2["Constructor"] = "__constructor";
                    InternalSymbolName2["New"] = "__new";
                    InternalSymbolName2["Index"] = "__index";
                    InternalSymbolName2["ExportStar"] = "__export";
                    InternalSymbolName2["Global"] = "__global";
                    InternalSymbolName2["Missing"] = "__missing";
                    InternalSymbolName2["Type"] = "__type";
                    InternalSymbolName2["Object"] = "__object";
                    InternalSymbolName2["JSXAttributes"] = "__jsxAttributes";
                    InternalSymbolName2["Class"] = "__class";
                    InternalSymbolName2["Function"] = "__function";
                    InternalSymbolName2["Computed"] = "__computed";
                    InternalSymbolName2["Resolving"] = "__resolving__";
                    InternalSymbolName2["ExportEquals"] = "export=";
                    InternalSymbolName2["Default"] = "default";
                    InternalSymbolName2["This"] = "this";
                    return InternalSymbolName2;
                })(InternalSymbolName || {});
                NodeCheckFlags = /* @__PURE__ */ ((NodeCheckFlags2) => {
                    NodeCheckFlags2[NodeCheckFlags2["None"] = 0] = "None";
                    NodeCheckFlags2[NodeCheckFlags2["TypeChecked"] = 1] = "TypeChecked";
                    NodeCheckFlags2[NodeCheckFlags2["LexicalThis"] = 2] = "LexicalThis";
                    NodeCheckFlags2[NodeCheckFlags2["CaptureThis"] = 4] = "CaptureThis";
                    NodeCheckFlags2[NodeCheckFlags2["CaptureNewTarget"] = 8] = "CaptureNewTarget";
                    NodeCheckFlags2[NodeCheckFlags2["SuperInstance"] = 16] = "SuperInstance";
                    NodeCheckFlags2[NodeCheckFlags2["SuperStatic"] = 32] = "SuperStatic";
                    NodeCheckFlags2[NodeCheckFlags2["ContextChecked"] = 64] = "ContextChecked";
                    NodeCheckFlags2[NodeCheckFlags2["MethodWithSuperPropertyAccessInAsync"] = 128] = "MethodWithSuperPropertyAccessInAsync";
                    NodeCheckFlags2[NodeCheckFlags2["MethodWithSuperPropertyAssignmentInAsync"] = 256] = "MethodWithSuperPropertyAssignmentInAsync";
                    NodeCheckFlags2[NodeCheckFlags2["CaptureArguments"] = 512] = "CaptureArguments";
                    NodeCheckFlags2[NodeCheckFlags2["EnumValuesComputed"] = 1024] = "EnumValuesComputed";
                    NodeCheckFlags2[NodeCheckFlags2["LexicalModuleMergesWithClass"] = 2048] = "LexicalModuleMergesWithClass";
                    NodeCheckFlags2[NodeCheckFlags2["LoopWithCapturedBlockScopedBinding"] = 4096] = "LoopWithCapturedBlockScopedBinding";
                    NodeCheckFlags2[NodeCheckFlags2["ContainsCapturedBlockScopeBinding"] = 8192] = "ContainsCapturedBlockScopeBinding";
                    NodeCheckFlags2[NodeCheckFlags2["CapturedBlockScopedBinding"] = 16384] = "CapturedBlockScopedBinding";
                    NodeCheckFlags2[NodeCheckFlags2["BlockScopedBindingInLoop"] = 32768] = "BlockScopedBindingInLoop";
                    NodeCheckFlags2[NodeCheckFlags2["ClassWithBodyScopedClassBinding"] = 65536] = "ClassWithBodyScopedClassBinding";
                    NodeCheckFlags2[NodeCheckFlags2["BodyScopedClassBinding"] = 131072] = "BodyScopedClassBinding";
                    NodeCheckFlags2[NodeCheckFlags2["NeedsLoopOutParameter"] = 262144] = "NeedsLoopOutParameter";
                    NodeCheckFlags2[NodeCheckFlags2["AssignmentsMarked"] = 524288] = "AssignmentsMarked";
                    NodeCheckFlags2[NodeCheckFlags2["ClassWithConstructorReference"] = 1048576] = "ClassWithConstructorReference";
                    NodeCheckFlags2[NodeCheckFlags2["ConstructorReferenceInClass"] = 2097152] = "ConstructorReferenceInClass";
                    NodeCheckFlags2[NodeCheckFlags2["ContainsClassWithPrivateIdentifiers"] = 4194304] = "ContainsClassWithPrivateIdentifiers";
                    NodeCheckFlags2[NodeCheckFlags2["ContainsSuperPropertyInStaticInitializer"] = 8388608] = "ContainsSuperPropertyInStaticInitializer";
                    NodeCheckFlags2[NodeCheckFlags2["InCheckIdentifier"] = 16777216] = "InCheckIdentifier";
                    return NodeCheckFlags2;
                })(NodeCheckFlags || {});
                TypeFlags = /* @__PURE__ */ ((TypeFlags2) => {
                    TypeFlags2[TypeFlags2["Any"] = 1] = "Any";
                    TypeFlags2[TypeFlags2["Unknown"] = 2] = "Unknown";
                    TypeFlags2[TypeFlags2["String"] = 4] = "String";
                    TypeFlags2[TypeFlags2["Number"] = 8] = "Number";
                    TypeFlags2[TypeFlags2["Boolean"] = 16] = "Boolean";
                    TypeFlags2[TypeFlags2["Enum"] = 32] = "Enum";
                    TypeFlags2[TypeFlags2["BigInt"] = 64] = "BigInt";
                    TypeFlags2[TypeFlags2["StringLiteral"] = 128] = "StringLiteral";
                    TypeFlags2[TypeFlags2["NumberLiteral"] = 256] = "NumberLiteral";
                    TypeFlags2[TypeFlags2["BooleanLiteral"] = 512] = "BooleanLiteral";
                    TypeFlags2[TypeFlags2["EnumLiteral"] = 1024] = "EnumLiteral";
                    TypeFlags2[TypeFlags2["BigIntLiteral"] = 2048] = "BigIntLiteral";
                    TypeFlags2[TypeFlags2["ESSymbol"] = 4096] = "ESSymbol";
                    TypeFlags2[TypeFlags2["UniqueESSymbol"] = 8192] = "UniqueESSymbol";
                    TypeFlags2[TypeFlags2["Void"] = 16384] = "Void";
                    TypeFlags2[TypeFlags2["Undefined"] = 32768] = "Undefined";
                    TypeFlags2[TypeFlags2["Null"] = 65536] = "Null";
                    TypeFlags2[TypeFlags2["Never"] = 131072] = "Never";
                    TypeFlags2[TypeFlags2["TypeParameter"] = 262144] = "TypeParameter";
                    TypeFlags2[TypeFlags2["Object"] = 524288] = "Object";
                    TypeFlags2[TypeFlags2["Union"] = 1048576] = "Union";
                    TypeFlags2[TypeFlags2["Intersection"] = 2097152] = "Intersection";
                    TypeFlags2[TypeFlags2["Index"] = 4194304] = "Index";
                    TypeFlags2[TypeFlags2["IndexedAccess"] = 8388608] = "IndexedAccess";
                    TypeFlags2[TypeFlags2["Conditional"] = 16777216] = "Conditional";
                    TypeFlags2[TypeFlags2["Substitution"] = 33554432] = "Substitution";
                    TypeFlags2[TypeFlags2["NonPrimitive"] = 67108864] = "NonPrimitive";
                    TypeFlags2[TypeFlags2["TemplateLiteral"] = 134217728] = "TemplateLiteral";
                    TypeFlags2[TypeFlags2["StringMapping"] = 268435456] = "StringMapping";
                    TypeFlags2[TypeFlags2["AnyOrUnknown"] = 3] = "AnyOrUnknown";
                    TypeFlags2[TypeFlags2["Nullable"] = 98304] = "Nullable";
                    TypeFlags2[TypeFlags2["Literal"] = 2944] = "Literal";
                    TypeFlags2[TypeFlags2["Unit"] = 109472] = "Unit";
                    TypeFlags2[TypeFlags2["Freshable"] = 2976] = "Freshable";
                    TypeFlags2[TypeFlags2["StringOrNumberLiteral"] = 384] = "StringOrNumberLiteral";
                    TypeFlags2[TypeFlags2["StringOrNumberLiteralOrUnique"] = 8576] = "StringOrNumberLiteralOrUnique";
                    TypeFlags2[TypeFlags2["DefinitelyFalsy"] = 117632] = "DefinitelyFalsy";
                    TypeFlags2[TypeFlags2["PossiblyFalsy"] = 117724] = "PossiblyFalsy";
                    TypeFlags2[TypeFlags2["Intrinsic"] = 67359327] = "Intrinsic";
                    TypeFlags2[TypeFlags2["Primitive"] = 134348796] = "Primitive";
                    TypeFlags2[TypeFlags2["StringLike"] = 402653316] = "StringLike";
                    TypeFlags2[TypeFlags2["NumberLike"] = 296] = "NumberLike";
                    TypeFlags2[TypeFlags2["BigIntLike"] = 2112] = "BigIntLike";
                    TypeFlags2[TypeFlags2["BooleanLike"] = 528] = "BooleanLike";
                    TypeFlags2[TypeFlags2["EnumLike"] = 1056] = "EnumLike";
                    TypeFlags2[TypeFlags2["ESSymbolLike"] = 12288] = "ESSymbolLike";
                    TypeFlags2[TypeFlags2["VoidLike"] = 49152] = "VoidLike";
                    TypeFlags2[TypeFlags2["DefinitelyNonNullable"] = 470302716] = "DefinitelyNonNullable";
                    TypeFlags2[TypeFlags2["DisjointDomains"] = 469892092] = "DisjointDomains";
                    TypeFlags2[TypeFlags2["UnionOrIntersection"] = 3145728] = "UnionOrIntersection";
                    TypeFlags2[TypeFlags2["StructuredType"] = 3670016] = "StructuredType";
                    TypeFlags2[TypeFlags2["TypeVariable"] = 8650752] = "TypeVariable";
                    TypeFlags2[TypeFlags2["InstantiableNonPrimitive"] = 58982400] = "InstantiableNonPrimitive";
                    TypeFlags2[TypeFlags2["InstantiablePrimitive"] = 406847488] = "InstantiablePrimitive";
                    TypeFlags2[TypeFlags2["Instantiable"] = 465829888] = "Instantiable";
                    TypeFlags2[TypeFlags2["StructuredOrInstantiable"] = 469499904] = "StructuredOrInstantiable";
                    TypeFlags2[TypeFlags2["ObjectFlagsType"] = 3899393] = "ObjectFlagsType";
                    TypeFlags2[TypeFlags2["Simplifiable"] = 25165824] = "Simplifiable";
                    TypeFlags2[TypeFlags2["Singleton"] = 67358815] = "Singleton";
                    TypeFlags2[TypeFlags2["Narrowable"] = 536624127] = "Narrowable";
                    TypeFlags2[TypeFlags2["IncludesMask"] = 205258751] = "IncludesMask";
                    TypeFlags2[TypeFlags2["IncludesMissingType"] = 262144 /* TypeParameter */] = "IncludesMissingType";
                    TypeFlags2[TypeFlags2["IncludesNonWideningType"] = 4194304 /* Index */] = "IncludesNonWideningType";
                    TypeFlags2[TypeFlags2["IncludesWildcard"] = 8388608 /* IndexedAccess */] = "IncludesWildcard";
                    TypeFlags2[TypeFlags2["IncludesEmptyObject"] = 16777216 /* Conditional */] = "IncludesEmptyObject";
                    TypeFlags2[TypeFlags2["IncludesInstantiable"] = 33554432 /* Substitution */] = "IncludesInstantiable";
                    TypeFlags2[TypeFlags2["NotPrimitiveUnion"] = 36323363] = "NotPrimitiveUnion";
                    return TypeFlags2;
                })(TypeFlags || {});
                ObjectFlags = /* @__PURE__ */ ((ObjectFlags3) => {
                    ObjectFlags3[ObjectFlags3["None"] = 0] = "None";
                    ObjectFlags3[ObjectFlags3["Class"] = 1] = "Class";
                    ObjectFlags3[ObjectFlags3["Interface"] = 2] = "Interface";
                    ObjectFlags3[ObjectFlags3["Reference"] = 4] = "Reference";
                    ObjectFlags3[ObjectFlags3["Tuple"] = 8] = "Tuple";
                    ObjectFlags3[ObjectFlags3["Anonymous"] = 16] = "Anonymous";
                    ObjectFlags3[ObjectFlags3["Mapped"] = 32] = "Mapped";
                    ObjectFlags3[ObjectFlags3["Instantiated"] = 64] = "Instantiated";
                    ObjectFlags3[ObjectFlags3["ObjectLiteral"] = 128] = "ObjectLiteral";
                    ObjectFlags3[ObjectFlags3["EvolvingArray"] = 256] = "EvolvingArray";
                    ObjectFlags3[ObjectFlags3["ObjectLiteralPatternWithComputedProperties"] = 512] = "ObjectLiteralPatternWithComputedProperties";
                    ObjectFlags3[ObjectFlags3["ReverseMapped"] = 1024] = "ReverseMapped";
                    ObjectFlags3[ObjectFlags3["JsxAttributes"] = 2048] = "JsxAttributes";
                    ObjectFlags3[ObjectFlags3["JSLiteral"] = 4096] = "JSLiteral";
                    ObjectFlags3[ObjectFlags3["FreshLiteral"] = 8192] = "FreshLiteral";
                    ObjectFlags3[ObjectFlags3["ArrayLiteral"] = 16384] = "ArrayLiteral";
                    ObjectFlags3[ObjectFlags3["PrimitiveUnion"] = 32768] = "PrimitiveUnion";
                    ObjectFlags3[ObjectFlags3["ContainsWideningType"] = 65536] = "ContainsWideningType";
                    ObjectFlags3[ObjectFlags3["ContainsObjectOrArrayLiteral"] = 131072] = "ContainsObjectOrArrayLiteral";
                    ObjectFlags3[ObjectFlags3["NonInferrableType"] = 262144] = "NonInferrableType";
                    ObjectFlags3[ObjectFlags3["CouldContainTypeVariablesComputed"] = 524288] = "CouldContainTypeVariablesComputed";
                    ObjectFlags3[ObjectFlags3["CouldContainTypeVariables"] = 1048576] = "CouldContainTypeVariables";
                    ObjectFlags3[ObjectFlags3["ClassOrInterface"] = 3] = "ClassOrInterface";
                    ObjectFlags3[ObjectFlags3["RequiresWidening"] = 196608] = "RequiresWidening";
                    ObjectFlags3[ObjectFlags3["PropagatingFlags"] = 458752] = "PropagatingFlags";
                    ObjectFlags3[ObjectFlags3["ObjectTypeKindMask"] = 1343] = "ObjectTypeKindMask";
                    ObjectFlags3[ObjectFlags3["ContainsSpread"] = 2097152] = "ContainsSpread";
                    ObjectFlags3[ObjectFlags3["ObjectRestType"] = 4194304] = "ObjectRestType";
                    ObjectFlags3[ObjectFlags3["InstantiationExpressionType"] = 8388608] = "InstantiationExpressionType";
                    ObjectFlags3[ObjectFlags3["IsClassInstanceClone"] = 16777216] = "IsClassInstanceClone";
                    ObjectFlags3[ObjectFlags3["IdenticalBaseTypeCalculated"] = 33554432] = "IdenticalBaseTypeCalculated";
                    ObjectFlags3[ObjectFlags3["IdenticalBaseTypeExists"] = 67108864] = "IdenticalBaseTypeExists";
                    ObjectFlags3[ObjectFlags3["IsGenericTypeComputed"] = 2097152] = "IsGenericTypeComputed";
                    ObjectFlags3[ObjectFlags3["IsGenericObjectType"] = 4194304] = "IsGenericObjectType";
                    ObjectFlags3[ObjectFlags3["IsGenericIndexType"] = 8388608] = "IsGenericIndexType";
                    ObjectFlags3[ObjectFlags3["IsGenericType"] = 12582912] = "IsGenericType";
                    ObjectFlags3[ObjectFlags3["ContainsIntersections"] = 16777216] = "ContainsIntersections";
                    ObjectFlags3[ObjectFlags3["IsUnknownLikeUnionComputed"] = 33554432] = "IsUnknownLikeUnionComputed";
                    ObjectFlags3[ObjectFlags3["IsUnknownLikeUnion"] = 67108864] = "IsUnknownLikeUnion";
                    ObjectFlags3[ObjectFlags3["IsNeverIntersectionComputed"] = 16777216] = "IsNeverIntersectionComputed";
                    ObjectFlags3[ObjectFlags3["IsNeverIntersection"] = 33554432] = "IsNeverIntersection";
                    return ObjectFlags3;
                })(ObjectFlags || {});
                VarianceFlags = /* @__PURE__ */ ((VarianceFlags2) => {
                    VarianceFlags2[VarianceFlags2["Invariant"] = 0] = "Invariant";
                    VarianceFlags2[VarianceFlags2["Covariant"] = 1] = "Covariant";
                    VarianceFlags2[VarianceFlags2["Contravariant"] = 2] = "Contravariant";
                    VarianceFlags2[VarianceFlags2["Bivariant"] = 3] = "Bivariant";
                    VarianceFlags2[VarianceFlags2["Independent"] = 4] = "Independent";
                    VarianceFlags2[VarianceFlags2["VarianceMask"] = 7] = "VarianceMask";
                    VarianceFlags2[VarianceFlags2["Unmeasurable"] = 8] = "Unmeasurable";
                    VarianceFlags2[VarianceFlags2["Unreliable"] = 16] = "Unreliable";
                    VarianceFlags2[VarianceFlags2["AllowsStructuralFallback"] = 24] = "AllowsStructuralFallback";
                    return VarianceFlags2;
                })(VarianceFlags || {});
                ElementFlags = /* @__PURE__ */ ((ElementFlags2) => {
                    ElementFlags2[ElementFlags2["Required"] = 1] = "Required";
                    ElementFlags2[ElementFlags2["Optional"] = 2] = "Optional";
                    ElementFlags2[ElementFlags2["Rest"] = 4] = "Rest";
                    ElementFlags2[ElementFlags2["Variadic"] = 8] = "Variadic";
                    ElementFlags2[ElementFlags2["Fixed"] = 3] = "Fixed";
                    ElementFlags2[ElementFlags2["Variable"] = 12] = "Variable";
                    ElementFlags2[ElementFlags2["NonRequired"] = 14] = "NonRequired";
                    ElementFlags2[ElementFlags2["NonRest"] = 11] = "NonRest";
                    return ElementFlags2;
                })(ElementFlags || {});
                AccessFlags = /* @__PURE__ */ ((AccessFlags2) => {
                    AccessFlags2[AccessFlags2["None"] = 0] = "None";
                    AccessFlags2[AccessFlags2["IncludeUndefined"] = 1] = "IncludeUndefined";
                    AccessFlags2[AccessFlags2["NoIndexSignatures"] = 2] = "NoIndexSignatures";
                    AccessFlags2[AccessFlags2["Writing"] = 4] = "Writing";
                    AccessFlags2[AccessFlags2["CacheSymbol"] = 8] = "CacheSymbol";
                    AccessFlags2[AccessFlags2["NoTupleBoundsCheck"] = 16] = "NoTupleBoundsCheck";
                    AccessFlags2[AccessFlags2["ExpressionPosition"] = 32] = "ExpressionPosition";
                    AccessFlags2[AccessFlags2["ReportDeprecated"] = 64] = "ReportDeprecated";
                    AccessFlags2[AccessFlags2["SuppressNoImplicitAnyError"] = 128] = "SuppressNoImplicitAnyError";
                    AccessFlags2[AccessFlags2["Contextual"] = 256] = "Contextual";
                    AccessFlags2[AccessFlags2["Persistent"] = 1 /* IncludeUndefined */] = "Persistent";
                    return AccessFlags2;
                })(AccessFlags || {});
                JsxReferenceKind = /* @__PURE__ */ ((JsxReferenceKind2) => {
                    JsxReferenceKind2[JsxReferenceKind2["Component"] = 0] = "Component";
                    JsxReferenceKind2[JsxReferenceKind2["Function"] = 1] = "Function";
                    JsxReferenceKind2[JsxReferenceKind2["Mixed"] = 2] = "Mixed";
                    return JsxReferenceKind2;
                })(JsxReferenceKind || {});
                SignatureKind = /* @__PURE__ */ ((SignatureKind2) => {
                    SignatureKind2[SignatureKind2["Call"] = 0] = "Call";
                    SignatureKind2[SignatureKind2["Construct"] = 1] = "Construct";
                    return SignatureKind2;
                })(SignatureKind || {});
                SignatureFlags = /* @__PURE__ */ ((SignatureFlags5) => {
                    SignatureFlags5[SignatureFlags5["None"] = 0] = "None";
                    SignatureFlags5[SignatureFlags5["HasRestParameter"] = 1] = "HasRestParameter";
                    SignatureFlags5[SignatureFlags5["HasLiteralTypes"] = 2] = "HasLiteralTypes";
                    SignatureFlags5[SignatureFlags5["Abstract"] = 4] = "Abstract";
                    SignatureFlags5[SignatureFlags5["IsInnerCallChain"] = 8] = "IsInnerCallChain";
                    SignatureFlags5[SignatureFlags5["IsOuterCallChain"] = 16] = "IsOuterCallChain";
                    SignatureFlags5[SignatureFlags5["IsUntypedSignatureInJSFile"] = 32] = "IsUntypedSignatureInJSFile";
                    SignatureFlags5[SignatureFlags5["PropagatingFlags"] = 39] = "PropagatingFlags";
                    SignatureFlags5[SignatureFlags5["CallChainFlags"] = 24] = "CallChainFlags";
                    return SignatureFlags5;
                })(SignatureFlags || {});
                IndexKind = /* @__PURE__ */ ((IndexKind2) => {
                    IndexKind2[IndexKind2["String"] = 0] = "String";
                    IndexKind2[IndexKind2["Number"] = 1] = "Number";
                    return IndexKind2;
                })(IndexKind || {});
                TypeMapKind = /* @__PURE__ */ ((TypeMapKind2) => {
                    TypeMapKind2[TypeMapKind2["Simple"] = 0] = "Simple";
                    TypeMapKind2[TypeMapKind2["Array"] = 1] = "Array";
                    TypeMapKind2[TypeMapKind2["Deferred"] = 2] = "Deferred";
                    TypeMapKind2[TypeMapKind2["Function"] = 3] = "Function";
                    TypeMapKind2[TypeMapKind2["Composite"] = 4] = "Composite";
                    TypeMapKind2[TypeMapKind2["Merged"] = 5] = "Merged";
                    return TypeMapKind2;
                })(TypeMapKind || {});
                InferencePriority = /* @__PURE__ */ ((InferencePriority2) => {
                    InferencePriority2[InferencePriority2["None"] = 0] = "None";
                    InferencePriority2[InferencePriority2["NakedTypeVariable"] = 1] = "NakedTypeVariable";
                    InferencePriority2[InferencePriority2["SpeculativeTuple"] = 2] = "SpeculativeTuple";
                    InferencePriority2[InferencePriority2["SubstituteSource"] = 4] = "SubstituteSource";
                    InferencePriority2[InferencePriority2["HomomorphicMappedType"] = 8] = "HomomorphicMappedType";
                    InferencePriority2[InferencePriority2["PartialHomomorphicMappedType"] = 16] = "PartialHomomorphicMappedType";
                    InferencePriority2[InferencePriority2["MappedTypeConstraint"] = 32] = "MappedTypeConstraint";
                    InferencePriority2[InferencePriority2["ContravariantConditional"] = 64] = "ContravariantConditional";
                    InferencePriority2[InferencePriority2["ReturnType"] = 128] = "ReturnType";
                    InferencePriority2[InferencePriority2["LiteralKeyof"] = 256] = "LiteralKeyof";
                    InferencePriority2[InferencePriority2["NoConstraints"] = 512] = "NoConstraints";
                    InferencePriority2[InferencePriority2["AlwaysStrict"] = 1024] = "AlwaysStrict";
                    InferencePriority2[InferencePriority2["MaxValue"] = 2048] = "MaxValue";
                    InferencePriority2[InferencePriority2["PriorityImpliesCombination"] = 416] = "PriorityImpliesCombination";
                    InferencePriority2[InferencePriority2["Circularity"] = -1] = "Circularity";
                    return InferencePriority2;
                })(InferencePriority || {});
                InferenceFlags = /* @__PURE__ */ ((InferenceFlags2) => {
                    InferenceFlags2[InferenceFlags2["None"] = 0] = "None";
                    InferenceFlags2[InferenceFlags2["NoDefault"] = 1] = "NoDefault";
                    InferenceFlags2[InferenceFlags2["AnyDefault"] = 2] = "AnyDefault";
                    InferenceFlags2[InferenceFlags2["SkippedGenericFunction"] = 4] = "SkippedGenericFunction";
                    return InferenceFlags2;
                })(InferenceFlags || {});
                Ternary = /* @__PURE__ */ ((Ternary2) => {
                    Ternary2[Ternary2["False"] = 0] = "False";
                    Ternary2[Ternary2["Unknown"] = 1] = "Unknown";
                    Ternary2[Ternary2["Maybe"] = 3] = "Maybe";
                    Ternary2[Ternary2["True"] = -1] = "True";
                    return Ternary2;
                })(Ternary || {});
                AssignmentDeclarationKind = /* @__PURE__ */ ((AssignmentDeclarationKind2) => {
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["None"] = 0] = "None";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ExportsProperty"] = 1] = "ExportsProperty";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ModuleExports"] = 2] = "ModuleExports";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["PrototypeProperty"] = 3] = "PrototypeProperty";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ThisProperty"] = 4] = "ThisProperty";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["Property"] = 5] = "Property";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["Prototype"] = 6] = "Prototype";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ObjectDefinePropertyValue"] = 7] = "ObjectDefinePropertyValue";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ObjectDefinePropertyExports"] = 8] = "ObjectDefinePropertyExports";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ObjectDefinePrototypeProperty"] = 9] = "ObjectDefinePrototypeProperty";
                    return AssignmentDeclarationKind2;
                })(AssignmentDeclarationKind || {});
                DiagnosticCategory = /* @__PURE__ */ ((DiagnosticCategory2) => {
                    DiagnosticCategory2[DiagnosticCategory2["Warning"] = 0] = "Warning";
                    DiagnosticCategory2[DiagnosticCategory2["Error"] = 1] = "Error";
                    DiagnosticCategory2[DiagnosticCategory2["Suggestion"] = 2] = "Suggestion";
                    DiagnosticCategory2[DiagnosticCategory2["Message"] = 3] = "Message";
                    return DiagnosticCategory2;
                })(DiagnosticCategory || {});
                ModuleResolutionKind = /* @__PURE__ */ ((ModuleResolutionKind2) => {
                    ModuleResolutionKind2[ModuleResolutionKind2["Classic"] = 1] = "Classic";
                    ModuleResolutionKind2[ModuleResolutionKind2["NodeJs"] = 2] = "NodeJs";
                    ModuleResolutionKind2[ModuleResolutionKind2["Node10"] = 2] = "Node10";
                    ModuleResolutionKind2[ModuleResolutionKind2["Node16"] = 3] = "Node16";
                    ModuleResolutionKind2[ModuleResolutionKind2["NodeNext"] = 99] = "NodeNext";
                    ModuleResolutionKind2[ModuleResolutionKind2["Bundler"] = 100] = "Bundler";
                    return ModuleResolutionKind2;
                })(ModuleResolutionKind || {});
                ModuleDetectionKind = /* @__PURE__ */ ((ModuleDetectionKind2) => {
                    ModuleDetectionKind2[ModuleDetectionKind2["Legacy"] = 1] = "Legacy";
                    ModuleDetectionKind2[ModuleDetectionKind2["Auto"] = 2] = "Auto";
                    ModuleDetectionKind2[ModuleDetectionKind2["Force"] = 3] = "Force";
                    return ModuleDetectionKind2;
                })(ModuleDetectionKind || {});
                WatchFileKind = /* @__PURE__ */ ((WatchFileKind2) => {
                    WatchFileKind2[WatchFileKind2["FixedPollingInterval"] = 0] = "FixedPollingInterval";
                    WatchFileKind2[WatchFileKind2["PriorityPollingInterval"] = 1] = "PriorityPollingInterval";
                    WatchFileKind2[WatchFileKind2["DynamicPriorityPolling"] = 2] = "DynamicPriorityPolling";
                    WatchFileKind2[WatchFileKind2["FixedChunkSizePolling"] = 3] = "FixedChunkSizePolling";
                    WatchFileKind2[WatchFileKind2["UseFsEvents"] = 4] = "UseFsEvents";
                    WatchFileKind2[WatchFileKind2["UseFsEventsOnParentDirectory"] = 5] = "UseFsEventsOnParentDirectory";
                    return WatchFileKind2;
                })(WatchFileKind || {});
                WatchDirectoryKind = /* @__PURE__ */ ((WatchDirectoryKind2) => {
                    WatchDirectoryKind2[WatchDirectoryKind2["UseFsEvents"] = 0] = "UseFsEvents";
                    WatchDirectoryKind2[WatchDirectoryKind2["FixedPollingInterval"] = 1] = "FixedPollingInterval";
                    WatchDirectoryKind2[WatchDirectoryKind2["DynamicPriorityPolling"] = 2] = "DynamicPriorityPolling";
                    WatchDirectoryKind2[WatchDirectoryKind2["FixedChunkSizePolling"] = 3] = "FixedChunkSizePolling";
                    return WatchDirectoryKind2;
                })(WatchDirectoryKind || {});
                PollingWatchKind = /* @__PURE__ */ ((PollingWatchKind2) => {
                    PollingWatchKind2[PollingWatchKind2["FixedInterval"] = 0] = "FixedInterval";
                    PollingWatchKind2[PollingWatchKind2["PriorityInterval"] = 1] = "PriorityInterval";
                    PollingWatchKind2[PollingWatchKind2["DynamicPriority"] = 2] = "DynamicPriority";
                    PollingWatchKind2[PollingWatchKind2["FixedChunkSize"] = 3] = "FixedChunkSize";
                    return PollingWatchKind2;
                })(PollingWatchKind || {});
                ModuleKind = /* @__PURE__ */ ((ModuleKind2) => {
                    ModuleKind2[ModuleKind2["None"] = 0] = "None";
                    ModuleKind2[ModuleKind2["CommonJS"] = 1] = "CommonJS";
                    ModuleKind2[ModuleKind2["AMD"] = 2] = "AMD";
                    ModuleKind2[ModuleKind2["UMD"] = 3] = "UMD";
                    ModuleKind2[ModuleKind2["System"] = 4] = "System";
                    ModuleKind2[ModuleKind2["ES2015"] = 5] = "ES2015";
                    ModuleKind2[ModuleKind2["ES2020"] = 6] = "ES2020";
                    ModuleKind2[ModuleKind2["ES2022"] = 7] = "ES2022";
                    ModuleKind2[ModuleKind2["ESNext"] = 99] = "ESNext";
                    ModuleKind2[ModuleKind2["Node16"] = 100] = "Node16";
                    ModuleKind2[ModuleKind2["NodeNext"] = 199] = "NodeNext";
                    return ModuleKind2;
                })(ModuleKind || {});
                JsxEmit = /* @__PURE__ */ ((JsxEmit2) => {
                    JsxEmit2[JsxEmit2["None"] = 0] = "None";
                    JsxEmit2[JsxEmit2["Preserve"] = 1] = "Preserve";
                    JsxEmit2[JsxEmit2["React"] = 2] = "React";
                    JsxEmit2[JsxEmit2["ReactNative"] = 3] = "ReactNative";
                    JsxEmit2[JsxEmit2["ReactJSX"] = 4] = "ReactJSX";
                    JsxEmit2[JsxEmit2["ReactJSXDev"] = 5] = "ReactJSXDev";
                    return JsxEmit2;
                })(JsxEmit || {});
                ImportsNotUsedAsValues = /* @__PURE__ */ ((ImportsNotUsedAsValues2) => {
                    ImportsNotUsedAsValues2[ImportsNotUsedAsValues2["Remove"] = 0] = "Remove";
                    ImportsNotUsedAsValues2[ImportsNotUsedAsValues2["Preserve"] = 1] = "Preserve";
                    ImportsNotUsedAsValues2[ImportsNotUsedAsValues2["Error"] = 2] = "Error";
                    return ImportsNotUsedAsValues2;
                })(ImportsNotUsedAsValues || {});
                NewLineKind = /* @__PURE__ */ ((NewLineKind2) => {
                    NewLineKind2[NewLineKind2["CarriageReturnLineFeed"] = 0] = "CarriageReturnLineFeed";
                    NewLineKind2[NewLineKind2["LineFeed"] = 1] = "LineFeed";
                    return NewLineKind2;
                })(NewLineKind || {});
                ScriptKind = /* @__PURE__ */ ((ScriptKind5) => {
                    ScriptKind5[ScriptKind5["Unknown"] = 0] = "Unknown";
                    ScriptKind5[ScriptKind5["JS"] = 1] = "JS";
                    ScriptKind5[ScriptKind5["JSX"] = 2] = "JSX";
                    ScriptKind5[ScriptKind5["TS"] = 3] = "TS";
                    ScriptKind5[ScriptKind5["TSX"] = 4] = "TSX";
                    ScriptKind5[ScriptKind5["External"] = 5] = "External";
                    ScriptKind5[ScriptKind5["JSON"] = 6] = "JSON";
                    ScriptKind5[ScriptKind5["Deferred"] = 7] = "Deferred";
                    return ScriptKind5;
                })(ScriptKind || {});
                ScriptTarget = /* @__PURE__ */ ((ScriptTarget10) => {
                    ScriptTarget10[ScriptTarget10["ES3"] = 0] = "ES3";
                    ScriptTarget10[ScriptTarget10["ES5"] = 1] = "ES5";
                    ScriptTarget10[ScriptTarget10["ES2015"] = 2] = "ES2015";
                    ScriptTarget10[ScriptTarget10["ES2016"] = 3] = "ES2016";
                    ScriptTarget10[ScriptTarget10["ES2017"] = 4] = "ES2017";
                    ScriptTarget10[ScriptTarget10["ES2018"] = 5] = "ES2018";
                    ScriptTarget10[ScriptTarget10["ES2019"] = 6] = "ES2019";
                    ScriptTarget10[ScriptTarget10["ES2020"] = 7] = "ES2020";
                    ScriptTarget10[ScriptTarget10["ES2021"] = 8] = "ES2021";
                    ScriptTarget10[ScriptTarget10["ES2022"] = 9] = "ES2022";
                    ScriptTarget10[ScriptTarget10["ESNext"] = 99] = "ESNext";
                    ScriptTarget10[ScriptTarget10["JSON"] = 100] = "JSON";
                    ScriptTarget10[ScriptTarget10["Latest"] = 99 /* ESNext */] = "Latest";
                    return ScriptTarget10;
                })(ScriptTarget || {});
                LanguageVariant = /* @__PURE__ */ ((LanguageVariant4) => {
                    LanguageVariant4[LanguageVariant4["Standard"] = 0] = "Standard";
                    LanguageVariant4[LanguageVariant4["JSX"] = 1] = "JSX";
                    return LanguageVariant4;
                })(LanguageVariant || {});
                WatchDirectoryFlags = /* @__PURE__ */ ((WatchDirectoryFlags3) => {
                    WatchDirectoryFlags3[WatchDirectoryFlags3["None"] = 0] = "None";
                    WatchDirectoryFlags3[WatchDirectoryFlags3["Recursive"] = 1] = "Recursive";
                    return WatchDirectoryFlags3;
                })(WatchDirectoryFlags || {});
                CharacterCodes = /* @__PURE__ */ ((CharacterCodes2) => {
                    CharacterCodes2[CharacterCodes2["nullCharacter"] = 0] = "nullCharacter";
                    CharacterCodes2[CharacterCodes2["maxAsciiCharacter"] = 127] = "maxAsciiCharacter";
                    CharacterCodes2[CharacterCodes2["lineFeed"] = 10] = "lineFeed";
                    CharacterCodes2[CharacterCodes2["carriageReturn"] = 13] = "carriageReturn";
                    CharacterCodes2[CharacterCodes2["lineSeparator"] = 8232] = "lineSeparator";
                    CharacterCodes2[CharacterCodes2["paragraphSeparator"] = 8233] = "paragraphSeparator";
                    CharacterCodes2[CharacterCodes2["nextLine"] = 133] = "nextLine";
                    CharacterCodes2[CharacterCodes2["space"] = 32] = "space";
                    CharacterCodes2[CharacterCodes2["nonBreakingSpace"] = 160] = "nonBreakingSpace";
                    CharacterCodes2[CharacterCodes2["enQuad"] = 8192] = "enQuad";
                    CharacterCodes2[CharacterCodes2["emQuad"] = 8193] = "emQuad";
                    CharacterCodes2[CharacterCodes2["enSpace"] = 8194] = "enSpace";
                    CharacterCodes2[CharacterCodes2["emSpace"] = 8195] = "emSpace";
                    CharacterCodes2[CharacterCodes2["threePerEmSpace"] = 8196] = "threePerEmSpace";
                    CharacterCodes2[CharacterCodes2["fourPerEmSpace"] = 8197] = "fourPerEmSpace";
                    CharacterCodes2[CharacterCodes2["sixPerEmSpace"] = 8198] = "sixPerEmSpace";
                    CharacterCodes2[CharacterCodes2["figureSpace"] = 8199] = "figureSpace";
                    CharacterCodes2[CharacterCodes2["punctuationSpace"] = 8200] = "punctuationSpace";
                    CharacterCodes2[CharacterCodes2["thinSpace"] = 8201] = "thinSpace";
                    CharacterCodes2[CharacterCodes2["hairSpace"] = 8202] = "hairSpace";
                    CharacterCodes2[CharacterCodes2["zeroWidthSpace"] = 8203] = "zeroWidthSpace";
                    CharacterCodes2[CharacterCodes2["narrowNoBreakSpace"] = 8239] = "narrowNoBreakSpace";
                    CharacterCodes2[CharacterCodes2["ideographicSpace"] = 12288] = "ideographicSpace";
                    CharacterCodes2[CharacterCodes2["mathematicalSpace"] = 8287] = "mathematicalSpace";
                    CharacterCodes2[CharacterCodes2["ogham"] = 5760] = "ogham";
                    CharacterCodes2[CharacterCodes2["_"] = 95] = "_";
                    CharacterCodes2[CharacterCodes2["$"] = 36] = "$";
                    CharacterCodes2[CharacterCodes2["_0"] = 48] = "_0";
                    CharacterCodes2[CharacterCodes2["_1"] = 49] = "_1";
                    CharacterCodes2[CharacterCodes2["_2"] = 50] = "_2";
                    CharacterCodes2[CharacterCodes2["_3"] = 51] = "_3";
                    CharacterCodes2[CharacterCodes2["_4"] = 52] = "_4";
                    CharacterCodes2[CharacterCodes2["_5"] = 53] = "_5";
                    CharacterCodes2[CharacterCodes2["_6"] = 54] = "_6";
                    CharacterCodes2[CharacterCodes2["_7"] = 55] = "_7";
                    CharacterCodes2[CharacterCodes2["_8"] = 56] = "_8";
                    CharacterCodes2[CharacterCodes2["_9"] = 57] = "_9";
                    CharacterCodes2[CharacterCodes2["a"] = 97] = "a";
                    CharacterCodes2[CharacterCodes2["b"] = 98] = "b";
                    CharacterCodes2[CharacterCodes2["c"] = 99] = "c";
                    CharacterCodes2[CharacterCodes2["d"] = 100] = "d";
                    CharacterCodes2[CharacterCodes2["e"] = 101] = "e";
                    CharacterCodes2[CharacterCodes2["f"] = 102] = "f";
                    CharacterCodes2[CharacterCodes2["g"] = 103] = "g";
                    CharacterCodes2[CharacterCodes2["h"] = 104] = "h";
                    CharacterCodes2[CharacterCodes2["i"] = 105] = "i";
                    CharacterCodes2[CharacterCodes2["j"] = 106] = "j";
                    CharacterCodes2[CharacterCodes2["k"] = 107] = "k";
                    CharacterCodes2[CharacterCodes2["l"] = 108] = "l";
                    CharacterCodes2[CharacterCodes2["m"] = 109] = "m";
                    CharacterCodes2[CharacterCodes2["n"] = 110] = "n";
                    CharacterCodes2[CharacterCodes2["o"] = 111] = "o";
                    CharacterCodes2[CharacterCodes2["p"] = 112] = "p";
                    CharacterCodes2[CharacterCodes2["q"] = 113] = "q";
                    CharacterCodes2[CharacterCodes2["r"] = 114] = "r";
                    CharacterCodes2[CharacterCodes2["s"] = 115] = "s";
                    CharacterCodes2[CharacterCodes2["t"] = 116] = "t";
                    CharacterCodes2[CharacterCodes2["u"] = 117] = "u";
                    CharacterCodes2[CharacterCodes2["v"] = 118] = "v";
                    CharacterCodes2[CharacterCodes2["w"] = 119] = "w";
                    CharacterCodes2[CharacterCodes2["x"] = 120] = "x";
                    CharacterCodes2[CharacterCodes2["y"] = 121] = "y";
                    CharacterCodes2[CharacterCodes2["z"] = 122] = "z";
                    CharacterCodes2[CharacterCodes2["A"] = 65] = "A";
                    CharacterCodes2[CharacterCodes2["B"] = 66] = "B";
                    CharacterCodes2[CharacterCodes2["C"] = 67] = "C";
                    CharacterCodes2[CharacterCodes2["D"] = 68] = "D";
                    CharacterCodes2[CharacterCodes2["E"] = 69] = "E";
                    CharacterCodes2[CharacterCodes2["F"] = 70] = "F";
                    CharacterCodes2[CharacterCodes2["G"] = 71] = "G";
                    CharacterCodes2[CharacterCodes2["H"] = 72] = "H";
                    CharacterCodes2[CharacterCodes2["I"] = 73] = "I";
                    CharacterCodes2[CharacterCodes2["J"] = 74] = "J";
                    CharacterCodes2[CharacterCodes2["K"] = 75] = "K";
                    CharacterCodes2[CharacterCodes2["L"] = 76] = "L";
                    CharacterCodes2[CharacterCodes2["M"] = 77] = "M";
                    CharacterCodes2[CharacterCodes2["N"] = 78] = "N";
                    CharacterCodes2[CharacterCodes2["O"] = 79] = "O";
                    CharacterCodes2[CharacterCodes2["P"] = 80] = "P";
                    CharacterCodes2[CharacterCodes2["Q"] = 81] = "Q";
                    CharacterCodes2[CharacterCodes2["R"] = 82] = "R";
                    CharacterCodes2[CharacterCodes2["S"] = 83] = "S";
                    CharacterCodes2[CharacterCodes2["T"] = 84] = "T";
                    CharacterCodes2[CharacterCodes2["U"] = 85] = "U";
                    CharacterCodes2[CharacterCodes2["V"] = 86] = "V";
                    CharacterCodes2[CharacterCodes2["W"] = 87] = "W";
                    CharacterCodes2[CharacterCodes2["X"] = 88] = "X";
                    CharacterCodes2[CharacterCodes2["Y"] = 89] = "Y";
                    CharacterCodes2[CharacterCodes2["Z"] = 90] = "Z";
                    CharacterCodes2[CharacterCodes2["ampersand"] = 38] = "ampersand";
                    CharacterCodes2[CharacterCodes2["asterisk"] = 42] = "asterisk";
                    CharacterCodes2[CharacterCodes2["at"] = 64] = "at";
                    CharacterCodes2[CharacterCodes2["backslash"] = 92] = "backslash";
                    CharacterCodes2[CharacterCodes2["backtick"] = 96] = "backtick";
                    CharacterCodes2[CharacterCodes2["bar"] = 124] = "bar";
                    CharacterCodes2[CharacterCodes2["caret"] = 94] = "caret";
                    CharacterCodes2[CharacterCodes2["closeBrace"] = 125] = "closeBrace";
                    CharacterCodes2[CharacterCodes2["closeBracket"] = 93] = "closeBracket";
                    CharacterCodes2[CharacterCodes2["closeParen"] = 41] = "closeParen";
                    CharacterCodes2[CharacterCodes2["colon"] = 58] = "colon";
                    CharacterCodes2[CharacterCodes2["comma"] = 44] = "comma";
                    CharacterCodes2[CharacterCodes2["dot"] = 46] = "dot";
                    CharacterCodes2[CharacterCodes2["doubleQuote"] = 34] = "doubleQuote";
                    CharacterCodes2[CharacterCodes2["equals"] = 61] = "equals";
                    CharacterCodes2[CharacterCodes2["exclamation"] = 33] = "exclamation";
                    CharacterCodes2[CharacterCodes2["greaterThan"] = 62] = "greaterThan";
                    CharacterCodes2[CharacterCodes2["hash"] = 35] = "hash";
                    CharacterCodes2[CharacterCodes2["lessThan"] = 60] = "lessThan";
                    CharacterCodes2[CharacterCodes2["minus"] = 45] = "minus";
                    CharacterCodes2[CharacterCodes2["openBrace"] = 123] = "openBrace";
                    CharacterCodes2[CharacterCodes2["openBracket"] = 91] = "openBracket";
                    CharacterCodes2[CharacterCodes2["openParen"] = 40] = "openParen";
                    CharacterCodes2[CharacterCodes2["percent"] = 37] = "percent";
                    CharacterCodes2[CharacterCodes2["plus"] = 43] = "plus";
                    CharacterCodes2[CharacterCodes2["question"] = 63] = "question";
                    CharacterCodes2[CharacterCodes2["semicolon"] = 59] = "semicolon";
                    CharacterCodes2[CharacterCodes2["singleQuote"] = 39] = "singleQuote";
                    CharacterCodes2[CharacterCodes2["slash"] = 47] = "slash";
                    CharacterCodes2[CharacterCodes2["tilde"] = 126] = "tilde";
                    CharacterCodes2[CharacterCodes2["backspace"] = 8] = "backspace";
                    CharacterCodes2[CharacterCodes2["formFeed"] = 12] = "formFeed";
                    CharacterCodes2[CharacterCodes2["byteOrderMark"] = 65279] = "byteOrderMark";
                    CharacterCodes2[CharacterCodes2["tab"] = 9] = "tab";
                    CharacterCodes2[CharacterCodes2["verticalTab"] = 11] = "verticalTab";
                    return CharacterCodes2;
                })(CharacterCodes || {});
                Extension = /* @__PURE__ */ ((Extension2) => {
                    Extension2["Ts"] = ".ts";
                    Extension2["Tsx"] = ".tsx";
                    Extension2["Dts"] = ".d.ts";
                    Extension2["Js"] = ".js";
                    Extension2["Jsx"] = ".jsx";
                    Extension2["Json"] = ".json";
                    Extension2["TsBuildInfo"] = ".tsbuildinfo";
                    Extension2["Mjs"] = ".mjs";
                    Extension2["Mts"] = ".mts";
                    Extension2["Dmts"] = ".d.mts";
                    Extension2["Cjs"] = ".cjs";
                    Extension2["Cts"] = ".cts";
                    Extension2["Dcts"] = ".d.cts";
                    return Extension2;
                })(Extension || {});
                TransformFlags = /* @__PURE__ */ ((TransformFlags3) => {
                    TransformFlags3[TransformFlags3["None"] = 0] = "None";
                    TransformFlags3[TransformFlags3["ContainsTypeScript"] = 1] = "ContainsTypeScript";
                    TransformFlags3[TransformFlags3["ContainsJsx"] = 2] = "ContainsJsx";
                    TransformFlags3[TransformFlags3["ContainsESNext"] = 4] = "ContainsESNext";
                    TransformFlags3[TransformFlags3["ContainsES2022"] = 8] = "ContainsES2022";
                    TransformFlags3[TransformFlags3["ContainsES2021"] = 16] = "ContainsES2021";
                    TransformFlags3[TransformFlags3["ContainsES2020"] = 32] = "ContainsES2020";
                    TransformFlags3[TransformFlags3["ContainsES2019"] = 64] = "ContainsES2019";
                    TransformFlags3[TransformFlags3["ContainsES2018"] = 128] = "ContainsES2018";
                    TransformFlags3[TransformFlags3["ContainsES2017"] = 256] = "ContainsES2017";
                    TransformFlags3[TransformFlags3["ContainsES2016"] = 512] = "ContainsES2016";
                    TransformFlags3[TransformFlags3["ContainsES2015"] = 1024] = "ContainsES2015";
                    TransformFlags3[TransformFlags3["ContainsGenerator"] = 2048] = "ContainsGenerator";
                    TransformFlags3[TransformFlags3["ContainsDestructuringAssignment"] = 4096] = "ContainsDestructuringAssignment";
                    TransformFlags3[TransformFlags3["ContainsTypeScriptClassSyntax"] = 8192] = "ContainsTypeScriptClassSyntax";
                    TransformFlags3[TransformFlags3["ContainsLexicalThis"] = 16384] = "ContainsLexicalThis";
                    TransformFlags3[TransformFlags3["ContainsRestOrSpread"] = 32768] = "ContainsRestOrSpread";
                    TransformFlags3[TransformFlags3["ContainsObjectRestOrSpread"] = 65536] = "ContainsObjectRestOrSpread";
                    TransformFlags3[TransformFlags3["ContainsComputedPropertyName"] = 131072] = "ContainsComputedPropertyName";
                    TransformFlags3[TransformFlags3["ContainsBlockScopedBinding"] = 262144] = "ContainsBlockScopedBinding";
                    TransformFlags3[TransformFlags3["ContainsBindingPattern"] = 524288] = "ContainsBindingPattern";
                    TransformFlags3[TransformFlags3["ContainsYield"] = 1048576] = "ContainsYield";
                    TransformFlags3[TransformFlags3["ContainsAwait"] = 2097152] = "ContainsAwait";
                    TransformFlags3[TransformFlags3["ContainsHoistedDeclarationOrCompletion"] = 4194304] = "ContainsHoistedDeclarationOrCompletion";
                    TransformFlags3[TransformFlags3["ContainsDynamicImport"] = 8388608] = "ContainsDynamicImport";
                    TransformFlags3[TransformFlags3["ContainsClassFields"] = 16777216] = "ContainsClassFields";
                    TransformFlags3[TransformFlags3["ContainsDecorators"] = 33554432] = "ContainsDecorators";
                    TransformFlags3[TransformFlags3["ContainsPossibleTopLevelAwait"] = 67108864] = "ContainsPossibleTopLevelAwait";
                    TransformFlags3[TransformFlags3["ContainsLexicalSuper"] = 134217728] = "ContainsLexicalSuper";
                    TransformFlags3[TransformFlags3["ContainsUpdateExpressionForIdentifier"] = 268435456] = "ContainsUpdateExpressionForIdentifier";
                    TransformFlags3[TransformFlags3["ContainsPrivateIdentifierInExpression"] = 536870912] = "ContainsPrivateIdentifierInExpression";
                    TransformFlags3[TransformFlags3["HasComputedFlags"] = -2147483648] = "HasComputedFlags";
                    TransformFlags3[TransformFlags3["AssertTypeScript"] = 1 /* ContainsTypeScript */] = "AssertTypeScript";
                    TransformFlags3[TransformFlags3["AssertJsx"] = 2 /* ContainsJsx */] = "AssertJsx";
                    TransformFlags3[TransformFlags3["AssertESNext"] = 4 /* ContainsESNext */] = "AssertESNext";
                    TransformFlags3[TransformFlags3["AssertES2022"] = 8 /* ContainsES2022 */] = "AssertES2022";
                    TransformFlags3[TransformFlags3["AssertES2021"] = 16 /* ContainsES2021 */] = "AssertES2021";
                    TransformFlags3[TransformFlags3["AssertES2020"] = 32 /* ContainsES2020 */] = "AssertES2020";
                    TransformFlags3[TransformFlags3["AssertES2019"] = 64 /* ContainsES2019 */] = "AssertES2019";
                    TransformFlags3[TransformFlags3["AssertES2018"] = 128 /* ContainsES2018 */] = "AssertES2018";
                    TransformFlags3[TransformFlags3["AssertES2017"] = 256 /* ContainsES2017 */] = "AssertES2017";
                    TransformFlags3[TransformFlags3["AssertES2016"] = 512 /* ContainsES2016 */] = "AssertES2016";
                    TransformFlags3[TransformFlags3["AssertES2015"] = 1024 /* ContainsES2015 */] = "AssertES2015";
                    TransformFlags3[TransformFlags3["AssertGenerator"] = 2048 /* ContainsGenerator */] = "AssertGenerator";
                    TransformFlags3[TransformFlags3["AssertDestructuringAssignment"] = 4096 /* ContainsDestructuringAssignment */] = "AssertDestructuringAssignment";
                    TransformFlags3[TransformFlags3["OuterExpressionExcludes"] = -2147483648 /* HasComputedFlags */] = "OuterExpressionExcludes";
                    TransformFlags3[TransformFlags3["PropertyAccessExcludes"] = -2147483648 /* OuterExpressionExcludes */] = "PropertyAccessExcludes";
                    TransformFlags3[TransformFlags3["NodeExcludes"] = -2147483648 /* PropertyAccessExcludes */] = "NodeExcludes";
                    TransformFlags3[TransformFlags3["ArrowFunctionExcludes"] = -2072174592] = "ArrowFunctionExcludes";
                    TransformFlags3[TransformFlags3["FunctionExcludes"] = -1937940480] = "FunctionExcludes";
                    TransformFlags3[TransformFlags3["ConstructorExcludes"] = -1937948672] = "ConstructorExcludes";
                    TransformFlags3[TransformFlags3["MethodOrAccessorExcludes"] = -2005057536] = "MethodOrAccessorExcludes";
                    TransformFlags3[TransformFlags3["PropertyExcludes"] = -2013249536] = "PropertyExcludes";
                    TransformFlags3[TransformFlags3["ClassExcludes"] = -2147344384] = "ClassExcludes";
                    TransformFlags3[TransformFlags3["ModuleExcludes"] = -1941676032] = "ModuleExcludes";
                    TransformFlags3[TransformFlags3["TypeExcludes"] = -2] = "TypeExcludes";
                    TransformFlags3[TransformFlags3["ObjectLiteralExcludes"] = -2147278848] = "ObjectLiteralExcludes";
                    TransformFlags3[TransformFlags3["ArrayLiteralOrCallOrNewExcludes"] = -2147450880] = "ArrayLiteralOrCallOrNewExcludes";
                    TransformFlags3[TransformFlags3["VariableDeclarationListExcludes"] = -2146893824] = "VariableDeclarationListExcludes";
                    TransformFlags3[TransformFlags3["ParameterExcludes"] = -2147483648 /* NodeExcludes */] = "ParameterExcludes";
                    TransformFlags3[TransformFlags3["CatchClauseExcludes"] = -2147418112] = "CatchClauseExcludes";
                    TransformFlags3[TransformFlags3["BindingPatternExcludes"] = -2147450880] = "BindingPatternExcludes";
                    TransformFlags3[TransformFlags3["ContainsLexicalThisOrSuper"] = 134234112] = "ContainsLexicalThisOrSuper";
                    TransformFlags3[TransformFlags3["PropertyNamePropagatingFlags"] = 134234112] = "PropertyNamePropagatingFlags";
                    return TransformFlags3;
                })(TransformFlags || {});
                SnippetKind = /* @__PURE__ */ ((SnippetKind3) => {
                    SnippetKind3[SnippetKind3["TabStop"] = 0] = "TabStop";
                    SnippetKind3[SnippetKind3["Placeholder"] = 1] = "Placeholder";
                    SnippetKind3[SnippetKind3["Choice"] = 2] = "Choice";
                    SnippetKind3[SnippetKind3["Variable"] = 3] = "Variable";
                    return SnippetKind3;
                })(SnippetKind || {});
                EmitFlags = /* @__PURE__ */ ((EmitFlags3) => {
                    EmitFlags3[EmitFlags3["None"] = 0] = "None";
                    EmitFlags3[EmitFlags3["SingleLine"] = 1] = "SingleLine";
                    EmitFlags3[EmitFlags3["MultiLine"] = 2] = "MultiLine";
                    EmitFlags3[EmitFlags3["AdviseOnEmitNode"] = 4] = "AdviseOnEmitNode";
                    EmitFlags3[EmitFlags3["NoSubstitution"] = 8] = "NoSubstitution";
                    EmitFlags3[EmitFlags3["CapturesThis"] = 16] = "CapturesThis";
                    EmitFlags3[EmitFlags3["NoLeadingSourceMap"] = 32] = "NoLeadingSourceMap";
                    EmitFlags3[EmitFlags3["NoTrailingSourceMap"] = 64] = "NoTrailingSourceMap";
                    EmitFlags3[EmitFlags3["NoSourceMap"] = 96] = "NoSourceMap";
                    EmitFlags3[EmitFlags3["NoNestedSourceMaps"] = 128] = "NoNestedSourceMaps";
                    EmitFlags3[EmitFlags3["NoTokenLeadingSourceMaps"] = 256] = "NoTokenLeadingSourceMaps";
                    EmitFlags3[EmitFlags3["NoTokenTrailingSourceMaps"] = 512] = "NoTokenTrailingSourceMaps";
                    EmitFlags3[EmitFlags3["NoTokenSourceMaps"] = 768] = "NoTokenSourceMaps";
                    EmitFlags3[EmitFlags3["NoLeadingComments"] = 1024] = "NoLeadingComments";
                    EmitFlags3[EmitFlags3["NoTrailingComments"] = 2048] = "NoTrailingComments";
                    EmitFlags3[EmitFlags3["NoComments"] = 3072] = "NoComments";
                    EmitFlags3[EmitFlags3["NoNestedComments"] = 4096] = "NoNestedComments";
                    EmitFlags3[EmitFlags3["HelperName"] = 8192] = "HelperName";
                    EmitFlags3[EmitFlags3["ExportName"] = 16384] = "ExportName";
                    EmitFlags3[EmitFlags3["LocalName"] = 32768] = "LocalName";
                    EmitFlags3[EmitFlags3["InternalName"] = 65536] = "InternalName";
                    EmitFlags3[EmitFlags3["Indented"] = 131072] = "Indented";
                    EmitFlags3[EmitFlags3["NoIndentation"] = 262144] = "NoIndentation";
                    EmitFlags3[EmitFlags3["AsyncFunctionBody"] = 524288] = "AsyncFunctionBody";
                    EmitFlags3[EmitFlags3["ReuseTempVariableScope"] = 1048576] = "ReuseTempVariableScope";
                    EmitFlags3[EmitFlags3["CustomPrologue"] = 2097152] = "CustomPrologue";
                    EmitFlags3[EmitFlags3["NoHoisting"] = 4194304] = "NoHoisting";
                    EmitFlags3[EmitFlags3["HasEndOfDeclarationMarker"] = 8388608] = "HasEndOfDeclarationMarker";
                    EmitFlags3[EmitFlags3["Iterator"] = 16777216] = "Iterator";
                    EmitFlags3[EmitFlags3["NoAsciiEscaping"] = 33554432] = "NoAsciiEscaping";
                    return EmitFlags3;
                })(EmitFlags || {});
                InternalEmitFlags = /* @__PURE__ */ ((InternalEmitFlags3) => {
                    InternalEmitFlags3[InternalEmitFlags3["None"] = 0] = "None";
                    InternalEmitFlags3[InternalEmitFlags3["TypeScriptClassWrapper"] = 1] = "TypeScriptClassWrapper";
                    InternalEmitFlags3[InternalEmitFlags3["NeverApplyImportHelper"] = 2] = "NeverApplyImportHelper";
                    InternalEmitFlags3[InternalEmitFlags3["IgnoreSourceNewlines"] = 4] = "IgnoreSourceNewlines";
                    InternalEmitFlags3[InternalEmitFlags3["Immutable"] = 8] = "Immutable";
                    InternalEmitFlags3[InternalEmitFlags3["IndirectCall"] = 16] = "IndirectCall";
                    InternalEmitFlags3[InternalEmitFlags3["TransformPrivateStaticElements"] = 32] = "TransformPrivateStaticElements";
                    return InternalEmitFlags3;
                })(InternalEmitFlags || {});
                ExternalEmitHelpers = /* @__PURE__ */ ((ExternalEmitHelpers2) => {
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Extends"] = 1] = "Extends";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Assign"] = 2] = "Assign";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Rest"] = 4] = "Rest";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Decorate"] = 8] = "Decorate";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ESDecorateAndRunInitializers"] = 8 /* Decorate */] = "ESDecorateAndRunInitializers";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Metadata"] = 16] = "Metadata";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Param"] = 32] = "Param";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Awaiter"] = 64] = "Awaiter";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Generator"] = 128] = "Generator";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Values"] = 256] = "Values";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Read"] = 512] = "Read";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["SpreadArray"] = 1024] = "SpreadArray";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Await"] = 2048] = "Await";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncGenerator"] = 4096] = "AsyncGenerator";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncDelegator"] = 8192] = "AsyncDelegator";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncValues"] = 16384] = "AsyncValues";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ExportStar"] = 32768] = "ExportStar";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ImportStar"] = 65536] = "ImportStar";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ImportDefault"] = 131072] = "ImportDefault";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["MakeTemplateObject"] = 262144] = "MakeTemplateObject";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ClassPrivateFieldGet"] = 524288] = "ClassPrivateFieldGet";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ClassPrivateFieldSet"] = 1048576] = "ClassPrivateFieldSet";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ClassPrivateFieldIn"] = 2097152] = "ClassPrivateFieldIn";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["CreateBinding"] = 4194304] = "CreateBinding";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["SetFunctionName"] = 8388608] = "SetFunctionName";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["PropKey"] = 16777216] = "PropKey";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["FirstEmitHelper"] = 1 /* Extends */] = "FirstEmitHelper";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["LastEmitHelper"] = 16777216 /* PropKey */] = "LastEmitHelper";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ForOfIncludes"] = 256 /* Values */] = "ForOfIncludes";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ForAwaitOfIncludes"] = 16384 /* AsyncValues */] = "ForAwaitOfIncludes";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncGeneratorIncludes"] = 6144] = "AsyncGeneratorIncludes";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncDelegatorIncludes"] = 26624] = "AsyncDelegatorIncludes";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["SpreadIncludes"] = 1536] = "SpreadIncludes";
                    return ExternalEmitHelpers2;
                })(ExternalEmitHelpers || {});
                EmitHint = /* @__PURE__ */ ((EmitHint6) => {
                    EmitHint6[EmitHint6["SourceFile"] = 0] = "SourceFile";
                    EmitHint6[EmitHint6["Expression"] = 1] = "Expression";
                    EmitHint6[EmitHint6["IdentifierName"] = 2] = "IdentifierName";
                    EmitHint6[EmitHint6["MappedTypeParameter"] = 3] = "MappedTypeParameter";
                    EmitHint6[EmitHint6["Unspecified"] = 4] = "Unspecified";
                    EmitHint6[EmitHint6["EmbeddedStatement"] = 5] = "EmbeddedStatement";
                    EmitHint6[EmitHint6["JsxAttributeValue"] = 6] = "JsxAttributeValue";
                    return EmitHint6;
                })(EmitHint || {});
                OuterExpressionKinds = /* @__PURE__ */ ((OuterExpressionKinds2) => {
                    OuterExpressionKinds2[OuterExpressionKinds2["Parentheses"] = 1] = "Parentheses";
                    OuterExpressionKinds2[OuterExpressionKinds2["TypeAssertions"] = 2] = "TypeAssertions";
                    OuterExpressionKinds2[OuterExpressionKinds2["NonNullAssertions"] = 4] = "NonNullAssertions";
                    OuterExpressionKinds2[OuterExpressionKinds2["PartiallyEmittedExpressions"] = 8] = "PartiallyEmittedExpressions";
                    OuterExpressionKinds2[OuterExpressionKinds2["Assertions"] = 6] = "Assertions";
                    OuterExpressionKinds2[OuterExpressionKinds2["All"] = 15] = "All";
                    OuterExpressionKinds2[OuterExpressionKinds2["ExcludeJSDocTypeAssertion"] = 16] = "ExcludeJSDocTypeAssertion";
                    return OuterExpressionKinds2;
                })(OuterExpressionKinds || {});
                LexicalEnvironmentFlags = /* @__PURE__ */ ((LexicalEnvironmentFlags2) => {
                    LexicalEnvironmentFlags2[LexicalEnvironmentFlags2["None"] = 0] = "None";
                    LexicalEnvironmentFlags2[LexicalEnvironmentFlags2["InParameters"] = 1] = "InParameters";
                    LexicalEnvironmentFlags2[LexicalEnvironmentFlags2["VariablesHoistedInParameters"] = 2] = "VariablesHoistedInParameters";
                    return LexicalEnvironmentFlags2;
                })(LexicalEnvironmentFlags || {});
                BundleFileSectionKind = /* @__PURE__ */ ((BundleFileSectionKind2) => {
                    BundleFileSectionKind2["Prologue"] = "prologue";
                    BundleFileSectionKind2["EmitHelpers"] = "emitHelpers";
                    BundleFileSectionKind2["NoDefaultLib"] = "no-default-lib";
                    BundleFileSectionKind2["Reference"] = "reference";
                    BundleFileSectionKind2["Type"] = "type";
                    BundleFileSectionKind2["TypeResolutionModeRequire"] = "type-require";
                    BundleFileSectionKind2["TypeResolutionModeImport"] = "type-import";
                    BundleFileSectionKind2["Lib"] = "lib";
                    BundleFileSectionKind2["Prepend"] = "prepend";
                    BundleFileSectionKind2["Text"] = "text";
                    BundleFileSectionKind2["Internal"] = "internal";
                    return BundleFileSectionKind2;
                })(BundleFileSectionKind || {});
                ListFormat = /* @__PURE__ */ ((ListFormat2) => {
                    ListFormat2[ListFormat2["None"] = 0] = "None";
                    ListFormat2[ListFormat2["SingleLine"] = 0] = "SingleLine";
                    ListFormat2[ListFormat2["MultiLine"] = 1] = "MultiLine";
                    ListFormat2[ListFormat2["PreserveLines"] = 2] = "PreserveLines";
                    ListFormat2[ListFormat2["LinesMask"] = 3] = "LinesMask";
                    ListFormat2[ListFormat2["NotDelimited"] = 0] = "NotDelimited";
                    ListFormat2[ListFormat2["BarDelimited"] = 4] = "BarDelimited";
                    ListFormat2[ListFormat2["AmpersandDelimited"] = 8] = "AmpersandDelimited";
                    ListFormat2[ListFormat2["CommaDelimited"] = 16] = "CommaDelimited";
                    ListFormat2[ListFormat2["AsteriskDelimited"] = 32] = "AsteriskDelimited";
                    ListFormat2[ListFormat2["DelimitersMask"] = 60] = "DelimitersMask";
                    ListFormat2[ListFormat2["AllowTrailingComma"] = 64] = "AllowTrailingComma";
                    ListFormat2[ListFormat2["Indented"] = 128] = "Indented";
                    ListFormat2[ListFormat2["SpaceBetweenBraces"] = 256] = "SpaceBetweenBraces";
                    ListFormat2[ListFormat2["SpaceBetweenSiblings"] = 512] = "SpaceBetweenSiblings";
                    ListFormat2[ListFormat2["Braces"] = 1024] = "Braces";
                    ListFormat2[ListFormat2["Parenthesis"] = 2048] = "Parenthesis";
                    ListFormat2[ListFormat2["AngleBrackets"] = 4096] = "AngleBrackets";
                    ListFormat2[ListFormat2["SquareBrackets"] = 8192] = "SquareBrackets";
                    ListFormat2[ListFormat2["BracketsMask"] = 15360] = "BracketsMask";
                    ListFormat2[ListFormat2["OptionalIfUndefined"] = 16384] = "OptionalIfUndefined";
                    ListFormat2[ListFormat2["OptionalIfEmpty"] = 32768] = "OptionalIfEmpty";
                    ListFormat2[ListFormat2["Optional"] = 49152] = "Optional";
                    ListFormat2[ListFormat2["PreferNewLine"] = 65536] = "PreferNewLine";
                    ListFormat2[ListFormat2["NoTrailingNewLine"] = 131072] = "NoTrailingNewLine";
                    ListFormat2[ListFormat2["NoInterveningComments"] = 262144] = "NoInterveningComments";
                    ListFormat2[ListFormat2["NoSpaceIfEmpty"] = 524288] = "NoSpaceIfEmpty";
                    ListFormat2[ListFormat2["SingleElement"] = 1048576] = "SingleElement";
                    ListFormat2[ListFormat2["SpaceAfterList"] = 2097152] = "SpaceAfterList";
                    ListFormat2[ListFormat2["Modifiers"] = 2359808] = "Modifiers";
                    ListFormat2[ListFormat2["HeritageClauses"] = 512] = "HeritageClauses";
                    ListFormat2[ListFormat2["SingleLineTypeLiteralMembers"] = 768] = "SingleLineTypeLiteralMembers";
                    ListFormat2[ListFormat2["MultiLineTypeLiteralMembers"] = 32897] = "MultiLineTypeLiteralMembers";
                    ListFormat2[ListFormat2["SingleLineTupleTypeElements"] = 528] = "SingleLineTupleTypeElements";
                    ListFormat2[ListFormat2["MultiLineTupleTypeElements"] = 657] = "MultiLineTupleTypeElements";
                    ListFormat2[ListFormat2["UnionTypeConstituents"] = 516] = "UnionTypeConstituents";
                    ListFormat2[ListFormat2["IntersectionTypeConstituents"] = 520] = "IntersectionTypeConstituents";
                    ListFormat2[ListFormat2["ObjectBindingPatternElements"] = 525136] = "ObjectBindingPatternElements";
                    ListFormat2[ListFormat2["ArrayBindingPatternElements"] = 524880] = "ArrayBindingPatternElements";
                    ListFormat2[ListFormat2["ObjectLiteralExpressionProperties"] = 526226] = "ObjectLiteralExpressionProperties";
                    ListFormat2[ListFormat2["ImportClauseEntries"] = 526226] = "ImportClauseEntries";
                    ListFormat2[ListFormat2["ArrayLiteralExpressionElements"] = 8914] = "ArrayLiteralExpressionElements";
                    ListFormat2[ListFormat2["CommaListElements"] = 528] = "CommaListElements";
                    ListFormat2[ListFormat2["CallExpressionArguments"] = 2576] = "CallExpressionArguments";
                    ListFormat2[ListFormat2["NewExpressionArguments"] = 18960] = "NewExpressionArguments";
                    ListFormat2[ListFormat2["TemplateExpressionSpans"] = 262144] = "TemplateExpressionSpans";
                    ListFormat2[ListFormat2["SingleLineBlockStatements"] = 768] = "SingleLineBlockStatements";
                    ListFormat2[ListFormat2["MultiLineBlockStatements"] = 129] = "MultiLineBlockStatements";
                    ListFormat2[ListFormat2["VariableDeclarationList"] = 528] = "VariableDeclarationList";
                    ListFormat2[ListFormat2["SingleLineFunctionBodyStatements"] = 768] = "SingleLineFunctionBodyStatements";
                    ListFormat2[ListFormat2["MultiLineFunctionBodyStatements"] = 1 /* MultiLine */] = "MultiLineFunctionBodyStatements";
                    ListFormat2[ListFormat2["ClassHeritageClauses"] = 0 /* SingleLine */] = "ClassHeritageClauses";
                    ListFormat2[ListFormat2["ClassMembers"] = 129] = "ClassMembers";
                    ListFormat2[ListFormat2["InterfaceMembers"] = 129] = "InterfaceMembers";
                    ListFormat2[ListFormat2["EnumMembers"] = 145] = "EnumMembers";
                    ListFormat2[ListFormat2["CaseBlockClauses"] = 129] = "CaseBlockClauses";
                    ListFormat2[ListFormat2["NamedImportsOrExportsElements"] = 525136] = "NamedImportsOrExportsElements";
                    ListFormat2[ListFormat2["JsxElementOrFragmentChildren"] = 262144] = "JsxElementOrFragmentChildren";
                    ListFormat2[ListFormat2["JsxElementAttributes"] = 262656] = "JsxElementAttributes";
                    ListFormat2[ListFormat2["CaseOrDefaultClauseStatements"] = 163969] = "CaseOrDefaultClauseStatements";
                    ListFormat2[ListFormat2["HeritageClauseTypes"] = 528] = "HeritageClauseTypes";
                    ListFormat2[ListFormat2["SourceFileStatements"] = 131073] = "SourceFileStatements";
                    ListFormat2[ListFormat2["Decorators"] = 2146305] = "Decorators";
                    ListFormat2[ListFormat2["TypeArguments"] = 53776] = "TypeArguments";
                    ListFormat2[ListFormat2["TypeParameters"] = 53776] = "TypeParameters";
                    ListFormat2[ListFormat2["Parameters"] = 2576] = "Parameters";
                    ListFormat2[ListFormat2["IndexSignatureParameters"] = 8848] = "IndexSignatureParameters";
                    ListFormat2[ListFormat2["JSDocComment"] = 33] = "JSDocComment";
                    return ListFormat2;
                })(ListFormat || {});
                PragmaKindFlags = /* @__PURE__ */ ((PragmaKindFlags2) => {
                    PragmaKindFlags2[PragmaKindFlags2["None"] = 0] = "None";
                    PragmaKindFlags2[PragmaKindFlags2["TripleSlashXML"] = 1] = "TripleSlashXML";
                    PragmaKindFlags2[PragmaKindFlags2["SingleLine"] = 2] = "SingleLine";
                    PragmaKindFlags2[PragmaKindFlags2["MultiLine"] = 4] = "MultiLine";
                    PragmaKindFlags2[PragmaKindFlags2["All"] = 7] = "All";
                    PragmaKindFlags2[PragmaKindFlags2["Default"] = 7 /* All */] = "Default";
                    return PragmaKindFlags2;
                })(PragmaKindFlags || {});
                commentPragmas = {
                    "reference": {
                        args: [
                            { name: "types", optional: true, captureSpan: true },
                            { name: "lib", optional: true, captureSpan: true },
                            { name: "path", optional: true, captureSpan: true },
                            { name: "no-default-lib", optional: true },
                            { name: "resolution-mode", optional: true }
                        ],
                        kind: 1 /* TripleSlashXML */
                    },
                    "amd-dependency": {
                        args: [{ name: "path" }, { name: "name", optional: true }],
                        kind: 1 /* TripleSlashXML */
                    },
                    "amd-module": {
                        args: [{ name: "name" }],
                        kind: 1 /* TripleSlashXML */
                    },
                    "ts-check": {
                        kind: 2 /* SingleLine */
                    },
                    "ts-nocheck": {
                        kind: 2 /* SingleLine */
                    },
                    "jsx": {
                        args: [{ name: "factory" }],
                        kind: 4 /* MultiLine */
                    },
                    "jsxfrag": {
                        args: [{ name: "factory" }],
                        kind: 4 /* MultiLine */
                    },
                    "jsximportsource": {
                        args: [{ name: "factory" }],
                        kind: 4 /* MultiLine */
                    },
                    "jsxruntime": {
                        args: [{ name: "factory" }],
                        kind: 4 /* MultiLine */
                    }
                };
            }
        });
        // src/compiler/sys.ts
        function generateDjb2Hash(data) {
            let acc = 5381;
            for (let i = 0; i < data.length; i++) {
                acc = (acc << 5) + acc + data.charCodeAt(i);
            }
            return acc.toString();
        }
        function setStackTraceLimit() {
            if (Error.stackTraceLimit < 100) {
                Error.stackTraceLimit = 100;
            }
        }
        function getModifiedTime(host, fileName) {
            return host.getModifiedTime(fileName) || missingFileModifiedTime;
        }
        function createPollingIntervalBasedLevels(levels) {
            return {
                [250 /* Low */]: levels.Low,
                [500 /* Medium */]: levels.Medium,
                [2e3 /* High */]: levels.High
            };
        }
        function setCustomPollingValues(system) {
            if (!system.getEnvironmentVariable) {
                return;
            }
            const pollingIntervalChanged = setCustomLevels("TSC_WATCH_POLLINGINTERVAL", PollingInterval);
            pollingChunkSize = getCustomPollingBasedLevels("TSC_WATCH_POLLINGCHUNKSIZE", defaultChunkLevels) || pollingChunkSize;
            unchangedPollThresholds = getCustomPollingBasedLevels("TSC_WATCH_UNCHANGEDPOLLTHRESHOLDS", defaultChunkLevels) || unchangedPollThresholds;
            function getLevel(envVar, level) {
                return system.getEnvironmentVariable(`${envVar}_${level.toUpperCase()}`);
            }
            function getCustomLevels(baseVariable) {
                let customLevels;
                setCustomLevel("Low");
                setCustomLevel("Medium");
                setCustomLevel("High");
                return customLevels;
                function setCustomLevel(level) {
                    const customLevel = getLevel(baseVariable, level);
                    if (customLevel) {
                        (customLevels || (customLevels = {}))[level] = Number(customLevel);
                    }
                }
            }
            function setCustomLevels(baseVariable, levels) {
                const customLevels = getCustomLevels(baseVariable);
                if (customLevels) {
                    setLevel("Low");
                    setLevel("Medium");
                    setLevel("High");
                    return true;
                }
                return false;
                function setLevel(level) {
                    levels[level] = customLevels[level] || levels[level];
                }
            }
            function getCustomPollingBasedLevels(baseVariable, defaultLevels) {
                const customLevels = getCustomLevels(baseVariable);
                return (pollingIntervalChanged || customLevels) && createPollingIntervalBasedLevels(customLevels ? { ...defaultLevels, ...customLevels } : defaultLevels);
            }
        }
        function pollWatchedFileQueue(host, queue, pollIndex, chunkSize, callbackOnWatchFileStat) {
            let definedValueCopyToIndex = pollIndex;
            for (let canVisit = queue.length; chunkSize && canVisit; nextPollIndex(), canVisit--) {
                const watchedFile = queue[pollIndex];
                if (!watchedFile) {
                    continue;
                }
                else if (watchedFile.isClosed) {
                    queue[pollIndex] = void 0;
                    continue;
                }
                chunkSize--;
                const fileChanged = onWatchedFileStat(watchedFile, getModifiedTime(host, watchedFile.fileName));
                if (watchedFile.isClosed) {
                    queue[pollIndex] = void 0;
                    continue;
                }
                callbackOnWatchFileStat == null ? void 0 : callbackOnWatchFileStat(watchedFile, pollIndex, fileChanged);
                if (queue[pollIndex]) {
                    if (definedValueCopyToIndex < pollIndex) {
                        queue[definedValueCopyToIndex] = watchedFile;
                        queue[pollIndex] = void 0;
                    }
                    definedValueCopyToIndex++;
                }
            }
            return pollIndex;
            function nextPollIndex() {
                pollIndex++;
                if (pollIndex === queue.length) {
                    if (definedValueCopyToIndex < pollIndex) {
                        queue.length = definedValueCopyToIndex;
                    }
                    pollIndex = 0;
                    definedValueCopyToIndex = 0;
                }
            }
        }
        function createDynamicPriorityPollingWatchFile(host) {
            const watchedFiles = [];
            const changedFilesInLastPoll = [];
            const lowPollingIntervalQueue = createPollingIntervalQueue(250 /* Low */);
            const mediumPollingIntervalQueue = createPollingIntervalQueue(500 /* Medium */);
            const highPollingIntervalQueue = createPollingIntervalQueue(2e3 /* High */);
            return watchFile2;
            function watchFile2(fileName, callback, defaultPollingInterval) {
                const file = {
                    fileName,
                    callback,
                    unchangedPolls: 0,
                    mtime: getModifiedTime(host, fileName)
                };
                watchedFiles.push(file);
                addToPollingIntervalQueue(file, defaultPollingInterval);
                return {
                    close: () => {
                        file.isClosed = true;
                        unorderedRemoveItem(watchedFiles, file);
                    }
                };
            }
            function createPollingIntervalQueue(pollingInterval) {
                const queue = [];
                queue.pollingInterval = pollingInterval;
                queue.pollIndex = 0;
                queue.pollScheduled = false;
                return queue;
            }
            function pollPollingIntervalQueue(queue) {
                queue.pollIndex = pollQueue(queue, queue.pollingInterval, queue.pollIndex, pollingChunkSize[queue.pollingInterval]);
                if (queue.length) {
                    scheduleNextPoll(queue.pollingInterval);
                }
                else {
                    Debug.assert(queue.pollIndex === 0);
                    queue.pollScheduled = false;
                }
            }
            function pollLowPollingIntervalQueue(queue) {
                pollQueue(changedFilesInLastPoll, 250 /* Low */, 
                /*pollIndex*/
                0, changedFilesInLastPoll.length);
                pollPollingIntervalQueue(queue);
                if (!queue.pollScheduled && changedFilesInLastPoll.length) {
                    scheduleNextPoll(250 /* Low */);
                }
            }
            function pollQueue(queue, pollingInterval, pollIndex, chunkSize) {
                return pollWatchedFileQueue(host, queue, pollIndex, chunkSize, onWatchFileStat);
                function onWatchFileStat(watchedFile, pollIndex2, fileChanged) {
                    if (fileChanged) {
                        watchedFile.unchangedPolls = 0;
                        if (queue !== changedFilesInLastPoll) {
                            queue[pollIndex2] = void 0;
                            addChangedFileToLowPollingIntervalQueue(watchedFile);
                        }
                    }
                    else if (watchedFile.unchangedPolls !== unchangedPollThresholds[pollingInterval]) {
                        watchedFile.unchangedPolls++;
                    }
                    else if (queue === changedFilesInLastPoll) {
                        watchedFile.unchangedPolls = 1;
                        queue[pollIndex2] = void 0;
                        addToPollingIntervalQueue(watchedFile, 250 /* Low */);
                    }
                    else if (pollingInterval !== 2e3 /* High */) {
                        watchedFile.unchangedPolls++;
                        queue[pollIndex2] = void 0;
                        addToPollingIntervalQueue(watchedFile, pollingInterval === 250 /* Low */ ? 500 /* Medium */ : 2e3 /* High */);
                    }
                }
            }
            function pollingIntervalQueue(pollingInterval) {
                switch (pollingInterval) {
                    case 250 /* Low */:
                        return lowPollingIntervalQueue;
                    case 500 /* Medium */:
                        return mediumPollingIntervalQueue;
                    case 2e3 /* High */:
                        return highPollingIntervalQueue;
                }
            }
            function addToPollingIntervalQueue(file, pollingInterval) {
                pollingIntervalQueue(pollingInterval).push(file);
                scheduleNextPollIfNotAlreadyScheduled(pollingInterval);
            }
            function addChangedFileToLowPollingIntervalQueue(file) {
                changedFilesInLastPoll.push(file);
                scheduleNextPollIfNotAlreadyScheduled(250 /* Low */);
            }
            function scheduleNextPollIfNotAlreadyScheduled(pollingInterval) {
                if (!pollingIntervalQueue(pollingInterval).pollScheduled) {
                    scheduleNextPoll(pollingInterval);
                }
            }
            function scheduleNextPoll(pollingInterval) {
                pollingIntervalQueue(pollingInterval).pollScheduled = host.setTimeout(pollingInterval === 250 /* Low */ ? pollLowPollingIntervalQueue : pollPollingIntervalQueue, pollingInterval, pollingIntervalQueue(pollingInterval));
            }
        }
        function createUseFsEventsOnParentDirectoryWatchFile(fsWatch, useCaseSensitiveFileNames) {
            const fileWatcherCallbacks = createMultiMap();
            const dirWatchers = /* @__PURE__ */ new Map();
            const toCanonicalName = createGetCanonicalFileName(useCaseSensitiveFileNames);
            return nonPollingWatchFile;
            function nonPollingWatchFile(fileName, callback, _pollingInterval, fallbackOptions) {
                const filePath = toCanonicalName(fileName);
                fileWatcherCallbacks.add(filePath, callback);
                const dirPath = getDirectoryPath(filePath) || ".";
                const watcher = dirWatchers.get(dirPath) || createDirectoryWatcher(getDirectoryPath(fileName) || ".", dirPath, fallbackOptions);
                watcher.referenceCount++;
                return {
                    close: () => {
                        if (watcher.referenceCount === 1) {
                            watcher.close();
                            dirWatchers.delete(dirPath);
                        }
                        else {
                            watcher.referenceCount--;
                        }
                        fileWatcherCallbacks.remove(filePath, callback);
                    }
                };
            }
            function createDirectoryWatcher(dirName, dirPath, fallbackOptions) {
                const watcher = fsWatch(dirName, 1 /* Directory */, (_eventName, relativeFileName, modifiedTime) => {
                    if (!isString(relativeFileName))
                        return;
                    const fileName = getNormalizedAbsolutePath(relativeFileName, dirName);
                    const callbacks = fileName && fileWatcherCallbacks.get(toCanonicalName(fileName));
                    if (callbacks) {
                        for (const fileCallback of callbacks) {
                            fileCallback(fileName, 1 /* Changed */, modifiedTime);
                        }
                    }
                }, 
                /*recursive*/
                false, 500 /* Medium */, fallbackOptions);
                watcher.referenceCount = 0;
                dirWatchers.set(dirPath, watcher);
                return watcher;
            }
        }
        function createFixedChunkSizePollingWatchFile(host) {
            const watchedFiles = [];
            let pollIndex = 0;
            let pollScheduled;
            return watchFile2;
            function watchFile2(fileName, callback) {
                const file = {
                    fileName,
                    callback,
                    mtime: getModifiedTime(host, fileName)
                };
                watchedFiles.push(file);
                scheduleNextPoll();
                return {
                    close: () => {
                        file.isClosed = true;
                        unorderedRemoveItem(watchedFiles, file);
                    }
                };
            }
            function pollQueue() {
                pollScheduled = void 0;
                pollIndex = pollWatchedFileQueue(host, watchedFiles, pollIndex, pollingChunkSize[250 /* Low */]);
                scheduleNextPoll();
            }
            function scheduleNextPoll() {
                if (!watchedFiles.length || pollScheduled)
                    return;
                pollScheduled = host.setTimeout(pollQueue, 2e3 /* High */);
            }
        }
        function createSingleWatcherPerName(cache, useCaseSensitiveFileNames, name, callback, createWatcher) {
            const toCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames);
            const path = toCanonicalFileName(name);
            const existing = cache.get(path);
            if (existing) {
                existing.callbacks.push(callback);
            }
            else {
                cache.set(path, {
                    watcher: createWatcher(
                    // Cant infer types correctly so lets satisfy checker
                    (param1, param2, param3) => {
                        var _a2;
                        return (_a2 = cache.get(path)) == null ? void 0 : _a2.callbacks.slice().forEach((cb) => cb(param1, param2, param3));
                    }),
                    callbacks: [callback]
                });
            }
            return {
                close: () => {
                    const watcher = cache.get(path);
                    if (!watcher)
                        return;
                    if (!orderedRemoveItem(watcher.callbacks, callback) || watcher.callbacks.length)
                        return;
                    cache.delete(path);
                    closeFileWatcherOf(watcher);
                }
            };
        }
        function onWatchedFileStat(watchedFile, modifiedTime) {
            const oldTime = watchedFile.mtime.getTime();
            const newTime = modifiedTime.getTime();
            if (oldTime !== newTime) {
                watchedFile.mtime = modifiedTime;
                watchedFile.callback(watchedFile.fileName, getFileWatcherEventKind(oldTime, newTime), modifiedTime);
                return true;
            }
            return false;
        }
        function getFileWatcherEventKind(oldTime, newTime) {
            return oldTime === 0 ? 0 /* Created */ : newTime === 0 ? 2 /* Deleted */ : 1 /* Changed */;
        }
        function sysLog(s) {
            return curSysLog(s);
        }
        function setSysLog(logger) {
            curSysLog = logger;
        }
        function createDirectoryWatcherSupportingRecursive({ watchDirectory, useCaseSensitiveFileNames, getCurrentDirectory, getAccessibleSortedChildDirectories, fileSystemEntryExists, realpath, setTimeout: setTimeout2, clearTimeout: clearTimeout2 }) {
            const cache = /* @__PURE__ */ new Map();
            const callbackCache = createMultiMap();
            const cacheToUpdateChildWatches = /* @__PURE__ */ new Map();
            let timerToUpdateChildWatches;
            const filePathComparer = getStringComparer(!useCaseSensitiveFileNames);
            const toCanonicalFilePath = createGetCanonicalFileName(useCaseSensitiveFileNames);
            return (dirName, callback, recursive, options) => recursive ? createDirectoryWatcher(dirName, options, callback) : watchDirectory(dirName, callback, recursive, options);
            function createDirectoryWatcher(dirName, options, callback) {
                const dirPath = toCanonicalFilePath(dirName);
                let directoryWatcher = cache.get(dirPath);
                if (directoryWatcher) {
                    directoryWatcher.refCount++;
                }
                else {
                    directoryWatcher = {
                        watcher: watchDirectory(dirName, (fileName) => {
                            if (isIgnoredPath(fileName, options))
                                return;
                            if (options == null ? void 0 : options.synchronousWatchDirectory) {
                                invokeCallbacks(dirPath, fileName);
                                updateChildWatches(dirName, dirPath, options);
                            }
                            else {
                                nonSyncUpdateChildWatches(dirName, dirPath, fileName, options);
                            }
                        }, 
                        /*recursive*/
                        false, options),
                        refCount: 1,
                        childWatches: emptyArray
                    };
                    cache.set(dirPath, directoryWatcher);
                    updateChildWatches(dirName, dirPath, options);
                }
                const callbackToAdd = callback && { dirName, callback };
                if (callbackToAdd) {
                    callbackCache.add(dirPath, callbackToAdd);
                }
                return {
                    dirName,
                    close: () => {
                        const directoryWatcher2 = Debug.checkDefined(cache.get(dirPath));
                        if (callbackToAdd)
                            callbackCache.remove(dirPath, callbackToAdd);
                        directoryWatcher2.refCount--;
                        if (directoryWatcher2.refCount)
                            return;
                        cache.delete(dirPath);
                        closeFileWatcherOf(directoryWatcher2);
                        directoryWatcher2.childWatches.forEach(closeFileWatcher);
                    }
                };
            }
            function invokeCallbacks(dirPath, fileNameOrInvokeMap, fileNames) {
                let fileName;
                let invokeMap;
                if (isString(fileNameOrInvokeMap)) {
                    fileName = fileNameOrInvokeMap;
                }
                else {
                    invokeMap = fileNameOrInvokeMap;
                }
                callbackCache.forEach((callbacks, rootDirName) => {
                    if (invokeMap && invokeMap.get(rootDirName) === true)
                        return;
                    if (rootDirName === dirPath || startsWith(dirPath, rootDirName) && dirPath[rootDirName.length] === directorySeparator) {
                        if (invokeMap) {
                            if (fileNames) {
                                const existing = invokeMap.get(rootDirName);
                                if (existing) {
                                    existing.push(...fileNames);
                                }
                                else {
                                    invokeMap.set(rootDirName, fileNames.slice());
                                }
                            }
                            else {
                                invokeMap.set(rootDirName, true);
                            }
                        }
                        else {
                            callbacks.forEach(({ callback }) => callback(fileName));
                        }
                    }
                });
            }
            function nonSyncUpdateChildWatches(dirName, dirPath, fileName, options) {
                const parentWatcher = cache.get(dirPath);
                if (parentWatcher && fileSystemEntryExists(dirName, 1 /* Directory */)) {
                    scheduleUpdateChildWatches(dirName, dirPath, fileName, options);
                    return;
                }
                invokeCallbacks(dirPath, fileName);
                removeChildWatches(parentWatcher);
            }
            function scheduleUpdateChildWatches(dirName, dirPath, fileName, options) {
                const existing = cacheToUpdateChildWatches.get(dirPath);
                if (existing) {
                    existing.fileNames.push(fileName);
                }
                else {
                    cacheToUpdateChildWatches.set(dirPath, { dirName, options, fileNames: [fileName] });
                }
                if (timerToUpdateChildWatches) {
                    clearTimeout2(timerToUpdateChildWatches);
                    timerToUpdateChildWatches = void 0;
                }
                timerToUpdateChildWatches = setTimeout2(onTimerToUpdateChildWatches, 1e3);
            }
            function onTimerToUpdateChildWatches() {
                timerToUpdateChildWatches = void 0;
                sysLog(`sysLog:: onTimerToUpdateChildWatches:: ${cacheToUpdateChildWatches.size}`);
                const start = timestamp();
                const invokeMap = /* @__PURE__ */ new Map();
                while (!timerToUpdateChildWatches && cacheToUpdateChildWatches.size) {
                    const result = cacheToUpdateChildWatches.entries().next();
                    Debug.assert(!result.done);
                    const { value: [dirPath, { dirName, options, fileNames }] } = result;
                    cacheToUpdateChildWatches.delete(dirPath);
                    const hasChanges = updateChildWatches(dirName, dirPath, options);
                    invokeCallbacks(dirPath, invokeMap, hasChanges ? void 0 : fileNames);
                }
                sysLog(`sysLog:: invokingWatchers:: Elapsed:: ${timestamp() - start}ms:: ${cacheToUpdateChildWatches.size}`);
                callbackCache.forEach((callbacks, rootDirName) => {
                    const existing = invokeMap.get(rootDirName);
                    if (existing) {
                        callbacks.forEach(({ callback, dirName }) => {
                            if (isArray(existing)) {
                                existing.forEach(callback);
                            }
                            else {
                                callback(dirName);
                            }
                        });
                    }
                });
                const elapsed = timestamp() - start;
                sysLog(`sysLog:: Elapsed:: ${elapsed}ms:: onTimerToUpdateChildWatches:: ${cacheToUpdateChildWatches.size} ${timerToUpdateChildWatches}`);
            }
            function removeChildWatches(parentWatcher) {
                if (!parentWatcher)
                    return;
                const existingChildWatches = parentWatcher.childWatches;
                parentWatcher.childWatches = emptyArray;
                for (const childWatcher of existingChildWatches) {
                    childWatcher.close();
                    removeChildWatches(cache.get(toCanonicalFilePath(childWatcher.dirName)));
                }
            }
            function updateChildWatches(parentDir, parentDirPath, options) {
                const parentWatcher = cache.get(parentDirPath);
                if (!parentWatcher)
                    return false;
                let newChildWatches;
                const hasChanges = enumerateInsertsAndDeletes(fileSystemEntryExists(parentDir, 1 /* Directory */) ? mapDefined(getAccessibleSortedChildDirectories(parentDir), (child) => {
                    const childFullName = getNormalizedAbsolutePath(child, parentDir);
                    return !isIgnoredPath(childFullName, options) && filePathComparer(childFullName, normalizePath(realpath(childFullName))) === 0 /* EqualTo */ ? childFullName : void 0;
                }) : emptyArray, parentWatcher.childWatches, (child, childWatcher) => filePathComparer(child, childWatcher.dirName), createAndAddChildDirectoryWatcher, closeFileWatcher, addChildDirectoryWatcher);
                parentWatcher.childWatches = newChildWatches || emptyArray;
                return hasChanges;
                function createAndAddChildDirectoryWatcher(childName) {
                    const result = createDirectoryWatcher(childName, options);
                    addChildDirectoryWatcher(result);
                }
                function addChildDirectoryWatcher(childWatcher) {
                    (newChildWatches || (newChildWatches = [])).push(childWatcher);
                }
            }
            function isIgnoredPath(path, options) {
                return some(ignoredPaths, (searchPath) => isInPath(path, searchPath)) || isIgnoredByWatchOptions(path, options, useCaseSensitiveFileNames, getCurrentDirectory);
            }
            function isInPath(path, searchPath) {
                if (stringContains(path, searchPath))
                    return true;
                if (useCaseSensitiveFileNames)
                    return false;
                return stringContains(toCanonicalFilePath(path), searchPath);
            }
        }
        function createFileWatcherCallback(callback) {
            return (_fileName, eventKind, modifiedTime) => callback(eventKind === 1 /* Changed */ ? "change" : "rename", "", modifiedTime);
        }
        function createFsWatchCallbackForFileWatcherCallback(fileName, callback, getModifiedTime3) {
            return (eventName, _relativeFileName, modifiedTime) => {
                if (eventName === "rename") {
                    modifiedTime || (modifiedTime = getModifiedTime3(fileName) || missingFileModifiedTime);
                    callback(fileName, modifiedTime !== missingFileModifiedTime ? 0 /* Created */ : 2 /* Deleted */, modifiedTime);
                }
                else {
                    callback(fileName, 1 /* Changed */, modifiedTime);
                }
            };
        }
        function isIgnoredByWatchOptions(pathToCheck, options, useCaseSensitiveFileNames, getCurrentDirectory) {
            return ((options == null ? void 0 : options.excludeDirectories) || (options == null ? void 0 : options.excludeFiles)) && (matchesExclude(pathToCheck, options == null ? void 0 : options.excludeFiles, useCaseSensitiveFileNames, getCurrentDirectory()) || matchesExclude(pathToCheck, options == null ? void 0 : options.excludeDirectories, useCaseSensitiveFileNames, getCurrentDirectory()));
        }
        function createFsWatchCallbackForDirectoryWatcherCallback(directoryName, callback, options, useCaseSensitiveFileNames, getCurrentDirectory) {
            return (eventName, relativeFileName) => {
                if (eventName === "rename") {
                    const fileName = !relativeFileName ? directoryName : normalizePath(combinePaths(directoryName, relativeFileName));
                    if (!relativeFileName || !isIgnoredByWatchOptions(fileName, options, useCaseSensitiveFileNames, getCurrentDirectory)) {
                        callback(fileName);
                    }
                }
            };
        }
        function createSystemWatchFunctions({ pollingWatchFileWorker, getModifiedTime: getModifiedTime3, setTimeout: setTimeout2, clearTimeout: clearTimeout2, fsWatchWorker, fileSystemEntryExists, useCaseSensitiveFileNames, getCurrentDirectory, fsSupportsRecursiveFsWatch, getAccessibleSortedChildDirectories, realpath, tscWatchFile, useNonPollingWatchers, tscWatchDirectory, inodeWatching, sysLog: sysLog2 }) {
            const pollingWatches = /* @__PURE__ */ new Map();
            const fsWatches = /* @__PURE__ */ new Map();
            const fsWatchesRecursive = /* @__PURE__ */ new Map();
            let dynamicPollingWatchFile;
            let fixedChunkSizePollingWatchFile;
            let nonPollingWatchFile;
            let hostRecursiveDirectoryWatcher;
            let hitSystemWatcherLimit = false;
            return {
                watchFile: watchFile2,
                watchDirectory
            };
            function watchFile2(fileName, callback, pollingInterval, options) {
                options = updateOptionsForWatchFile(options, useNonPollingWatchers);
                const watchFileKind = Debug.checkDefined(options.watchFile);
                switch (watchFileKind) {
                    case 0 /* FixedPollingInterval */:
                        return pollingWatchFile(fileName, callback, 250 /* Low */, 
                        /*options*/
                        void 0);
                    case 1 /* PriorityPollingInterval */:
                        return pollingWatchFile(fileName, callback, pollingInterval, 
                        /*options*/
                        void 0);
                    case 2 /* DynamicPriorityPolling */:
                        return ensureDynamicPollingWatchFile()(fileName, callback, pollingInterval, 
                        /*options*/
                        void 0);
                    case 3 /* FixedChunkSizePolling */:
                        return ensureFixedChunkSizePollingWatchFile()(fileName, callback, 
                        /* pollingInterval */
                        void 0, 
                        /*options*/
                        void 0);
                    case 4 /* UseFsEvents */:
                        return fsWatch(fileName, 0 /* File */, createFsWatchCallbackForFileWatcherCallback(fileName, callback, getModifiedTime3), 
                        /*recursive*/
                        false, pollingInterval, getFallbackOptions(options));
                    case 5 /* UseFsEventsOnParentDirectory */:
                        if (!nonPollingWatchFile) {
                            nonPollingWatchFile = createUseFsEventsOnParentDirectoryWatchFile(fsWatch, useCaseSensitiveFileNames);
                        }
                        return nonPollingWatchFile(fileName, callback, pollingInterval, getFallbackOptions(options));
                    default:
                        Debug.assertNever(watchFileKind);
                }
            }
            function ensureDynamicPollingWatchFile() {
                return dynamicPollingWatchFile || (dynamicPollingWatchFile = createDynamicPriorityPollingWatchFile({ getModifiedTime: getModifiedTime3, setTimeout: setTimeout2 }));
            }
            function ensureFixedChunkSizePollingWatchFile() {
                return fixedChunkSizePollingWatchFile || (fixedChunkSizePollingWatchFile = createFixedChunkSizePollingWatchFile({ getModifiedTime: getModifiedTime3, setTimeout: setTimeout2 }));
            }
            function updateOptionsForWatchFile(options, useNonPollingWatchers2) {
                if (options && options.watchFile !== void 0)
                    return options;
                switch (tscWatchFile) {
                    case "PriorityPollingInterval":
                        return { watchFile: 1 /* PriorityPollingInterval */ };
                    case "DynamicPriorityPolling":
                        return { watchFile: 2 /* DynamicPriorityPolling */ };
                    case "UseFsEvents":
                        return generateWatchFileOptions(4 /* UseFsEvents */, 1 /* PriorityInterval */, options);
                    case "UseFsEventsWithFallbackDynamicPolling":
                        return generateWatchFileOptions(4 /* UseFsEvents */, 2 /* DynamicPriority */, options);
                    case "UseFsEventsOnParentDirectory":
                        useNonPollingWatchers2 = true;
                    default:
                        return useNonPollingWatchers2 ? (
                        // Use notifications from FS to watch with falling back to fs.watchFile
                        generateWatchFileOptions(5 /* UseFsEventsOnParentDirectory */, 1 /* PriorityInterval */, options)) : (
                        // Default to using fs events
                        { watchFile: 4 /* UseFsEvents */ });
                }
            }
            function generateWatchFileOptions(watchFile3, fallbackPolling, options) {
                const defaultFallbackPolling = options == null ? void 0 : options.fallbackPolling;
                return {
                    watchFile: watchFile3,
                    fallbackPolling: defaultFallbackPolling === void 0 ? fallbackPolling : defaultFallbackPolling
                };
            }
            function watchDirectory(directoryName, callback, recursive, options) {
                if (fsSupportsRecursiveFsWatch) {
                    return fsWatch(directoryName, 1 /* Directory */, createFsWatchCallbackForDirectoryWatcherCallback(directoryName, callback, options, useCaseSensitiveFileNames, getCurrentDirectory), recursive, 500 /* Medium */, getFallbackOptions(options));
                }
                if (!hostRecursiveDirectoryWatcher) {
                    hostRecursiveDirectoryWatcher = createDirectoryWatcherSupportingRecursive({
                        useCaseSensitiveFileNames,
                        getCurrentDirectory,
                        fileSystemEntryExists,
                        getAccessibleSortedChildDirectories,
                        watchDirectory: nonRecursiveWatchDirectory,
                        realpath,
                        setTimeout: setTimeout2,
                        clearTimeout: clearTimeout2
                    });
                }
                return hostRecursiveDirectoryWatcher(directoryName, callback, recursive, options);
            }
            function nonRecursiveWatchDirectory(directoryName, callback, recursive, options) {
                Debug.assert(!recursive);
                const watchDirectoryOptions = updateOptionsForWatchDirectory(options);
                const watchDirectoryKind = Debug.checkDefined(watchDirectoryOptions.watchDirectory);
                switch (watchDirectoryKind) {
                    case 1 /* FixedPollingInterval */:
                        return pollingWatchFile(directoryName, () => callback(directoryName), 500 /* Medium */, 
                        /*options*/
                        void 0);
                    case 2 /* DynamicPriorityPolling */:
                        return ensureDynamicPollingWatchFile()(directoryName, () => callback(directoryName), 500 /* Medium */, 
                        /*options*/
                        void 0);
                    case 3 /* FixedChunkSizePolling */:
                        return ensureFixedChunkSizePollingWatchFile()(directoryName, () => callback(directoryName), 
                        /* pollingInterval */
                        void 0, 
                        /*options*/
                        void 0);
                    case 0 /* UseFsEvents */:
                        return fsWatch(directoryName, 1 /* Directory */, createFsWatchCallbackForDirectoryWatcherCallback(directoryName, callback, options, useCaseSensitiveFileNames, getCurrentDirectory), recursive, 500 /* Medium */, getFallbackOptions(watchDirectoryOptions));
                    default:
                        Debug.assertNever(watchDirectoryKind);
                }
            }
            function updateOptionsForWatchDirectory(options) {
                if (options && options.watchDirectory !== void 0)
                    return options;
                switch (tscWatchDirectory) {
                    case "RecursiveDirectoryUsingFsWatchFile":
                        return { watchDirectory: 1 /* FixedPollingInterval */ };
                    case "RecursiveDirectoryUsingDynamicPriorityPolling":
                        return { watchDirectory: 2 /* DynamicPriorityPolling */ };
                    default:
                        const defaultFallbackPolling = options == null ? void 0 : options.fallbackPolling;
                        return {
                            watchDirectory: 0 /* UseFsEvents */,
                            fallbackPolling: defaultFallbackPolling !== void 0 ? defaultFallbackPolling : void 0
                        };
                }
            }
            function pollingWatchFile(fileName, callback, pollingInterval, options) {
                return createSingleWatcherPerName(pollingWatches, useCaseSensitiveFileNames, fileName, callback, (cb) => pollingWatchFileWorker(fileName, cb, pollingInterval, options));
            }
            function fsWatch(fileOrDirectory, entryKind, callback, recursive, fallbackPollingInterval, fallbackOptions) {
                return createSingleWatcherPerName(recursive ? fsWatchesRecursive : fsWatches, useCaseSensitiveFileNames, fileOrDirectory, callback, (cb) => fsWatchHandlingExistenceOnHost(fileOrDirectory, entryKind, cb, recursive, fallbackPollingInterval, fallbackOptions));
            }
            function fsWatchHandlingExistenceOnHost(fileOrDirectory, entryKind, callback, recursive, fallbackPollingInterval, fallbackOptions) {
                let lastDirectoryPartWithDirectorySeparator;
                let lastDirectoryPart;
                if (inodeWatching) {
                    lastDirectoryPartWithDirectorySeparator = fileOrDirectory.substring(fileOrDirectory.lastIndexOf(directorySeparator));
                    lastDirectoryPart = lastDirectoryPartWithDirectorySeparator.slice(directorySeparator.length);
                }
                let watcher = !fileSystemEntryExists(fileOrDirectory, entryKind) ? watchMissingFileSystemEntry() : watchPresentFileSystemEntry();
                return {
                    close: () => {
                        if (watcher) {
                            watcher.close();
                            watcher = void 0;
                        }
                    }
                };
                function updateWatcher(createWatcher) {
                    if (watcher) {
                        sysLog2(`sysLog:: ${fileOrDirectory}:: Changing watcher to ${createWatcher === watchPresentFileSystemEntry ? "Present" : "Missing"}FileSystemEntryWatcher`);
                        watcher.close();
                        watcher = createWatcher();
                    }
                }
                function watchPresentFileSystemEntry() {
                    if (hitSystemWatcherLimit) {
                        sysLog2(`sysLog:: ${fileOrDirectory}:: Defaulting to watchFile`);
                        return watchPresentFileSystemEntryWithFsWatchFile();
                    }
                    try {
                        const presentWatcher = fsWatchWorker(fileOrDirectory, recursive, inodeWatching ? callbackChangingToMissingFileSystemEntry : callback);
                        presentWatcher.on("error", () => {
                            callback("rename", "");
                            updateWatcher(watchMissingFileSystemEntry);
                        });
                        return presentWatcher;
                    }
                    catch (e) {
                        hitSystemWatcherLimit || (hitSystemWatcherLimit = e.code === "ENOSPC");
                        sysLog2(`sysLog:: ${fileOrDirectory}:: Changing to watchFile`);
                        return watchPresentFileSystemEntryWithFsWatchFile();
                    }
                }
                function callbackChangingToMissingFileSystemEntry(event, relativeName) {
                    let originalRelativeName;
                    if (relativeName && endsWith(relativeName, "~")) {
                        originalRelativeName = relativeName;
                        relativeName = relativeName.slice(0, relativeName.length - 1);
                    }
                    if (event === "rename" && (!relativeName || relativeName === lastDirectoryPart || endsWith(relativeName, lastDirectoryPartWithDirectorySeparator))) {
                        const modifiedTime = getModifiedTime3(fileOrDirectory) || missingFileModifiedTime;
                        if (originalRelativeName)
                            callback(event, originalRelativeName, modifiedTime);
                        callback(event, relativeName, modifiedTime);
                        if (inodeWatching) {
                            updateWatcher(modifiedTime === missingFileModifiedTime ? watchMissingFileSystemEntry : watchPresentFileSystemEntry);
                        }
                        else if (modifiedTime === missingFileModifiedTime) {
                            updateWatcher(watchMissingFileSystemEntry);
                        }
                    }
                    else {
                        if (originalRelativeName)
                            callback(event, originalRelativeName);
                        callback(event, relativeName);
                    }
                }
                function watchPresentFileSystemEntryWithFsWatchFile() {
                    return watchFile2(fileOrDirectory, createFileWatcherCallback(callback), fallbackPollingInterval, fallbackOptions);
                }
                function watchMissingFileSystemEntry() {
                    return watchFile2(fileOrDirectory, (_fileName, eventKind, modifiedTime) => {
                        if (eventKind === 0 /* Created */) {
                            modifiedTime || (modifiedTime = getModifiedTime3(fileOrDirectory) || missingFileModifiedTime);
                            if (modifiedTime !== missingFileModifiedTime) {
                                callback("rename", "", modifiedTime);
                                updateWatcher(watchPresentFileSystemEntry);
                            }
                        }
                    }, fallbackPollingInterval, fallbackOptions);
                }
            }
        }
        function patchWriteFileEnsuringDirectory(sys2) {
            const originalWriteFile = sys2.writeFile;
            sys2.writeFile = (path, data, writeBom) => writeFileEnsuringDirectories(path, data, !!writeBom, (path2, data2, writeByteOrderMark) => originalWriteFile.call(sys2, path2, data2, writeByteOrderMark), (path2) => sys2.createDirectory(path2), (path2) => sys2.directoryExists(path2));
        }
        function setSys(s) {
            sys = s;
        }
        var FileWatcherEventKind, PollingInterval, missingFileModifiedTime, defaultChunkLevels, pollingChunkSize, unchangedPollThresholds, ignoredPaths, curSysLog, FileSystemEntryKind, sys;
        var init_sys = __esm({
            "src/compiler/sys.ts"() {
                "use strict";
                init_ts2();
                FileWatcherEventKind = /* @__PURE__ */ ((FileWatcherEventKind2) => {
                    FileWatcherEventKind2[FileWatcherEventKind2["Created"] = 0] = "Created";
                    FileWatcherEventKind2[FileWatcherEventKind2["Changed"] = 1] = "Changed";
                    FileWatcherEventKind2[FileWatcherEventKind2["Deleted"] = 2] = "Deleted";
                    return FileWatcherEventKind2;
                })(FileWatcherEventKind || {});
                PollingInterval = /* @__PURE__ */ ((PollingInterval3) => {
                    PollingInterval3[PollingInterval3["High"] = 2e3] = "High";
                    PollingInterval3[PollingInterval3["Medium"] = 500] = "Medium";
                    PollingInterval3[PollingInterval3["Low"] = 250] = "Low";
                    return PollingInterval3;
                })(PollingInterval || {});
                missingFileModifiedTime = /* @__PURE__ */ new Date(0);
                defaultChunkLevels = { Low: 32, Medium: 64, High: 256 };
                pollingChunkSize = createPollingIntervalBasedLevels(defaultChunkLevels);
                unchangedPollThresholds = createPollingIntervalBasedLevels(defaultChunkLevels);
                ignoredPaths = ["/node_modules/.", "/.git", "/.#"];
                curSysLog = noop;
                FileSystemEntryKind = /* @__PURE__ */ ((FileSystemEntryKind2) => {
                    FileSystemEntryKind2[FileSystemEntryKind2["File"] = 0] = "File";
                    FileSystemEntryKind2[FileSystemEntryKind2["Directory"] = 1] = "Directory";
                    return FileSystemEntryKind2;
                })(FileSystemEntryKind || {});
                sys = (() => {
                    const byteOrderMarkIndicator = "\uFEFF";
                    function getNodeSystem() {
                        const nativePattern = /^native |^\([^)]+\)$|^(internal[\\/]|[a-zA-Z0-9_\s]+(\.js)?$)/;
                        const _fs = require("fs");
                        const _path = require("path");
                        const _os = require("os");
                        let _crypto;
                        try {
                            _crypto = require("crypto");
                        }
                        catch (e) {
                            _crypto = void 0;
                        }
                        let activeSession;
                        let profilePath = "./profile.cpuprofile";
                        const Buffer2 = require("buffer").Buffer;
                        const isLinuxOrMacOs = process.platform === "linux" || process.platform === "darwin";
                        const platform = _os.platform();
                        const useCaseSensitiveFileNames = isFileSystemCaseSensitive();
                        const fsRealpath = !!_fs.realpathSync.native ? process.platform === "win32" ? fsRealPathHandlingLongPath : _fs.realpathSync.native : _fs.realpathSync;
                        const executingFilePath = __filename.endsWith("sys.js") ? _path.join(_path.dirname(__dirname), "__fake__.js") : __filename;
                        const fsSupportsRecursiveFsWatch = process.platform === "win32" || process.platform === "darwin";
                        const getCurrentDirectory = memoize(() => process.cwd());
                        const { watchFile: watchFile2, watchDirectory } = createSystemWatchFunctions({
                            pollingWatchFileWorker: fsWatchFileWorker,
                            getModifiedTime: getModifiedTime3,
                            setTimeout,
                            clearTimeout,
                            fsWatchWorker,
                            useCaseSensitiveFileNames,
                            getCurrentDirectory,
                            fileSystemEntryExists,
                            // Node 4.0 `fs.watch` function supports the "recursive" option on both OSX and Windows
                            // (ref: https://github.com/nodejs/node/pull/2649 and https://github.com/Microsoft/TypeScript/issues/4643)
                            fsSupportsRecursiveFsWatch,
                            getAccessibleSortedChildDirectories: (path) => getAccessibleFileSystemEntries(path).directories,
                            realpath,
                            tscWatchFile: process.env.TSC_WATCHFILE,
                            useNonPollingWatchers: process.env.TSC_NONPOLLING_WATCHER,
                            tscWatchDirectory: process.env.TSC_WATCHDIRECTORY,
                            inodeWatching: isLinuxOrMacOs,
                            sysLog
                        });
                        const nodeSystem = {
                            args: process.argv.slice(2),
                            newLine: _os.EOL,
                            useCaseSensitiveFileNames,
                            write(s) {
                                process.stdout.write(s);
                            },
                            getWidthOfTerminal() {
                                return process.stdout.columns;
                            },
                            writeOutputIsTTY() {
                                return process.stdout.isTTY;
                            },
                            readFile,
                            writeFile: writeFile2,
                            watchFile: watchFile2,
                            watchDirectory,
                            resolvePath: (path) => _path.resolve(path),
                            fileExists,
                            directoryExists,
                            createDirectory(directoryName) {
                                if (!nodeSystem.directoryExists(directoryName)) {
                                    try {
                                        _fs.mkdirSync(directoryName);
                                    }
                                    catch (e) {
                                        if (e.code !== "EEXIST") {
                                            throw e;
                                        }
                                    }
                                }
                            },
                            getExecutingFilePath() {
                                return executingFilePath;
                            },
                            getCurrentDirectory,
                            getDirectories,
                            getEnvironmentVariable(name) {
                                return process.env[name] || "";
                            },
                            readDirectory,
                            getModifiedTime: getModifiedTime3,
                            setModifiedTime,
                            deleteFile,
                            createHash: _crypto ? createSHA256Hash : generateDjb2Hash,
                            createSHA256Hash: _crypto ? createSHA256Hash : void 0,
                            getMemoryUsage() {
                                if (global.gc) {
                                    global.gc();
                                }
                                return process.memoryUsage().heapUsed;
                            },
                            getFileSize(path) {
                                try {
                                    const stat = statSync(path);
                                    if (stat == null ? void 0 : stat.isFile()) {
                                        return stat.size;
                                    }
                                }
                                catch (e) {
                                }
                                return 0;
                            },
                            exit(exitCode) {
                                disableCPUProfiler(() => process.exit(exitCode));
                            },
                            enableCPUProfiler,
                            disableCPUProfiler,
                            cpuProfilingEnabled: () => !!activeSession || contains(process.execArgv, "--cpu-prof") || contains(process.execArgv, "--prof"),
                            realpath,
                            debugMode: !!process.env.NODE_INSPECTOR_IPC || !!process.env.VSCODE_INSPECTOR_OPTIONS || some(process.execArgv, (arg) => /^--(inspect|debug)(-brk)?(=\d+)?$/i.test(arg)),
                            tryEnableSourceMapsForHost() {
                                try {
                                    require(22) /* source-map-support */.install();
                                }
                                catch (e) {
                                }
                            },
                            setTimeout,
                            clearTimeout,
                            clearScreen: () => {
                                process.stdout.write("\x1Bc");
                            },
                            setBlocking: () => {
                                if (process.stdout && process.stdout._handle && process.stdout._handle.setBlocking) {
                                    process.stdout._handle.setBlocking(true);
                                }
                            },
                            bufferFrom,
                            base64decode: (input) => bufferFrom(input, "base64").toString("utf8"),
                            base64encode: (input) => bufferFrom(input).toString("base64"),
                            require: (baseDir, moduleName) => {
                                try {
                                    const modulePath = resolveJSModule(moduleName, baseDir, nodeSystem);
                                    return { module: require(modulePath), modulePath, error: void 0 };
                                }
                                catch (error) {
                                    return { module: void 0, modulePath: void 0, error };
                                }
                            }
                        };
                        return nodeSystem;
                        function statSync(path) {
                            return _fs.statSync(path, { throwIfNoEntry: false });
                        }
                        function enableCPUProfiler(path, cb) {
                            if (activeSession) {
                                cb();
                                return false;
                            }
                            const inspector = require("inspector");
                            if (!inspector || !inspector.Session) {
                                cb();
                                return false;
                            }
                            const session = new inspector.Session();
                            session.connect();
                            session.post("Profiler.enable", () => {
                                session.post("Profiler.start", () => {
                                    activeSession = session;
                                    profilePath = path;
                                    cb();
                                });
                            });
                            return true;
                        }
                        function cleanupPaths(profile) {
                            let externalFileCounter = 0;
                            const remappedPaths = /* @__PURE__ */ new Map();
                            const normalizedDir = normalizeSlashes(_path.dirname(executingFilePath));
                            const fileUrlRoot = `file://${getRootLength(normalizedDir) === 1 ? "" : "/"}${normalizedDir}`;
                            for (const node of profile.nodes) {
                                if (node.callFrame.url) {
                                    const url = normalizeSlashes(node.callFrame.url);
                                    if (containsPath(fileUrlRoot, url, useCaseSensitiveFileNames)) {
                                        node.callFrame.url = getRelativePathToDirectoryOrUrl(fileUrlRoot, url, fileUrlRoot, createGetCanonicalFileName(useCaseSensitiveFileNames), 
                                        /*isAbsolutePathAnUrl*/
                                        true);
                                    }
                                    else if (!nativePattern.test(url)) {
                                        node.callFrame.url = (remappedPaths.has(url) ? remappedPaths : remappedPaths.set(url, `external${externalFileCounter}.js`)).get(url);
                                        externalFileCounter++;
                                    }
                                }
                            }
                            return profile;
                        }
                        function disableCPUProfiler(cb) {
                            if (activeSession && activeSession !== "stopping") {
                                const s = activeSession;
                                activeSession.post("Profiler.stop", (err, { profile }) => {
                                    var _a2;
                                    if (!err) {
                                        try {
                                            if ((_a2 = statSync(profilePath)) == null ? void 0 : _a2.isDirectory()) {
                                                profilePath = _path.join(profilePath, `${( /* @__PURE__ */new Date()).toISOString().replace(/:/g, "-")}+P${process.pid}.cpuprofile`);
                                            }
                                        }
                                        catch (e) {
                                        }
                                        try {
                                            _fs.mkdirSync(_path.dirname(profilePath), { recursive: true });
                                        }
                                        catch (e) {
                                        }
                                        _fs.writeFileSync(profilePath, JSON.stringify(cleanupPaths(profile)));
                                    }
                                    activeSession = void 0;
                                    s.disconnect();
                                    cb();
                                });
                                activeSession = "stopping";
                                return true;
                            }
                            else {
                                cb();
                                return false;
                            }
                        }
                        function bufferFrom(input, encoding) {
                            return Buffer2.from && Buffer2.from !== Int8Array.from ? Buffer2.from(input, encoding) : new Buffer2(input, encoding);
                        }
                        function isFileSystemCaseSensitive() {
                            if (platform === "win32" || platform === "win64") {
                                return false;
                            }
                            return !fileExists(swapCase(__filename));
                        }
                        function swapCase(s) {
                            return s.replace(/\w/g, (ch) => {
                                const up = ch.toUpperCase();
                                return ch === up ? ch.toLowerCase() : up;
                            });
                        }
                        function fsWatchFileWorker(fileName, callback, pollingInterval) {
                            _fs.watchFile(fileName, { persistent: true, interval: pollingInterval }, fileChanged);
                            let eventKind;
                            return {
                                close: () => _fs.unwatchFile(fileName, fileChanged)
                            };
                            function fileChanged(curr, prev) {
                                const isPreviouslyDeleted = +prev.mtime === 0 || eventKind === 2 /* Deleted */;
                                if (+curr.mtime === 0) {
                                    if (isPreviouslyDeleted) {
                                        return;
                                    }
                                    eventKind = 2 /* Deleted */;
                                }
                                else if (isPreviouslyDeleted) {
                                    eventKind = 0 /* Created */;
                                }
                                else if (+curr.mtime === +prev.mtime) {
                                    return;
                                }
                                else {
                                    eventKind = 1 /* Changed */;
                                }
                                callback(fileName, eventKind, curr.mtime);
                            }
                        }
                        function fsWatchWorker(fileOrDirectory, recursive, callback) {
                            return _fs.watch(fileOrDirectory, fsSupportsRecursiveFsWatch ? { persistent: true, recursive: !!recursive } : { persistent: true }, callback);
                        }
                        function readFileWorker(fileName, _encoding) {
                            let buffer;
                            try {
                                buffer = _fs.readFileSync(fileName);
                            }
                            catch (e) {
                                return void 0;
                            }
                            let len = buffer.length;
                            if (len >= 2 && buffer[0] === 254 && buffer[1] === 255) {
                                len &= ~1;
                                for (let i = 0; i < len; i += 2) {
                                    const temp = buffer[i];
                                    buffer[i] = buffer[i + 1];
                                    buffer[i + 1] = temp;
                                }
                                return buffer.toString("utf16le", 2);
                            }
                            if (len >= 2 && buffer[0] === 255 && buffer[1] === 254) {
                                return buffer.toString("utf16le", 2);
                            }
                            if (len >= 3 && buffer[0] === 239 && buffer[1] === 187 && buffer[2] === 191) {
                                return buffer.toString("utf8", 3);
                            }
                            return buffer.toString("utf8");
                        }
                        function readFile(fileName, _encoding) {
                            perfLogger.logStartReadFile(fileName);
                            const file = readFileWorker(fileName, _encoding);
                            perfLogger.logStopReadFile();
                            return file;
                        }
                        function writeFile2(fileName, data, writeByteOrderMark) {
                            perfLogger.logEvent("WriteFile: " + fileName);
                            if (writeByteOrderMark) {
                                data = byteOrderMarkIndicator + data;
                            }
                            let fd;
                            try {
                                fd = _fs.openSync(fileName, "w");
                                _fs.writeSync(fd, data, 
                                /*position*/
                                void 0, "utf8");
                            }
                            finally {
                                if (fd !== void 0) {
                                    _fs.closeSync(fd);
                                }
                            }
                        }
                        function getAccessibleFileSystemEntries(path) {
                            perfLogger.logEvent("ReadDir: " + (path || "."));
                            try {
                                const entries = _fs.readdirSync(path || ".", { withFileTypes: true });
                                const files = [];
                                const directories = [];
                                for (const dirent of entries) {
                                    const entry = typeof dirent === "string" ? dirent : dirent.name;
                                    if (entry === "." || entry === "..") {
                                        continue;
                                    }
                                    let stat;
                                    if (typeof dirent === "string" || dirent.isSymbolicLink()) {
                                        const name = combinePaths(path, entry);
                                        try {
                                            stat = statSync(name);
                                            if (!stat) {
                                                continue;
                                            }
                                        }
                                        catch (e) {
                                            continue;
                                        }
                                    }
                                    else {
                                        stat = dirent;
                                    }
                                    if (stat.isFile()) {
                                        files.push(entry);
                                    }
                                    else if (stat.isDirectory()) {
                                        directories.push(entry);
                                    }
                                }
                                files.sort();
                                directories.sort();
                                return { files, directories };
                            }
                            catch (e) {
                                return emptyFileSystemEntries;
                            }
                        }
                        function readDirectory(path, extensions, excludes, includes, depth) {
                            return matchFiles(path, extensions, excludes, includes, useCaseSensitiveFileNames, process.cwd(), depth, getAccessibleFileSystemEntries, realpath);
                        }
                        function fileSystemEntryExists(path, entryKind) {
                            const originalStackTraceLimit = Error.stackTraceLimit;
                            Error.stackTraceLimit = 0;
                            try {
                                const stat = statSync(path);
                                if (!stat) {
                                    return false;
                                }
                                switch (entryKind) {
                                    case 0 /* File */:
                                        return stat.isFile();
                                    case 1 /* Directory */:
                                        return stat.isDirectory();
                                    default:
                                        return false;
                                }
                            }
                            catch (e) {
                                return false;
                            }
                            finally {
                                Error.stackTraceLimit = originalStackTraceLimit;
                            }
                        }
                        function fileExists(path) {
                            return fileSystemEntryExists(path, 0 /* File */);
                        }
                        function directoryExists(path) {
                            return fileSystemEntryExists(path, 1 /* Directory */);
                        }
                        function getDirectories(path) {
                            return getAccessibleFileSystemEntries(path).directories.slice();
                        }
                        function fsRealPathHandlingLongPath(path) {
                            return path.length < 260 ? _fs.realpathSync.native(path) : _fs.realpathSync(path);
                        }
                        function realpath(path) {
                            try {
                                return fsRealpath(path);
                            }
                            catch (e) {
                                return path;
                            }
                        }
                        function getModifiedTime3(path) {
                            var _a2;
                            const originalStackTraceLimit = Error.stackTraceLimit;
                            Error.stackTraceLimit = 0;
                            try {
                                return (_a2 = statSync(path)) == null ? void 0 : _a2.mtime;
                            }
                            catch (e) {
                                return void 0;
                            }
                            finally {
                                Error.stackTraceLimit = originalStackTraceLimit;
                            }
                        }
                        function setModifiedTime(path, time) {
                            try {
                                _fs.utimesSync(path, time, time);
                            }
                            catch (e) {
                                return;
                            }
                        }
                        function deleteFile(path) {
                            try {
                                return _fs.unlinkSync(path);
                            }
                            catch (e) {
                                return;
                            }
                        }
                        function createSHA256Hash(data) {
                            const hash = _crypto.createHash("sha256");
                            hash.update(data);
                            return hash.digest("hex");
                        }
                    }
                    let sys2;
                    if (isNodeLikeSystem()) {
                        sys2 = getNodeSystem();
                    }
                    if (sys2) {
                        patchWriteFileEnsuringDirectory(sys2);
                    }
                    return sys2;
                })();
                if (sys && sys.getEnvironmentVariable) {
                    setCustomPollingValues(sys);
                    Debug.setAssertionLevel(/^development$/i.test(sys.getEnvironmentVariable("NODE_ENV")) ? 1 /* Normal */ : 0 /* None */);
                }
                if (sys && sys.debugMode) {
                    Debug.isDebugging = true;
                }
            }
        });
        // src/compiler/path.ts
        function isAnyDirectorySeparator(charCode) {
            return charCode === 47 /* slash */ || charCode === 92 /* backslash */;
        }
        function isUrl(path) {
            return getEncodedRootLength(path) < 0;
        }
        function isRootedDiskPath(path) {
            return getEncodedRootLength(path) > 0;
        }
        function isDiskPathRoot(path) {
            const rootLength = getEncodedRootLength(path);
            return rootLength > 0 && rootLength === path.length;
        }
        function pathIsAbsolute(path) {
            return getEncodedRootLength(path) !== 0;
        }
        function pathIsRelative(path) {
            return /^\.\.?($|[\\/])/.test(path);
        }
        function pathIsBareSpecifier(path) {
            return !pathIsAbsolute(path) && !pathIsRelative(path);
        }
        function hasExtension(fileName) {
            return stringContains(getBaseFileName(fileName), ".");
        }
        function fileExtensionIs(path, extension) {
            return path.length > extension.length && endsWith(path, extension);
        }
        function fileExtensionIsOneOf(path, extensions) {
            for (const extension of extensions) {
                if (fileExtensionIs(path, extension)) {
                    return true;
                }
            }
            return false;
        }
        function hasTrailingDirectorySeparator(path) {
            return path.length > 0 && isAnyDirectorySeparator(path.charCodeAt(path.length - 1));
        }
        function isVolumeCharacter(charCode) {
            return charCode >= 97 /* a */ && charCode <= 122 /* z */ || charCode >= 65 /* A */ && charCode <= 90 /* Z */;
        }
        function getFileUrlVolumeSeparatorEnd(url, start) {
            const ch0 = url.charCodeAt(start);
            if (ch0 === 58 /* colon */)
                return start + 1;
            if (ch0 === 37 /* percent */ && url.charCodeAt(start + 1) === 51 /* _3 */) {
                const ch2 = url.charCodeAt(start + 2);
                if (ch2 === 97 /* a */ || ch2 === 65 /* A */)
                    return start + 3;
            }
            return -1;
        }
        function getEncodedRootLength(path) {
            if (!path)
                return 0;
            const ch0 = path.charCodeAt(0);
            if (ch0 === 47 /* slash */ || ch0 === 92 /* backslash */) {
                if (path.charCodeAt(1) !== ch0)
                    return 1;
                const p1 = path.indexOf(ch0 === 47 /* slash */ ? directorySeparator : altDirectorySeparator, 2);
                if (p1 < 0)
                    return path.length;
                return p1 + 1;
            }
            if (isVolumeCharacter(ch0) && path.charCodeAt(1) === 58 /* colon */) {
                const ch2 = path.charCodeAt(2);
                if (ch2 === 47 /* slash */ || ch2 === 92 /* backslash */)
                    return 3;
                if (path.length === 2)
                    return 2;
            }
            const schemeEnd = path.indexOf(urlSchemeSeparator);
            if (schemeEnd !== -1) {
                const authorityStart = schemeEnd + urlSchemeSeparator.length;
                const authorityEnd = path.indexOf(directorySeparator, authorityStart);
                if (authorityEnd !== -1) {
                    const scheme = path.slice(0, schemeEnd);
                    const authority = path.slice(authorityStart, authorityEnd);
                    if (scheme === "file" && (authority === "" || authority === "localhost") && isVolumeCharacter(path.charCodeAt(authorityEnd + 1))) {
                        const volumeSeparatorEnd = getFileUrlVolumeSeparatorEnd(path, authorityEnd + 2);
                        if (volumeSeparatorEnd !== -1) {
                            if (path.charCodeAt(volumeSeparatorEnd) === 47 /* slash */) {
                                return ~(volumeSeparatorEnd + 1);
                            }
                            if (volumeSeparatorEnd === path.length) {
                                return ~volumeSeparatorEnd;
                            }
                        }
                    }
                    return ~(authorityEnd + 1);
                }
                return ~path.length;
            }
            return 0;
        }
        function getRootLength(path) {
            const rootLength = getEncodedRootLength(path);
            return rootLength < 0 ? ~rootLength : rootLength;
        }
        function getDirectoryPath(path) {
            path = normalizeSlashes(path);
            const rootLength = getRootLength(path);
            if (rootLength === path.length)
                return path;
            path = removeTrailingDirectorySeparator(path);
            return path.slice(0, Math.max(rootLength, path.lastIndexOf(directorySeparator)));
        }
        function getBaseFileName(path, extensions, ignoreCase) {
            path = normalizeSlashes(path);
            const rootLength = getRootLength(path);
            if (rootLength === path.length)
                return "";
            path = removeTrailingDirectorySeparator(path);
            const name = path.slice(Math.max(getRootLength(path), path.lastIndexOf(directorySeparator) + 1));
            const extension = extensions !== void 0 && ignoreCase !== void 0 ? getAnyExtensionFromPath(name, extensions, ignoreCase) : void 0;
            return extension ? name.slice(0, name.length - extension.length) : name;
        }
        function tryGetExtensionFromPath(path, extension, stringEqualityComparer) {
            if (!startsWith(extension, "."))
                extension = "." + extension;
            if (path.length >= extension.length && path.charCodeAt(path.length - extension.length) === 46 /* dot */) {
                const pathExtension = path.slice(path.length - extension.length);
                if (stringEqualityComparer(pathExtension, extension)) {
                    return pathExtension;
                }
            }
        }
        function getAnyExtensionFromPathWorker(path, extensions, stringEqualityComparer) {
            if (typeof extensions === "string") {
                return tryGetExtensionFromPath(path, extensions, stringEqualityComparer) || "";
            }
            for (const extension of extensions) {
                const result = tryGetExtensionFromPath(path, extension, stringEqualityComparer);
                if (result)
                    return result;
            }
            return "";
        }
        function getAnyExtensionFromPath(path, extensions, ignoreCase) {
            if (extensions) {
                return getAnyExtensionFromPathWorker(removeTrailingDirectorySeparator(path), extensions, ignoreCase ? equateStringsCaseInsensitive : equateStringsCaseSensitive);
            }
            const baseFileName = getBaseFileName(path);
            const extensionIndex = baseFileName.lastIndexOf(".");
            if (extensionIndex >= 0) {
                return baseFileName.substring(extensionIndex);
            }
            return "";
        }
        function pathComponents(path, rootLength) {
            const root = path.substring(0, rootLength);
            const rest = path.substring(rootLength).split(directorySeparator);
            if (rest.length && !lastOrUndefined(rest))
                rest.pop();
            return [root, ...rest];
        }
        function getPathComponents(path, currentDirectory = "") {
            path = combinePaths(currentDirectory, path);
            return pathComponents(path, getRootLength(path));
        }
        function getPathFromPathComponents(pathComponents2) {
            if (pathComponents2.length === 0)
                return "";
            const root = pathComponents2[0] && ensureTrailingDirectorySeparator(pathComponents2[0]);
            return root + pathComponents2.slice(1).join(directorySeparator);
        }
        function normalizeSlashes(path) {
            return path.indexOf("\\") !== -1 ? path.replace(backslashRegExp, directorySeparator) : path;
        }
        function reducePathComponents(components) {
            if (!some(components))
                return [];
            const reduced = [components[0]];
            for (let i = 1; i < components.length; i++) {
                const component = components[i];
                if (!component)
                    continue;
                if (component === ".")
                    continue;
                if (component === "..") {
                    if (reduced.length > 1) {
                        if (reduced[reduced.length - 1] !== "..") {
                            reduced.pop();
                            continue;
                        }
                    }
                    else if (reduced[0])
                        continue;
                }
                reduced.push(component);
            }
            return reduced;
        }
        function combinePaths(path, ...paths) {
            if (path)
                path = normalizeSlashes(path);
            for (let relativePath of paths) {
                if (!relativePath)
                    continue;
                relativePath = normalizeSlashes(relativePath);
                if (!path || getRootLength(relativePath) !== 0) {
                    path = relativePath;
                }
                else {
                    path = ensureTrailingDirectorySeparator(path) + relativePath;
                }
            }
            return path;
        }
        function resolvePath(path, ...paths) {
            return normalizePath(some(paths) ? combinePaths(path, ...paths) : normalizeSlashes(path));
        }
        function getNormalizedPathComponents(path, currentDirectory) {
            return reducePathComponents(getPathComponents(path, currentDirectory));
        }
        function getNormalizedAbsolutePath(fileName, currentDirectory) {
            return getPathFromPathComponents(getNormalizedPathComponents(fileName, currentDirectory));
        }
        function normalizePath(path) {
            path = normalizeSlashes(path);
            if (!relativePathSegmentRegExp.test(path)) {
                return path;
            }
            const simplified = path.replace(/\/\.\//g, "/").replace(/^\.\//, "");
            if (simplified !== path) {
                path = simplified;
                if (!relativePathSegmentRegExp.test(path)) {
                    return path;
                }
            }
            const normalized = getPathFromPathComponents(reducePathComponents(getPathComponents(path)));
            return normalized && hasTrailingDirectorySeparator(path) ? ensureTrailingDirectorySeparator(normalized) : normalized;
        }
        function getPathWithoutRoot(pathComponents2) {
            if (pathComponents2.length === 0)
                return "";
            return pathComponents2.slice(1).join(directorySeparator);
        }
        function getNormalizedAbsolutePathWithoutRoot(fileName, currentDirectory) {
            return getPathWithoutRoot(getNormalizedPathComponents(fileName, currentDirectory));
        }
        function toPath(fileName, basePath, getCanonicalFileName) {
            const nonCanonicalizedPath = isRootedDiskPath(fileName) ? normalizePath(fileName) : getNormalizedAbsolutePath(fileName, basePath);
            return getCanonicalFileName(nonCanonicalizedPath);
        }
        function removeTrailingDirectorySeparator(path) {
            if (hasTrailingDirectorySeparator(path)) {
                return path.substr(0, path.length - 1);
            }
            return path;
        }
        function ensureTrailingDirectorySeparator(path) {
            if (!hasTrailingDirectorySeparator(path)) {
                return path + directorySeparator;
            }
            return path;
        }
        function ensurePathIsNonModuleName(path) {
            return !pathIsAbsolute(path) && !pathIsRelative(path) ? "./" + path : path;
        }
        function changeAnyExtension(path, ext, extensions, ignoreCase) {
            const pathext = extensions !== void 0 && ignoreCase !== void 0 ? getAnyExtensionFromPath(path, extensions, ignoreCase) : getAnyExtensionFromPath(path);
            return pathext ? path.slice(0, path.length - pathext.length) + (startsWith(ext, ".") ? ext : "." + ext) : path;
        }
        function comparePathsWorker(a, b, componentComparer) {
            if (a === b)
                return 0 /* EqualTo */;
            if (a === void 0)
                return -1 /* LessThan */;
            if (b === void 0)
                return 1 /* GreaterThan */;
            const aRoot = a.substring(0, getRootLength(a));
            const bRoot = b.substring(0, getRootLength(b));
            const result = compareStringsCaseInsensitive(aRoot, bRoot);
            if (result !== 0 /* EqualTo */) {
                return result;
            }
            const aRest = a.substring(aRoot.length);
            const bRest = b.substring(bRoot.length);
            if (!relativePathSegmentRegExp.test(aRest) && !relativePathSegmentRegExp.test(bRest)) {
                return componentComparer(aRest, bRest);
            }
            const aComponents = reducePathComponents(getPathComponents(a));
            const bComponents = reducePathComponents(getPathComponents(b));
            const sharedLength = Math.min(aComponents.length, bComponents.length);
            for (let i = 1; i < sharedLength; i++) {
                const result2 = componentComparer(aComponents[i], bComponents[i]);
                if (result2 !== 0 /* EqualTo */) {
                    return result2;
                }
            }
            return compareValues(aComponents.length, bComponents.length);
        }
        function comparePathsCaseSensitive(a, b) {
            return comparePathsWorker(a, b, compareStringsCaseSensitive);
        }
        function comparePathsCaseInsensitive(a, b) {
            return comparePathsWorker(a, b, compareStringsCaseInsensitive);
        }
        function comparePaths(a, b, currentDirectory, ignoreCase) {
            if (typeof currentDirectory === "string") {
                a = combinePaths(currentDirectory, a);
                b = combinePaths(currentDirectory, b);
            }
            else if (typeof currentDirectory === "boolean") {
                ignoreCase = currentDirectory;
            }
            return comparePathsWorker(a, b, getStringComparer(ignoreCase));
        }
        function containsPath(parent2, child, currentDirectory, ignoreCase) {
            if (typeof currentDirectory === "string") {
                parent2 = combinePaths(currentDirectory, parent2);
                child = combinePaths(currentDirectory, child);
            }
            else if (typeof currentDirectory === "boolean") {
                ignoreCase = currentDirectory;
            }
            if (parent2 === void 0 || child === void 0)
                return false;
            if (parent2 === child)
                return true;
            const parentComponents = reducePathComponents(getPathComponents(parent2));
            const childComponents = reducePathComponents(getPathComponents(child));
            if (childComponents.length < parentComponents.length) {
                return false;
            }
            const componentEqualityComparer = ignoreCase ? equateStringsCaseInsensitive : equateStringsCaseSensitive;
            for (let i = 0; i < parentComponents.length; i++) {
                const equalityComparer = i === 0 ? equateStringsCaseInsensitive : componentEqualityComparer;
                if (!equalityComparer(parentComponents[i], childComponents[i])) {
                    return false;
                }
            }
            return true;
        }
        function startsWithDirectory(fileName, directoryName, getCanonicalFileName) {
            const canonicalFileName = getCanonicalFileName(fileName);
            const canonicalDirectoryName = getCanonicalFileName(directoryName);
            return startsWith(canonicalFileName, canonicalDirectoryName + "/") || startsWith(canonicalFileName, canonicalDirectoryName + "\\");
        }
        function getPathComponentsRelativeTo(from, to, stringEqualityComparer, getCanonicalFileName) {
            const fromComponents = reducePathComponents(getPathComponents(from));
            const toComponents = reducePathComponents(getPathComponents(to));
            let start;
            for (start = 0; start < fromComponents.length && start < toComponents.length; start++) {
                const fromComponent = getCanonicalFileName(fromComponents[start]);
                const toComponent = getCanonicalFileName(toComponents[start]);
                const comparer = start === 0 ? equateStringsCaseInsensitive : stringEqualityComparer;
                if (!comparer(fromComponent, toComponent))
                    break;
            }
            if (start === 0) {
                return toComponents;
            }
            const components = toComponents.slice(start);
            const relative = [];
            for (; start < fromComponents.length; start++) {
                relative.push("..");
            }
            return ["", ...relative, ...components];
        }
        function getRelativePathFromDirectory(fromDirectory, to, getCanonicalFileNameOrIgnoreCase) {
            Debug.assert(getRootLength(fromDirectory) > 0 === getRootLength(to) > 0, "Paths must either both be absolute or both be relative");
            const getCanonicalFileName = typeof getCanonicalFileNameOrIgnoreCase === "function" ? getCanonicalFileNameOrIgnoreCase : identity;
            const ignoreCase = typeof getCanonicalFileNameOrIgnoreCase === "boolean" ? getCanonicalFileNameOrIgnoreCase : false;
            const pathComponents2 = getPathComponentsRelativeTo(fromDirectory, to, ignoreCase ? equateStringsCaseInsensitive : equateStringsCaseSensitive, getCanonicalFileName);
            return getPathFromPathComponents(pathComponents2);
        }
        function convertToRelativePath(absoluteOrRelativePath, basePath, getCanonicalFileName) {
            return !isRootedDiskPath(absoluteOrRelativePath) ? absoluteOrRelativePath : getRelativePathToDirectoryOrUrl(basePath, absoluteOrRelativePath, basePath, getCanonicalFileName, 
            /*isAbsolutePathAnUrl*/
            false);
        }
        function getRelativePathFromFile(from, to, getCanonicalFileName) {
            return ensurePathIsNonModuleName(getRelativePathFromDirectory(getDirectoryPath(from), to, getCanonicalFileName));
        }
        function getRelativePathToDirectoryOrUrl(directoryPathOrUrl, relativeOrAbsolutePath, currentDirectory, getCanonicalFileName, isAbsolutePathAnUrl) {
            const pathComponents2 = getPathComponentsRelativeTo(resolvePath(currentDirectory, directoryPathOrUrl), resolvePath(currentDirectory, relativeOrAbsolutePath), equateStringsCaseSensitive, getCanonicalFileName);
            const firstComponent = pathComponents2[0];
            if (isAbsolutePathAnUrl && isRootedDiskPath(firstComponent)) {
                const prefix = firstComponent.charAt(0) === directorySeparator ? "file://" : "file:///";
                pathComponents2[0] = prefix + firstComponent;
            }
            return getPathFromPathComponents(pathComponents2);
        }
        function forEachAncestorDirectory(directory, callback) {
            while (true) {
                const result = callback(directory);
                if (result !== void 0) {
                    return result;
                }
                const parentPath = getDirectoryPath(directory);
                if (parentPath === directory) {
                    return void 0;
                }
                directory = parentPath;
            }
        }
        function isNodeModulesDirectory(dirPath) {
            return endsWith(dirPath, "/node_modules");
        }
        var directorySeparator, altDirectorySeparator, urlSchemeSeparator, backslashRegExp, relativePathSegmentRegExp;
        var init_path = __esm({
            "src/compiler/path.ts"() {
                "use strict";
                init_ts2();
                directorySeparator = "/";
                altDirectorySeparator = "\\";
                urlSchemeSeparator = "://";
                backslashRegExp = /\\/g;
                relativePathSegmentRegExp = /(?:\/\/)|(?:^|\/)\.\.?(?:$|\/)/;
            }
        });
        // src/compiler/diagnosticInformationMap.generated.ts
        function diag(code, category, key, message, reportsUnnecessary, elidedInCompatabilityPyramid, reportsDeprecated) {
            return { code, category, key, message, reportsUnnecessary, elidedInCompatabilityPyramid, reportsDeprecated };
        }
        var Diagnostics;
        var init_diagnosticInformationMap_generated = __esm({
            "src/compiler/diagnosticInformationMap.generated.ts"() {
                "use strict";
                init_types();
                Diagnostics = {
                    Unterminated_string_literal: diag(1002, 1 /* Error */, "Unterminated_string_literal_1002", "Unterminated string literal."),
                    Identifier_expected: diag(1003, 1 /* Error */, "Identifier_expected_1003", "Identifier expected."),
                    _0_expected: diag(1005, 1 /* Error */, "_0_expected_1005", "'{0}' expected."),
                    A_file_cannot_have_a_reference_to_itself: diag(1006, 1 /* Error */, "A_file_cannot_have_a_reference_to_itself_1006", "A file cannot have a reference to itself."),
                    The_parser_expected_to_find_a_1_to_match_the_0_token_here: diag(1007, 1 /* Error */, "The_parser_expected_to_find_a_1_to_match_the_0_token_here_1007", "The parser expected to find a '{1}' to match the '{0}' token here."),
                    Trailing_comma_not_allowed: diag(1009, 1 /* Error */, "Trailing_comma_not_allowed_1009", "Trailing comma not allowed."),
                    Asterisk_Slash_expected: diag(1010, 1 /* Error */, "Asterisk_Slash_expected_1010", "'*/' expected."),
                    An_element_access_expression_should_take_an_argument: diag(1011, 1 /* Error */, "An_element_access_expression_should_take_an_argument_1011", "An element access expression should take an argument."),
                    Unexpected_token: diag(1012, 1 /* Error */, "Unexpected_token_1012", "Unexpected token."),
                    A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma: diag(1013, 1 /* Error */, "A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma_1013", "A rest parameter or binding pattern may not have a trailing comma."),
                    A_rest_parameter_must_be_last_in_a_parameter_list: diag(1014, 1 /* Error */, "A_rest_parameter_must_be_last_in_a_parameter_list_1014", "A rest parameter must be last in a parameter list."),
                    Parameter_cannot_have_question_mark_and_initializer: diag(1015, 1 /* Error */, "Parameter_cannot_have_question_mark_and_initializer_1015", "Parameter cannot have question mark and initializer."),
                    A_required_parameter_cannot_follow_an_optional_parameter: diag(1016, 1 /* Error */, "A_required_parameter_cannot_follow_an_optional_parameter_1016", "A required parameter cannot follow an optional parameter."),
                    An_index_signature_cannot_have_a_rest_parameter: diag(1017, 1 /* Error */, "An_index_signature_cannot_have_a_rest_parameter_1017", "An index signature cannot have a rest parameter."),
                    An_index_signature_parameter_cannot_have_an_accessibility_modifier: diag(1018, 1 /* Error */, "An_index_signature_parameter_cannot_have_an_accessibility_modifier_1018", "An index signature parameter cannot have an accessibility modifier."),
                    An_index_signature_parameter_cannot_have_a_question_mark: diag(1019, 1 /* Error */, "An_index_signature_parameter_cannot_have_a_question_mark_1019", "An index signature parameter cannot have a question mark."),
                    An_index_signature_parameter_cannot_have_an_initializer: diag(1020, 1 /* Error */, "An_index_signature_parameter_cannot_have_an_initializer_1020", "An index signature parameter cannot have an initializer."),
                    An_index_signature_must_have_a_type_annotation: diag(1021, 1 /* Error */, "An_index_signature_must_have_a_type_annotation_1021", "An index signature must have a type annotation."),
                    An_index_signature_parameter_must_have_a_type_annotation: diag(1022, 1 /* Error */, "An_index_signature_parameter_must_have_a_type_annotation_1022", "An index signature parameter must have a type annotation."),
                    readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature: diag(1024, 1 /* Error */, "readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature_1024", "'readonly' modifier can only appear on a property declaration or index signature."),
                    An_index_signature_cannot_have_a_trailing_comma: diag(1025, 1 /* Error */, "An_index_signature_cannot_have_a_trailing_comma_1025", "An index signature cannot have a trailing comma."),
                    Accessibility_modifier_already_seen: diag(1028, 1 /* Error */, "Accessibility_modifier_already_seen_1028", "Accessibility modifier already seen."),
                    _0_modifier_must_precede_1_modifier: diag(1029, 1 /* Error */, "_0_modifier_must_precede_1_modifier_1029", "'{0}' modifier must precede '{1}' modifier."),
                    _0_modifier_already_seen: diag(1030, 1 /* Error */, "_0_modifier_already_seen_1030", "'{0}' modifier already seen."),
                    _0_modifier_cannot_appear_on_class_elements_of_this_kind: diag(1031, 1 /* Error */, "_0_modifier_cannot_appear_on_class_elements_of_this_kind_1031", "'{0}' modifier cannot appear on class elements of this kind."),
                    super_must_be_followed_by_an_argument_list_or_member_access: diag(1034, 1 /* Error */, "super_must_be_followed_by_an_argument_list_or_member_access_1034", "'super' must be followed by an argument list or member access."),
                    Only_ambient_modules_can_use_quoted_names: diag(1035, 1 /* Error */, "Only_ambient_modules_can_use_quoted_names_1035", "Only ambient modules can use quoted names."),
                    Statements_are_not_allowed_in_ambient_contexts: diag(1036, 1 /* Error */, "Statements_are_not_allowed_in_ambient_contexts_1036", "Statements are not allowed in ambient contexts."),
                    A_declare_modifier_cannot_be_used_in_an_already_ambient_context: diag(1038, 1 /* Error */, "A_declare_modifier_cannot_be_used_in_an_already_ambient_context_1038", "A 'declare' modifier cannot be used in an already ambient context."),
                    Initializers_are_not_allowed_in_ambient_contexts: diag(1039, 1 /* Error */, "Initializers_are_not_allowed_in_ambient_contexts_1039", "Initializers are not allowed in ambient contexts."),
                    _0_modifier_cannot_be_used_in_an_ambient_context: diag(1040, 1 /* Error */, "_0_modifier_cannot_be_used_in_an_ambient_context_1040", "'{0}' modifier cannot be used in an ambient context."),
                    _0_modifier_cannot_be_used_here: diag(1042, 1 /* Error */, "_0_modifier_cannot_be_used_here_1042", "'{0}' modifier cannot be used here."),
                    _0_modifier_cannot_appear_on_a_module_or_namespace_element: diag(1044, 1 /* Error */, "_0_modifier_cannot_appear_on_a_module_or_namespace_element_1044", "'{0}' modifier cannot appear on a module or namespace element."),
                    Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier: diag(1046, 1 /* Error */, "Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier_1046", "Top-level declarations in .d.ts files must start with either a 'declare' or 'export' modifier."),
                    A_rest_parameter_cannot_be_optional: diag(1047, 1 /* Error */, "A_rest_parameter_cannot_be_optional_1047", "A rest parameter cannot be optional."),
                    A_rest_parameter_cannot_have_an_initializer: diag(1048, 1 /* Error */, "A_rest_parameter_cannot_have_an_initializer_1048", "A rest parameter cannot have an initializer."),
                    A_set_accessor_must_have_exactly_one_parameter: diag(1049, 1 /* Error */, "A_set_accessor_must_have_exactly_one_parameter_1049", "A 'set' accessor must have exactly one parameter."),
                    A_set_accessor_cannot_have_an_optional_parameter: diag(1051, 1 /* Error */, "A_set_accessor_cannot_have_an_optional_parameter_1051", "A 'set' accessor cannot have an optional parameter."),
                    A_set_accessor_parameter_cannot_have_an_initializer: diag(1052, 1 /* Error */, "A_set_accessor_parameter_cannot_have_an_initializer_1052", "A 'set' accessor parameter cannot have an initializer."),
                    A_set_accessor_cannot_have_rest_parameter: diag(1053, 1 /* Error */, "A_set_accessor_cannot_have_rest_parameter_1053", "A 'set' accessor cannot have rest parameter."),
                    A_get_accessor_cannot_have_parameters: diag(1054, 1 /* Error */, "A_get_accessor_cannot_have_parameters_1054", "A 'get' accessor cannot have parameters."),
                    Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value: diag(1055, 1 /* Error */, "Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Prom_1055", "Type '{0}' is not a valid async function return type in ES5/ES3 because it does not refer to a Promise-compatible constructor value."),
                    Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher: diag(1056, 1 /* Error */, "Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher_1056", "Accessors are only available when targeting ECMAScript 5 and higher."),
                    The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: diag(1058, 1 /* Error */, "The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_t_1058", "The return type of an async function must either be a valid promise or must not contain a callable 'then' member."),
                    A_promise_must_have_a_then_method: diag(1059, 1 /* Error */, "A_promise_must_have_a_then_method_1059", "A promise must have a 'then' method."),
                    The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback: diag(1060, 1 /* Error */, "The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback_1060", "The first parameter of the 'then' method of a promise must be a callback."),
                    Enum_member_must_have_initializer: diag(1061, 1 /* Error */, "Enum_member_must_have_initializer_1061", "Enum member must have initializer."),
                    Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method: diag(1062, 1 /* Error */, "Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method_1062", "Type is referenced directly or indirectly in the fulfillment callback of its own 'then' method."),
                    An_export_assignment_cannot_be_used_in_a_namespace: diag(1063, 1 /* Error */, "An_export_assignment_cannot_be_used_in_a_namespace_1063", "An export assignment cannot be used in a namespace."),
                    The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0: diag(1064, 1 /* Error */, "The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_wri_1064", "The return type of an async function or method must be the global Promise<T> type. Did you mean to write 'Promise<{0}>'?"),
                    In_ambient_enum_declarations_member_initializer_must_be_constant_expression: diag(1066, 1 /* Error */, "In_ambient_enum_declarations_member_initializer_must_be_constant_expression_1066", "In ambient enum declarations member initializer must be constant expression."),
                    Unexpected_token_A_constructor_method_accessor_or_property_was_expected: diag(1068, 1 /* Error */, "Unexpected_token_A_constructor_method_accessor_or_property_was_expected_1068", "Unexpected token. A constructor, method, accessor, or property was expected."),
                    Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces: diag(1069, 1 /* Error */, "Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces_1069", "Unexpected token. A type parameter name was expected without curly braces."),
                    _0_modifier_cannot_appear_on_a_type_member: diag(1070, 1 /* Error */, "_0_modifier_cannot_appear_on_a_type_member_1070", "'{0}' modifier cannot appear on a type member."),
                    _0_modifier_cannot_appear_on_an_index_signature: diag(1071, 1 /* Error */, "_0_modifier_cannot_appear_on_an_index_signature_1071", "'{0}' modifier cannot appear on an index signature."),
                    A_0_modifier_cannot_be_used_with_an_import_declaration: diag(1079, 1 /* Error */, "A_0_modifier_cannot_be_used_with_an_import_declaration_1079", "A '{0}' modifier cannot be used with an import declaration."),
                    Invalid_reference_directive_syntax: diag(1084, 1 /* Error */, "Invalid_reference_directive_syntax_1084", "Invalid 'reference' directive syntax."),
                    Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher_Use_the_syntax_0: diag(1085, 1 /* Error */, "Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher_Use_the_syntax_0_1085", "Octal literals are not available when targeting ECMAScript 5 and higher. Use the syntax '{0}'."),
                    _0_modifier_cannot_appear_on_a_constructor_declaration: diag(1089, 1 /* Error */, "_0_modifier_cannot_appear_on_a_constructor_declaration_1089", "'{0}' modifier cannot appear on a constructor declaration."),
                    _0_modifier_cannot_appear_on_a_parameter: diag(1090, 1 /* Error */, "_0_modifier_cannot_appear_on_a_parameter_1090", "'{0}' modifier cannot appear on a parameter."),
                    Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement: diag(1091, 1 /* Error */, "Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement_1091", "Only a single variable declaration is allowed in a 'for...in' statement."),
                    Type_parameters_cannot_appear_on_a_constructor_declaration: diag(1092, 1 /* Error */, "Type_parameters_cannot_appear_on_a_constructor_declaration_1092", "Type parameters cannot appear on a constructor declaration."),
                    Type_annotation_cannot_appear_on_a_constructor_declaration: diag(1093, 1 /* Error */, "Type_annotation_cannot_appear_on_a_constructor_declaration_1093", "Type annotation cannot appear on a constructor declaration."),
                    An_accessor_cannot_have_type_parameters: diag(1094, 1 /* Error */, "An_accessor_cannot_have_type_parameters_1094", "An accessor cannot have type parameters."),
                    A_set_accessor_cannot_have_a_return_type_annotation: diag(1095, 1 /* Error */, "A_set_accessor_cannot_have_a_return_type_annotation_1095", "A 'set' accessor cannot have a return type annotation."),
                    An_index_signature_must_have_exactly_one_parameter: diag(1096, 1 /* Error */, "An_index_signature_must_have_exactly_one_parameter_1096", "An index signature must have exactly one parameter."),
                    _0_list_cannot_be_empty: diag(1097, 1 /* Error */, "_0_list_cannot_be_empty_1097", "'{0}' list cannot be empty."),
                    Type_parameter_list_cannot_be_empty: diag(1098, 1 /* Error */, "Type_parameter_list_cannot_be_empty_1098", "Type parameter list cannot be empty."),
                    Type_argument_list_cannot_be_empty: diag(1099, 1 /* Error */, "Type_argument_list_cannot_be_empty_1099", "Type argument list cannot be empty."),
                    Invalid_use_of_0_in_strict_mode: diag(1100, 1 /* Error */, "Invalid_use_of_0_in_strict_mode_1100", "Invalid use of '{0}' in strict mode."),
                    with_statements_are_not_allowed_in_strict_mode: diag(1101, 1 /* Error */, "with_statements_are_not_allowed_in_strict_mode_1101", "'with' statements are not allowed in strict mode."),
                    delete_cannot_be_called_on_an_identifier_in_strict_mode: diag(1102, 1 /* Error */, "delete_cannot_be_called_on_an_identifier_in_strict_mode_1102", "'delete' cannot be called on an identifier in strict mode."),
                    for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: diag(1103, 1 /* Error */, "for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1103", "'for await' loops are only allowed within async functions and at the top levels of modules."),
                    A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement: diag(1104, 1 /* Error */, "A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement_1104", "A 'continue' statement can only be used within an enclosing iteration statement."),
                    A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement: diag(1105, 1 /* Error */, "A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement_1105", "A 'break' statement can only be used within an enclosing iteration or switch statement."),
                    The_left_hand_side_of_a_for_of_statement_may_not_be_async: diag(1106, 1 /* Error */, "The_left_hand_side_of_a_for_of_statement_may_not_be_async_1106", "The left-hand side of a 'for...of' statement may not be 'async'."),
                    Jump_target_cannot_cross_function_boundary: diag(1107, 1 /* Error */, "Jump_target_cannot_cross_function_boundary_1107", "Jump target cannot cross function boundary."),
                    A_return_statement_can_only_be_used_within_a_function_body: diag(1108, 1 /* Error */, "A_return_statement_can_only_be_used_within_a_function_body_1108", "A 'return' statement can only be used within a function body."),
                    Expression_expected: diag(1109, 1 /* Error */, "Expression_expected_1109", "Expression expected."),
                    Type_expected: diag(1110, 1 /* Error */, "Type_expected_1110", "Type expected."),
                    A_default_clause_cannot_appear_more_than_once_in_a_switch_statement: diag(1113, 1 /* Error */, "A_default_clause_cannot_appear_more_than_once_in_a_switch_statement_1113", "A 'default' clause cannot appear more than once in a 'switch' statement."),
                    Duplicate_label_0: diag(1114, 1 /* Error */, "Duplicate_label_0_1114", "Duplicate label '{0}'."),
                    A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement: diag(1115, 1 /* Error */, "A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement_1115", "A 'continue' statement can only jump to a label of an enclosing iteration statement."),
                    A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement: diag(1116, 1 /* Error */, "A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement_1116", "A 'break' statement can only jump to a label of an enclosing statement."),
                    An_object_literal_cannot_have_multiple_properties_with_the_same_name: diag(1117, 1 /* Error */, "An_object_literal_cannot_have_multiple_properties_with_the_same_name_1117", "An object literal cannot have multiple properties with the same name."),
                    An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name: diag(1118, 1 /* Error */, "An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name_1118", "An object literal cannot have multiple get/set accessors with the same name."),
                    An_object_literal_cannot_have_property_and_accessor_with_the_same_name: diag(1119, 1 /* Error */, "An_object_literal_cannot_have_property_and_accessor_with_the_same_name_1119", "An object literal cannot have property and accessor with the same name."),
                    An_export_assignment_cannot_have_modifiers: diag(1120, 1 /* Error */, "An_export_assignment_cannot_have_modifiers_1120", "An export assignment cannot have modifiers."),
                    Octal_literals_are_not_allowed_in_strict_mode: diag(1121, 1 /* Error */, "Octal_literals_are_not_allowed_in_strict_mode_1121", "Octal literals are not allowed in strict mode."),
                    Variable_declaration_list_cannot_be_empty: diag(1123, 1 /* Error */, "Variable_declaration_list_cannot_be_empty_1123", "Variable declaration list cannot be empty."),
                    Digit_expected: diag(1124, 1 /* Error */, "Digit_expected_1124", "Digit expected."),
                    Hexadecimal_digit_expected: diag(1125, 1 /* Error */, "Hexadecimal_digit_expected_1125", "Hexadecimal digit expected."),
                    Unexpected_end_of_text: diag(1126, 1 /* Error */, "Unexpected_end_of_text_1126", "Unexpected end of text."),
                    Invalid_character: diag(1127, 1 /* Error */, "Invalid_character_1127", "Invalid character."),
                    Declaration_or_statement_expected: diag(1128, 1 /* Error */, "Declaration_or_statement_expected_1128", "Declaration or statement expected."),
                    Statement_expected: diag(1129, 1 /* Error */, "Statement_expected_1129", "Statement expected."),
                    case_or_default_expected: diag(1130, 1 /* Error */, "case_or_default_expected_1130", "'case' or 'default' expected."),
                    Property_or_signature_expected: diag(1131, 1 /* Error */, "Property_or_signature_expected_1131", "Property or signature expected."),
                    Enum_member_expected: diag(1132, 1 /* Error */, "Enum_member_expected_1132", "Enum member expected."),
                    Variable_declaration_expected: diag(1134, 1 /* Error */, "Variable_declaration_expected_1134", "Variable declaration expected."),
                    Argument_expression_expected: diag(1135, 1 /* Error */, "Argument_expression_expected_1135", "Argument expression expected."),
                    Property_assignment_expected: diag(1136, 1 /* Error */, "Property_assignment_expected_1136", "Property assignment expected."),
                    Expression_or_comma_expected: diag(1137, 1 /* Error */, "Expression_or_comma_expected_1137", "Expression or comma expected."),
                    Parameter_declaration_expected: diag(1138, 1 /* Error */, "Parameter_declaration_expected_1138", "Parameter declaration expected."),
                    Type_parameter_declaration_expected: diag(1139, 1 /* Error */, "Type_parameter_declaration_expected_1139", "Type parameter declaration expected."),
                    Type_argument_expected: diag(1140, 1 /* Error */, "Type_argument_expected_1140", "Type argument expected."),
                    String_literal_expected: diag(1141, 1 /* Error */, "String_literal_expected_1141", "String literal expected."),
                    Line_break_not_permitted_here: diag(1142, 1 /* Error */, "Line_break_not_permitted_here_1142", "Line break not permitted here."),
                    or_expected: diag(1144, 1 /* Error */, "or_expected_1144", "'{' or ';' expected."),
                    or_JSX_element_expected: diag(1145, 1 /* Error */, "or_JSX_element_expected_1145", "'{' or JSX element expected."),
                    Declaration_expected: diag(1146, 1 /* Error */, "Declaration_expected_1146", "Declaration expected."),
                    Import_declarations_in_a_namespace_cannot_reference_a_module: diag(1147, 1 /* Error */, "Import_declarations_in_a_namespace_cannot_reference_a_module_1147", "Import declarations in a namespace cannot reference a module."),
                    Cannot_use_imports_exports_or_module_augmentations_when_module_is_none: diag(1148, 1 /* Error */, "Cannot_use_imports_exports_or_module_augmentations_when_module_is_none_1148", "Cannot use imports, exports, or module augmentations when '--module' is 'none'."),
                    File_name_0_differs_from_already_included_file_name_1_only_in_casing: diag(1149, 1 /* Error */, "File_name_0_differs_from_already_included_file_name_1_only_in_casing_1149", "File name '{0}' differs from already included file name '{1}' only in casing."),
                    const_declarations_must_be_initialized: diag(1155, 1 /* Error */, "const_declarations_must_be_initialized_1155", "'const' declarations must be initialized."),
                    const_declarations_can_only_be_declared_inside_a_block: diag(1156, 1 /* Error */, "const_declarations_can_only_be_declared_inside_a_block_1156", "'const' declarations can only be declared inside a block."),
                    let_declarations_can_only_be_declared_inside_a_block: diag(1157, 1 /* Error */, "let_declarations_can_only_be_declared_inside_a_block_1157", "'let' declarations can only be declared inside a block."),
                    Unterminated_template_literal: diag(1160, 1 /* Error */, "Unterminated_template_literal_1160", "Unterminated template literal."),
                    Unterminated_regular_expression_literal: diag(1161, 1 /* Error */, "Unterminated_regular_expression_literal_1161", "Unterminated regular expression literal."),
                    An_object_member_cannot_be_declared_optional: diag(1162, 1 /* Error */, "An_object_member_cannot_be_declared_optional_1162", "An object member cannot be declared optional."),
                    A_yield_expression_is_only_allowed_in_a_generator_body: diag(1163, 1 /* Error */, "A_yield_expression_is_only_allowed_in_a_generator_body_1163", "A 'yield' expression is only allowed in a generator body."),
                    Computed_property_names_are_not_allowed_in_enums: diag(1164, 1 /* Error */, "Computed_property_names_are_not_allowed_in_enums_1164", "Computed property names are not allowed in enums."),
                    A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: diag(1165, 1 /* Error */, "A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_t_1165", "A computed property name in an ambient context must refer to an expression whose type is a literal type or a 'unique symbol' type."),
                    A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_symbol_type: diag(1166, 1 /* Error */, "A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_1166", "A computed property name in a class property declaration must have a simple literal type or a 'unique symbol' type."),
                    A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: diag(1168, 1 /* Error */, "A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_ty_1168", "A computed property name in a method overload must refer to an expression whose type is a literal type or a 'unique symbol' type."),
                    A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: diag(1169, 1 /* Error */, "A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_1169", "A computed property name in an interface must refer to an expression whose type is a literal type or a 'unique symbol' type."),
                    A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: diag(1170, 1 /* Error */, "A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type__1170", "A computed property name in a type literal must refer to an expression whose type is a literal type or a 'unique symbol' type."),
                    A_comma_expression_is_not_allowed_in_a_computed_property_name: diag(1171, 1 /* Error */, "A_comma_expression_is_not_allowed_in_a_computed_property_name_1171", "A comma expression is not allowed in a computed property name."),
                    extends_clause_already_seen: diag(1172, 1 /* Error */, "extends_clause_already_seen_1172", "'extends' clause already seen."),
                    extends_clause_must_precede_implements_clause: diag(1173, 1 /* Error */, "extends_clause_must_precede_implements_clause_1173", "'extends' clause must precede 'implements' clause."),
                    Classes_can_only_extend_a_single_class: diag(1174, 1 /* Error */, "Classes_can_only_extend_a_single_class_1174", "Classes can only extend a single class."),
                    implements_clause_already_seen: diag(1175, 1 /* Error */, "implements_clause_already_seen_1175", "'implements' clause already seen."),
                    Interface_declaration_cannot_have_implements_clause: diag(1176, 1 /* Error */, "Interface_declaration_cannot_have_implements_clause_1176", "Interface declaration cannot have 'implements' clause."),
                    Binary_digit_expected: diag(1177, 1 /* Error */, "Binary_digit_expected_1177", "Binary digit expected."),
                    Octal_digit_expected: diag(1178, 1 /* Error */, "Octal_digit_expected_1178", "Octal digit expected."),
                    Unexpected_token_expected: diag(1179, 1 /* Error */, "Unexpected_token_expected_1179", "Unexpected token. '{' expected."),
                    Property_destructuring_pattern_expected: diag(1180, 1 /* Error */, "Property_destructuring_pattern_expected_1180", "Property destructuring pattern expected."),
                    Array_element_destructuring_pattern_expected: diag(1181, 1 /* Error */, "Array_element_destructuring_pattern_expected_1181", "Array element destructuring pattern expected."),
                    A_destructuring_declaration_must_have_an_initializer: diag(1182, 1 /* Error */, "A_destructuring_declaration_must_have_an_initializer_1182", "A destructuring declaration must have an initializer."),
                    An_implementation_cannot_be_declared_in_ambient_contexts: diag(1183, 1 /* Error */, "An_implementation_cannot_be_declared_in_ambient_contexts_1183", "An implementation cannot be declared in ambient contexts."),
                    Modifiers_cannot_appear_here: diag(1184, 1 /* Error */, "Modifiers_cannot_appear_here_1184", "Modifiers cannot appear here."),
                    Merge_conflict_marker_encountered: diag(1185, 1 /* Error */, "Merge_conflict_marker_encountered_1185", "Merge conflict marker encountered."),
                    A_rest_element_cannot_have_an_initializer: diag(1186, 1 /* Error */, "A_rest_element_cannot_have_an_initializer_1186", "A rest element cannot have an initializer."),
                    A_parameter_property_may_not_be_declared_using_a_binding_pattern: diag(1187, 1 /* Error */, "A_parameter_property_may_not_be_declared_using_a_binding_pattern_1187", "A parameter property may not be declared using a binding pattern."),
                    Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement: diag(1188, 1 /* Error */, "Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement_1188", "Only a single variable declaration is allowed in a 'for...of' statement."),
                    The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer: diag(1189, 1 /* Error */, "The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer_1189", "The variable declaration of a 'for...in' statement cannot have an initializer."),
                    The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer: diag(1190, 1 /* Error */, "The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer_1190", "The variable declaration of a 'for...of' statement cannot have an initializer."),
                    An_import_declaration_cannot_have_modifiers: diag(1191, 1 /* Error */, "An_import_declaration_cannot_have_modifiers_1191", "An import declaration cannot have modifiers."),
                    Module_0_has_no_default_export: diag(1192, 1 /* Error */, "Module_0_has_no_default_export_1192", "Module '{0}' has no default export."),
                    An_export_declaration_cannot_have_modifiers: diag(1193, 1 /* Error */, "An_export_declaration_cannot_have_modifiers_1193", "An export declaration cannot have modifiers."),
                    Export_declarations_are_not_permitted_in_a_namespace: diag(1194, 1 /* Error */, "Export_declarations_are_not_permitted_in_a_namespace_1194", "Export declarations are not permitted in a namespace."),
                    export_Asterisk_does_not_re_export_a_default: diag(1195, 1 /* Error */, "export_Asterisk_does_not_re_export_a_default_1195", "'export *' does not re-export a default."),
                    Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified: diag(1196, 1 /* Error */, "Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified_1196", "Catch clause variable type annotation must be 'any' or 'unknown' if specified."),
                    Catch_clause_variable_cannot_have_an_initializer: diag(1197, 1 /* Error */, "Catch_clause_variable_cannot_have_an_initializer_1197", "Catch clause variable cannot have an initializer."),
                    An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive: diag(1198, 1 /* Error */, "An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive_1198", "An extended Unicode escape value must be between 0x0 and 0x10FFFF inclusive."),
                    Unterminated_Unicode_escape_sequence: diag(1199, 1 /* Error */, "Unterminated_Unicode_escape_sequence_1199", "Unterminated Unicode escape sequence."),
                    Line_terminator_not_permitted_before_arrow: diag(1200, 1 /* Error */, "Line_terminator_not_permitted_before_arrow_1200", "Line terminator not permitted before arrow."),
                    Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead: diag(1202, 1 /* Error */, "Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_1202", `Import assignment cannot be used when targeting ECMAScript modules. Consider using 'import * as ns from "mod"', 'import {a} from "mod"', 'import d from "mod"', or another module format instead.`),
                    Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or_another_module_format_instead: diag(1203, 1 /* Error */, "Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or__1203", "Export assignment cannot be used when targeting ECMAScript modules. Consider using 'export default' or another module format instead."),
                    Re_exporting_a_type_when_0_is_enabled_requires_using_export_type: diag(1205, 1 /* Error */, "Re_exporting_a_type_when_0_is_enabled_requires_using_export_type_1205", "Re-exporting a type when '{0}' is enabled requires using 'export type'."),
                    Decorators_are_not_valid_here: diag(1206, 1 /* Error */, "Decorators_are_not_valid_here_1206", "Decorators are not valid here."),
                    Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name: diag(1207, 1 /* Error */, "Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name_1207", "Decorators cannot be applied to multiple get/set accessors of the same name."),
                    Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0: diag(1209, 1 /* Error */, "Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0_1209", "Invalid optional chain from new expression. Did you mean to call '{0}()'?"),
                    Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of_0_For_more_information_see_https_Colon_Slash_Slashdeveloper_mozilla_org_Slashen_US_Slashdocs_SlashWeb_SlashJavaScript_SlashReference_SlashStrict_mode: diag(1210, 1 /* Error */, "Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of__1210", "Code contained in a class is evaluated in JavaScript's strict mode which does not allow this use of '{0}'. For more information, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Strict_mode."),
                    A_class_declaration_without_the_default_modifier_must_have_a_name: diag(1211, 1 /* Error */, "A_class_declaration_without_the_default_modifier_must_have_a_name_1211", "A class declaration without the 'default' modifier must have a name."),
                    Identifier_expected_0_is_a_reserved_word_in_strict_mode: diag(1212, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_1212", "Identifier expected. '{0}' is a reserved word in strict mode."),
                    Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode: diag(1213, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_stric_1213", "Identifier expected. '{0}' is a reserved word in strict mode. Class definitions are automatically in strict mode."),
                    Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode: diag(1214, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode_1214", "Identifier expected. '{0}' is a reserved word in strict mode. Modules are automatically in strict mode."),
                    Invalid_use_of_0_Modules_are_automatically_in_strict_mode: diag(1215, 1 /* Error */, "Invalid_use_of_0_Modules_are_automatically_in_strict_mode_1215", "Invalid use of '{0}'. Modules are automatically in strict mode."),
                    Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules: diag(1216, 1 /* Error */, "Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules_1216", "Identifier expected. '__esModule' is reserved as an exported marker when transforming ECMAScript modules."),
                    Export_assignment_is_not_supported_when_module_flag_is_system: diag(1218, 1 /* Error */, "Export_assignment_is_not_supported_when_module_flag_is_system_1218", "Export assignment is not supported when '--module' flag is 'system'."),
                    Generators_are_not_allowed_in_an_ambient_context: diag(1221, 1 /* Error */, "Generators_are_not_allowed_in_an_ambient_context_1221", "Generators are not allowed in an ambient context."),
                    An_overload_signature_cannot_be_declared_as_a_generator: diag(1222, 1 /* Error */, "An_overload_signature_cannot_be_declared_as_a_generator_1222", "An overload signature cannot be declared as a generator."),
                    _0_tag_already_specified: diag(1223, 1 /* Error */, "_0_tag_already_specified_1223", "'{0}' tag already specified."),
                    Signature_0_must_be_a_type_predicate: diag(1224, 1 /* Error */, "Signature_0_must_be_a_type_predicate_1224", "Signature '{0}' must be a type predicate."),
                    Cannot_find_parameter_0: diag(1225, 1 /* Error */, "Cannot_find_parameter_0_1225", "Cannot find parameter '{0}'."),
                    Type_predicate_0_is_not_assignable_to_1: diag(1226, 1 /* Error */, "Type_predicate_0_is_not_assignable_to_1_1226", "Type predicate '{0}' is not assignable to '{1}'."),
                    Parameter_0_is_not_in_the_same_position_as_parameter_1: diag(1227, 1 /* Error */, "Parameter_0_is_not_in_the_same_position_as_parameter_1_1227", "Parameter '{0}' is not in the same position as parameter '{1}'."),
                    A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods: diag(1228, 1 /* Error */, "A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods_1228", "A type predicate is only allowed in return type position for functions and methods."),
                    A_type_predicate_cannot_reference_a_rest_parameter: diag(1229, 1 /* Error */, "A_type_predicate_cannot_reference_a_rest_parameter_1229", "A type predicate cannot reference a rest parameter."),
                    A_type_predicate_cannot_reference_element_0_in_a_binding_pattern: diag(1230, 1 /* Error */, "A_type_predicate_cannot_reference_element_0_in_a_binding_pattern_1230", "A type predicate cannot reference element '{0}' in a binding pattern."),
                    An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration: diag(1231, 1 /* Error */, "An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration_1231", "An export assignment must be at the top level of a file or module declaration."),
                    An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module: diag(1232, 1 /* Error */, "An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module_1232", "An import declaration can only be used at the top level of a namespace or module."),
                    An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module: diag(1233, 1 /* Error */, "An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module_1233", "An export declaration can only be used at the top level of a namespace or module."),
                    An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file: diag(1234, 1 /* Error */, "An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file_1234", "An ambient module declaration is only allowed at the top level in a file."),
                    A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module: diag(1235, 1 /* Error */, "A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module_1235", "A namespace declaration is only allowed at the top level of a namespace or module."),
                    The_return_type_of_a_property_decorator_function_must_be_either_void_or_any: diag(1236, 1 /* Error */, "The_return_type_of_a_property_decorator_function_must_be_either_void_or_any_1236", "The return type of a property decorator function must be either 'void' or 'any'."),
                    The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any: diag(1237, 1 /* Error */, "The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any_1237", "The return type of a parameter decorator function must be either 'void' or 'any'."),
                    Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression: diag(1238, 1 /* Error */, "Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression_1238", "Unable to resolve signature of class decorator when called as an expression."),
                    Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression: diag(1239, 1 /* Error */, "Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression_1239", "Unable to resolve signature of parameter decorator when called as an expression."),
                    Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression: diag(1240, 1 /* Error */, "Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression_1240", "Unable to resolve signature of property decorator when called as an expression."),
                    Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression: diag(1241, 1 /* Error */, "Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression_1241", "Unable to resolve signature of method decorator when called as an expression."),
                    abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration: diag(1242, 1 /* Error */, "abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration_1242", "'abstract' modifier can only appear on a class, method, or property declaration."),
                    _0_modifier_cannot_be_used_with_1_modifier: diag(1243, 1 /* Error */, "_0_modifier_cannot_be_used_with_1_modifier_1243", "'{0}' modifier cannot be used with '{1}' modifier."),
                    Abstract_methods_can_only_appear_within_an_abstract_class: diag(1244, 1 /* Error */, "Abstract_methods_can_only_appear_within_an_abstract_class_1244", "Abstract methods can only appear within an abstract class."),
                    Method_0_cannot_have_an_implementation_because_it_is_marked_abstract: diag(1245, 1 /* Error */, "Method_0_cannot_have_an_implementation_because_it_is_marked_abstract_1245", "Method '{0}' cannot have an implementation because it is marked abstract."),
                    An_interface_property_cannot_have_an_initializer: diag(1246, 1 /* Error */, "An_interface_property_cannot_have_an_initializer_1246", "An interface property cannot have an initializer."),
                    A_type_literal_property_cannot_have_an_initializer: diag(1247, 1 /* Error */, "A_type_literal_property_cannot_have_an_initializer_1247", "A type literal property cannot have an initializer."),
                    A_class_member_cannot_have_the_0_keyword: diag(1248, 1 /* Error */, "A_class_member_cannot_have_the_0_keyword_1248", "A class member cannot have the '{0}' keyword."),
                    A_decorator_can_only_decorate_a_method_implementation_not_an_overload: diag(1249, 1 /* Error */, "A_decorator_can_only_decorate_a_method_implementation_not_an_overload_1249", "A decorator can only decorate a method implementation, not an overload."),
                    Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5: diag(1250, 1 /* Error */, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_1250", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'."),
                    Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_definitions_are_automatically_in_strict_mode: diag(1251, 1 /* Error */, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_d_1251", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'. Class definitions are automatically in strict mode."),
                    Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_are_automatically_in_strict_mode: diag(1252, 1 /* Error */, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_1252", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'. Modules are automatically in strict mode."),
                    A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_reference: diag(1254, 1 /* Error */, "A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_refere_1254", "A 'const' initializer in an ambient context must be a string or numeric literal or literal enum reference."),
                    A_definite_assignment_assertion_is_not_permitted_in_this_context: diag(1255, 1 /* Error */, "A_definite_assignment_assertion_is_not_permitted_in_this_context_1255", "A definite assignment assertion '!' is not permitted in this context."),
                    A_required_element_cannot_follow_an_optional_element: diag(1257, 1 /* Error */, "A_required_element_cannot_follow_an_optional_element_1257", "A required element cannot follow an optional element."),
                    A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration: diag(1258, 1 /* Error */, "A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration_1258", "A default export must be at the top level of a file or module declaration."),
                    Module_0_can_only_be_default_imported_using_the_1_flag: diag(1259, 1 /* Error */, "Module_0_can_only_be_default_imported_using_the_1_flag_1259", "Module '{0}' can only be default-imported using the '{1}' flag"),
                    Keywords_cannot_contain_escape_characters: diag(1260, 1 /* Error */, "Keywords_cannot_contain_escape_characters_1260", "Keywords cannot contain escape characters."),
                    Already_included_file_name_0_differs_from_file_name_1_only_in_casing: diag(1261, 1 /* Error */, "Already_included_file_name_0_differs_from_file_name_1_only_in_casing_1261", "Already included file name '{0}' differs from file name '{1}' only in casing."),
                    Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module: diag(1262, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module_1262", "Identifier expected. '{0}' is a reserved word at the top-level of a module."),
                    Declarations_with_initializers_cannot_also_have_definite_assignment_assertions: diag(1263, 1 /* Error */, "Declarations_with_initializers_cannot_also_have_definite_assignment_assertions_1263", "Declarations with initializers cannot also have definite assignment assertions."),
                    Declarations_with_definite_assignment_assertions_must_also_have_type_annotations: diag(1264, 1 /* Error */, "Declarations_with_definite_assignment_assertions_must_also_have_type_annotations_1264", "Declarations with definite assignment assertions must also have type annotations."),
                    A_rest_element_cannot_follow_another_rest_element: diag(1265, 1 /* Error */, "A_rest_element_cannot_follow_another_rest_element_1265", "A rest element cannot follow another rest element."),
                    An_optional_element_cannot_follow_a_rest_element: diag(1266, 1 /* Error */, "An_optional_element_cannot_follow_a_rest_element_1266", "An optional element cannot follow a rest element."),
                    Property_0_cannot_have_an_initializer_because_it_is_marked_abstract: diag(1267, 1 /* Error */, "Property_0_cannot_have_an_initializer_because_it_is_marked_abstract_1267", "Property '{0}' cannot have an initializer because it is marked abstract."),
                    An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type: diag(1268, 1 /* Error */, "An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type_1268", "An index signature parameter type must be 'string', 'number', 'symbol', or a template literal type."),
                    Cannot_use_export_import_on_a_type_or_type_only_namespace_when_0_is_enabled: diag(1269, 1 /* Error */, "Cannot_use_export_import_on_a_type_or_type_only_namespace_when_0_is_enabled_1269", "Cannot use 'export import' on a type or type-only namespace when '{0}' is enabled."),
                    Decorator_function_return_type_0_is_not_assignable_to_type_1: diag(1270, 1 /* Error */, "Decorator_function_return_type_0_is_not_assignable_to_type_1_1270", "Decorator function return type '{0}' is not assignable to type '{1}'."),
                    Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any: diag(1271, 1 /* Error */, "Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any_1271", "Decorator function return type is '{0}' but is expected to be 'void' or 'any'."),
                    A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_when_isolatedModules_and_emitDecoratorMetadata_are_enabled: diag(1272, 1 /* Error */, "A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_w_1272", "A type referenced in a decorated signature must be imported with 'import type' or a namespace import when 'isolatedModules' and 'emitDecoratorMetadata' are enabled."),
                    _0_modifier_cannot_appear_on_a_type_parameter: diag(1273, 1 /* Error */, "_0_modifier_cannot_appear_on_a_type_parameter_1273", "'{0}' modifier cannot appear on a type parameter"),
                    _0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias: diag(1274, 1 /* Error */, "_0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias_1274", "'{0}' modifier can only appear on a type parameter of a class, interface or type alias"),
                    accessor_modifier_can_only_appear_on_a_property_declaration: diag(1275, 1 /* Error */, "accessor_modifier_can_only_appear_on_a_property_declaration_1275", "'accessor' modifier can only appear on a property declaration."),
                    An_accessor_property_cannot_be_declared_optional: diag(1276, 1 /* Error */, "An_accessor_property_cannot_be_declared_optional_1276", "An 'accessor' property cannot be declared optional."),
                    _0_modifier_can_only_appear_on_a_type_parameter_of_a_function_method_or_class: diag(1277, 1 /* Error */, "_0_modifier_can_only_appear_on_a_type_parameter_of_a_function_method_or_class_1277", "'{0}' modifier can only appear on a type parameter of a function, method or class"),
                    The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_0: diag(1278, 1 /* Error */, "The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_0_1278", "The runtime will invoke the decorator with {1} arguments, but the decorator expects {0}."),
                    The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_at_least_0: diag(1279, 1 /* Error */, "The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_at_least_0_1279", "The runtime will invoke the decorator with {1} arguments, but the decorator expects at least {0}."),
                    Namespaces_are_not_allowed_in_global_script_files_when_0_is_enabled_If_this_file_is_not_intended_to_be_a_global_script_set_moduleDetection_to_force_or_add_an_empty_export_statement: diag(1280, 1 /* Error */, "Namespaces_are_not_allowed_in_global_script_files_when_0_is_enabled_If_this_file_is_not_intended_to__1280", "Namespaces are not allowed in global script files when '{0}' is enabled. If this file is not intended to be a global script, set 'moduleDetection' to 'force' or add an empty 'export {}' statement."),
                    Cannot_access_0_from_another_file_without_qualification_when_1_is_enabled_Use_2_instead: diag(1281, 1 /* Error */, "Cannot_access_0_from_another_file_without_qualification_when_1_is_enabled_Use_2_instead_1281", "Cannot access '{0}' from another file without qualification when '{1}' is enabled. Use '{2}' instead."),
                    An_export_declaration_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type: diag(1282, 1 /* Error */, "An_export_declaration_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers__1282", "An 'export =' declaration must reference a value when 'verbatimModuleSyntax' is enabled, but '{0}' only refers to a type."),
                    An_export_declaration_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration: diag(1283, 1 /* Error */, "An_export_declaration_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolve_1283", "An 'export =' declaration must reference a real value when 'verbatimModuleSyntax' is enabled, but '{0}' resolves to a type-only declaration."),
                    An_export_default_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type: diag(1284, 1 /* Error */, "An_export_default_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_1284", "An 'export default' must reference a value when 'verbatimModuleSyntax' is enabled, but '{0}' only refers to a type."),
                    An_export_default_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration: diag(1285, 1 /* Error */, "An_export_default_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_1285", "An 'export default' must reference a real value when 'verbatimModuleSyntax' is enabled, but '{0}' resolves to a type-only declaration."),
                    ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled: diag(1286, 1 /* Error */, "ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled_1286", "ESM syntax is not allowed in a CommonJS module when 'verbatimModuleSyntax' is enabled."),
                    A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled: diag(1287, 1 /* Error */, "A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimM_1287", "A top-level 'export' modifier cannot be used on value declarations in a CommonJS module when 'verbatimModuleSyntax' is enabled."),
                    An_import_alias_cannot_resolve_to_a_type_or_type_only_declaration_when_verbatimModuleSyntax_is_enabled: diag(1288, 1 /* Error */, "An_import_alias_cannot_resolve_to_a_type_or_type_only_declaration_when_verbatimModuleSyntax_is_enabl_1288", "An import alias cannot resolve to a type or type-only declaration when 'verbatimModuleSyntax' is enabled."),
                    with_statements_are_not_allowed_in_an_async_function_block: diag(1300, 1 /* Error */, "with_statements_are_not_allowed_in_an_async_function_block_1300", "'with' statements are not allowed in an async function block."),
                    await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: diag(1308, 1 /* Error */, "await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1308", "'await' expressions are only allowed within async functions and at the top levels of modules."),
                    The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level: diag(1309, 1 /* Error */, "The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level_1309", "The current file is a CommonJS module and cannot use 'await' at the top level."),
                    Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern: diag(1312, 1 /* Error */, "Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_1312", "Did you mean to use a ':'? An '=' can only follow a property name when the containing object literal is part of a destructuring pattern."),
                    The_body_of_an_if_statement_cannot_be_the_empty_statement: diag(1313, 1 /* Error */, "The_body_of_an_if_statement_cannot_be_the_empty_statement_1313", "The body of an 'if' statement cannot be the empty statement."),
                    Global_module_exports_may_only_appear_in_module_files: diag(1314, 1 /* Error */, "Global_module_exports_may_only_appear_in_module_files_1314", "Global module exports may only appear in module files."),
                    Global_module_exports_may_only_appear_in_declaration_files: diag(1315, 1 /* Error */, "Global_module_exports_may_only_appear_in_declaration_files_1315", "Global module exports may only appear in declaration files."),
                    Global_module_exports_may_only_appear_at_top_level: diag(1316, 1 /* Error */, "Global_module_exports_may_only_appear_at_top_level_1316", "Global module exports may only appear at top level."),
                    A_parameter_property_cannot_be_declared_using_a_rest_parameter: diag(1317, 1 /* Error */, "A_parameter_property_cannot_be_declared_using_a_rest_parameter_1317", "A parameter property cannot be declared using a rest parameter."),
                    An_abstract_accessor_cannot_have_an_implementation: diag(1318, 1 /* Error */, "An_abstract_accessor_cannot_have_an_implementation_1318", "An abstract accessor cannot have an implementation."),
                    A_default_export_can_only_be_used_in_an_ECMAScript_style_module: diag(1319, 1 /* Error */, "A_default_export_can_only_be_used_in_an_ECMAScript_style_module_1319", "A default export can only be used in an ECMAScript-style module."),
                    Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: diag(1320, 1 /* Error */, "Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member_1320", "Type of 'await' operand must either be a valid promise or must not contain a callable 'then' member."),
                    Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: diag(1321, 1 /* Error */, "Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_cal_1321", "Type of 'yield' operand in an async generator must either be a valid promise or must not contain a callable 'then' member."),
                    Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: diag(1322, 1 /* Error */, "Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_con_1322", "Type of iterated elements of a 'yield*' operand must either be a valid promise or must not contain a callable 'then' member."),
                    Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd_system_umd_node16_or_nodenext: diag(1323, 1 /* Error */, "Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd__1323", "Dynamic imports are only supported when the '--module' flag is set to 'es2020', 'es2022', 'esnext', 'commonjs', 'amd', 'system', 'umd', 'node16', or 'nodenext'."),
                    Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_or_nodenext: diag(1324, 1 /* Error */, "Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_or_nod_1324", "Dynamic imports only support a second argument when the '--module' option is set to 'esnext', 'node16', or 'nodenext'."),
                    Argument_of_dynamic_import_cannot_be_spread_element: diag(1325, 1 /* Error */, "Argument_of_dynamic_import_cannot_be_spread_element_1325", "Argument of dynamic import cannot be spread element."),
                    This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot_have_type_arguments: diag(1326, 1 /* Error */, "This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot__1326", "This use of 'import' is invalid. 'import()' calls can be written, but they must have parentheses and cannot have type arguments."),
                    String_literal_with_double_quotes_expected: diag(1327, 1 /* Error */, "String_literal_with_double_quotes_expected_1327", "String literal with double quotes expected."),
                    Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_literal: diag(1328, 1 /* Error */, "Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_li_1328", "Property value can only be string literal, numeric literal, 'true', 'false', 'null', object literal or array literal."),
                    _0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0: diag(1329, 1 /* Error */, "_0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write__1329", "'{0}' accepts too few arguments to be used as a decorator here. Did you mean to call it first and write '@{0}()'?"),
                    A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly: diag(1330, 1 /* Error */, "A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly_1330", "A property of an interface or type literal whose type is a 'unique symbol' type must be 'readonly'."),
                    A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly: diag(1331, 1 /* Error */, "A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly_1331", "A property of a class whose type is a 'unique symbol' type must be both 'static' and 'readonly'."),
                    A_variable_whose_type_is_a_unique_symbol_type_must_be_const: diag(1332, 1 /* Error */, "A_variable_whose_type_is_a_unique_symbol_type_must_be_const_1332", "A variable whose type is a 'unique symbol' type must be 'const'."),
                    unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name: diag(1333, 1 /* Error */, "unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name_1333", "'unique symbol' types may not be used on a variable declaration with a binding name."),
                    unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement: diag(1334, 1 /* Error */, "unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement_1334", "'unique symbol' types are only allowed on variables in a variable statement."),
                    unique_symbol_types_are_not_allowed_here: diag(1335, 1 /* Error */, "unique_symbol_types_are_not_allowed_here_1335", "'unique symbol' types are not allowed here."),
                    An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_object_type_instead: diag(1337, 1 /* Error */, "An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_o_1337", "An index signature parameter type cannot be a literal type or generic type. Consider using a mapped object type instead."),
                    infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type: diag(1338, 1 /* Error */, "infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type_1338", "'infer' declarations are only permitted in the 'extends' clause of a conditional type."),
                    Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here: diag(1339, 1 /* Error */, "Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here_1339", "Module '{0}' does not refer to a value, but is used as a value here."),
                    Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0: diag(1340, 1 /* Error */, "Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0_1340", "Module '{0}' does not refer to a type, but is used as a type here. Did you mean 'typeof import('{0}')'?"),
                    Class_constructor_may_not_be_an_accessor: diag(1341, 1 /* Error */, "Class_constructor_may_not_be_an_accessor_1341", "Class constructor may not be an accessor."),
                    The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system_node16_or_nodenext: diag(1343, 1 /* Error */, "The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system__1343", "The 'import.meta' meta-property is only allowed when the '--module' option is 'es2020', 'es2022', 'esnext', 'system', 'node16', or 'nodenext'."),
                    A_label_is_not_allowed_here: diag(1344, 1 /* Error */, "A_label_is_not_allowed_here_1344", "'A label is not allowed here."),
                    An_expression_of_type_void_cannot_be_tested_for_truthiness: diag(1345, 1 /* Error */, "An_expression_of_type_void_cannot_be_tested_for_truthiness_1345", "An expression of type 'void' cannot be tested for truthiness."),
                    This_parameter_is_not_allowed_with_use_strict_directive: diag(1346, 1 /* Error */, "This_parameter_is_not_allowed_with_use_strict_directive_1346", "This parameter is not allowed with 'use strict' directive."),
                    use_strict_directive_cannot_be_used_with_non_simple_parameter_list: diag(1347, 1 /* Error */, "use_strict_directive_cannot_be_used_with_non_simple_parameter_list_1347", "'use strict' directive cannot be used with non-simple parameter list."),
                    Non_simple_parameter_declared_here: diag(1348, 1 /* Error */, "Non_simple_parameter_declared_here_1348", "Non-simple parameter declared here."),
                    use_strict_directive_used_here: diag(1349, 1 /* Error */, "use_strict_directive_used_here_1349", "'use strict' directive used here."),
                    Print_the_final_configuration_instead_of_building: diag(1350, 3 /* Message */, "Print_the_final_configuration_instead_of_building_1350", "Print the final configuration instead of building."),
                    An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal: diag(1351, 1 /* Error */, "An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal_1351", "An identifier or keyword cannot immediately follow a numeric literal."),
                    A_bigint_literal_cannot_use_exponential_notation: diag(1352, 1 /* Error */, "A_bigint_literal_cannot_use_exponential_notation_1352", "A bigint literal cannot use exponential notation."),
                    A_bigint_literal_must_be_an_integer: diag(1353, 1 /* Error */, "A_bigint_literal_must_be_an_integer_1353", "A bigint literal must be an integer."),
                    readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types: diag(1354, 1 /* Error */, "readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types_1354", "'readonly' type modifier is only permitted on array and tuple literal types."),
                    A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array_or_object_literals: diag(1355, 1 /* Error */, "A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array__1355", "A 'const' assertions can only be applied to references to enum members, or string, number, boolean, array, or object literals."),
                    Did_you_mean_to_mark_this_function_as_async: diag(1356, 1 /* Error */, "Did_you_mean_to_mark_this_function_as_async_1356", "Did you mean to mark this function as 'async'?"),
                    An_enum_member_name_must_be_followed_by_a_or: diag(1357, 1 /* Error */, "An_enum_member_name_must_be_followed_by_a_or_1357", "An enum member name must be followed by a ',', '=', or '}'."),
                    Tagged_template_expressions_are_not_permitted_in_an_optional_chain: diag(1358, 1 /* Error */, "Tagged_template_expressions_are_not_permitted_in_an_optional_chain_1358", "Tagged template expressions are not permitted in an optional chain."),
                    Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here: diag(1359, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here_1359", "Identifier expected. '{0}' is a reserved word that cannot be used here."),
                    Type_0_does_not_satisfy_the_expected_type_1: diag(1360, 1 /* Error */, "Type_0_does_not_satisfy_the_expected_type_1_1360", "Type '{0}' does not satisfy the expected type '{1}'."),
                    _0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type: diag(1361, 1 /* Error */, "_0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type_1361", "'{0}' cannot be used as a value because it was imported using 'import type'."),
                    _0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type: diag(1362, 1 /* Error */, "_0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type_1362", "'{0}' cannot be used as a value because it was exported using 'export type'."),
                    A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both: diag(1363, 1 /* Error */, "A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both_1363", "A type-only import can specify a default import or named bindings, but not both."),
                    Convert_to_type_only_export: diag(1364, 3 /* Message */, "Convert_to_type_only_export_1364", "Convert to type-only export"),
                    Convert_all_re_exported_types_to_type_only_exports: diag(1365, 3 /* Message */, "Convert_all_re_exported_types_to_type_only_exports_1365", "Convert all re-exported types to type-only exports"),
                    Split_into_two_separate_import_declarations: diag(1366, 3 /* Message */, "Split_into_two_separate_import_declarations_1366", "Split into two separate import declarations"),
                    Split_all_invalid_type_only_imports: diag(1367, 3 /* Message */, "Split_all_invalid_type_only_imports_1367", "Split all invalid type-only imports"),
                    Class_constructor_may_not_be_a_generator: diag(1368, 1 /* Error */, "Class_constructor_may_not_be_a_generator_1368", "Class constructor may not be a generator."),
                    Did_you_mean_0: diag(1369, 3 /* Message */, "Did_you_mean_0_1369", "Did you mean '{0}'?"),
                    This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error: diag(1371, 1 /* Error */, "This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set__1371", "This import is never used as a value and must use 'import type' because 'importsNotUsedAsValues' is set to 'error'."),
                    Convert_to_type_only_import: diag(1373, 3 /* Message */, "Convert_to_type_only_import_1373", "Convert to type-only import"),
                    Convert_all_imports_not_used_as_a_value_to_type_only_imports: diag(1374, 3 /* Message */, "Convert_all_imports_not_used_as_a_value_to_type_only_imports_1374", "Convert all imports not used as a value to type-only imports"),
                    await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: diag(1375, 1 /* Error */, "await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_fi_1375", "'await' expressions are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),
                    _0_was_imported_here: diag(1376, 3 /* Message */, "_0_was_imported_here_1376", "'{0}' was imported here."),
                    _0_was_exported_here: diag(1377, 3 /* Message */, "_0_was_exported_here_1377", "'{0}' was exported here."),
                    Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_or_nodenext_and_the_target_option_is_set_to_es2017_or_higher: diag(1378, 1 /* Error */, "Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_n_1378", "Top-level 'await' expressions are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', or 'nodenext', and the 'target' option is set to 'es2017' or higher."),
                    An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type: diag(1379, 1 /* Error */, "An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type_1379", "An import alias cannot reference a declaration that was exported using 'export type'."),
                    An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type: diag(1380, 1 /* Error */, "An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type_1380", "An import alias cannot reference a declaration that was imported using 'import type'."),
                    Unexpected_token_Did_you_mean_or_rbrace: diag(1381, 1 /* Error */, "Unexpected_token_Did_you_mean_or_rbrace_1381", "Unexpected token. Did you mean `{'}'}` or `&rbrace;`?"),
                    Unexpected_token_Did_you_mean_or_gt: diag(1382, 1 /* Error */, "Unexpected_token_Did_you_mean_or_gt_1382", "Unexpected token. Did you mean `{'>'}` or `&gt;`?"),
                    Function_type_notation_must_be_parenthesized_when_used_in_a_union_type: diag(1385, 1 /* Error */, "Function_type_notation_must_be_parenthesized_when_used_in_a_union_type_1385", "Function type notation must be parenthesized when used in a union type."),
                    Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type: diag(1386, 1 /* Error */, "Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type_1386", "Constructor type notation must be parenthesized when used in a union type."),
                    Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type: diag(1387, 1 /* Error */, "Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1387", "Function type notation must be parenthesized when used in an intersection type."),
                    Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type: diag(1388, 1 /* Error */, "Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1388", "Constructor type notation must be parenthesized when used in an intersection type."),
                    _0_is_not_allowed_as_a_variable_declaration_name: diag(1389, 1 /* Error */, "_0_is_not_allowed_as_a_variable_declaration_name_1389", "'{0}' is not allowed as a variable declaration name."),
                    _0_is_not_allowed_as_a_parameter_name: diag(1390, 1 /* Error */, "_0_is_not_allowed_as_a_parameter_name_1390", "'{0}' is not allowed as a parameter name."),
                    An_import_alias_cannot_use_import_type: diag(1392, 1 /* Error */, "An_import_alias_cannot_use_import_type_1392", "An import alias cannot use 'import type'"),
                    Imported_via_0_from_file_1: diag(1393, 3 /* Message */, "Imported_via_0_from_file_1_1393", "Imported via {0} from file '{1}'"),
                    Imported_via_0_from_file_1_with_packageId_2: diag(1394, 3 /* Message */, "Imported_via_0_from_file_1_with_packageId_2_1394", "Imported via {0} from file '{1}' with packageId '{2}'"),
                    Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions: diag(1395, 3 /* Message */, "Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions_1395", "Imported via {0} from file '{1}' to import 'importHelpers' as specified in compilerOptions"),
                    Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions: diag(1396, 3 /* Message */, "Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions_1396", "Imported via {0} from file '{1}' with packageId '{2}' to import 'importHelpers' as specified in compilerOptions"),
                    Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions: diag(1397, 3 /* Message */, "Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions_1397", "Imported via {0} from file '{1}' to import 'jsx' and 'jsxs' factory functions"),
                    Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions: diag(1398, 3 /* Message */, "Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions_1398", "Imported via {0} from file '{1}' with packageId '{2}' to import 'jsx' and 'jsxs' factory functions"),
                    File_is_included_via_import_here: diag(1399, 3 /* Message */, "File_is_included_via_import_here_1399", "File is included via import here."),
                    Referenced_via_0_from_file_1: diag(1400, 3 /* Message */, "Referenced_via_0_from_file_1_1400", "Referenced via '{0}' from file '{1}'"),
                    File_is_included_via_reference_here: diag(1401, 3 /* Message */, "File_is_included_via_reference_here_1401", "File is included via reference here."),
                    Type_library_referenced_via_0_from_file_1: diag(1402, 3 /* Message */, "Type_library_referenced_via_0_from_file_1_1402", "Type library referenced via '{0}' from file '{1}'"),
                    Type_library_referenced_via_0_from_file_1_with_packageId_2: diag(1403, 3 /* Message */, "Type_library_referenced_via_0_from_file_1_with_packageId_2_1403", "Type library referenced via '{0}' from file '{1}' with packageId '{2}'"),
                    File_is_included_via_type_library_reference_here: diag(1404, 3 /* Message */, "File_is_included_via_type_library_reference_here_1404", "File is included via type library reference here."),
                    Library_referenced_via_0_from_file_1: diag(1405, 3 /* Message */, "Library_referenced_via_0_from_file_1_1405", "Library referenced via '{0}' from file '{1}'"),
                    File_is_included_via_library_reference_here: diag(1406, 3 /* Message */, "File_is_included_via_library_reference_here_1406", "File is included via library reference here."),
                    Matched_by_include_pattern_0_in_1: diag(1407, 3 /* Message */, "Matched_by_include_pattern_0_in_1_1407", "Matched by include pattern '{0}' in '{1}'"),
                    File_is_matched_by_include_pattern_specified_here: diag(1408, 3 /* Message */, "File_is_matched_by_include_pattern_specified_here_1408", "File is matched by include pattern specified here."),
                    Part_of_files_list_in_tsconfig_json: diag(1409, 3 /* Message */, "Part_of_files_list_in_tsconfig_json_1409", "Part of 'files' list in tsconfig.json"),
                    File_is_matched_by_files_list_specified_here: diag(1410, 3 /* Message */, "File_is_matched_by_files_list_specified_here_1410", "File is matched by 'files' list specified here."),
                    Output_from_referenced_project_0_included_because_1_specified: diag(1411, 3 /* Message */, "Output_from_referenced_project_0_included_because_1_specified_1411", "Output from referenced project '{0}' included because '{1}' specified"),
                    Output_from_referenced_project_0_included_because_module_is_specified_as_none: diag(1412, 3 /* Message */, "Output_from_referenced_project_0_included_because_module_is_specified_as_none_1412", "Output from referenced project '{0}' included because '--module' is specified as 'none'"),
                    File_is_output_from_referenced_project_specified_here: diag(1413, 3 /* Message */, "File_is_output_from_referenced_project_specified_here_1413", "File is output from referenced project specified here."),
                    Source_from_referenced_project_0_included_because_1_specified: diag(1414, 3 /* Message */, "Source_from_referenced_project_0_included_because_1_specified_1414", "Source from referenced project '{0}' included because '{1}' specified"),
                    Source_from_referenced_project_0_included_because_module_is_specified_as_none: diag(1415, 3 /* Message */, "Source_from_referenced_project_0_included_because_module_is_specified_as_none_1415", "Source from referenced project '{0}' included because '--module' is specified as 'none'"),
                    File_is_source_from_referenced_project_specified_here: diag(1416, 3 /* Message */, "File_is_source_from_referenced_project_specified_here_1416", "File is source from referenced project specified here."),
                    Entry_point_of_type_library_0_specified_in_compilerOptions: diag(1417, 3 /* Message */, "Entry_point_of_type_library_0_specified_in_compilerOptions_1417", "Entry point of type library '{0}' specified in compilerOptions"),
                    Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1: diag(1418, 3 /* Message */, "Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1_1418", "Entry point of type library '{0}' specified in compilerOptions with packageId '{1}'"),
                    File_is_entry_point_of_type_library_specified_here: diag(1419, 3 /* Message */, "File_is_entry_point_of_type_library_specified_here_1419", "File is entry point of type library specified here."),
                    Entry_point_for_implicit_type_library_0: diag(1420, 3 /* Message */, "Entry_point_for_implicit_type_library_0_1420", "Entry point for implicit type library '{0}'"),
                    Entry_point_for_implicit_type_library_0_with_packageId_1: diag(1421, 3 /* Message */, "Entry_point_for_implicit_type_library_0_with_packageId_1_1421", "Entry point for implicit type library '{0}' with packageId '{1}'"),
                    Library_0_specified_in_compilerOptions: diag(1422, 3 /* Message */, "Library_0_specified_in_compilerOptions_1422", "Library '{0}' specified in compilerOptions"),
                    File_is_library_specified_here: diag(1423, 3 /* Message */, "File_is_library_specified_here_1423", "File is library specified here."),
                    Default_library: diag(1424, 3 /* Message */, "Default_library_1424", "Default library"),
                    Default_library_for_target_0: diag(1425, 3 /* Message */, "Default_library_for_target_0_1425", "Default library for target '{0}'"),
                    File_is_default_library_for_target_specified_here: diag(1426, 3 /* Message */, "File_is_default_library_for_target_specified_here_1426", "File is default library for target specified here."),
                    Root_file_specified_for_compilation: diag(1427, 3 /* Message */, "Root_file_specified_for_compilation_1427", "Root file specified for compilation"),
                    File_is_output_of_project_reference_source_0: diag(1428, 3 /* Message */, "File_is_output_of_project_reference_source_0_1428", "File is output of project reference source '{0}'"),
                    File_redirects_to_file_0: diag(1429, 3 /* Message */, "File_redirects_to_file_0_1429", "File redirects to file '{0}'"),
                    The_file_is_in_the_program_because_Colon: diag(1430, 3 /* Message */, "The_file_is_in_the_program_because_Colon_1430", "The file is in the program because:"),
                    for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: diag(1431, 1 /* Error */, "for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_1431", "'for await' loops are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),
                    Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_or_nodenext_and_the_target_option_is_set_to_es2017_or_higher: diag(1432, 1 /* Error */, "Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_nod_1432", "Top-level 'for await' loops are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', or 'nodenext', and the 'target' option is set to 'es2017' or higher."),
                    Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters: diag(1433, 1 /* Error */, "Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters_1433", "Neither decorators nor modifiers may be applied to 'this' parameters."),
                    Unexpected_keyword_or_identifier: diag(1434, 1 /* Error */, "Unexpected_keyword_or_identifier_1434", "Unexpected keyword or identifier."),
                    Unknown_keyword_or_identifier_Did_you_mean_0: diag(1435, 1 /* Error */, "Unknown_keyword_or_identifier_Did_you_mean_0_1435", "Unknown keyword or identifier. Did you mean '{0}'?"),
                    Decorators_must_precede_the_name_and_all_keywords_of_property_declarations: diag(1436, 1 /* Error */, "Decorators_must_precede_the_name_and_all_keywords_of_property_declarations_1436", "Decorators must precede the name and all keywords of property declarations."),
                    Namespace_must_be_given_a_name: diag(1437, 1 /* Error */, "Namespace_must_be_given_a_name_1437", "Namespace must be given a name."),
                    Interface_must_be_given_a_name: diag(1438, 1 /* Error */, "Interface_must_be_given_a_name_1438", "Interface must be given a name."),
                    Type_alias_must_be_given_a_name: diag(1439, 1 /* Error */, "Type_alias_must_be_given_a_name_1439", "Type alias must be given a name."),
                    Variable_declaration_not_allowed_at_this_location: diag(1440, 1 /* Error */, "Variable_declaration_not_allowed_at_this_location_1440", "Variable declaration not allowed at this location."),
                    Cannot_start_a_function_call_in_a_type_annotation: diag(1441, 1 /* Error */, "Cannot_start_a_function_call_in_a_type_annotation_1441", "Cannot start a function call in a type annotation."),
                    Expected_for_property_initializer: diag(1442, 1 /* Error */, "Expected_for_property_initializer_1442", "Expected '=' for property initializer."),
                    Module_declaration_names_may_only_use_or_quoted_strings: diag(1443, 1 /* Error */, "Module_declaration_names_may_only_use_or_quoted_strings_1443", `Module declaration names may only use ' or " quoted strings.`),
                    _0_is_a_type_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled: diag(1444, 1 /* Error */, "_0_is_a_type_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedMod_1444", "'{0}' is a type and must be imported using a type-only import when 'preserveValueImports' and 'isolatedModules' are both enabled."),
                    _0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled: diag(1446, 1 /* Error */, "_0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_preserveVa_1446", "'{0}' resolves to a type-only declaration and must be imported using a type-only import when 'preserveValueImports' and 'isolatedModules' are both enabled."),
                    _0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_1_is_enabled: diag(1448, 1 /* Error */, "_0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_1_is_1448", "'{0}' resolves to a type-only declaration and must be re-exported using a type-only re-export when '{1}' is enabled."),
                    Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed: diag(1449, 3 /* Message */, "Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed_1449", "Preserve unused imported values in the JavaScript output that would otherwise be removed."),
                    Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_assertion_as_arguments: diag(1450, 3 /* Message */, "Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_assertion_as_arguments_1450", "Dynamic imports can only accept a module specifier and an optional assertion as arguments"),
                    Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression: diag(1451, 1 /* Error */, "Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member__1451", "Private identifiers are only allowed in class bodies and may only be used as part of a class member declaration, property access, or on the left-hand-side of an 'in' expression"),
                    resolution_mode_assertions_are_only_supported_when_moduleResolution_is_node16_or_nodenext: diag(1452, 1 /* Error */, "resolution_mode_assertions_are_only_supported_when_moduleResolution_is_node16_or_nodenext_1452", "'resolution-mode' assertions are only supported when `moduleResolution` is `node16` or `nodenext`."),
                    resolution_mode_should_be_either_require_or_import: diag(1453, 1 /* Error */, "resolution_mode_should_be_either_require_or_import_1453", "`resolution-mode` should be either `require` or `import`."),
                    resolution_mode_can_only_be_set_for_type_only_imports: diag(1454, 1 /* Error */, "resolution_mode_can_only_be_set_for_type_only_imports_1454", "`resolution-mode` can only be set for type-only imports."),
                    resolution_mode_is_the_only_valid_key_for_type_import_assertions: diag(1455, 1 /* Error */, "resolution_mode_is_the_only_valid_key_for_type_import_assertions_1455", "`resolution-mode` is the only valid key for type import assertions."),
                    Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require: diag(1456, 1 /* Error */, "Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require_1456", "Type import assertions should have exactly one key - `resolution-mode` - with value `import` or `require`."),
                    Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk: diag(1457, 3 /* Message */, "Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk_1457", "Matched by default include pattern '**/*'"),
                    File_is_ECMAScript_module_because_0_has_field_type_with_value_module: diag(1458, 3 /* Message */, "File_is_ECMAScript_module_because_0_has_field_type_with_value_module_1458", `File is ECMAScript module because '{0}' has field "type" with value "module"`),
                    File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module: diag(1459, 3 /* Message */, "File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module_1459", `File is CommonJS module because '{0}' has field "type" whose value is not "module"`),
                    File_is_CommonJS_module_because_0_does_not_have_field_type: diag(1460, 3 /* Message */, "File_is_CommonJS_module_because_0_does_not_have_field_type_1460", `File is CommonJS module because '{0}' does not have field "type"`),
                    File_is_CommonJS_module_because_package_json_was_not_found: diag(1461, 3 /* Message */, "File_is_CommonJS_module_because_package_json_was_not_found_1461", "File is CommonJS module because 'package.json' was not found"),
                    The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output: diag(1470, 1 /* Error */, "The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output_1470", "The 'import.meta' meta-property is not allowed in files which will build into CommonJS output."),
                    Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_cannot_be_imported_with_require_Use_an_ECMAScript_import_instead: diag(1471, 1 /* Error */, "Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_c_1471", "Module '{0}' cannot be imported using this construct. The specifier only resolves to an ES module, which cannot be imported with 'require'. Use an ECMAScript import instead."),
                    catch_or_finally_expected: diag(1472, 1 /* Error */, "catch_or_finally_expected_1472", "'catch' or 'finally' expected."),
                    An_import_declaration_can_only_be_used_at_the_top_level_of_a_module: diag(1473, 1 /* Error */, "An_import_declaration_can_only_be_used_at_the_top_level_of_a_module_1473", "An import declaration can only be used at the top level of a module."),
                    An_export_declaration_can_only_be_used_at_the_top_level_of_a_module: diag(1474, 1 /* Error */, "An_export_declaration_can_only_be_used_at_the_top_level_of_a_module_1474", "An export declaration can only be used at the top level of a module."),
                    Control_what_method_is_used_to_detect_module_format_JS_files: diag(1475, 3 /* Message */, "Control_what_method_is_used_to_detect_module_format_JS_files_1475", "Control what method is used to detect module-format JS files."),
                    auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_with_module_Colon_node16_as_modules: diag(1476, 3 /* Message */, "auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_w_1476", '"auto": Treat files with imports, exports, import.meta, jsx (with jsx: react-jsx), or esm format (with module: node16+) as modules.'),
                    An_instantiation_expression_cannot_be_followed_by_a_property_access: diag(1477, 1 /* Error */, "An_instantiation_expression_cannot_be_followed_by_a_property_access_1477", "An instantiation expression cannot be followed by a property access."),
                    Identifier_or_string_literal_expected: diag(1478, 1 /* Error */, "Identifier_or_string_literal_expected_1478", "Identifier or string literal expected."),
                    The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_referenced_file_is_an_ECMAScript_module_and_cannot_be_imported_with_require_Consider_writing_a_dynamic_import_0_call_instead: diag(1479, 1 /* Error */, "The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_reference_1479", `The current file is a CommonJS module whose imports will produce 'require' calls; however, the referenced file is an ECMAScript module and cannot be imported with 'require'. Consider writing a dynamic 'import("{0}")' call instead.`),
                    To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_package_json_file_with_type_Colon_module: diag(1480, 3 /* Message */, "To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_packag_1480", 'To convert this file to an ECMAScript module, change its file extension to \'{0}\' or create a local package.json file with `{ "type": "module" }`.'),
                    To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Colon_module_to_1: diag(1481, 3 /* Message */, "To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Co_1481", `To convert this file to an ECMAScript module, change its file extension to '{0}', or add the field \`"type": "module"\` to '{1}'.`),
                    To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0: diag(1482, 3 /* Message */, "To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0_1482", 'To convert this file to an ECMAScript module, add the field `"type": "module"` to \'{0}\'.'),
                    To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module: diag(1483, 3 /* Message */, "To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module_1483", 'To convert this file to an ECMAScript module, create a local package.json file with `{ "type": "module" }`.'),
                    _0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled: diag(1484, 1 /* Error */, "_0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled_1484", "'{0}' is a type and must be imported using a type-only import when 'verbatimModuleSyntax' is enabled."),
                    _0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled: diag(1485, 1 /* Error */, "_0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_verbatimMo_1485", "'{0}' resolves to a type-only declaration and must be imported using a type-only import when 'verbatimModuleSyntax' is enabled."),
                    Decorator_used_before_export_here: diag(1486, 1 /* Error */, "Decorator_used_before_export_here_1486", "Decorator used before 'export' here."),
                    The_types_of_0_are_incompatible_between_these_types: diag(2200, 1 /* Error */, "The_types_of_0_are_incompatible_between_these_types_2200", "The types of '{0}' are incompatible between these types."),
                    The_types_returned_by_0_are_incompatible_between_these_types: diag(2201, 1 /* Error */, "The_types_returned_by_0_are_incompatible_between_these_types_2201", "The types returned by '{0}' are incompatible between these types."),
                    Call_signature_return_types_0_and_1_are_incompatible: diag(2202, 1 /* Error */, "Call_signature_return_types_0_and_1_are_incompatible_2202", "Call signature return types '{0}' and '{1}' are incompatible.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    true),
                    Construct_signature_return_types_0_and_1_are_incompatible: diag(2203, 1 /* Error */, "Construct_signature_return_types_0_and_1_are_incompatible_2203", "Construct signature return types '{0}' and '{1}' are incompatible.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    true),
                    Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1: diag(2204, 1 /* Error */, "Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2204", "Call signatures with no arguments have incompatible return types '{0}' and '{1}'.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    true),
                    Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1: diag(2205, 1 /* Error */, "Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2205", "Construct signatures with no arguments have incompatible return types '{0}' and '{1}'.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    true),
                    The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement: diag(2206, 1 /* Error */, "The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement_2206", "The 'type' modifier cannot be used on a named import when 'import type' is used on its import statement."),
                    The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement: diag(2207, 1 /* Error */, "The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement_2207", "The 'type' modifier cannot be used on a named export when 'export type' is used on its export statement."),
                    This_type_parameter_might_need_an_extends_0_constraint: diag(2208, 1 /* Error */, "This_type_parameter_might_need_an_extends_0_constraint_2208", "This type parameter might need an `extends {0}` constraint."),
                    The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate: diag(2209, 1 /* Error */, "The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_roo_2209", "The project root is ambiguous, but is required to resolve export map entry '{0}' in file '{1}'. Supply the `rootDir` compiler option to disambiguate."),
                    The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate: diag(2210, 1 /* Error */, "The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_roo_2210", "The project root is ambiguous, but is required to resolve import map entry '{0}' in file '{1}'. Supply the `rootDir` compiler option to disambiguate."),
                    Add_extends_constraint: diag(2211, 3 /* Message */, "Add_extends_constraint_2211", "Add `extends` constraint."),
                    Add_extends_constraint_to_all_type_parameters: diag(2212, 3 /* Message */, "Add_extends_constraint_to_all_type_parameters_2212", "Add `extends` constraint to all type parameters"),
                    Duplicate_identifier_0: diag(2300, 1 /* Error */, "Duplicate_identifier_0_2300", "Duplicate identifier '{0}'."),
                    Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor: diag(2301, 1 /* Error */, "Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2301", "Initializer of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor."),
                    Static_members_cannot_reference_class_type_parameters: diag(2302, 1 /* Error */, "Static_members_cannot_reference_class_type_parameters_2302", "Static members cannot reference class type parameters."),
                    Circular_definition_of_import_alias_0: diag(2303, 1 /* Error */, "Circular_definition_of_import_alias_0_2303", "Circular definition of import alias '{0}'."),
                    Cannot_find_name_0: diag(2304, 1 /* Error */, "Cannot_find_name_0_2304", "Cannot find name '{0}'."),
                    Module_0_has_no_exported_member_1: diag(2305, 1 /* Error */, "Module_0_has_no_exported_member_1_2305", "Module '{0}' has no exported member '{1}'."),
                    File_0_is_not_a_module: diag(2306, 1 /* Error */, "File_0_is_not_a_module_2306", "File '{0}' is not a module."),
                    Cannot_find_module_0_or_its_corresponding_type_declarations: diag(2307, 1 /* Error */, "Cannot_find_module_0_or_its_corresponding_type_declarations_2307", "Cannot find module '{0}' or its corresponding type declarations."),
                    Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity: diag(2308, 1 /* Error */, "Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambig_2308", "Module {0} has already exported a member named '{1}'. Consider explicitly re-exporting to resolve the ambiguity."),
                    An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements: diag(2309, 1 /* Error */, "An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements_2309", "An export assignment cannot be used in a module with other exported elements."),
                    Type_0_recursively_references_itself_as_a_base_type: diag(2310, 1 /* Error */, "Type_0_recursively_references_itself_as_a_base_type_2310", "Type '{0}' recursively references itself as a base type."),
                    Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function: diag(2311, 1 /* Error */, "Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function_2311", "Cannot find name '{0}'. Did you mean to write this in an async function?"),
                    An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_members: diag(2312, 1 /* Error */, "An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_me_2312", "An interface can only extend an object type or intersection of object types with statically known members."),
                    Type_parameter_0_has_a_circular_constraint: diag(2313, 1 /* Error */, "Type_parameter_0_has_a_circular_constraint_2313", "Type parameter '{0}' has a circular constraint."),
                    Generic_type_0_requires_1_type_argument_s: diag(2314, 1 /* Error */, "Generic_type_0_requires_1_type_argument_s_2314", "Generic type '{0}' requires {1} type argument(s)."),
                    Type_0_is_not_generic: diag(2315, 1 /* Error */, "Type_0_is_not_generic_2315", "Type '{0}' is not generic."),
                    Global_type_0_must_be_a_class_or_interface_type: diag(2316, 1 /* Error */, "Global_type_0_must_be_a_class_or_interface_type_2316", "Global type '{0}' must be a class or interface type."),
                    Global_type_0_must_have_1_type_parameter_s: diag(2317, 1 /* Error */, "Global_type_0_must_have_1_type_parameter_s_2317", "Global type '{0}' must have {1} type parameter(s)."),
                    Cannot_find_global_type_0: diag(2318, 1 /* Error */, "Cannot_find_global_type_0_2318", "Cannot find global type '{0}'."),
                    Named_property_0_of_types_1_and_2_are_not_identical: diag(2319, 1 /* Error */, "Named_property_0_of_types_1_and_2_are_not_identical_2319", "Named property '{0}' of types '{1}' and '{2}' are not identical."),
                    Interface_0_cannot_simultaneously_extend_types_1_and_2: diag(2320, 1 /* Error */, "Interface_0_cannot_simultaneously_extend_types_1_and_2_2320", "Interface '{0}' cannot simultaneously extend types '{1}' and '{2}'."),
                    Excessive_stack_depth_comparing_types_0_and_1: diag(2321, 1 /* Error */, "Excessive_stack_depth_comparing_types_0_and_1_2321", "Excessive stack depth comparing types '{0}' and '{1}'."),
                    Type_0_is_not_assignable_to_type_1: diag(2322, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_2322", "Type '{0}' is not assignable to type '{1}'."),
                    Cannot_redeclare_exported_variable_0: diag(2323, 1 /* Error */, "Cannot_redeclare_exported_variable_0_2323", "Cannot redeclare exported variable '{0}'."),
                    Property_0_is_missing_in_type_1: diag(2324, 1 /* Error */, "Property_0_is_missing_in_type_1_2324", "Property '{0}' is missing in type '{1}'."),
                    Property_0_is_private_in_type_1_but_not_in_type_2: diag(2325, 1 /* Error */, "Property_0_is_private_in_type_1_but_not_in_type_2_2325", "Property '{0}' is private in type '{1}' but not in type '{2}'."),
                    Types_of_property_0_are_incompatible: diag(2326, 1 /* Error */, "Types_of_property_0_are_incompatible_2326", "Types of property '{0}' are incompatible."),
                    Property_0_is_optional_in_type_1_but_required_in_type_2: diag(2327, 1 /* Error */, "Property_0_is_optional_in_type_1_but_required_in_type_2_2327", "Property '{0}' is optional in type '{1}' but required in type '{2}'."),
                    Types_of_parameters_0_and_1_are_incompatible: diag(2328, 1 /* Error */, "Types_of_parameters_0_and_1_are_incompatible_2328", "Types of parameters '{0}' and '{1}' are incompatible."),
                    Index_signature_for_type_0_is_missing_in_type_1: diag(2329, 1 /* Error */, "Index_signature_for_type_0_is_missing_in_type_1_2329", "Index signature for type '{0}' is missing in type '{1}'."),
                    _0_and_1_index_signatures_are_incompatible: diag(2330, 1 /* Error */, "_0_and_1_index_signatures_are_incompatible_2330", "'{0}' and '{1}' index signatures are incompatible."),
                    this_cannot_be_referenced_in_a_module_or_namespace_body: diag(2331, 1 /* Error */, "this_cannot_be_referenced_in_a_module_or_namespace_body_2331", "'this' cannot be referenced in a module or namespace body."),
                    this_cannot_be_referenced_in_current_location: diag(2332, 1 /* Error */, "this_cannot_be_referenced_in_current_location_2332", "'this' cannot be referenced in current location."),
                    this_cannot_be_referenced_in_constructor_arguments: diag(2333, 1 /* Error */, "this_cannot_be_referenced_in_constructor_arguments_2333", "'this' cannot be referenced in constructor arguments."),
                    this_cannot_be_referenced_in_a_static_property_initializer: diag(2334, 1 /* Error */, "this_cannot_be_referenced_in_a_static_property_initializer_2334", "'this' cannot be referenced in a static property initializer."),
                    super_can_only_be_referenced_in_a_derived_class: diag(2335, 1 /* Error */, "super_can_only_be_referenced_in_a_derived_class_2335", "'super' can only be referenced in a derived class."),
                    super_cannot_be_referenced_in_constructor_arguments: diag(2336, 1 /* Error */, "super_cannot_be_referenced_in_constructor_arguments_2336", "'super' cannot be referenced in constructor arguments."),
                    Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors: diag(2337, 1 /* Error */, "Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors_2337", "Super calls are not permitted outside constructors or in nested functions inside constructors."),
                    super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class: diag(2338, 1 /* Error */, "super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_der_2338", "'super' property access is permitted only in a constructor, member function, or member accessor of a derived class."),
                    Property_0_does_not_exist_on_type_1: diag(2339, 1 /* Error */, "Property_0_does_not_exist_on_type_1_2339", "Property '{0}' does not exist on type '{1}'."),
                    Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword: diag(2340, 1 /* Error */, "Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword_2340", "Only public and protected methods of the base class are accessible via the 'super' keyword."),
                    Property_0_is_private_and_only_accessible_within_class_1: diag(2341, 1 /* Error */, "Property_0_is_private_and_only_accessible_within_class_1_2341", "Property '{0}' is private and only accessible within class '{1}'."),
                    This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_version_of_0: diag(2343, 1 /* Error */, "This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_ve_2343", "This syntax requires an imported helper named '{1}' which does not exist in '{0}'. Consider upgrading your version of '{0}'."),
                    Type_0_does_not_satisfy_the_constraint_1: diag(2344, 1 /* Error */, "Type_0_does_not_satisfy_the_constraint_1_2344", "Type '{0}' does not satisfy the constraint '{1}'."),
                    Argument_of_type_0_is_not_assignable_to_parameter_of_type_1: diag(2345, 1 /* Error */, "Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_2345", "Argument of type '{0}' is not assignable to parameter of type '{1}'."),
                    Call_target_does_not_contain_any_signatures: diag(2346, 1 /* Error */, "Call_target_does_not_contain_any_signatures_2346", "Call target does not contain any signatures."),
                    Untyped_function_calls_may_not_accept_type_arguments: diag(2347, 1 /* Error */, "Untyped_function_calls_may_not_accept_type_arguments_2347", "Untyped function calls may not accept type arguments."),
                    Value_of_type_0_is_not_callable_Did_you_mean_to_include_new: diag(2348, 1 /* Error */, "Value_of_type_0_is_not_callable_Did_you_mean_to_include_new_2348", "Value of type '{0}' is not callable. Did you mean to include 'new'?"),
                    This_expression_is_not_callable: diag(2349, 1 /* Error */, "This_expression_is_not_callable_2349", "This expression is not callable."),
                    Only_a_void_function_can_be_called_with_the_new_keyword: diag(2350, 1 /* Error */, "Only_a_void_function_can_be_called_with_the_new_keyword_2350", "Only a void function can be called with the 'new' keyword."),
                    This_expression_is_not_constructable: diag(2351, 1 /* Error */, "This_expression_is_not_constructable_2351", "This expression is not constructable."),
                    Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first: diag(2352, 1 /* Error */, "Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the__2352", "Conversion of type '{0}' to type '{1}' may be a mistake because neither type sufficiently overlaps with the other. If this was intentional, convert the expression to 'unknown' first."),
                    Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1: diag(2353, 1 /* Error */, "Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1_2353", "Object literal may only specify known properties, and '{0}' does not exist in type '{1}'."),
                    This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found: diag(2354, 1 /* Error */, "This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found_2354", "This syntax requires an imported helper but module '{0}' cannot be found."),
                    A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value: diag(2355, 1 /* Error */, "A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value_2355", "A function whose declared type is neither 'void' nor 'any' must return a value."),
                    An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type: diag(2356, 1 /* Error */, "An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type_2356", "An arithmetic operand must be of type 'any', 'number', 'bigint' or an enum type."),
                    The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access: diag(2357, 1 /* Error */, "The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access_2357", "The operand of an increment or decrement operator must be a variable or a property access."),
                    The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter: diag(2358, 1 /* Error */, "The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_paramete_2358", "The left-hand side of an 'instanceof' expression must be of type 'any', an object type or a type parameter."),
                    The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_Function_interface_type: diag(2359, 1 /* Error */, "The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_F_2359", "The right-hand side of an 'instanceof' expression must be of type 'any' or of a type assignable to the 'Function' interface type."),
                    The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type: diag(2362, 1 /* Error */, "The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2362", "The left-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."),
                    The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type: diag(2363, 1 /* Error */, "The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2363", "The right-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."),
                    The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access: diag(2364, 1 /* Error */, "The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access_2364", "The left-hand side of an assignment expression must be a variable or a property access."),
                    Operator_0_cannot_be_applied_to_types_1_and_2: diag(2365, 1 /* Error */, "Operator_0_cannot_be_applied_to_types_1_and_2_2365", "Operator '{0}' cannot be applied to types '{1}' and '{2}'."),
                    Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined: diag(2366, 1 /* Error */, "Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined_2366", "Function lacks ending return statement and return type does not include 'undefined'."),
                    This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap: diag(2367, 1 /* Error */, "This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap_2367", "This comparison appears to be unintentional because the types '{0}' and '{1}' have no overlap."),
                    Type_parameter_name_cannot_be_0: diag(2368, 1 /* Error */, "Type_parameter_name_cannot_be_0_2368", "Type parameter name cannot be '{0}'."),
                    A_parameter_property_is_only_allowed_in_a_constructor_implementation: diag(2369, 1 /* Error */, "A_parameter_property_is_only_allowed_in_a_constructor_implementation_2369", "A parameter property is only allowed in a constructor implementation."),
                    A_rest_parameter_must_be_of_an_array_type: diag(2370, 1 /* Error */, "A_rest_parameter_must_be_of_an_array_type_2370", "A rest parameter must be of an array type."),
                    A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation: diag(2371, 1 /* Error */, "A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation_2371", "A parameter initializer is only allowed in a function or constructor implementation."),
                    Parameter_0_cannot_reference_itself: diag(2372, 1 /* Error */, "Parameter_0_cannot_reference_itself_2372", "Parameter '{0}' cannot reference itself."),
                    Parameter_0_cannot_reference_identifier_1_declared_after_it: diag(2373, 1 /* Error */, "Parameter_0_cannot_reference_identifier_1_declared_after_it_2373", "Parameter '{0}' cannot reference identifier '{1}' declared after it."),
                    Duplicate_index_signature_for_type_0: diag(2374, 1 /* Error */, "Duplicate_index_signature_for_type_0_2374", "Duplicate index signature for type '{0}'."),
                    Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties: diag(2375, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefi_2375", "Type '{0}' is not assignable to type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the types of the target's properties."),
                    A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_class_contains_initialized_properties_parameter_properties_or_private_identifiers: diag(2376, 1 /* Error */, "A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_2376", "A 'super' call must be the first statement in the constructor to refer to 'super' or 'this' when a derived class contains initialized properties, parameter properties, or private identifiers."),
                    Constructors_for_derived_classes_must_contain_a_super_call: diag(2377, 1 /* Error */, "Constructors_for_derived_classes_must_contain_a_super_call_2377", "Constructors for derived classes must contain a 'super' call."),
                    A_get_accessor_must_return_a_value: diag(2378, 1 /* Error */, "A_get_accessor_must_return_a_value_2378", "A 'get' accessor must return a value."),
                    Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties: diag(2379, 1 /* Error */, "Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_tr_2379", "Argument of type '{0}' is not assignable to parameter of type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the types of the target's properties."),
                    The_return_type_of_a_get_accessor_must_be_assignable_to_its_set_accessor_type: diag(2380, 1 /* Error */, "The_return_type_of_a_get_accessor_must_be_assignable_to_its_set_accessor_type_2380", "The return type of a 'get' accessor must be assignable to its 'set' accessor type"),
                    Overload_signatures_must_all_be_exported_or_non_exported: diag(2383, 1 /* Error */, "Overload_signatures_must_all_be_exported_or_non_exported_2383", "Overload signatures must all be exported or non-exported."),
                    Overload_signatures_must_all_be_ambient_or_non_ambient: diag(2384, 1 /* Error */, "Overload_signatures_must_all_be_ambient_or_non_ambient_2384", "Overload signatures must all be ambient or non-ambient."),
                    Overload_signatures_must_all_be_public_private_or_protected: diag(2385, 1 /* Error */, "Overload_signatures_must_all_be_public_private_or_protected_2385", "Overload signatures must all be public, private or protected."),
                    Overload_signatures_must_all_be_optional_or_required: diag(2386, 1 /* Error */, "Overload_signatures_must_all_be_optional_or_required_2386", "Overload signatures must all be optional or required."),
                    Function_overload_must_be_static: diag(2387, 1 /* Error */, "Function_overload_must_be_static_2387", "Function overload must be static."),
                    Function_overload_must_not_be_static: diag(2388, 1 /* Error */, "Function_overload_must_not_be_static_2388", "Function overload must not be static."),
                    Function_implementation_name_must_be_0: diag(2389, 1 /* Error */, "Function_implementation_name_must_be_0_2389", "Function implementation name must be '{0}'."),
                    Constructor_implementation_is_missing: diag(2390, 1 /* Error */, "Constructor_implementation_is_missing_2390", "Constructor implementation is missing."),
                    Function_implementation_is_missing_or_not_immediately_following_the_declaration: diag(2391, 1 /* Error */, "Function_implementation_is_missing_or_not_immediately_following_the_declaration_2391", "Function implementation is missing or not immediately following the declaration."),
                    Multiple_constructor_implementations_are_not_allowed: diag(2392, 1 /* Error */, "Multiple_constructor_implementations_are_not_allowed_2392", "Multiple constructor implementations are not allowed."),
                    Duplicate_function_implementation: diag(2393, 1 /* Error */, "Duplicate_function_implementation_2393", "Duplicate function implementation."),
                    This_overload_signature_is_not_compatible_with_its_implementation_signature: diag(2394, 1 /* Error */, "This_overload_signature_is_not_compatible_with_its_implementation_signature_2394", "This overload signature is not compatible with its implementation signature."),
                    Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local: diag(2395, 1 /* Error */, "Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local_2395", "Individual declarations in merged declaration '{0}' must be all exported or all local."),
                    Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters: diag(2396, 1 /* Error */, "Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters_2396", "Duplicate identifier 'arguments'. Compiler uses 'arguments' to initialize rest parameters."),
                    Declaration_name_conflicts_with_built_in_global_identifier_0: diag(2397, 1 /* Error */, "Declaration_name_conflicts_with_built_in_global_identifier_0_2397", "Declaration name conflicts with built-in global identifier '{0}'."),
                    constructor_cannot_be_used_as_a_parameter_property_name: diag(2398, 1 /* Error */, "constructor_cannot_be_used_as_a_parameter_property_name_2398", "'constructor' cannot be used as a parameter property name."),
                    Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference: diag(2399, 1 /* Error */, "Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference_2399", "Duplicate identifier '_this'. Compiler uses variable declaration '_this' to capture 'this' reference."),
                    Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference: diag(2400, 1 /* Error */, "Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference_2400", "Expression resolves to variable declaration '_this' that compiler uses to capture 'this' reference."),
                    A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_initialized_properties_parameter_properties_or_private_identifiers: diag(2401, 1 /* Error */, "A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_in_2401", "A 'super' call must be a root-level statement within a constructor of a derived class that contains initialized properties, parameter properties, or private identifiers."),
                    Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference: diag(2402, 1 /* Error */, "Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference_2402", "Expression resolves to '_super' that compiler uses to capture base class reference."),
                    Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2: diag(2403, 1 /* Error */, "Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_t_2403", "Subsequent variable declarations must have the same type.  Variable '{0}' must be of type '{1}', but here has type '{2}'."),
                    The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation: diag(2404, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation_2404", "The left-hand side of a 'for...in' statement cannot use a type annotation."),
                    The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any: diag(2405, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any_2405", "The left-hand side of a 'for...in' statement must be of type 'string' or 'any'."),
                    The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access: diag(2406, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access_2406", "The left-hand side of a 'for...in' statement must be a variable or a property access."),
                    The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_here_has_type_0: diag(2407, 1 /* Error */, "The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_2407", "The right-hand side of a 'for...in' statement must be of type 'any', an object type or a type parameter, but here has type '{0}'."),
                    Setters_cannot_return_a_value: diag(2408, 1 /* Error */, "Setters_cannot_return_a_value_2408", "Setters cannot return a value."),
                    Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class: diag(2409, 1 /* Error */, "Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class_2409", "Return type of constructor signature must be assignable to the instance type of the class."),
                    The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any: diag(2410, 1 /* Error */, "The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any_2410", "The 'with' statement is not supported. All symbols in a 'with' block will have type 'any'."),
                    Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target: diag(2412, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefi_2412", "Type '{0}' is not assignable to type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the type of the target."),
                    Property_0_of_type_1_is_not_assignable_to_2_index_type_3: diag(2411, 1 /* Error */, "Property_0_of_type_1_is_not_assignable_to_2_index_type_3_2411", "Property '{0}' of type '{1}' is not assignable to '{2}' index type '{3}'."),
                    _0_index_type_1_is_not_assignable_to_2_index_type_3: diag(2413, 1 /* Error */, "_0_index_type_1_is_not_assignable_to_2_index_type_3_2413", "'{0}' index type '{1}' is not assignable to '{2}' index type '{3}'."),
                    Class_name_cannot_be_0: diag(2414, 1 /* Error */, "Class_name_cannot_be_0_2414", "Class name cannot be '{0}'."),
                    Class_0_incorrectly_extends_base_class_1: diag(2415, 1 /* Error */, "Class_0_incorrectly_extends_base_class_1_2415", "Class '{0}' incorrectly extends base class '{1}'."),
                    Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2: diag(2416, 1 /* Error */, "Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2_2416", "Property '{0}' in type '{1}' is not assignable to the same property in base type '{2}'."),
                    Class_static_side_0_incorrectly_extends_base_class_static_side_1: diag(2417, 1 /* Error */, "Class_static_side_0_incorrectly_extends_base_class_static_side_1_2417", "Class static side '{0}' incorrectly extends base class static side '{1}'."),
                    Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1: diag(2418, 1 /* Error */, "Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1_2418", "Type of computed property's value is '{0}', which is not assignable to type '{1}'."),
                    Types_of_construct_signatures_are_incompatible: diag(2419, 1 /* Error */, "Types_of_construct_signatures_are_incompatible_2419", "Types of construct signatures are incompatible."),
                    Class_0_incorrectly_implements_interface_1: diag(2420, 1 /* Error */, "Class_0_incorrectly_implements_interface_1_2420", "Class '{0}' incorrectly implements interface '{1}'."),
                    A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_members: diag(2422, 1 /* Error */, "A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_memb_2422", "A class can only implement an object type or intersection of object types with statically known members."),
                    Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor: diag(2423, 1 /* Error */, "Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_access_2423", "Class '{0}' defines instance member function '{1}', but extended class '{2}' defines it as instance member accessor."),
                    Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function: diag(2425, 1 /* Error */, "Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_functi_2425", "Class '{0}' defines instance member property '{1}', but extended class '{2}' defines it as instance member function."),
                    Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function: diag(2426, 1 /* Error */, "Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_functi_2426", "Class '{0}' defines instance member accessor '{1}', but extended class '{2}' defines it as instance member function."),
                    Interface_name_cannot_be_0: diag(2427, 1 /* Error */, "Interface_name_cannot_be_0_2427", "Interface name cannot be '{0}'."),
                    All_declarations_of_0_must_have_identical_type_parameters: diag(2428, 1 /* Error */, "All_declarations_of_0_must_have_identical_type_parameters_2428", "All declarations of '{0}' must have identical type parameters."),
                    Interface_0_incorrectly_extends_interface_1: diag(2430, 1 /* Error */, "Interface_0_incorrectly_extends_interface_1_2430", "Interface '{0}' incorrectly extends interface '{1}'."),
                    Enum_name_cannot_be_0: diag(2431, 1 /* Error */, "Enum_name_cannot_be_0_2431", "Enum name cannot be '{0}'."),
                    In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element: diag(2432, 1 /* Error */, "In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enu_2432", "In an enum with multiple declarations, only one declaration can omit an initializer for its first enum element."),
                    A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged: diag(2433, 1 /* Error */, "A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merg_2433", "A namespace declaration cannot be in a different file from a class or function with which it is merged."),
                    A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged: diag(2434, 1 /* Error */, "A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged_2434", "A namespace declaration cannot be located prior to a class or function with which it is merged."),
                    Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces: diag(2435, 1 /* Error */, "Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces_2435", "Ambient modules cannot be nested in other modules or namespaces."),
                    Ambient_module_declaration_cannot_specify_relative_module_name: diag(2436, 1 /* Error */, "Ambient_module_declaration_cannot_specify_relative_module_name_2436", "Ambient module declaration cannot specify relative module name."),
                    Module_0_is_hidden_by_a_local_declaration_with_the_same_name: diag(2437, 1 /* Error */, "Module_0_is_hidden_by_a_local_declaration_with_the_same_name_2437", "Module '{0}' is hidden by a local declaration with the same name."),
                    Import_name_cannot_be_0: diag(2438, 1 /* Error */, "Import_name_cannot_be_0_2438", "Import name cannot be '{0}'."),
                    Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name: diag(2439, 1 /* Error */, "Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relati_2439", "Import or export declaration in an ambient module declaration cannot reference module through relative module name."),
                    Import_declaration_conflicts_with_local_declaration_of_0: diag(2440, 1 /* Error */, "Import_declaration_conflicts_with_local_declaration_of_0_2440", "Import declaration conflicts with local declaration of '{0}'."),
                    Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module: diag(2441, 1 /* Error */, "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_2441", "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module."),
                    Types_have_separate_declarations_of_a_private_property_0: diag(2442, 1 /* Error */, "Types_have_separate_declarations_of_a_private_property_0_2442", "Types have separate declarations of a private property '{0}'."),
                    Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2: diag(2443, 1 /* Error */, "Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2_2443", "Property '{0}' is protected but type '{1}' is not a class derived from '{2}'."),
                    Property_0_is_protected_in_type_1_but_public_in_type_2: diag(2444, 1 /* Error */, "Property_0_is_protected_in_type_1_but_public_in_type_2_2444", "Property '{0}' is protected in type '{1}' but public in type '{2}'."),
                    Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses: diag(2445, 1 /* Error */, "Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses_2445", "Property '{0}' is protected and only accessible within class '{1}' and its subclasses."),
                    Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_class_2: diag(2446, 1 /* Error */, "Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_cl_2446", "Property '{0}' is protected and only accessible through an instance of class '{1}'. This is an instance of class '{2}'."),
                    The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead: diag(2447, 1 /* Error */, "The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead_2447", "The '{0}' operator is not allowed for boolean types. Consider using '{1}' instead."),
                    Block_scoped_variable_0_used_before_its_declaration: diag(2448, 1 /* Error */, "Block_scoped_variable_0_used_before_its_declaration_2448", "Block-scoped variable '{0}' used before its declaration."),
                    Class_0_used_before_its_declaration: diag(2449, 1 /* Error */, "Class_0_used_before_its_declaration_2449", "Class '{0}' used before its declaration."),
                    Enum_0_used_before_its_declaration: diag(2450, 1 /* Error */, "Enum_0_used_before_its_declaration_2450", "Enum '{0}' used before its declaration."),
                    Cannot_redeclare_block_scoped_variable_0: diag(2451, 1 /* Error */, "Cannot_redeclare_block_scoped_variable_0_2451", "Cannot redeclare block-scoped variable '{0}'."),
                    An_enum_member_cannot_have_a_numeric_name: diag(2452, 1 /* Error */, "An_enum_member_cannot_have_a_numeric_name_2452", "An enum member cannot have a numeric name."),
                    Variable_0_is_used_before_being_assigned: diag(2454, 1 /* Error */, "Variable_0_is_used_before_being_assigned_2454", "Variable '{0}' is used before being assigned."),
                    Type_alias_0_circularly_references_itself: diag(2456, 1 /* Error */, "Type_alias_0_circularly_references_itself_2456", "Type alias '{0}' circularly references itself."),
                    Type_alias_name_cannot_be_0: diag(2457, 1 /* Error */, "Type_alias_name_cannot_be_0_2457", "Type alias name cannot be '{0}'."),
                    An_AMD_module_cannot_have_multiple_name_assignments: diag(2458, 1 /* Error */, "An_AMD_module_cannot_have_multiple_name_assignments_2458", "An AMD module cannot have multiple name assignments."),
                    Module_0_declares_1_locally_but_it_is_not_exported: diag(2459, 1 /* Error */, "Module_0_declares_1_locally_but_it_is_not_exported_2459", "Module '{0}' declares '{1}' locally, but it is not exported."),
                    Module_0_declares_1_locally_but_it_is_exported_as_2: diag(2460, 1 /* Error */, "Module_0_declares_1_locally_but_it_is_exported_as_2_2460", "Module '{0}' declares '{1}' locally, but it is exported as '{2}'."),
                    Type_0_is_not_an_array_type: diag(2461, 1 /* Error */, "Type_0_is_not_an_array_type_2461", "Type '{0}' is not an array type."),
                    A_rest_element_must_be_last_in_a_destructuring_pattern: diag(2462, 1 /* Error */, "A_rest_element_must_be_last_in_a_destructuring_pattern_2462", "A rest element must be last in a destructuring pattern."),
                    A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature: diag(2463, 1 /* Error */, "A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature_2463", "A binding pattern parameter cannot be optional in an implementation signature."),
                    A_computed_property_name_must_be_of_type_string_number_symbol_or_any: diag(2464, 1 /* Error */, "A_computed_property_name_must_be_of_type_string_number_symbol_or_any_2464", "A computed property name must be of type 'string', 'number', 'symbol', or 'any'."),
                    this_cannot_be_referenced_in_a_computed_property_name: diag(2465, 1 /* Error */, "this_cannot_be_referenced_in_a_computed_property_name_2465", "'this' cannot be referenced in a computed property name."),
                    super_cannot_be_referenced_in_a_computed_property_name: diag(2466, 1 /* Error */, "super_cannot_be_referenced_in_a_computed_property_name_2466", "'super' cannot be referenced in a computed property name."),
                    A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type: diag(2467, 1 /* Error */, "A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type_2467", "A computed property name cannot reference a type parameter from its containing type."),
                    Cannot_find_global_value_0: diag(2468, 1 /* Error */, "Cannot_find_global_value_0_2468", "Cannot find global value '{0}'."),
                    The_0_operator_cannot_be_applied_to_type_symbol: diag(2469, 1 /* Error */, "The_0_operator_cannot_be_applied_to_type_symbol_2469", "The '{0}' operator cannot be applied to type 'symbol'."),
                    Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher: diag(2472, 1 /* Error */, "Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher_2472", "Spread operator in 'new' expressions is only available when targeting ECMAScript 5 and higher."),
                    Enum_declarations_must_all_be_const_or_non_const: diag(2473, 1 /* Error */, "Enum_declarations_must_all_be_const_or_non_const_2473", "Enum declarations must all be const or non-const."),
                    const_enum_member_initializers_must_be_constant_expressions: diag(2474, 1 /* Error */, "const_enum_member_initializers_must_be_constant_expressions_2474", "const enum member initializers must be constant expressions."),
                    const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment_or_type_query: diag(2475, 1 /* Error */, "const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_im_2475", "'const' enums can only be used in property or index access expressions or the right hand side of an import declaration or export assignment or type query."),
                    A_const_enum_member_can_only_be_accessed_using_a_string_literal: diag(2476, 1 /* Error */, "A_const_enum_member_can_only_be_accessed_using_a_string_literal_2476", "A const enum member can only be accessed using a string literal."),
                    const_enum_member_initializer_was_evaluated_to_a_non_finite_value: diag(2477, 1 /* Error */, "const_enum_member_initializer_was_evaluated_to_a_non_finite_value_2477", "'const' enum member initializer was evaluated to a non-finite value."),
                    const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN: diag(2478, 1 /* Error */, "const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN_2478", "'const' enum member initializer was evaluated to disallowed value 'NaN'."),
                    let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations: diag(2480, 1 /* Error */, "let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations_2480", "'let' is not allowed to be used as a name in 'let' or 'const' declarations."),
                    Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1: diag(2481, 1 /* Error */, "Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1_2481", "Cannot initialize outer scoped variable '{0}' in the same scope as block scoped declaration '{1}'."),
                    The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation: diag(2483, 1 /* Error */, "The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation_2483", "The left-hand side of a 'for...of' statement cannot use a type annotation."),
                    Export_declaration_conflicts_with_exported_declaration_of_0: diag(2484, 1 /* Error */, "Export_declaration_conflicts_with_exported_declaration_of_0_2484", "Export declaration conflicts with exported declaration of '{0}'."),
                    The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access: diag(2487, 1 /* Error */, "The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access_2487", "The left-hand side of a 'for...of' statement must be a variable or a property access."),
                    Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator: diag(2488, 1 /* Error */, "Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator_2488", "Type '{0}' must have a '[Symbol.iterator]()' method that returns an iterator."),
                    An_iterator_must_have_a_next_method: diag(2489, 1 /* Error */, "An_iterator_must_have_a_next_method_2489", "An iterator must have a 'next()' method."),
                    The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property: diag(2490, 1 /* Error */, "The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property_2490", "The type returned by the '{0}()' method of an iterator must have a 'value' property."),
                    The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern: diag(2491, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern_2491", "The left-hand side of a 'for...in' statement cannot be a destructuring pattern."),
                    Cannot_redeclare_identifier_0_in_catch_clause: diag(2492, 1 /* Error */, "Cannot_redeclare_identifier_0_in_catch_clause_2492", "Cannot redeclare identifier '{0}' in catch clause."),
                    Tuple_type_0_of_length_1_has_no_element_at_index_2: diag(2493, 1 /* Error */, "Tuple_type_0_of_length_1_has_no_element_at_index_2_2493", "Tuple type '{0}' of length '{1}' has no element at index '{2}'."),
                    Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher: diag(2494, 1 /* Error */, "Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher_2494", "Using a string in a 'for...of' statement is only supported in ECMAScript 5 and higher."),
                    Type_0_is_not_an_array_type_or_a_string_type: diag(2495, 1 /* Error */, "Type_0_is_not_an_array_type_or_a_string_type_2495", "Type '{0}' is not an array type or a string type."),
                    The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_standard_function_expression: diag(2496, 1 /* Error */, "The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_stand_2496", "The 'arguments' object cannot be referenced in an arrow function in ES3 and ES5. Consider using a standard function expression."),
                    This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_referencing_its_default_export: diag(2497, 1 /* Error */, "This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_2497", "This module can only be referenced with ECMAScript imports/exports by turning on the '{0}' flag and referencing its default export."),
                    Module_0_uses_export_and_cannot_be_used_with_export_Asterisk: diag(2498, 1 /* Error */, "Module_0_uses_export_and_cannot_be_used_with_export_Asterisk_2498", "Module '{0}' uses 'export =' and cannot be used with 'export *'."),
                    An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments: diag(2499, 1 /* Error */, "An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments_2499", "An interface can only extend an identifier/qualified-name with optional type arguments."),
                    A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments: diag(2500, 1 /* Error */, "A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments_2500", "A class can only implement an identifier/qualified-name with optional type arguments."),
                    A_rest_element_cannot_contain_a_binding_pattern: diag(2501, 1 /* Error */, "A_rest_element_cannot_contain_a_binding_pattern_2501", "A rest element cannot contain a binding pattern."),
                    _0_is_referenced_directly_or_indirectly_in_its_own_type_annotation: diag(2502, 1 /* Error */, "_0_is_referenced_directly_or_indirectly_in_its_own_type_annotation_2502", "'{0}' is referenced directly or indirectly in its own type annotation."),
                    Cannot_find_namespace_0: diag(2503, 1 /* Error */, "Cannot_find_namespace_0_2503", "Cannot find namespace '{0}'."),
                    Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator: diag(2504, 1 /* Error */, "Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator_2504", "Type '{0}' must have a '[Symbol.asyncIterator]()' method that returns an async iterator."),
                    A_generator_cannot_have_a_void_type_annotation: diag(2505, 1 /* Error */, "A_generator_cannot_have_a_void_type_annotation_2505", "A generator cannot have a 'void' type annotation."),
                    _0_is_referenced_directly_or_indirectly_in_its_own_base_expression: diag(2506, 1 /* Error */, "_0_is_referenced_directly_or_indirectly_in_its_own_base_expression_2506", "'{0}' is referenced directly or indirectly in its own base expression."),
                    Type_0_is_not_a_constructor_function_type: diag(2507, 1 /* Error */, "Type_0_is_not_a_constructor_function_type_2507", "Type '{0}' is not a constructor function type."),
                    No_base_constructor_has_the_specified_number_of_type_arguments: diag(2508, 1 /* Error */, "No_base_constructor_has_the_specified_number_of_type_arguments_2508", "No base constructor has the specified number of type arguments."),
                    Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_known_members: diag(2509, 1 /* Error */, "Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_2509", "Base constructor return type '{0}' is not an object type or intersection of object types with statically known members."),
                    Base_constructors_must_all_have_the_same_return_type: diag(2510, 1 /* Error */, "Base_constructors_must_all_have_the_same_return_type_2510", "Base constructors must all have the same return type."),
                    Cannot_create_an_instance_of_an_abstract_class: diag(2511, 1 /* Error */, "Cannot_create_an_instance_of_an_abstract_class_2511", "Cannot create an instance of an abstract class."),
                    Overload_signatures_must_all_be_abstract_or_non_abstract: diag(2512, 1 /* Error */, "Overload_signatures_must_all_be_abstract_or_non_abstract_2512", "Overload signatures must all be abstract or non-abstract."),
                    Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression: diag(2513, 1 /* Error */, "Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression_2513", "Abstract method '{0}' in class '{1}' cannot be accessed via super expression."),
                    A_tuple_type_cannot_be_indexed_with_a_negative_value: diag(2514, 1 /* Error */, "A_tuple_type_cannot_be_indexed_with_a_negative_value_2514", "A tuple type cannot be indexed with a negative value."),
                    Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2: diag(2515, 1 /* Error */, "Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2_2515", "Non-abstract class '{0}' does not implement inherited abstract member '{1}' from class '{2}'."),
                    All_declarations_of_an_abstract_method_must_be_consecutive: diag(2516, 1 /* Error */, "All_declarations_of_an_abstract_method_must_be_consecutive_2516", "All declarations of an abstract method must be consecutive."),
                    Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type: diag(2517, 1 /* Error */, "Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type_2517", "Cannot assign an abstract constructor type to a non-abstract constructor type."),
                    A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard: diag(2518, 1 /* Error */, "A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard_2518", "A 'this'-based type guard is not compatible with a parameter-based type guard."),
                    An_async_iterator_must_have_a_next_method: diag(2519, 1 /* Error */, "An_async_iterator_must_have_a_next_method_2519", "An async iterator must have a 'next()' method."),
                    Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions: diag(2520, 1 /* Error */, "Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions_2520", "Duplicate identifier '{0}'. Compiler uses declaration '{1}' to support async functions."),
                    The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_using_a_standard_function_or_method: diag(2522, 1 /* Error */, "The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_usi_2522", "The 'arguments' object cannot be referenced in an async function or method in ES3 and ES5. Consider using a standard function or method."),
                    yield_expressions_cannot_be_used_in_a_parameter_initializer: diag(2523, 1 /* Error */, "yield_expressions_cannot_be_used_in_a_parameter_initializer_2523", "'yield' expressions cannot be used in a parameter initializer."),
                    await_expressions_cannot_be_used_in_a_parameter_initializer: diag(2524, 1 /* Error */, "await_expressions_cannot_be_used_in_a_parameter_initializer_2524", "'await' expressions cannot be used in a parameter initializer."),
                    Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value: diag(2525, 1 /* Error */, "Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value_2525", "Initializer provides no value for this binding element and the binding element has no default value."),
                    A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface: diag(2526, 1 /* Error */, "A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface_2526", "A 'this' type is available only in a non-static member of a class or interface."),
                    The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary: diag(2527, 1 /* Error */, "The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary_2527", "The inferred type of '{0}' references an inaccessible '{1}' type. A type annotation is necessary."),
                    A_module_cannot_have_multiple_default_exports: diag(2528, 1 /* Error */, "A_module_cannot_have_multiple_default_exports_2528", "A module cannot have multiple default exports."),
                    Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions: diag(2529, 1 /* Error */, "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_func_2529", "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module containing async functions."),
                    Property_0_is_incompatible_with_index_signature: diag(2530, 1 /* Error */, "Property_0_is_incompatible_with_index_signature_2530", "Property '{0}' is incompatible with index signature."),
                    Object_is_possibly_null: diag(2531, 1 /* Error */, "Object_is_possibly_null_2531", "Object is possibly 'null'."),
                    Object_is_possibly_undefined: diag(2532, 1 /* Error */, "Object_is_possibly_undefined_2532", "Object is possibly 'undefined'."),
                    Object_is_possibly_null_or_undefined: diag(2533, 1 /* Error */, "Object_is_possibly_null_or_undefined_2533", "Object is possibly 'null' or 'undefined'."),
                    A_function_returning_never_cannot_have_a_reachable_end_point: diag(2534, 1 /* Error */, "A_function_returning_never_cannot_have_a_reachable_end_point_2534", "A function returning 'never' cannot have a reachable end point."),
                    Type_0_cannot_be_used_to_index_type_1: diag(2536, 1 /* Error */, "Type_0_cannot_be_used_to_index_type_1_2536", "Type '{0}' cannot be used to index type '{1}'."),
                    Type_0_has_no_matching_index_signature_for_type_1: diag(2537, 1 /* Error */, "Type_0_has_no_matching_index_signature_for_type_1_2537", "Type '{0}' has no matching index signature for type '{1}'."),
                    Type_0_cannot_be_used_as_an_index_type: diag(2538, 1 /* Error */, "Type_0_cannot_be_used_as_an_index_type_2538", "Type '{0}' cannot be used as an index type."),
                    Cannot_assign_to_0_because_it_is_not_a_variable: diag(2539, 1 /* Error */, "Cannot_assign_to_0_because_it_is_not_a_variable_2539", "Cannot assign to '{0}' because it is not a variable."),
                    Cannot_assign_to_0_because_it_is_a_read_only_property: diag(2540, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_read_only_property_2540", "Cannot assign to '{0}' because it is a read-only property."),
                    Index_signature_in_type_0_only_permits_reading: diag(2542, 1 /* Error */, "Index_signature_in_type_0_only_permits_reading_2542", "Index signature in type '{0}' only permits reading."),
                    Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_meta_property_reference: diag(2543, 1 /* Error */, "Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_me_2543", "Duplicate identifier '_newTarget'. Compiler uses variable declaration '_newTarget' to capture 'new.target' meta-property reference."),
                    Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta_property_reference: diag(2544, 1 /* Error */, "Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta__2544", "Expression resolves to variable declaration '_newTarget' that compiler uses to capture 'new.target' meta-property reference."),
                    A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any: diag(2545, 1 /* Error */, "A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any_2545", "A mixin class must have a constructor with a single rest parameter of type 'any[]'."),
                    The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_property: diag(2547, 1 /* Error */, "The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_pro_2547", "The type returned by the '{0}()' method of an async iterator must be a promise for a type with a 'value' property."),
                    Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator: diag(2548, 1 /* Error */, "Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator_2548", "Type '{0}' is not an array type or does not have a '[Symbol.iterator]()' method that returns an iterator."),
                    Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator: diag(2549, 1 /* Error */, "Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns__2549", "Type '{0}' is not an array type or a string type or does not have a '[Symbol.iterator]()' method that returns an iterator."),
                    Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2_or_later: diag(2550, 1 /* Error */, "Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_c_2550", "Property '{0}' does not exist on type '{1}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{2}' or later."),
                    Property_0_does_not_exist_on_type_1_Did_you_mean_2: diag(2551, 1 /* Error */, "Property_0_does_not_exist_on_type_1_Did_you_mean_2_2551", "Property '{0}' does not exist on type '{1}'. Did you mean '{2}'?"),
                    Cannot_find_name_0_Did_you_mean_1: diag(2552, 1 /* Error */, "Cannot_find_name_0_Did_you_mean_1_2552", "Cannot find name '{0}'. Did you mean '{1}'?"),
                    Computed_values_are_not_permitted_in_an_enum_with_string_valued_members: diag(2553, 1 /* Error */, "Computed_values_are_not_permitted_in_an_enum_with_string_valued_members_2553", "Computed values are not permitted in an enum with string valued members."),
                    Expected_0_arguments_but_got_1: diag(2554, 1 /* Error */, "Expected_0_arguments_but_got_1_2554", "Expected {0} arguments, but got {1}."),
                    Expected_at_least_0_arguments_but_got_1: diag(2555, 1 /* Error */, "Expected_at_least_0_arguments_but_got_1_2555", "Expected at least {0} arguments, but got {1}."),
                    A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter: diag(2556, 1 /* Error */, "A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter_2556", "A spread argument must either have a tuple type or be passed to a rest parameter."),
                    Expected_0_type_arguments_but_got_1: diag(2558, 1 /* Error */, "Expected_0_type_arguments_but_got_1_2558", "Expected {0} type arguments, but got {1}."),
                    Type_0_has_no_properties_in_common_with_type_1: diag(2559, 1 /* Error */, "Type_0_has_no_properties_in_common_with_type_1_2559", "Type '{0}' has no properties in common with type '{1}'."),
                    Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it: diag(2560, 1 /* Error */, "Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it_2560", "Value of type '{0}' has no properties in common with type '{1}'. Did you mean to call it?"),
                    Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_write_2: diag(2561, 1 /* Error */, "Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_writ_2561", "Object literal may only specify known properties, but '{0}' does not exist in type '{1}'. Did you mean to write '{2}'?"),
                    Base_class_expressions_cannot_reference_class_type_parameters: diag(2562, 1 /* Error */, "Base_class_expressions_cannot_reference_class_type_parameters_2562", "Base class expressions cannot reference class type parameters."),
                    The_containing_function_or_module_body_is_too_large_for_control_flow_analysis: diag(2563, 1 /* Error */, "The_containing_function_or_module_body_is_too_large_for_control_flow_analysis_2563", "The containing function or module body is too large for control flow analysis."),
                    Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor: diag(2564, 1 /* Error */, "Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor_2564", "Property '{0}' has no initializer and is not definitely assigned in the constructor."),
                    Property_0_is_used_before_being_assigned: diag(2565, 1 /* Error */, "Property_0_is_used_before_being_assigned_2565", "Property '{0}' is used before being assigned."),
                    A_rest_element_cannot_have_a_property_name: diag(2566, 1 /* Error */, "A_rest_element_cannot_have_a_property_name_2566", "A rest element cannot have a property name."),
                    Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations: diag(2567, 1 /* Error */, "Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations_2567", "Enum declarations can only merge with namespace or other enum declarations."),
                    Property_0_may_not_exist_on_type_1_Did_you_mean_2: diag(2568, 1 /* Error */, "Property_0_may_not_exist_on_type_1_Did_you_mean_2_2568", "Property '{0}' may not exist on type '{1}'. Did you mean '{2}'?"),
                    Could_not_find_name_0_Did_you_mean_1: diag(2570, 1 /* Error */, "Could_not_find_name_0_Did_you_mean_1_2570", "Could not find name '{0}'. Did you mean '{1}'?"),
                    Object_is_of_type_unknown: diag(2571, 1 /* Error */, "Object_is_of_type_unknown_2571", "Object is of type 'unknown'."),
                    A_rest_element_type_must_be_an_array_type: diag(2574, 1 /* Error */, "A_rest_element_type_must_be_an_array_type_2574", "A rest element type must be an array type."),
                    No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments: diag(2575, 1 /* Error */, "No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments_2575", "No overload expects {0} arguments, but overloads do exist that expect either {1} or {2} arguments."),
                    Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead: diag(2576, 1 /* Error */, "Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead_2576", "Property '{0}' does not exist on type '{1}'. Did you mean to access the static member '{2}' instead?"),
                    Return_type_annotation_circularly_references_itself: diag(2577, 1 /* Error */, "Return_type_annotation_circularly_references_itself_2577", "Return type annotation circularly references itself."),
                    Unused_ts_expect_error_directive: diag(2578, 1 /* Error */, "Unused_ts_expect_error_directive_2578", "Unused '@ts-expect-error' directive."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode: diag(2580, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2580", "Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node`."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery: diag(2581, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2581", "Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery`."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha: diag(2582, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2582", "Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha`."),
                    Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_1_or_later: diag(2583, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2583", "Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{1}' or later."),
                    Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_include_dom: diag(2584, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2584", "Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to include 'dom'."),
                    _0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_es2015_or_later: diag(2585, 1 /* Error */, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_2585", "'{0}' only refers to a type, but is being used as a value here. Do you need to change your target library? Try changing the 'lib' compiler option to es2015 or later."),
                    Cannot_assign_to_0_because_it_is_a_constant: diag(2588, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_constant_2588", "Cannot assign to '{0}' because it is a constant."),
                    Type_instantiation_is_excessively_deep_and_possibly_infinite: diag(2589, 1 /* Error */, "Type_instantiation_is_excessively_deep_and_possibly_infinite_2589", "Type instantiation is excessively deep and possibly infinite."),
                    Expression_produces_a_union_type_that_is_too_complex_to_represent: diag(2590, 1 /* Error */, "Expression_produces_a_union_type_that_is_too_complex_to_represent_2590", "Expression produces a union type that is too complex to represent."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode_and_then_add_node_to_the_types_field_in_your_tsconfig: diag(2591, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2591", "Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node` and then add 'node' to the types field in your tsconfig."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery_and_then_add_jquery_to_the_types_field_in_your_tsconfig: diag(2592, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2592", "Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery` and then add 'jquery' to the types field in your tsconfig."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha_and_then_add_jest_or_mocha_to_the_types_field_in_your_tsconfig: diag(2593, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2593", "Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha` and then add 'jest' or 'mocha' to the types field in your tsconfig."),
                    This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag: diag(2594, 1 /* Error */, "This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag_2594", "This module is declared with 'export =', and can only be used with a default import when using the '{0}' flag."),
                    _0_can_only_be_imported_by_using_a_default_import: diag(2595, 1 /* Error */, "_0_can_only_be_imported_by_using_a_default_import_2595", "'{0}' can only be imported by using a default import."),
                    _0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: diag(2596, 1 /* Error */, "_0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import_2596", "'{0}' can only be imported by turning on the 'esModuleInterop' flag and using a default import."),
                    _0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import: diag(2597, 1 /* Error */, "_0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import_2597", "'{0}' can only be imported by using a 'require' call or by using a default import."),
                    _0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: diag(2598, 1 /* Error */, "_0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using__2598", "'{0}' can only be imported by using a 'require' call or by turning on the 'esModuleInterop' flag and using a default import."),
                    JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist: diag(2602, 1 /* Error */, "JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist_2602", "JSX element implicitly has type 'any' because the global type 'JSX.Element' does not exist."),
                    Property_0_in_type_1_is_not_assignable_to_type_2: diag(2603, 1 /* Error */, "Property_0_in_type_1_is_not_assignable_to_type_2_2603", "Property '{0}' in type '{1}' is not assignable to type '{2}'."),
                    JSX_element_type_0_does_not_have_any_construct_or_call_signatures: diag(2604, 1 /* Error */, "JSX_element_type_0_does_not_have_any_construct_or_call_signatures_2604", "JSX element type '{0}' does not have any construct or call signatures."),
                    Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property: diag(2606, 1 /* Error */, "Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property_2606", "Property '{0}' of JSX spread attribute is not assignable to target property."),
                    JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property: diag(2607, 1 /* Error */, "JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property_2607", "JSX element class does not support attributes because it does not have a '{0}' property."),
                    The_global_type_JSX_0_may_not_have_more_than_one_property: diag(2608, 1 /* Error */, "The_global_type_JSX_0_may_not_have_more_than_one_property_2608", "The global type 'JSX.{0}' may not have more than one property."),
                    JSX_spread_child_must_be_an_array_type: diag(2609, 1 /* Error */, "JSX_spread_child_must_be_an_array_type_2609", "JSX spread child must be an array type."),
                    _0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property: diag(2610, 1 /* Error */, "_0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property_2610", "'{0}' is defined as an accessor in class '{1}', but is overridden here in '{2}' as an instance property."),
                    _0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor: diag(2611, 1 /* Error */, "_0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor_2611", "'{0}' is defined as a property in class '{1}', but is overridden here in '{2}' as an accessor."),
                    Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration: diag(2612, 1 /* Error */, "Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_2612", "Property '{0}' will overwrite the base property in '{1}'. If this is intentional, add an initializer. Otherwise, add a 'declare' modifier or remove the redundant declaration."),
                    Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead: diag(2613, 1 /* Error */, "Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead_2613", "Module '{0}' has no default export. Did you mean to use 'import { {1} } from {0}' instead?"),
                    Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead: diag(2614, 1 /* Error */, "Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead_2614", "Module '{0}' has no exported member '{1}'. Did you mean to use 'import {1} from {0}' instead?"),
                    Type_of_property_0_circularly_references_itself_in_mapped_type_1: diag(2615, 1 /* Error */, "Type_of_property_0_circularly_references_itself_in_mapped_type_1_2615", "Type of property '{0}' circularly references itself in mapped type '{1}'."),
                    _0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import: diag(2616, 1 /* Error */, "_0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import_2616", "'{0}' can only be imported by using 'import {1} = require({2})' or a default import."),
                    _0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: diag(2617, 1 /* Error */, "_0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_us_2617", "'{0}' can only be imported by using 'import {1} = require({2})' or by turning on the 'esModuleInterop' flag and using a default import."),
                    Source_has_0_element_s_but_target_requires_1: diag(2618, 1 /* Error */, "Source_has_0_element_s_but_target_requires_1_2618", "Source has {0} element(s) but target requires {1}."),
                    Source_has_0_element_s_but_target_allows_only_1: diag(2619, 1 /* Error */, "Source_has_0_element_s_but_target_allows_only_1_2619", "Source has {0} element(s) but target allows only {1}."),
                    Target_requires_0_element_s_but_source_may_have_fewer: diag(2620, 1 /* Error */, "Target_requires_0_element_s_but_source_may_have_fewer_2620", "Target requires {0} element(s) but source may have fewer."),
                    Target_allows_only_0_element_s_but_source_may_have_more: diag(2621, 1 /* Error */, "Target_allows_only_0_element_s_but_source_may_have_more_2621", "Target allows only {0} element(s) but source may have more."),
                    Source_provides_no_match_for_required_element_at_position_0_in_target: diag(2623, 1 /* Error */, "Source_provides_no_match_for_required_element_at_position_0_in_target_2623", "Source provides no match for required element at position {0} in target."),
                    Source_provides_no_match_for_variadic_element_at_position_0_in_target: diag(2624, 1 /* Error */, "Source_provides_no_match_for_variadic_element_at_position_0_in_target_2624", "Source provides no match for variadic element at position {0} in target."),
                    Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target: diag(2625, 1 /* Error */, "Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target_2625", "Variadic element at position {0} in source does not match element at position {1} in target."),
                    Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target: diag(2626, 1 /* Error */, "Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target_2626", "Type at position {0} in source is not compatible with type at position {1} in target."),
                    Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target: diag(2627, 1 /* Error */, "Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target_2627", "Type at positions {0} through {1} in source is not compatible with type at position {2} in target."),
                    Cannot_assign_to_0_because_it_is_an_enum: diag(2628, 1 /* Error */, "Cannot_assign_to_0_because_it_is_an_enum_2628", "Cannot assign to '{0}' because it is an enum."),
                    Cannot_assign_to_0_because_it_is_a_class: diag(2629, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_class_2629", "Cannot assign to '{0}' because it is a class."),
                    Cannot_assign_to_0_because_it_is_a_function: diag(2630, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_function_2630", "Cannot assign to '{0}' because it is a function."),
                    Cannot_assign_to_0_because_it_is_a_namespace: diag(2631, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_namespace_2631", "Cannot assign to '{0}' because it is a namespace."),
                    Cannot_assign_to_0_because_it_is_an_import: diag(2632, 1 /* Error */, "Cannot_assign_to_0_because_it_is_an_import_2632", "Cannot assign to '{0}' because it is an import."),
                    JSX_property_access_expressions_cannot_include_JSX_namespace_names: diag(2633, 1 /* Error */, "JSX_property_access_expressions_cannot_include_JSX_namespace_names_2633", "JSX property access expressions cannot include JSX namespace names"),
                    _0_index_signatures_are_incompatible: diag(2634, 1 /* Error */, "_0_index_signatures_are_incompatible_2634", "'{0}' index signatures are incompatible."),
                    Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable: diag(2635, 1 /* Error */, "Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable_2635", "Type '{0}' has no signatures for which the type argument list is applicable."),
                    Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation: diag(2636, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation_2636", "Type '{0}' is not assignable to type '{1}' as implied by variance annotation."),
                    Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_types: diag(2637, 1 /* Error */, "Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_t_2637", "Variance annotations are only supported in type aliases for object, function, constructor, and mapped types."),
                    Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operator: diag(2638, 1 /* Error */, "Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operato_2638", "Type '{0}' may represent a primitive value, which is not permitted as the right operand of the 'in' operator."),
                    Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity: diag(2649, 1 /* Error */, "Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity_2649", "Cannot augment module '{0}' with value exports because it resolves to a non-module entity."),
                    A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums: diag(2651, 1 /* Error */, "A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_memb_2651", "A member initializer in a enum declaration cannot reference members declared after it, including members defined in other enums."),
                    Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead: diag(2652, 1 /* Error */, "Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_d_2652", "Merged declaration '{0}' cannot include a default export declaration. Consider adding a separate 'export default {0}' declaration instead."),
                    Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1: diag(2653, 1 /* Error */, "Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1_2653", "Non-abstract class expression does not implement inherited abstract member '{0}' from class '{1}'."),
                    JSX_expressions_must_have_one_parent_element: diag(2657, 1 /* Error */, "JSX_expressions_must_have_one_parent_element_2657", "JSX expressions must have one parent element."),
                    Type_0_provides_no_match_for_the_signature_1: diag(2658, 1 /* Error */, "Type_0_provides_no_match_for_the_signature_1_2658", "Type '{0}' provides no match for the signature '{1}'."),
                    super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher: diag(2659, 1 /* Error */, "super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_highe_2659", "'super' is only allowed in members of object literal expressions when option 'target' is 'ES2015' or higher."),
                    super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions: diag(2660, 1 /* Error */, "super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions_2660", "'super' can only be referenced in members of derived classes or object literal expressions."),
                    Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module: diag(2661, 1 /* Error */, "Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module_2661", "Cannot export '{0}'. Only local declarations can be exported from a module."),
                    Cannot_find_name_0_Did_you_mean_the_static_member_1_0: diag(2662, 1 /* Error */, "Cannot_find_name_0_Did_you_mean_the_static_member_1_0_2662", "Cannot find name '{0}'. Did you mean the static member '{1}.{0}'?"),
                    Cannot_find_name_0_Did_you_mean_the_instance_member_this_0: diag(2663, 1 /* Error */, "Cannot_find_name_0_Did_you_mean_the_instance_member_this_0_2663", "Cannot find name '{0}'. Did you mean the instance member 'this.{0}'?"),
                    Invalid_module_name_in_augmentation_module_0_cannot_be_found: diag(2664, 1 /* Error */, "Invalid_module_name_in_augmentation_module_0_cannot_be_found_2664", "Invalid module name in augmentation, module '{0}' cannot be found."),
                    Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augmented: diag(2665, 1 /* Error */, "Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augm_2665", "Invalid module name in augmentation. Module '{0}' resolves to an untyped module at '{1}', which cannot be augmented."),
                    Exports_and_export_assignments_are_not_permitted_in_module_augmentations: diag(2666, 1 /* Error */, "Exports_and_export_assignments_are_not_permitted_in_module_augmentations_2666", "Exports and export assignments are not permitted in module augmentations."),
                    Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module: diag(2667, 1 /* Error */, "Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_mod_2667", "Imports are not permitted in module augmentations. Consider moving them to the enclosing external module."),
                    export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible: diag(2668, 1 /* Error */, "export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always__2668", "'export' modifier cannot be applied to ambient modules and module augmentations since they are always visible."),
                    Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations: diag(2669, 1 /* Error */, "Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_2669", "Augmentations for the global scope can only be directly nested in external modules or ambient module declarations."),
                    Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context: diag(2670, 1 /* Error */, "Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambien_2670", "Augmentations for the global scope should have 'declare' modifier unless they appear in already ambient context."),
                    Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity: diag(2671, 1 /* Error */, "Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity_2671", "Cannot augment module '{0}' because it resolves to a non-module entity."),
                    Cannot_assign_a_0_constructor_type_to_a_1_constructor_type: diag(2672, 1 /* Error */, "Cannot_assign_a_0_constructor_type_to_a_1_constructor_type_2672", "Cannot assign a '{0}' constructor type to a '{1}' constructor type."),
                    Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration: diag(2673, 1 /* Error */, "Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration_2673", "Constructor of class '{0}' is private and only accessible within the class declaration."),
                    Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration: diag(2674, 1 /* Error */, "Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration_2674", "Constructor of class '{0}' is protected and only accessible within the class declaration."),
                    Cannot_extend_a_class_0_Class_constructor_is_marked_as_private: diag(2675, 1 /* Error */, "Cannot_extend_a_class_0_Class_constructor_is_marked_as_private_2675", "Cannot extend a class '{0}'. Class constructor is marked as private."),
                    Accessors_must_both_be_abstract_or_non_abstract: diag(2676, 1 /* Error */, "Accessors_must_both_be_abstract_or_non_abstract_2676", "Accessors must both be abstract or non-abstract."),
                    A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type: diag(2677, 1 /* Error */, "A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type_2677", "A type predicate's type must be assignable to its parameter's type."),
                    Type_0_is_not_comparable_to_type_1: diag(2678, 1 /* Error */, "Type_0_is_not_comparable_to_type_1_2678", "Type '{0}' is not comparable to type '{1}'."),
                    A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void: diag(2679, 1 /* Error */, "A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void_2679", "A function that is called with the 'new' keyword cannot have a 'this' type that is 'void'."),
                    A_0_parameter_must_be_the_first_parameter: diag(2680, 1 /* Error */, "A_0_parameter_must_be_the_first_parameter_2680", "A '{0}' parameter must be the first parameter."),
                    A_constructor_cannot_have_a_this_parameter: diag(2681, 1 /* Error */, "A_constructor_cannot_have_a_this_parameter_2681", "A constructor cannot have a 'this' parameter."),
                    this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation: diag(2683, 1 /* Error */, "this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_2683", "'this' implicitly has type 'any' because it does not have a type annotation."),
                    The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1: diag(2684, 1 /* Error */, "The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1_2684", "The 'this' context of type '{0}' is not assignable to method's 'this' of type '{1}'."),
                    The_this_types_of_each_signature_are_incompatible: diag(2685, 1 /* Error */, "The_this_types_of_each_signature_are_incompatible_2685", "The 'this' types of each signature are incompatible."),
                    _0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead: diag(2686, 1 /* Error */, "_0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead_2686", "'{0}' refers to a UMD global, but the current file is a module. Consider adding an import instead."),
                    All_declarations_of_0_must_have_identical_modifiers: diag(2687, 1 /* Error */, "All_declarations_of_0_must_have_identical_modifiers_2687", "All declarations of '{0}' must have identical modifiers."),
                    Cannot_find_type_definition_file_for_0: diag(2688, 1 /* Error */, "Cannot_find_type_definition_file_for_0_2688", "Cannot find type definition file for '{0}'."),
                    Cannot_extend_an_interface_0_Did_you_mean_implements: diag(2689, 1 /* Error */, "Cannot_extend_an_interface_0_Did_you_mean_implements_2689", "Cannot extend an interface '{0}'. Did you mean 'implements'?"),
                    _0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0: diag(2690, 1 /* Error */, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0_2690", "'{0}' only refers to a type, but is being used as a value here. Did you mean to use '{1} in {0}'?"),
                    _0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible: diag(2692, 1 /* Error */, "_0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible_2692", "'{0}' is a primitive, but '{1}' is a wrapper object. Prefer using '{0}' when possible."),
                    _0_only_refers_to_a_type_but_is_being_used_as_a_value_here: diag(2693, 1 /* Error */, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_2693", "'{0}' only refers to a type, but is being used as a value here."),
                    Namespace_0_has_no_exported_member_1: diag(2694, 1 /* Error */, "Namespace_0_has_no_exported_member_1_2694", "Namespace '{0}' has no exported member '{1}'."),
                    Left_side_of_comma_operator_is_unused_and_has_no_side_effects: diag(2695, 1 /* Error */, "Left_side_of_comma_operator_is_unused_and_has_no_side_effects_2695", "Left side of comma operator is unused and has no side effects.", 
                    /*reportsUnnecessary*/
                    true),
                    The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead: diag(2696, 1 /* Error */, "The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead_2696", "The 'Object' type is assignable to very few other types. Did you mean to use the 'any' type instead?"),
                    An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option: diag(2697, 1 /* Error */, "An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_in_2697", "An async function or method must return a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."),
                    Spread_types_may_only_be_created_from_object_types: diag(2698, 1 /* Error */, "Spread_types_may_only_be_created_from_object_types_2698", "Spread types may only be created from object types."),
                    Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1: diag(2699, 1 /* Error */, "Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1_2699", "Static property '{0}' conflicts with built-in property 'Function.{0}' of constructor function '{1}'."),
                    Rest_types_may_only_be_created_from_object_types: diag(2700, 1 /* Error */, "Rest_types_may_only_be_created_from_object_types_2700", "Rest types may only be created from object types."),
                    The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access: diag(2701, 1 /* Error */, "The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access_2701", "The target of an object rest assignment must be a variable or a property access."),
                    _0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here: diag(2702, 1 /* Error */, "_0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here_2702", "'{0}' only refers to a type, but is being used as a namespace here."),
                    The_operand_of_a_delete_operator_must_be_a_property_reference: diag(2703, 1 /* Error */, "The_operand_of_a_delete_operator_must_be_a_property_reference_2703", "The operand of a 'delete' operator must be a property reference."),
                    The_operand_of_a_delete_operator_cannot_be_a_read_only_property: diag(2704, 1 /* Error */, "The_operand_of_a_delete_operator_cannot_be_a_read_only_property_2704", "The operand of a 'delete' operator cannot be a read-only property."),
                    An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option: diag(2705, 1 /* Error */, "An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_de_2705", "An async function or method in ES5/ES3 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."),
                    Required_type_parameters_may_not_follow_optional_type_parameters: diag(2706, 1 /* Error */, "Required_type_parameters_may_not_follow_optional_type_parameters_2706", "Required type parameters may not follow optional type parameters."),
                    Generic_type_0_requires_between_1_and_2_type_arguments: diag(2707, 1 /* Error */, "Generic_type_0_requires_between_1_and_2_type_arguments_2707", "Generic type '{0}' requires between {1} and {2} type arguments."),
                    Cannot_use_namespace_0_as_a_value: diag(2708, 1 /* Error */, "Cannot_use_namespace_0_as_a_value_2708", "Cannot use namespace '{0}' as a value."),
                    Cannot_use_namespace_0_as_a_type: diag(2709, 1 /* Error */, "Cannot_use_namespace_0_as_a_type_2709", "Cannot use namespace '{0}' as a type."),
                    _0_are_specified_twice_The_attribute_named_0_will_be_overwritten: diag(2710, 1 /* Error */, "_0_are_specified_twice_The_attribute_named_0_will_be_overwritten_2710", "'{0}' are specified twice. The attribute named '{0}' will be overwritten."),
                    A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option: diag(2711, 1 /* Error */, "A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES20_2711", "A dynamic import call returns a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."),
                    A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option: diag(2712, 1 /* Error */, "A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declarat_2712", "A dynamic import call in ES5/ES3 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."),
                    Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1: diag(2713, 1 /* Error */, "Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_p_2713", `Cannot access '{0}.{1}' because '{0}' is a type, but not a namespace. Did you mean to retrieve the type of the property '{1}' in '{0}' with '{0}["{1}"]'?`),
                    The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context: diag(2714, 1 /* Error */, "The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context_2714", "The expression of an export assignment must be an identifier or qualified name in an ambient context."),
                    Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor: diag(2715, 1 /* Error */, "Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor_2715", "Abstract property '{0}' in class '{1}' cannot be accessed in the constructor."),
                    Type_parameter_0_has_a_circular_default: diag(2716, 1 /* Error */, "Type_parameter_0_has_a_circular_default_2716", "Type parameter '{0}' has a circular default."),
                    Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_type_2: diag(2717, 1 /* Error */, "Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_t_2717", "Subsequent property declarations must have the same type.  Property '{0}' must be of type '{1}', but here has type '{2}'."),
                    Duplicate_property_0: diag(2718, 1 /* Error */, "Duplicate_property_0_2718", "Duplicate property '{0}'."),
                    Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated: diag(2719, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated_2719", "Type '{0}' is not assignable to type '{1}'. Two different types with this name exist, but they are unrelated."),
                    Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass: diag(2720, 1 /* Error */, "Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclas_2720", "Class '{0}' incorrectly implements class '{1}'. Did you mean to extend '{1}' and inherit its members as a subclass?"),
                    Cannot_invoke_an_object_which_is_possibly_null: diag(2721, 1 /* Error */, "Cannot_invoke_an_object_which_is_possibly_null_2721", "Cannot invoke an object which is possibly 'null'."),
                    Cannot_invoke_an_object_which_is_possibly_undefined: diag(2722, 1 /* Error */, "Cannot_invoke_an_object_which_is_possibly_undefined_2722", "Cannot invoke an object which is possibly 'undefined'."),
                    Cannot_invoke_an_object_which_is_possibly_null_or_undefined: diag(2723, 1 /* Error */, "Cannot_invoke_an_object_which_is_possibly_null_or_undefined_2723", "Cannot invoke an object which is possibly 'null' or 'undefined'."),
                    _0_has_no_exported_member_named_1_Did_you_mean_2: diag(2724, 1 /* Error */, "_0_has_no_exported_member_named_1_Did_you_mean_2_2724", "'{0}' has no exported member named '{1}'. Did you mean '{2}'?"),
                    Class_name_cannot_be_Object_when_targeting_ES5_with_module_0: diag(2725, 1 /* Error */, "Class_name_cannot_be_Object_when_targeting_ES5_with_module_0_2725", "Class name cannot be 'Object' when targeting ES5 with module {0}."),
                    Cannot_find_lib_definition_for_0: diag(2726, 1 /* Error */, "Cannot_find_lib_definition_for_0_2726", "Cannot find lib definition for '{0}'."),
                    Cannot_find_lib_definition_for_0_Did_you_mean_1: diag(2727, 1 /* Error */, "Cannot_find_lib_definition_for_0_Did_you_mean_1_2727", "Cannot find lib definition for '{0}'. Did you mean '{1}'?"),
                    _0_is_declared_here: diag(2728, 3 /* Message */, "_0_is_declared_here_2728", "'{0}' is declared here."),
                    Property_0_is_used_before_its_initialization: diag(2729, 1 /* Error */, "Property_0_is_used_before_its_initialization_2729", "Property '{0}' is used before its initialization."),
                    An_arrow_function_cannot_have_a_this_parameter: diag(2730, 1 /* Error */, "An_arrow_function_cannot_have_a_this_parameter_2730", "An arrow function cannot have a 'this' parameter."),
                    Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_in_String: diag(2731, 1 /* Error */, "Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_i_2731", "Implicit conversion of a 'symbol' to a 'string' will fail at runtime. Consider wrapping this expression in 'String(...)'."),
                    Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension: diag(2732, 1 /* Error */, "Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension_2732", "Cannot find module '{0}'. Consider using '--resolveJsonModule' to import module with '.json' extension."),
                    Property_0_was_also_declared_here: diag(2733, 1 /* Error */, "Property_0_was_also_declared_here_2733", "Property '{0}' was also declared here."),
                    Are_you_missing_a_semicolon: diag(2734, 1 /* Error */, "Are_you_missing_a_semicolon_2734", "Are you missing a semicolon?"),
                    Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1: diag(2735, 1 /* Error */, "Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1_2735", "Did you mean for '{0}' to be constrained to type 'new (...args: any[]) => {1}'?"),
                    Operator_0_cannot_be_applied_to_type_1: diag(2736, 1 /* Error */, "Operator_0_cannot_be_applied_to_type_1_2736", "Operator '{0}' cannot be applied to type '{1}'."),
                    BigInt_literals_are_not_available_when_targeting_lower_than_ES2020: diag(2737, 1 /* Error */, "BigInt_literals_are_not_available_when_targeting_lower_than_ES2020_2737", "BigInt literals are not available when targeting lower than ES2020."),
                    An_outer_value_of_this_is_shadowed_by_this_container: diag(2738, 3 /* Message */, "An_outer_value_of_this_is_shadowed_by_this_container_2738", "An outer value of 'this' is shadowed by this container."),
                    Type_0_is_missing_the_following_properties_from_type_1_Colon_2: diag(2739, 1 /* Error */, "Type_0_is_missing_the_following_properties_from_type_1_Colon_2_2739", "Type '{0}' is missing the following properties from type '{1}': {2}"),
                    Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more: diag(2740, 1 /* Error */, "Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more_2740", "Type '{0}' is missing the following properties from type '{1}': {2}, and {3} more."),
                    Property_0_is_missing_in_type_1_but_required_in_type_2: diag(2741, 1 /* Error */, "Property_0_is_missing_in_type_1_but_required_in_type_2_2741", "Property '{0}' is missing in type '{1}' but required in type '{2}'."),
                    The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_annotation_is_necessary: diag(2742, 1 /* Error */, "The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_a_2742", "The inferred type of '{0}' cannot be named without a reference to '{1}'. This is likely not portable. A type annotation is necessary."),
                    No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments: diag(2743, 1 /* Error */, "No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments_2743", "No overload expects {0} type arguments, but overloads do exist that expect either {1} or {2} type arguments."),
                    Type_parameter_defaults_can_only_reference_previously_declared_type_parameters: diag(2744, 1 /* Error */, "Type_parameter_defaults_can_only_reference_previously_declared_type_parameters_2744", "Type parameter defaults can only reference previously declared type parameters."),
                    This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_provided: diag(2745, 1 /* Error */, "This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_pr_2745", "This JSX tag's '{0}' prop expects type '{1}' which requires multiple children, but only a single child was provided."),
                    This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided: diag(2746, 1 /* Error */, "This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided_2746", "This JSX tag's '{0}' prop expects a single child of type '{1}', but multiple children were provided."),
                    _0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_type_of_1_is_2: diag(2747, 1 /* Error */, "_0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_t_2747", "'{0}' components don't accept text as child elements. Text in JSX has the type 'string', but the expected type of '{1}' is '{2}'."),
                    Cannot_access_ambient_const_enums_when_0_is_enabled: diag(2748, 1 /* Error */, "Cannot_access_ambient_const_enums_when_0_is_enabled_2748", "Cannot access ambient const enums when '{0}' is enabled."),
                    _0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0: diag(2749, 1 /* Error */, "_0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0_2749", "'{0}' refers to a value, but is being used as a type here. Did you mean 'typeof {0}'?"),
                    The_implementation_signature_is_declared_here: diag(2750, 1 /* Error */, "The_implementation_signature_is_declared_here_2750", "The implementation signature is declared here."),
                    Circularity_originates_in_type_at_this_location: diag(2751, 1 /* Error */, "Circularity_originates_in_type_at_this_location_2751", "Circularity originates in type at this location."),
                    The_first_export_default_is_here: diag(2752, 1 /* Error */, "The_first_export_default_is_here_2752", "The first export default is here."),
                    Another_export_default_is_here: diag(2753, 1 /* Error */, "Another_export_default_is_here_2753", "Another export default is here."),
                    super_may_not_use_type_arguments: diag(2754, 1 /* Error */, "super_may_not_use_type_arguments_2754", "'super' may not use type arguments."),
                    No_constituent_of_type_0_is_callable: diag(2755, 1 /* Error */, "No_constituent_of_type_0_is_callable_2755", "No constituent of type '{0}' is callable."),
                    Not_all_constituents_of_type_0_are_callable: diag(2756, 1 /* Error */, "Not_all_constituents_of_type_0_are_callable_2756", "Not all constituents of type '{0}' are callable."),
                    Type_0_has_no_call_signatures: diag(2757, 1 /* Error */, "Type_0_has_no_call_signatures_2757", "Type '{0}' has no call signatures."),
                    Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_other: diag(2758, 1 /* Error */, "Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_2758", "Each member of the union type '{0}' has signatures, but none of those signatures are compatible with each other."),
                    No_constituent_of_type_0_is_constructable: diag(2759, 1 /* Error */, "No_constituent_of_type_0_is_constructable_2759", "No constituent of type '{0}' is constructable."),
                    Not_all_constituents_of_type_0_are_constructable: diag(2760, 1 /* Error */, "Not_all_constituents_of_type_0_are_constructable_2760", "Not all constituents of type '{0}' are constructable."),
                    Type_0_has_no_construct_signatures: diag(2761, 1 /* Error */, "Type_0_has_no_construct_signatures_2761", "Type '{0}' has no construct signatures."),
                    Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_with_each_other: diag(2762, 1 /* Error */, "Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_2762", "Each member of the union type '{0}' has construct signatures, but none of those signatures are compatible with each other."),
                    Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_send_0: diag(2763, 1 /* Error */, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_s_2763", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but for-of will always send '{0}'."),
                    Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_always_send_0: diag(2764, 1 /* Error */, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_al_2764", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array spread will always send '{0}'."),
                    Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring_will_always_send_0: diag(2765, 1 /* Error */, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring__2765", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array destructuring will always send '{0}'."),
                    Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_containing_generator_will_always_send_0: diag(2766, 1 /* Error */, "Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_co_2766", "Cannot delegate iteration to value because the 'next' method of its iterator expects type '{1}', but the containing generator will always send '{0}'."),
                    The_0_property_of_an_iterator_must_be_a_method: diag(2767, 1 /* Error */, "The_0_property_of_an_iterator_must_be_a_method_2767", "The '{0}' property of an iterator must be a method."),
                    The_0_property_of_an_async_iterator_must_be_a_method: diag(2768, 1 /* Error */, "The_0_property_of_an_async_iterator_must_be_a_method_2768", "The '{0}' property of an async iterator must be a method."),
                    No_overload_matches_this_call: diag(2769, 1 /* Error */, "No_overload_matches_this_call_2769", "No overload matches this call."),
                    The_last_overload_gave_the_following_error: diag(2770, 1 /* Error */, "The_last_overload_gave_the_following_error_2770", "The last overload gave the following error."),
                    The_last_overload_is_declared_here: diag(2771, 1 /* Error */, "The_last_overload_is_declared_here_2771", "The last overload is declared here."),
                    Overload_0_of_1_2_gave_the_following_error: diag(2772, 1 /* Error */, "Overload_0_of_1_2_gave_the_following_error_2772", "Overload {0} of {1}, '{2}', gave the following error."),
                    Did_you_forget_to_use_await: diag(2773, 1 /* Error */, "Did_you_forget_to_use_await_2773", "Did you forget to use 'await'?"),
                    This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead: diag(2774, 1 /* Error */, "This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_2774", "This condition will always return true since this function is always defined. Did you mean to call it instead?"),
                    Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation: diag(2775, 1 /* Error */, "Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation_2775", "Assertions require every name in the call target to be declared with an explicit type annotation."),
                    Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name: diag(2776, 1 /* Error */, "Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name_2776", "Assertions require the call target to be an identifier or qualified name."),
                    The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access: diag(2777, 1 /* Error */, "The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access_2777", "The operand of an increment or decrement operator may not be an optional property access."),
                    The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access: diag(2778, 1 /* Error */, "The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access_2778", "The target of an object rest assignment may not be an optional property access."),
                    The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access: diag(2779, 1 /* Error */, "The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access_2779", "The left-hand side of an assignment expression may not be an optional property access."),
                    The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access: diag(2780, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access_2780", "The left-hand side of a 'for...in' statement may not be an optional property access."),
                    The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access: diag(2781, 1 /* Error */, "The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access_2781", "The left-hand side of a 'for...of' statement may not be an optional property access."),
                    _0_needs_an_explicit_type_annotation: diag(2782, 3 /* Message */, "_0_needs_an_explicit_type_annotation_2782", "'{0}' needs an explicit type annotation."),
                    _0_is_specified_more_than_once_so_this_usage_will_be_overwritten: diag(2783, 1 /* Error */, "_0_is_specified_more_than_once_so_this_usage_will_be_overwritten_2783", "'{0}' is specified more than once, so this usage will be overwritten."),
                    get_and_set_accessors_cannot_declare_this_parameters: diag(2784, 1 /* Error */, "get_and_set_accessors_cannot_declare_this_parameters_2784", "'get' and 'set' accessors cannot declare 'this' parameters."),
                    This_spread_always_overwrites_this_property: diag(2785, 1 /* Error */, "This_spread_always_overwrites_this_property_2785", "This spread always overwrites this property."),
                    _0_cannot_be_used_as_a_JSX_component: diag(2786, 1 /* Error */, "_0_cannot_be_used_as_a_JSX_component_2786", "'{0}' cannot be used as a JSX component."),
                    Its_return_type_0_is_not_a_valid_JSX_element: diag(2787, 1 /* Error */, "Its_return_type_0_is_not_a_valid_JSX_element_2787", "Its return type '{0}' is not a valid JSX element."),
                    Its_instance_type_0_is_not_a_valid_JSX_element: diag(2788, 1 /* Error */, "Its_instance_type_0_is_not_a_valid_JSX_element_2788", "Its instance type '{0}' is not a valid JSX element."),
                    Its_element_type_0_is_not_a_valid_JSX_element: diag(2789, 1 /* Error */, "Its_element_type_0_is_not_a_valid_JSX_element_2789", "Its element type '{0}' is not a valid JSX element."),
                    The_operand_of_a_delete_operator_must_be_optional: diag(2790, 1 /* Error */, "The_operand_of_a_delete_operator_must_be_optional_2790", "The operand of a 'delete' operator must be optional."),
                    Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_later: diag(2791, 1 /* Error */, "Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_lat_2791", "Exponentiation cannot be performed on 'bigint' values unless the 'target' option is set to 'es2016' or later."),
                    Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_to_the_paths_option: diag(2792, 1 /* Error */, "Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_t_2792", "Cannot find module '{0}'. Did you mean to set the 'moduleResolution' option to 'nodenext', or to add aliases to the 'paths' option?"),
                    The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_are_not_externally_visible: diag(2793, 1 /* Error */, "The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_2793", "The call would have succeeded against this implementation, but implementation signatures of overloads are not externally visible."),
                    Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise: diag(2794, 1 /* Error */, "Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise_2794", "Expected {0} arguments, but got {1}. Did you forget to include 'void' in your type argument to 'Promise'?"),
                    The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types: diag(2795, 1 /* Error */, "The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types_2795", "The 'intrinsic' keyword can only be used to declare compiler provided intrinsic types."),
                    It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tagged_template_expression_which_cannot_be_invoked: diag(2796, 1 /* Error */, "It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tag_2796", "It is likely that you are missing a comma to separate these two template expressions. They form a tagged template expression which cannot be invoked."),
                    A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_be_declared_abstract: diag(2797, 1 /* Error */, "A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_2797", "A mixin class that extends from a type variable containing an abstract construct signature must also be declared 'abstract'."),
                    The_declaration_was_marked_as_deprecated_here: diag(2798, 1 /* Error */, "The_declaration_was_marked_as_deprecated_here_2798", "The declaration was marked as deprecated here."),
                    Type_produces_a_tuple_type_that_is_too_large_to_represent: diag(2799, 1 /* Error */, "Type_produces_a_tuple_type_that_is_too_large_to_represent_2799", "Type produces a tuple type that is too large to represent."),
                    Expression_produces_a_tuple_type_that_is_too_large_to_represent: diag(2800, 1 /* Error */, "Expression_produces_a_tuple_type_that_is_too_large_to_represent_2800", "Expression produces a tuple type that is too large to represent."),
                    This_condition_will_always_return_true_since_this_0_is_always_defined: diag(2801, 1 /* Error */, "This_condition_will_always_return_true_since_this_0_is_always_defined_2801", "This condition will always return true since this '{0}' is always defined."),
                    Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher: diag(2802, 1 /* Error */, "Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es201_2802", "Type '{0}' can only be iterated through when using the '--downlevelIteration' flag or with a '--target' of 'es2015' or higher."),
                    Cannot_assign_to_private_method_0_Private_methods_are_not_writable: diag(2803, 1 /* Error */, "Cannot_assign_to_private_method_0_Private_methods_are_not_writable_2803", "Cannot assign to private method '{0}'. Private methods are not writable."),
                    Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name: diag(2804, 1 /* Error */, "Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name_2804", "Duplicate identifier '{0}'. Static and instance elements cannot share the same private name."),
                    Private_accessor_was_defined_without_a_getter: diag(2806, 1 /* Error */, "Private_accessor_was_defined_without_a_getter_2806", "Private accessor was defined without a getter."),
                    This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0: diag(2807, 1 /* Error */, "This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_o_2807", "This syntax requires an imported helper named '{1}' with {2} parameters, which is not compatible with the one in '{0}'. Consider upgrading your version of '{0}'."),
                    A_get_accessor_must_be_at_least_as_accessible_as_the_setter: diag(2808, 1 /* Error */, "A_get_accessor_must_be_at_least_as_accessible_as_the_setter_2808", "A get accessor must be at least as accessible as the setter"),
                    Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_whole_assignment_in_parentheses: diag(2809, 1 /* Error */, "Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_d_2809", "Declaration or statement expected. This '=' follows a block of statements, so if you intended to write a destructuring assignment, you might need to wrap the whole assignment in parentheses."),
                    Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_without_arguments: diag(2810, 1 /* Error */, "Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_2810", "Expected 1 argument, but got 0. 'new Promise()' needs a JSDoc hint to produce a 'resolve' that can be called without arguments."),
                    Initializer_for_property_0: diag(2811, 1 /* Error */, "Initializer_for_property_0_2811", "Initializer for property '{0}'"),
                    Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom: diag(2812, 1 /* Error */, "Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom_2812", "Property '{0}' does not exist on type '{1}'. Try changing the 'lib' compiler option to include 'dom'."),
                    Class_declaration_cannot_implement_overload_list_for_0: diag(2813, 1 /* Error */, "Class_declaration_cannot_implement_overload_list_for_0_2813", "Class declaration cannot implement overload list for '{0}'."),
                    Function_with_bodies_can_only_merge_with_classes_that_are_ambient: diag(2814, 1 /* Error */, "Function_with_bodies_can_only_merge_with_classes_that_are_ambient_2814", "Function with bodies can only merge with classes that are ambient."),
                    arguments_cannot_be_referenced_in_property_initializers: diag(2815, 1 /* Error */, "arguments_cannot_be_referenced_in_property_initializers_2815", "'arguments' cannot be referenced in property initializers."),
                    Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class: diag(2816, 1 /* Error */, "Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class_2816", "Cannot use 'this' in a static property initializer of a decorated class."),
                    Property_0_has_no_initializer_and_is_not_definitely_assigned_in_a_class_static_block: diag(2817, 1 /* Error */, "Property_0_has_no_initializer_and_is_not_definitely_assigned_in_a_class_static_block_2817", "Property '{0}' has no initializer and is not definitely assigned in a class static block."),
                    Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializers: diag(2818, 1 /* Error */, "Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializer_2818", "Duplicate identifier '{0}'. Compiler reserves name '{1}' when emitting 'super' references in static initializers."),
                    Namespace_name_cannot_be_0: diag(2819, 1 /* Error */, "Namespace_name_cannot_be_0_2819", "Namespace name cannot be '{0}'."),
                    Type_0_is_not_assignable_to_type_1_Did_you_mean_2: diag(2820, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_Did_you_mean_2_2820", "Type '{0}' is not assignable to type '{1}'. Did you mean '{2}'?"),
                    Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_or_nodenext: diag(2821, 1 /* Error */, "Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_or_nodenext_2821", "Import assertions are only supported when the '--module' option is set to 'esnext' or 'nodenext'."),
                    Import_assertions_cannot_be_used_with_type_only_imports_or_exports: diag(2822, 1 /* Error */, "Import_assertions_cannot_be_used_with_type_only_imports_or_exports_2822", "Import assertions cannot be used with type-only imports or exports."),
                    Cannot_find_namespace_0_Did_you_mean_1: diag(2833, 1 /* Error */, "Cannot_find_namespace_0_Did_you_mean_1_2833", "Cannot find namespace '{0}'. Did you mean '{1}'?"),
                    Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_node16_or_nodenext_Consider_adding_an_extension_to_the_import_path: diag(2834, 1 /* Error */, "Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_n_2834", "Relative import paths need explicit file extensions in EcmaScript imports when '--moduleResolution' is 'node16' or 'nodenext'. Consider adding an extension to the import path."),
                    Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_node16_or_nodenext_Did_you_mean_0: diag(2835, 1 /* Error */, "Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_n_2835", "Relative import paths need explicit file extensions in EcmaScript imports when '--moduleResolution' is 'node16' or 'nodenext'. Did you mean '{0}'?"),
                    Import_assertions_are_not_allowed_on_statements_that_transpile_to_commonjs_require_calls: diag(2836, 1 /* Error */, "Import_assertions_are_not_allowed_on_statements_that_transpile_to_commonjs_require_calls_2836", "Import assertions are not allowed on statements that transpile to commonjs 'require' calls."),
                    Import_assertion_values_must_be_string_literal_expressions: diag(2837, 1 /* Error */, "Import_assertion_values_must_be_string_literal_expressions_2837", "Import assertion values must be string literal expressions."),
                    All_declarations_of_0_must_have_identical_constraints: diag(2838, 1 /* Error */, "All_declarations_of_0_must_have_identical_constraints_2838", "All declarations of '{0}' must have identical constraints."),
                    This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value: diag(2839, 1 /* Error */, "This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value_2839", "This condition will always return '{0}' since JavaScript compares objects by reference, not value."),
                    An_interface_cannot_extend_a_primitive_type_like_0_an_interface_can_only_extend_named_types_and_classes: diag(2840, 1 /* Error */, "An_interface_cannot_extend_a_primitive_type_like_0_an_interface_can_only_extend_named_types_and_clas_2840", "An interface cannot extend a primitive type like '{0}'; an interface can only extend named types and classes"),
                    The_type_of_this_expression_cannot_be_named_without_a_resolution_mode_assertion_which_is_an_unstable_feature_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next: diag(2841, 1 /* Error */, "The_type_of_this_expression_cannot_be_named_without_a_resolution_mode_assertion_which_is_an_unstable_2841", "The type of this expression cannot be named without a 'resolution-mode' assertion, which is an unstable feature. Use nightly TypeScript to silence this error. Try updating with 'npm install -D typescript@next'."),
                    _0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation: diag(2842, 1 /* Error */, "_0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation_2842", "'{0}' is an unused renaming of '{1}'. Did you intend to use it as a type annotation?"),
                    We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here: diag(2843, 1 /* Error */, "We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here_2843", "We can only write a type for '{0}' by adding a type for the entire parameter here."),
                    Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor: diag(2844, 1 /* Error */, "Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2844", "Type of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor."),
                    This_condition_will_always_return_0: diag(2845, 1 /* Error */, "This_condition_will_always_return_0_2845", "This condition will always return '{0}'."),
                    A_declaration_file_cannot_be_imported_without_import_type_Did_you_mean_to_import_an_implementation_file_0_instead: diag(2846, 1 /* Error */, "A_declaration_file_cannot_be_imported_without_import_type_Did_you_mean_to_import_an_implementation_f_2846", "A declaration file cannot be imported without 'import type'. Did you mean to import an implementation file '{0}' instead?"),
                    Import_declaration_0_is_using_private_name_1: diag(4e3, 1 /* Error */, "Import_declaration_0_is_using_private_name_1_4000", "Import declaration '{0}' is using private name '{1}'."),
                    Type_parameter_0_of_exported_class_has_or_is_using_private_name_1: diag(4002, 1 /* Error */, "Type_parameter_0_of_exported_class_has_or_is_using_private_name_1_4002", "Type parameter '{0}' of exported class has or is using private name '{1}'."),
                    Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1: diag(4004, 1 /* Error */, "Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1_4004", "Type parameter '{0}' of exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4006, 1 /* Error */, "Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4006", "Type parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4008, 1 /* Error */, "Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4008", "Type parameter '{0}' of call signature from exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: diag(4010, 1 /* Error */, "Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4010", "Type parameter '{0}' of public static method from exported class has or is using private name '{1}'."),
                    Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: diag(4012, 1 /* Error */, "Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4012", "Type parameter '{0}' of public method from exported class has or is using private name '{1}'."),
                    Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: diag(4014, 1 /* Error */, "Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4014", "Type parameter '{0}' of method from exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_exported_function_has_or_is_using_private_name_1: diag(4016, 1 /* Error */, "Type_parameter_0_of_exported_function_has_or_is_using_private_name_1_4016", "Type parameter '{0}' of exported function has or is using private name '{1}'."),
                    Implements_clause_of_exported_class_0_has_or_is_using_private_name_1: diag(4019, 1 /* Error */, "Implements_clause_of_exported_class_0_has_or_is_using_private_name_1_4019", "Implements clause of exported class '{0}' has or is using private name '{1}'."),
                    extends_clause_of_exported_class_0_has_or_is_using_private_name_1: diag(4020, 1 /* Error */, "extends_clause_of_exported_class_0_has_or_is_using_private_name_1_4020", "'extends' clause of exported class '{0}' has or is using private name '{1}'."),
                    extends_clause_of_exported_class_has_or_is_using_private_name_0: diag(4021, 1 /* Error */, "extends_clause_of_exported_class_has_or_is_using_private_name_0_4021", "'extends' clause of exported class has or is using private name '{0}'."),
                    extends_clause_of_exported_interface_0_has_or_is_using_private_name_1: diag(4022, 1 /* Error */, "extends_clause_of_exported_interface_0_has_or_is_using_private_name_1_4022", "'extends' clause of exported interface '{0}' has or is using private name '{1}'."),
                    Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4023, 1 /* Error */, "Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4023", "Exported variable '{0}' has or is using name '{1}' from external module {2} but cannot be named."),
                    Exported_variable_0_has_or_is_using_name_1_from_private_module_2: diag(4024, 1 /* Error */, "Exported_variable_0_has_or_is_using_name_1_from_private_module_2_4024", "Exported variable '{0}' has or is using name '{1}' from private module '{2}'."),
                    Exported_variable_0_has_or_is_using_private_name_1: diag(4025, 1 /* Error */, "Exported_variable_0_has_or_is_using_private_name_1_4025", "Exported variable '{0}' has or is using private name '{1}'."),
                    Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4026, 1 /* Error */, "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot__4026", "Public static property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4027, 1 /* Error */, "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4027", "Public static property '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
                    Public_static_property_0_of_exported_class_has_or_is_using_private_name_1: diag(4028, 1 /* Error */, "Public_static_property_0_of_exported_class_has_or_is_using_private_name_1_4028", "Public static property '{0}' of exported class has or is using private name '{1}'."),
                    Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4029, 1 /* Error */, "Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_name_4029", "Public property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4030, 1 /* Error */, "Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4030", "Public property '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
                    Public_property_0_of_exported_class_has_or_is_using_private_name_1: diag(4031, 1 /* Error */, "Public_property_0_of_exported_class_has_or_is_using_private_name_1_4031", "Public property '{0}' of exported class has or is using private name '{1}'."),
                    Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4032, 1 /* Error */, "Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4032", "Property '{0}' of exported interface has or is using name '{1}' from private module '{2}'."),
                    Property_0_of_exported_interface_has_or_is_using_private_name_1: diag(4033, 1 /* Error */, "Property_0_of_exported_interface_has_or_is_using_private_name_1_4033", "Property '{0}' of exported interface has or is using private name '{1}'."),
                    Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4034, 1 /* Error */, "Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_mod_4034", "Parameter type of public static setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1: diag(4035, 1 /* Error */, "Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1_4035", "Parameter type of public static setter '{0}' from exported class has or is using private name '{1}'."),
                    Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4036, 1 /* Error */, "Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4036", "Parameter type of public setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1: diag(4037, 1 /* Error */, "Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1_4037", "Parameter type of public setter '{0}' from exported class has or is using private name '{1}'."),
                    Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4038, 1 /* Error */, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_modul_4038", "Return type of public static getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4039, 1 /* Error */, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_4039", "Return type of public static getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
                    Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1: diag(4040, 1 /* Error */, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1_4040", "Return type of public static getter '{0}' from exported class has or is using private name '{1}'."),
                    Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4041, 1 /* Error */, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_4041", "Return type of public getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4042, 1 /* Error */, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4042", "Return type of public getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
                    Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1: diag(4043, 1 /* Error */, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1_4043", "Return type of public getter '{0}' from exported class has or is using private name '{1}'."),
                    Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: diag(4044, 1 /* Error */, "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_mod_4044", "Return type of constructor signature from exported interface has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0: diag(4045, 1 /* Error */, "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0_4045", "Return type of constructor signature from exported interface has or is using private name '{0}'."),
                    Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: diag(4046, 1 /* Error */, "Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4046", "Return type of call signature from exported interface has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0: diag(4047, 1 /* Error */, "Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0_4047", "Return type of call signature from exported interface has or is using private name '{0}'."),
                    Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: diag(4048, 1 /* Error */, "Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4048", "Return type of index signature from exported interface has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0: diag(4049, 1 /* Error */, "Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0_4049", "Return type of index signature from exported interface has or is using private name '{0}'."),
                    Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: diag(4050, 1 /* Error */, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module__4050", "Return type of public static method from exported class has or is using name '{0}' from external module {1} but cannot be named."),
                    Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: diag(4051, 1 /* Error */, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4051", "Return type of public static method from exported class has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0: diag(4052, 1 /* Error */, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0_4052", "Return type of public static method from exported class has or is using private name '{0}'."),
                    Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: diag(4053, 1 /* Error */, "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_c_4053", "Return type of public method from exported class has or is using name '{0}' from external module {1} but cannot be named."),
                    Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: diag(4054, 1 /* Error */, "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4054", "Return type of public method from exported class has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0: diag(4055, 1 /* Error */, "Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0_4055", "Return type of public method from exported class has or is using private name '{0}'."),
                    Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1: diag(4056, 1 /* Error */, "Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4056", "Return type of method from exported interface has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0: diag(4057, 1 /* Error */, "Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0_4057", "Return type of method from exported interface has or is using private name '{0}'."),
                    Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: diag(4058, 1 /* Error */, "Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named_4058", "Return type of exported function has or is using name '{0}' from external module {1} but cannot be named."),
                    Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1: diag(4059, 1 /* Error */, "Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1_4059", "Return type of exported function has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_exported_function_has_or_is_using_private_name_0: diag(4060, 1 /* Error */, "Return_type_of_exported_function_has_or_is_using_private_name_0_4060", "Return type of exported function has or is using private name '{0}'."),
                    Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4061, 1 /* Error */, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_can_4061", "Parameter '{0}' of constructor from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4062, 1 /* Error */, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2_4062", "Parameter '{0}' of constructor from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1: diag(4063, 1 /* Error */, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1_4063", "Parameter '{0}' of constructor from exported class has or is using private name '{1}'."),
                    Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4064, 1 /* Error */, "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_mod_4064", "Parameter '{0}' of constructor signature from exported interface has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4065, 1 /* Error */, "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4065", "Parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."),
                    Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4066, 1 /* Error */, "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4066", "Parameter '{0}' of call signature from exported interface has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4067, 1 /* Error */, "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4067", "Parameter '{0}' of call signature from exported interface has or is using private name '{1}'."),
                    Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4068, 1 /* Error */, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module__4068", "Parameter '{0}' of public static method from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4069, 1 /* Error */, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4069", "Parameter '{0}' of public static method from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: diag(4070, 1 /* Error */, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4070", "Parameter '{0}' of public static method from exported class has or is using private name '{1}'."),
                    Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4071, 1 /* Error */, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_c_4071", "Parameter '{0}' of public method from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4072, 1 /* Error */, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4072", "Parameter '{0}' of public method from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: diag(4073, 1 /* Error */, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4073", "Parameter '{0}' of public method from exported class has or is using private name '{1}'."),
                    Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4074, 1 /* Error */, "Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4074", "Parameter '{0}' of method from exported interface has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: diag(4075, 1 /* Error */, "Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4075", "Parameter '{0}' of method from exported interface has or is using private name '{1}'."),
                    Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4076, 1 /* Error */, "Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4076", "Parameter '{0}' of exported function has or is using name '{1}' from external module {2} but cannot be named."),
                    Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2: diag(4077, 1 /* Error */, "Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2_4077", "Parameter '{0}' of exported function has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_exported_function_has_or_is_using_private_name_1: diag(4078, 1 /* Error */, "Parameter_0_of_exported_function_has_or_is_using_private_name_1_4078", "Parameter '{0}' of exported function has or is using private name '{1}'."),
                    Exported_type_alias_0_has_or_is_using_private_name_1: diag(4081, 1 /* Error */, "Exported_type_alias_0_has_or_is_using_private_name_1_4081", "Exported type alias '{0}' has or is using private name '{1}'."),
                    Default_export_of_the_module_has_or_is_using_private_name_0: diag(4082, 1 /* Error */, "Default_export_of_the_module_has_or_is_using_private_name_0_4082", "Default export of the module has or is using private name '{0}'."),
                    Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1: diag(4083, 1 /* Error */, "Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1_4083", "Type parameter '{0}' of exported type alias has or is using private name '{1}'."),
                    Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2: diag(4084, 1 /* Error */, "Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2_4084", "Exported type alias '{0}' has or is using private name '{1}' from module {2}."),
                    Extends_clause_for_inferred_type_0_has_or_is_using_private_name_1: diag(4085, 1 /* Error */, "Extends_clause_for_inferred_type_0_has_or_is_using_private_name_1_4085", "Extends clause for inferred type '{0}' has or is using private name '{1}'."),
                    Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_library_to_resolve_the_conflict: diag(4090, 1 /* Error */, "Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_librar_4090", "Conflicting definitions for '{0}' found at '{1}' and '{2}'. Consider installing a specific version of this library to resolve the conflict."),
                    Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4091, 1 /* Error */, "Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4091", "Parameter '{0}' of index signature from exported interface has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4092, 1 /* Error */, "Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1_4092", "Parameter '{0}' of index signature from exported interface has or is using private name '{1}'."),
                    Property_0_of_exported_class_expression_may_not_be_private_or_protected: diag(4094, 1 /* Error */, "Property_0_of_exported_class_expression_may_not_be_private_or_protected_4094", "Property '{0}' of exported class expression may not be private or protected."),
                    Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4095, 1 /* Error */, "Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_4095", "Public static method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4096, 1 /* Error */, "Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4096", "Public static method '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
                    Public_static_method_0_of_exported_class_has_or_is_using_private_name_1: diag(4097, 1 /* Error */, "Public_static_method_0_of_exported_class_has_or_is_using_private_name_1_4097", "Public static method '{0}' of exported class has or is using private name '{1}'."),
                    Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4098, 1 /* Error */, "Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4098", "Public method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4099, 1 /* Error */, "Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4099", "Public method '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
                    Public_method_0_of_exported_class_has_or_is_using_private_name_1: diag(4100, 1 /* Error */, "Public_method_0_of_exported_class_has_or_is_using_private_name_1_4100", "Public method '{0}' of exported class has or is using private name '{1}'."),
                    Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4101, 1 /* Error */, "Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4101", "Method '{0}' of exported interface has or is using name '{1}' from private module '{2}'."),
                    Method_0_of_exported_interface_has_or_is_using_private_name_1: diag(4102, 1 /* Error */, "Method_0_of_exported_interface_has_or_is_using_private_name_1_4102", "Method '{0}' of exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1: diag(4103, 1 /* Error */, "Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1_4103", "Type parameter '{0}' of exported mapped object type is using private name '{1}'."),
                    The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1: diag(4104, 1 /* Error */, "The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1_4104", "The type '{0}' is 'readonly' and cannot be assigned to the mutable type '{1}'."),
                    Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter: diag(4105, 1 /* Error */, "Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter_4105", "Private or protected member '{0}' cannot be accessed on a type parameter."),
                    Parameter_0_of_accessor_has_or_is_using_private_name_1: diag(4106, 1 /* Error */, "Parameter_0_of_accessor_has_or_is_using_private_name_1_4106", "Parameter '{0}' of accessor has or is using private name '{1}'."),
                    Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2: diag(4107, 1 /* Error */, "Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2_4107", "Parameter '{0}' of accessor has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4108, 1 /* Error */, "Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4108", "Parameter '{0}' of accessor has or is using name '{1}' from external module '{2}' but cannot be named."),
                    Type_arguments_for_0_circularly_reference_themselves: diag(4109, 1 /* Error */, "Type_arguments_for_0_circularly_reference_themselves_4109", "Type arguments for '{0}' circularly reference themselves."),
                    Tuple_type_arguments_circularly_reference_themselves: diag(4110, 1 /* Error */, "Tuple_type_arguments_circularly_reference_themselves_4110", "Tuple type arguments circularly reference themselves."),
                    Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0: diag(4111, 1 /* Error */, "Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0_4111", "Property '{0}' comes from an index signature, so it must be accessed with ['{0}']."),
                    This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class: diag(4112, 1 /* Error */, "This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another__4112", "This member cannot have an 'override' modifier because its containing class '{0}' does not extend another class."),
                    This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0: diag(4113, 1 /* Error */, "This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_4113", "This member cannot have an 'override' modifier because it is not declared in the base class '{0}'."),
                    This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0: diag(4114, 1 /* Error */, "This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0_4114", "This member must have an 'override' modifier because it overrides a member in the base class '{0}'."),
                    This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0: diag(4115, 1 /* Error */, "This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0_4115", "This parameter property must have an 'override' modifier because it overrides a member in base class '{0}'."),
                    This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0: diag(4116, 1 /* Error */, "This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared__4116", "This member must have an 'override' modifier because it overrides an abstract method that is declared in the base class '{0}'."),
                    This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1: diag(4117, 1 /* Error */, "This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you__4117", "This member cannot have an 'override' modifier because it is not declared in the base class '{0}'. Did you mean '{1}'?"),
                    The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized: diag(4118, 1 /* Error */, "The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized_4118", "The type of this node cannot be serialized because its property '{0}' cannot be serialized."),
                    This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0: diag(4119, 1 /* Error */, "This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_4119", "This member must have a JSDoc comment with an '@override' tag because it overrides a member in the base class '{0}'."),
                    This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0: diag(4120, 1 /* Error */, "This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_4120", "This parameter property must have a JSDoc comment with an '@override' tag because it overrides a member in the base class '{0}'."),
                    This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class: diag(4121, 1 /* Error */, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_4121", "This member cannot have a JSDoc comment with an '@override' tag because its containing class '{0}' does not extend another class."),
                    This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0: diag(4122, 1 /* Error */, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base__4122", "This member cannot have a JSDoc comment with an '@override' tag because it is not declared in the base class '{0}'."),
                    This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1: diag(4123, 1 /* Error */, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base__4123", "This member cannot have a JSDoc comment with an 'override' tag because it is not declared in the base class '{0}'. Did you mean '{1}'?"),
                    Compiler_option_0_of_value_1_is_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next: diag(4124, 1 /* Error */, "Compiler_option_0_of_value_1_is_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_w_4124", "Compiler option '{0}' of value '{1}' is unstable. Use nightly TypeScript to silence this error. Try updating with 'npm install -D typescript@next'."),
                    resolution_mode_assertions_are_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next: diag(4125, 1 /* Error */, "resolution_mode_assertions_are_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_wi_4125", "'resolution-mode' assertions are unstable. Use nightly TypeScript to silence this error. Try updating with 'npm install -D typescript@next'."),
                    The_current_host_does_not_support_the_0_option: diag(5001, 1 /* Error */, "The_current_host_does_not_support_the_0_option_5001", "The current host does not support the '{0}' option."),
                    Cannot_find_the_common_subdirectory_path_for_the_input_files: diag(5009, 1 /* Error */, "Cannot_find_the_common_subdirectory_path_for_the_input_files_5009", "Cannot find the common subdirectory path for the input files."),
                    File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0: diag(5010, 1 /* Error */, "File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0_5010", "File specification cannot end in a recursive directory wildcard ('**'): '{0}'."),
                    Cannot_read_file_0_Colon_1: diag(5012, 1 /* Error */, "Cannot_read_file_0_Colon_1_5012", "Cannot read file '{0}': {1}."),
                    Failed_to_parse_file_0_Colon_1: diag(5014, 1 /* Error */, "Failed_to_parse_file_0_Colon_1_5014", "Failed to parse file '{0}': {1}."),
                    Unknown_compiler_option_0: diag(5023, 1 /* Error */, "Unknown_compiler_option_0_5023", "Unknown compiler option '{0}'."),
                    Compiler_option_0_requires_a_value_of_type_1: diag(5024, 1 /* Error */, "Compiler_option_0_requires_a_value_of_type_1_5024", "Compiler option '{0}' requires a value of type {1}."),
                    Unknown_compiler_option_0_Did_you_mean_1: diag(5025, 1 /* Error */, "Unknown_compiler_option_0_Did_you_mean_1_5025", "Unknown compiler option '{0}'. Did you mean '{1}'?"),
                    Could_not_write_file_0_Colon_1: diag(5033, 1 /* Error */, "Could_not_write_file_0_Colon_1_5033", "Could not write file '{0}': {1}."),
                    Option_project_cannot_be_mixed_with_source_files_on_a_command_line: diag(5042, 1 /* Error */, "Option_project_cannot_be_mixed_with_source_files_on_a_command_line_5042", "Option 'project' cannot be mixed with source files on a command line."),
                    Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher: diag(5047, 1 /* Error */, "Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES_5047", "Option 'isolatedModules' can only be used when either option '--module' is provided or option 'target' is 'ES2015' or higher."),
                    Option_0_cannot_be_specified_when_option_target_is_ES3: diag(5048, 1 /* Error */, "Option_0_cannot_be_specified_when_option_target_is_ES3_5048", "Option '{0}' cannot be specified when option 'target' is 'ES3'."),
                    Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided: diag(5051, 1 /* Error */, "Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided_5051", "Option '{0} can only be used when either option '--inlineSourceMap' or option '--sourceMap' is provided."),
                    Option_0_cannot_be_specified_without_specifying_option_1: diag(5052, 1 /* Error */, "Option_0_cannot_be_specified_without_specifying_option_1_5052", "Option '{0}' cannot be specified without specifying option '{1}'."),
                    Option_0_cannot_be_specified_with_option_1: diag(5053, 1 /* Error */, "Option_0_cannot_be_specified_with_option_1_5053", "Option '{0}' cannot be specified with option '{1}'."),
                    A_tsconfig_json_file_is_already_defined_at_Colon_0: diag(5054, 1 /* Error */, "A_tsconfig_json_file_is_already_defined_at_Colon_0_5054", "A 'tsconfig.json' file is already defined at: '{0}'."),
                    Cannot_write_file_0_because_it_would_overwrite_input_file: diag(5055, 1 /* Error */, "Cannot_write_file_0_because_it_would_overwrite_input_file_5055", "Cannot write file '{0}' because it would overwrite input file."),
                    Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files: diag(5056, 1 /* Error */, "Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files_5056", "Cannot write file '{0}' because it would be overwritten by multiple input files."),
                    Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0: diag(5057, 1 /* Error */, "Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0_5057", "Cannot find a tsconfig.json file at the specified directory: '{0}'."),
                    The_specified_path_does_not_exist_Colon_0: diag(5058, 1 /* Error */, "The_specified_path_does_not_exist_Colon_0_5058", "The specified path does not exist: '{0}'."),
                    Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier: diag(5059, 1 /* Error */, "Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier_5059", "Invalid value for '--reactNamespace'. '{0}' is not a valid identifier."),
                    Pattern_0_can_have_at_most_one_Asterisk_character: diag(5061, 1 /* Error */, "Pattern_0_can_have_at_most_one_Asterisk_character_5061", "Pattern '{0}' can have at most one '*' character."),
                    Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character: diag(5062, 1 /* Error */, "Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character_5062", "Substitution '{0}' in pattern '{1}' can have at most one '*' character."),
                    Substitutions_for_pattern_0_should_be_an_array: diag(5063, 1 /* Error */, "Substitutions_for_pattern_0_should_be_an_array_5063", "Substitutions for pattern '{0}' should be an array."),
                    Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2: diag(5064, 1 /* Error */, "Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2_5064", "Substitution '{0}' for pattern '{1}' has incorrect type, expected 'string', got '{2}'."),
                    File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0: diag(5065, 1 /* Error */, "File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildca_5065", "File specification cannot contain a parent directory ('..') that appears after a recursive directory wildcard ('**'): '{0}'."),
                    Substitutions_for_pattern_0_shouldn_t_be_an_empty_array: diag(5066, 1 /* Error */, "Substitutions_for_pattern_0_shouldn_t_be_an_empty_array_5066", "Substitutions for pattern '{0}' shouldn't be an empty array."),
                    Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name: diag(5067, 1 /* Error */, "Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name_5067", "Invalid value for 'jsxFactory'. '{0}' is not a valid identifier or qualified-name."),
                    Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript_files_Learn_more_at_https_Colon_Slash_Slashaka_ms_Slashtsconfig: diag(5068, 1 /* Error */, "Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript__5068", "Adding a tsconfig.json file will help organize projects that contain both TypeScript and JavaScript files. Learn more at https://aka.ms/tsconfig."),
                    Option_0_cannot_be_specified_without_specifying_option_1_or_option_2: diag(5069, 1 /* Error */, "Option_0_cannot_be_specified_without_specifying_option_1_or_option_2_5069", "Option '{0}' cannot be specified without specifying option '{1}' or option '{2}'."),
                    Option_resolveJsonModule_cannot_be_specified_when_moduleResolution_is_set_to_classic: diag(5070, 1 /* Error */, "Option_resolveJsonModule_cannot_be_specified_when_moduleResolution_is_set_to_classic_5070", "Option '--resolveJsonModule' cannot be specified when 'moduleResolution' is set to 'classic'."),
                    Option_resolveJsonModule_can_only_be_specified_when_module_code_generation_is_commonjs_amd_es2015_or_esNext: diag(5071, 1 /* Error */, "Option_resolveJsonModule_can_only_be_specified_when_module_code_generation_is_commonjs_amd_es2015_or_5071", "Option '--resolveJsonModule' can only be specified when module code generation is 'commonjs', 'amd', 'es2015' or 'esNext'."),
                    Unknown_build_option_0: diag(5072, 1 /* Error */, "Unknown_build_option_0_5072", "Unknown build option '{0}'."),
                    Build_option_0_requires_a_value_of_type_1: diag(5073, 1 /* Error */, "Build_option_0_requires_a_value_of_type_1_5073", "Build option '{0}' requires a value of type {1}."),
                    Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBuildInfoFile_is_specified: diag(5074, 1 /* Error */, "Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBui_5074", "Option '--incremental' can only be specified using tsconfig, emitting to single file or when option '--tsBuildInfoFile' is specified."),
                    _0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_constraint_2: diag(5075, 1 /* Error */, "_0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_5075", "'{0}' is assignable to the constraint of type '{1}', but '{1}' could be instantiated with a different subtype of constraint '{2}'."),
                    _0_and_1_operations_cannot_be_mixed_without_parentheses: diag(5076, 1 /* Error */, "_0_and_1_operations_cannot_be_mixed_without_parentheses_5076", "'{0}' and '{1}' operations cannot be mixed without parentheses."),
                    Unknown_build_option_0_Did_you_mean_1: diag(5077, 1 /* Error */, "Unknown_build_option_0_Did_you_mean_1_5077", "Unknown build option '{0}'. Did you mean '{1}'?"),
                    Unknown_watch_option_0: diag(5078, 1 /* Error */, "Unknown_watch_option_0_5078", "Unknown watch option '{0}'."),
                    Unknown_watch_option_0_Did_you_mean_1: diag(5079, 1 /* Error */, "Unknown_watch_option_0_Did_you_mean_1_5079", "Unknown watch option '{0}'. Did you mean '{1}'?"),
                    Watch_option_0_requires_a_value_of_type_1: diag(5080, 1 /* Error */, "Watch_option_0_requires_a_value_of_type_1_5080", "Watch option '{0}' requires a value of type {1}."),
                    Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0: diag(5081, 1 /* Error */, "Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0_5081", "Cannot find a tsconfig.json file at the current directory: {0}."),
                    _0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1: diag(5082, 1 /* Error */, "_0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1_5082", "'{0}' could be instantiated with an arbitrary type which could be unrelated to '{1}'."),
                    Cannot_read_file_0: diag(5083, 1 /* Error */, "Cannot_read_file_0_5083", "Cannot read file '{0}'."),
                    Tuple_members_must_all_have_names_or_all_not_have_names: diag(5084, 1 /* Error */, "Tuple_members_must_all_have_names_or_all_not_have_names_5084", "Tuple members must all have names or all not have names."),
                    A_tuple_member_cannot_be_both_optional_and_rest: diag(5085, 1 /* Error */, "A_tuple_member_cannot_be_both_optional_and_rest_5085", "A tuple member cannot be both optional and rest."),
                    A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type: diag(5086, 1 /* Error */, "A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_c_5086", "A labeled tuple element is declared as optional with a question mark after the name and before the colon, rather than after the type."),
                    A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type: diag(5087, 1 /* Error */, "A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type_5087", "A labeled tuple element is declared as rest with a '...' before the name, rather than before the type."),
                    The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialized_A_type_annotation_is_necessary: diag(5088, 1 /* Error */, "The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialize_5088", "The inferred type of '{0}' references a type with a cyclic structure which cannot be trivially serialized. A type annotation is necessary."),
                    Option_0_cannot_be_specified_when_option_jsx_is_1: diag(5089, 1 /* Error */, "Option_0_cannot_be_specified_when_option_jsx_is_1_5089", "Option '{0}' cannot be specified when option 'jsx' is '{1}'."),
                    Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash: diag(5090, 1 /* Error */, "Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash_5090", "Non-relative paths are not allowed when 'baseUrl' is not set. Did you forget a leading './'?"),
                    Option_preserveConstEnums_cannot_be_disabled_when_0_is_enabled: diag(5091, 1 /* Error */, "Option_preserveConstEnums_cannot_be_disabled_when_0_is_enabled_5091", "Option 'preserveConstEnums' cannot be disabled when '{0}' is enabled."),
                    The_root_value_of_a_0_file_must_be_an_object: diag(5092, 1 /* Error */, "The_root_value_of_a_0_file_must_be_an_object_5092", "The root value of a '{0}' file must be an object."),
                    Compiler_option_0_may_only_be_used_with_build: diag(5093, 1 /* Error */, "Compiler_option_0_may_only_be_used_with_build_5093", "Compiler option '--{0}' may only be used with '--build'."),
                    Compiler_option_0_may_not_be_used_with_build: diag(5094, 1 /* Error */, "Compiler_option_0_may_not_be_used_with_build_5094", "Compiler option '--{0}' may not be used with '--build'."),
                    Option_0_can_only_be_used_when_module_is_set_to_es2015_or_later: diag(5095, 1 /* Error */, "Option_0_can_only_be_used_when_module_is_set_to_es2015_or_later_5095", "Option '{0}' can only be used when 'module' is set to 'es2015' or later."),
                    Option_allowImportingTsExtensions_can_only_be_used_when_either_noEmit_or_emitDeclarationOnly_is_set: diag(5096, 1 /* Error */, "Option_allowImportingTsExtensions_can_only_be_used_when_either_noEmit_or_emitDeclarationOnly_is_set_5096", "Option 'allowImportingTsExtensions' can only be used when either 'noEmit' or 'emitDeclarationOnly' is set."),
                    An_import_path_can_only_end_with_a_0_extension_when_allowImportingTsExtensions_is_enabled: diag(5097, 1 /* Error */, "An_import_path_can_only_end_with_a_0_extension_when_allowImportingTsExtensions_is_enabled_5097", "An import path can only end with a '{0}' extension when 'allowImportingTsExtensions' is enabled."),
                    Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler: diag(5098, 1 /* Error */, "Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler_5098", "Option '{0}' can only be used when 'moduleResolution' is set to 'node16', 'nodenext', or 'bundler'."),
                    Option_0_is_deprecated_and_will_stop_functioning_in_TypeScript_1_Specify_compilerOption_ignoreDeprecations_Colon_2_to_silence_this_error: diag(5101, 1 /* Error */, "Option_0_is_deprecated_and_will_stop_functioning_in_TypeScript_1_Specify_compilerOption_ignoreDeprec_5101", `Option '{0}' is deprecated and will stop functioning in TypeScript {1}. Specify compilerOption '"ignoreDeprecations": "{2}"' to silence this error.`),
                    Option_0_has_been_removed_Please_remove_it_from_your_configuration: diag(5102, 1 /* Error */, "Option_0_has_been_removed_Please_remove_it_from_your_configuration_5102", "Option '{0}' has been removed. Please remove it from your configuration."),
                    Invalid_value_for_ignoreDeprecations: diag(5103, 1 /* Error */, "Invalid_value_for_ignoreDeprecations_5103", "Invalid value for '--ignoreDeprecations'."),
                    Option_0_is_redundant_and_cannot_be_specified_with_option_1: diag(5104, 1 /* Error */, "Option_0_is_redundant_and_cannot_be_specified_with_option_1_5104", "Option '{0}' is redundant and cannot be specified with option '{1}'."),
                    Option_verbatimModuleSyntax_cannot_be_used_when_module_is_set_to_UMD_AMD_or_System: diag(5105, 1 /* Error */, "Option_verbatimModuleSyntax_cannot_be_used_when_module_is_set_to_UMD_AMD_or_System_5105", "Option 'verbatimModuleSyntax' cannot be used when 'module' is set to 'UMD', 'AMD', or 'System'."),
                    Use_0_instead: diag(5106, 3 /* Message */, "Use_0_instead_5106", "Use '{0}' instead."),
                    Option_0_1_is_deprecated_and_will_stop_functioning_in_TypeScript_2_Specify_compilerOption_ignoreDeprecations_Colon_3_to_silence_this_error: diag(5107, 1 /* Error */, "Option_0_1_is_deprecated_and_will_stop_functioning_in_TypeScript_2_Specify_compilerOption_ignoreDepr_5107", `Option '{0}={1}' is deprecated and will stop functioning in TypeScript {2}. Specify compilerOption '"ignoreDeprecations": "{3}"' to silence this error.`),
                    Option_0_1_has_been_removed_Please_remove_it_from_your_configuration: diag(5108, 1 /* Error */, "Option_0_1_has_been_removed_Please_remove_it_from_your_configuration_5108", "Option '{0}={1}' has been removed. Please remove it from your configuration."),
                    Generates_a_sourcemap_for_each_corresponding_d_ts_file: diag(6e3, 3 /* Message */, "Generates_a_sourcemap_for_each_corresponding_d_ts_file_6000", "Generates a sourcemap for each corresponding '.d.ts' file."),
                    Concatenate_and_emit_output_to_single_file: diag(6001, 3 /* Message */, "Concatenate_and_emit_output_to_single_file_6001", "Concatenate and emit output to single file."),
                    Generates_corresponding_d_ts_file: diag(6002, 3 /* Message */, "Generates_corresponding_d_ts_file_6002", "Generates corresponding '.d.ts' file."),
                    Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations: diag(6004, 3 /* Message */, "Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations_6004", "Specify the location where debugger should locate TypeScript files instead of source locations."),
                    Watch_input_files: diag(6005, 3 /* Message */, "Watch_input_files_6005", "Watch input files."),
                    Redirect_output_structure_to_the_directory: diag(6006, 3 /* Message */, "Redirect_output_structure_to_the_directory_6006", "Redirect output structure to the directory."),
                    Do_not_erase_const_enum_declarations_in_generated_code: diag(6007, 3 /* Message */, "Do_not_erase_const_enum_declarations_in_generated_code_6007", "Do not erase const enum declarations in generated code."),
                    Do_not_emit_outputs_if_any_errors_were_reported: diag(6008, 3 /* Message */, "Do_not_emit_outputs_if_any_errors_were_reported_6008", "Do not emit outputs if any errors were reported."),
                    Do_not_emit_comments_to_output: diag(6009, 3 /* Message */, "Do_not_emit_comments_to_output_6009", "Do not emit comments to output."),
                    Do_not_emit_outputs: diag(6010, 3 /* Message */, "Do_not_emit_outputs_6010", "Do not emit outputs."),
                    Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typechecking: diag(6011, 3 /* Message */, "Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typech_6011", "Allow default imports from modules with no default export. This does not affect code emit, just typechecking."),
                    Skip_type_checking_of_declaration_files: diag(6012, 3 /* Message */, "Skip_type_checking_of_declaration_files_6012", "Skip type checking of declaration files."),
                    Do_not_resolve_the_real_path_of_symlinks: diag(6013, 3 /* Message */, "Do_not_resolve_the_real_path_of_symlinks_6013", "Do not resolve the real path of symlinks."),
                    Only_emit_d_ts_declaration_files: diag(6014, 3 /* Message */, "Only_emit_d_ts_declaration_files_6014", "Only emit '.d.ts' declaration files."),
                    Specify_ECMAScript_target_version: diag(6015, 3 /* Message */, "Specify_ECMAScript_target_version_6015", "Specify ECMAScript target version."),
                    Specify_module_code_generation: diag(6016, 3 /* Message */, "Specify_module_code_generation_6016", "Specify module code generation."),
                    Print_this_message: diag(6017, 3 /* Message */, "Print_this_message_6017", "Print this message."),
                    Print_the_compiler_s_version: diag(6019, 3 /* Message */, "Print_the_compiler_s_version_6019", "Print the compiler's version."),
                    Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json: diag(6020, 3 /* Message */, "Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json_6020", "Compile the project given the path to its configuration file, or to a folder with a 'tsconfig.json'."),
                    Syntax_Colon_0: diag(6023, 3 /* Message */, "Syntax_Colon_0_6023", "Syntax: {0}"),
                    options: diag(6024, 3 /* Message */, "options_6024", "options"),
                    file: diag(6025, 3 /* Message */, "file_6025", "file"),
                    Examples_Colon_0: diag(6026, 3 /* Message */, "Examples_Colon_0_6026", "Examples: {0}"),
                    Options_Colon: diag(6027, 3 /* Message */, "Options_Colon_6027", "Options:"),
                    Version_0: diag(6029, 3 /* Message */, "Version_0_6029", "Version {0}"),
                    Insert_command_line_options_and_files_from_a_file: diag(6030, 3 /* Message */, "Insert_command_line_options_and_files_from_a_file_6030", "Insert command line options and files from a file."),
                    Starting_compilation_in_watch_mode: diag(6031, 3 /* Message */, "Starting_compilation_in_watch_mode_6031", "Starting compilation in watch mode..."),
                    File_change_detected_Starting_incremental_compilation: diag(6032, 3 /* Message */, "File_change_detected_Starting_incremental_compilation_6032", "File change detected. Starting incremental compilation..."),
                    KIND: diag(6034, 3 /* Message */, "KIND_6034", "KIND"),
                    FILE: diag(6035, 3 /* Message */, "FILE_6035", "FILE"),
                    VERSION: diag(6036, 3 /* Message */, "VERSION_6036", "VERSION"),
                    LOCATION: diag(6037, 3 /* Message */, "LOCATION_6037", "LOCATION"),
                    DIRECTORY: diag(6038, 3 /* Message */, "DIRECTORY_6038", "DIRECTORY"),
                    STRATEGY: diag(6039, 3 /* Message */, "STRATEGY_6039", "STRATEGY"),
                    FILE_OR_DIRECTORY: diag(6040, 3 /* Message */, "FILE_OR_DIRECTORY_6040", "FILE OR DIRECTORY"),
                    Errors_Files: diag(6041, 3 /* Message */, "Errors_Files_6041", "Errors  Files"),
                    Generates_corresponding_map_file: diag(6043, 3 /* Message */, "Generates_corresponding_map_file_6043", "Generates corresponding '.map' file."),
                    Compiler_option_0_expects_an_argument: diag(6044, 1 /* Error */, "Compiler_option_0_expects_an_argument_6044", "Compiler option '{0}' expects an argument."),
                    Unterminated_quoted_string_in_response_file_0: diag(6045, 1 /* Error */, "Unterminated_quoted_string_in_response_file_0_6045", "Unterminated quoted string in response file '{0}'."),
                    Argument_for_0_option_must_be_Colon_1: diag(6046, 1 /* Error */, "Argument_for_0_option_must_be_Colon_1_6046", "Argument for '{0}' option must be: {1}."),
                    Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1: diag(6048, 1 /* Error */, "Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1_6048", "Locale must be of the form <language> or <language>-<territory>. For example '{0}' or '{1}'."),
                    Unable_to_open_file_0: diag(6050, 1 /* Error */, "Unable_to_open_file_0_6050", "Unable to open file '{0}'."),
                    Corrupted_locale_file_0: diag(6051, 1 /* Error */, "Corrupted_locale_file_0_6051", "Corrupted locale file {0}."),
                    Raise_error_on_expressions_and_declarations_with_an_implied_any_type: diag(6052, 3 /* Message */, "Raise_error_on_expressions_and_declarations_with_an_implied_any_type_6052", "Raise error on expressions and declarations with an implied 'any' type."),
                    File_0_not_found: diag(6053, 1 /* Error */, "File_0_not_found_6053", "File '{0}' not found."),
                    File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1: diag(6054, 1 /* Error */, "File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1_6054", "File '{0}' has an unsupported extension. The only supported extensions are {1}."),
                    Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures: diag(6055, 3 /* Message */, "Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures_6055", "Suppress noImplicitAny errors for indexing objects lacking index signatures."),
                    Do_not_emit_declarations_for_code_that_has_an_internal_annotation: diag(6056, 3 /* Message */, "Do_not_emit_declarations_for_code_that_has_an_internal_annotation_6056", "Do not emit declarations for code that has an '@internal' annotation."),
                    Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir: diag(6058, 3 /* Message */, "Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir_6058", "Specify the root directory of input files. Use to control the output directory structure with --outDir."),
                    File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files: diag(6059, 1 /* Error */, "File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files_6059", "File '{0}' is not under 'rootDir' '{1}'. 'rootDir' is expected to contain all source files."),
                    Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix: diag(6060, 3 /* Message */, "Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix_6060", "Specify the end of line sequence to be used when emitting files: 'CRLF' (dos) or 'LF' (unix)."),
                    NEWLINE: diag(6061, 3 /* Message */, "NEWLINE_6061", "NEWLINE"),
                    Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line: diag(6064, 1 /* Error */, "Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line_6064", "Option '{0}' can only be specified in 'tsconfig.json' file or set to 'null' on command line."),
                    Enables_experimental_support_for_ES7_decorators: diag(6065, 3 /* Message */, "Enables_experimental_support_for_ES7_decorators_6065", "Enables experimental support for ES7 decorators."),
                    Enables_experimental_support_for_emitting_type_metadata_for_decorators: diag(6066, 3 /* Message */, "Enables_experimental_support_for_emitting_type_metadata_for_decorators_6066", "Enables experimental support for emitting type metadata for decorators."),
                    Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file: diag(6070, 3 /* Message */, "Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file_6070", "Initializes a TypeScript project and creates a tsconfig.json file."),
                    Successfully_created_a_tsconfig_json_file: diag(6071, 3 /* Message */, "Successfully_created_a_tsconfig_json_file_6071", "Successfully created a tsconfig.json file."),
                    Suppress_excess_property_checks_for_object_literals: diag(6072, 3 /* Message */, "Suppress_excess_property_checks_for_object_literals_6072", "Suppress excess property checks for object literals."),
                    Stylize_errors_and_messages_using_color_and_context_experimental: diag(6073, 3 /* Message */, "Stylize_errors_and_messages_using_color_and_context_experimental_6073", "Stylize errors and messages using color and context (experimental)."),
                    Do_not_report_errors_on_unused_labels: diag(6074, 3 /* Message */, "Do_not_report_errors_on_unused_labels_6074", "Do not report errors on unused labels."),
                    Report_error_when_not_all_code_paths_in_function_return_a_value: diag(6075, 3 /* Message */, "Report_error_when_not_all_code_paths_in_function_return_a_value_6075", "Report error when not all code paths in function return a value."),
                    Report_errors_for_fallthrough_cases_in_switch_statement: diag(6076, 3 /* Message */, "Report_errors_for_fallthrough_cases_in_switch_statement_6076", "Report errors for fallthrough cases in switch statement."),
                    Do_not_report_errors_on_unreachable_code: diag(6077, 3 /* Message */, "Do_not_report_errors_on_unreachable_code_6077", "Do not report errors on unreachable code."),
                    Disallow_inconsistently_cased_references_to_the_same_file: diag(6078, 3 /* Message */, "Disallow_inconsistently_cased_references_to_the_same_file_6078", "Disallow inconsistently-cased references to the same file."),
                    Specify_library_files_to_be_included_in_the_compilation: diag(6079, 3 /* Message */, "Specify_library_files_to_be_included_in_the_compilation_6079", "Specify library files to be included in the compilation."),
                    Specify_JSX_code_generation: diag(6080, 3 /* Message */, "Specify_JSX_code_generation_6080", "Specify JSX code generation."),
                    File_0_has_an_unsupported_extension_so_skipping_it: diag(6081, 3 /* Message */, "File_0_has_an_unsupported_extension_so_skipping_it_6081", "File '{0}' has an unsupported extension, so skipping it."),
                    Only_amd_and_system_modules_are_supported_alongside_0: diag(6082, 1 /* Error */, "Only_amd_and_system_modules_are_supported_alongside_0_6082", "Only 'amd' and 'system' modules are supported alongside --{0}."),
                    Base_directory_to_resolve_non_absolute_module_names: diag(6083, 3 /* Message */, "Base_directory_to_resolve_non_absolute_module_names_6083", "Base directory to resolve non-absolute module names."),
                    Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react_JSX_emit: diag(6084, 3 /* Message */, "Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react__6084", "[Deprecated] Use '--jsxFactory' instead. Specify the object invoked for createElement when targeting 'react' JSX emit"),
                    Enable_tracing_of_the_name_resolution_process: diag(6085, 3 /* Message */, "Enable_tracing_of_the_name_resolution_process_6085", "Enable tracing of the name resolution process."),
                    Resolving_module_0_from_1: diag(6086, 3 /* Message */, "Resolving_module_0_from_1_6086", "======== Resolving module '{0}' from '{1}'. ========"),
                    Explicitly_specified_module_resolution_kind_Colon_0: diag(6087, 3 /* Message */, "Explicitly_specified_module_resolution_kind_Colon_0_6087", "Explicitly specified module resolution kind: '{0}'."),
                    Module_resolution_kind_is_not_specified_using_0: diag(6088, 3 /* Message */, "Module_resolution_kind_is_not_specified_using_0_6088", "Module resolution kind is not specified, using '{0}'."),
                    Module_name_0_was_successfully_resolved_to_1: diag(6089, 3 /* Message */, "Module_name_0_was_successfully_resolved_to_1_6089", "======== Module name '{0}' was successfully resolved to '{1}'. ========"),
                    Module_name_0_was_not_resolved: diag(6090, 3 /* Message */, "Module_name_0_was_not_resolved_6090", "======== Module name '{0}' was not resolved. ========"),
                    paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0: diag(6091, 3 /* Message */, "paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0_6091", "'paths' option is specified, looking for a pattern to match module name '{0}'."),
                    Module_name_0_matched_pattern_1: diag(6092, 3 /* Message */, "Module_name_0_matched_pattern_1_6092", "Module name '{0}', matched pattern '{1}'."),
                    Trying_substitution_0_candidate_module_location_Colon_1: diag(6093, 3 /* Message */, "Trying_substitution_0_candidate_module_location_Colon_1_6093", "Trying substitution '{0}', candidate module location: '{1}'."),
                    Resolving_module_name_0_relative_to_base_url_1_2: diag(6094, 3 /* Message */, "Resolving_module_name_0_relative_to_base_url_1_2_6094", "Resolving module name '{0}' relative to base url '{1}' - '{2}'."),
                    Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_types_Colon_1: diag(6095, 3 /* Message */, "Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_types_Colon_1_6095", "Loading module as file / folder, candidate module location '{0}', target file types: {1}."),
                    File_0_does_not_exist: diag(6096, 3 /* Message */, "File_0_does_not_exist_6096", "File '{0}' does not exist."),
                    File_0_exists_use_it_as_a_name_resolution_result: diag(6097, 3 /* Message */, "File_0_exists_use_it_as_a_name_resolution_result_6097", "File '{0}' exists - use it as a name resolution result."),
                    Loading_module_0_from_node_modules_folder_target_file_types_Colon_1: diag(6098, 3 /* Message */, "Loading_module_0_from_node_modules_folder_target_file_types_Colon_1_6098", "Loading module '{0}' from 'node_modules' folder, target file types: {1}."),
                    Found_package_json_at_0: diag(6099, 3 /* Message */, "Found_package_json_at_0_6099", "Found 'package.json' at '{0}'."),
                    package_json_does_not_have_a_0_field: diag(6100, 3 /* Message */, "package_json_does_not_have_a_0_field_6100", "'package.json' does not have a '{0}' field."),
                    package_json_has_0_field_1_that_references_2: diag(6101, 3 /* Message */, "package_json_has_0_field_1_that_references_2_6101", "'package.json' has '{0}' field '{1}' that references '{2}'."),
                    Allow_javascript_files_to_be_compiled: diag(6102, 3 /* Message */, "Allow_javascript_files_to_be_compiled_6102", "Allow javascript files to be compiled."),
                    Checking_if_0_is_the_longest_matching_prefix_for_1_2: diag(6104, 3 /* Message */, "Checking_if_0_is_the_longest_matching_prefix_for_1_2_6104", "Checking if '{0}' is the longest matching prefix for '{1}' - '{2}'."),
                    Expected_type_of_0_field_in_package_json_to_be_1_got_2: diag(6105, 3 /* Message */, "Expected_type_of_0_field_in_package_json_to_be_1_got_2_6105", "Expected type of '{0}' field in 'package.json' to be '{1}', got '{2}'."),
                    baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1: diag(6106, 3 /* Message */, "baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1_6106", "'baseUrl' option is set to '{0}', using this value to resolve non-relative module name '{1}'."),
                    rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0: diag(6107, 3 /* Message */, "rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0_6107", "'rootDirs' option is set, using it to resolve relative module name '{0}'."),
                    Longest_matching_prefix_for_0_is_1: diag(6108, 3 /* Message */, "Longest_matching_prefix_for_0_is_1_6108", "Longest matching prefix for '{0}' is '{1}'."),
                    Loading_0_from_the_root_dir_1_candidate_location_2: diag(6109, 3 /* Message */, "Loading_0_from_the_root_dir_1_candidate_location_2_6109", "Loading '{0}' from the root dir '{1}', candidate location '{2}'."),
                    Trying_other_entries_in_rootDirs: diag(6110, 3 /* Message */, "Trying_other_entries_in_rootDirs_6110", "Trying other entries in 'rootDirs'."),
                    Module_resolution_using_rootDirs_has_failed: diag(6111, 3 /* Message */, "Module_resolution_using_rootDirs_has_failed_6111", "Module resolution using 'rootDirs' has failed."),
                    Do_not_emit_use_strict_directives_in_module_output: diag(6112, 3 /* Message */, "Do_not_emit_use_strict_directives_in_module_output_6112", "Do not emit 'use strict' directives in module output."),
                    Enable_strict_null_checks: diag(6113, 3 /* Message */, "Enable_strict_null_checks_6113", "Enable strict null checks."),
                    Unknown_option_excludes_Did_you_mean_exclude: diag(6114, 1 /* Error */, "Unknown_option_excludes_Did_you_mean_exclude_6114", "Unknown option 'excludes'. Did you mean 'exclude'?"),
                    Raise_error_on_this_expressions_with_an_implied_any_type: diag(6115, 3 /* Message */, "Raise_error_on_this_expressions_with_an_implied_any_type_6115", "Raise error on 'this' expressions with an implied 'any' type."),
                    Resolving_type_reference_directive_0_containing_file_1_root_directory_2: diag(6116, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_1_root_directory_2_6116", "======== Resolving type reference directive '{0}', containing file '{1}', root directory '{2}'. ========"),
                    Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2: diag(6119, 3 /* Message */, "Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2_6119", "======== Type reference directive '{0}' was successfully resolved to '{1}', primary: {2}. ========"),
                    Type_reference_directive_0_was_not_resolved: diag(6120, 3 /* Message */, "Type_reference_directive_0_was_not_resolved_6120", "======== Type reference directive '{0}' was not resolved. ========"),
                    Resolving_with_primary_search_path_0: diag(6121, 3 /* Message */, "Resolving_with_primary_search_path_0_6121", "Resolving with primary search path '{0}'."),
                    Root_directory_cannot_be_determined_skipping_primary_search_paths: diag(6122, 3 /* Message */, "Root_directory_cannot_be_determined_skipping_primary_search_paths_6122", "Root directory cannot be determined, skipping primary search paths."),
                    Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set: diag(6123, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set_6123", "======== Resolving type reference directive '{0}', containing file '{1}', root directory not set. ========"),
                    Type_declaration_files_to_be_included_in_compilation: diag(6124, 3 /* Message */, "Type_declaration_files_to_be_included_in_compilation_6124", "Type declaration files to be included in compilation."),
                    Looking_up_in_node_modules_folder_initial_location_0: diag(6125, 3 /* Message */, "Looking_up_in_node_modules_folder_initial_location_0_6125", "Looking up in 'node_modules' folder, initial location '{0}'."),
                    Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_modules_folder: diag(6126, 3 /* Message */, "Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_mod_6126", "Containing file is not specified and root directory cannot be determined, skipping lookup in 'node_modules' folder."),
                    Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1: diag(6127, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1_6127", "======== Resolving type reference directive '{0}', containing file not set, root directory '{1}'. ========"),
                    Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set: diag(6128, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set_6128", "======== Resolving type reference directive '{0}', containing file not set, root directory not set. ========"),
                    Resolving_real_path_for_0_result_1: diag(6130, 3 /* Message */, "Resolving_real_path_for_0_result_1_6130", "Resolving real path for '{0}', result '{1}'."),
                    Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system: diag(6131, 1 /* Error */, "Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system_6131", "Cannot compile modules using option '{0}' unless the '--module' flag is 'amd' or 'system'."),
                    File_name_0_has_a_1_extension_stripping_it: diag(6132, 3 /* Message */, "File_name_0_has_a_1_extension_stripping_it_6132", "File name '{0}' has a '{1}' extension - stripping it."),
                    _0_is_declared_but_its_value_is_never_read: diag(6133, 1 /* Error */, "_0_is_declared_but_its_value_is_never_read_6133", "'{0}' is declared but its value is never read.", 
                    /*reportsUnnecessary*/
                    true),
                    Report_errors_on_unused_locals: diag(6134, 3 /* Message */, "Report_errors_on_unused_locals_6134", "Report errors on unused locals."),
                    Report_errors_on_unused_parameters: diag(6135, 3 /* Message */, "Report_errors_on_unused_parameters_6135", "Report errors on unused parameters."),
                    The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files: diag(6136, 3 /* Message */, "The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files_6136", "The maximum dependency depth to search under node_modules and load JavaScript files."),
                    Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1: diag(6137, 1 /* Error */, "Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1_6137", "Cannot import type declaration files. Consider importing '{0}' instead of '{1}'."),
                    Property_0_is_declared_but_its_value_is_never_read: diag(6138, 1 /* Error */, "Property_0_is_declared_but_its_value_is_never_read_6138", "Property '{0}' is declared but its value is never read.", 
                    /*reportsUnnecessary*/
                    true),
                    Import_emit_helpers_from_tslib: diag(6139, 3 /* Message */, "Import_emit_helpers_from_tslib_6139", "Import emit helpers from 'tslib'."),
                    Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using_cache_location_2: diag(6140, 1 /* Error */, "Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using__6140", "Auto discovery for typings is enabled in project '{0}'. Running extra resolution pass for module '{1}' using cache location '{2}'."),
                    Parse_in_strict_mode_and_emit_use_strict_for_each_source_file: diag(6141, 3 /* Message */, "Parse_in_strict_mode_and_emit_use_strict_for_each_source_file_6141", 'Parse in strict mode and emit "use strict" for each source file.'),
                    Module_0_was_resolved_to_1_but_jsx_is_not_set: diag(6142, 1 /* Error */, "Module_0_was_resolved_to_1_but_jsx_is_not_set_6142", "Module '{0}' was resolved to '{1}', but '--jsx' is not set."),
                    Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1: diag(6144, 3 /* Message */, "Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1_6144", "Module '{0}' was resolved as locally declared ambient module in file '{1}'."),
                    Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified: diag(6145, 3 /* Message */, "Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified_6145", "Module '{0}' was resolved as ambient module declared in '{1}' since this file was not modified."),
                    Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h: diag(6146, 3 /* Message */, "Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h_6146", "Specify the JSX factory function to use when targeting 'react' JSX emit, e.g. 'React.createElement' or 'h'."),
                    Resolution_for_module_0_was_found_in_cache_from_location_1: diag(6147, 3 /* Message */, "Resolution_for_module_0_was_found_in_cache_from_location_1_6147", "Resolution for module '{0}' was found in cache from location '{1}'."),
                    Directory_0_does_not_exist_skipping_all_lookups_in_it: diag(6148, 3 /* Message */, "Directory_0_does_not_exist_skipping_all_lookups_in_it_6148", "Directory '{0}' does not exist, skipping all lookups in it."),
                    Show_diagnostic_information: diag(6149, 3 /* Message */, "Show_diagnostic_information_6149", "Show diagnostic information."),
                    Show_verbose_diagnostic_information: diag(6150, 3 /* Message */, "Show_verbose_diagnostic_information_6150", "Show verbose diagnostic information."),
                    Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file: diag(6151, 3 /* Message */, "Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file_6151", "Emit a single file with source maps instead of having a separate file."),
                    Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap_to_be_set: diag(6152, 3 /* Message */, "Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap__6152", "Emit the source alongside the sourcemaps within a single file; requires '--inlineSourceMap' or '--sourceMap' to be set."),
                    Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule: diag(6153, 3 /* Message */, "Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule_6153", "Transpile each file as a separate module (similar to 'ts.transpileModule')."),
                    Print_names_of_generated_files_part_of_the_compilation: diag(6154, 3 /* Message */, "Print_names_of_generated_files_part_of_the_compilation_6154", "Print names of generated files part of the compilation."),
                    Print_names_of_files_part_of_the_compilation: diag(6155, 3 /* Message */, "Print_names_of_files_part_of_the_compilation_6155", "Print names of files part of the compilation."),
                    The_locale_used_when_displaying_messages_to_the_user_e_g_en_us: diag(6156, 3 /* Message */, "The_locale_used_when_displaying_messages_to_the_user_e_g_en_us_6156", "The locale used when displaying messages to the user (e.g. 'en-us')"),
                    Do_not_generate_custom_helper_functions_like_extends_in_compiled_output: diag(6157, 3 /* Message */, "Do_not_generate_custom_helper_functions_like_extends_in_compiled_output_6157", "Do not generate custom helper functions like '__extends' in compiled output."),
                    Do_not_include_the_default_library_file_lib_d_ts: diag(6158, 3 /* Message */, "Do_not_include_the_default_library_file_lib_d_ts_6158", "Do not include the default library file (lib.d.ts)."),
                    Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files: diag(6159, 3 /* Message */, "Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files_6159", "Do not add triple-slash references or imported modules to the list of compiled files."),
                    Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files: diag(6160, 3 /* Message */, "Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files_6160", "[Deprecated] Use '--skipLibCheck' instead. Skip type checking of default library declaration files."),
                    List_of_folders_to_include_type_definitions_from: diag(6161, 3 /* Message */, "List_of_folders_to_include_type_definitions_from_6161", "List of folders to include type definitions from."),
                    Disable_size_limitations_on_JavaScript_projects: diag(6162, 3 /* Message */, "Disable_size_limitations_on_JavaScript_projects_6162", "Disable size limitations on JavaScript projects."),
                    The_character_set_of_the_input_files: diag(6163, 3 /* Message */, "The_character_set_of_the_input_files_6163", "The character set of the input files."),
                    Do_not_truncate_error_messages: diag(6165, 3 /* Message */, "Do_not_truncate_error_messages_6165", "Do not truncate error messages."),
                    Output_directory_for_generated_declaration_files: diag(6166, 3 /* Message */, "Output_directory_for_generated_declaration_files_6166", "Output directory for generated declaration files."),
                    A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl: diag(6167, 3 /* Message */, "A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl_6167", "A series of entries which re-map imports to lookup locations relative to the 'baseUrl'."),
                    List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime: diag(6168, 3 /* Message */, "List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime_6168", "List of root folders whose combined content represents the structure of the project at runtime."),
                    Show_all_compiler_options: diag(6169, 3 /* Message */, "Show_all_compiler_options_6169", "Show all compiler options."),
                    Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file: diag(6170, 3 /* Message */, "Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file_6170", "[Deprecated] Use '--outFile' instead. Concatenate and emit output to single file"),
                    Command_line_Options: diag(6171, 3 /* Message */, "Command_line_Options_6171", "Command-line Options"),
                    Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_or_ES3: diag(6179, 3 /* Message */, "Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_or_ES3_6179", "Provide full support for iterables in 'for-of', spread, and destructuring when targeting 'ES5' or 'ES3'."),
                    Enable_all_strict_type_checking_options: diag(6180, 3 /* Message */, "Enable_all_strict_type_checking_options_6180", "Enable all strict type-checking options."),
                    Scoped_package_detected_looking_in_0: diag(6182, 3 /* Message */, "Scoped_package_detected_looking_in_0_6182", "Scoped package detected, looking in '{0}'"),
                    Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2: diag(6183, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_6183", "Reusing resolution of module '{0}' from '{1}' of old program, it was successfully resolved to '{2}'."),
                    Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3: diag(6184, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package__6184", "Reusing resolution of module '{0}' from '{1}' of old program, it was successfully resolved to '{2}' with Package ID '{3}'."),
                    Enable_strict_checking_of_function_types: diag(6186, 3 /* Message */, "Enable_strict_checking_of_function_types_6186", "Enable strict checking of function types."),
                    Enable_strict_checking_of_property_initialization_in_classes: diag(6187, 3 /* Message */, "Enable_strict_checking_of_property_initialization_in_classes_6187", "Enable strict checking of property initialization in classes."),
                    Numeric_separators_are_not_allowed_here: diag(6188, 1 /* Error */, "Numeric_separators_are_not_allowed_here_6188", "Numeric separators are not allowed here."),
                    Multiple_consecutive_numeric_separators_are_not_permitted: diag(6189, 1 /* Error */, "Multiple_consecutive_numeric_separators_are_not_permitted_6189", "Multiple consecutive numeric separators are not permitted."),
                    Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen: diag(6191, 3 /* Message */, "Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen_6191", "Whether to keep outdated console output in watch mode instead of clearing the screen."),
                    All_imports_in_import_declaration_are_unused: diag(6192, 1 /* Error */, "All_imports_in_import_declaration_are_unused_6192", "All imports in import declaration are unused.", 
                    /*reportsUnnecessary*/
                    true),
                    Found_1_error_Watching_for_file_changes: diag(6193, 3 /* Message */, "Found_1_error_Watching_for_file_changes_6193", "Found 1 error. Watching for file changes."),
                    Found_0_errors_Watching_for_file_changes: diag(6194, 3 /* Message */, "Found_0_errors_Watching_for_file_changes_6194", "Found {0} errors. Watching for file changes."),
                    Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols: diag(6195, 3 /* Message */, "Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols_6195", "Resolve 'keyof' to string valued property names only (no numbers or symbols)."),
                    _0_is_declared_but_never_used: diag(6196, 1 /* Error */, "_0_is_declared_but_never_used_6196", "'{0}' is declared but never used.", 
                    /*reportsUnnecessary*/
                    true),
                    Include_modules_imported_with_json_extension: diag(6197, 3 /* Message */, "Include_modules_imported_with_json_extension_6197", "Include modules imported with '.json' extension"),
                    All_destructured_elements_are_unused: diag(6198, 1 /* Error */, "All_destructured_elements_are_unused_6198", "All destructured elements are unused.", 
                    /*reportsUnnecessary*/
                    true),
                    All_variables_are_unused: diag(6199, 1 /* Error */, "All_variables_are_unused_6199", "All variables are unused.", 
                    /*reportsUnnecessary*/
                    true),
                    Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0: diag(6200, 1 /* Error */, "Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0_6200", "Definitions of the following identifiers conflict with those in another file: {0}"),
                    Conflicts_are_in_this_file: diag(6201, 3 /* Message */, "Conflicts_are_in_this_file_6201", "Conflicts are in this file."),
                    Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0: diag(6202, 1 /* Error */, "Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0_6202", "Project references may not form a circular graph. Cycle detected: {0}"),
                    _0_was_also_declared_here: diag(6203, 3 /* Message */, "_0_was_also_declared_here_6203", "'{0}' was also declared here."),
                    and_here: diag(6204, 3 /* Message */, "and_here_6204", "and here."),
                    All_type_parameters_are_unused: diag(6205, 1 /* Error */, "All_type_parameters_are_unused_6205", "All type parameters are unused."),
                    package_json_has_a_typesVersions_field_with_version_specific_path_mappings: diag(6206, 3 /* Message */, "package_json_has_a_typesVersions_field_with_version_specific_path_mappings_6206", "'package.json' has a 'typesVersions' field with version-specific path mappings."),
                    package_json_does_not_have_a_typesVersions_entry_that_matches_version_0: diag(6207, 3 /* Message */, "package_json_does_not_have_a_typesVersions_entry_that_matches_version_0_6207", "'package.json' does not have a 'typesVersions' entry that matches version '{0}'."),
                    package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2: diag(6208, 3 /* Message */, "package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_ma_6208", "'package.json' has a 'typesVersions' entry '{0}' that matches compiler version '{1}', looking for a pattern to match module name '{2}'."),
                    package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range: diag(6209, 3 /* Message */, "package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range_6209", "'package.json' has a 'typesVersions' entry '{0}' that is not a valid semver range."),
                    An_argument_for_0_was_not_provided: diag(6210, 3 /* Message */, "An_argument_for_0_was_not_provided_6210", "An argument for '{0}' was not provided."),
                    An_argument_matching_this_binding_pattern_was_not_provided: diag(6211, 3 /* Message */, "An_argument_matching_this_binding_pattern_was_not_provided_6211", "An argument matching this binding pattern was not provided."),
                    Did_you_mean_to_call_this_expression: diag(6212, 3 /* Message */, "Did_you_mean_to_call_this_expression_6212", "Did you mean to call this expression?"),
                    Did_you_mean_to_use_new_with_this_expression: diag(6213, 3 /* Message */, "Did_you_mean_to_use_new_with_this_expression_6213", "Did you mean to use 'new' with this expression?"),
                    Enable_strict_bind_call_and_apply_methods_on_functions: diag(6214, 3 /* Message */, "Enable_strict_bind_call_and_apply_methods_on_functions_6214", "Enable strict 'bind', 'call', and 'apply' methods on functions."),
                    Using_compiler_options_of_project_reference_redirect_0: diag(6215, 3 /* Message */, "Using_compiler_options_of_project_reference_redirect_0_6215", "Using compiler options of project reference redirect '{0}'."),
                    Found_1_error: diag(6216, 3 /* Message */, "Found_1_error_6216", "Found 1 error."),
                    Found_0_errors: diag(6217, 3 /* Message */, "Found_0_errors_6217", "Found {0} errors."),
                    Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2: diag(6218, 3 /* Message */, "Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2_6218", "======== Module name '{0}' was successfully resolved to '{1}' with Package ID '{2}'. ========"),
                    Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3: diag(6219, 3 /* Message */, "Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3_6219", "======== Type reference directive '{0}' was successfully resolved to '{1}' with Package ID '{2}', primary: {3}. ========"),
                    package_json_had_a_falsy_0_field: diag(6220, 3 /* Message */, "package_json_had_a_falsy_0_field_6220", "'package.json' had a falsy '{0}' field."),
                    Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects: diag(6221, 3 /* Message */, "Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects_6221", "Disable use of source files instead of declaration files from referenced projects."),
                    Emit_class_fields_with_Define_instead_of_Set: diag(6222, 3 /* Message */, "Emit_class_fields_with_Define_instead_of_Set_6222", "Emit class fields with Define instead of Set."),
                    Generates_a_CPU_profile: diag(6223, 3 /* Message */, "Generates_a_CPU_profile_6223", "Generates a CPU profile."),
                    Disable_solution_searching_for_this_project: diag(6224, 3 /* Message */, "Disable_solution_searching_for_this_project_6224", "Disable solution searching for this project."),
                    Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling_UseFsEvents_UseFsEventsOnParentDirectory: diag(6225, 3 /* Message */, "Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_Dynami_6225", "Specify strategy for watching file: 'FixedPollingInterval' (default), 'PriorityPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling', 'UseFsEvents', 'UseFsEventsOnParentDirectory'."),
                    Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively_Colon_UseFsEvents_default_FixedPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling: diag(6226, 3 /* Message */, "Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively__6226", "Specify strategy for watching directory on platforms that don't support recursive watching natively: 'UseFsEvents' (default), 'FixedPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling'."),
                    Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_FixedInterval_default_PriorityInterval_DynamicPriority_FixedChunkSize: diag(6227, 3 /* Message */, "Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_6227", "Specify strategy for creating a polling watch when it fails to create using file system events: 'FixedInterval' (default), 'PriorityInterval', 'DynamicPriority', 'FixedChunkSize'."),
                    Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3: diag(6229, 1 /* Error */, "Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3_6229", "Tag '{0}' expects at least '{1}' arguments, but the JSX factory '{2}' provides at most '{3}'."),
                    Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line: diag(6230, 1 /* Error */, "Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line_6230", "Option '{0}' can only be specified in 'tsconfig.json' file or set to 'false' or 'null' on command line."),
                    Could_not_resolve_the_path_0_with_the_extensions_Colon_1: diag(6231, 1 /* Error */, "Could_not_resolve_the_path_0_with_the_extensions_Colon_1_6231", "Could not resolve the path '{0}' with the extensions: {1}."),
                    Declaration_augments_declaration_in_another_file_This_cannot_be_serialized: diag(6232, 1 /* Error */, "Declaration_augments_declaration_in_another_file_This_cannot_be_serialized_6232", "Declaration augments declaration in another file. This cannot be serialized."),
                    This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_file: diag(6233, 1 /* Error */, "This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_fil_6233", "This is the declaration being augmented. Consider moving the augmenting declaration into the same file."),
                    This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without: diag(6234, 1 /* Error */, "This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without_6234", "This expression is not callable because it is a 'get' accessor. Did you mean to use it without '()'?"),
                    Disable_loading_referenced_projects: diag(6235, 3 /* Message */, "Disable_loading_referenced_projects_6235", "Disable loading referenced projects."),
                    Arguments_for_the_rest_parameter_0_were_not_provided: diag(6236, 1 /* Error */, "Arguments_for_the_rest_parameter_0_were_not_provided_6236", "Arguments for the rest parameter '{0}' were not provided."),
                    Generates_an_event_trace_and_a_list_of_types: diag(6237, 3 /* Message */, "Generates_an_event_trace_and_a_list_of_types_6237", "Generates an event trace and a list of types."),
                    Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react: diag(6238, 1 /* Error */, "Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react_6238", "Specify the module specifier to be used to import the 'jsx' and 'jsxs' factory functions from. eg, react"),
                    File_0_exists_according_to_earlier_cached_lookups: diag(6239, 3 /* Message */, "File_0_exists_according_to_earlier_cached_lookups_6239", "File '{0}' exists according to earlier cached lookups."),
                    File_0_does_not_exist_according_to_earlier_cached_lookups: diag(6240, 3 /* Message */, "File_0_does_not_exist_according_to_earlier_cached_lookups_6240", "File '{0}' does not exist according to earlier cached lookups."),
                    Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1: diag(6241, 3 /* Message */, "Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1_6241", "Resolution for type reference directive '{0}' was found in cache from location '{1}'."),
                    Resolving_type_reference_directive_0_containing_file_1: diag(6242, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_1_6242", "======== Resolving type reference directive '{0}', containing file '{1}'. ========"),
                    Interpret_optional_property_types_as_written_rather_than_adding_undefined: diag(6243, 3 /* Message */, "Interpret_optional_property_types_as_written_rather_than_adding_undefined_6243", "Interpret optional property types as written, rather than adding 'undefined'."),
                    Modules: diag(6244, 3 /* Message */, "Modules_6244", "Modules"),
                    File_Management: diag(6245, 3 /* Message */, "File_Management_6245", "File Management"),
                    Emit: diag(6246, 3 /* Message */, "Emit_6246", "Emit"),
                    JavaScript_Support: diag(6247, 3 /* Message */, "JavaScript_Support_6247", "JavaScript Support"),
                    Type_Checking: diag(6248, 3 /* Message */, "Type_Checking_6248", "Type Checking"),
                    Editor_Support: diag(6249, 3 /* Message */, "Editor_Support_6249", "Editor Support"),
                    Watch_and_Build_Modes: diag(6250, 3 /* Message */, "Watch_and_Build_Modes_6250", "Watch and Build Modes"),
                    Compiler_Diagnostics: diag(6251, 3 /* Message */, "Compiler_Diagnostics_6251", "Compiler Diagnostics"),
                    Interop_Constraints: diag(6252, 3 /* Message */, "Interop_Constraints_6252", "Interop Constraints"),
                    Backwards_Compatibility: diag(6253, 3 /* Message */, "Backwards_Compatibility_6253", "Backwards Compatibility"),
                    Language_and_Environment: diag(6254, 3 /* Message */, "Language_and_Environment_6254", "Language and Environment"),
                    Projects: diag(6255, 3 /* Message */, "Projects_6255", "Projects"),
                    Output_Formatting: diag(6256, 3 /* Message */, "Output_Formatting_6256", "Output Formatting"),
                    Completeness: diag(6257, 3 /* Message */, "Completeness_6257", "Completeness"),
                    _0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file: diag(6258, 1 /* Error */, "_0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file_6258", "'{0}' should be set inside the 'compilerOptions' object of the config json file"),
                    Found_1_error_in_1: diag(6259, 3 /* Message */, "Found_1_error_in_1_6259", "Found 1 error in {1}"),
                    Found_0_errors_in_the_same_file_starting_at_Colon_1: diag(6260, 3 /* Message */, "Found_0_errors_in_the_same_file_starting_at_Colon_1_6260", "Found {0} errors in the same file, starting at: {1}"),
                    Found_0_errors_in_1_files: diag(6261, 3 /* Message */, "Found_0_errors_in_1_files_6261", "Found {0} errors in {1} files."),
                    File_name_0_has_a_1_extension_looking_up_2_instead: diag(6262, 3 /* Message */, "File_name_0_has_a_1_extension_looking_up_2_instead_6262", "File name '{0}' has a '{1}' extension - looking up '{2}' instead."),
                    Module_0_was_resolved_to_1_but_allowArbitraryExtensions_is_not_set: diag(6263, 1 /* Error */, "Module_0_was_resolved_to_1_but_allowArbitraryExtensions_is_not_set_6263", "Module '{0}' was resolved to '{1}', but '--allowArbitraryExtensions' is not set."),
                    Enable_importing_files_with_any_extension_provided_a_declaration_file_is_present: diag(6264, 3 /* Message */, "Enable_importing_files_with_any_extension_provided_a_declaration_file_is_present_6264", "Enable importing files with any extension, provided a declaration file is present."),
                    Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve: diag(6270, 3 /* Message */, "Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve_6270", "Directory '{0}' has no containing package.json scope. Imports will not resolve."),
                    Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1: diag(6271, 3 /* Message */, "Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1_6271", "Import specifier '{0}' does not exist in package.json scope at path '{1}'."),
                    Invalid_import_specifier_0_has_no_possible_resolutions: diag(6272, 3 /* Message */, "Invalid_import_specifier_0_has_no_possible_resolutions_6272", "Invalid import specifier '{0}' has no possible resolutions."),
                    package_json_scope_0_has_no_imports_defined: diag(6273, 3 /* Message */, "package_json_scope_0_has_no_imports_defined_6273", "package.json scope '{0}' has no imports defined."),
                    package_json_scope_0_explicitly_maps_specifier_1_to_null: diag(6274, 3 /* Message */, "package_json_scope_0_explicitly_maps_specifier_1_to_null_6274", "package.json scope '{0}' explicitly maps specifier '{1}' to null."),
                    package_json_scope_0_has_invalid_type_for_target_of_specifier_1: diag(6275, 3 /* Message */, "package_json_scope_0_has_invalid_type_for_target_of_specifier_1_6275", "package.json scope '{0}' has invalid type for target of specifier '{1}'"),
                    Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1: diag(6276, 3 /* Message */, "Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1_6276", "Export specifier '{0}' does not exist in package.json scope at path '{1}'."),
                    Resolution_of_non_relative_name_failed_trying_with_modern_Node_resolution_features_disabled_to_see_if_npm_library_needs_configuration_update: diag(6277, 3 /* Message */, "Resolution_of_non_relative_name_failed_trying_with_modern_Node_resolution_features_disabled_to_see_i_6277", "Resolution of non-relative name failed; trying with modern Node resolution features disabled to see if npm library needs configuration update."),
                    There_are_types_at_0_but_this_result_could_not_be_resolved_when_respecting_package_json_exports_The_1_library_may_need_to_update_its_package_json_or_typings: diag(6278, 3 /* Message */, "There_are_types_at_0_but_this_result_could_not_be_resolved_when_respecting_package_json_exports_The__6278", `There are types at '{0}', but this result could not be resolved when respecting package.json "exports". The '{1}' library may need to update its package.json or typings.`),
                    Enable_project_compilation: diag(6302, 3 /* Message */, "Enable_project_compilation_6302", "Enable project compilation"),
                    Composite_projects_may_not_disable_declaration_emit: diag(6304, 1 /* Error */, "Composite_projects_may_not_disable_declaration_emit_6304", "Composite projects may not disable declaration emit."),
                    Output_file_0_has_not_been_built_from_source_file_1: diag(6305, 1 /* Error */, "Output_file_0_has_not_been_built_from_source_file_1_6305", "Output file '{0}' has not been built from source file '{1}'."),
                    Referenced_project_0_must_have_setting_composite_Colon_true: diag(6306, 1 /* Error */, "Referenced_project_0_must_have_setting_composite_Colon_true_6306", `Referenced project '{0}' must have setting "composite": true.`),
                    File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_include_pattern: diag(6307, 1 /* Error */, "File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_includ_6307", "File '{0}' is not listed within the file list of project '{1}'. Projects must list all files or use an 'include' pattern."),
                    Cannot_prepend_project_0_because_it_does_not_have_outFile_set: diag(6308, 1 /* Error */, "Cannot_prepend_project_0_because_it_does_not_have_outFile_set_6308", "Cannot prepend project '{0}' because it does not have 'outFile' set"),
                    Output_file_0_from_project_1_does_not_exist: diag(6309, 1 /* Error */, "Output_file_0_from_project_1_does_not_exist_6309", "Output file '{0}' from project '{1}' does not exist"),
                    Referenced_project_0_may_not_disable_emit: diag(6310, 1 /* Error */, "Referenced_project_0_may_not_disable_emit_6310", "Referenced project '{0}' may not disable emit."),
                    Project_0_is_out_of_date_because_output_1_is_older_than_input_2: diag(6350, 3 /* Message */, "Project_0_is_out_of_date_because_output_1_is_older_than_input_2_6350", "Project '{0}' is out of date because output '{1}' is older than input '{2}'"),
                    Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2: diag(6351, 3 /* Message */, "Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2_6351", "Project '{0}' is up to date because newest input '{1}' is older than output '{2}'"),
                    Project_0_is_out_of_date_because_output_file_1_does_not_exist: diag(6352, 3 /* Message */, "Project_0_is_out_of_date_because_output_file_1_does_not_exist_6352", "Project '{0}' is out of date because output file '{1}' does not exist"),
                    Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date: diag(6353, 3 /* Message */, "Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date_6353", "Project '{0}' is out of date because its dependency '{1}' is out of date"),
                    Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies: diag(6354, 3 /* Message */, "Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies_6354", "Project '{0}' is up to date with .d.ts files from its dependencies"),
                    Projects_in_this_build_Colon_0: diag(6355, 3 /* Message */, "Projects_in_this_build_Colon_0_6355", "Projects in this build: {0}"),
                    A_non_dry_build_would_delete_the_following_files_Colon_0: diag(6356, 3 /* Message */, "A_non_dry_build_would_delete_the_following_files_Colon_0_6356", "A non-dry build would delete the following files: {0}"),
                    A_non_dry_build_would_build_project_0: diag(6357, 3 /* Message */, "A_non_dry_build_would_build_project_0_6357", "A non-dry build would build project '{0}'"),
                    Building_project_0: diag(6358, 3 /* Message */, "Building_project_0_6358", "Building project '{0}'..."),
                    Updating_output_timestamps_of_project_0: diag(6359, 3 /* Message */, "Updating_output_timestamps_of_project_0_6359", "Updating output timestamps of project '{0}'..."),
                    Project_0_is_up_to_date: diag(6361, 3 /* Message */, "Project_0_is_up_to_date_6361", "Project '{0}' is up to date"),
                    Skipping_build_of_project_0_because_its_dependency_1_has_errors: diag(6362, 3 /* Message */, "Skipping_build_of_project_0_because_its_dependency_1_has_errors_6362", "Skipping build of project '{0}' because its dependency '{1}' has errors"),
                    Project_0_can_t_be_built_because_its_dependency_1_has_errors: diag(6363, 3 /* Message */, "Project_0_can_t_be_built_because_its_dependency_1_has_errors_6363", "Project '{0}' can't be built because its dependency '{1}' has errors"),
                    Build_one_or_more_projects_and_their_dependencies_if_out_of_date: diag(6364, 3 /* Message */, "Build_one_or_more_projects_and_their_dependencies_if_out_of_date_6364", "Build one or more projects and their dependencies, if out of date"),
                    Delete_the_outputs_of_all_projects: diag(6365, 3 /* Message */, "Delete_the_outputs_of_all_projects_6365", "Delete the outputs of all projects."),
                    Show_what_would_be_built_or_deleted_if_specified_with_clean: diag(6367, 3 /* Message */, "Show_what_would_be_built_or_deleted_if_specified_with_clean_6367", "Show what would be built (or deleted, if specified with '--clean')"),
                    Option_build_must_be_the_first_command_line_argument: diag(6369, 1 /* Error */, "Option_build_must_be_the_first_command_line_argument_6369", "Option '--build' must be the first command line argument."),
                    Options_0_and_1_cannot_be_combined: diag(6370, 1 /* Error */, "Options_0_and_1_cannot_be_combined_6370", "Options '{0}' and '{1}' cannot be combined."),
                    Updating_unchanged_output_timestamps_of_project_0: diag(6371, 3 /* Message */, "Updating_unchanged_output_timestamps_of_project_0_6371", "Updating unchanged output timestamps of project '{0}'..."),
                    Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed: diag(6372, 3 /* Message */, "Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed_6372", "Project '{0}' is out of date because output of its dependency '{1}' has changed"),
                    Updating_output_of_project_0: diag(6373, 3 /* Message */, "Updating_output_of_project_0_6373", "Updating output of project '{0}'..."),
                    A_non_dry_build_would_update_timestamps_for_output_of_project_0: diag(6374, 3 /* Message */, "A_non_dry_build_would_update_timestamps_for_output_of_project_0_6374", "A non-dry build would update timestamps for output of project '{0}'"),
                    A_non_dry_build_would_update_output_of_project_0: diag(6375, 3 /* Message */, "A_non_dry_build_would_update_output_of_project_0_6375", "A non-dry build would update output of project '{0}'"),
                    Cannot_update_output_of_project_0_because_there_was_error_reading_file_1: diag(6376, 3 /* Message */, "Cannot_update_output_of_project_0_because_there_was_error_reading_file_1_6376", "Cannot update output of project '{0}' because there was error reading file '{1}'"),
                    Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1: diag(6377, 1 /* Error */, "Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1_6377", "Cannot write file '{0}' because it will overwrite '.tsbuildinfo' file generated by referenced project '{1}'"),
                    Composite_projects_may_not_disable_incremental_compilation: diag(6379, 1 /* Error */, "Composite_projects_may_not_disable_incremental_compilation_6379", "Composite projects may not disable incremental compilation."),
                    Specify_file_to_store_incremental_compilation_information: diag(6380, 3 /* Message */, "Specify_file_to_store_incremental_compilation_information_6380", "Specify file to store incremental compilation information"),
                    Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_current_version_2: diag(6381, 3 /* Message */, "Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_curren_6381", "Project '{0}' is out of date because output for it was generated with version '{1}' that differs with current version '{2}'"),
                    Skipping_build_of_project_0_because_its_dependency_1_was_not_built: diag(6382, 3 /* Message */, "Skipping_build_of_project_0_because_its_dependency_1_was_not_built_6382", "Skipping build of project '{0}' because its dependency '{1}' was not built"),
                    Project_0_can_t_be_built_because_its_dependency_1_was_not_built: diag(6383, 3 /* Message */, "Project_0_can_t_be_built_because_its_dependency_1_was_not_built_6383", "Project '{0}' can't be built because its dependency '{1}' was not built"),
                    Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it: diag(6384, 3 /* Message */, "Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_di_6384", "Have recompiles in '--incremental' and '--watch' assume that changes within a file will only affect files directly depending on it."),
                    _0_is_deprecated: diag(6385, 2 /* Suggestion */, "_0_is_deprecated_6385", "'{0}' is deprecated.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    void 0, 
                    /*reportsDeprecated*/
                    true),
                    Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_native_implementation_of_the_Web_Performance_API_could_not_be_found: diag(6386, 3 /* Message */, "Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_nativ_6386", "Performance timings for '--diagnostics' or '--extendedDiagnostics' are not available in this session. A native implementation of the Web Performance API could not be found."),
                    The_signature_0_of_1_is_deprecated: diag(6387, 2 /* Suggestion */, "The_signature_0_of_1_is_deprecated_6387", "The signature '{0}' of '{1}' is deprecated.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    void 0, 
                    /*reportsDeprecated*/
                    true),
                    Project_0_is_being_forcibly_rebuilt: diag(6388, 3 /* Message */, "Project_0_is_being_forcibly_rebuilt_6388", "Project '{0}' is being forcibly rebuilt"),
                    Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved: diag(6389, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved_6389", "Reusing resolution of module '{0}' from '{1}' of old program, it was not resolved."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2: diag(6390, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved__6390", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was successfully resolved to '{2}'."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3: diag(6391, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved__6391", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was successfully resolved to '{2}' with Package ID '{3}'."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved: diag(6392, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved_6392", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was not resolved."),
                    Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3: diag(6393, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_6393", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}'."),
                    Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3_with_Package_ID_4: diag(6394, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_6394", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}' with Package ID '{4}'."),
                    Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_not_resolved: diag(6395, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_not_resolved_6395", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was not resolved."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3: diag(6396, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_succes_6396", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}'."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3_with_Package_ID_4: diag(6397, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_succes_6397", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}' with Package ID '{4}'."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_not_resolved: diag(6398, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_not_re_6398", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was not resolved."),
                    Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitted: diag(6399, 3 /* Message */, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitte_6399", "Project '{0}' is out of date because buildinfo file '{1}' indicates that some of the changes were not emitted"),
                    Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_files: diag(6400, 3 /* Message */, "Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_fil_6400", "Project '{0}' is up to date but needs to update timestamps of output files that are older than input files"),
                    Project_0_is_out_of_date_because_there_was_error_reading_file_1: diag(6401, 3 /* Message */, "Project_0_is_out_of_date_because_there_was_error_reading_file_1_6401", "Project '{0}' is out of date because there was error reading file '{1}'"),
                    Resolving_in_0_mode_with_conditions_1: diag(6402, 3 /* Message */, "Resolving_in_0_mode_with_conditions_1_6402", "Resolving in {0} mode with conditions {1}."),
                    Matched_0_condition_1: diag(6403, 3 /* Message */, "Matched_0_condition_1_6403", "Matched '{0}' condition '{1}'."),
                    Using_0_subpath_1_with_target_2: diag(6404, 3 /* Message */, "Using_0_subpath_1_with_target_2_6404", "Using '{0}' subpath '{1}' with target '{2}'."),
                    Saw_non_matching_condition_0: diag(6405, 3 /* Message */, "Saw_non_matching_condition_0_6405", "Saw non-matching condition '{0}'."),
                    Project_0_is_out_of_date_because_buildinfo_file_1_indicates_there_is_change_in_compilerOptions: diag(6406, 3 /* Message */, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_there_is_change_in_compilerOptions_6406", "Project '{0}' is out of date because buildinfo file '{1}' indicates there is change in compilerOptions"),
                    Allow_imports_to_include_TypeScript_file_extensions_Requires_moduleResolution_bundler_and_either_noEmit_or_emitDeclarationOnly_to_be_set: diag(6407, 3 /* Message */, "Allow_imports_to_include_TypeScript_file_extensions_Requires_moduleResolution_bundler_and_either_noE_6407", "Allow imports to include TypeScript file extensions. Requires '--moduleResolution bundler' and either '--noEmit' or '--emitDeclarationOnly' to be set."),
                    Use_the_package_json_exports_field_when_resolving_package_imports: diag(6408, 3 /* Message */, "Use_the_package_json_exports_field_when_resolving_package_imports_6408", "Use the package.json 'exports' field when resolving package imports."),
                    Use_the_package_json_imports_field_when_resolving_imports: diag(6409, 3 /* Message */, "Use_the_package_json_imports_field_when_resolving_imports_6409", "Use the package.json 'imports' field when resolving imports."),
                    Conditions_to_set_in_addition_to_the_resolver_specific_defaults_when_resolving_imports: diag(6410, 3 /* Message */, "Conditions_to_set_in_addition_to_the_resolver_specific_defaults_when_resolving_imports_6410", "Conditions to set in addition to the resolver-specific defaults when resolving imports."),
                    true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false: diag(6411, 3 /* Message */, "true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false_6411", "`true` when 'moduleResolution' is 'node16', 'nodenext', or 'bundler'; otherwise `false`."),
                    Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_file_2_was_root_file_of_compilation_but_not_any_more: diag(6412, 3 /* Message */, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_file_2_was_root_file_of_compilation_6412", "Project '{0}' is out of date because buildinfo file '{1}' indicates that file '{2}' was root file of compilation but not any more."),
                    Entering_conditional_exports: diag(6413, 3 /* Message */, "Entering_conditional_exports_6413", "Entering conditional exports."),
                    Resolved_under_condition_0: diag(6414, 3 /* Message */, "Resolved_under_condition_0_6414", "Resolved under condition '{0}'."),
                    Failed_to_resolve_under_condition_0: diag(6415, 3 /* Message */, "Failed_to_resolve_under_condition_0_6415", "Failed to resolve under condition '{0}'."),
                    Exiting_conditional_exports: diag(6416, 3 /* Message */, "Exiting_conditional_exports_6416", "Exiting conditional exports."),
                    The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1: diag(6500, 3 /* Message */, "The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1_6500", "The expected type comes from property '{0}' which is declared here on type '{1}'"),
                    The_expected_type_comes_from_this_index_signature: diag(6501, 3 /* Message */, "The_expected_type_comes_from_this_index_signature_6501", "The expected type comes from this index signature."),
                    The_expected_type_comes_from_the_return_type_of_this_signature: diag(6502, 3 /* Message */, "The_expected_type_comes_from_the_return_type_of_this_signature_6502", "The expected type comes from the return type of this signature."),
                    Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing: diag(6503, 3 /* Message */, "Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing_6503", "Print names of files that are part of the compilation and then stop processing."),
                    File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option: diag(6504, 1 /* Error */, "File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option_6504", "File '{0}' is a JavaScript file. Did you mean to enable the 'allowJs' option?"),
                    Print_names_of_files_and_the_reason_they_are_part_of_the_compilation: diag(6505, 3 /* Message */, "Print_names_of_files_and_the_reason_they_are_part_of_the_compilation_6505", "Print names of files and the reason they are part of the compilation."),
                    Consider_adding_a_declare_modifier_to_this_class: diag(6506, 3 /* Message */, "Consider_adding_a_declare_modifier_to_this_class_6506", "Consider adding a 'declare' modifier to this class."),
                    Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJS_option_to_get_errors_from_these_files: diag(6600, 3 /* Message */, "Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJS_option_to_get_errors_from_these__6600", "Allow JavaScript files to be a part of your program. Use the 'checkJS' option to get errors from these files."),
                    Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export: diag(6601, 3 /* Message */, "Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export_6601", "Allow 'import x from y' when a module doesn't have a default export."),
                    Allow_accessing_UMD_globals_from_modules: diag(6602, 3 /* Message */, "Allow_accessing_UMD_globals_from_modules_6602", "Allow accessing UMD globals from modules."),
                    Disable_error_reporting_for_unreachable_code: diag(6603, 3 /* Message */, "Disable_error_reporting_for_unreachable_code_6603", "Disable error reporting for unreachable code."),
                    Disable_error_reporting_for_unused_labels: diag(6604, 3 /* Message */, "Disable_error_reporting_for_unused_labels_6604", "Disable error reporting for unused labels."),
                    Ensure_use_strict_is_always_emitted: diag(6605, 3 /* Message */, "Ensure_use_strict_is_always_emitted_6605", "Ensure 'use strict' is always emitted."),
                    Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it: diag(6606, 3 /* Message */, "Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_wi_6606", "Have recompiles in projects that use 'incremental' and 'watch' mode assume that changes within a file will only affect files directly depending on it."),
                    Specify_the_base_directory_to_resolve_non_relative_module_names: diag(6607, 3 /* Message */, "Specify_the_base_directory_to_resolve_non_relative_module_names_6607", "Specify the base directory to resolve non-relative module names."),
                    No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files: diag(6608, 3 /* Message */, "No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files_6608", "No longer supported. In early versions, manually set the text encoding for reading files."),
                    Enable_error_reporting_in_type_checked_JavaScript_files: diag(6609, 3 /* Message */, "Enable_error_reporting_in_type_checked_JavaScript_files_6609", "Enable error reporting in type-checked JavaScript files."),
                    Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references: diag(6611, 3 /* Message */, "Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references_6611", "Enable constraints that allow a TypeScript project to be used with project references."),
                    Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project: diag(6612, 3 /* Message */, "Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project_6612", "Generate .d.ts files from TypeScript and JavaScript files in your project."),
                    Specify_the_output_directory_for_generated_declaration_files: diag(6613, 3 /* Message */, "Specify_the_output_directory_for_generated_declaration_files_6613", "Specify the output directory for generated declaration files."),
                    Create_sourcemaps_for_d_ts_files: diag(6614, 3 /* Message */, "Create_sourcemaps_for_d_ts_files_6614", "Create sourcemaps for d.ts files."),
                    Output_compiler_performance_information_after_building: diag(6615, 3 /* Message */, "Output_compiler_performance_information_after_building_6615", "Output compiler performance information after building."),
                    Disables_inference_for_type_acquisition_by_looking_at_filenames_in_a_project: diag(6616, 3 /* Message */, "Disables_inference_for_type_acquisition_by_looking_at_filenames_in_a_project_6616", "Disables inference for type acquisition by looking at filenames in a project."),
                    Reduce_the_number_of_projects_loaded_automatically_by_TypeScript: diag(6617, 3 /* Message */, "Reduce_the_number_of_projects_loaded_automatically_by_TypeScript_6617", "Reduce the number of projects loaded automatically by TypeScript."),
                    Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server: diag(6618, 3 /* Message */, "Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server_6618", "Remove the 20mb cap on total source code size for JavaScript files in the TypeScript language server."),
                    Opt_a_project_out_of_multi_project_reference_checking_when_editing: diag(6619, 3 /* Message */, "Opt_a_project_out_of_multi_project_reference_checking_when_editing_6619", "Opt a project out of multi-project reference checking when editing."),
                    Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects: diag(6620, 3 /* Message */, "Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects_6620", "Disable preferring source files instead of declaration files when referencing composite projects."),
                    Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration: diag(6621, 3 /* Message */, "Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration_6621", "Emit more compliant, but verbose and less performant JavaScript for iteration."),
                    Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files: diag(6622, 3 /* Message */, "Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files_6622", "Emit a UTF-8 Byte Order Mark (BOM) in the beginning of output files."),
                    Only_output_d_ts_files_and_not_JavaScript_files: diag(6623, 3 /* Message */, "Only_output_d_ts_files_and_not_JavaScript_files_6623", "Only output d.ts files and not JavaScript files."),
                    Emit_design_type_metadata_for_decorated_declarations_in_source_files: diag(6624, 3 /* Message */, "Emit_design_type_metadata_for_decorated_declarations_in_source_files_6624", "Emit design-type metadata for decorated declarations in source files."),
                    Disable_the_type_acquisition_for_JavaScript_projects: diag(6625, 3 /* Message */, "Disable_the_type_acquisition_for_JavaScript_projects_6625", "Disable the type acquisition for JavaScript projects"),
                    Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheticDefaultImports_for_type_compatibility: diag(6626, 3 /* Message */, "Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheti_6626", "Emit additional JavaScript to ease support for importing CommonJS modules. This enables 'allowSyntheticDefaultImports' for type compatibility."),
                    Filters_results_from_the_include_option: diag(6627, 3 /* Message */, "Filters_results_from_the_include_option_6627", "Filters results from the `include` option."),
                    Remove_a_list_of_directories_from_the_watch_process: diag(6628, 3 /* Message */, "Remove_a_list_of_directories_from_the_watch_process_6628", "Remove a list of directories from the watch process."),
                    Remove_a_list_of_files_from_the_watch_mode_s_processing: diag(6629, 3 /* Message */, "Remove_a_list_of_files_from_the_watch_mode_s_processing_6629", "Remove a list of files from the watch mode's processing."),
                    Enable_experimental_support_for_legacy_experimental_decorators: diag(6630, 3 /* Message */, "Enable_experimental_support_for_legacy_experimental_decorators_6630", "Enable experimental support for legacy experimental decorators."),
                    Print_files_read_during_the_compilation_including_why_it_was_included: diag(6631, 3 /* Message */, "Print_files_read_during_the_compilation_including_why_it_was_included_6631", "Print files read during the compilation including why it was included."),
                    Output_more_detailed_compiler_performance_information_after_building: diag(6632, 3 /* Message */, "Output_more_detailed_compiler_performance_information_after_building_6632", "Output more detailed compiler performance information after building."),
                    Specify_one_or_more_path_or_node_module_references_to_base_configuration_files_from_which_settings_are_inherited: diag(6633, 3 /* Message */, "Specify_one_or_more_path_or_node_module_references_to_base_configuration_files_from_which_settings_a_6633", "Specify one or more path or node module references to base configuration files from which settings are inherited."),
                    Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers: diag(6634, 3 /* Message */, "Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers_6634", "Specify what approach the watcher should use if the system runs out of native file watchers."),
                    Include_a_list_of_files_This_does_not_support_glob_patterns_as_opposed_to_include: diag(6635, 3 /* Message */, "Include_a_list_of_files_This_does_not_support_glob_patterns_as_opposed_to_include_6635", "Include a list of files. This does not support glob patterns, as opposed to `include`."),
                    Build_all_projects_including_those_that_appear_to_be_up_to_date: diag(6636, 3 /* Message */, "Build_all_projects_including_those_that_appear_to_be_up_to_date_6636", "Build all projects, including those that appear to be up to date."),
                    Ensure_that_casing_is_correct_in_imports: diag(6637, 3 /* Message */, "Ensure_that_casing_is_correct_in_imports_6637", "Ensure that casing is correct in imports."),
                    Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging: diag(6638, 3 /* Message */, "Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging_6638", "Emit a v8 CPU profile of the compiler run for debugging."),
                    Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file: diag(6639, 3 /* Message */, "Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file_6639", "Allow importing helper functions from tslib once per project, instead of including them per-file."),
                    Specify_a_list_of_glob_patterns_that_match_files_to_be_included_in_compilation: diag(6641, 3 /* Message */, "Specify_a_list_of_glob_patterns_that_match_files_to_be_included_in_compilation_6641", "Specify a list of glob patterns that match files to be included in compilation."),
                    Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects: diag(6642, 3 /* Message */, "Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects_6642", "Save .tsbuildinfo files to allow for incremental compilation of projects."),
                    Include_sourcemap_files_inside_the_emitted_JavaScript: diag(6643, 3 /* Message */, "Include_sourcemap_files_inside_the_emitted_JavaScript_6643", "Include sourcemap files inside the emitted JavaScript."),
                    Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript: diag(6644, 3 /* Message */, "Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript_6644", "Include source code in the sourcemaps inside the emitted JavaScript."),
                    Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports: diag(6645, 3 /* Message */, "Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports_6645", "Ensure that each file can be safely transpiled without relying on other imports."),
                    Specify_what_JSX_code_is_generated: diag(6646, 3 /* Message */, "Specify_what_JSX_code_is_generated_6646", "Specify what JSX code is generated."),
                    Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h: diag(6647, 3 /* Message */, "Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h_6647", "Specify the JSX factory function used when targeting React JSX emit, e.g. 'React.createElement' or 'h'."),
                    Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragment_or_Fragment: diag(6648, 3 /* Message */, "Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragme_6648", "Specify the JSX Fragment reference used for fragments when targeting React JSX emit e.g. 'React.Fragment' or 'Fragment'."),
                    Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Asterisk: diag(6649, 3 /* Message */, "Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Ast_6649", "Specify module specifier used to import the JSX factory functions when using 'jsx: react-jsx*'."),
                    Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option: diag(6650, 3 /* Message */, "Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option_6650", "Make keyof only return strings instead of string, numbers or symbols. Legacy option."),
                    Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment: diag(6651, 3 /* Message */, "Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment_6651", "Specify a set of bundled library declaration files that describe the target runtime environment."),
                    Print_the_names_of_emitted_files_after_a_compilation: diag(6652, 3 /* Message */, "Print_the_names_of_emitted_files_after_a_compilation_6652", "Print the names of emitted files after a compilation."),
                    Print_all_of_the_files_read_during_the_compilation: diag(6653, 3 /* Message */, "Print_all_of_the_files_read_during_the_compilation_6653", "Print all of the files read during the compilation."),
                    Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit: diag(6654, 3 /* Message */, "Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit_6654", "Set the language of the messaging from TypeScript. This does not affect emit."),
                    Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations: diag(6655, 3 /* Message */, "Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations_6655", "Specify the location where debugger should locate map files instead of generated locations."),
                    Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicable_with_allowJs: diag(6656, 3 /* Message */, "Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicabl_6656", "Specify the maximum folder depth used for checking JavaScript files from 'node_modules'. Only applicable with 'allowJs'."),
                    Specify_what_module_code_is_generated: diag(6657, 3 /* Message */, "Specify_what_module_code_is_generated_6657", "Specify what module code is generated."),
                    Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier: diag(6658, 3 /* Message */, "Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier_6658", "Specify how TypeScript looks up a file from a given module specifier."),
                    Set_the_newline_character_for_emitting_files: diag(6659, 3 /* Message */, "Set_the_newline_character_for_emitting_files_6659", "Set the newline character for emitting files."),
                    Disable_emitting_files_from_a_compilation: diag(6660, 3 /* Message */, "Disable_emitting_files_from_a_compilation_6660", "Disable emitting files from a compilation."),
                    Disable_generating_custom_helper_functions_like_extends_in_compiled_output: diag(6661, 3 /* Message */, "Disable_generating_custom_helper_functions_like_extends_in_compiled_output_6661", "Disable generating custom helper functions like '__extends' in compiled output."),
                    Disable_emitting_files_if_any_type_checking_errors_are_reported: diag(6662, 3 /* Message */, "Disable_emitting_files_if_any_type_checking_errors_are_reported_6662", "Disable emitting files if any type checking errors are reported."),
                    Disable_truncating_types_in_error_messages: diag(6663, 3 /* Message */, "Disable_truncating_types_in_error_messages_6663", "Disable truncating types in error messages."),
                    Enable_error_reporting_for_fallthrough_cases_in_switch_statements: diag(6664, 3 /* Message */, "Enable_error_reporting_for_fallthrough_cases_in_switch_statements_6664", "Enable error reporting for fallthrough cases in switch statements."),
                    Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type: diag(6665, 3 /* Message */, "Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type_6665", "Enable error reporting for expressions and declarations with an implied 'any' type."),
                    Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier: diag(6666, 3 /* Message */, "Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier_6666", "Ensure overriding members in derived classes are marked with an override modifier."),
                    Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function: diag(6667, 3 /* Message */, "Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function_6667", "Enable error reporting for codepaths that do not explicitly return in a function."),
                    Enable_error_reporting_when_this_is_given_the_type_any: diag(6668, 3 /* Message */, "Enable_error_reporting_when_this_is_given_the_type_any_6668", "Enable error reporting when 'this' is given the type 'any'."),
                    Disable_adding_use_strict_directives_in_emitted_JavaScript_files: diag(6669, 3 /* Message */, "Disable_adding_use_strict_directives_in_emitted_JavaScript_files_6669", "Disable adding 'use strict' directives in emitted JavaScript files."),
                    Disable_including_any_library_files_including_the_default_lib_d_ts: diag(6670, 3 /* Message */, "Disable_including_any_library_files_including_the_default_lib_d_ts_6670", "Disable including any library files, including the default lib.d.ts."),
                    Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type: diag(6671, 3 /* Message */, "Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type_6671", "Enforces using indexed accessors for keys declared using an indexed type."),
                    Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add_to_a_project: diag(6672, 3 /* Message */, "Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add__6672", "Disallow 'import's, 'require's or '<reference>'s from expanding the number of files TypeScript should add to a project."),
                    Disable_strict_checking_of_generic_signatures_in_function_types: diag(6673, 3 /* Message */, "Disable_strict_checking_of_generic_signatures_in_function_types_6673", "Disable strict checking of generic signatures in function types."),
                    Add_undefined_to_a_type_when_accessed_using_an_index: diag(6674, 3 /* Message */, "Add_undefined_to_a_type_when_accessed_using_an_index_6674", "Add 'undefined' to a type when accessed using an index."),
                    Enable_error_reporting_when_local_variables_aren_t_read: diag(6675, 3 /* Message */, "Enable_error_reporting_when_local_variables_aren_t_read_6675", "Enable error reporting when local variables aren't read."),
                    Raise_an_error_when_a_function_parameter_isn_t_read: diag(6676, 3 /* Message */, "Raise_an_error_when_a_function_parameter_isn_t_read_6676", "Raise an error when a function parameter isn't read."),
                    Deprecated_setting_Use_outFile_instead: diag(6677, 3 /* Message */, "Deprecated_setting_Use_outFile_instead_6677", "Deprecated setting. Use 'outFile' instead."),
                    Specify_an_output_folder_for_all_emitted_files: diag(6678, 3 /* Message */, "Specify_an_output_folder_for_all_emitted_files_6678", "Specify an output folder for all emitted files."),
                    Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designates_a_file_that_bundles_all_d_ts_output: diag(6679, 3 /* Message */, "Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designa_6679", "Specify a file that bundles all outputs into one JavaScript file. If 'declaration' is true, also designates a file that bundles all .d.ts output."),
                    Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations: diag(6680, 3 /* Message */, "Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations_6680", "Specify a set of entries that re-map imports to additional lookup locations."),
                    Specify_a_list_of_language_service_plugins_to_include: diag(6681, 3 /* Message */, "Specify_a_list_of_language_service_plugins_to_include_6681", "Specify a list of language service plugins to include."),
                    Disable_erasing_const_enum_declarations_in_generated_code: diag(6682, 3 /* Message */, "Disable_erasing_const_enum_declarations_in_generated_code_6682", "Disable erasing 'const enum' declarations in generated code."),
                    Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node: diag(6683, 3 /* Message */, "Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node_6683", "Disable resolving symlinks to their realpath. This correlates to the same flag in node."),
                    Disable_wiping_the_console_in_watch_mode: diag(6684, 3 /* Message */, "Disable_wiping_the_console_in_watch_mode_6684", "Disable wiping the console in watch mode."),
                    Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read: diag(6685, 3 /* Message */, "Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read_6685", "Enable color and formatting in TypeScript's output to make compiler errors easier to read."),
                    Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit: diag(6686, 3 /* Message */, "Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit_6686", "Specify the object invoked for 'createElement'. This only applies when targeting 'react' JSX emit."),
                    Specify_an_array_of_objects_that_specify_paths_for_projects_Used_in_project_references: diag(6687, 3 /* Message */, "Specify_an_array_of_objects_that_specify_paths_for_projects_Used_in_project_references_6687", "Specify an array of objects that specify paths for projects. Used in project references."),
                    Disable_emitting_comments: diag(6688, 3 /* Message */, "Disable_emitting_comments_6688", "Disable emitting comments."),
                    Enable_importing_json_files: diag(6689, 3 /* Message */, "Enable_importing_json_files_6689", "Enable importing .json files."),
                    Specify_the_root_folder_within_your_source_files: diag(6690, 3 /* Message */, "Specify_the_root_folder_within_your_source_files_6690", "Specify the root folder within your source files."),
                    Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules: diag(6691, 3 /* Message */, "Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules_6691", "Allow multiple folders to be treated as one when resolving modules."),
                    Skip_type_checking_d_ts_files_that_are_included_with_TypeScript: diag(6692, 3 /* Message */, "Skip_type_checking_d_ts_files_that_are_included_with_TypeScript_6692", "Skip type checking .d.ts files that are included with TypeScript."),
                    Skip_type_checking_all_d_ts_files: diag(6693, 3 /* Message */, "Skip_type_checking_all_d_ts_files_6693", "Skip type checking all .d.ts files."),
                    Create_source_map_files_for_emitted_JavaScript_files: diag(6694, 3 /* Message */, "Create_source_map_files_for_emitted_JavaScript_files_6694", "Create source map files for emitted JavaScript files."),
                    Specify_the_root_path_for_debuggers_to_find_the_reference_source_code: diag(6695, 3 /* Message */, "Specify_the_root_path_for_debuggers_to_find_the_reference_source_code_6695", "Specify the root path for debuggers to find the reference source code."),
                    Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function: diag(6697, 3 /* Message */, "Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function_6697", "Check that the arguments for 'bind', 'call', and 'apply' methods match the original function."),
                    When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible: diag(6698, 3 /* Message */, "When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible_6698", "When assigning functions, check to ensure parameters and the return values are subtype-compatible."),
                    When_type_checking_take_into_account_null_and_undefined: diag(6699, 3 /* Message */, "When_type_checking_take_into_account_null_and_undefined_6699", "When type checking, take into account 'null' and 'undefined'."),
                    Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor: diag(6700, 3 /* Message */, "Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor_6700", "Check for class properties that are declared but not set in the constructor."),
                    Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments: diag(6701, 3 /* Message */, "Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments_6701", "Disable emitting declarations that have '@internal' in their JSDoc comments."),
                    Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals: diag(6702, 3 /* Message */, "Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals_6702", "Disable reporting of excess property errors during the creation of object literals."),
                    Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures: diag(6703, 3 /* Message */, "Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures_6703", "Suppress 'noImplicitAny' errors when indexing objects that lack index signatures."),
                    Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively: diag(6704, 3 /* Message */, "Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_supp_6704", "Synchronously call callbacks and update the state of directory watchers on platforms that don`t support recursive watching natively."),
                    Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declarations: diag(6705, 3 /* Message */, "Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declaratio_6705", "Set the JavaScript language version for emitted JavaScript and include compatible library declarations."),
                    Log_paths_used_during_the_moduleResolution_process: diag(6706, 3 /* Message */, "Log_paths_used_during_the_moduleResolution_process_6706", "Log paths used during the 'moduleResolution' process."),
                    Specify_the_path_to_tsbuildinfo_incremental_compilation_file: diag(6707, 3 /* Message */, "Specify_the_path_to_tsbuildinfo_incremental_compilation_file_6707", "Specify the path to .tsbuildinfo incremental compilation file."),
                    Specify_options_for_automatic_acquisition_of_declaration_files: diag(6709, 3 /* Message */, "Specify_options_for_automatic_acquisition_of_declaration_files_6709", "Specify options for automatic acquisition of declaration files."),
                    Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types: diag(6710, 3 /* Message */, "Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types_6710", "Specify multiple folders that act like './node_modules/@types'."),
                    Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file: diag(6711, 3 /* Message */, "Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file_6711", "Specify type package names to be included without being referenced in a source file."),
                    Emit_ECMAScript_standard_compliant_class_fields: diag(6712, 3 /* Message */, "Emit_ECMAScript_standard_compliant_class_fields_6712", "Emit ECMAScript-standard-compliant class fields."),
                    Enable_verbose_logging: diag(6713, 3 /* Message */, "Enable_verbose_logging_6713", "Enable verbose logging."),
                    Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality: diag(6714, 3 /* Message */, "Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality_6714", "Specify how directories are watched on systems that lack recursive file-watching functionality."),
                    Specify_how_the_TypeScript_watch_mode_works: diag(6715, 3 /* Message */, "Specify_how_the_TypeScript_watch_mode_works_6715", "Specify how the TypeScript watch mode works."),
                    Require_undeclared_properties_from_index_signatures_to_use_element_accesses: diag(6717, 3 /* Message */, "Require_undeclared_properties_from_index_signatures_to_use_element_accesses_6717", "Require undeclared properties from index signatures to use element accesses."),
                    Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types: diag(6718, 3 /* Message */, "Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types_6718", "Specify emit/checking behavior for imports that are only used for types."),
                    Default_catch_clause_variables_as_unknown_instead_of_any: diag(6803, 3 /* Message */, "Default_catch_clause_variables_as_unknown_instead_of_any_6803", "Default catch clause variables as 'unknown' instead of 'any'."),
                    Do_not_transform_or_elide_any_imports_or_exports_not_marked_as_type_only_ensuring_they_are_written_in_the_output_file_s_format_based_on_the_module_setting: diag(6804, 3 /* Message */, "Do_not_transform_or_elide_any_imports_or_exports_not_marked_as_type_only_ensuring_they_are_written_i_6804", "Do not transform or elide any imports or exports not marked as type-only, ensuring they are written in the output file's format based on the 'module' setting."),
                    one_of_Colon: diag(6900, 3 /* Message */, "one_of_Colon_6900", "one of:"),
                    one_or_more_Colon: diag(6901, 3 /* Message */, "one_or_more_Colon_6901", "one or more:"),
                    type_Colon: diag(6902, 3 /* Message */, "type_Colon_6902", "type:"),
                    default_Colon: diag(6903, 3 /* Message */, "default_Colon_6903", "default:"),
                    module_system_or_esModuleInterop: diag(6904, 3 /* Message */, "module_system_or_esModuleInterop_6904", 'module === "system" or esModuleInterop'),
                    false_unless_strict_is_set: diag(6905, 3 /* Message */, "false_unless_strict_is_set_6905", "`false`, unless `strict` is set"),
                    false_unless_composite_is_set: diag(6906, 3 /* Message */, "false_unless_composite_is_set_6906", "`false`, unless `composite` is set"),
                    node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified: diag(6907, 3 /* Message */, "node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified_6907", '`["node_modules", "bower_components", "jspm_packages"]`, plus the value of `outDir` if one is specified.'),
                    if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk: diag(6908, 3 /* Message */, "if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk_6908", '`[]` if `files` is specified, otherwise `["**/*"]`'),
                    true_if_composite_false_otherwise: diag(6909, 3 /* Message */, "true_if_composite_false_otherwise_6909", "`true` if `composite`, `false` otherwise"),
                    module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node: diag(69010, 3 /* Message */, "module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node_69010", "module === `AMD` or `UMD` or `System` or `ES6`, then `Classic`, Otherwise `Node`"),
                    Computed_from_the_list_of_input_files: diag(6911, 3 /* Message */, "Computed_from_the_list_of_input_files_6911", "Computed from the list of input files"),
                    Platform_specific: diag(6912, 3 /* Message */, "Platform_specific_6912", "Platform specific"),
                    You_can_learn_about_all_of_the_compiler_options_at_0: diag(6913, 3 /* Message */, "You_can_learn_about_all_of_the_compiler_options_at_0_6913", "You can learn about all of the compiler options at {0}"),
                    Including_watch_w_will_start_watching_the_current_project_for_the_file_changes_Once_set_you_can_config_watch_mode_with_Colon: diag(6914, 3 /* Message */, "Including_watch_w_will_start_watching_the_current_project_for_the_file_changes_Once_set_you_can_conf_6914", "Including --watch, -w will start watching the current project for the file changes. Once set, you can config watch mode with:"),
                    Using_build_b_will_make_tsc_behave_more_like_a_build_orchestrator_than_a_compiler_This_is_used_to_trigger_building_composite_projects_which_you_can_learn_more_about_at_0: diag(6915, 3 /* Message */, "Using_build_b_will_make_tsc_behave_more_like_a_build_orchestrator_than_a_compiler_This_is_used_to_tr_6915", "Using --build, -b will make tsc behave more like a build orchestrator than a compiler. This is used to trigger building composite projects which you can learn more about at {0}"),
                    COMMON_COMMANDS: diag(6916, 3 /* Message */, "COMMON_COMMANDS_6916", "COMMON COMMANDS"),
                    ALL_COMPILER_OPTIONS: diag(6917, 3 /* Message */, "ALL_COMPILER_OPTIONS_6917", "ALL COMPILER OPTIONS"),
                    WATCH_OPTIONS: diag(6918, 3 /* Message */, "WATCH_OPTIONS_6918", "WATCH OPTIONS"),
                    BUILD_OPTIONS: diag(6919, 3 /* Message */, "BUILD_OPTIONS_6919", "BUILD OPTIONS"),
                    COMMON_COMPILER_OPTIONS: diag(6920, 3 /* Message */, "COMMON_COMPILER_OPTIONS_6920", "COMMON COMPILER OPTIONS"),
                    COMMAND_LINE_FLAGS: diag(6921, 3 /* Message */, "COMMAND_LINE_FLAGS_6921", "COMMAND LINE FLAGS"),
                    tsc_Colon_The_TypeScript_Compiler: diag(6922, 3 /* Message */, "tsc_Colon_The_TypeScript_Compiler_6922", "tsc: The TypeScript Compiler"),
                    Compiles_the_current_project_tsconfig_json_in_the_working_directory: diag(6923, 3 /* Message */, "Compiles_the_current_project_tsconfig_json_in_the_working_directory_6923", "Compiles the current project (tsconfig.json in the working directory.)"),
                    Ignoring_tsconfig_json_compiles_the_specified_files_with_default_compiler_options: diag(6924, 3 /* Message */, "Ignoring_tsconfig_json_compiles_the_specified_files_with_default_compiler_options_6924", "Ignoring tsconfig.json, compiles the specified files with default compiler options."),
                    Build_a_composite_project_in_the_working_directory: diag(6925, 3 /* Message */, "Build_a_composite_project_in_the_working_directory_6925", "Build a composite project in the working directory."),
                    Creates_a_tsconfig_json_with_the_recommended_settings_in_the_working_directory: diag(6926, 3 /* Message */, "Creates_a_tsconfig_json_with_the_recommended_settings_in_the_working_directory_6926", "Creates a tsconfig.json with the recommended settings in the working directory."),
                    Compiles_the_TypeScript_project_located_at_the_specified_path: diag(6927, 3 /* Message */, "Compiles_the_TypeScript_project_located_at_the_specified_path_6927", "Compiles the TypeScript project located at the specified path."),
                    An_expanded_version_of_this_information_showing_all_possible_compiler_options: diag(6928, 3 /* Message */, "An_expanded_version_of_this_information_showing_all_possible_compiler_options_6928", "An expanded version of this information, showing all possible compiler options"),
                    Compiles_the_current_project_with_additional_settings: diag(6929, 3 /* Message */, "Compiles_the_current_project_with_additional_settings_6929", "Compiles the current project, with additional settings."),
                    true_for_ES2022_and_above_including_ESNext: diag(6930, 3 /* Message */, "true_for_ES2022_and_above_including_ESNext_6930", "`true` for ES2022 and above, including ESNext."),
                    List_of_file_name_suffixes_to_search_when_resolving_a_module: diag(6931, 1 /* Error */, "List_of_file_name_suffixes_to_search_when_resolving_a_module_6931", "List of file name suffixes to search when resolving a module."),
                    Variable_0_implicitly_has_an_1_type: diag(7005, 1 /* Error */, "Variable_0_implicitly_has_an_1_type_7005", "Variable '{0}' implicitly has an '{1}' type."),
                    Parameter_0_implicitly_has_an_1_type: diag(7006, 1 /* Error */, "Parameter_0_implicitly_has_an_1_type_7006", "Parameter '{0}' implicitly has an '{1}' type."),
                    Member_0_implicitly_has_an_1_type: diag(7008, 1 /* Error */, "Member_0_implicitly_has_an_1_type_7008", "Member '{0}' implicitly has an '{1}' type."),
                    new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type: diag(7009, 1 /* Error */, "new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type_7009", "'new' expression, whose target lacks a construct signature, implicitly has an 'any' type."),
                    _0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type: diag(7010, 1 /* Error */, "_0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type_7010", "'{0}', which lacks return-type annotation, implicitly has an '{1}' return type."),
                    Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type: diag(7011, 1 /* Error */, "Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7011", "Function expression, which lacks return-type annotation, implicitly has an '{0}' return type."),
                    This_overload_implicitly_returns_the_type_0_because_it_lacks_a_return_type_annotation: diag(7012, 1 /* Error */, "This_overload_implicitly_returns_the_type_0_because_it_lacks_a_return_type_annotation_7012", "This overload implicitly returns the type '{0}' because it lacks a return type annotation."),
                    Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: diag(7013, 1 /* Error */, "Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7013", "Construct signature, which lacks return-type annotation, implicitly has an 'any' return type."),
                    Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type: diag(7014, 1 /* Error */, "Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7014", "Function type, which lacks return-type annotation, implicitly has an '{0}' return type."),
                    Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number: diag(7015, 1 /* Error */, "Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number_7015", "Element implicitly has an 'any' type because index expression is not of type 'number'."),
                    Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type: diag(7016, 1 /* Error */, "Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type_7016", "Could not find a declaration file for module '{0}'. '{1}' implicitly has an 'any' type."),
                    Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature: diag(7017, 1 /* Error */, "Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_7017", "Element implicitly has an 'any' type because type '{0}' has no index signature."),
                    Object_literal_s_property_0_implicitly_has_an_1_type: diag(7018, 1 /* Error */, "Object_literal_s_property_0_implicitly_has_an_1_type_7018", "Object literal's property '{0}' implicitly has an '{1}' type."),
                    Rest_parameter_0_implicitly_has_an_any_type: diag(7019, 1 /* Error */, "Rest_parameter_0_implicitly_has_an_any_type_7019", "Rest parameter '{0}' implicitly has an 'any[]' type."),
                    Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: diag(7020, 1 /* Error */, "Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7020", "Call signature, which lacks return-type annotation, implicitly has an 'any' return type."),
                    _0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer: diag(7022, 1 /* Error */, "_0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or__7022", "'{0}' implicitly has type 'any' because it does not have a type annotation and is referenced directly or indirectly in its own initializer."),
                    _0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: diag(7023, 1 /* Error */, "_0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_reference_7023", "'{0}' implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."),
                    Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: diag(7024, 1 /* Error */, "Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_ref_7024", "Function implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."),
                    Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_type_annotation: diag(7025, 1 /* Error */, "Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_retu_7025", "Generator implicitly has yield type '{0}' because it does not yield any values. Consider supplying a return type annotation."),
                    JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists: diag(7026, 1 /* Error */, "JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists_7026", "JSX element implicitly has type 'any' because no interface 'JSX.{0}' exists."),
                    Unreachable_code_detected: diag(7027, 1 /* Error */, "Unreachable_code_detected_7027", "Unreachable code detected.", 
                    /*reportsUnnecessary*/
                    true),
                    Unused_label: diag(7028, 1 /* Error */, "Unused_label_7028", "Unused label.", 
                    /*reportsUnnecessary*/
                    true),
                    Fallthrough_case_in_switch: diag(7029, 1 /* Error */, "Fallthrough_case_in_switch_7029", "Fallthrough case in switch."),
                    Not_all_code_paths_return_a_value: diag(7030, 1 /* Error */, "Not_all_code_paths_return_a_value_7030", "Not all code paths return a value."),
                    Binding_element_0_implicitly_has_an_1_type: diag(7031, 1 /* Error */, "Binding_element_0_implicitly_has_an_1_type_7031", "Binding element '{0}' implicitly has an '{1}' type."),
                    Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation: diag(7032, 1 /* Error */, "Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation_7032", "Property '{0}' implicitly has type 'any', because its set accessor lacks a parameter type annotation."),
                    Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation: diag(7033, 1 /* Error */, "Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation_7033", "Property '{0}' implicitly has type 'any', because its get accessor lacks a return type annotation."),
                    Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined: diag(7034, 1 /* Error */, "Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined_7034", "Variable '{0}' implicitly has type '{1}' in some locations where its type cannot be determined."),
                    Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare_module_0: diag(7035, 1 /* Error */, "Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare__7035", "Try `npm i --save-dev @types/{1}` if it exists or add a new declaration (.d.ts) file containing `declare module '{0}';`"),
                    Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0: diag(7036, 1 /* Error */, "Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0_7036", "Dynamic import's specifier must be of type 'string', but here has type '{0}'."),
                    Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for_all_imports_Implies_allowSyntheticDefaultImports: diag(7037, 3 /* Message */, "Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for__7037", "Enables emit interoperability between CommonJS and ES Modules via creation of namespace objects for all imports. Implies 'allowSyntheticDefaultImports'."),
                    Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead: diag(7038, 3 /* Message */, "Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cau_7038", "Type originates at this import. A namespace-style import cannot be called or constructed, and will cause a failure at runtime. Consider using a default import or import require here instead."),
                    Mapped_object_type_implicitly_has_an_any_template_type: diag(7039, 1 /* Error */, "Mapped_object_type_implicitly_has_an_any_template_type_7039", "Mapped object type implicitly has an 'any' template type."),
                    If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_Slash_Slashgithub_com_SlashDefinitelyTyped_SlashDefinitelyTyped_Slashtree_Slashmaster_Slashtypes_Slash_1: diag(7040, 1 /* Error */, "If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_S_7040", "If the '{0}' package actually exposes this module, consider sending a pull request to amend 'https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/{1}'"),
                    The_containing_arrow_function_captures_the_global_value_of_this: diag(7041, 1 /* Error */, "The_containing_arrow_function_captures_the_global_value_of_this_7041", "The containing arrow function captures the global value of 'this'."),
                    Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used: diag(7042, 1 /* Error */, "Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used_7042", "Module '{0}' was resolved to '{1}', but '--resolveJsonModule' is not used."),
                    Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: diag(7043, 2 /* Suggestion */, "Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7043", "Variable '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),
                    Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: diag(7044, 2 /* Suggestion */, "Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7044", "Parameter '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),
                    Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: diag(7045, 2 /* Suggestion */, "Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7045", "Member '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),
                    Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage: diag(7046, 2 /* Suggestion */, "Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage_7046", "Variable '{0}' implicitly has type '{1}' in some locations, but a better type may be inferred from usage."),
                    Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage: diag(7047, 2 /* Suggestion */, "Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage_7047", "Rest parameter '{0}' implicitly has an 'any[]' type, but a better type may be inferred from usage."),
                    Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage: diag(7048, 2 /* Suggestion */, "Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage_7048", "Property '{0}' implicitly has type 'any', but a better type for its get accessor may be inferred from usage."),
                    Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage: diag(7049, 2 /* Suggestion */, "Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage_7049", "Property '{0}' implicitly has type 'any', but a better type for its set accessor may be inferred from usage."),
                    _0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage: diag(7050, 2 /* Suggestion */, "_0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage_7050", "'{0}' implicitly has an '{1}' return type, but a better type may be inferred from usage."),
                    Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1: diag(7051, 1 /* Error */, "Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1_7051", "Parameter has a name but no type. Did you mean '{0}: {1}'?"),
                    Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1: diag(7052, 1 /* Error */, "Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1_7052", "Element implicitly has an 'any' type because type '{0}' has no index signature. Did you mean to call '{1}'?"),
                    Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1: diag(7053, 1 /* Error */, "Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1_7053", "Element implicitly has an 'any' type because expression of type '{0}' can't be used to index type '{1}'."),
                    No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1: diag(7054, 1 /* Error */, "No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1_7054", "No index signature with a parameter of type '{0}' was found on type '{1}'."),
                    _0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type: diag(7055, 1 /* Error */, "_0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type_7055", "'{0}', which lacks return-type annotation, implicitly has an '{1}' yield type."),
                    The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_type_annotation_is_needed: diag(7056, 1 /* Error */, "The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_ty_7056", "The inferred type of this node exceeds the maximum length the compiler will serialize. An explicit type annotation is needed."),
                    yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_type_annotation: diag(7057, 1 /* Error */, "yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_t_7057", "'yield' expression implicitly results in an 'any' type because its containing generator lacks a return-type annotation."),
                    If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_declare_module_1: diag(7058, 1 /* Error */, "If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_decl_7058", "If the '{0}' package actually exposes this module, try adding a new declaration (.d.ts) file containing `declare module '{1}';`"),
                    This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead: diag(7059, 1 /* Error */, "This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead_7059", "This syntax is reserved in files with the .mts or .cts extension. Use an `as` expression instead."),
                    This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_constraint: diag(7060, 1 /* Error */, "This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_cons_7060", "This syntax is reserved in files with the .mts or .cts extension. Add a trailing comma or explicit constraint."),
                    A_mapped_type_may_not_declare_properties_or_methods: diag(7061, 1 /* Error */, "A_mapped_type_may_not_declare_properties_or_methods_7061", "A mapped type may not declare properties or methods."),
                    You_cannot_rename_this_element: diag(8e3, 1 /* Error */, "You_cannot_rename_this_element_8000", "You cannot rename this element."),
                    You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library: diag(8001, 1 /* Error */, "You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library_8001", "You cannot rename elements that are defined in the standard TypeScript library."),
                    import_can_only_be_used_in_TypeScript_files: diag(8002, 1 /* Error */, "import_can_only_be_used_in_TypeScript_files_8002", "'import ... =' can only be used in TypeScript files."),
                    export_can_only_be_used_in_TypeScript_files: diag(8003, 1 /* Error */, "export_can_only_be_used_in_TypeScript_files_8003", "'export =' can only be used in TypeScript files."),
                    Type_parameter_declarations_can_only_be_used_in_TypeScript_files: diag(8004, 1 /* Error */, "Type_parameter_declarations_can_only_be_used_in_TypeScript_files_8004", "Type parameter declarations can only be used in TypeScript files."),
                    implements_clauses_can_only_be_used_in_TypeScript_files: diag(8005, 1 /* Error */, "implements_clauses_can_only_be_used_in_TypeScript_files_8005", "'implements' clauses can only be used in TypeScript files."),
                    _0_declarations_can_only_be_used_in_TypeScript_files: diag(8006, 1 /* Error */, "_0_declarations_can_only_be_used_in_TypeScript_files_8006", "'{0}' declarations can only be used in TypeScript files."),
                    Type_aliases_can_only_be_used_in_TypeScript_files: diag(8008, 1 /* Error */, "Type_aliases_can_only_be_used_in_TypeScript_files_8008", "Type aliases can only be used in TypeScript files."),
                    The_0_modifier_can_only_be_used_in_TypeScript_files: diag(8009, 1 /* Error */, "The_0_modifier_can_only_be_used_in_TypeScript_files_8009", "The '{0}' modifier can only be used in TypeScript files."),
                    Type_annotations_can_only_be_used_in_TypeScript_files: diag(8010, 1 /* Error */, "Type_annotations_can_only_be_used_in_TypeScript_files_8010", "Type annotations can only be used in TypeScript files."),
                    Type_arguments_can_only_be_used_in_TypeScript_files: diag(8011, 1 /* Error */, "Type_arguments_can_only_be_used_in_TypeScript_files_8011", "Type arguments can only be used in TypeScript files."),
                    Parameter_modifiers_can_only_be_used_in_TypeScript_files: diag(8012, 1 /* Error */, "Parameter_modifiers_can_only_be_used_in_TypeScript_files_8012", "Parameter modifiers can only be used in TypeScript files."),
                    Non_null_assertions_can_only_be_used_in_TypeScript_files: diag(8013, 1 /* Error */, "Non_null_assertions_can_only_be_used_in_TypeScript_files_8013", "Non-null assertions can only be used in TypeScript files."),
                    Type_assertion_expressions_can_only_be_used_in_TypeScript_files: diag(8016, 1 /* Error */, "Type_assertion_expressions_can_only_be_used_in_TypeScript_files_8016", "Type assertion expressions can only be used in TypeScript files."),
                    Octal_literal_types_must_use_ES2015_syntax_Use_the_syntax_0: diag(8017, 1 /* Error */, "Octal_literal_types_must_use_ES2015_syntax_Use_the_syntax_0_8017", "Octal literal types must use ES2015 syntax. Use the syntax '{0}'."),
                    Octal_literals_are_not_allowed_in_enums_members_initializer_Use_the_syntax_0: diag(8018, 1 /* Error */, "Octal_literals_are_not_allowed_in_enums_members_initializer_Use_the_syntax_0_8018", "Octal literals are not allowed in enums members initializer. Use the syntax '{0}'."),
                    Report_errors_in_js_files: diag(8019, 3 /* Message */, "Report_errors_in_js_files_8019", "Report errors in .js files."),
                    JSDoc_types_can_only_be_used_inside_documentation_comments: diag(8020, 1 /* Error */, "JSDoc_types_can_only_be_used_inside_documentation_comments_8020", "JSDoc types can only be used inside documentation comments."),
                    JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags: diag(8021, 1 /* Error */, "JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags_8021", "JSDoc '@typedef' tag should either have a type annotation or be followed by '@property' or '@member' tags."),
                    JSDoc_0_is_not_attached_to_a_class: diag(8022, 1 /* Error */, "JSDoc_0_is_not_attached_to_a_class_8022", "JSDoc '@{0}' is not attached to a class."),
                    JSDoc_0_1_does_not_match_the_extends_2_clause: diag(8023, 1 /* Error */, "JSDoc_0_1_does_not_match_the_extends_2_clause_8023", "JSDoc '@{0} {1}' does not match the 'extends {2}' clause."),
                    JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name: diag(8024, 1 /* Error */, "JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_8024", "JSDoc '@param' tag has name '{0}', but there is no parameter with that name."),
                    Class_declarations_cannot_have_more_than_one_augments_or_extends_tag: diag(8025, 1 /* Error */, "Class_declarations_cannot_have_more_than_one_augments_or_extends_tag_8025", "Class declarations cannot have more than one '@augments' or '@extends' tag."),
                    Expected_0_type_arguments_provide_these_with_an_extends_tag: diag(8026, 1 /* Error */, "Expected_0_type_arguments_provide_these_with_an_extends_tag_8026", "Expected {0} type arguments; provide these with an '@extends' tag."),
                    Expected_0_1_type_arguments_provide_these_with_an_extends_tag: diag(8027, 1 /* Error */, "Expected_0_1_type_arguments_provide_these_with_an_extends_tag_8027", "Expected {0}-{1} type arguments; provide these with an '@extends' tag."),
                    JSDoc_may_only_appear_in_the_last_parameter_of_a_signature: diag(8028, 1 /* Error */, "JSDoc_may_only_appear_in_the_last_parameter_of_a_signature_8028", "JSDoc '...' may only appear in the last parameter of a signature."),
                    JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_had_an_array_type: diag(8029, 1 /* Error */, "JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_h_8029", "JSDoc '@param' tag has name '{0}', but there is no parameter with that name. It would match 'arguments' if it had an array type."),
                    The_type_of_a_function_declaration_must_match_the_function_s_signature: diag(8030, 1 /* Error */, "The_type_of_a_function_declaration_must_match_the_function_s_signature_8030", "The type of a function declaration must match the function's signature."),
                    You_cannot_rename_a_module_via_a_global_import: diag(8031, 1 /* Error */, "You_cannot_rename_a_module_via_a_global_import_8031", "You cannot rename a module via a global import."),
                    Qualified_name_0_is_not_allowed_without_a_leading_param_object_1: diag(8032, 1 /* Error */, "Qualified_name_0_is_not_allowed_without_a_leading_param_object_1_8032", "Qualified name '{0}' is not allowed without a leading '@param {object} {1}'."),
                    A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags: diag(8033, 1 /* Error */, "A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags_8033", "A JSDoc '@typedef' comment may not contain multiple '@type' tags."),
                    The_tag_was_first_specified_here: diag(8034, 1 /* Error */, "The_tag_was_first_specified_here_8034", "The tag was first specified here."),
                    You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder: diag(8035, 1 /* Error */, "You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder_8035", "You cannot rename elements that are defined in a 'node_modules' folder."),
                    You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder: diag(8036, 1 /* Error */, "You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder_8036", "You cannot rename elements that are defined in another 'node_modules' folder."),
                    Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files: diag(8037, 1 /* Error */, "Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files_8037", "Type satisfaction expressions can only be used in TypeScript files."),
                    Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export: diag(8038, 1 /* Error */, "Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export_8038", "Decorators may not appear after 'export' or 'export default' if they also appear before 'export'."),
                    Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_declaration_emit: diag(9005, 1 /* Error */, "Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_9005", "Declaration emit for this file requires using private name '{0}'. An explicit type annotation may unblock declaration emit."),
                    Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotation_may_unblock_declaration_emit: diag(9006, 1 /* Error */, "Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotati_9006", "Declaration emit for this file requires using private name '{0}' from module '{1}'. An explicit type annotation may unblock declaration emit."),
                    JSX_attributes_must_only_be_assigned_a_non_empty_expression: diag(17e3, 1 /* Error */, "JSX_attributes_must_only_be_assigned_a_non_empty_expression_17000", "JSX attributes must only be assigned a non-empty 'expression'."),
                    JSX_elements_cannot_have_multiple_attributes_with_the_same_name: diag(17001, 1 /* Error */, "JSX_elements_cannot_have_multiple_attributes_with_the_same_name_17001", "JSX elements cannot have multiple attributes with the same name."),
                    Expected_corresponding_JSX_closing_tag_for_0: diag(17002, 1 /* Error */, "Expected_corresponding_JSX_closing_tag_for_0_17002", "Expected corresponding JSX closing tag for '{0}'."),
                    Cannot_use_JSX_unless_the_jsx_flag_is_provided: diag(17004, 1 /* Error */, "Cannot_use_JSX_unless_the_jsx_flag_is_provided_17004", "Cannot use JSX unless the '--jsx' flag is provided."),
                    A_constructor_cannot_contain_a_super_call_when_its_class_extends_null: diag(17005, 1 /* Error */, "A_constructor_cannot_contain_a_super_call_when_its_class_extends_null_17005", "A constructor cannot contain a 'super' call when its class extends 'null'."),
                    An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: diag(17006, 1 /* Error */, "An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_ex_17006", "An unary expression with the '{0}' operator is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."),
                    A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: diag(17007, 1 /* Error */, "A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Con_17007", "A type assertion expression is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."),
                    JSX_element_0_has_no_corresponding_closing_tag: diag(17008, 1 /* Error */, "JSX_element_0_has_no_corresponding_closing_tag_17008", "JSX element '{0}' has no corresponding closing tag."),
                    super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class: diag(17009, 1 /* Error */, "super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class_17009", "'super' must be called before accessing 'this' in the constructor of a derived class."),
                    Unknown_type_acquisition_option_0: diag(17010, 1 /* Error */, "Unknown_type_acquisition_option_0_17010", "Unknown type acquisition option '{0}'."),
                    super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class: diag(17011, 1 /* Error */, "super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class_17011", "'super' must be called before accessing a property of 'super' in the constructor of a derived class."),
                    _0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2: diag(17012, 1 /* Error */, "_0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2_17012", "'{0}' is not a valid meta-property for keyword '{1}'. Did you mean '{2}'?"),
                    Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constructor: diag(17013, 1 /* Error */, "Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constru_17013", "Meta-property '{0}' is only allowed in the body of a function declaration, function expression, or constructor."),
                    JSX_fragment_has_no_corresponding_closing_tag: diag(17014, 1 /* Error */, "JSX_fragment_has_no_corresponding_closing_tag_17014", "JSX fragment has no corresponding closing tag."),
                    Expected_corresponding_closing_tag_for_JSX_fragment: diag(17015, 1 /* Error */, "Expected_corresponding_closing_tag_for_JSX_fragment_17015", "Expected corresponding closing tag for JSX fragment."),
                    The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_compiler_option: diag(17016, 1 /* Error */, "The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_com_17016", "The 'jsxFragmentFactory' compiler option must be provided to use JSX fragments with the 'jsxFactory' compiler option."),
                    An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments: diag(17017, 1 /* Error */, "An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments_17017", "An @jsxFrag pragma is required when using an @jsx pragma with JSX fragments."),
                    Unknown_type_acquisition_option_0_Did_you_mean_1: diag(17018, 1 /* Error */, "Unknown_type_acquisition_option_0_Did_you_mean_1_17018", "Unknown type acquisition option '{0}'. Did you mean '{1}'?"),
                    _0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1: diag(17019, 1 /* Error */, "_0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1_17019", "'{0}' at the end of a type is not valid TypeScript syntax. Did you mean to write '{1}'?"),
                    _0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1: diag(17020, 1 /* Error */, "_0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1_17020", "'{0}' at the start of a type is not valid TypeScript syntax. Did you mean to write '{1}'?"),
                    Circularity_detected_while_resolving_configuration_Colon_0: diag(18e3, 1 /* Error */, "Circularity_detected_while_resolving_configuration_Colon_0_18000", "Circularity detected while resolving configuration: {0}"),
                    The_files_list_in_config_file_0_is_empty: diag(18002, 1 /* Error */, "The_files_list_in_config_file_0_is_empty_18002", "The 'files' list in config file '{0}' is empty."),
                    No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2: diag(18003, 1 /* Error */, "No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2_18003", "No inputs were found in config file '{0}'. Specified 'include' paths were '{1}' and 'exclude' paths were '{2}'."),
                    File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module: diag(80001, 2 /* Suggestion */, "File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module_80001", "File is a CommonJS module; it may be converted to an ES module."),
                    This_constructor_function_may_be_converted_to_a_class_declaration: diag(80002, 2 /* Suggestion */, "This_constructor_function_may_be_converted_to_a_class_declaration_80002", "This constructor function may be converted to a class declaration."),
                    Import_may_be_converted_to_a_default_import: diag(80003, 2 /* Suggestion */, "Import_may_be_converted_to_a_default_import_80003", "Import may be converted to a default import."),
                    JSDoc_types_may_be_moved_to_TypeScript_types: diag(80004, 2 /* Suggestion */, "JSDoc_types_may_be_moved_to_TypeScript_types_80004", "JSDoc types may be moved to TypeScript types."),
                    require_call_may_be_converted_to_an_import: diag(80005, 2 /* Suggestion */, "require_call_may_be_converted_to_an_import_80005", "'require' call may be converted to an import."),
                    This_may_be_converted_to_an_async_function: diag(80006, 2 /* Suggestion */, "This_may_be_converted_to_an_async_function_80006", "This may be converted to an async function."),
                    await_has_no_effect_on_the_type_of_this_expression: diag(80007, 2 /* Suggestion */, "await_has_no_effect_on_the_type_of_this_expression_80007", "'await' has no effect on the type of this expression."),
                    Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers: diag(80008, 2 /* Suggestion */, "Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accur_80008", "Numeric literals with absolute values equal to 2^53 or greater are too large to be represented accurately as integers."),
                    Add_missing_super_call: diag(90001, 3 /* Message */, "Add_missing_super_call_90001", "Add missing 'super()' call"),
                    Make_super_call_the_first_statement_in_the_constructor: diag(90002, 3 /* Message */, "Make_super_call_the_first_statement_in_the_constructor_90002", "Make 'super()' call the first statement in the constructor"),
                    Change_extends_to_implements: diag(90003, 3 /* Message */, "Change_extends_to_implements_90003", "Change 'extends' to 'implements'"),
                    Remove_unused_declaration_for_Colon_0: diag(90004, 3 /* Message */, "Remove_unused_declaration_for_Colon_0_90004", "Remove unused declaration for: '{0}'"),
                    Remove_import_from_0: diag(90005, 3 /* Message */, "Remove_import_from_0_90005", "Remove import from '{0}'"),
                    Implement_interface_0: diag(90006, 3 /* Message */, "Implement_interface_0_90006", "Implement interface '{0}'"),
                    Implement_inherited_abstract_class: diag(90007, 3 /* Message */, "Implement_inherited_abstract_class_90007", "Implement inherited abstract class"),
                    Add_0_to_unresolved_variable: diag(90008, 3 /* Message */, "Add_0_to_unresolved_variable_90008", "Add '{0}.' to unresolved variable"),
                    Remove_variable_statement: diag(90010, 3 /* Message */, "Remove_variable_statement_90010", "Remove variable statement"),
                    Remove_template_tag: diag(90011, 3 /* Message */, "Remove_template_tag_90011", "Remove template tag"),
                    Remove_type_parameters: diag(90012, 3 /* Message */, "Remove_type_parameters_90012", "Remove type parameters"),
                    Import_0_from_1: diag(90013, 3 /* Message */, "Import_0_from_1_90013", `Import '{0}' from "{1}"`),
                    Change_0_to_1: diag(90014, 3 /* Message */, "Change_0_to_1_90014", "Change '{0}' to '{1}'"),
                    Declare_property_0: diag(90016, 3 /* Message */, "Declare_property_0_90016", "Declare property '{0}'"),
                    Add_index_signature_for_property_0: diag(90017, 3 /* Message */, "Add_index_signature_for_property_0_90017", "Add index signature for property '{0}'"),
                    Disable_checking_for_this_file: diag(90018, 3 /* Message */, "Disable_checking_for_this_file_90018", "Disable checking for this file"),
                    Ignore_this_error_message: diag(90019, 3 /* Message */, "Ignore_this_error_message_90019", "Ignore this error message"),
                    Initialize_property_0_in_the_constructor: diag(90020, 3 /* Message */, "Initialize_property_0_in_the_constructor_90020", "Initialize property '{0}' in the constructor"),
                    Initialize_static_property_0: diag(90021, 3 /* Message */, "Initialize_static_property_0_90021", "Initialize static property '{0}'"),
                    Change_spelling_to_0: diag(90022, 3 /* Message */, "Change_spelling_to_0_90022", "Change spelling to '{0}'"),
                    Declare_method_0: diag(90023, 3 /* Message */, "Declare_method_0_90023", "Declare method '{0}'"),
                    Declare_static_method_0: diag(90024, 3 /* Message */, "Declare_static_method_0_90024", "Declare static method '{0}'"),
                    Prefix_0_with_an_underscore: diag(90025, 3 /* Message */, "Prefix_0_with_an_underscore_90025", "Prefix '{0}' with an underscore"),
                    Rewrite_as_the_indexed_access_type_0: diag(90026, 3 /* Message */, "Rewrite_as_the_indexed_access_type_0_90026", "Rewrite as the indexed access type '{0}'"),
                    Declare_static_property_0: diag(90027, 3 /* Message */, "Declare_static_property_0_90027", "Declare static property '{0}'"),
                    Call_decorator_expression: diag(90028, 3 /* Message */, "Call_decorator_expression_90028", "Call decorator expression"),
                    Add_async_modifier_to_containing_function: diag(90029, 3 /* Message */, "Add_async_modifier_to_containing_function_90029", "Add async modifier to containing function"),
                    Replace_infer_0_with_unknown: diag(90030, 3 /* Message */, "Replace_infer_0_with_unknown_90030", "Replace 'infer {0}' with 'unknown'"),
                    Replace_all_unused_infer_with_unknown: diag(90031, 3 /* Message */, "Replace_all_unused_infer_with_unknown_90031", "Replace all unused 'infer' with 'unknown'"),
                    Add_parameter_name: diag(90034, 3 /* Message */, "Add_parameter_name_90034", "Add parameter name"),
                    Declare_private_property_0: diag(90035, 3 /* Message */, "Declare_private_property_0_90035", "Declare private property '{0}'"),
                    Replace_0_with_Promise_1: diag(90036, 3 /* Message */, "Replace_0_with_Promise_1_90036", "Replace '{0}' with 'Promise<{1}>'"),
                    Fix_all_incorrect_return_type_of_an_async_functions: diag(90037, 3 /* Message */, "Fix_all_incorrect_return_type_of_an_async_functions_90037", "Fix all incorrect return type of an async functions"),
                    Declare_private_method_0: diag(90038, 3 /* Message */, "Declare_private_method_0_90038", "Declare private method '{0}'"),
                    Remove_unused_destructuring_declaration: diag(90039, 3 /* Message */, "Remove_unused_destructuring_declaration_90039", "Remove unused destructuring declaration"),
                    Remove_unused_declarations_for_Colon_0: diag(90041, 3 /* Message */, "Remove_unused_declarations_for_Colon_0_90041", "Remove unused declarations for: '{0}'"),
                    Declare_a_private_field_named_0: diag(90053, 3 /* Message */, "Declare_a_private_field_named_0_90053", "Declare a private field named '{0}'."),
                    Includes_imports_of_types_referenced_by_0: diag(90054, 3 /* Message */, "Includes_imports_of_types_referenced_by_0_90054", "Includes imports of types referenced by '{0}'"),
                    Remove_type_from_import_declaration_from_0: diag(90055, 3 /* Message */, "Remove_type_from_import_declaration_from_0_90055", `Remove 'type' from import declaration from "{0}"`),
                    Remove_type_from_import_of_0_from_1: diag(90056, 3 /* Message */, "Remove_type_from_import_of_0_from_1_90056", `Remove 'type' from import of '{0}' from "{1}"`),
                    Add_import_from_0: diag(90057, 3 /* Message */, "Add_import_from_0_90057", 'Add import from "{0}"'),
                    Update_import_from_0: diag(90058, 3 /* Message */, "Update_import_from_0_90058", 'Update import from "{0}"'),
                    Export_0_from_module_1: diag(90059, 3 /* Message */, "Export_0_from_module_1_90059", "Export '{0}' from module '{1}'"),
                    Export_all_referenced_locals: diag(90060, 3 /* Message */, "Export_all_referenced_locals_90060", "Export all referenced locals"),
                    Convert_function_to_an_ES2015_class: diag(95001, 3 /* Message */, "Convert_function_to_an_ES2015_class_95001", "Convert function to an ES2015 class"),
                    Convert_0_to_1_in_0: diag(95003, 3 /* Message */, "Convert_0_to_1_in_0_95003", "Convert '{0}' to '{1} in {0}'"),
                    Extract_to_0_in_1: diag(95004, 3 /* Message */, "Extract_to_0_in_1_95004", "Extract to {0} in {1}"),
                    Extract_function: diag(95005, 3 /* Message */, "Extract_function_95005", "Extract function"),
                    Extract_constant: diag(95006, 3 /* Message */, "Extract_constant_95006", "Extract constant"),
                    Extract_to_0_in_enclosing_scope: diag(95007, 3 /* Message */, "Extract_to_0_in_enclosing_scope_95007", "Extract to {0} in enclosing scope"),
                    Extract_to_0_in_1_scope: diag(95008, 3 /* Message */, "Extract_to_0_in_1_scope_95008", "Extract to {0} in {1} scope"),
                    Annotate_with_type_from_JSDoc: diag(95009, 3 /* Message */, "Annotate_with_type_from_JSDoc_95009", "Annotate with type from JSDoc"),
                    Infer_type_of_0_from_usage: diag(95011, 3 /* Message */, "Infer_type_of_0_from_usage_95011", "Infer type of '{0}' from usage"),
                    Infer_parameter_types_from_usage: diag(95012, 3 /* Message */, "Infer_parameter_types_from_usage_95012", "Infer parameter types from usage"),
                    Convert_to_default_import: diag(95013, 3 /* Message */, "Convert_to_default_import_95013", "Convert to default import"),
                    Install_0: diag(95014, 3 /* Message */, "Install_0_95014", "Install '{0}'"),
                    Replace_import_with_0: diag(95015, 3 /* Message */, "Replace_import_with_0_95015", "Replace import with '{0}'."),
                    Use_synthetic_default_member: diag(95016, 3 /* Message */, "Use_synthetic_default_member_95016", "Use synthetic 'default' member."),
                    Convert_to_ES_module: diag(95017, 3 /* Message */, "Convert_to_ES_module_95017", "Convert to ES module"),
                    Add_undefined_type_to_property_0: diag(95018, 3 /* Message */, "Add_undefined_type_to_property_0_95018", "Add 'undefined' type to property '{0}'"),
                    Add_initializer_to_property_0: diag(95019, 3 /* Message */, "Add_initializer_to_property_0_95019", "Add initializer to property '{0}'"),
                    Add_definite_assignment_assertion_to_property_0: diag(95020, 3 /* Message */, "Add_definite_assignment_assertion_to_property_0_95020", "Add definite assignment assertion to property '{0}'"),
                    Convert_all_type_literals_to_mapped_type: diag(95021, 3 /* Message */, "Convert_all_type_literals_to_mapped_type_95021", "Convert all type literals to mapped type"),
                    Add_all_missing_members: diag(95022, 3 /* Message */, "Add_all_missing_members_95022", "Add all missing members"),
                    Infer_all_types_from_usage: diag(95023, 3 /* Message */, "Infer_all_types_from_usage_95023", "Infer all types from usage"),
                    Delete_all_unused_declarations: diag(95024, 3 /* Message */, "Delete_all_unused_declarations_95024", "Delete all unused declarations"),
                    Prefix_all_unused_declarations_with_where_possible: diag(95025, 3 /* Message */, "Prefix_all_unused_declarations_with_where_possible_95025", "Prefix all unused declarations with '_' where possible"),
                    Fix_all_detected_spelling_errors: diag(95026, 3 /* Message */, "Fix_all_detected_spelling_errors_95026", "Fix all detected spelling errors"),
                    Add_initializers_to_all_uninitialized_properties: diag(95027, 3 /* Message */, "Add_initializers_to_all_uninitialized_properties_95027", "Add initializers to all uninitialized properties"),
                    Add_definite_assignment_assertions_to_all_uninitialized_properties: diag(95028, 3 /* Message */, "Add_definite_assignment_assertions_to_all_uninitialized_properties_95028", "Add definite assignment assertions to all uninitialized properties"),
                    Add_undefined_type_to_all_uninitialized_properties: diag(95029, 3 /* Message */, "Add_undefined_type_to_all_uninitialized_properties_95029", "Add undefined type to all uninitialized properties"),
                    Change_all_jsdoc_style_types_to_TypeScript: diag(95030, 3 /* Message */, "Change_all_jsdoc_style_types_to_TypeScript_95030", "Change all jsdoc-style types to TypeScript"),
                    Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types: diag(95031, 3 /* Message */, "Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types_95031", "Change all jsdoc-style types to TypeScript (and add '| undefined' to nullable types)"),
                    Implement_all_unimplemented_interfaces: diag(95032, 3 /* Message */, "Implement_all_unimplemented_interfaces_95032", "Implement all unimplemented interfaces"),
                    Install_all_missing_types_packages: diag(95033, 3 /* Message */, "Install_all_missing_types_packages_95033", "Install all missing types packages"),
                    Rewrite_all_as_indexed_access_types: diag(95034, 3 /* Message */, "Rewrite_all_as_indexed_access_types_95034", "Rewrite all as indexed access types"),
                    Convert_all_to_default_imports: diag(95035, 3 /* Message */, "Convert_all_to_default_imports_95035", "Convert all to default imports"),
                    Make_all_super_calls_the_first_statement_in_their_constructor: diag(95036, 3 /* Message */, "Make_all_super_calls_the_first_statement_in_their_constructor_95036", "Make all 'super()' calls the first statement in their constructor"),
                    Add_qualifier_to_all_unresolved_variables_matching_a_member_name: diag(95037, 3 /* Message */, "Add_qualifier_to_all_unresolved_variables_matching_a_member_name_95037", "Add qualifier to all unresolved variables matching a member name"),
                    Change_all_extended_interfaces_to_implements: diag(95038, 3 /* Message */, "Change_all_extended_interfaces_to_implements_95038", "Change all extended interfaces to 'implements'"),
                    Add_all_missing_super_calls: diag(95039, 3 /* Message */, "Add_all_missing_super_calls_95039", "Add all missing super calls"),
                    Implement_all_inherited_abstract_classes: diag(95040, 3 /* Message */, "Implement_all_inherited_abstract_classes_95040", "Implement all inherited abstract classes"),
                    Add_all_missing_async_modifiers: diag(95041, 3 /* Message */, "Add_all_missing_async_modifiers_95041", "Add all missing 'async' modifiers"),
                    Add_ts_ignore_to_all_error_messages: diag(95042, 3 /* Message */, "Add_ts_ignore_to_all_error_messages_95042", "Add '@ts-ignore' to all error messages"),
                    Annotate_everything_with_types_from_JSDoc: diag(95043, 3 /* Message */, "Annotate_everything_with_types_from_JSDoc_95043", "Annotate everything with types from JSDoc"),
                    Add_to_all_uncalled_decorators: diag(95044, 3 /* Message */, "Add_to_all_uncalled_decorators_95044", "Add '()' to all uncalled decorators"),
                    Convert_all_constructor_functions_to_classes: diag(95045, 3 /* Message */, "Convert_all_constructor_functions_to_classes_95045", "Convert all constructor functions to classes"),
                    Generate_get_and_set_accessors: diag(95046, 3 /* Message */, "Generate_get_and_set_accessors_95046", "Generate 'get' and 'set' accessors"),
                    Convert_require_to_import: diag(95047, 3 /* Message */, "Convert_require_to_import_95047", "Convert 'require' to 'import'"),
                    Convert_all_require_to_import: diag(95048, 3 /* Message */, "Convert_all_require_to_import_95048", "Convert all 'require' to 'import'"),
                    Move_to_a_new_file: diag(95049, 3 /* Message */, "Move_to_a_new_file_95049", "Move to a new file"),
                    Remove_unreachable_code: diag(95050, 3 /* Message */, "Remove_unreachable_code_95050", "Remove unreachable code"),
                    Remove_all_unreachable_code: diag(95051, 3 /* Message */, "Remove_all_unreachable_code_95051", "Remove all unreachable code"),
                    Add_missing_typeof: diag(95052, 3 /* Message */, "Add_missing_typeof_95052", "Add missing 'typeof'"),
                    Remove_unused_label: diag(95053, 3 /* Message */, "Remove_unused_label_95053", "Remove unused label"),
                    Remove_all_unused_labels: diag(95054, 3 /* Message */, "Remove_all_unused_labels_95054", "Remove all unused labels"),
                    Convert_0_to_mapped_object_type: diag(95055, 3 /* Message */, "Convert_0_to_mapped_object_type_95055", "Convert '{0}' to mapped object type"),
                    Convert_namespace_import_to_named_imports: diag(95056, 3 /* Message */, "Convert_namespace_import_to_named_imports_95056", "Convert namespace import to named imports"),
                    Convert_named_imports_to_namespace_import: diag(95057, 3 /* Message */, "Convert_named_imports_to_namespace_import_95057", "Convert named imports to namespace import"),
                    Add_or_remove_braces_in_an_arrow_function: diag(95058, 3 /* Message */, "Add_or_remove_braces_in_an_arrow_function_95058", "Add or remove braces in an arrow function"),
                    Add_braces_to_arrow_function: diag(95059, 3 /* Message */, "Add_braces_to_arrow_function_95059", "Add braces to arrow function"),
                    Remove_braces_from_arrow_function: diag(95060, 3 /* Message */, "Remove_braces_from_arrow_function_95060", "Remove braces from arrow function"),
                    Convert_default_export_to_named_export: diag(95061, 3 /* Message */, "Convert_default_export_to_named_export_95061", "Convert default export to named export"),
                    Convert_named_export_to_default_export: diag(95062, 3 /* Message */, "Convert_named_export_to_default_export_95062", "Convert named export to default export"),
                    Add_missing_enum_member_0: diag(95063, 3 /* Message */, "Add_missing_enum_member_0_95063", "Add missing enum member '{0}'"),
                    Add_all_missing_imports: diag(95064, 3 /* Message */, "Add_all_missing_imports_95064", "Add all missing imports"),
                    Convert_to_async_function: diag(95065, 3 /* Message */, "Convert_to_async_function_95065", "Convert to async function"),
                    Convert_all_to_async_functions: diag(95066, 3 /* Message */, "Convert_all_to_async_functions_95066", "Convert all to async functions"),
                    Add_missing_call_parentheses: diag(95067, 3 /* Message */, "Add_missing_call_parentheses_95067", "Add missing call parentheses"),
                    Add_all_missing_call_parentheses: diag(95068, 3 /* Message */, "Add_all_missing_call_parentheses_95068", "Add all missing call parentheses"),
                    Add_unknown_conversion_for_non_overlapping_types: diag(95069, 3 /* Message */, "Add_unknown_conversion_for_non_overlapping_types_95069", "Add 'unknown' conversion for non-overlapping types"),
                    Add_unknown_to_all_conversions_of_non_overlapping_types: diag(95070, 3 /* Message */, "Add_unknown_to_all_conversions_of_non_overlapping_types_95070", "Add 'unknown' to all conversions of non-overlapping types"),
                    Add_missing_new_operator_to_call: diag(95071, 3 /* Message */, "Add_missing_new_operator_to_call_95071", "Add missing 'new' operator to call"),
                    Add_missing_new_operator_to_all_calls: diag(95072, 3 /* Message */, "Add_missing_new_operator_to_all_calls_95072", "Add missing 'new' operator to all calls"),
                    Add_names_to_all_parameters_without_names: diag(95073, 3 /* Message */, "Add_names_to_all_parameters_without_names_95073", "Add names to all parameters without names"),
                    Enable_the_experimentalDecorators_option_in_your_configuration_file: diag(95074, 3 /* Message */, "Enable_the_experimentalDecorators_option_in_your_configuration_file_95074", "Enable the 'experimentalDecorators' option in your configuration file"),
                    Convert_parameters_to_destructured_object: diag(95075, 3 /* Message */, "Convert_parameters_to_destructured_object_95075", "Convert parameters to destructured object"),
                    Extract_type: diag(95077, 3 /* Message */, "Extract_type_95077", "Extract type"),
                    Extract_to_type_alias: diag(95078, 3 /* Message */, "Extract_to_type_alias_95078", "Extract to type alias"),
                    Extract_to_typedef: diag(95079, 3 /* Message */, "Extract_to_typedef_95079", "Extract to typedef"),
                    Infer_this_type_of_0_from_usage: diag(95080, 3 /* Message */, "Infer_this_type_of_0_from_usage_95080", "Infer 'this' type of '{0}' from usage"),
                    Add_const_to_unresolved_variable: diag(95081, 3 /* Message */, "Add_const_to_unresolved_variable_95081", "Add 'const' to unresolved variable"),
                    Add_const_to_all_unresolved_variables: diag(95082, 3 /* Message */, "Add_const_to_all_unresolved_variables_95082", "Add 'const' to all unresolved variables"),
                    Add_await: diag(95083, 3 /* Message */, "Add_await_95083", "Add 'await'"),
                    Add_await_to_initializer_for_0: diag(95084, 3 /* Message */, "Add_await_to_initializer_for_0_95084", "Add 'await' to initializer for '{0}'"),
                    Fix_all_expressions_possibly_missing_await: diag(95085, 3 /* Message */, "Fix_all_expressions_possibly_missing_await_95085", "Fix all expressions possibly missing 'await'"),
                    Remove_unnecessary_await: diag(95086, 3 /* Message */, "Remove_unnecessary_await_95086", "Remove unnecessary 'await'"),
                    Remove_all_unnecessary_uses_of_await: diag(95087, 3 /* Message */, "Remove_all_unnecessary_uses_of_await_95087", "Remove all unnecessary uses of 'await'"),
                    Enable_the_jsx_flag_in_your_configuration_file: diag(95088, 3 /* Message */, "Enable_the_jsx_flag_in_your_configuration_file_95088", "Enable the '--jsx' flag in your configuration file"),
                    Add_await_to_initializers: diag(95089, 3 /* Message */, "Add_await_to_initializers_95089", "Add 'await' to initializers"),
                    Extract_to_interface: diag(95090, 3 /* Message */, "Extract_to_interface_95090", "Extract to interface"),
                    Convert_to_a_bigint_numeric_literal: diag(95091, 3 /* Message */, "Convert_to_a_bigint_numeric_literal_95091", "Convert to a bigint numeric literal"),
                    Convert_all_to_bigint_numeric_literals: diag(95092, 3 /* Message */, "Convert_all_to_bigint_numeric_literals_95092", "Convert all to bigint numeric literals"),
                    Convert_const_to_let: diag(95093, 3 /* Message */, "Convert_const_to_let_95093", "Convert 'const' to 'let'"),
                    Prefix_with_declare: diag(95094, 3 /* Message */, "Prefix_with_declare_95094", "Prefix with 'declare'"),
                    Prefix_all_incorrect_property_declarations_with_declare: diag(95095, 3 /* Message */, "Prefix_all_incorrect_property_declarations_with_declare_95095", "Prefix all incorrect property declarations with 'declare'"),
                    Convert_to_template_string: diag(95096, 3 /* Message */, "Convert_to_template_string_95096", "Convert to template string"),
                    Add_export_to_make_this_file_into_a_module: diag(95097, 3 /* Message */, "Add_export_to_make_this_file_into_a_module_95097", "Add 'export {}' to make this file into a module"),
                    Set_the_target_option_in_your_configuration_file_to_0: diag(95098, 3 /* Message */, "Set_the_target_option_in_your_configuration_file_to_0_95098", "Set the 'target' option in your configuration file to '{0}'"),
                    Set_the_module_option_in_your_configuration_file_to_0: diag(95099, 3 /* Message */, "Set_the_module_option_in_your_configuration_file_to_0_95099", "Set the 'module' option in your configuration file to '{0}'"),
                    Convert_invalid_character_to_its_html_entity_code: diag(95100, 3 /* Message */, "Convert_invalid_character_to_its_html_entity_code_95100", "Convert invalid character to its html entity code"),
                    Convert_all_invalid_characters_to_HTML_entity_code: diag(95101, 3 /* Message */, "Convert_all_invalid_characters_to_HTML_entity_code_95101", "Convert all invalid characters to HTML entity code"),
                    Convert_all_const_to_let: diag(95102, 3 /* Message */, "Convert_all_const_to_let_95102", "Convert all 'const' to 'let'"),
                    Convert_function_expression_0_to_arrow_function: diag(95105, 3 /* Message */, "Convert_function_expression_0_to_arrow_function_95105", "Convert function expression '{0}' to arrow function"),
                    Convert_function_declaration_0_to_arrow_function: diag(95106, 3 /* Message */, "Convert_function_declaration_0_to_arrow_function_95106", "Convert function declaration '{0}' to arrow function"),
                    Fix_all_implicit_this_errors: diag(95107, 3 /* Message */, "Fix_all_implicit_this_errors_95107", "Fix all implicit-'this' errors"),
                    Wrap_invalid_character_in_an_expression_container: diag(95108, 3 /* Message */, "Wrap_invalid_character_in_an_expression_container_95108", "Wrap invalid character in an expression container"),
                    Wrap_all_invalid_characters_in_an_expression_container: diag(95109, 3 /* Message */, "Wrap_all_invalid_characters_in_an_expression_container_95109", "Wrap all invalid characters in an expression container"),
                    Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file: diag(95110, 3 /* Message */, "Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file_95110", "Visit https://aka.ms/tsconfig to read more about this file"),
                    Add_a_return_statement: diag(95111, 3 /* Message */, "Add_a_return_statement_95111", "Add a return statement"),
                    Remove_braces_from_arrow_function_body: diag(95112, 3 /* Message */, "Remove_braces_from_arrow_function_body_95112", "Remove braces from arrow function body"),
                    Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal: diag(95113, 3 /* Message */, "Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal_95113", "Wrap the following body with parentheses which should be an object literal"),
                    Add_all_missing_return_statement: diag(95114, 3 /* Message */, "Add_all_missing_return_statement_95114", "Add all missing return statement"),
                    Remove_braces_from_all_arrow_function_bodies_with_relevant_issues: diag(95115, 3 /* Message */, "Remove_braces_from_all_arrow_function_bodies_with_relevant_issues_95115", "Remove braces from all arrow function bodies with relevant issues"),
                    Wrap_all_object_literal_with_parentheses: diag(95116, 3 /* Message */, "Wrap_all_object_literal_with_parentheses_95116", "Wrap all object literal with parentheses"),
                    Move_labeled_tuple_element_modifiers_to_labels: diag(95117, 3 /* Message */, "Move_labeled_tuple_element_modifiers_to_labels_95117", "Move labeled tuple element modifiers to labels"),
                    Convert_overload_list_to_single_signature: diag(95118, 3 /* Message */, "Convert_overload_list_to_single_signature_95118", "Convert overload list to single signature"),
                    Generate_get_and_set_accessors_for_all_overriding_properties: diag(95119, 3 /* Message */, "Generate_get_and_set_accessors_for_all_overriding_properties_95119", "Generate 'get' and 'set' accessors for all overriding properties"),
                    Wrap_in_JSX_fragment: diag(95120, 3 /* Message */, "Wrap_in_JSX_fragment_95120", "Wrap in JSX fragment"),
                    Wrap_all_unparented_JSX_in_JSX_fragment: diag(95121, 3 /* Message */, "Wrap_all_unparented_JSX_in_JSX_fragment_95121", "Wrap all unparented JSX in JSX fragment"),
                    Convert_arrow_function_or_function_expression: diag(95122, 3 /* Message */, "Convert_arrow_function_or_function_expression_95122", "Convert arrow function or function expression"),
                    Convert_to_anonymous_function: diag(95123, 3 /* Message */, "Convert_to_anonymous_function_95123", "Convert to anonymous function"),
                    Convert_to_named_function: diag(95124, 3 /* Message */, "Convert_to_named_function_95124", "Convert to named function"),
                    Convert_to_arrow_function: diag(95125, 3 /* Message */, "Convert_to_arrow_function_95125", "Convert to arrow function"),
                    Remove_parentheses: diag(95126, 3 /* Message */, "Remove_parentheses_95126", "Remove parentheses"),
                    Could_not_find_a_containing_arrow_function: diag(95127, 3 /* Message */, "Could_not_find_a_containing_arrow_function_95127", "Could not find a containing arrow function"),
                    Containing_function_is_not_an_arrow_function: diag(95128, 3 /* Message */, "Containing_function_is_not_an_arrow_function_95128", "Containing function is not an arrow function"),
                    Could_not_find_export_statement: diag(95129, 3 /* Message */, "Could_not_find_export_statement_95129", "Could not find export statement"),
                    This_file_already_has_a_default_export: diag(95130, 3 /* Message */, "This_file_already_has_a_default_export_95130", "This file already has a default export"),
                    Could_not_find_import_clause: diag(95131, 3 /* Message */, "Could_not_find_import_clause_95131", "Could not find import clause"),
                    Could_not_find_namespace_import_or_named_imports: diag(95132, 3 /* Message */, "Could_not_find_namespace_import_or_named_imports_95132", "Could not find namespace import or named imports"),
                    Selection_is_not_a_valid_type_node: diag(95133, 3 /* Message */, "Selection_is_not_a_valid_type_node_95133", "Selection is not a valid type node"),
                    No_type_could_be_extracted_from_this_type_node: diag(95134, 3 /* Message */, "No_type_could_be_extracted_from_this_type_node_95134", "No type could be extracted from this type node"),
                    Could_not_find_property_for_which_to_generate_accessor: diag(95135, 3 /* Message */, "Could_not_find_property_for_which_to_generate_accessor_95135", "Could not find property for which to generate accessor"),
                    Name_is_not_valid: diag(95136, 3 /* Message */, "Name_is_not_valid_95136", "Name is not valid"),
                    Can_only_convert_property_with_modifier: diag(95137, 3 /* Message */, "Can_only_convert_property_with_modifier_95137", "Can only convert property with modifier"),
                    Switch_each_misused_0_to_1: diag(95138, 3 /* Message */, "Switch_each_misused_0_to_1_95138", "Switch each misused '{0}' to '{1}'"),
                    Convert_to_optional_chain_expression: diag(95139, 3 /* Message */, "Convert_to_optional_chain_expression_95139", "Convert to optional chain expression"),
                    Could_not_find_convertible_access_expression: diag(95140, 3 /* Message */, "Could_not_find_convertible_access_expression_95140", "Could not find convertible access expression"),
                    Could_not_find_matching_access_expressions: diag(95141, 3 /* Message */, "Could_not_find_matching_access_expressions_95141", "Could not find matching access expressions"),
                    Can_only_convert_logical_AND_access_chains: diag(95142, 3 /* Message */, "Can_only_convert_logical_AND_access_chains_95142", "Can only convert logical AND access chains"),
                    Add_void_to_Promise_resolved_without_a_value: diag(95143, 3 /* Message */, "Add_void_to_Promise_resolved_without_a_value_95143", "Add 'void' to Promise resolved without a value"),
                    Add_void_to_all_Promises_resolved_without_a_value: diag(95144, 3 /* Message */, "Add_void_to_all_Promises_resolved_without_a_value_95144", "Add 'void' to all Promises resolved without a value"),
                    Use_element_access_for_0: diag(95145, 3 /* Message */, "Use_element_access_for_0_95145", "Use element access for '{0}'"),
                    Use_element_access_for_all_undeclared_properties: diag(95146, 3 /* Message */, "Use_element_access_for_all_undeclared_properties_95146", "Use element access for all undeclared properties."),
                    Delete_all_unused_imports: diag(95147, 3 /* Message */, "Delete_all_unused_imports_95147", "Delete all unused imports"),
                    Infer_function_return_type: diag(95148, 3 /* Message */, "Infer_function_return_type_95148", "Infer function return type"),
                    Return_type_must_be_inferred_from_a_function: diag(95149, 3 /* Message */, "Return_type_must_be_inferred_from_a_function_95149", "Return type must be inferred from a function"),
                    Could_not_determine_function_return_type: diag(95150, 3 /* Message */, "Could_not_determine_function_return_type_95150", "Could not determine function return type"),
                    Could_not_convert_to_arrow_function: diag(95151, 3 /* Message */, "Could_not_convert_to_arrow_function_95151", "Could not convert to arrow function"),
                    Could_not_convert_to_named_function: diag(95152, 3 /* Message */, "Could_not_convert_to_named_function_95152", "Could not convert to named function"),
                    Could_not_convert_to_anonymous_function: diag(95153, 3 /* Message */, "Could_not_convert_to_anonymous_function_95153", "Could not convert to anonymous function"),
                    Can_only_convert_string_concatenation: diag(95154, 3 /* Message */, "Can_only_convert_string_concatenation_95154", "Can only convert string concatenation"),
                    Selection_is_not_a_valid_statement_or_statements: diag(95155, 3 /* Message */, "Selection_is_not_a_valid_statement_or_statements_95155", "Selection is not a valid statement or statements"),
                    Add_missing_function_declaration_0: diag(95156, 3 /* Message */, "Add_missing_function_declaration_0_95156", "Add missing function declaration '{0}'"),
                    Add_all_missing_function_declarations: diag(95157, 3 /* Message */, "Add_all_missing_function_declarations_95157", "Add all missing function declarations"),
                    Method_not_implemented: diag(95158, 3 /* Message */, "Method_not_implemented_95158", "Method not implemented."),
                    Function_not_implemented: diag(95159, 3 /* Message */, "Function_not_implemented_95159", "Function not implemented."),
                    Add_override_modifier: diag(95160, 3 /* Message */, "Add_override_modifier_95160", "Add 'override' modifier"),
                    Remove_override_modifier: diag(95161, 3 /* Message */, "Remove_override_modifier_95161", "Remove 'override' modifier"),
                    Add_all_missing_override_modifiers: diag(95162, 3 /* Message */, "Add_all_missing_override_modifiers_95162", "Add all missing 'override' modifiers"),
                    Remove_all_unnecessary_override_modifiers: diag(95163, 3 /* Message */, "Remove_all_unnecessary_override_modifiers_95163", "Remove all unnecessary 'override' modifiers"),
                    Can_only_convert_named_export: diag(95164, 3 /* Message */, "Can_only_convert_named_export_95164", "Can only convert named export"),
                    Add_missing_properties: diag(95165, 3 /* Message */, "Add_missing_properties_95165", "Add missing properties"),
                    Add_all_missing_properties: diag(95166, 3 /* Message */, "Add_all_missing_properties_95166", "Add all missing properties"),
                    Add_missing_attributes: diag(95167, 3 /* Message */, "Add_missing_attributes_95167", "Add missing attributes"),
                    Add_all_missing_attributes: diag(95168, 3 /* Message */, "Add_all_missing_attributes_95168", "Add all missing attributes"),
                    Add_undefined_to_optional_property_type: diag(95169, 3 /* Message */, "Add_undefined_to_optional_property_type_95169", "Add 'undefined' to optional property type"),
                    Convert_named_imports_to_default_import: diag(95170, 3 /* Message */, "Convert_named_imports_to_default_import_95170", "Convert named imports to default import"),
                    Delete_unused_param_tag_0: diag(95171, 3 /* Message */, "Delete_unused_param_tag_0_95171", "Delete unused '@param' tag '{0}'"),
                    Delete_all_unused_param_tags: diag(95172, 3 /* Message */, "Delete_all_unused_param_tags_95172", "Delete all unused '@param' tags"),
                    Rename_param_tag_name_0_to_1: diag(95173, 3 /* Message */, "Rename_param_tag_name_0_to_1_95173", "Rename '@param' tag name '{0}' to '{1}'"),
                    Use_0: diag(95174, 3 /* Message */, "Use_0_95174", "Use `{0}`."),
                    Use_Number_isNaN_in_all_conditions: diag(95175, 3 /* Message */, "Use_Number_isNaN_in_all_conditions_95175", "Use `Number.isNaN` in all conditions."),
                    No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer: diag(18004, 1 /* Error */, "No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer_18004", "No value exists in scope for the shorthand property '{0}'. Either declare one or provide an initializer."),
                    Classes_may_not_have_a_field_named_constructor: diag(18006, 1 /* Error */, "Classes_may_not_have_a_field_named_constructor_18006", "Classes may not have a field named 'constructor'."),
                    JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array: diag(18007, 1 /* Error */, "JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array_18007", "JSX expressions may not use the comma operator. Did you mean to write an array?"),
                    Private_identifiers_cannot_be_used_as_parameters: diag(18009, 1 /* Error */, "Private_identifiers_cannot_be_used_as_parameters_18009", "Private identifiers cannot be used as parameters."),
                    An_accessibility_modifier_cannot_be_used_with_a_private_identifier: diag(18010, 1 /* Error */, "An_accessibility_modifier_cannot_be_used_with_a_private_identifier_18010", "An accessibility modifier cannot be used with a private identifier."),
                    The_operand_of_a_delete_operator_cannot_be_a_private_identifier: diag(18011, 1 /* Error */, "The_operand_of_a_delete_operator_cannot_be_a_private_identifier_18011", "The operand of a 'delete' operator cannot be a private identifier."),
                    constructor_is_a_reserved_word: diag(18012, 1 /* Error */, "constructor_is_a_reserved_word_18012", "'#constructor' is a reserved word."),
                    Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier: diag(18013, 1 /* Error */, "Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier_18013", "Property '{0}' is not accessible outside class '{1}' because it has a private identifier."),
                    The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_private_identifier_with_the_same_spelling: diag(18014, 1 /* Error */, "The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_priv_18014", "The property '{0}' cannot be accessed on type '{1}' within this class because it is shadowed by another private identifier with the same spelling."),
                    Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2: diag(18015, 1 /* Error */, "Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2_18015", "Property '{0}' in type '{1}' refers to a different member that cannot be accessed from within type '{2}'."),
                    Private_identifiers_are_not_allowed_outside_class_bodies: diag(18016, 1 /* Error */, "Private_identifiers_are_not_allowed_outside_class_bodies_18016", "Private identifiers are not allowed outside class bodies."),
                    The_shadowing_declaration_of_0_is_defined_here: diag(18017, 1 /* Error */, "The_shadowing_declaration_of_0_is_defined_here_18017", "The shadowing declaration of '{0}' is defined here"),
                    The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here: diag(18018, 1 /* Error */, "The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here_18018", "The declaration of '{0}' that you probably intended to use is defined here"),
                    _0_modifier_cannot_be_used_with_a_private_identifier: diag(18019, 1 /* Error */, "_0_modifier_cannot_be_used_with_a_private_identifier_18019", "'{0}' modifier cannot be used with a private identifier."),
                    An_enum_member_cannot_be_named_with_a_private_identifier: diag(18024, 1 /* Error */, "An_enum_member_cannot_be_named_with_a_private_identifier_18024", "An enum member cannot be named with a private identifier."),
                    can_only_be_used_at_the_start_of_a_file: diag(18026, 1 /* Error */, "can_only_be_used_at_the_start_of_a_file_18026", "'#!' can only be used at the start of a file."),
                    Compiler_reserves_name_0_when_emitting_private_identifier_downlevel: diag(18027, 1 /* Error */, "Compiler_reserves_name_0_when_emitting_private_identifier_downlevel_18027", "Compiler reserves name '{0}' when emitting private identifier downlevel."),
                    Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher: diag(18028, 1 /* Error */, "Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher_18028", "Private identifiers are only available when targeting ECMAScript 2015 and higher."),
                    Private_identifiers_are_not_allowed_in_variable_declarations: diag(18029, 1 /* Error */, "Private_identifiers_are_not_allowed_in_variable_declarations_18029", "Private identifiers are not allowed in variable declarations."),
                    An_optional_chain_cannot_contain_private_identifiers: diag(18030, 1 /* Error */, "An_optional_chain_cannot_contain_private_identifiers_18030", "An optional chain cannot contain private identifiers."),
                    The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituents: diag(18031, 1 /* Error */, "The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituent_18031", "The intersection '{0}' was reduced to 'never' because property '{1}' has conflicting types in some constituents."),
                    The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_private_in_some: diag(18032, 1 /* Error */, "The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_pr_18032", "The intersection '{0}' was reduced to 'never' because property '{1}' exists in multiple constituents and is private in some."),
                    Type_0_is_not_assignable_to_type_1_as_required_for_computed_enum_member_values: diag(18033, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_as_required_for_computed_enum_member_values_18033", "Type '{0}' is not assignable to type '{1}' as required for computed enum member values."),
                    Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compiler_option_is_specified_e_g_Fragment: diag(18034, 3 /* Message */, "Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compi_18034", "Specify the JSX fragment factory function to use when targeting 'react' JSX emit with 'jsxFactory' compiler option is specified, e.g. 'Fragment'."),
                    Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name: diag(18035, 1 /* Error */, "Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name_18035", "Invalid value for 'jsxFragmentFactory'. '{0}' is not a valid identifier or qualified-name."),
                    Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator: diag(18036, 1 /* Error */, "Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_dec_18036", "Class decorators can't be used with static private identifier. Consider removing the experimental decorator."),
                    Await_expression_cannot_be_used_inside_a_class_static_block: diag(18037, 1 /* Error */, "Await_expression_cannot_be_used_inside_a_class_static_block_18037", "Await expression cannot be used inside a class static block."),
                    For_await_loops_cannot_be_used_inside_a_class_static_block: diag(18038, 1 /* Error */, "For_await_loops_cannot_be_used_inside_a_class_static_block_18038", "'For await' loops cannot be used inside a class static block."),
                    Invalid_use_of_0_It_cannot_be_used_inside_a_class_static_block: diag(18039, 1 /* Error */, "Invalid_use_of_0_It_cannot_be_used_inside_a_class_static_block_18039", "Invalid use of '{0}'. It cannot be used inside a class static block."),
                    A_return_statement_cannot_be_used_inside_a_class_static_block: diag(18041, 1 /* Error */, "A_return_statement_cannot_be_used_inside_a_class_static_block_18041", "A 'return' statement cannot be used inside a class static block."),
                    _0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation: diag(18042, 1 /* Error */, "_0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation_18042", "'{0}' is a type and cannot be imported in JavaScript files. Use '{1}' in a JSDoc type annotation."),
                    Types_cannot_appear_in_export_declarations_in_JavaScript_files: diag(18043, 1 /* Error */, "Types_cannot_appear_in_export_declarations_in_JavaScript_files_18043", "Types cannot appear in export declarations in JavaScript files."),
                    _0_is_automatically_exported_here: diag(18044, 3 /* Message */, "_0_is_automatically_exported_here_18044", "'{0}' is automatically exported here."),
                    Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher: diag(18045, 1 /* Error */, "Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher_18045", "Properties with the 'accessor' modifier are only available when targeting ECMAScript 2015 and higher."),
                    _0_is_of_type_unknown: diag(18046, 1 /* Error */, "_0_is_of_type_unknown_18046", "'{0}' is of type 'unknown'."),
                    _0_is_possibly_null: diag(18047, 1 /* Error */, "_0_is_possibly_null_18047", "'{0}' is possibly 'null'."),
                    _0_is_possibly_undefined: diag(18048, 1 /* Error */, "_0_is_possibly_undefined_18048", "'{0}' is possibly 'undefined'."),
                    _0_is_possibly_null_or_undefined: diag(18049, 1 /* Error */, "_0_is_possibly_null_or_undefined_18049", "'{0}' is possibly 'null' or 'undefined'."),
                    The_value_0_cannot_be_used_here: diag(18050, 1 /* Error */, "The_value_0_cannot_be_used_here_18050", "The value '{0}' cannot be used here."),
                    Compiler_option_0_cannot_be_given_an_empty_string: diag(18051, 1 /* Error */, "Compiler_option_0_cannot_be_given_an_empty_string_18051", "Compiler option '{0}' cannot be given an empty string.")
                };
            }
        });
        // src/compiler/scanner.ts
        function tokenIsIdentifierOrKeyword(token) {
            return token >= 79 /* Identifier */;
        }
        function tokenIsIdentifierOrKeywordOrGreaterThan(token) {
            return token === 31 /* GreaterThanToken */ || tokenIsIdentifierOrKeyword(token);
        }
        function lookupInUnicodeMap(code, map2) {
            if (code < map2[0]) {
                return false;
            }
            let lo = 0;
            let hi = map2.length;
            let mid;
            while (lo + 1 < hi) {
                mid = lo + (hi - lo) / 2;
                mid -= mid % 2;
                if (map2[mid] <= code && code <= map2[mid + 1]) {
                    return true;
                }
                if (code < map2[mid]) {
                    hi = mid;
                }
                else {
                    lo = mid + 2;
                }
            }
            return false;
        }
        function isUnicodeIdentifierStart(code, languageVersion) {
            return languageVersion >= 2 /* ES2015 */ ? lookupInUnicodeMap(code, unicodeESNextIdentifierStart) : languageVersion === 1 /* ES5 */ ? lookupInUnicodeMap(code, unicodeES5IdentifierStart) : lookupInUnicodeMap(code, unicodeES3IdentifierStart);
        }
        function isUnicodeIdentifierPart(code, languageVersion) {
            return languageVersion >= 2 /* ES2015 */ ? lookupInUnicodeMap(code, unicodeESNextIdentifierPart) : languageVersion === 1 /* ES5 */ ? lookupInUnicodeMap(code, unicodeES5IdentifierPart) : lookupInUnicodeMap(code, unicodeES3IdentifierPart);
        }
        function makeReverseMap(source) {
            const result = [];
            source.forEach((value, name) => {
                result[value] = name;
            });
            return result;
        }
        function tokenToString(t) {
            return tokenStrings[t];
        }
        function stringToToken(s) {
            return textToToken.get(s);
        }
        function computeLineStarts(text) {
            const result = [];
            let pos = 0;
            let lineStart = 0;
            while (pos < text.length) {
                const ch = text.charCodeAt(pos);
                pos++;
                switch (ch) {
                    case 13 /* carriageReturn */:
                        if (text.charCodeAt(pos) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                        result.push(lineStart);
                        lineStart = pos;
                        break;
                    default:
                        if (ch > 127 /* maxAsciiCharacter */ && isLineBreak(ch)) {
                            result.push(lineStart);
                            lineStart = pos;
                        }
                        break;
                }
            }
            result.push(lineStart);
            return result;
        }
        function getPositionOfLineAndCharacter(sourceFile, line, character, allowEdits) {
            return sourceFile.getPositionOfLineAndCharacter ? sourceFile.getPositionOfLineAndCharacter(line, character, allowEdits) : computePositionOfLineAndCharacter(getLineStarts(sourceFile), line, character, sourceFile.text, allowEdits);
        }
        function computePositionOfLineAndCharacter(lineStarts, line, character, debugText, allowEdits) {
            if (line < 0 || line >= lineStarts.length) {
                if (allowEdits) {
                    line = line < 0 ? 0 : line >= lineStarts.length ? lineStarts.length - 1 : line;
                }
                else {
                    Debug.fail(`Bad line number. Line: ${line}, lineStarts.length: ${lineStarts.length} , line map is correct? ${debugText !== void 0 ? arraysEqual(lineStarts, computeLineStarts(debugText)) : "unknown"}`);
                }
            }
            const res = lineStarts[line] + character;
            if (allowEdits) {
                return res > lineStarts[line + 1] ? lineStarts[line + 1] : typeof debugText === "string" && res > debugText.length ? debugText.length : res;
            }
            if (line < lineStarts.length - 1) {
                Debug.assert(res < lineStarts[line + 1]);
            }
            else if (debugText !== void 0) {
                Debug.assert(res <= debugText.length);
            }
            return res;
        }
        function getLineStarts(sourceFile) {
            return sourceFile.lineMap || (sourceFile.lineMap = computeLineStarts(sourceFile.text));
        }
        function computeLineAndCharacterOfPosition(lineStarts, position) {
            const lineNumber = computeLineOfPosition(lineStarts, position);
            return {
                line: lineNumber,
                character: position - lineStarts[lineNumber]
            };
        }
        function computeLineOfPosition(lineStarts, position, lowerBound) {
            let lineNumber = binarySearch(lineStarts, position, identity, compareValues, lowerBound);
            if (lineNumber < 0) {
                lineNumber = ~lineNumber - 1;
                Debug.assert(lineNumber !== -1, "position cannot precede the beginning of the file");
            }
            return lineNumber;
        }
        function getLinesBetweenPositions(sourceFile, pos1, pos2) {
            if (pos1 === pos2)
                return 0;
            const lineStarts = getLineStarts(sourceFile);
            const lower = Math.min(pos1, pos2);
            const isNegative = lower === pos2;
            const upper = isNegative ? pos1 : pos2;
            const lowerLine = computeLineOfPosition(lineStarts, lower);
            const upperLine = computeLineOfPosition(lineStarts, upper, lowerLine);
            return isNegative ? lowerLine - upperLine : upperLine - lowerLine;
        }
        function getLineAndCharacterOfPosition(sourceFile, position) {
            return computeLineAndCharacterOfPosition(getLineStarts(sourceFile), position);
        }
        function isWhiteSpaceLike(ch) {
            return isWhiteSpaceSingleLine(ch) || isLineBreak(ch);
        }
        function isWhiteSpaceSingleLine(ch) {
            return ch === 32 /* space */ || ch === 9 /* tab */ || ch === 11 /* verticalTab */ || ch === 12 /* formFeed */ || ch === 160 /* nonBreakingSpace */ || ch === 133 /* nextLine */ || ch === 5760 /* ogham */ || ch >= 8192 /* enQuad */ && ch <= 8203 /* zeroWidthSpace */ || ch === 8239 /* narrowNoBreakSpace */ || ch === 8287 /* mathematicalSpace */ || ch === 12288 /* ideographicSpace */ || ch === 65279 /* byteOrderMark */;
        }
        function isLineBreak(ch) {
            return ch === 10 /* lineFeed */ || ch === 13 /* carriageReturn */ || ch === 8232 /* lineSeparator */ || ch === 8233 /* paragraphSeparator */;
        }
        function isDigit(ch) {
            return ch >= 48 /* _0 */ && ch <= 57 /* _9 */;
        }
        function isHexDigit(ch) {
            return isDigit(ch) || ch >= 65 /* A */ && ch <= 70 /* F */ || ch >= 97 /* a */ && ch <= 102 /* f */;
        }
        function isCodePoint(code) {
            return code <= 1114111;
        }
        function isOctalDigit(ch) {
            return ch >= 48 /* _0 */ && ch <= 55 /* _7 */;
        }
        function couldStartTrivia(text, pos) {
            const ch = text.charCodeAt(pos);
            switch (ch) {
                case 13 /* carriageReturn */:
                case 10 /* lineFeed */:
                case 9 /* tab */:
                case 11 /* verticalTab */:
                case 12 /* formFeed */:
                case 32 /* space */:
                case 47 /* slash */:
                case 60 /* lessThan */:
                case 124 /* bar */:
                case 61 /* equals */:
                case 62 /* greaterThan */:
                    return true;
                case 35 /* hash */:
                    return pos === 0;
                default:
                    return ch > 127 /* maxAsciiCharacter */;
            }
        }
        function skipTrivia(text, pos, stopAfterLineBreak, stopAtComments, inJSDoc) {
            if (positionIsSynthesized(pos)) {
                return pos;
            }
            let canConsumeStar = false;
            while (true) {
                const ch = text.charCodeAt(pos);
                switch (ch) {
                    case 13 /* carriageReturn */:
                        if (text.charCodeAt(pos + 1) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                        pos++;
                        if (stopAfterLineBreak) {
                            return pos;
                        }
                        canConsumeStar = !!inJSDoc;
                        continue;
                    case 9 /* tab */:
                    case 11 /* verticalTab */:
                    case 12 /* formFeed */:
                    case 32 /* space */:
                        pos++;
                        continue;
                    case 47 /* slash */:
                        if (stopAtComments) {
                            break;
                        }
                        if (text.charCodeAt(pos + 1) === 47 /* slash */) {
                            pos += 2;
                            while (pos < text.length) {
                                if (isLineBreak(text.charCodeAt(pos))) {
                                    break;
                                }
                                pos++;
                            }
                            canConsumeStar = false;
                            continue;
                        }
                        if (text.charCodeAt(pos + 1) === 42 /* asterisk */) {
                            pos += 2;
                            while (pos < text.length) {
                                if (text.charCodeAt(pos) === 42 /* asterisk */ && text.charCodeAt(pos + 1) === 47 /* slash */) {
                                    pos += 2;
                                    break;
                                }
                                pos++;
                            }
                            canConsumeStar = false;
                            continue;
                        }
                        break;
                    case 60 /* lessThan */:
                    case 124 /* bar */:
                    case 61 /* equals */:
                    case 62 /* greaterThan */:
                        if (isConflictMarkerTrivia(text, pos)) {
                            pos = scanConflictMarkerTrivia(text, pos);
                            canConsumeStar = false;
                            continue;
                        }
                        break;
                    case 35 /* hash */:
                        if (pos === 0 && isShebangTrivia(text, pos)) {
                            pos = scanShebangTrivia(text, pos);
                            canConsumeStar = false;
                            continue;
                        }
                        break;
                    case 42 /* asterisk */:
                        if (canConsumeStar) {
                            pos++;
                            canConsumeStar = false;
                            continue;
                        }
                        break;
                    default:
                        if (ch > 127 /* maxAsciiCharacter */ && isWhiteSpaceLike(ch)) {
                            pos++;
                            continue;
                        }
                        break;
                }
                return pos;
            }
        }
        function isConflictMarkerTrivia(text, pos) {
            Debug.assert(pos >= 0);
            if (pos === 0 || isLineBreak(text.charCodeAt(pos - 1))) {
                const ch = text.charCodeAt(pos);
                if (pos + mergeConflictMarkerLength < text.length) {
                    for (let i = 0; i < mergeConflictMarkerLength; i++) {
                        if (text.charCodeAt(pos + i) !== ch) {
                            return false;
                        }
                    }
                    return ch === 61 /* equals */ || text.charCodeAt(pos + mergeConflictMarkerLength) === 32 /* space */;
                }
            }
            return false;
        }
        function scanConflictMarkerTrivia(text, pos, error) {
            if (error) {
                error(Diagnostics.Merge_conflict_marker_encountered, pos, mergeConflictMarkerLength);
            }
            const ch = text.charCodeAt(pos);
            const len = text.length;
            if (ch === 60 /* lessThan */ || ch === 62 /* greaterThan */) {
                while (pos < len && !isLineBreak(text.charCodeAt(pos))) {
                    pos++;
                }
            }
            else {
                Debug.assert(ch === 124 /* bar */ || ch === 61 /* equals */);
                while (pos < len) {
                    const currentChar = text.charCodeAt(pos);
                    if ((currentChar === 61 /* equals */ || currentChar === 62 /* greaterThan */) && currentChar !== ch && isConflictMarkerTrivia(text, pos)) {
                        break;
                    }
                    pos++;
                }
            }
            return pos;
        }
        function isShebangTrivia(text, pos) {
            Debug.assert(pos === 0);
            return shebangTriviaRegex.test(text);
        }
        function scanShebangTrivia(text, pos) {
            const shebang = shebangTriviaRegex.exec(text)[0];
            pos = pos + shebang.length;
            return pos;
        }
        function iterateCommentRanges(reduce, text, pos, trailing, cb, state, initial) {
            let pendingPos;
            let pendingEnd;
            let pendingKind;
            let pendingHasTrailingNewLine;
            let hasPendingCommentRange = false;
            let collecting = trailing;
            let accumulator = initial;
            if (pos === 0) {
                collecting = true;
                const shebang = getShebang(text);
                if (shebang) {
                    pos = shebang.length;
                }
            }
            scan: while (pos >= 0 && pos < text.length) {
                const ch = text.charCodeAt(pos);
                switch (ch) {
                    case 13 /* carriageReturn */:
                        if (text.charCodeAt(pos + 1) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                        pos++;
                        if (trailing) {
                            break scan;
                        }
                        collecting = true;
                        if (hasPendingCommentRange) {
                            pendingHasTrailingNewLine = true;
                        }
                        continue;
                    case 9 /* tab */:
                    case 11 /* verticalTab */:
                    case 12 /* formFeed */:
                    case 32 /* space */:
                        pos++;
                        continue;
                    case 47 /* slash */:
                        const nextChar = text.charCodeAt(pos + 1);
                        let hasTrailingNewLine = false;
                        if (nextChar === 47 /* slash */ || nextChar === 42 /* asterisk */) {
                            const kind = nextChar === 47 /* slash */ ? 2 /* SingleLineCommentTrivia */ : 3 /* MultiLineCommentTrivia */;
                            const startPos = pos;
                            pos += 2;
                            if (nextChar === 47 /* slash */) {
                                while (pos < text.length) {
                                    if (isLineBreak(text.charCodeAt(pos))) {
                                        hasTrailingNewLine = true;
                                        break;
                                    }
                                    pos++;
                                }
                            }
                            else {
                                while (pos < text.length) {
                                    if (text.charCodeAt(pos) === 42 /* asterisk */ && text.charCodeAt(pos + 1) === 47 /* slash */) {
                                        pos += 2;
                                        break;
                                    }
                                    pos++;
                                }
                            }
                            if (collecting) {
                                if (hasPendingCommentRange) {
                                    accumulator = cb(pendingPos, pendingEnd, pendingKind, pendingHasTrailingNewLine, state, accumulator);
                                    if (!reduce && accumulator) {
                                        return accumulator;
                                    }
                                }
                                pendingPos = startPos;
                                pendingEnd = pos;
                                pendingKind = kind;
                                pendingHasTrailingNewLine = hasTrailingNewLine;
                                hasPendingCommentRange = true;
                            }
                            continue;
                        }
                        break scan;
                    default:
                        if (ch > 127 /* maxAsciiCharacter */ && isWhiteSpaceLike(ch)) {
                            if (hasPendingCommentRange && isLineBreak(ch)) {
                                pendingHasTrailingNewLine = true;
                            }
                            pos++;
                            continue;
                        }
                        break scan;
                }
            }
            if (hasPendingCommentRange) {
                accumulator = cb(pendingPos, pendingEnd, pendingKind, pendingHasTrailingNewLine, state, accumulator);
            }
            return accumulator;
        }
        function forEachLeadingCommentRange(text, pos, cb, state) {
            return iterateCommentRanges(
            /*reduce*/
            false, text, pos, 
            /*trailing*/
            false, cb, state);
        }
        function forEachTrailingCommentRange(text, pos, cb, state) {
            return iterateCommentRanges(
            /*reduce*/
            false, text, pos, 
            /*trailing*/
            true, cb, state);
        }
        function reduceEachLeadingCommentRange(text, pos, cb, state, initial) {
            return iterateCommentRanges(
            /*reduce*/
            true, text, pos, 
            /*trailing*/
            false, cb, state, initial);
        }
        function reduceEachTrailingCommentRange(text, pos, cb, state, initial) {
            return iterateCommentRanges(
            /*reduce*/
            true, text, pos, 
            /*trailing*/
            true, cb, state, initial);
        }
        function appendCommentRange(pos, end, kind, hasTrailingNewLine, _state, comments = []) {
            comments.push({ kind, pos, end, hasTrailingNewLine });
            return comments;
        }
        function getLeadingCommentRanges(text, pos) {
            return reduceEachLeadingCommentRange(text, pos, appendCommentRange, 
            /*state*/
            void 0, 
            /*initial*/
            void 0);
        }
        function getTrailingCommentRanges(text, pos) {
            return reduceEachTrailingCommentRange(text, pos, appendCommentRange, 
            /*state*/
            void 0, 
            /*initial*/
            void 0);
        }
        function getShebang(text) {
            const match = shebangTriviaRegex.exec(text);
            if (match) {
                return match[0];
            }
        }
        function isIdentifierStart(ch, languageVersion) {
            return ch >= 65 /* A */ && ch <= 90 /* Z */ || ch >= 97 /* a */ && ch <= 122 /* z */ || ch === 36 /* $ */ || ch === 95 /* _ */ || ch > 127 /* maxAsciiCharacter */ && isUnicodeIdentifierStart(ch, languageVersion);
        }
        function isIdentifierPart(ch, languageVersion, identifierVariant) {
            return ch >= 65 /* A */ && ch <= 90 /* Z */ || ch >= 97 /* a */ && ch <= 122 /* z */ || ch >= 48 /* _0 */ && ch <= 57 /* _9 */ || ch === 36 /* $ */ || ch === 95 /* _ */ || // "-" and ":" are valid in JSX Identifiers
                (identifierVariant === 1 /* JSX */ ? ch === 45 /* minus */ || ch === 58 /* colon */ : false) || ch > 127 /* maxAsciiCharacter */ && isUnicodeIdentifierPart(ch, languageVersion);
        }
        function isIdentifierText(name, languageVersion, identifierVariant) {
            let ch = codePointAt(name, 0);
            if (!isIdentifierStart(ch, languageVersion)) {
                return false;
            }
            for (let i = charSize(ch); i < name.length; i += charSize(ch)) {
                if (!isIdentifierPart(ch = codePointAt(name, i), languageVersion, identifierVariant)) {
                    return false;
                }
            }
            return true;
        }
        function createScanner(languageVersion, skipTrivia2, languageVariant = 0 /* Standard */, textInitial, onError, start, length2) {
            var text = textInitial;
            var pos;
            var end;
            var startPos;
            var tokenPos;
            var token;
            var tokenValue;
            var tokenFlags;
            var commentDirectives;
            var inJSDocType = 0;
            setText(text, start, length2);
            var scanner2 = {
                getStartPos: () => startPos,
                getTextPos: () => pos,
                getToken: () => token,
                getTokenPos: () => tokenPos,
                getTokenText: () => text.substring(tokenPos, pos),
                getTokenValue: () => tokenValue,
                hasUnicodeEscape: () => (tokenFlags & 1024 /* UnicodeEscape */) !== 0,
                hasExtendedUnicodeEscape: () => (tokenFlags & 8 /* ExtendedUnicodeEscape */) !== 0,
                hasPrecedingLineBreak: () => (tokenFlags & 1 /* PrecedingLineBreak */) !== 0,
                hasPrecedingJSDocComment: () => (tokenFlags & 2 /* PrecedingJSDocComment */) !== 0,
                isIdentifier: () => token === 79 /* Identifier */ || token > 116 /* LastReservedWord */,
                isReservedWord: () => token >= 81 /* FirstReservedWord */ && token <= 116 /* LastReservedWord */,
                isUnterminated: () => (tokenFlags & 4 /* Unterminated */) !== 0,
                getCommentDirectives: () => commentDirectives,
                getNumericLiteralFlags: () => tokenFlags & 1008 /* NumericLiteralFlags */,
                getTokenFlags: () => tokenFlags,
                reScanGreaterToken,
                reScanAsteriskEqualsToken,
                reScanSlashToken,
                reScanTemplateToken,
                reScanTemplateHeadOrNoSubstitutionTemplate,
                scanJsxIdentifier,
                scanJsxAttributeValue,
                reScanJsxAttributeValue,
                reScanJsxToken,
                reScanLessThanToken,
                reScanHashToken,
                reScanQuestionToken,
                reScanInvalidIdentifier,
                scanJsxToken,
                scanJsDocToken,
                scan,
                getText,
                clearCommentDirectives,
                setText,
                setScriptTarget,
                setLanguageVariant,
                setOnError,
                setTextPos,
                setInJSDocType,
                tryScan,
                lookAhead,
                scanRange
            };
            if (Debug.isDebugging) {
                Object.defineProperty(scanner2, "__debugShowCurrentPositionInText", {
                    get: () => {
                        const text2 = scanner2.getText();
                        return text2.slice(0, scanner2.getStartPos()) + "\u2551" + text2.slice(scanner2.getStartPos());
                    }
                });
            }
            return scanner2;
            function error(message, errPos = pos, length3) {
                if (onError) {
                    const oldPos = pos;
                    pos = errPos;
                    onError(message, length3 || 0);
                    pos = oldPos;
                }
            }
            function scanNumberFragment() {
                let start2 = pos;
                let allowSeparator = false;
                let isPreviousTokenSeparator = false;
                let result = "";
                while (true) {
                    const ch = text.charCodeAt(pos);
                    if (ch === 95 /* _ */) {
                        tokenFlags |= 512 /* ContainsSeparator */;
                        if (allowSeparator) {
                            allowSeparator = false;
                            isPreviousTokenSeparator = true;
                            result += text.substring(start2, pos);
                        }
                        else if (isPreviousTokenSeparator) {
                            error(Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted, pos, 1);
                        }
                        else {
                            error(Diagnostics.Numeric_separators_are_not_allowed_here, pos, 1);
                        }
                        pos++;
                        start2 = pos;
                        continue;
                    }
                    if (isDigit(ch)) {
                        allowSeparator = true;
                        isPreviousTokenSeparator = false;
                        pos++;
                        continue;
                    }
                    break;
                }
                if (text.charCodeAt(pos - 1) === 95 /* _ */) {
                    error(Diagnostics.Numeric_separators_are_not_allowed_here, pos - 1, 1);
                }
                return result + text.substring(start2, pos);
            }
            function scanNumber() {
                const start2 = pos;
                const mainFragment = scanNumberFragment();
                let decimalFragment;
                let scientificFragment;
                if (text.charCodeAt(pos) === 46 /* dot */) {
                    pos++;
                    decimalFragment = scanNumberFragment();
                }
                let end2 = pos;
                if (text.charCodeAt(pos) === 69 /* E */ || text.charCodeAt(pos) === 101 /* e */) {
                    pos++;
                    tokenFlags |= 16 /* Scientific */;
                    if (text.charCodeAt(pos) === 43 /* plus */ || text.charCodeAt(pos) === 45 /* minus */)
                        pos++;
                    const preNumericPart = pos;
                    const finalFragment = scanNumberFragment();
                    if (!finalFragment) {
                        error(Diagnostics.Digit_expected);
                    }
                    else {
                        scientificFragment = text.substring(end2, preNumericPart) + finalFragment;
                        end2 = pos;
                    }
                }
                let result;
                if (tokenFlags & 512 /* ContainsSeparator */) {
                    result = mainFragment;
                    if (decimalFragment) {
                        result += "." + decimalFragment;
                    }
                    if (scientificFragment) {
                        result += scientificFragment;
                    }
                }
                else {
                    result = text.substring(start2, end2);
                }
                if (decimalFragment !== void 0 || tokenFlags & 16 /* Scientific */) {
                    checkForIdentifierStartAfterNumericLiteral(start2, decimalFragment === void 0 && !!(tokenFlags & 16 /* Scientific */));
                    return {
                        type: 8 /* NumericLiteral */,
                        value: "" + +result
                        // if value is not an integer, it can be safely coerced to a number
                    };
                }
                else {
                    tokenValue = result;
                    const type = checkBigIntSuffix();
                    checkForIdentifierStartAfterNumericLiteral(start2);
                    return { type, value: tokenValue };
                }
            }
            function checkForIdentifierStartAfterNumericLiteral(numericStart, isScientific) {
                if (!isIdentifierStart(codePointAt(text, pos), languageVersion)) {
                    return;
                }
                const identifierStart = pos;
                const { length: length3 } = scanIdentifierParts();
                if (length3 === 1 && text[identifierStart] === "n") {
                    if (isScientific) {
                        error(Diagnostics.A_bigint_literal_cannot_use_exponential_notation, numericStart, identifierStart - numericStart + 1);
                    }
                    else {
                        error(Diagnostics.A_bigint_literal_must_be_an_integer, numericStart, identifierStart - numericStart + 1);
                    }
                }
                else {
                    error(Diagnostics.An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal, identifierStart, length3);
                    pos = identifierStart;
                }
            }
            function scanOctalDigits() {
                const start2 = pos;
                while (isOctalDigit(text.charCodeAt(pos))) {
                    pos++;
                }
                return +text.substring(start2, pos);
            }
            function scanExactNumberOfHexDigits(count, canHaveSeparators) {
                const valueString = scanHexDigits(
                /*minCount*/
                count, 
                /*scanAsManyAsPossible*/
                false, canHaveSeparators);
                return valueString ? parseInt(valueString, 16) : -1;
            }
            function scanMinimumNumberOfHexDigits(count, canHaveSeparators) {
                return scanHexDigits(
                /*minCount*/
                count, 
                /*scanAsManyAsPossible*/
                true, canHaveSeparators);
            }
            function scanHexDigits(minCount, scanAsManyAsPossible, canHaveSeparators) {
                let valueChars = [];
                let allowSeparator = false;
                let isPreviousTokenSeparator = false;
                while (valueChars.length < minCount || scanAsManyAsPossible) {
                    let ch = text.charCodeAt(pos);
                    if (canHaveSeparators && ch === 95 /* _ */) {
                        tokenFlags |= 512 /* ContainsSeparator */;
                        if (allowSeparator) {
                            allowSeparator = false;
                            isPreviousTokenSeparator = true;
                        }
                        else if (isPreviousTokenSeparator) {
                            error(Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted, pos, 1);
                        }
                        else {
                            error(Diagnostics.Numeric_separators_are_not_allowed_here, pos, 1);
                        }
                        pos++;
                        continue;
                    }
                    allowSeparator = canHaveSeparators;
                    if (ch >= 65 /* A */ && ch <= 70 /* F */) {
                        ch += 97 /* a */ - 65 /* A */;
                    }
                    else if (!(ch >= 48 /* _0 */ && ch <= 57 /* _9 */ || ch >= 97 /* a */ && ch <= 102 /* f */)) {
                        break;
                    }
                    valueChars.push(ch);
                    pos++;
                    isPreviousTokenSeparator = false;
                }
                if (valueChars.length < minCount) {
                    valueChars = [];
                }
                if (text.charCodeAt(pos - 1) === 95 /* _ */) {
                    error(Diagnostics.Numeric_separators_are_not_allowed_here, pos - 1, 1);
                }
                return String.fromCharCode(...valueChars);
            }
            function scanString(jsxAttributeString = false) {
                const quote2 = text.charCodeAt(pos);
                pos++;
                let result = "";
                let start2 = pos;
                while (true) {
                    if (pos >= end) {
                        result += text.substring(start2, pos);
                        tokenFlags |= 4 /* Unterminated */;
                        error(Diagnostics.Unterminated_string_literal);
                        break;
                    }
                    const ch = text.charCodeAt(pos);
                    if (ch === quote2) {
                        result += text.substring(start2, pos);
                        pos++;
                        break;
                    }
                    if (ch === 92 /* backslash */ && !jsxAttributeString) {
                        result += text.substring(start2, pos);
                        result += scanEscapeSequence();
                        start2 = pos;
                        continue;
                    }
                    if (isLineBreak(ch) && !jsxAttributeString) {
                        result += text.substring(start2, pos);
                        tokenFlags |= 4 /* Unterminated */;
                        error(Diagnostics.Unterminated_string_literal);
                        break;
                    }
                    pos++;
                }
                return result;
            }
            function scanTemplateAndSetTokenValue(isTaggedTemplate) {
                const startedWithBacktick = text.charCodeAt(pos) === 96 /* backtick */;
                pos++;
                let start2 = pos;
                let contents = "";
                let resultingToken;
                while (true) {
                    if (pos >= end) {
                        contents += text.substring(start2, pos);
                        tokenFlags |= 4 /* Unterminated */;
                        error(Diagnostics.Unterminated_template_literal);
                        resultingToken = startedWithBacktick ? 14 /* NoSubstitutionTemplateLiteral */ : 17 /* TemplateTail */;
                        break;
                    }
                    const currChar = text.charCodeAt(pos);
                    if (currChar === 96 /* backtick */) {
                        contents += text.substring(start2, pos);
                        pos++;
                        resultingToken = startedWithBacktick ? 14 /* NoSubstitutionTemplateLiteral */ : 17 /* TemplateTail */;
                        break;
                    }
                    if (currChar === 36 /* $ */ && pos + 1 < end && text.charCodeAt(pos + 1) === 123 /* openBrace */) {
                        contents += text.substring(start2, pos);
                        pos += 2;
                        resultingToken = startedWithBacktick ? 15 /* TemplateHead */ : 16 /* TemplateMiddle */;
                        break;
                    }
                    if (currChar === 92 /* backslash */) {
                        contents += text.substring(start2, pos);
                        contents += scanEscapeSequence(isTaggedTemplate);
                        start2 = pos;
                        continue;
                    }
                    if (currChar === 13 /* carriageReturn */) {
                        contents += text.substring(start2, pos);
                        pos++;
                        if (pos < end && text.charCodeAt(pos) === 10 /* lineFeed */) {
                            pos++;
                        }
                        contents += "\n";
                        start2 = pos;
                        continue;
                    }
                    pos++;
                }
                Debug.assert(resultingToken !== void 0);
                tokenValue = contents;
                return resultingToken;
            }
            function scanEscapeSequence(isTaggedTemplate) {
                const start2 = pos;
                pos++;
                if (pos >= end) {
                    error(Diagnostics.Unexpected_end_of_text);
                    return "";
                }
                const ch = text.charCodeAt(pos);
                pos++;
                switch (ch) {
                    case 48 /* _0 */:
                        if (isTaggedTemplate && pos < end && isDigit(text.charCodeAt(pos))) {
                            pos++;
                            tokenFlags |= 2048 /* ContainsInvalidEscape */;
                            return text.substring(start2, pos);
                        }
                        return "\0";
                    case 98 /* b */:
                        return "\b";
                    case 116 /* t */:
                        return "	";
                    case 110 /* n */:
                        return "\n";
                    case 118 /* v */:
                        return "\v";
                    case 102 /* f */:
                        return "\f";
                    case 114 /* r */:
                        return "\r";
                    case 39 /* singleQuote */:
                        return "'";
                    case 34 /* doubleQuote */:
                        return '"';
                    case 117 /* u */:
                        if (isTaggedTemplate) {
                            for (let escapePos = pos; escapePos < pos + 4; escapePos++) {
                                if (escapePos < end && !isHexDigit(text.charCodeAt(escapePos)) && text.charCodeAt(escapePos) !== 123 /* openBrace */) {
                                    pos = escapePos;
                                    tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                    return text.substring(start2, pos);
                                }
                            }
                        }
                        if (pos < end && text.charCodeAt(pos) === 123 /* openBrace */) {
                            pos++;
                            if (isTaggedTemplate && !isHexDigit(text.charCodeAt(pos))) {
                                tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                return text.substring(start2, pos);
                            }
                            if (isTaggedTemplate) {
                                const savePos = pos;
                                const escapedValueString = scanMinimumNumberOfHexDigits(1, 
                                /*canHaveSeparators*/
                                false);
                                const escapedValue = escapedValueString ? parseInt(escapedValueString, 16) : -1;
                                if (!isCodePoint(escapedValue) || text.charCodeAt(pos) !== 125 /* closeBrace */) {
                                    tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                    return text.substring(start2, pos);
                                }
                                else {
                                    pos = savePos;
                                }
                            }
                            tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                            return scanExtendedUnicodeEscape();
                        }
                        tokenFlags |= 1024 /* UnicodeEscape */;
                        return scanHexadecimalEscape(
                        /*numDigits*/
                        4);
                    case 120 /* x */:
                        if (isTaggedTemplate) {
                            if (!isHexDigit(text.charCodeAt(pos))) {
                                tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                return text.substring(start2, pos);
                            }
                            else if (!isHexDigit(text.charCodeAt(pos + 1))) {
                                pos++;
                                tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                return text.substring(start2, pos);
                            }
                        }
                        return scanHexadecimalEscape(
                        /*numDigits*/
                        2);
                    case 13 /* carriageReturn */:
                        if (pos < end && text.charCodeAt(pos) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                    case 8232 /* lineSeparator */:
                    case 8233 /* paragraphSeparator */:
                        return "";
                    default:
                        return String.fromCharCode(ch);
                }
            }
            function scanHexadecimalEscape(numDigits) {
                const escapedValue = scanExactNumberOfHexDigits(numDigits, 
                /*canHaveSeparators*/
                false);
                if (escapedValue >= 0) {
                    return String.fromCharCode(escapedValue);
                }
                else {
                    error(Diagnostics.Hexadecimal_digit_expected);
                    return "";
                }
            }
            function scanExtendedUnicodeEscape() {
                const escapedValueString = scanMinimumNumberOfHexDigits(1, 
                /*canHaveSeparators*/
                false);
                const escapedValue = escapedValueString ? parseInt(escapedValueString, 16) : -1;
                let isInvalidExtendedEscape = false;
                if (escapedValue < 0) {
                    error(Diagnostics.Hexadecimal_digit_expected);
                    isInvalidExtendedEscape = true;
                }
                else if (escapedValue > 1114111) {
                    error(Diagnostics.An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive);
                    isInvalidExtendedEscape = true;
                }
                if (pos >= end) {
                    error(Diagnostics.Unexpected_end_of_text);
                    isInvalidExtendedEscape = true;
                }
                else if (text.charCodeAt(pos) === 125 /* closeBrace */) {
                    pos++;
                }
                else {
                    error(Diagnostics.Unterminated_Unicode_escape_sequence);
                    isInvalidExtendedEscape = true;
                }
                if (isInvalidExtendedEscape) {
                    return "";
                }
                return utf16EncodeAsString(escapedValue);
            }
            function peekUnicodeEscape() {
                if (pos + 5 < end && text.charCodeAt(pos + 1) === 117 /* u */) {
                    const start2 = pos;
                    pos += 2;
                    const value = scanExactNumberOfHexDigits(4, 
                    /*canHaveSeparators*/
                    false);
                    pos = start2;
                    return value;
                }
                return -1;
            }
            function peekExtendedUnicodeEscape() {
                if (codePointAt(text, pos + 1) === 117 /* u */ && codePointAt(text, pos + 2) === 123 /* openBrace */) {
                    const start2 = pos;
                    pos += 3;
                    const escapedValueString = scanMinimumNumberOfHexDigits(1, 
                    /*canHaveSeparators*/
                    false);
                    const escapedValue = escapedValueString ? parseInt(escapedValueString, 16) : -1;
                    pos = start2;
                    return escapedValue;
                }
                return -1;
            }
            function scanIdentifierParts() {
                let result = "";
                let start2 = pos;
                while (pos < end) {
                    let ch = codePointAt(text, pos);
                    if (isIdentifierPart(ch, languageVersion)) {
                        pos += charSize(ch);
                    }
                    else if (ch === 92 /* backslash */) {
                        ch = peekExtendedUnicodeEscape();
                        if (ch >= 0 && isIdentifierPart(ch, languageVersion)) {
                            pos += 3;
                            tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                            result += scanExtendedUnicodeEscape();
                            start2 = pos;
                            continue;
                        }
                        ch = peekUnicodeEscape();
                        if (!(ch >= 0 && isIdentifierPart(ch, languageVersion))) {
                            break;
                        }
                        tokenFlags |= 1024 /* UnicodeEscape */;
                        result += text.substring(start2, pos);
                        result += utf16EncodeAsString(ch);
                        pos += 6;
                        start2 = pos;
                    }
                    else {
                        break;
                    }
                }
                result += text.substring(start2, pos);
                return result;
            }
            function getIdentifierToken() {
                const len = tokenValue.length;
                if (len >= 2 && len <= 12) {
                    const ch = tokenValue.charCodeAt(0);
                    if (ch >= 97 /* a */ && ch <= 122 /* z */) {
                        const keyword = textToKeyword.get(tokenValue);
                        if (keyword !== void 0) {
                            return token = keyword;
                        }
                    }
                }
                return token = 79 /* Identifier */;
            }
            function scanBinaryOrOctalDigits(base) {
                let value = "";
                let separatorAllowed = false;
                let isPreviousTokenSeparator = false;
                while (true) {
                    const ch = text.charCodeAt(pos);
                    if (ch === 95 /* _ */) {
                        tokenFlags |= 512 /* ContainsSeparator */;
                        if (separatorAllowed) {
                            separatorAllowed = false;
                            isPreviousTokenSeparator = true;
                        }
                        else if (isPreviousTokenSeparator) {
                            error(Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted, pos, 1);
                        }
                        else {
                            error(Diagnostics.Numeric_separators_are_not_allowed_here, pos, 1);
                        }
                        pos++;
                        continue;
                    }
                    separatorAllowed = true;
                    if (!isDigit(ch) || ch - 48 /* _0 */ >= base) {
                        break;
                    }
                    value += text[pos];
                    pos++;
                    isPreviousTokenSeparator = false;
                }
                if (text.charCodeAt(pos - 1) === 95 /* _ */) {
                    error(Diagnostics.Numeric_separators_are_not_allowed_here, pos - 1, 1);
                }
                return value;
            }
            function checkBigIntSuffix() {
                if (text.charCodeAt(pos) === 110 /* n */) {
                    tokenValue += "n";
                    if (tokenFlags & 384 /* BinaryOrOctalSpecifier */) {
                        tokenValue = parsePseudoBigInt(tokenValue) + "n";
                    }
                    pos++;
                    return 9 /* BigIntLiteral */;
                }
                else {
                    const numericValue = tokenFlags & 128 /* BinarySpecifier */ ? parseInt(tokenValue.slice(2), 2) : tokenFlags & 256 /* OctalSpecifier */ ? parseInt(tokenValue.slice(2), 8) : +tokenValue;
                    tokenValue = "" + numericValue;
                    return 8 /* NumericLiteral */;
                }
            }
            function scan() {
                startPos = pos;
                tokenFlags = 0 /* None */;
                let asteriskSeen = false;
                while (true) {
                    tokenPos = pos;
                    if (pos >= end) {
                        return token = 1 /* EndOfFileToken */;
                    }
                    const ch = codePointAt(text, pos);
                    if (ch === 35 /* hash */ && pos === 0 && isShebangTrivia(text, pos)) {
                        pos = scanShebangTrivia(text, pos);
                        if (skipTrivia2) {
                            continue;
                        }
                        else {
                            return token = 6 /* ShebangTrivia */;
                        }
                    }
                    switch (ch) {
                        case 10 /* lineFeed */:
                        case 13 /* carriageReturn */:
                            tokenFlags |= 1 /* PrecedingLineBreak */;
                            if (skipTrivia2) {
                                pos++;
                                continue;
                            }
                            else {
                                if (ch === 13 /* carriageReturn */ && pos + 1 < end && text.charCodeAt(pos + 1) === 10 /* lineFeed */) {
                                    pos += 2;
                                }
                                else {
                                    pos++;
                                }
                                return token = 4 /* NewLineTrivia */;
                            }
                        case 9 /* tab */:
                        case 11 /* verticalTab */:
                        case 12 /* formFeed */:
                        case 32 /* space */:
                        case 160 /* nonBreakingSpace */:
                        case 5760 /* ogham */:
                        case 8192 /* enQuad */:
                        case 8193 /* emQuad */:
                        case 8194 /* enSpace */:
                        case 8195 /* emSpace */:
                        case 8196 /* threePerEmSpace */:
                        case 8197 /* fourPerEmSpace */:
                        case 8198 /* sixPerEmSpace */:
                        case 8199 /* figureSpace */:
                        case 8200 /* punctuationSpace */:
                        case 8201 /* thinSpace */:
                        case 8202 /* hairSpace */:
                        case 8203 /* zeroWidthSpace */:
                        case 8239 /* narrowNoBreakSpace */:
                        case 8287 /* mathematicalSpace */:
                        case 12288 /* ideographicSpace */:
                        case 65279 /* byteOrderMark */:
                            if (skipTrivia2) {
                                pos++;
                                continue;
                            }
                            else {
                                while (pos < end && isWhiteSpaceSingleLine(text.charCodeAt(pos))) {
                                    pos++;
                                }
                                return token = 5 /* WhitespaceTrivia */;
                            }
                        case 33 /* exclamation */:
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 37 /* ExclamationEqualsEqualsToken */;
                                }
                                return pos += 2, token = 35 /* ExclamationEqualsToken */;
                            }
                            pos++;
                            return token = 53 /* ExclamationToken */;
                        case 34 /* doubleQuote */:
                        case 39 /* singleQuote */:
                            tokenValue = scanString();
                            return token = 10 /* StringLiteral */;
                        case 96 /* backtick */:
                            return token = scanTemplateAndSetTokenValue(
                            /* isTaggedTemplate */
                            false);
                        case 37 /* percent */:
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 69 /* PercentEqualsToken */;
                            }
                            pos++;
                            return token = 44 /* PercentToken */;
                        case 38 /* ampersand */:
                            if (text.charCodeAt(pos + 1) === 38 /* ampersand */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 76 /* AmpersandAmpersandEqualsToken */;
                                }
                                return pos += 2, token = 55 /* AmpersandAmpersandToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 73 /* AmpersandEqualsToken */;
                            }
                            pos++;
                            return token = 50 /* AmpersandToken */;
                        case 40 /* openParen */:
                            pos++;
                            return token = 20 /* OpenParenToken */;
                        case 41 /* closeParen */:
                            pos++;
                            return token = 21 /* CloseParenToken */;
                        case 42 /* asterisk */:
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 66 /* AsteriskEqualsToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 42 /* asterisk */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 67 /* AsteriskAsteriskEqualsToken */;
                                }
                                return pos += 2, token = 42 /* AsteriskAsteriskToken */;
                            }
                            pos++;
                            if (inJSDocType && !asteriskSeen && tokenFlags & 1 /* PrecedingLineBreak */) {
                                asteriskSeen = true;
                                continue;
                            }
                            return token = 41 /* AsteriskToken */;
                        case 43 /* plus */:
                            if (text.charCodeAt(pos + 1) === 43 /* plus */) {
                                return pos += 2, token = 45 /* PlusPlusToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 64 /* PlusEqualsToken */;
                            }
                            pos++;
                            return token = 39 /* PlusToken */;
                        case 44 /* comma */:
                            pos++;
                            return token = 27 /* CommaToken */;
                        case 45 /* minus */:
                            if (text.charCodeAt(pos + 1) === 45 /* minus */) {
                                return pos += 2, token = 46 /* MinusMinusToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 65 /* MinusEqualsToken */;
                            }
                            pos++;
                            return token = 40 /* MinusToken */;
                        case 46 /* dot */:
                            if (isDigit(text.charCodeAt(pos + 1))) {
                                tokenValue = scanNumber().value;
                                return token = 8 /* NumericLiteral */;
                            }
                            if (text.charCodeAt(pos + 1) === 46 /* dot */ && text.charCodeAt(pos + 2) === 46 /* dot */) {
                                return pos += 3, token = 25 /* DotDotDotToken */;
                            }
                            pos++;
                            return token = 24 /* DotToken */;
                        case 47 /* slash */:
                            if (text.charCodeAt(pos + 1) === 47 /* slash */) {
                                pos += 2;
                                while (pos < end) {
                                    if (isLineBreak(text.charCodeAt(pos))) {
                                        break;
                                    }
                                    pos++;
                                }
                                commentDirectives = appendIfCommentDirective(commentDirectives, text.slice(tokenPos, pos), commentDirectiveRegExSingleLine, tokenPos);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 2 /* SingleLineCommentTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 42 /* asterisk */) {
                                pos += 2;
                                if (text.charCodeAt(pos) === 42 /* asterisk */ && text.charCodeAt(pos + 1) !== 47 /* slash */) {
                                    tokenFlags |= 2 /* PrecedingJSDocComment */;
                                }
                                let commentClosed = false;
                                let lastLineStart = tokenPos;
                                while (pos < end) {
                                    const ch2 = text.charCodeAt(pos);
                                    if (ch2 === 42 /* asterisk */ && text.charCodeAt(pos + 1) === 47 /* slash */) {
                                        pos += 2;
                                        commentClosed = true;
                                        break;
                                    }
                                    pos++;
                                    if (isLineBreak(ch2)) {
                                        lastLineStart = pos;
                                        tokenFlags |= 1 /* PrecedingLineBreak */;
                                    }
                                }
                                commentDirectives = appendIfCommentDirective(commentDirectives, text.slice(lastLineStart, pos), commentDirectiveRegExMultiLine, lastLineStart);
                                if (!commentClosed) {
                                    error(Diagnostics.Asterisk_Slash_expected);
                                }
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    if (!commentClosed) {
                                        tokenFlags |= 4 /* Unterminated */;
                                    }
                                    return token = 3 /* MultiLineCommentTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 68 /* SlashEqualsToken */;
                            }
                            pos++;
                            return token = 43 /* SlashToken */;
                        case 48 /* _0 */:
                            if (pos + 2 < end && (text.charCodeAt(pos + 1) === 88 /* X */ || text.charCodeAt(pos + 1) === 120 /* x */)) {
                                pos += 2;
                                tokenValue = scanMinimumNumberOfHexDigits(1, 
                                /*canHaveSeparators*/
                                true);
                                if (!tokenValue) {
                                    error(Diagnostics.Hexadecimal_digit_expected);
                                    tokenValue = "0";
                                }
                                tokenValue = "0x" + tokenValue;
                                tokenFlags |= 64 /* HexSpecifier */;
                                return token = checkBigIntSuffix();
                            }
                            else if (pos + 2 < end && (text.charCodeAt(pos + 1) === 66 /* B */ || text.charCodeAt(pos + 1) === 98 /* b */)) {
                                pos += 2;
                                tokenValue = scanBinaryOrOctalDigits(
                                /* base */
                                2);
                                if (!tokenValue) {
                                    error(Diagnostics.Binary_digit_expected);
                                    tokenValue = "0";
                                }
                                tokenValue = "0b" + tokenValue;
                                tokenFlags |= 128 /* BinarySpecifier */;
                                return token = checkBigIntSuffix();
                            }
                            else if (pos + 2 < end && (text.charCodeAt(pos + 1) === 79 /* O */ || text.charCodeAt(pos + 1) === 111 /* o */)) {
                                pos += 2;
                                tokenValue = scanBinaryOrOctalDigits(
                                /* base */
                                8);
                                if (!tokenValue) {
                                    error(Diagnostics.Octal_digit_expected);
                                    tokenValue = "0";
                                }
                                tokenValue = "0o" + tokenValue;
                                tokenFlags |= 256 /* OctalSpecifier */;
                                return token = checkBigIntSuffix();
                            }
                            if (pos + 1 < end && isOctalDigit(text.charCodeAt(pos + 1))) {
                                tokenValue = "" + scanOctalDigits();
                                tokenFlags |= 32 /* Octal */;
                                return token = 8 /* NumericLiteral */;
                            }
                        case 49 /* _1 */:
                        case 50 /* _2 */:
                        case 51 /* _3 */:
                        case 52 /* _4 */:
                        case 53 /* _5 */:
                        case 54 /* _6 */:
                        case 55 /* _7 */:
                        case 56 /* _8 */:
                        case 57 /* _9 */:
                            ({ type: token, value: tokenValue } = scanNumber());
                            return token;
                        case 58 /* colon */:
                            pos++;
                            return token = 58 /* ColonToken */;
                        case 59 /* semicolon */:
                            pos++;
                            return token = 26 /* SemicolonToken */;
                        case 60 /* lessThan */:
                            if (isConflictMarkerTrivia(text, pos)) {
                                pos = scanConflictMarkerTrivia(text, pos, error);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 7 /* ConflictMarkerTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 60 /* lessThan */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 70 /* LessThanLessThanEqualsToken */;
                                }
                                return pos += 2, token = 47 /* LessThanLessThanToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 32 /* LessThanEqualsToken */;
                            }
                            if (languageVariant === 1 /* JSX */ && text.charCodeAt(pos + 1) === 47 /* slash */ && text.charCodeAt(pos + 2) !== 42 /* asterisk */) {
                                return pos += 2, token = 30 /* LessThanSlashToken */;
                            }
                            pos++;
                            return token = 29 /* LessThanToken */;
                        case 61 /* equals */:
                            if (isConflictMarkerTrivia(text, pos)) {
                                pos = scanConflictMarkerTrivia(text, pos, error);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 7 /* ConflictMarkerTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 36 /* EqualsEqualsEqualsToken */;
                                }
                                return pos += 2, token = 34 /* EqualsEqualsToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 62 /* greaterThan */) {
                                return pos += 2, token = 38 /* EqualsGreaterThanToken */;
                            }
                            pos++;
                            return token = 63 /* EqualsToken */;
                        case 62 /* greaterThan */:
                            if (isConflictMarkerTrivia(text, pos)) {
                                pos = scanConflictMarkerTrivia(text, pos, error);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 7 /* ConflictMarkerTrivia */;
                                }
                            }
                            pos++;
                            return token = 31 /* GreaterThanToken */;
                        case 63 /* question */:
                            if (text.charCodeAt(pos + 1) === 46 /* dot */ && !isDigit(text.charCodeAt(pos + 2))) {
                                return pos += 2, token = 28 /* QuestionDotToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 63 /* question */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 77 /* QuestionQuestionEqualsToken */;
                                }
                                return pos += 2, token = 60 /* QuestionQuestionToken */;
                            }
                            pos++;
                            return token = 57 /* QuestionToken */;
                        case 91 /* openBracket */:
                            pos++;
                            return token = 22 /* OpenBracketToken */;
                        case 93 /* closeBracket */:
                            pos++;
                            return token = 23 /* CloseBracketToken */;
                        case 94 /* caret */:
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 78 /* CaretEqualsToken */;
                            }
                            pos++;
                            return token = 52 /* CaretToken */;
                        case 123 /* openBrace */:
                            pos++;
                            return token = 18 /* OpenBraceToken */;
                        case 124 /* bar */:
                            if (isConflictMarkerTrivia(text, pos)) {
                                pos = scanConflictMarkerTrivia(text, pos, error);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 7 /* ConflictMarkerTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 124 /* bar */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 75 /* BarBarEqualsToken */;
                                }
                                return pos += 2, token = 56 /* BarBarToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 74 /* BarEqualsToken */;
                            }
                            pos++;
                            return token = 51 /* BarToken */;
                        case 125 /* closeBrace */:
                            pos++;
                            return token = 19 /* CloseBraceToken */;
                        case 126 /* tilde */:
                            pos++;
                            return token = 54 /* TildeToken */;
                        case 64 /* at */:
                            pos++;
                            return token = 59 /* AtToken */;
                        case 92 /* backslash */:
                            const extendedCookedChar = peekExtendedUnicodeEscape();
                            if (extendedCookedChar >= 0 && isIdentifierStart(extendedCookedChar, languageVersion)) {
                                pos += 3;
                                tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                                tokenValue = scanExtendedUnicodeEscape() + scanIdentifierParts();
                                return token = getIdentifierToken();
                            }
                            const cookedChar = peekUnicodeEscape();
                            if (cookedChar >= 0 && isIdentifierStart(cookedChar, languageVersion)) {
                                pos += 6;
                                tokenFlags |= 1024 /* UnicodeEscape */;
                                tokenValue = String.fromCharCode(cookedChar) + scanIdentifierParts();
                                return token = getIdentifierToken();
                            }
                            error(Diagnostics.Invalid_character);
                            pos++;
                            return token = 0 /* Unknown */;
                        case 35 /* hash */:
                            if (pos !== 0 && text[pos + 1] === "!") {
                                error(Diagnostics.can_only_be_used_at_the_start_of_a_file);
                                pos++;
                                return token = 0 /* Unknown */;
                            }
                            const charAfterHash = codePointAt(text, pos + 1);
                            if (charAfterHash === 92 /* backslash */) {
                                pos++;
                                const extendedCookedChar2 = peekExtendedUnicodeEscape();
                                if (extendedCookedChar2 >= 0 && isIdentifierStart(extendedCookedChar2, languageVersion)) {
                                    pos += 3;
                                    tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                                    tokenValue = "#" + scanExtendedUnicodeEscape() + scanIdentifierParts();
                                    return token = 80 /* PrivateIdentifier */;
                                }
                                const cookedChar2 = peekUnicodeEscape();
                                if (cookedChar2 >= 0 && isIdentifierStart(cookedChar2, languageVersion)) {
                                    pos += 6;
                                    tokenFlags |= 1024 /* UnicodeEscape */;
                                    tokenValue = "#" + String.fromCharCode(cookedChar2) + scanIdentifierParts();
                                    return token = 80 /* PrivateIdentifier */;
                                }
                                pos--;
                            }
                            if (isIdentifierStart(charAfterHash, languageVersion)) {
                                pos++;
                                scanIdentifier(charAfterHash, languageVersion);
                            }
                            else {
                                tokenValue = "#";
                                error(Diagnostics.Invalid_character, pos++, charSize(ch));
                            }
                            return token = 80 /* PrivateIdentifier */;
                        default:
                            const identifierKind = scanIdentifier(ch, languageVersion);
                            if (identifierKind) {
                                return token = identifierKind;
                            }
                            else if (isWhiteSpaceSingleLine(ch)) {
                                pos += charSize(ch);
                                continue;
                            }
                            else if (isLineBreak(ch)) {
                                tokenFlags |= 1 /* PrecedingLineBreak */;
                                pos += charSize(ch);
                                continue;
                            }
                            const size = charSize(ch);
                            error(Diagnostics.Invalid_character, pos, size);
                            pos += size;
                            return token = 0 /* Unknown */;
                    }
                }
            }
            function reScanInvalidIdentifier() {
                Debug.assert(token === 0 /* Unknown */, "'reScanInvalidIdentifier' should only be called when the current token is 'SyntaxKind.Unknown'.");
                pos = tokenPos = startPos;
                tokenFlags = 0;
                const ch = codePointAt(text, pos);
                const identifierKind = scanIdentifier(ch, 99 /* ESNext */);
                if (identifierKind) {
                    return token = identifierKind;
                }
                pos += charSize(ch);
                return token;
            }
            function scanIdentifier(startCharacter, languageVersion2) {
                let ch = startCharacter;
                if (isIdentifierStart(ch, languageVersion2)) {
                    pos += charSize(ch);
                    while (pos < end && isIdentifierPart(ch = codePointAt(text, pos), languageVersion2))
                        pos += charSize(ch);
                    tokenValue = text.substring(tokenPos, pos);
                    if (ch === 92 /* backslash */) {
                        tokenValue += scanIdentifierParts();
                    }
                    return getIdentifierToken();
                }
            }
            function reScanGreaterToken() {
                if (token === 31 /* GreaterThanToken */) {
                    if (text.charCodeAt(pos) === 62 /* greaterThan */) {
                        if (text.charCodeAt(pos + 1) === 62 /* greaterThan */) {
                            if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                return pos += 3, token = 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */;
                            }
                            return pos += 2, token = 49 /* GreaterThanGreaterThanGreaterThanToken */;
                        }
                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                            return pos += 2, token = 71 /* GreaterThanGreaterThanEqualsToken */;
                        }
                        pos++;
                        return token = 48 /* GreaterThanGreaterThanToken */;
                    }
                    if (text.charCodeAt(pos) === 61 /* equals */) {
                        pos++;
                        return token = 33 /* GreaterThanEqualsToken */;
                    }
                }
                return token;
            }
            function reScanAsteriskEqualsToken() {
                Debug.assert(token === 66 /* AsteriskEqualsToken */, "'reScanAsteriskEqualsToken' should only be called on a '*='");
                pos = tokenPos + 1;
                return token = 63 /* EqualsToken */;
            }
            function reScanSlashToken() {
                if (token === 43 /* SlashToken */ || token === 68 /* SlashEqualsToken */) {
                    let p = tokenPos + 1;
                    let inEscape = false;
                    let inCharacterClass = false;
                    while (true) {
                        if (p >= end) {
                            tokenFlags |= 4 /* Unterminated */;
                            error(Diagnostics.Unterminated_regular_expression_literal);
                            break;
                        }
                        const ch = text.charCodeAt(p);
                        if (isLineBreak(ch)) {
                            tokenFlags |= 4 /* Unterminated */;
                            error(Diagnostics.Unterminated_regular_expression_literal);
                            break;
                        }
                        if (inEscape) {
                            inEscape = false;
                        }
                        else if (ch === 47 /* slash */ && !inCharacterClass) {
                            p++;
                            break;
                        }
                        else if (ch === 91 /* openBracket */) {
                            inCharacterClass = true;
                        }
                        else if (ch === 92 /* backslash */) {
                            inEscape = true;
                        }
                        else if (ch === 93 /* closeBracket */) {
                            inCharacterClass = false;
                        }
                        p++;
                    }
                    while (p < end && isIdentifierPart(text.charCodeAt(p), languageVersion)) {
                        p++;
                    }
                    pos = p;
                    tokenValue = text.substring(tokenPos, pos);
                    token = 13 /* RegularExpressionLiteral */;
                }
                return token;
            }
            function appendIfCommentDirective(commentDirectives2, text2, commentDirectiveRegEx, lineStart) {
                const type = getDirectiveFromComment(trimStringStart(text2), commentDirectiveRegEx);
                if (type === void 0) {
                    return commentDirectives2;
                }
                return append(commentDirectives2, {
                    range: { pos: lineStart, end: pos },
                    type
                });
            }
            function getDirectiveFromComment(text2, commentDirectiveRegEx) {
                const match = commentDirectiveRegEx.exec(text2);
                if (!match) {
                    return void 0;
                }
                switch (match[1]) {
                    case "ts-expect-error":
                        return 0 /* ExpectError */;
                    case "ts-ignore":
                        return 1 /* Ignore */;
                }
                return void 0;
            }
            function reScanTemplateToken(isTaggedTemplate) {
                Debug.assert(token === 19 /* CloseBraceToken */, "'reScanTemplateToken' should only be called on a '}'");
                pos = tokenPos;
                return token = scanTemplateAndSetTokenValue(isTaggedTemplate);
            }
            function reScanTemplateHeadOrNoSubstitutionTemplate() {
                pos = tokenPos;
                return token = scanTemplateAndSetTokenValue(
                /* isTaggedTemplate */
                true);
            }
            function reScanJsxToken(allowMultilineJsxText = true) {
                pos = tokenPos = startPos;
                return token = scanJsxToken(allowMultilineJsxText);
            }
            function reScanLessThanToken() {
                if (token === 47 /* LessThanLessThanToken */) {
                    pos = tokenPos + 1;
                    return token = 29 /* LessThanToken */;
                }
                return token;
            }
            function reScanHashToken() {
                if (token === 80 /* PrivateIdentifier */) {
                    pos = tokenPos + 1;
                    return token = 62 /* HashToken */;
                }
                return token;
            }
            function reScanQuestionToken() {
                Debug.assert(token === 60 /* QuestionQuestionToken */, "'reScanQuestionToken' should only be called on a '??'");
                pos = tokenPos + 1;
                return token = 57 /* QuestionToken */;
            }
            function scanJsxToken(allowMultilineJsxText = true) {
                startPos = tokenPos = pos;
                if (pos >= end) {
                    return token = 1 /* EndOfFileToken */;
                }
                let char = text.charCodeAt(pos);
                if (char === 60 /* lessThan */) {
                    if (text.charCodeAt(pos + 1) === 47 /* slash */) {
                        pos += 2;
                        return token = 30 /* LessThanSlashToken */;
                    }
                    pos++;
                    return token = 29 /* LessThanToken */;
                }
                if (char === 123 /* openBrace */) {
                    pos++;
                    return token = 18 /* OpenBraceToken */;
                }
                let firstNonWhitespace = 0;
                while (pos < end) {
                    char = text.charCodeAt(pos);
                    if (char === 123 /* openBrace */) {
                        break;
                    }
                    if (char === 60 /* lessThan */) {
                        if (isConflictMarkerTrivia(text, pos)) {
                            pos = scanConflictMarkerTrivia(text, pos, error);
                            return token = 7 /* ConflictMarkerTrivia */;
                        }
                        break;
                    }
                    if (char === 62 /* greaterThan */) {
                        error(Diagnostics.Unexpected_token_Did_you_mean_or_gt, pos, 1);
                    }
                    if (char === 125 /* closeBrace */) {
                        error(Diagnostics.Unexpected_token_Did_you_mean_or_rbrace, pos, 1);
                    }
                    if (isLineBreak(char) && firstNonWhitespace === 0) {
                        firstNonWhitespace = -1;
                    }
                    else if (!allowMultilineJsxText && isLineBreak(char) && firstNonWhitespace > 0) {
                        break;
                    }
                    else if (!isWhiteSpaceLike(char)) {
                        firstNonWhitespace = pos;
                    }
                    pos++;
                }
                tokenValue = text.substring(startPos, pos);
                return firstNonWhitespace === -1 ? 12 /* JsxTextAllWhiteSpaces */ : 11 /* JsxText */;
            }
            function scanJsxIdentifier() {
                if (tokenIsIdentifierOrKeyword(token)) {
                    let namespaceSeparator = false;
                    while (pos < end) {
                        const ch = text.charCodeAt(pos);
                        if (ch === 45 /* minus */) {
                            tokenValue += "-";
                            pos++;
                            continue;
                        }
                        else if (ch === 58 /* colon */ && !namespaceSeparator) {
                            tokenValue += ":";
                            pos++;
                            namespaceSeparator = true;
                            token = 79 /* Identifier */;
                            continue;
                        }
                        const oldPos = pos;
                        tokenValue += scanIdentifierParts();
                        if (pos === oldPos) {
                            break;
                        }
                    }
                    if (tokenValue.slice(-1) === ":") {
                        tokenValue = tokenValue.slice(0, -1);
                        pos--;
                    }
                    return getIdentifierToken();
                }
                return token;
            }
            function scanJsxAttributeValue() {
                startPos = pos;
                switch (text.charCodeAt(pos)) {
                    case 34 /* doubleQuote */:
                    case 39 /* singleQuote */:
                        tokenValue = scanString(
                        /*jsxAttributeString*/
                        true);
                        return token = 10 /* StringLiteral */;
                    default:
                        return scan();
                }
            }
            function reScanJsxAttributeValue() {
                pos = tokenPos = startPos;
                return scanJsxAttributeValue();
            }
            function scanJsDocToken() {
                startPos = tokenPos = pos;
                tokenFlags = 0 /* None */;
                if (pos >= end) {
                    return token = 1 /* EndOfFileToken */;
                }
                const ch = codePointAt(text, pos);
                pos += charSize(ch);
                switch (ch) {
                    case 9 /* tab */:
                    case 11 /* verticalTab */:
                    case 12 /* formFeed */:
                    case 32 /* space */:
                        while (pos < end && isWhiteSpaceSingleLine(text.charCodeAt(pos))) {
                            pos++;
                        }
                        return token = 5 /* WhitespaceTrivia */;
                    case 64 /* at */:
                        return token = 59 /* AtToken */;
                    case 13 /* carriageReturn */:
                        if (text.charCodeAt(pos) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                        tokenFlags |= 1 /* PrecedingLineBreak */;
                        return token = 4 /* NewLineTrivia */;
                    case 42 /* asterisk */:
                        return token = 41 /* AsteriskToken */;
                    case 123 /* openBrace */:
                        return token = 18 /* OpenBraceToken */;
                    case 125 /* closeBrace */:
                        return token = 19 /* CloseBraceToken */;
                    case 91 /* openBracket */:
                        return token = 22 /* OpenBracketToken */;
                    case 93 /* closeBracket */:
                        return token = 23 /* CloseBracketToken */;
                    case 60 /* lessThan */:
                        return token = 29 /* LessThanToken */;
                    case 62 /* greaterThan */:
                        return token = 31 /* GreaterThanToken */;
                    case 61 /* equals */:
                        return token = 63 /* EqualsToken */;
                    case 44 /* comma */:
                        return token = 27 /* CommaToken */;
                    case 46 /* dot */:
                        return token = 24 /* DotToken */;
                    case 96 /* backtick */:
                        return token = 61 /* BacktickToken */;
                    case 35 /* hash */:
                        return token = 62 /* HashToken */;
                    case 92 /* backslash */:
                        pos--;
                        const extendedCookedChar = peekExtendedUnicodeEscape();
                        if (extendedCookedChar >= 0 && isIdentifierStart(extendedCookedChar, languageVersion)) {
                            pos += 3;
                            tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                            tokenValue = scanExtendedUnicodeEscape() + scanIdentifierParts();
                            return token = getIdentifierToken();
                        }
                        const cookedChar = peekUnicodeEscape();
                        if (cookedChar >= 0 && isIdentifierStart(cookedChar, languageVersion)) {
                            pos += 6;
                            tokenFlags |= 1024 /* UnicodeEscape */;
                            tokenValue = String.fromCharCode(cookedChar) + scanIdentifierParts();
                            return token = getIdentifierToken();
                        }
                        pos++;
                        return token = 0 /* Unknown */;
                }
                if (isIdentifierStart(ch, languageVersion)) {
                    let char = ch;
                    while (pos < end && isIdentifierPart(char = codePointAt(text, pos), languageVersion) || text.charCodeAt(pos) === 45 /* minus */)
                        pos += charSize(char);
                    tokenValue = text.substring(tokenPos, pos);
                    if (char === 92 /* backslash */) {
                        tokenValue += scanIdentifierParts();
                    }
                    return token = getIdentifierToken();
                }
                else {
                    return token = 0 /* Unknown */;
                }
            }
            function speculationHelper(callback, isLookahead) {
                const savePos = pos;
                const saveStartPos = startPos;
                const saveTokenPos = tokenPos;
                const saveToken = token;
                const saveTokenValue = tokenValue;
                const saveTokenFlags = tokenFlags;
                const result = callback();
                if (!result || isLookahead) {
                    pos = savePos;
                    startPos = saveStartPos;
                    tokenPos = saveTokenPos;
                    token = saveToken;
                    tokenValue = saveTokenValue;
                    tokenFlags = saveTokenFlags;
                }
                return result;
            }
            function scanRange(start2, length3, callback) {
                const saveEnd = end;
                const savePos = pos;
                const saveStartPos = startPos;
                const saveTokenPos = tokenPos;
                const saveToken = token;
                const saveTokenValue = tokenValue;
                const saveTokenFlags = tokenFlags;
                const saveErrorExpectations = commentDirectives;
                setText(text, start2, length3);
                const result = callback();
                end = saveEnd;
                pos = savePos;
                startPos = saveStartPos;
                tokenPos = saveTokenPos;
                token = saveToken;
                tokenValue = saveTokenValue;
                tokenFlags = saveTokenFlags;
                commentDirectives = saveErrorExpectations;
                return result;
            }
            function lookAhead(callback) {
                return speculationHelper(callback, 
                /*isLookahead*/
                true);
            }
            function tryScan(callback) {
                return speculationHelper(callback, 
                /*isLookahead*/
                false);
            }
            function getText() {
                return text;
            }
            function clearCommentDirectives() {
                commentDirectives = void 0;
            }
            function setText(newText, start2, length3) {
                text = newText || "";
                end = length3 === void 0 ? text.length : start2 + length3;
                setTextPos(start2 || 0);
            }
            function setOnError(errorCallback) {
                onError = errorCallback;
            }
            function setScriptTarget(scriptTarget) {
                languageVersion = scriptTarget;
            }
            function setLanguageVariant(variant) {
                languageVariant = variant;
            }
            function setTextPos(textPos) {
                Debug.assert(textPos >= 0);
                pos = textPos;
                startPos = textPos;
                tokenPos = textPos;
                token = 0 /* Unknown */;
                tokenValue = void 0;
                tokenFlags = 0 /* None */;
            }
            function setInJSDocType(inType) {
                inJSDocType += inType ? 1 : -1;
            }
        }
        function charSize(ch) {
            if (ch >= 65536) {
                return 2;
            }
            return 1;
        }
        function utf16EncodeAsStringFallback(codePoint) {
            Debug.assert(0 <= codePoint && codePoint <= 1114111);
            if (codePoint <= 65535) {
                return String.fromCharCode(codePoint);
            }
            const codeUnit1 = Math.floor((codePoint - 65536) / 1024) + 55296;
            const codeUnit2 = (codePoint - 65536) % 1024 + 56320;
            return String.fromCharCode(codeUnit1, codeUnit2);
        }
        function utf16EncodeAsString(codePoint) {
            return utf16EncodeAsStringWorker(codePoint);
        }
        var textToKeywordObj, textToKeyword, textToToken, unicodeES3IdentifierStart, unicodeES3IdentifierPart, unicodeES5IdentifierStart, unicodeES5IdentifierPart, unicodeESNextIdentifierStart, unicodeESNextIdentifierPart, commentDirectiveRegExSingleLine, commentDirectiveRegExMultiLine, tokenStrings, mergeConflictMarkerLength, shebangTriviaRegex, codePointAt, utf16EncodeAsStringWorker;
        var init_scanner = __esm({
            "src/compiler/scanner.ts"() {
                "use strict";
                init_ts2();
                textToKeywordObj = {
                    abstract: 126 /* AbstractKeyword */,
                    accessor: 127 /* AccessorKeyword */,
                    any: 131 /* AnyKeyword */,
                    as: 128 /* AsKeyword */,
                    asserts: 129 /* AssertsKeyword */,
                    assert: 130 /* AssertKeyword */,
                    bigint: 160 /* BigIntKeyword */,
                    boolean: 134 /* BooleanKeyword */,
                    break: 81 /* BreakKeyword */,
                    case: 82 /* CaseKeyword */,
                    catch: 83 /* CatchKeyword */,
                    class: 84 /* ClassKeyword */,
                    continue: 86 /* ContinueKeyword */,
                    const: 85 /* ConstKeyword */,
                    ["constructor"]: 135 /* ConstructorKeyword */,
                    debugger: 87 /* DebuggerKeyword */,
                    declare: 136 /* DeclareKeyword */,
                    default: 88 /* DefaultKeyword */,
                    delete: 89 /* DeleteKeyword */,
                    do: 90 /* DoKeyword */,
                    else: 91 /* ElseKeyword */,
                    enum: 92 /* EnumKeyword */,
                    export: 93 /* ExportKeyword */,
                    extends: 94 /* ExtendsKeyword */,
                    false: 95 /* FalseKeyword */,
                    finally: 96 /* FinallyKeyword */,
                    for: 97 /* ForKeyword */,
                    from: 158 /* FromKeyword */,
                    function: 98 /* FunctionKeyword */,
                    get: 137 /* GetKeyword */,
                    if: 99 /* IfKeyword */,
                    implements: 117 /* ImplementsKeyword */,
                    import: 100 /* ImportKeyword */,
                    in: 101 /* InKeyword */,
                    infer: 138 /* InferKeyword */,
                    instanceof: 102 /* InstanceOfKeyword */,
                    interface: 118 /* InterfaceKeyword */,
                    intrinsic: 139 /* IntrinsicKeyword */,
                    is: 140 /* IsKeyword */,
                    keyof: 141 /* KeyOfKeyword */,
                    let: 119 /* LetKeyword */,
                    module: 142 /* ModuleKeyword */,
                    namespace: 143 /* NamespaceKeyword */,
                    never: 144 /* NeverKeyword */,
                    new: 103 /* NewKeyword */,
                    null: 104 /* NullKeyword */,
                    number: 148 /* NumberKeyword */,
                    object: 149 /* ObjectKeyword */,
                    package: 120 /* PackageKeyword */,
                    private: 121 /* PrivateKeyword */,
                    protected: 122 /* ProtectedKeyword */,
                    public: 123 /* PublicKeyword */,
                    override: 161 /* OverrideKeyword */,
                    out: 145 /* OutKeyword */,
                    readonly: 146 /* ReadonlyKeyword */,
                    require: 147 /* RequireKeyword */,
                    global: 159 /* GlobalKeyword */,
                    return: 105 /* ReturnKeyword */,
                    satisfies: 150 /* SatisfiesKeyword */,
                    set: 151 /* SetKeyword */,
                    static: 124 /* StaticKeyword */,
                    string: 152 /* StringKeyword */,
                    super: 106 /* SuperKeyword */,
                    switch: 107 /* SwitchKeyword */,
                    symbol: 153 /* SymbolKeyword */,
                    this: 108 /* ThisKeyword */,
                    throw: 109 /* ThrowKeyword */,
                    true: 110 /* TrueKeyword */,
                    try: 111 /* TryKeyword */,
                    type: 154 /* TypeKeyword */,
                    typeof: 112 /* TypeOfKeyword */,
                    undefined: 155 /* UndefinedKeyword */,
                    unique: 156 /* UniqueKeyword */,
                    unknown: 157 /* UnknownKeyword */,
                    var: 113 /* VarKeyword */,
                    void: 114 /* VoidKeyword */,
                    while: 115 /* WhileKeyword */,
                    with: 116 /* WithKeyword */,
                    yield: 125 /* YieldKeyword */,
                    async: 132 /* AsyncKeyword */,
                    await: 133 /* AwaitKeyword */,
                    of: 162 /* OfKeyword */
                };
                textToKeyword = new Map(Object.entries(textToKeywordObj));
                textToToken = new Map(Object.entries({
                    ...textToKeywordObj,
                    "{": 18 /* OpenBraceToken */,
                    "}": 19 /* CloseBraceToken */,
                    "(": 20 /* OpenParenToken */,
                    ")": 21 /* CloseParenToken */,
                    "[": 22 /* OpenBracketToken */,
                    "]": 23 /* CloseBracketToken */,
                    ".": 24 /* DotToken */,
                    "...": 25 /* DotDotDotToken */,
                    ";": 26 /* SemicolonToken */,
                    ",": 27 /* CommaToken */,
                    "<": 29 /* LessThanToken */,
                    ">": 31 /* GreaterThanToken */,
                    "<=": 32 /* LessThanEqualsToken */,
                    ">=": 33 /* GreaterThanEqualsToken */,
                    "==": 34 /* EqualsEqualsToken */,
                    "!=": 35 /* ExclamationEqualsToken */,
                    "===": 36 /* EqualsEqualsEqualsToken */,
                    "!==": 37 /* ExclamationEqualsEqualsToken */,
                    "=>": 38 /* EqualsGreaterThanToken */,
                    "+": 39 /* PlusToken */,
                    "-": 40 /* MinusToken */,
                    "**": 42 /* AsteriskAsteriskToken */,
                    "*": 41 /* AsteriskToken */,
                    "/": 43 /* SlashToken */,
                    "%": 44 /* PercentToken */,
                    "++": 45 /* PlusPlusToken */,
                    "--": 46 /* MinusMinusToken */,
                    "<<": 47 /* LessThanLessThanToken */,
                    "</": 30 /* LessThanSlashToken */,
                    ">>": 48 /* GreaterThanGreaterThanToken */,
                    ">>>": 49 /* GreaterThanGreaterThanGreaterThanToken */,
                    "&": 50 /* AmpersandToken */,
                    "|": 51 /* BarToken */,
                    "^": 52 /* CaretToken */,
                    "!": 53 /* ExclamationToken */,
                    "~": 54 /* TildeToken */,
                    "&&": 55 /* AmpersandAmpersandToken */,
                    "||": 56 /* BarBarToken */,
                    "?": 57 /* QuestionToken */,
                    "??": 60 /* QuestionQuestionToken */,
                    "?.": 28 /* QuestionDotToken */,
                    ":": 58 /* ColonToken */,
                    "=": 63 /* EqualsToken */,
                    "+=": 64 /* PlusEqualsToken */,
                    "-=": 65 /* MinusEqualsToken */,
                    "*=": 66 /* AsteriskEqualsToken */,
                    "**=": 67 /* AsteriskAsteriskEqualsToken */,
                    "/=": 68 /* SlashEqualsToken */,
                    "%=": 69 /* PercentEqualsToken */,
                    "<<=": 70 /* LessThanLessThanEqualsToken */,
                    ">>=": 71 /* GreaterThanGreaterThanEqualsToken */,
                    ">>>=": 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */,
                    "&=": 73 /* AmpersandEqualsToken */,
                    "|=": 74 /* BarEqualsToken */,
                    "^=": 78 /* CaretEqualsToken */,
                    "||=": 75 /* BarBarEqualsToken */,
                    "&&=": 76 /* AmpersandAmpersandEqualsToken */,
                    "??=": 77 /* QuestionQuestionEqualsToken */,
                    "@": 59 /* AtToken */,
                    "#": 62 /* HashToken */,
                    "`": 61 /* BacktickToken */
                }));
                unicodeES3IdentifierStart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 543, 546, 563, 592, 685, 688, 696, 699, 705, 720, 721, 736, 740, 750, 750, 890, 890, 902, 902, 904, 906, 908, 908, 910, 929, 931, 974, 976, 983, 986, 1011, 1024, 1153, 1164, 1220, 1223, 1224, 1227, 1228, 1232, 1269, 1272, 1273, 1329, 1366, 1369, 1369, 1377, 1415, 1488, 1514, 1520, 1522, 1569, 1594, 1600, 1610, 1649, 1747, 1749, 1749, 1765, 1766, 1786, 1788, 1808, 1808, 1810, 1836, 1920, 1957, 2309, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2524, 2525, 2527, 2529, 2544, 2545, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2699, 2701, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2784, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2870, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 2997, 2999, 3001, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3168, 3169, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3294, 3294, 3296, 3297, 3333, 3340, 3342, 3344, 3346, 3368, 3370, 3385, 3424, 3425, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3805, 3840, 3840, 3904, 3911, 3913, 3946, 3976, 3979, 4096, 4129, 4131, 4135, 4137, 4138, 4176, 4181, 4256, 4293, 4304, 4342, 4352, 4441, 4447, 4514, 4520, 4601, 4608, 4614, 4616, 4678, 4680, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4742, 4744, 4744, 4746, 4749, 4752, 4782, 4784, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4814, 4816, 4822, 4824, 4846, 4848, 4878, 4880, 4880, 4882, 4885, 4888, 4894, 4896, 4934, 4936, 4954, 5024, 5108, 5121, 5740, 5743, 5750, 5761, 5786, 5792, 5866, 6016, 6067, 6176, 6263, 6272, 6312, 7680, 7835, 7840, 7929, 7936, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8319, 8319, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8497, 8499, 8505, 8544, 8579, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12346, 12353, 12436, 12445, 12446, 12449, 12538, 12540, 12542, 12549, 12588, 12593, 12686, 12704, 12727, 13312, 19893, 19968, 40869, 40960, 42124, 44032, 55203, 63744, 64045, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65138, 65140, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500];
                unicodeES3IdentifierPart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 543, 546, 563, 592, 685, 688, 696, 699, 705, 720, 721, 736, 740, 750, 750, 768, 846, 864, 866, 890, 890, 902, 902, 904, 906, 908, 908, 910, 929, 931, 974, 976, 983, 986, 1011, 1024, 1153, 1155, 1158, 1164, 1220, 1223, 1224, 1227, 1228, 1232, 1269, 1272, 1273, 1329, 1366, 1369, 1369, 1377, 1415, 1425, 1441, 1443, 1465, 1467, 1469, 1471, 1471, 1473, 1474, 1476, 1476, 1488, 1514, 1520, 1522, 1569, 1594, 1600, 1621, 1632, 1641, 1648, 1747, 1749, 1756, 1759, 1768, 1770, 1773, 1776, 1788, 1808, 1836, 1840, 1866, 1920, 1968, 2305, 2307, 2309, 2361, 2364, 2381, 2384, 2388, 2392, 2403, 2406, 2415, 2433, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2492, 2494, 2500, 2503, 2504, 2507, 2509, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2562, 2562, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2649, 2652, 2654, 2654, 2662, 2676, 2689, 2691, 2693, 2699, 2701, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2784, 2790, 2799, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2870, 2873, 2876, 2883, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2913, 2918, 2927, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 2997, 2999, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3031, 3031, 3047, 3055, 3073, 3075, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3134, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3168, 3169, 3174, 3183, 3202, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3262, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3297, 3302, 3311, 3330, 3331, 3333, 3340, 3342, 3344, 3346, 3368, 3370, 3385, 3390, 3395, 3398, 3400, 3402, 3405, 3415, 3415, 3424, 3425, 3430, 3439, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3769, 3771, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3805, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3946, 3953, 3972, 3974, 3979, 3984, 3991, 3993, 4028, 4038, 4038, 4096, 4129, 4131, 4135, 4137, 4138, 4140, 4146, 4150, 4153, 4160, 4169, 4176, 4185, 4256, 4293, 4304, 4342, 4352, 4441, 4447, 4514, 4520, 4601, 4608, 4614, 4616, 4678, 4680, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4742, 4744, 4744, 4746, 4749, 4752, 4782, 4784, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4814, 4816, 4822, 4824, 4846, 4848, 4878, 4880, 4880, 4882, 4885, 4888, 4894, 4896, 4934, 4936, 4954, 4969, 4977, 5024, 5108, 5121, 5740, 5743, 5750, 5761, 5786, 5792, 5866, 6016, 6099, 6112, 6121, 6160, 6169, 6176, 6263, 6272, 6313, 7680, 7835, 7840, 7929, 7936, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8255, 8256, 8319, 8319, 8400, 8412, 8417, 8417, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8497, 8499, 8505, 8544, 8579, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12346, 12353, 12436, 12441, 12442, 12445, 12446, 12449, 12542, 12549, 12588, 12593, 12686, 12704, 12727, 13312, 19893, 19968, 40869, 40960, 42124, 44032, 55203, 63744, 64045, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65056, 65059, 65075, 65076, 65101, 65103, 65136, 65138, 65140, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65381, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500];
                unicodeES5IdentifierStart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 880, 884, 886, 887, 890, 893, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1162, 1319, 1329, 1366, 1369, 1369, 1377, 1415, 1488, 1514, 1520, 1522, 1568, 1610, 1646, 1647, 1649, 1747, 1749, 1749, 1765, 1766, 1774, 1775, 1786, 1788, 1791, 1791, 1808, 1808, 1810, 1839, 1869, 1957, 1969, 1969, 1994, 2026, 2036, 2037, 2042, 2042, 2048, 2069, 2074, 2074, 2084, 2084, 2088, 2088, 2112, 2136, 2208, 2208, 2210, 2220, 2308, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2417, 2423, 2425, 2431, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2493, 2493, 2510, 2510, 2524, 2525, 2527, 2529, 2544, 2545, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2785, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2929, 2929, 2947, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3024, 3024, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3133, 3133, 3160, 3161, 3168, 3169, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3261, 3261, 3294, 3294, 3296, 3297, 3313, 3314, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3389, 3406, 3406, 3424, 3425, 3450, 3455, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3807, 3840, 3840, 3904, 3911, 3913, 3948, 3976, 3980, 4096, 4138, 4159, 4159, 4176, 4181, 4186, 4189, 4193, 4193, 4197, 4198, 4206, 4208, 4213, 4225, 4238, 4238, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4992, 5007, 5024, 5108, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5872, 5888, 5900, 5902, 5905, 5920, 5937, 5952, 5969, 5984, 5996, 5998, 6e3, 6016, 6067, 6103, 6103, 6108, 6108, 6176, 6263, 6272, 6312, 6314, 6314, 6320, 6389, 6400, 6428, 6480, 6509, 6512, 6516, 6528, 6571, 6593, 6599, 6656, 6678, 6688, 6740, 6823, 6823, 6917, 6963, 6981, 6987, 7043, 7072, 7086, 7087, 7098, 7141, 7168, 7203, 7245, 7247, 7258, 7293, 7401, 7404, 7406, 7409, 7413, 7414, 7424, 7615, 7680, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8305, 8305, 8319, 8319, 8336, 8348, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11502, 11506, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11648, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11823, 11823, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12348, 12353, 12438, 12445, 12447, 12449, 12538, 12540, 12543, 12549, 12589, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40908, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42527, 42538, 42539, 42560, 42606, 42623, 42647, 42656, 42735, 42775, 42783, 42786, 42888, 42891, 42894, 42896, 42899, 42912, 42922, 43e3, 43009, 43011, 43013, 43015, 43018, 43020, 43042, 43072, 43123, 43138, 43187, 43250, 43255, 43259, 43259, 43274, 43301, 43312, 43334, 43360, 43388, 43396, 43442, 43471, 43471, 43520, 43560, 43584, 43586, 43588, 43595, 43616, 43638, 43642, 43642, 43648, 43695, 43697, 43697, 43701, 43702, 43705, 43709, 43712, 43712, 43714, 43714, 43739, 43741, 43744, 43754, 43762, 43764, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43968, 44002, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500];
                unicodeES5IdentifierPart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 768, 884, 886, 887, 890, 893, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1155, 1159, 1162, 1319, 1329, 1366, 1369, 1369, 1377, 1415, 1425, 1469, 1471, 1471, 1473, 1474, 1476, 1477, 1479, 1479, 1488, 1514, 1520, 1522, 1552, 1562, 1568, 1641, 1646, 1747, 1749, 1756, 1759, 1768, 1770, 1788, 1791, 1791, 1808, 1866, 1869, 1969, 1984, 2037, 2042, 2042, 2048, 2093, 2112, 2139, 2208, 2208, 2210, 2220, 2276, 2302, 2304, 2403, 2406, 2415, 2417, 2423, 2425, 2431, 2433, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2500, 2503, 2504, 2507, 2510, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2561, 2563, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2641, 2641, 2649, 2652, 2654, 2654, 2662, 2677, 2689, 2691, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2787, 2790, 2799, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2876, 2884, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2915, 2918, 2927, 2929, 2929, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3024, 3024, 3031, 3031, 3046, 3055, 3073, 3075, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3133, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3160, 3161, 3168, 3171, 3174, 3183, 3202, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3260, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3299, 3302, 3311, 3313, 3314, 3330, 3331, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3396, 3398, 3400, 3402, 3406, 3415, 3415, 3424, 3427, 3430, 3439, 3450, 3455, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3769, 3771, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3807, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3948, 3953, 3972, 3974, 3991, 3993, 4028, 4038, 4038, 4096, 4169, 4176, 4253, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4957, 4959, 4992, 5007, 5024, 5108, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5872, 5888, 5900, 5902, 5908, 5920, 5940, 5952, 5971, 5984, 5996, 5998, 6e3, 6002, 6003, 6016, 6099, 6103, 6103, 6108, 6109, 6112, 6121, 6155, 6157, 6160, 6169, 6176, 6263, 6272, 6314, 6320, 6389, 6400, 6428, 6432, 6443, 6448, 6459, 6470, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6608, 6617, 6656, 6683, 6688, 6750, 6752, 6780, 6783, 6793, 6800, 6809, 6823, 6823, 6912, 6987, 6992, 7001, 7019, 7027, 7040, 7155, 7168, 7223, 7232, 7241, 7245, 7293, 7376, 7378, 7380, 7414, 7424, 7654, 7676, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8204, 8205, 8255, 8256, 8276, 8276, 8305, 8305, 8319, 8319, 8336, 8348, 8400, 8412, 8417, 8417, 8421, 8432, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11647, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11744, 11775, 11823, 11823, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12348, 12353, 12438, 12441, 12442, 12445, 12447, 12449, 12538, 12540, 12543, 12549, 12589, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40908, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42539, 42560, 42607, 42612, 42621, 42623, 42647, 42655, 42737, 42775, 42783, 42786, 42888, 42891, 42894, 42896, 42899, 42912, 42922, 43e3, 43047, 43072, 43123, 43136, 43204, 43216, 43225, 43232, 43255, 43259, 43259, 43264, 43309, 43312, 43347, 43360, 43388, 43392, 43456, 43471, 43481, 43520, 43574, 43584, 43597, 43600, 43609, 43616, 43638, 43642, 43643, 43648, 43714, 43739, 43741, 43744, 43759, 43762, 43766, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43968, 44010, 44012, 44013, 44016, 44025, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65024, 65039, 65056, 65062, 65075, 65076, 65101, 65103, 65136, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500];
                unicodeESNextIdentifierStart = [65, 90, 97, 122, 170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 880, 884, 886, 887, 890, 893, 895, 895, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1162, 1327, 1329, 1366, 1369, 1369, 1376, 1416, 1488, 1514, 1519, 1522, 1568, 1610, 1646, 1647, 1649, 1747, 1749, 1749, 1765, 1766, 1774, 1775, 1786, 1788, 1791, 1791, 1808, 1808, 1810, 1839, 1869, 1957, 1969, 1969, 1994, 2026, 2036, 2037, 2042, 2042, 2048, 2069, 2074, 2074, 2084, 2084, 2088, 2088, 2112, 2136, 2144, 2154, 2208, 2228, 2230, 2237, 2308, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2417, 2432, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2493, 2493, 2510, 2510, 2524, 2525, 2527, 2529, 2544, 2545, 2556, 2556, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2785, 2809, 2809, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2929, 2929, 2947, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3024, 3024, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3129, 3133, 3133, 3160, 3162, 3168, 3169, 3200, 3200, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3261, 3261, 3294, 3294, 3296, 3297, 3313, 3314, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3389, 3406, 3406, 3412, 3414, 3423, 3425, 3450, 3455, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3718, 3722, 3724, 3747, 3749, 3749, 3751, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3807, 3840, 3840, 3904, 3911, 3913, 3948, 3976, 3980, 4096, 4138, 4159, 4159, 4176, 4181, 4186, 4189, 4193, 4193, 4197, 4198, 4206, 4208, 4213, 4225, 4238, 4238, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4992, 5007, 5024, 5109, 5112, 5117, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5880, 5888, 5900, 5902, 5905, 5920, 5937, 5952, 5969, 5984, 5996, 5998, 6e3, 6016, 6067, 6103, 6103, 6108, 6108, 6176, 6264, 6272, 6312, 6314, 6314, 6320, 6389, 6400, 6430, 6480, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6656, 6678, 6688, 6740, 6823, 6823, 6917, 6963, 6981, 6987, 7043, 7072, 7086, 7087, 7098, 7141, 7168, 7203, 7245, 7247, 7258, 7293, 7296, 7304, 7312, 7354, 7357, 7359, 7401, 7404, 7406, 7411, 7413, 7414, 7418, 7418, 7424, 7615, 7680, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8305, 8305, 8319, 8319, 8336, 8348, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8472, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11502, 11506, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11648, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12348, 12353, 12438, 12443, 12447, 12449, 12538, 12540, 12543, 12549, 12591, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40943, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42527, 42538, 42539, 42560, 42606, 42623, 42653, 42656, 42735, 42775, 42783, 42786, 42888, 42891, 42943, 42946, 42950, 42999, 43009, 43011, 43013, 43015, 43018, 43020, 43042, 43072, 43123, 43138, 43187, 43250, 43255, 43259, 43259, 43261, 43262, 43274, 43301, 43312, 43334, 43360, 43388, 43396, 43442, 43471, 43471, 43488, 43492, 43494, 43503, 43514, 43518, 43520, 43560, 43584, 43586, 43588, 43595, 43616, 43638, 43642, 43642, 43646, 43695, 43697, 43697, 43701, 43702, 43705, 43709, 43712, 43712, 43714, 43714, 43739, 43741, 43744, 43754, 43762, 43764, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43824, 43866, 43868, 43879, 43888, 44002, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500, 65536, 65547, 65549, 65574, 65576, 65594, 65596, 65597, 65599, 65613, 65616, 65629, 65664, 65786, 65856, 65908, 66176, 66204, 66208, 66256, 66304, 66335, 66349, 66378, 66384, 66421, 66432, 66461, 66464, 66499, 66504, 66511, 66513, 66517, 66560, 66717, 66736, 66771, 66776, 66811, 66816, 66855, 66864, 66915, 67072, 67382, 67392, 67413, 67424, 67431, 67584, 67589, 67592, 67592, 67594, 67637, 67639, 67640, 67644, 67644, 67647, 67669, 67680, 67702, 67712, 67742, 67808, 67826, 67828, 67829, 67840, 67861, 67872, 67897, 67968, 68023, 68030, 68031, 68096, 68096, 68112, 68115, 68117, 68119, 68121, 68149, 68192, 68220, 68224, 68252, 68288, 68295, 68297, 68324, 68352, 68405, 68416, 68437, 68448, 68466, 68480, 68497, 68608, 68680, 68736, 68786, 68800, 68850, 68864, 68899, 69376, 69404, 69415, 69415, 69424, 69445, 69600, 69622, 69635, 69687, 69763, 69807, 69840, 69864, 69891, 69926, 69956, 69956, 69968, 70002, 70006, 70006, 70019, 70066, 70081, 70084, 70106, 70106, 70108, 70108, 70144, 70161, 70163, 70187, 70272, 70278, 70280, 70280, 70282, 70285, 70287, 70301, 70303, 70312, 70320, 70366, 70405, 70412, 70415, 70416, 70419, 70440, 70442, 70448, 70450, 70451, 70453, 70457, 70461, 70461, 70480, 70480, 70493, 70497, 70656, 70708, 70727, 70730, 70751, 70751, 70784, 70831, 70852, 70853, 70855, 70855, 71040, 71086, 71128, 71131, 71168, 71215, 71236, 71236, 71296, 71338, 71352, 71352, 71424, 71450, 71680, 71723, 71840, 71903, 71935, 71935, 72096, 72103, 72106, 72144, 72161, 72161, 72163, 72163, 72192, 72192, 72203, 72242, 72250, 72250, 72272, 72272, 72284, 72329, 72349, 72349, 72384, 72440, 72704, 72712, 72714, 72750, 72768, 72768, 72818, 72847, 72960, 72966, 72968, 72969, 72971, 73008, 73030, 73030, 73056, 73061, 73063, 73064, 73066, 73097, 73112, 73112, 73440, 73458, 73728, 74649, 74752, 74862, 74880, 75075, 77824, 78894, 82944, 83526, 92160, 92728, 92736, 92766, 92880, 92909, 92928, 92975, 92992, 92995, 93027, 93047, 93053, 93071, 93760, 93823, 93952, 94026, 94032, 94032, 94099, 94111, 94176, 94177, 94179, 94179, 94208, 100343, 100352, 101106, 110592, 110878, 110928, 110930, 110948, 110951, 110960, 111355, 113664, 113770, 113776, 113788, 113792, 113800, 113808, 113817, 119808, 119892, 119894, 119964, 119966, 119967, 119970, 119970, 119973, 119974, 119977, 119980, 119982, 119993, 119995, 119995, 119997, 120003, 120005, 120069, 120071, 120074, 120077, 120084, 120086, 120092, 120094, 120121, 120123, 120126, 120128, 120132, 120134, 120134, 120138, 120144, 120146, 120485, 120488, 120512, 120514, 120538, 120540, 120570, 120572, 120596, 120598, 120628, 120630, 120654, 120656, 120686, 120688, 120712, 120714, 120744, 120746, 120770, 120772, 120779, 123136, 123180, 123191, 123197, 123214, 123214, 123584, 123627, 124928, 125124, 125184, 125251, 125259, 125259, 126464, 126467, 126469, 126495, 126497, 126498, 126500, 126500, 126503, 126503, 126505, 126514, 126516, 126519, 126521, 126521, 126523, 126523, 126530, 126530, 126535, 126535, 126537, 126537, 126539, 126539, 126541, 126543, 126545, 126546, 126548, 126548, 126551, 126551, 126553, 126553, 126555, 126555, 126557, 126557, 126559, 126559, 126561, 126562, 126564, 126564, 126567, 126570, 126572, 126578, 126580, 126583, 126585, 126588, 126590, 126590, 126592, 126601, 126603, 126619, 126625, 126627, 126629, 126633, 126635, 126651, 131072, 173782, 173824, 177972, 177984, 178205, 178208, 183969, 183984, 191456, 194560, 195101];
                unicodeESNextIdentifierPart = [48, 57, 65, 90, 95, 95, 97, 122, 170, 170, 181, 181, 183, 183, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 768, 884, 886, 887, 890, 893, 895, 895, 902, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1155, 1159, 1162, 1327, 1329, 1366, 1369, 1369, 1376, 1416, 1425, 1469, 1471, 1471, 1473, 1474, 1476, 1477, 1479, 1479, 1488, 1514, 1519, 1522, 1552, 1562, 1568, 1641, 1646, 1747, 1749, 1756, 1759, 1768, 1770, 1788, 1791, 1791, 1808, 1866, 1869, 1969, 1984, 2037, 2042, 2042, 2045, 2045, 2048, 2093, 2112, 2139, 2144, 2154, 2208, 2228, 2230, 2237, 2259, 2273, 2275, 2403, 2406, 2415, 2417, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2500, 2503, 2504, 2507, 2510, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2556, 2556, 2558, 2558, 2561, 2563, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2641, 2641, 2649, 2652, 2654, 2654, 2662, 2677, 2689, 2691, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2787, 2790, 2799, 2809, 2815, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2876, 2884, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2915, 2918, 2927, 2929, 2929, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3024, 3024, 3031, 3031, 3046, 3055, 3072, 3084, 3086, 3088, 3090, 3112, 3114, 3129, 3133, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3160, 3162, 3168, 3171, 3174, 3183, 3200, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3260, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3299, 3302, 3311, 3313, 3314, 3328, 3331, 3333, 3340, 3342, 3344, 3346, 3396, 3398, 3400, 3402, 3406, 3412, 3415, 3423, 3427, 3430, 3439, 3450, 3455, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3558, 3567, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3718, 3722, 3724, 3747, 3749, 3749, 3751, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3807, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3948, 3953, 3972, 3974, 3991, 3993, 4028, 4038, 4038, 4096, 4169, 4176, 4253, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4957, 4959, 4969, 4977, 4992, 5007, 5024, 5109, 5112, 5117, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5880, 5888, 5900, 5902, 5908, 5920, 5940, 5952, 5971, 5984, 5996, 5998, 6e3, 6002, 6003, 6016, 6099, 6103, 6103, 6108, 6109, 6112, 6121, 6155, 6157, 6160, 6169, 6176, 6264, 6272, 6314, 6320, 6389, 6400, 6430, 6432, 6443, 6448, 6459, 6470, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6608, 6618, 6656, 6683, 6688, 6750, 6752, 6780, 6783, 6793, 6800, 6809, 6823, 6823, 6832, 6845, 6912, 6987, 6992, 7001, 7019, 7027, 7040, 7155, 7168, 7223, 7232, 7241, 7245, 7293, 7296, 7304, 7312, 7354, 7357, 7359, 7376, 7378, 7380, 7418, 7424, 7673, 7675, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8255, 8256, 8276, 8276, 8305, 8305, 8319, 8319, 8336, 8348, 8400, 8412, 8417, 8417, 8421, 8432, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8472, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11647, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11744, 11775, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12348, 12353, 12438, 12441, 12447, 12449, 12538, 12540, 12543, 12549, 12591, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40943, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42539, 42560, 42607, 42612, 42621, 42623, 42737, 42775, 42783, 42786, 42888, 42891, 42943, 42946, 42950, 42999, 43047, 43072, 43123, 43136, 43205, 43216, 43225, 43232, 43255, 43259, 43259, 43261, 43309, 43312, 43347, 43360, 43388, 43392, 43456, 43471, 43481, 43488, 43518, 43520, 43574, 43584, 43597, 43600, 43609, 43616, 43638, 43642, 43714, 43739, 43741, 43744, 43759, 43762, 43766, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43824, 43866, 43868, 43879, 43888, 44010, 44012, 44013, 44016, 44025, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65024, 65039, 65056, 65071, 65075, 65076, 65101, 65103, 65136, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500, 65536, 65547, 65549, 65574, 65576, 65594, 65596, 65597, 65599, 65613, 65616, 65629, 65664, 65786, 65856, 65908, 66045, 66045, 66176, 66204, 66208, 66256, 66272, 66272, 66304, 66335, 66349, 66378, 66384, 66426, 66432, 66461, 66464, 66499, 66504, 66511, 66513, 66517, 66560, 66717, 66720, 66729, 66736, 66771, 66776, 66811, 66816, 66855, 66864, 66915, 67072, 67382, 67392, 67413, 67424, 67431, 67584, 67589, 67592, 67592, 67594, 67637, 67639, 67640, 67644, 67644, 67647, 67669, 67680, 67702, 67712, 67742, 67808, 67826, 67828, 67829, 67840, 67861, 67872, 67897, 67968, 68023, 68030, 68031, 68096, 68099, 68101, 68102, 68108, 68115, 68117, 68119, 68121, 68149, 68152, 68154, 68159, 68159, 68192, 68220, 68224, 68252, 68288, 68295, 68297, 68326, 68352, 68405, 68416, 68437, 68448, 68466, 68480, 68497, 68608, 68680, 68736, 68786, 68800, 68850, 68864, 68903, 68912, 68921, 69376, 69404, 69415, 69415, 69424, 69456, 69600, 69622, 69632, 69702, 69734, 69743, 69759, 69818, 69840, 69864, 69872, 69881, 69888, 69940, 69942, 69951, 69956, 69958, 69968, 70003, 70006, 70006, 70016, 70084, 70089, 70092, 70096, 70106, 70108, 70108, 70144, 70161, 70163, 70199, 70206, 70206, 70272, 70278, 70280, 70280, 70282, 70285, 70287, 70301, 70303, 70312, 70320, 70378, 70384, 70393, 70400, 70403, 70405, 70412, 70415, 70416, 70419, 70440, 70442, 70448, 70450, 70451, 70453, 70457, 70459, 70468, 70471, 70472, 70475, 70477, 70480, 70480, 70487, 70487, 70493, 70499, 70502, 70508, 70512, 70516, 70656, 70730, 70736, 70745, 70750, 70751, 70784, 70853, 70855, 70855, 70864, 70873, 71040, 71093, 71096, 71104, 71128, 71133, 71168, 71232, 71236, 71236, 71248, 71257, 71296, 71352, 71360, 71369, 71424, 71450, 71453, 71467, 71472, 71481, 71680, 71738, 71840, 71913, 71935, 71935, 72096, 72103, 72106, 72151, 72154, 72161, 72163, 72164, 72192, 72254, 72263, 72263, 72272, 72345, 72349, 72349, 72384, 72440, 72704, 72712, 72714, 72758, 72760, 72768, 72784, 72793, 72818, 72847, 72850, 72871, 72873, 72886, 72960, 72966, 72968, 72969, 72971, 73014, 73018, 73018, 73020, 73021, 73023, 73031, 73040, 73049, 73056, 73061, 73063, 73064, 73066, 73102, 73104, 73105, 73107, 73112, 73120, 73129, 73440, 73462, 73728, 74649, 74752, 74862, 74880, 75075, 77824, 78894, 82944, 83526, 92160, 92728, 92736, 92766, 92768, 92777, 92880, 92909, 92912, 92916, 92928, 92982, 92992, 92995, 93008, 93017, 93027, 93047, 93053, 93071, 93760, 93823, 93952, 94026, 94031, 94087, 94095, 94111, 94176, 94177, 94179, 94179, 94208, 100343, 100352, 101106, 110592, 110878, 110928, 110930, 110948, 110951, 110960, 111355, 113664, 113770, 113776, 113788, 113792, 113800, 113808, 113817, 113821, 113822, 119141, 119145, 119149, 119154, 119163, 119170, 119173, 119179, 119210, 119213, 119362, 119364, 119808, 119892, 119894, 119964, 119966, 119967, 119970, 119970, 119973, 119974, 119977, 119980, 119982, 119993, 119995, 119995, 119997, 120003, 120005, 120069, 120071, 120074, 120077, 120084, 120086, 120092, 120094, 120121, 120123, 120126, 120128, 120132, 120134, 120134, 120138, 120144, 120146, 120485, 120488, 120512, 120514, 120538, 120540, 120570, 120572, 120596, 120598, 120628, 120630, 120654, 120656, 120686, 120688, 120712, 120714, 120744, 120746, 120770, 120772, 120779, 120782, 120831, 121344, 121398, 121403, 121452, 121461, 121461, 121476, 121476, 121499, 121503, 121505, 121519, 122880, 122886, 122888, 122904, 122907, 122913, 122915, 122916, 122918, 122922, 123136, 123180, 123184, 123197, 123200, 123209, 123214, 123214, 123584, 123641, 124928, 125124, 125136, 125142, 125184, 125259, 125264, 125273, 126464, 126467, 126469, 126495, 126497, 126498, 126500, 126500, 126503, 126503, 126505, 126514, 126516, 126519, 126521, 126521, 126523, 126523, 126530, 126530, 126535, 126535, 126537, 126537, 126539, 126539, 126541, 126543, 126545, 126546, 126548, 126548, 126551, 126551, 126553, 126553, 126555, 126555, 126557, 126557, 126559, 126559, 126561, 126562, 126564, 126564, 126567, 126570, 126572, 126578, 126580, 126583, 126585, 126588, 126590, 126590, 126592, 126601, 126603, 126619, 126625, 126627, 126629, 126633, 126635, 126651, 131072, 173782, 173824, 177972, 177984, 178205, 178208, 183969, 183984, 191456, 194560, 195101, 917760, 917999];
                commentDirectiveRegExSingleLine = /^\/\/\/?\s*@(ts-expect-error|ts-ignore)/;
                commentDirectiveRegExMultiLine = /^(?:\/|\*)*\s*@(ts-expect-error|ts-ignore)/;
                tokenStrings = makeReverseMap(textToToken);
                mergeConflictMarkerLength = "<<<<<<<".length;
                shebangTriviaRegex = /^#!.*/;
                codePointAt = String.prototype.codePointAt ? (s, i) => s.codePointAt(i) : function codePointAt2(str, i) {
                    const size = str.length;
                    if (i < 0 || i >= size) {
                        return void 0;
                    }
                    const first2 = str.charCodeAt(i);
                    if (first2 >= 55296 && first2 <= 56319 && size > i + 1) {
                        const second = str.charCodeAt(i + 1);
                        if (second >= 56320 && second <= 57343) {
                            return (first2 - 55296) * 1024 + second - 56320 + 65536;
                        }
                    }
                    return first2;
                };
                utf16EncodeAsStringWorker = String.fromCodePoint ? (codePoint) => String.fromCodePoint(codePoint) : utf16EncodeAsStringFallback;
            }
        });
        // src/compiler/utilitiesPublic.ts
        function isExternalModuleNameRelative(moduleName) {
            return pathIsRelative(moduleName) || isRootedDiskPath(moduleName);
        }
        function sortAndDeduplicateDiagnostics(diagnostics) {
            return sortAndDeduplicate(diagnostics, compareDiagnostics);
        }
        function getDefaultLibFileName(options) {
            switch (getEmitScriptTarget(options)) {
                case 99 /* ESNext */:
                    return "lib.esnext.full.d.ts";
                case 9 /* ES2022 */:
                    return "lib.es2022.full.d.ts";
                case 8 /* ES2021 */:
                    return "lib.es2021.full.d.ts";
                case 7 /* ES2020 */:
                    return "lib.es2020.full.d.ts";
                case 6 /* ES2019 */:
                    return "lib.es2019.full.d.ts";
                case 5 /* ES2018 */:
                    return "lib.es2018.full.d.ts";
                case 4 /* ES2017 */:
                    return "lib.es2017.full.d.ts";
                case 3 /* ES2016 */:
                    return "lib.es2016.full.d.ts";
                case 2 /* ES2015 */:
                    return "lib.es6.d.ts";
                default:
                    return "lib.d.ts";
            }
        }
        function textSpanEnd(span) {
            return span.start + span.length;
        }
        function textSpanIsEmpty(span) {
            return span.length === 0;
        }
        function textSpanContainsPosition(span, position) {
            return position >= span.start && position < textSpanEnd(span);
        }
        function textRangeContainsPositionInclusive(span, position) {
            return position >= span.pos && position <= span.end;
        }
        function textSpanContainsTextSpan(span, other) {
            return other.start >= span.start && textSpanEnd(other) <= textSpanEnd(span);
        }
        function textSpanOverlapsWith(span, other) {
            return textSpanOverlap(span, other) !== void 0;
        }
        function textSpanOverlap(span1, span2) {
            const overlap = textSpanIntersection(span1, span2);
            return overlap && overlap.length === 0 ? void 0 : overlap;
        }
        function textSpanIntersectsWithTextSpan(span, other) {
            return decodedTextSpanIntersectsWith(span.start, span.length, other.start, other.length);
        }
        function textSpanIntersectsWith(span, start, length2) {
            return decodedTextSpanIntersectsWith(span.start, span.length, start, length2);
        }
        function decodedTextSpanIntersectsWith(start1, length1, start2, length2) {
            const end1 = start1 + length1;
            const end2 = start2 + length2;
            return start2 <= end1 && end2 >= start1;
        }
        function textSpanIntersectsWithPosition(span, position) {
            return position <= textSpanEnd(span) && position >= span.start;
        }
        function textSpanIntersection(span1, span2) {
            const start = Math.max(span1.start, span2.start);
            const end = Math.min(textSpanEnd(span1), textSpanEnd(span2));
            return start <= end ? createTextSpanFromBounds(start, end) : void 0;
        }
        function createTextSpan(start, length2) {
            if (start < 0) {
                throw new Error("start < 0");
            }
            if (length2 < 0) {
                throw new Error("length < 0");
            }
            return { start, length: length2 };
        }
        function createTextSpanFromBounds(start, end) {
            return createTextSpan(start, end - start);
        }
        function textChangeRangeNewSpan(range) {
            return createTextSpan(range.span.start, range.newLength);
        }
        function textChangeRangeIsUnchanged(range) {
            return textSpanIsEmpty(range.span) && range.newLength === 0;
        }
        function createTextChangeRange(span, newLength) {
            if (newLength < 0) {
                throw new Error("newLength < 0");
            }
            return { span, newLength };
        }
        function collapseTextChangeRangesAcrossMultipleVersions(changes) {
            if (changes.length === 0) {
                return unchangedTextChangeRange;
            }
            if (changes.length === 1) {
                return changes[0];
            }
            const change0 = changes[0];
            let oldStartN = change0.span.start;
            let oldEndN = textSpanEnd(change0.span);
            let newEndN = oldStartN + change0.newLength;
            for (let i = 1; i < changes.length; i++) {
                const nextChange = changes[i];
                const oldStart1 = oldStartN;
                const oldEnd1 = oldEndN;
                const newEnd1 = newEndN;
                const oldStart2 = nextChange.span.start;
                const oldEnd2 = textSpanEnd(nextChange.span);
                const newEnd2 = oldStart2 + nextChange.newLength;
                oldStartN = Math.min(oldStart1, oldStart2);
                oldEndN = Math.max(oldEnd1, oldEnd1 + (oldEnd2 - newEnd1));
                newEndN = Math.max(newEnd2, newEnd2 + (newEnd1 - oldEnd2));
            }
            return createTextChangeRange(createTextSpanFromBounds(oldStartN, oldEndN), 
            /*newLength*/
            newEndN - oldStartN);
        }
        function getTypeParameterOwner(d) {
            if (d && d.kind === 165 /* TypeParameter */) {
                for (let current = d; current; current = current.parent) {
                    if (isFunctionLike(current) || isClassLike(current) || current.kind === 261 /* InterfaceDeclaration */) {
                        return current;
                    }
                }
            }
        }
        function isParameterPropertyDeclaration(node, parent2) {
            return isParameter(node) && hasSyntacticModifier(node, 16476 /* ParameterPropertyModifier */) && parent2.kind === 173 /* Constructor */;
        }
        function isEmptyBindingPattern(node) {
            if (isBindingPattern(node)) {
                return every(node.elements, isEmptyBindingElement);
            }
            return false;
        }
        function isEmptyBindingElement(node) {
            if (isOmittedExpression(node)) {
                return true;
            }
            return isEmptyBindingPattern(node.name);
        }
        function walkUpBindingElementsAndPatterns(binding) {
            let node = binding.parent;
            while (isBindingElement(node.parent)) {
                node = node.parent.parent;
            }
            return node.parent;
        }
        function getCombinedFlags(node, getFlags) {
            if (isBindingElement(node)) {
                node = walkUpBindingElementsAndPatterns(node);
            }
            let flags = getFlags(node);
            if (node.kind === 257 /* VariableDeclaration */) {
                node = node.parent;
            }
            if (node && node.kind === 258 /* VariableDeclarationList */) {
                flags |= getFlags(node);
                node = node.parent;
            }
            if (node && node.kind === 240 /* VariableStatement */) {
                flags |= getFlags(node);
            }
            return flags;
        }
        function getCombinedModifierFlags(node) {
            return getCombinedFlags(node, getEffectiveModifierFlags);
        }
        function getCombinedNodeFlagsAlwaysIncludeJSDoc(node) {
            return getCombinedFlags(node, getEffectiveModifierFlagsAlwaysIncludeJSDoc);
        }
        function getCombinedNodeFlags(node) {
            return getCombinedFlags(node, (n) => n.flags);
        }
        function validateLocaleAndSetLanguage(locale, sys2, errors) {
            const lowerCaseLocale = locale.toLowerCase();
            const matchResult = /^([a-z]+)([_\-]([a-z]+))?$/.exec(lowerCaseLocale);
            if (!matchResult) {
                if (errors) {
                    errors.push(createCompilerDiagnostic(Diagnostics.Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1, "en", "ja-jp"));
                }
                return;
            }
            const language = matchResult[1];
            const territory = matchResult[3];
            if (contains(supportedLocaleDirectories, lowerCaseLocale) && !trySetLanguageAndTerritory(language, territory, errors)) {
                trySetLanguageAndTerritory(language, 
                /*territory*/
                void 0, errors);
            }
            setUILocale(locale);
            function trySetLanguageAndTerritory(language2, territory2, errors2) {
                const compilerFilePath = normalizePath(sys2.getExecutingFilePath());
                const containingDirectoryPath = getDirectoryPath(compilerFilePath);
                let filePath = combinePaths(containingDirectoryPath, language2);
                if (territory2) {
                    filePath = filePath + "-" + territory2;
                }
                filePath = sys2.resolvePath(combinePaths(filePath, "diagnosticMessages.generated.json"));
                if (!sys2.fileExists(filePath)) {
                    return false;
                }
                let fileContents = "";
                try {
                    fileContents = sys2.readFile(filePath);
                }
                catch (e) {
                    if (errors2) {
                        errors2.push(createCompilerDiagnostic(Diagnostics.Unable_to_open_file_0, filePath));
                    }
                    return false;
                }
                try {
                    setLocalizedDiagnosticMessages(JSON.parse(fileContents));
                }
                catch (e) {
                    if (errors2) {
                        errors2.push(createCompilerDiagnostic(Diagnostics.Corrupted_locale_file_0, filePath));
                    }
                    return false;
                }
                return true;
            }
        }
        function getOriginalNode(node, nodeTest) {
            if (node) {
                while (node.original !== void 0) {
                    node = node.original;
                }
            }
            if (!node || !nodeTest) {
                return node;
            }
            return nodeTest(node) ? node : void 0;
        }
        function findAncestor(node, callback) {
            while (node) {
                const result = callback(node);
                if (result === "quit") {
                    return void 0;
                }
                else if (result) {
                    return node;
                }
                node = node.parent;
            }
            return void 0;
        }
        function isParseTreeNode(node) {
            return (node.flags & 8 /* Synthesized */) === 0;
        }
        function getParseTreeNode(node, nodeTest) {
            if (node === void 0 || isParseTreeNode(node)) {
                return node;
            }
            node = node.original;
            while (node) {
                if (isParseTreeNode(node)) {
                    return !nodeTest || nodeTest(node) ? node : void 0;
                }
                node = node.original;
            }
        }
        function escapeLeadingUnderscores(identifier) {
            return identifier.length >= 2 && identifier.charCodeAt(0) === 95 /* _ */ && identifier.charCodeAt(1) === 95 /* _ */ ? "_" + identifier : identifier;
        }
        function unescapeLeadingUnderscores(identifier) {
            const id = identifier;
            return id.length >= 3 && id.charCodeAt(0) === 95 /* _ */ && id.charCodeAt(1) === 95 /* _ */ && id.charCodeAt(2) === 95 /* _ */ ? id.substr(1) : id;
        }
        function idText(identifierOrPrivateName) {
            return unescapeLeadingUnderscores(identifierOrPrivateName.escapedText);
        }
        function identifierToKeywordKind(node) {
            const token = stringToToken(node.escapedText);
            return token ? tryCast(token, isKeyword) : void 0;
        }
        function symbolName(symbol) {
            if (symbol.valueDeclaration && isPrivateIdentifierClassElementDeclaration(symbol.valueDeclaration)) {
                return idText(symbol.valueDeclaration.name);
            }
            return unescapeLeadingUnderscores(symbol.escapedName);
        }
        function nameForNamelessJSDocTypedef(declaration) {
            const hostNode = declaration.parent.parent;
            if (!hostNode) {
                return void 0;
            }
            if (isDeclaration(hostNode)) {
                return getDeclarationIdentifier(hostNode);
            }
            switch (hostNode.kind) {
                case 240 /* VariableStatement */:
                    if (hostNode.declarationList && hostNode.declarationList.declarations[0]) {
                        return getDeclarationIdentifier(hostNode.declarationList.declarations[0]);
                    }
                    break;
                case 241 /* ExpressionStatement */:
                    let expr = hostNode.expression;
                    if (expr.kind === 223 /* BinaryExpression */ && expr.operatorToken.kind === 63 /* EqualsToken */) {
                        expr = expr.left;
                    }
                    switch (expr.kind) {
                        case 208 /* PropertyAccessExpression */:
                            return expr.name;
                        case 209 /* ElementAccessExpression */:
                            const arg = expr.argumentExpression;
                            if (isIdentifier(arg)) {
                                return arg;
                            }
                    }
                    break;
                case 214 /* ParenthesizedExpression */: {
                    return getDeclarationIdentifier(hostNode.expression);
                }
                case 253 /* LabeledStatement */: {
                    if (isDeclaration(hostNode.statement) || isExpression(hostNode.statement)) {
                        return getDeclarationIdentifier(hostNode.statement);
                    }
                    break;
                }
            }
        }
        function getDeclarationIdentifier(node) {
            const name = getNameOfDeclaration(node);
            return name && isIdentifier(name) ? name : void 0;
        }
        function nodeHasName(statement, name) {
            if (isNamedDeclaration(statement) && isIdentifier(statement.name) && idText(statement.name) === idText(name)) {
                return true;
            }
            if (isVariableStatement(statement) && some(statement.declarationList.declarations, (d) => nodeHasName(d, name))) {
                return true;
            }
            return false;
        }
        function getNameOfJSDocTypedef(declaration) {
            return declaration.name || nameForNamelessJSDocTypedef(declaration);
        }
        function isNamedDeclaration(node) {
            return !!node.name;
        }
        function getNonAssignedNameOfDeclaration(declaration) {
            switch (declaration.kind) {
                case 79 /* Identifier */:
                    return declaration;
                case 351 /* JSDocPropertyTag */:
                case 344 /* JSDocParameterTag */: {
                    const { name } = declaration;
                    if (name.kind === 163 /* QualifiedName */) {
                        return name.right;
                    }
                    break;
                }
                case 210 /* CallExpression */:
                case 223 /* BinaryExpression */: {
                    const expr2 = declaration;
                    switch (getAssignmentDeclarationKind(expr2)) {
                        case 1 /* ExportsProperty */:
                        case 4 /* ThisProperty */:
                        case 5 /* Property */:
                        case 3 /* PrototypeProperty */:
                            return getElementOrPropertyAccessArgumentExpressionOrName(expr2.left);
                        case 7 /* ObjectDefinePropertyValue */:
                        case 8 /* ObjectDefinePropertyExports */:
                        case 9 /* ObjectDefinePrototypeProperty */:
                            return expr2.arguments[1];
                        default:
                            return void 0;
                    }
                }
                case 349 /* JSDocTypedefTag */:
                    return getNameOfJSDocTypedef(declaration);
                case 343 /* JSDocEnumTag */:
                    return nameForNamelessJSDocTypedef(declaration);
                case 274 /* ExportAssignment */: {
                    const { expression } = declaration;
                    return isIdentifier(expression) ? expression : void 0;
                }
                case 209 /* ElementAccessExpression */:
                    const expr = declaration;
                    if (isBindableStaticElementAccessExpression(expr)) {
                        return expr.argumentExpression;
                    }
            }
            return declaration.name;
        }
        function getNameOfDeclaration(declaration) {
            if (declaration === void 0)
                return void 0;
            return getNonAssignedNameOfDeclaration(declaration) || (isFunctionExpression(declaration) || isArrowFunction(declaration) || isClassExpression(declaration) ? getAssignedName(declaration) : void 0);
        }
        function getAssignedName(node) {
            if (!node.parent) {
                return void 0;
            }
            else if (isPropertyAssignment(node.parent) || isBindingElement(node.parent)) {
                return node.parent.name;
            }
            else if (isBinaryExpression(node.parent) && node === node.parent.right) {
                if (isIdentifier(node.parent.left)) {
                    return node.parent.left;
                }
                else if (isAccessExpression(node.parent.left)) {
                    return getElementOrPropertyAccessArgumentExpressionOrName(node.parent.left);
                }
            }
            else if (isVariableDeclaration(node.parent) && isIdentifier(node.parent.name)) {
                return node.parent.name;
            }
        }
        function getDecorators(node) {
            if (hasDecorators(node)) {
                return filter(node.modifiers, isDecorator);
            }
        }
        function getModifiers(node) {
            if (hasSyntacticModifier(node, 126975 /* Modifier */)) {
                return filter(node.modifiers, isModifier);
            }
        }
        function getJSDocParameterTagsWorker(param, noCache) {
            if (param.name) {
                if (isIdentifier(param.name)) {
                    const name = param.name.escapedText;
                    return getJSDocTagsWorker(param.parent, noCache).filter((tag) => isJSDocParameterTag(tag) && isIdentifier(tag.name) && tag.name.escapedText === name);
                }
                else {
                    const i = param.parent.parameters.indexOf(param);
                    Debug.assert(i > -1, "Parameters should always be in their parents' parameter list");
                    const paramTags = getJSDocTagsWorker(param.parent, noCache).filter(isJSDocParameterTag);
                    if (i < paramTags.length) {
                        return [paramTags[i]];
                    }
                }
            }
            return emptyArray;
        }
        function getJSDocParameterTags(param) {
            return getJSDocParameterTagsWorker(param, 
            /*noCache*/
            false);
        }
        function getJSDocParameterTagsNoCache(param) {
            return getJSDocParameterTagsWorker(param, 
            /*noCache*/
            true);
        }
        function getJSDocTypeParameterTagsWorker(param, noCache) {
            const name = param.name.escapedText;
            return getJSDocTagsWorker(param.parent, noCache).filter((tag) => isJSDocTemplateTag(tag) && tag.typeParameters.some((tp) => tp.name.escapedText === name));
        }
        function getJSDocTypeParameterTags(param) {
            return getJSDocTypeParameterTagsWorker(param, 
            /*noCache*/
            false);
        }
        function getJSDocTypeParameterTagsNoCache(param) {
            return getJSDocTypeParameterTagsWorker(param, 
            /*noCache*/
            true);
        }
        function hasJSDocParameterTags(node) {
            return !!getFirstJSDocTag(node, isJSDocParameterTag);
        }
        function getJSDocAugmentsTag(node) {
            return getFirstJSDocTag(node, isJSDocAugmentsTag);
        }
        function getJSDocImplementsTags(node) {
            return getAllJSDocTags(node, isJSDocImplementsTag);
        }
        function getJSDocClassTag(node) {
            return getFirstJSDocTag(node, isJSDocClassTag);
        }
        function getJSDocPublicTag(node) {
            return getFirstJSDocTag(node, isJSDocPublicTag);
        }
        function getJSDocPublicTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocPublicTag, 
            /*noCache*/
            true);
        }
        function getJSDocPrivateTag(node) {
            return getFirstJSDocTag(node, isJSDocPrivateTag);
        }
        function getJSDocPrivateTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocPrivateTag, 
            /*noCache*/
            true);
        }
        function getJSDocProtectedTag(node) {
            return getFirstJSDocTag(node, isJSDocProtectedTag);
        }
        function getJSDocProtectedTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocProtectedTag, 
            /*noCache*/
            true);
        }
        function getJSDocReadonlyTag(node) {
            return getFirstJSDocTag(node, isJSDocReadonlyTag);
        }
        function getJSDocReadonlyTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocReadonlyTag, 
            /*noCache*/
            true);
        }
        function getJSDocOverrideTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocOverrideTag, 
            /*noCache*/
            true);
        }
        function getJSDocDeprecatedTag(node) {
            return getFirstJSDocTag(node, isJSDocDeprecatedTag);
        }
        function getJSDocDeprecatedTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocDeprecatedTag, 
            /*noCache*/
            true);
        }
        function getJSDocEnumTag(node) {
            return getFirstJSDocTag(node, isJSDocEnumTag);
        }
        function getJSDocThisTag(node) {
            return getFirstJSDocTag(node, isJSDocThisTag);
        }
        function getJSDocReturnTag(node) {
            return getFirstJSDocTag(node, isJSDocReturnTag);
        }
        function getJSDocTemplateTag(node) {
            return getFirstJSDocTag(node, isJSDocTemplateTag);
        }
        function getJSDocSatisfiesTag(node) {
            return getFirstJSDocTag(node, isJSDocSatisfiesTag);
        }
        function getJSDocTypeTag(node) {
            const tag = getFirstJSDocTag(node, isJSDocTypeTag);
            if (tag && tag.typeExpression && tag.typeExpression.type) {
                return tag;
            }
            return void 0;
        }
        function getJSDocType(node) {
            let tag = getFirstJSDocTag(node, isJSDocTypeTag);
            if (!tag && isParameter(node)) {
                tag = find(getJSDocParameterTags(node), (tag2) => !!tag2.typeExpression);
            }
            return tag && tag.typeExpression && tag.typeExpression.type;
        }
        function getJSDocReturnType(node) {
            const returnTag = getJSDocReturnTag(node);
            if (returnTag && returnTag.typeExpression) {
                return returnTag.typeExpression.type;
            }
            const typeTag = getJSDocTypeTag(node);
            if (typeTag && typeTag.typeExpression) {
                const type = typeTag.typeExpression.type;
                if (isTypeLiteralNode(type)) {
                    const sig = find(type.members, isCallSignatureDeclaration);
                    return sig && sig.type;
                }
                if (isFunctionTypeNode(type) || isJSDocFunctionType(type)) {
                    return type.type;
                }
            }
        }
        function getJSDocTagsWorker(node, noCache) {
            var _a2, _b;
            if (!canHaveJSDoc(node))
                return emptyArray;
            let tags = (_a2 = node.jsDoc) == null ? void 0 : _a2.jsDocCache;
            if (tags === void 0 || noCache) {
                const comments = getJSDocCommentsAndTags(node, noCache);
                Debug.assert(comments.length < 2 || comments[0] !== comments[1]);
                tags = flatMap(comments, (j) => isJSDoc(j) ? j.tags : j);
                if (!noCache) {
                    (_b = node.jsDoc) != null ? _b : node.jsDoc = [];
                    node.jsDoc.jsDocCache = tags;
                }
            }
            return tags;
        }
        function getJSDocTags(node) {
            return getJSDocTagsWorker(node, 
            /*noCache*/
            false);
        }
        function getJSDocTagsNoCache(node) {
            return getJSDocTagsWorker(node, 
            /*noCache*/
            true);
        }
        function getFirstJSDocTag(node, predicate, noCache) {
            return find(getJSDocTagsWorker(node, noCache), predicate);
        }
        function getAllJSDocTags(node, predicate) {
            return getJSDocTags(node).filter(predicate);
        }
        function getAllJSDocTagsOfKind(node, kind) {
            return getJSDocTags(node).filter((doc) => doc.kind === kind);
        }
        function getTextOfJSDocComment(comment) {
            return typeof comment === "string" ? comment : comment == null ? void 0 : comment.map((c) => c.kind === 324 /* JSDocText */ ? c.text : formatJSDocLink(c)).join("");
        }
        function formatJSDocLink(link) {
            const kind = link.kind === 327 /* JSDocLink */ ? "link" : link.kind === 328 /* JSDocLinkCode */ ? "linkcode" : "linkplain";
            const name = link.name ? entityNameToString(link.name) : "";
            const space = link.name && link.text.startsWith("://") ? "" : " ";
            return `{@${kind} ${name}${space}${link.text}}`;
        }
        function getEffectiveTypeParameterDeclarations(node) {
            if (isJSDocSignature(node)) {
                if (isJSDocOverloadTag(node.parent)) {
                    const jsDoc = getJSDocRoot(node.parent);
                    if (jsDoc && length(jsDoc.tags)) {
                        return flatMap(jsDoc.tags, (tag) => isJSDocTemplateTag(tag) ? tag.typeParameters : void 0);
                    }
                }
                return emptyArray;
            }
            if (isJSDocTypeAlias(node)) {
                Debug.assert(node.parent.kind === 323 /* JSDoc */);
                return flatMap(node.parent.tags, (tag) => isJSDocTemplateTag(tag) ? tag.typeParameters : void 0);
            }
            if (node.typeParameters) {
                return node.typeParameters;
            }
            if (canHaveIllegalTypeParameters(node) && node.typeParameters) {
                return node.typeParameters;
            }
            if (isInJSFile(node)) {
                const decls = getJSDocTypeParameterDeclarations(node);
                if (decls.length) {
                    return decls;
                }
                const typeTag = getJSDocType(node);
                if (typeTag && isFunctionTypeNode(typeTag) && typeTag.typeParameters) {
                    return typeTag.typeParameters;
                }
            }
            return emptyArray;
        }
        function getEffectiveConstraintOfTypeParameter(node) {
            return node.constraint ? node.constraint : isJSDocTemplateTag(node.parent) && node === node.parent.typeParameters[0] ? node.parent.constraint : void 0;
        }
        function isMemberName(node) {
            return node.kind === 79 /* Identifier */ || node.kind === 80 /* PrivateIdentifier */;
        }
        function isGetOrSetAccessorDeclaration(node) {
            return node.kind === 175 /* SetAccessor */ || node.kind === 174 /* GetAccessor */;
        }
        function isPropertyAccessChain(node) {
            return isPropertyAccessExpression(node) && !!(node.flags & 32 /* OptionalChain */);
        }
        function isElementAccessChain(node) {
            return isElementAccessExpression(node) && !!(node.flags & 32 /* OptionalChain */);
        }
        function isCallChain(node) {
            return isCallExpression(node) && !!(node.flags & 32 /* OptionalChain */);
        }
        function isOptionalChain(node) {
            const kind = node.kind;
            return !!(node.flags & 32 /* OptionalChain */) && (kind === 208 /* PropertyAccessExpression */ || kind === 209 /* ElementAccessExpression */ || kind === 210 /* CallExpression */ || kind === 232 /* NonNullExpression */);
        }
        function isOptionalChainRoot(node) {
            return isOptionalChain(node) && !isNonNullExpression(node) && !!node.questionDotToken;
        }
        function isExpressionOfOptionalChainRoot(node) {
            return isOptionalChainRoot(node.parent) && node.parent.expression === node;
        }
        function isOutermostOptionalChain(node) {
            return !isOptionalChain(node.parent) || isOptionalChainRoot(node.parent) || node !== node.parent.expression;
        }
        function isNullishCoalesce(node) {
            return node.kind === 223 /* BinaryExpression */ && node.operatorToken.kind === 60 /* QuestionQuestionToken */;
        }
        function isConstTypeReference(node) {
            return isTypeReferenceNode(node) && isIdentifier(node.typeName) && node.typeName.escapedText === "const" && !node.typeArguments;
        }
        function skipPartiallyEmittedExpressions(node) {
            return skipOuterExpressions(node, 8 /* PartiallyEmittedExpressions */);
        }
        function isNonNullChain(node) {
            return isNonNullExpression(node) && !!(node.flags & 32 /* OptionalChain */);
        }
        function isBreakOrContinueStatement(node) {
            return node.kind === 249 /* BreakStatement */ || node.kind === 248 /* ContinueStatement */;
        }
        function isNamedExportBindings(node) {
            return node.kind === 277 /* NamespaceExport */ || node.kind === 276 /* NamedExports */;
        }
        function isUnparsedTextLike(node) {
            switch (node.kind) {
                case 305 /* UnparsedText */:
                case 306 /* UnparsedInternalText */:
                    return true;
                default:
                    return false;
            }
        }
        function isUnparsedNode(node) {
            return isUnparsedTextLike(node) || node.kind === 303 /* UnparsedPrologue */ || node.kind === 307 /* UnparsedSyntheticReference */;
        }
        function isJSDocPropertyLikeTag(node) {
            return node.kind === 351 /* JSDocPropertyTag */ || node.kind === 344 /* JSDocParameterTag */;
        }
        function isNode(node) {
            return isNodeKind(node.kind);
        }
        function isNodeKind(kind) {
            return kind >= 163 /* FirstNode */;
        }
        function isTokenKind(kind) {
            return kind >= 0 /* FirstToken */ && kind <= 162 /* LastToken */;
        }
        function isToken(n) {
            return isTokenKind(n.kind);
        }
        function isNodeArray(array) {
            return hasProperty(array, "pos") && hasProperty(array, "end");
        }
        function isLiteralKind(kind) {
            return 8 /* FirstLiteralToken */ <= kind && kind <= 14 /* LastLiteralToken */;
        }
        function isLiteralExpression(node) {
            return isLiteralKind(node.kind);
        }
        function isLiteralExpressionOfObject(node) {
            switch (node.kind) {
                case 207 /* ObjectLiteralExpression */:
                case 206 /* ArrayLiteralExpression */:
                case 13 /* RegularExpressionLiteral */:
                case 215 /* FunctionExpression */:
                case 228 /* ClassExpression */:
                    return true;
            }
            return false;
        }
        function isTemplateLiteralKind(kind) {
            return 14 /* FirstTemplateToken */ <= kind && kind <= 17 /* LastTemplateToken */;
        }
        function isTemplateLiteralToken(node) {
            return isTemplateLiteralKind(node.kind);
        }
        function isTemplateMiddleOrTemplateTail(node) {
            const kind = node.kind;
            return kind === 16 /* TemplateMiddle */ || kind === 17 /* TemplateTail */;
        }
        function isImportOrExportSpecifier(node) {
            return isImportSpecifier(node) || isExportSpecifier(node);
        }
        function isTypeOnlyImportDeclaration(node) {
            switch (node.kind) {
                case 273 /* ImportSpecifier */:
                    return node.isTypeOnly || node.parent.parent.isTypeOnly;
                case 271 /* NamespaceImport */:
                    return node.parent.isTypeOnly;
                case 270 /* ImportClause */:
                case 268 /* ImportEqualsDeclaration */:
                    return node.isTypeOnly;
            }
            return false;
        }
        function isTypeOnlyExportDeclaration(node) {
            switch (node.kind) {
                case 278 /* ExportSpecifier */:
                    return node.isTypeOnly || node.parent.parent.isTypeOnly;
                case 275 /* ExportDeclaration */:
                    return node.isTypeOnly && !!node.moduleSpecifier && !node.exportClause;
                case 277 /* NamespaceExport */:
                    return node.parent.isTypeOnly;
            }
            return false;
        }
        function isTypeOnlyImportOrExportDeclaration(node) {
            return isTypeOnlyImportDeclaration(node) || isTypeOnlyExportDeclaration(node);
        }
        function isAssertionKey(node) {
            return isStringLiteral(node) || isIdentifier(node);
        }
        function isStringTextContainingNode(node) {
            return node.kind === 10 /* StringLiteral */ || isTemplateLiteralKind(node.kind);
        }
        function isGeneratedIdentifier(node) {
            var _a2;
            return isIdentifier(node) && ((_a2 = node.emitNode) == null ? void 0 : _a2.autoGenerate) !== void 0;
        }
        function isGeneratedPrivateIdentifier(node) {
            var _a2;
            return isPrivateIdentifier(node) && ((_a2 = node.emitNode) == null ? void 0 : _a2.autoGenerate) !== void 0;
        }
        function isPrivateIdentifierClassElementDeclaration(node) {
            return (isPropertyDeclaration(node) || isMethodOrAccessor(node)) && isPrivateIdentifier(node.name);
        }
        function isPrivateIdentifierPropertyAccessExpression(node) {
            return isPropertyAccessExpression(node) && isPrivateIdentifier(node.name);
        }
        function isModifierKind(token) {
            switch (token) {
                case 126 /* AbstractKeyword */:
                case 127 /* AccessorKeyword */:
                case 132 /* AsyncKeyword */:
                case 85 /* ConstKeyword */:
                case 136 /* DeclareKeyword */:
                case 88 /* DefaultKeyword */:
                case 93 /* ExportKeyword */:
                case 101 /* InKeyword */:
                case 123 /* PublicKeyword */:
                case 121 /* PrivateKeyword */:
                case 122 /* ProtectedKeyword */:
                case 146 /* ReadonlyKeyword */:
                case 124 /* StaticKeyword */:
                case 145 /* OutKeyword */:
                case 161 /* OverrideKeyword */:
                    return true;
            }
            return false;
        }
        function isParameterPropertyModifier(kind) {
            return !!(modifierToFlag(kind) & 16476 /* ParameterPropertyModifier */);
        }
        function isClassMemberModifier(idToken) {
            return isParameterPropertyModifier(idToken) || idToken === 124 /* StaticKeyword */ || idToken === 161 /* OverrideKeyword */ || idToken === 127 /* AccessorKeyword */;
        }
        function isModifier(node) {
            return isModifierKind(node.kind);
        }
        function isEntityName(node) {
            const kind = node.kind;
            return kind === 163 /* QualifiedName */ || kind === 79 /* Identifier */;
        }
        function isPropertyName(node) {
            const kind = node.kind;
            return kind === 79 /* Identifier */ || kind === 80 /* PrivateIdentifier */ || kind === 10 /* StringLiteral */ || kind === 8 /* NumericLiteral */ || kind === 164 /* ComputedPropertyName */;
        }
        function isBindingName(node) {
            const kind = node.kind;
            return kind === 79 /* Identifier */ || kind === 203 /* ObjectBindingPattern */ || kind === 204 /* ArrayBindingPattern */;
        }
        function isFunctionLike(node) {
            return !!node && isFunctionLikeKind(node.kind);
        }
        function isFunctionLikeOrClassStaticBlockDeclaration(node) {
            return !!node && (isFunctionLikeKind(node.kind) || isClassStaticBlockDeclaration(node));
        }
        function isFunctionLikeDeclaration(node) {
            return node && isFunctionLikeDeclarationKind(node.kind);
        }
        function isBooleanLiteral(node) {
            return node.kind === 110 /* TrueKeyword */ || node.kind === 95 /* FalseKeyword */;
        }
        function isFunctionLikeDeclarationKind(kind) {
            switch (kind) {
                case 259 /* FunctionDeclaration */:
                case 171 /* MethodDeclaration */:
                case 173 /* Constructor */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                    return true;
                default:
                    return false;
            }
        }
        function isFunctionLikeKind(kind) {
            switch (kind) {
                case 170 /* MethodSignature */:
                case 176 /* CallSignature */:
                case 326 /* JSDocSignature */:
                case 177 /* ConstructSignature */:
                case 178 /* IndexSignature */:
                case 181 /* FunctionType */:
                case 320 /* JSDocFunctionType */:
                case 182 /* ConstructorType */:
                    return true;
                default:
                    return isFunctionLikeDeclarationKind(kind);
            }
        }
        function isFunctionOrModuleBlock(node) {
            return isSourceFile(node) || isModuleBlock(node) || isBlock(node) && isFunctionLike(node.parent);
        }
        function isClassElement(node) {
            const kind = node.kind;
            return kind === 173 /* Constructor */ || kind === 169 /* PropertyDeclaration */ || kind === 171 /* MethodDeclaration */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */ || kind === 178 /* IndexSignature */ || kind === 172 /* ClassStaticBlockDeclaration */ || kind === 237 /* SemicolonClassElement */;
        }
        function isClassLike(node) {
            return node && (node.kind === 260 /* ClassDeclaration */ || node.kind === 228 /* ClassExpression */);
        }
        function isAccessor(node) {
            return node && (node.kind === 174 /* GetAccessor */ || node.kind === 175 /* SetAccessor */);
        }
        function isAutoAccessorPropertyDeclaration(node) {
            return isPropertyDeclaration(node) && hasAccessorModifier(node);
        }
        function isMethodOrAccessor(node) {
            switch (node.kind) {
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    return true;
                default:
                    return false;
            }
        }
        function isNamedClassElement(node) {
            switch (node.kind) {
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 169 /* PropertyDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function isModifierLike(node) {
            return isModifier(node) || isDecorator(node);
        }
        function isTypeElement(node) {
            const kind = node.kind;
            return kind === 177 /* ConstructSignature */ || kind === 176 /* CallSignature */ || kind === 168 /* PropertySignature */ || kind === 170 /* MethodSignature */ || kind === 178 /* IndexSignature */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */;
        }
        function isClassOrTypeElement(node) {
            return isTypeElement(node) || isClassElement(node);
        }
        function isObjectLiteralElementLike(node) {
            const kind = node.kind;
            return kind === 299 /* PropertyAssignment */ || kind === 300 /* ShorthandPropertyAssignment */ || kind === 301 /* SpreadAssignment */ || kind === 171 /* MethodDeclaration */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */;
        }
        function isTypeNode(node) {
            return isTypeNodeKind(node.kind);
        }
        function isFunctionOrConstructorTypeNode(node) {
            switch (node.kind) {
                case 181 /* FunctionType */:
                case 182 /* ConstructorType */:
                    return true;
            }
            return false;
        }
        function isBindingPattern(node) {
            if (node) {
                const kind = node.kind;
                return kind === 204 /* ArrayBindingPattern */ || kind === 203 /* ObjectBindingPattern */;
            }
            return false;
        }
        function isAssignmentPattern(node) {
            const kind = node.kind;
            return kind === 206 /* ArrayLiteralExpression */ || kind === 207 /* ObjectLiteralExpression */;
        }
        function isArrayBindingElement(node) {
            const kind = node.kind;
            return kind === 205 /* BindingElement */ || kind === 229 /* OmittedExpression */;
        }
        function isDeclarationBindingElement(bindingElement) {
            switch (bindingElement.kind) {
                case 257 /* VariableDeclaration */:
                case 166 /* Parameter */:
                case 205 /* BindingElement */:
                    return true;
            }
            return false;
        }
        function isBindingOrAssignmentElement(node) {
            return isVariableDeclaration(node) || isParameter(node) || isObjectBindingOrAssignmentElement(node) || isArrayBindingOrAssignmentElement(node);
        }
        function isBindingOrAssignmentPattern(node) {
            return isObjectBindingOrAssignmentPattern(node) || isArrayBindingOrAssignmentPattern(node);
        }
        function isObjectBindingOrAssignmentPattern(node) {
            switch (node.kind) {
                case 203 /* ObjectBindingPattern */:
                case 207 /* ObjectLiteralExpression */:
                    return true;
            }
            return false;
        }
        function isObjectBindingOrAssignmentElement(node) {
            switch (node.kind) {
                case 205 /* BindingElement */:
                case 299 /* PropertyAssignment */:
                case 300 /* ShorthandPropertyAssignment */:
                case 301 /* SpreadAssignment */:
                    return true;
            }
            return false;
        }
        function isArrayBindingOrAssignmentPattern(node) {
            switch (node.kind) {
                case 204 /* ArrayBindingPattern */:
                case 206 /* ArrayLiteralExpression */:
                    return true;
            }
            return false;
        }
        function isArrayBindingOrAssignmentElement(node) {
            switch (node.kind) {
                case 205 /* BindingElement */:
                case 229 /* OmittedExpression */:
                case 227 /* SpreadElement */:
                case 206 /* ArrayLiteralExpression */:
                case 207 /* ObjectLiteralExpression */:
                case 79 /* Identifier */:
                case 208 /* PropertyAccessExpression */:
                case 209 /* ElementAccessExpression */:
                    return true;
            }
            return isAssignmentExpression(node, 
            /*excludeCompoundAssignment*/
            true);
        }
        function isPropertyAccessOrQualifiedNameOrImportTypeNode(node) {
            const kind = node.kind;
            return kind === 208 /* PropertyAccessExpression */ || kind === 163 /* QualifiedName */ || kind === 202 /* ImportType */;
        }
        function isPropertyAccessOrQualifiedName(node) {
            const kind = node.kind;
            return kind === 208 /* PropertyAccessExpression */ || kind === 163 /* QualifiedName */;
        }
        function isCallLikeExpression(node) {
            switch (node.kind) {
                case 283 /* JsxOpeningElement */:
                case 282 /* JsxSelfClosingElement */:
                case 210 /* CallExpression */:
                case 211 /* NewExpression */:
                case 212 /* TaggedTemplateExpression */:
                case 167 /* Decorator */:
                    return true;
                default:
                    return false;
            }
        }
        function isCallOrNewExpression(node) {
            return node.kind === 210 /* CallExpression */ || node.kind === 211 /* NewExpression */;
        }
        function isTemplateLiteral(node) {
            const kind = node.kind;
            return kind === 225 /* TemplateExpression */ || kind === 14 /* NoSubstitutionTemplateLiteral */;
        }
        function isLeftHandSideExpression(node) {
            return isLeftHandSideExpressionKind(skipPartiallyEmittedExpressions(node).kind);
        }
        function isLeftHandSideExpressionKind(kind) {
            switch (kind) {
                case 208 /* PropertyAccessExpression */:
                case 209 /* ElementAccessExpression */:
                case 211 /* NewExpression */:
                case 210 /* CallExpression */:
                case 281 /* JsxElement */:
                case 282 /* JsxSelfClosingElement */:
                case 285 /* JsxFragment */:
                case 212 /* TaggedTemplateExpression */:
                case 206 /* ArrayLiteralExpression */:
                case 214 /* ParenthesizedExpression */:
                case 207 /* ObjectLiteralExpression */:
                case 228 /* ClassExpression */:
                case 215 /* FunctionExpression */:
                case 79 /* Identifier */:
                case 80 /* PrivateIdentifier */:
                case 13 /* RegularExpressionLiteral */:
                case 8 /* NumericLiteral */:
                case 9 /* BigIntLiteral */:
                case 10 /* StringLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 225 /* TemplateExpression */:
                case 95 /* FalseKeyword */:
                case 104 /* NullKeyword */:
                case 108 /* ThisKeyword */:
                case 110 /* TrueKeyword */:
                case 106 /* SuperKeyword */:
                case 232 /* NonNullExpression */:
                case 230 /* ExpressionWithTypeArguments */:
                case 233 /* MetaProperty */:
                case 100 /* ImportKeyword */:
                case 279 /* MissingDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function isUnaryExpression(node) {
            return isUnaryExpressionKind(skipPartiallyEmittedExpressions(node).kind);
        }
        function isUnaryExpressionKind(kind) {
            switch (kind) {
                case 221 /* PrefixUnaryExpression */:
                case 222 /* PostfixUnaryExpression */:
                case 217 /* DeleteExpression */:
                case 218 /* TypeOfExpression */:
                case 219 /* VoidExpression */:
                case 220 /* AwaitExpression */:
                case 213 /* TypeAssertionExpression */:
                    return true;
                default:
                    return isLeftHandSideExpressionKind(kind);
            }
        }
        function isUnaryExpressionWithWrite(expr) {
            switch (expr.kind) {
                case 222 /* PostfixUnaryExpression */:
                    return true;
                case 221 /* PrefixUnaryExpression */:
                    return expr.operator === 45 /* PlusPlusToken */ || expr.operator === 46 /* MinusMinusToken */;
                default:
                    return false;
            }
        }
        function isLiteralTypeLiteral(node) {
            switch (node.kind) {
                case 104 /* NullKeyword */:
                case 110 /* TrueKeyword */:
                case 95 /* FalseKeyword */:
                case 221 /* PrefixUnaryExpression */:
                    return true;
                default:
                    return isLiteralExpression(node);
            }
        }
        function isExpression(node) {
            return isExpressionKind(skipPartiallyEmittedExpressions(node).kind);
        }
        function isExpressionKind(kind) {
            switch (kind) {
                case 224 /* ConditionalExpression */:
                case 226 /* YieldExpression */:
                case 216 /* ArrowFunction */:
                case 223 /* BinaryExpression */:
                case 227 /* SpreadElement */:
                case 231 /* AsExpression */:
                case 229 /* OmittedExpression */:
                case 357 /* CommaListExpression */:
                case 356 /* PartiallyEmittedExpression */:
                case 235 /* SatisfiesExpression */:
                    return true;
                default:
                    return isUnaryExpressionKind(kind);
            }
        }
        function isAssertionExpression(node) {
            const kind = node.kind;
            return kind === 213 /* TypeAssertionExpression */ || kind === 231 /* AsExpression */;
        }
        function isNotEmittedOrPartiallyEmittedNode(node) {
            return isNotEmittedStatement(node) || isPartiallyEmittedExpression(node);
        }
        function isIterationStatement(node, lookInLabeledStatements) {
            switch (node.kind) {
                case 245 /* ForStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                case 243 /* DoStatement */:
                case 244 /* WhileStatement */:
                    return true;
                case 253 /* LabeledStatement */:
                    return lookInLabeledStatements && isIterationStatement(node.statement, lookInLabeledStatements);
            }
            return false;
        }
        function isScopeMarker(node) {
            return isExportAssignment(node) || isExportDeclaration(node);
        }
        function hasScopeMarker(statements) {
            return some(statements, isScopeMarker);
        }
        function needsScopeMarker(result) {
            return !isAnyImportOrReExport(result) && !isExportAssignment(result) && !hasSyntacticModifier(result, 1 /* Export */) && !isAmbientModule(result);
        }
        function isExternalModuleIndicator(result) {
            return isAnyImportOrReExport(result) || isExportAssignment(result) || hasSyntacticModifier(result, 1 /* Export */);
        }
        function isForInOrOfStatement(node) {
            return node.kind === 246 /* ForInStatement */ || node.kind === 247 /* ForOfStatement */;
        }
        function isConciseBody(node) {
            return isBlock(node) || isExpression(node);
        }
        function isFunctionBody(node) {
            return isBlock(node);
        }
        function isForInitializer(node) {
            return isVariableDeclarationList(node) || isExpression(node);
        }
        function isModuleBody(node) {
            const kind = node.kind;
            return kind === 265 /* ModuleBlock */ || kind === 264 /* ModuleDeclaration */ || kind === 79 /* Identifier */;
        }
        function isNamespaceBody(node) {
            const kind = node.kind;
            return kind === 265 /* ModuleBlock */ || kind === 264 /* ModuleDeclaration */;
        }
        function isJSDocNamespaceBody(node) {
            const kind = node.kind;
            return kind === 79 /* Identifier */ || kind === 264 /* ModuleDeclaration */;
        }
        function isNamedImportBindings(node) {
            const kind = node.kind;
            return kind === 272 /* NamedImports */ || kind === 271 /* NamespaceImport */;
        }
        function isModuleOrEnumDeclaration(node) {
            return node.kind === 264 /* ModuleDeclaration */ || node.kind === 263 /* EnumDeclaration */;
        }
        function canHaveSymbol(node) {
            switch (node.kind) {
                case 216 /* ArrowFunction */:
                case 223 /* BinaryExpression */:
                case 205 /* BindingElement */:
                case 210 /* CallExpression */:
                case 176 /* CallSignature */:
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 172 /* ClassStaticBlockDeclaration */:
                case 173 /* Constructor */:
                case 182 /* ConstructorType */:
                case 177 /* ConstructSignature */:
                case 209 /* ElementAccessExpression */:
                case 263 /* EnumDeclaration */:
                case 302 /* EnumMember */:
                case 274 /* ExportAssignment */:
                case 275 /* ExportDeclaration */:
                case 278 /* ExportSpecifier */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 181 /* FunctionType */:
                case 174 /* GetAccessor */:
                case 79 /* Identifier */:
                case 270 /* ImportClause */:
                case 268 /* ImportEqualsDeclaration */:
                case 273 /* ImportSpecifier */:
                case 178 /* IndexSignature */:
                case 261 /* InterfaceDeclaration */:
                case 341 /* JSDocCallbackTag */:
                case 343 /* JSDocEnumTag */:
                case 320 /* JSDocFunctionType */:
                case 344 /* JSDocParameterTag */:
                case 351 /* JSDocPropertyTag */:
                case 326 /* JSDocSignature */:
                case 349 /* JSDocTypedefTag */:
                case 325 /* JSDocTypeLiteral */:
                case 288 /* JsxAttribute */:
                case 289 /* JsxAttributes */:
                case 290 /* JsxSpreadAttribute */:
                case 197 /* MappedType */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 264 /* ModuleDeclaration */:
                case 199 /* NamedTupleMember */:
                case 277 /* NamespaceExport */:
                case 267 /* NamespaceExportDeclaration */:
                case 271 /* NamespaceImport */:
                case 211 /* NewExpression */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 8 /* NumericLiteral */:
                case 207 /* ObjectLiteralExpression */:
                case 166 /* Parameter */:
                case 208 /* PropertyAccessExpression */:
                case 299 /* PropertyAssignment */:
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 175 /* SetAccessor */:
                case 300 /* ShorthandPropertyAssignment */:
                case 308 /* SourceFile */:
                case 301 /* SpreadAssignment */:
                case 10 /* StringLiteral */:
                case 262 /* TypeAliasDeclaration */:
                case 184 /* TypeLiteral */:
                case 165 /* TypeParameter */:
                case 257 /* VariableDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function canHaveLocals(node) {
            switch (node.kind) {
                case 216 /* ArrowFunction */:
                case 238 /* Block */:
                case 176 /* CallSignature */:
                case 266 /* CaseBlock */:
                case 295 /* CatchClause */:
                case 172 /* ClassStaticBlockDeclaration */:
                case 191 /* ConditionalType */:
                case 173 /* Constructor */:
                case 182 /* ConstructorType */:
                case 177 /* ConstructSignature */:
                case 245 /* ForStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 181 /* FunctionType */:
                case 174 /* GetAccessor */:
                case 178 /* IndexSignature */:
                case 341 /* JSDocCallbackTag */:
                case 343 /* JSDocEnumTag */:
                case 320 /* JSDocFunctionType */:
                case 326 /* JSDocSignature */:
                case 349 /* JSDocTypedefTag */:
                case 197 /* MappedType */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 264 /* ModuleDeclaration */:
                case 175 /* SetAccessor */:
                case 308 /* SourceFile */:
                case 262 /* TypeAliasDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function isDeclarationKind(kind) {
            return kind === 216 /* ArrowFunction */ || kind === 205 /* BindingElement */ || kind === 260 /* ClassDeclaration */ || kind === 228 /* ClassExpression */ || kind === 172 /* ClassStaticBlockDeclaration */ || kind === 173 /* Constructor */ || kind === 263 /* EnumDeclaration */ || kind === 302 /* EnumMember */ || kind === 278 /* ExportSpecifier */ || kind === 259 /* FunctionDeclaration */ || kind === 215 /* FunctionExpression */ || kind === 174 /* GetAccessor */ || kind === 270 /* ImportClause */ || kind === 268 /* ImportEqualsDeclaration */ || kind === 273 /* ImportSpecifier */ || kind === 261 /* InterfaceDeclaration */ || kind === 288 /* JsxAttribute */ || kind === 171 /* MethodDeclaration */ || kind === 170 /* MethodSignature */ || kind === 264 /* ModuleDeclaration */ || kind === 267 /* NamespaceExportDeclaration */ || kind === 271 /* NamespaceImport */ || kind === 277 /* NamespaceExport */ || kind === 166 /* Parameter */ || kind === 299 /* PropertyAssignment */ || kind === 169 /* PropertyDeclaration */ || kind === 168 /* PropertySignature */ || kind === 175 /* SetAccessor */ || kind === 300 /* ShorthandPropertyAssignment */ || kind === 262 /* TypeAliasDeclaration */ || kind === 165 /* TypeParameter */ || kind === 257 /* VariableDeclaration */ || kind === 349 /* JSDocTypedefTag */ || kind === 341 /* JSDocCallbackTag */ || kind === 351 /* JSDocPropertyTag */;
        }
        function isDeclarationStatementKind(kind) {
            return kind === 259 /* FunctionDeclaration */ || kind === 279 /* MissingDeclaration */ || kind === 260 /* ClassDeclaration */ || kind === 261 /* InterfaceDeclaration */ || kind === 262 /* TypeAliasDeclaration */ || kind === 263 /* EnumDeclaration */ || kind === 264 /* ModuleDeclaration */ || kind === 269 /* ImportDeclaration */ || kind === 268 /* ImportEqualsDeclaration */ || kind === 275 /* ExportDeclaration */ || kind === 274 /* ExportAssignment */ || kind === 267 /* NamespaceExportDeclaration */;
        }
        function isStatementKindButNotDeclarationKind(kind) {
            return kind === 249 /* BreakStatement */ || kind === 248 /* ContinueStatement */ || kind === 256 /* DebuggerStatement */ || kind === 243 /* DoStatement */ || kind === 241 /* ExpressionStatement */ || kind === 239 /* EmptyStatement */ || kind === 246 /* ForInStatement */ || kind === 247 /* ForOfStatement */ || kind === 245 /* ForStatement */ || kind === 242 /* IfStatement */ || kind === 253 /* LabeledStatement */ || kind === 250 /* ReturnStatement */ || kind === 252 /* SwitchStatement */ || kind === 254 /* ThrowStatement */ || kind === 255 /* TryStatement */ || kind === 240 /* VariableStatement */ || kind === 244 /* WhileStatement */ || kind === 251 /* WithStatement */ || kind === 355 /* NotEmittedStatement */ || kind === 359 /* EndOfDeclarationMarker */ || kind === 358 /* MergeDeclarationMarker */;
        }
        function isDeclaration(node) {
            if (node.kind === 165 /* TypeParameter */) {
                return node.parent && node.parent.kind !== 348 /* JSDocTemplateTag */ || isInJSFile(node);
            }
            return isDeclarationKind(node.kind);
        }
        function isDeclarationStatement(node) {
            return isDeclarationStatementKind(node.kind);
        }
        function isStatementButNotDeclaration(node) {
            return isStatementKindButNotDeclarationKind(node.kind);
        }
        function isStatement(node) {
            const kind = node.kind;
            return isStatementKindButNotDeclarationKind(kind) || isDeclarationStatementKind(kind) || isBlockStatement(node);
        }
        function isBlockStatement(node) {
            if (node.kind !== 238 /* Block */)
                return false;
            if (node.parent !== void 0) {
                if (node.parent.kind === 255 /* TryStatement */ || node.parent.kind === 295 /* CatchClause */) {
                    return false;
                }
            }
            return !isFunctionBlock(node);
        }
        function isStatementOrBlock(node) {
            const kind = node.kind;
            return isStatementKindButNotDeclarationKind(kind) || isDeclarationStatementKind(kind) || kind === 238 /* Block */;
        }
        function isModuleReference(node) {
            const kind = node.kind;
            return kind === 280 /* ExternalModuleReference */ || kind === 163 /* QualifiedName */ || kind === 79 /* Identifier */;
        }
        function isJsxTagNameExpression(node) {
            const kind = node.kind;
            return kind === 108 /* ThisKeyword */ || kind === 79 /* Identifier */ || kind === 208 /* PropertyAccessExpression */;
        }
        function isJsxChild(node) {
            const kind = node.kind;
            return kind === 281 /* JsxElement */ || kind === 291 /* JsxExpression */ || kind === 282 /* JsxSelfClosingElement */ || kind === 11 /* JsxText */ || kind === 285 /* JsxFragment */;
        }
        function isJsxAttributeLike(node) {
            const kind = node.kind;
            return kind === 288 /* JsxAttribute */ || kind === 290 /* JsxSpreadAttribute */;
        }
        function isStringLiteralOrJsxExpression(node) {
            const kind = node.kind;
            return kind === 10 /* StringLiteral */ || kind === 291 /* JsxExpression */;
        }
        function isJsxOpeningLikeElement(node) {
            const kind = node.kind;
            return kind === 283 /* JsxOpeningElement */ || kind === 282 /* JsxSelfClosingElement */;
        }
        function isCaseOrDefaultClause(node) {
            const kind = node.kind;
            return kind === 292 /* CaseClause */ || kind === 293 /* DefaultClause */;
        }
        function isJSDocNode(node) {
            return node.kind >= 312 /* FirstJSDocNode */ && node.kind <= 353 /* LastJSDocNode */;
        }
        function isJSDocCommentContainingNode(node) {
            return node.kind === 323 /* JSDoc */ || node.kind === 322 /* JSDocNamepathType */ || node.kind === 324 /* JSDocText */ || isJSDocLinkLike(node) || isJSDocTag(node) || isJSDocTypeLiteral(node) || isJSDocSignature(node);
        }
        function isJSDocTag(node) {
            return node.kind >= 330 /* FirstJSDocTagNode */ && node.kind <= 353 /* LastJSDocTagNode */;
        }
        function isSetAccessor(node) {
            return node.kind === 175 /* SetAccessor */;
        }
        function isGetAccessor(node) {
            return node.kind === 174 /* GetAccessor */;
        }
        function hasJSDocNodes(node) {
            if (!canHaveJSDoc(node))
                return false;
            const { jsDoc } = node;
            return !!jsDoc && jsDoc.length > 0;
        }
        function hasType(node) {
            return !!node.type;
        }
        function hasInitializer(node) {
            return !!node.initializer;
        }
        function hasOnlyExpressionInitializer(node) {
            switch (node.kind) {
                case 257 /* VariableDeclaration */:
                case 166 /* Parameter */:
                case 205 /* BindingElement */:
                case 169 /* PropertyDeclaration */:
                case 299 /* PropertyAssignment */:
                case 302 /* EnumMember */:
                    return true;
                default:
                    return false;
            }
        }
        function isObjectLiteralElement(node) {
            return node.kind === 288 /* JsxAttribute */ || node.kind === 290 /* JsxSpreadAttribute */ || isObjectLiteralElementLike(node);
        }
        function isTypeReferenceType(node) {
            return node.kind === 180 /* TypeReference */ || node.kind === 230 /* ExpressionWithTypeArguments */;
        }
        function guessIndentation(lines) {
            let indentation = MAX_SMI_X86;
            for (const line of lines) {
                if (!line.length) {
                    continue;
                }
                let i = 0;
                for (; i < line.length && i < indentation; i++) {
                    if (!isWhiteSpaceLike(line.charCodeAt(i))) {
                        break;
                    }
                }
                if (i < indentation) {
                    indentation = i;
                }
                if (indentation === 0) {
                    return 0;
                }
            }
            return indentation === MAX_SMI_X86 ? void 0 : indentation;
        }
        function isStringLiteralLike(node) {
            return node.kind === 10 /* StringLiteral */ || node.kind === 14 /* NoSubstitutionTemplateLiteral */;
        }
        function isJSDocLinkLike(node) {
            return node.kind === 327 /* JSDocLink */ || node.kind === 328 /* JSDocLinkCode */ || node.kind === 329 /* JSDocLinkPlain */;
        }
        function hasRestParameter(s) {
            const last2 = lastOrUndefined(s.parameters);
            return !!last2 && isRestParameter(last2);
        }
        function isRestParameter(node) {
            const type = isJSDocParameterTag(node) ? node.typeExpression && node.typeExpression.type : node.type;
            return node.dotDotDotToken !== void 0 || !!type && type.kind === 321 /* JSDocVariadicType */;
        }
        var unchangedTextChangeRange, supportedLocaleDirectories, MAX_SMI_X86;
        var init_utilitiesPublic = __esm({
            "src/compiler/utilitiesPublic.ts"() {
                "use strict";
                init_ts2();
                unchangedTextChangeRange = createTextChangeRange(createTextSpan(0, 0), 0);
                supportedLocaleDirectories = ["cs", "de", "es", "fr", "it", "ja", "ko", "pl", "pt-br", "ru", "tr", "zh-cn", "zh-tw"];
                MAX_SMI_X86 = 1073741823;
            }
        });
        // src/compiler/utilities.ts
        function getDeclarationOfKind(symbol, kind) {
            const declarations = symbol.declarations;
            if (declarations) {
                for (const declaration of declarations) {
                    if (declaration.kind === kind) {
                        return declaration;
                    }
                }
            }
            return void 0;
        }
        function getDeclarationsOfKind(symbol, kind) {
            return filter(symbol.declarations || emptyArray, (d) => d.kind === kind);
        }
        function createSymbolTable(symbols) {
            const result = /* @__PURE__ */ new Map();
            if (symbols) {
                for (const symbol of symbols) {
                    result.set(symbol.escapedName, symbol);
                }
            }
            return result;
        }
        function isTransientSymbol(symbol) {
            return (symbol.flags & 33554432 /* Transient */) !== 0;
        }
        function createSingleLineStringWriter() {
            var str = "";
            const writeText = (text) => str += text;
            return {
                getText: () => str,
                write: writeText,
                rawWrite: writeText,
                writeKeyword: writeText,
                writeOperator: writeText,
                writePunctuation: writeText,
                writeSpace: writeText,
                writeStringLiteral: writeText,
                writeLiteral: writeText,
                writeParameter: writeText,
                writeProperty: writeText,
                writeSymbol: (s, _) => writeText(s),
                writeTrailingSemicolon: writeText,
                writeComment: writeText,
                getTextPos: () => str.length,
                getLine: () => 0,
                getColumn: () => 0,
                getIndent: () => 0,
                isAtStartOfLine: () => false,
                hasTrailingComment: () => false,
                hasTrailingWhitespace: () => !!str.length && isWhiteSpaceLike(str.charCodeAt(str.length - 1)),
                // Completely ignore indentation for string writers.  And map newlines to
                // a single space.
                writeLine: () => str += " ",
                increaseIndent: noop,
                decreaseIndent: noop,
                clear: () => str = ""
            };
        }
        function changesAffectModuleResolution(oldOptions, newOptions) {
            return oldOptions.configFilePath !== newOptions.configFilePath || optionsHaveModuleResolutionChanges(oldOptions, newOptions);
        }
        function optionsHaveModuleResolutionChanges(oldOptions, newOptions) {
            return optionsHaveChanges(oldOptions, newOptions, moduleResolutionOptionDeclarations);
        }
        function changesAffectingProgramStructure(oldOptions, newOptions) {
            return optionsHaveChanges(oldOptions, newOptions, optionsAffectingProgramStructure);
        }
        function optionsHaveChanges(oldOptions, newOptions, optionDeclarations2) {
            return oldOptions !== newOptions && optionDeclarations2.some((o) => !isJsonEqual(getCompilerOptionValue(oldOptions, o), getCompilerOptionValue(newOptions, o)));
        }
        function forEachAncestor(node, callback) {
            while (true) {
                const res = callback(node);
                if (res === "quit")
                    return void 0;
                if (res !== void 0)
                    return res;
                if (isSourceFile(node))
                    return void 0;
                node = node.parent;
            }
        }
        function forEachEntry(map2, callback) {
            const iterator = map2.entries();
            for (const [key, value] of iterator) {
                const result = callback(value, key);
                if (result) {
                    return result;
                }
            }
            return void 0;
        }
        function forEachKey(map2, callback) {
            const iterator = map2.keys();
            for (const key of iterator) {
                const result = callback(key);
                if (result) {
                    return result;
                }
            }
            return void 0;
        }
        function copyEntries(source, target) {
            source.forEach((value, key) => {
                target.set(key, value);
            });
        }
        function usingSingleLineStringWriter(action) {
            const oldString = stringWriter.getText();
            try {
                action(stringWriter);
                return stringWriter.getText();
            }
            finally {
                stringWriter.clear();
                stringWriter.writeKeyword(oldString);
            }
        }
        function getFullWidth(node) {
            return node.end - node.pos;
        }
        function getResolvedModule(sourceFile, moduleNameText, mode) {
            var _a2, _b;
            return (_b = (_a2 = sourceFile == null ? void 0 : sourceFile.resolvedModules) == null ? void 0 : _a2.get(moduleNameText, mode)) == null ? void 0 : _b.resolvedModule;
        }
        function setResolvedModule(sourceFile, moduleNameText, resolvedModule, mode) {
            if (!sourceFile.resolvedModules) {
                sourceFile.resolvedModules = createModeAwareCache();
            }
            sourceFile.resolvedModules.set(moduleNameText, mode, resolvedModule);
        }
        function setResolvedTypeReferenceDirective(sourceFile, typeReferenceDirectiveName, resolvedTypeReferenceDirective, mode) {
            if (!sourceFile.resolvedTypeReferenceDirectiveNames) {
                sourceFile.resolvedTypeReferenceDirectiveNames = createModeAwareCache();
            }
            sourceFile.resolvedTypeReferenceDirectiveNames.set(typeReferenceDirectiveName, mode, resolvedTypeReferenceDirective);
        }
        function getResolvedTypeReferenceDirective(sourceFile, typeReferenceDirectiveName, mode) {
            var _a2, _b;
            return (_b = (_a2 = sourceFile == null ? void 0 : sourceFile.resolvedTypeReferenceDirectiveNames) == null ? void 0 : _a2.get(typeReferenceDirectiveName, mode)) == null ? void 0 : _b.resolvedTypeReferenceDirective;
        }
        function projectReferenceIsEqualTo(oldRef, newRef) {
            return oldRef.path === newRef.path && !oldRef.prepend === !newRef.prepend && !oldRef.circular === !newRef.circular;
        }
        function moduleResolutionIsEqualTo(oldResolution, newResolution) {
            return oldResolution === newResolution || oldResolution.resolvedModule === newResolution.resolvedModule || !!oldResolution.resolvedModule && !!newResolution.resolvedModule && oldResolution.resolvedModule.isExternalLibraryImport === newResolution.resolvedModule.isExternalLibraryImport && oldResolution.resolvedModule.extension === newResolution.resolvedModule.extension && oldResolution.resolvedModule.resolvedFileName === newResolution.resolvedModule.resolvedFileName && oldResolution.resolvedModule.originalPath === newResolution.resolvedModule.originalPath && packageIdIsEqual(oldResolution.resolvedModule.packageId, newResolution.resolvedModule.packageId);
        }
        function packageIdIsEqual(a, b) {
            return a === b || !!a && !!b && a.name === b.name && a.subModuleName === b.subModuleName && a.version === b.version;
        }
        function packageIdToPackageName({ name, subModuleName }) {
            return subModuleName ? `${name}/${subModuleName}` : name;
        }
        function packageIdToString(packageId) {
            return `${packageIdToPackageName(packageId)}@${packageId.version}`;
        }
        function typeDirectiveIsEqualTo(oldResolution, newResolution) {
            return oldResolution === newResolution || oldResolution.resolvedTypeReferenceDirective === newResolution.resolvedTypeReferenceDirective || !!oldResolution.resolvedTypeReferenceDirective && !!newResolution.resolvedTypeReferenceDirective && oldResolution.resolvedTypeReferenceDirective.resolvedFileName === newResolution.resolvedTypeReferenceDirective.resolvedFileName && !!oldResolution.resolvedTypeReferenceDirective.primary === !!newResolution.resolvedTypeReferenceDirective.primary && oldResolution.resolvedTypeReferenceDirective.originalPath === newResolution.resolvedTypeReferenceDirective.originalPath;
        }
        function hasChangesInResolutions(names, newSourceFile, newResolutions, oldResolutions, comparer, nameAndModeGetter) {
            Debug.assert(names.length === newResolutions.length);
            for (let i = 0; i < names.length; i++) {
                const newResolution = newResolutions[i];
                const entry = names[i];
                const name = nameAndModeGetter.getName(entry);
                const mode = nameAndModeGetter.getMode(entry, newSourceFile);
                const oldResolution = oldResolutions && oldResolutions.get(name, mode);
                const changed = oldResolution ? !newResolution || !comparer(oldResolution, newResolution) : newResolution;
                if (changed) {
                    return true;
                }
            }
            return false;
        }
        function containsParseError(node) {
            aggregateChildData(node);
            return (node.flags & 524288 /* ThisNodeOrAnySubNodesHasError */) !== 0;
        }
        function aggregateChildData(node) {
            if (!(node.flags & 1048576 /* HasAggregatedChildData */)) {
                const thisNodeOrAnySubNodesHasError = (node.flags & 131072 /* ThisNodeHasError */) !== 0 || forEachChild(node, containsParseError);
                if (thisNodeOrAnySubNodesHasError) {
                    node.flags |= 524288 /* ThisNodeOrAnySubNodesHasError */;
                }
                node.flags |= 1048576 /* HasAggregatedChildData */;
            }
        }
        function getSourceFileOfNode(node) {
            while (node && node.kind !== 308 /* SourceFile */) {
                node = node.parent;
            }
            return node;
        }
        function getSourceFileOfModule(module2) {
            return getSourceFileOfNode(module2.valueDeclaration || getNonAugmentationDeclaration(module2));
        }
        function isPlainJsFile(file, checkJs) {
            return !!file && (file.scriptKind === 1 /* JS */ || file.scriptKind === 2 /* JSX */) && !file.checkJsDirective && checkJs === void 0;
        }
        function isStatementWithLocals(node) {
            switch (node.kind) {
                case 238 /* Block */:
                case 266 /* CaseBlock */:
                case 245 /* ForStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                    return true;
            }
            return false;
        }
        function getStartPositionOfLine(line, sourceFile) {
            Debug.assert(line >= 0);
            return getLineStarts(sourceFile)[line];
        }
        function nodePosToString(node) {
            const file = getSourceFileOfNode(node);
            const loc = getLineAndCharacterOfPosition(file, node.pos);
            return `${file.fileName}(${loc.line + 1},${loc.character + 1})`;
        }
        function getEndLinePosition(line, sourceFile) {
            Debug.assert(line >= 0);
            const lineStarts = getLineStarts(sourceFile);
            const lineIndex = line;
            const sourceText = sourceFile.text;
            if (lineIndex + 1 === lineStarts.length) {
                return sourceText.length - 1;
            }
            else {
                const start = lineStarts[lineIndex];
                let pos = lineStarts[lineIndex + 1] - 1;
                Debug.assert(isLineBreak(sourceText.charCodeAt(pos)));
                while (start <= pos && isLineBreak(sourceText.charCodeAt(pos))) {
                    pos--;
                }
                return pos;
            }
        }
        function isFileLevelUniqueName(sourceFile, name, hasGlobalName) {
            return !(hasGlobalName && hasGlobalName(name)) && !sourceFile.identifiers.has(name);
        }
        function nodeIsMissing(node) {
            if (node === void 0) {
                return true;
            }
            return node.pos === node.end && node.pos >= 0 && node.kind !== 1 /* EndOfFileToken */;
        }
        function nodeIsPresent(node) {
            return !nodeIsMissing(node);
        }
        function isGrammarError(parent2, child) {
            if (isTypeParameterDeclaration(parent2))
                return child === parent2.expression;
            if (isClassStaticBlockDeclaration(parent2))
                return child === parent2.modifiers;
            if (isPropertySignature(parent2))
                return child === parent2.initializer;
            if (isPropertyDeclaration(parent2))
                return child === parent2.questionToken && isAutoAccessorPropertyDeclaration(parent2);
            if (isPropertyAssignment(parent2))
                return child === parent2.modifiers || child === parent2.questionToken || child === parent2.exclamationToken || isGrammarErrorElement(parent2.modifiers, child, isModifierLike);
            if (isShorthandPropertyAssignment(parent2))
                return child === parent2.equalsToken || child === parent2.modifiers || child === parent2.questionToken || child === parent2.exclamationToken || isGrammarErrorElement(parent2.modifiers, child, isModifierLike);
            if (isMethodDeclaration(parent2))
                return child === parent2.exclamationToken;
            if (isConstructorDeclaration(parent2))
                return child === parent2.typeParameters || child === parent2.type || isGrammarErrorElement(parent2.typeParameters, child, isTypeParameterDeclaration);
            if (isGetAccessorDeclaration(parent2))
                return child === parent2.typeParameters || isGrammarErrorElement(parent2.typeParameters, child, isTypeParameterDeclaration);
            if (isSetAccessorDeclaration(parent2))
                return child === parent2.typeParameters || child === parent2.type || isGrammarErrorElement(parent2.typeParameters, child, isTypeParameterDeclaration);
            if (isNamespaceExportDeclaration(parent2))
                return child === parent2.modifiers || isGrammarErrorElement(parent2.modifiers, child, isModifierLike);
            return false;
        }
        function isGrammarErrorElement(nodeArray, child, isElement) {
            if (!nodeArray || isArray(child) || !isElement(child))
                return false;
            return contains(nodeArray, child);
        }
        function insertStatementsAfterPrologue(to, from, isPrologueDirective2) {
            if (from === void 0 || from.length === 0)
                return to;
            let statementIndex = 0;
            for (; statementIndex < to.length; ++statementIndex) {
                if (!isPrologueDirective2(to[statementIndex])) {
                    break;
                }
            }
            to.splice(statementIndex, 0, ...from);
            return to;
        }
        function insertStatementAfterPrologue(to, statement, isPrologueDirective2) {
            if (statement === void 0)
                return to;
            let statementIndex = 0;
            for (; statementIndex < to.length; ++statementIndex) {
                if (!isPrologueDirective2(to[statementIndex])) {
                    break;
                }
            }
            to.splice(statementIndex, 0, statement);
            return to;
        }
        function isAnyPrologueDirective(node) {
            return isPrologueDirective(node) || !!(getEmitFlags(node) & 2097152 /* CustomPrologue */);
        }
        function insertStatementsAfterStandardPrologue(to, from) {
            return insertStatementsAfterPrologue(to, from, isPrologueDirective);
        }
        function insertStatementsAfterCustomPrologue(to, from) {
            return insertStatementsAfterPrologue(to, from, isAnyPrologueDirective);
        }
        function insertStatementAfterStandardPrologue(to, statement) {
            return insertStatementAfterPrologue(to, statement, isPrologueDirective);
        }
        function insertStatementAfterCustomPrologue(to, statement) {
            return insertStatementAfterPrologue(to, statement, isAnyPrologueDirective);
        }
        function isRecognizedTripleSlashComment(text, commentPos, commentEnd) {
            if (text.charCodeAt(commentPos + 1) === 47 /* slash */ && commentPos + 2 < commentEnd && text.charCodeAt(commentPos + 2) === 47 /* slash */) {
                const textSubStr = text.substring(commentPos, commentEnd);
                return fullTripleSlashReferencePathRegEx.test(textSubStr) || fullTripleSlashAMDReferencePathRegEx.test(textSubStr) || fullTripleSlashReferenceTypeReferenceDirectiveRegEx.test(textSubStr) || defaultLibReferenceRegEx.test(textSubStr) ? true : false;
            }
            return false;
        }
        function isPinnedComment(text, start) {
            return text.charCodeAt(start + 1) === 42 /* asterisk */ && text.charCodeAt(start + 2) === 33 /* exclamation */;
        }
        function createCommentDirectivesMap(sourceFile, commentDirectives) {
            const directivesByLine = new Map(commentDirectives.map((commentDirective) => [
                `${getLineAndCharacterOfPosition(sourceFile, commentDirective.range.end).line}`,
                commentDirective
            ]));
            const usedLines = /* @__PURE__ */ new Map();
            return { getUnusedExpectations, markUsed };
            function getUnusedExpectations() {
                return arrayFrom(directivesByLine.entries()).filter(([line, directive]) => directive.type === 0 /* ExpectError */ && !usedLines.get(line)).map(([_, directive]) => directive);
            }
            function markUsed(line) {
                if (!directivesByLine.has(`${line}`)) {
                    return false;
                }
                usedLines.set(`${line}`, true);
                return true;
            }
        }
        function getTokenPosOfNode(node, sourceFile, includeJsDoc) {
            if (nodeIsMissing(node)) {
                return node.pos;
            }
            if (isJSDocNode(node) || node.kind === 11 /* JsxText */) {
                return skipTrivia((sourceFile || getSourceFileOfNode(node)).text, node.pos, 
                /*stopAfterLineBreak*/
                false, 
                /*stopAtComments*/
                true);
            }
            if (includeJsDoc && hasJSDocNodes(node)) {
                return getTokenPosOfNode(node.jsDoc[0], sourceFile);
            }
            if (node.kind === 354 /* SyntaxList */ && node._children.length > 0) {
                return getTokenPosOfNode(node._children[0], sourceFile, includeJsDoc);
            }
            return skipTrivia((sourceFile || getSourceFileOfNode(node)).text, node.pos, 
            /*stopAfterLineBreak*/
            false, 
            /*stopAtComments*/
            false, isInJSDoc(node));
        }
        function getNonDecoratorTokenPosOfNode(node, sourceFile) {
            const lastDecorator = !nodeIsMissing(node) && canHaveModifiers(node) ? findLast(node.modifiers, isDecorator) : void 0;
            if (!lastDecorator) {
                return getTokenPosOfNode(node, sourceFile);
            }
            return skipTrivia((sourceFile || getSourceFileOfNode(node)).text, lastDecorator.end);
        }
        function getSourceTextOfNodeFromSourceFile(sourceFile, node, includeTrivia = false) {
            return getTextOfNodeFromSourceText(sourceFile.text, node, includeTrivia);
        }
        function isJSDocTypeExpressionOrChild(node) {
            return !!findAncestor(node, isJSDocTypeExpression);
        }
        function isExportNamespaceAsDefaultDeclaration(node) {
            return !!(isExportDeclaration(node) && node.exportClause && isNamespaceExport(node.exportClause) && node.exportClause.name.escapedText === "default");
        }
        function getTextOfNodeFromSourceText(sourceText, node, includeTrivia = false) {
            if (nodeIsMissing(node)) {
                return "";
            }
            let text = sourceText.substring(includeTrivia ? node.pos : skipTrivia(sourceText, node.pos), node.end);
            if (isJSDocTypeExpressionOrChild(node)) {
                text = text.split(/\r\n|\n|\r/).map((line) => trimStringStart(line.replace(/^\s*\*/, ""))).join("\n");
            }
            return text;
        }
        function getTextOfNode(node, includeTrivia = false) {
            return getSourceTextOfNodeFromSourceFile(getSourceFileOfNode(node), node, includeTrivia);
        }
        function getPos(range) {
            return range.pos;
        }
        function indexOfNode(nodeArray, node) {
            return binarySearch(nodeArray, node, getPos, compareValues);
        }
        function getEmitFlags(node) {
            const emitNode = node.emitNode;
            return emitNode && emitNode.flags || 0;
        }
        function getInternalEmitFlags(node) {
            const emitNode = node.emitNode;
            return emitNode && emitNode.internalFlags || 0;
        }
        function getScriptTargetFeatures() {
            return new Map(Object.entries({
                Array: new Map(Object.entries({
                    es2015: [
                        "find",
                        "findIndex",
                        "fill",
                        "copyWithin",
                        "entries",
                        "keys",
                        "values"
                    ],
                    es2016: [
                        "includes"
                    ],
                    es2019: [
                        "flat",
                        "flatMap"
                    ],
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Iterator: new Map(Object.entries({
                    es2015: emptyArray
                })),
                AsyncIterator: new Map(Object.entries({
                    es2015: emptyArray
                })),
                Atomics: new Map(Object.entries({
                    es2017: emptyArray
                })),
                SharedArrayBuffer: new Map(Object.entries({
                    es2017: emptyArray
                })),
                AsyncIterable: new Map(Object.entries({
                    es2018: emptyArray
                })),
                AsyncIterableIterator: new Map(Object.entries({
                    es2018: emptyArray
                })),
                AsyncGenerator: new Map(Object.entries({
                    es2018: emptyArray
                })),
                AsyncGeneratorFunction: new Map(Object.entries({
                    es2018: emptyArray
                })),
                RegExp: new Map(Object.entries({
                    es2015: [
                        "flags",
                        "sticky",
                        "unicode"
                    ],
                    es2018: [
                        "dotAll"
                    ]
                })),
                Reflect: new Map(Object.entries({
                    es2015: [
                        "apply",
                        "construct",
                        "defineProperty",
                        "deleteProperty",
                        "get",
                        " getOwnPropertyDescriptor",
                        "getPrototypeOf",
                        "has",
                        "isExtensible",
                        "ownKeys",
                        "preventExtensions",
                        "set",
                        "setPrototypeOf"
                    ]
                })),
                ArrayConstructor: new Map(Object.entries({
                    es2015: [
                        "from",
                        "of"
                    ]
                })),
                ObjectConstructor: new Map(Object.entries({
                    es2015: [
                        "assign",
                        "getOwnPropertySymbols",
                        "keys",
                        "is",
                        "setPrototypeOf"
                    ],
                    es2017: [
                        "values",
                        "entries",
                        "getOwnPropertyDescriptors"
                    ],
                    es2019: [
                        "fromEntries"
                    ],
                    es2022: [
                        "hasOwn"
                    ]
                })),
                NumberConstructor: new Map(Object.entries({
                    es2015: [
                        "isFinite",
                        "isInteger",
                        "isNaN",
                        "isSafeInteger",
                        "parseFloat",
                        "parseInt"
                    ]
                })),
                Math: new Map(Object.entries({
                    es2015: [
                        "clz32",
                        "imul",
                        "sign",
                        "log10",
                        "log2",
                        "log1p",
                        "expm1",
                        "cosh",
                        "sinh",
                        "tanh",
                        "acosh",
                        "asinh",
                        "atanh",
                        "hypot",
                        "trunc",
                        "fround",
                        "cbrt"
                    ]
                })),
                Map: new Map(Object.entries({
                    es2015: [
                        "entries",
                        "keys",
                        "values"
                    ]
                })),
                Set: new Map(Object.entries({
                    es2015: [
                        "entries",
                        "keys",
                        "values"
                    ]
                })),
                PromiseConstructor: new Map(Object.entries({
                    es2015: [
                        "all",
                        "race",
                        "reject",
                        "resolve"
                    ],
                    es2020: [
                        "allSettled"
                    ],
                    es2021: [
                        "any"
                    ]
                })),
                Symbol: new Map(Object.entries({
                    es2015: [
                        "for",
                        "keyFor"
                    ],
                    es2019: [
                        "description"
                    ]
                })),
                WeakMap: new Map(Object.entries({
                    es2015: [
                        "entries",
                        "keys",
                        "values"
                    ]
                })),
                WeakSet: new Map(Object.entries({
                    es2015: [
                        "entries",
                        "keys",
                        "values"
                    ]
                })),
                String: new Map(Object.entries({
                    es2015: [
                        "codePointAt",
                        "includes",
                        "endsWith",
                        "normalize",
                        "repeat",
                        "startsWith",
                        "anchor",
                        "big",
                        "blink",
                        "bold",
                        "fixed",
                        "fontcolor",
                        "fontsize",
                        "italics",
                        "link",
                        "small",
                        "strike",
                        "sub",
                        "sup"
                    ],
                    es2017: [
                        "padStart",
                        "padEnd"
                    ],
                    es2019: [
                        "trimStart",
                        "trimEnd",
                        "trimLeft",
                        "trimRight"
                    ],
                    es2020: [
                        "matchAll"
                    ],
                    es2021: [
                        "replaceAll"
                    ],
                    es2022: [
                        "at"
                    ]
                })),
                StringConstructor: new Map(Object.entries({
                    es2015: [
                        "fromCodePoint",
                        "raw"
                    ]
                })),
                DateTimeFormat: new Map(Object.entries({
                    es2017: [
                        "formatToParts"
                    ]
                })),
                Promise: new Map(Object.entries({
                    es2015: emptyArray,
                    es2018: [
                        "finally"
                    ]
                })),
                RegExpMatchArray: new Map(Object.entries({
                    es2018: [
                        "groups"
                    ]
                })),
                RegExpExecArray: new Map(Object.entries({
                    es2018: [
                        "groups"
                    ]
                })),
                Intl: new Map(Object.entries({
                    es2018: [
                        "PluralRules"
                    ]
                })),
                NumberFormat: new Map(Object.entries({
                    es2018: [
                        "formatToParts"
                    ]
                })),
                SymbolConstructor: new Map(Object.entries({
                    es2020: [
                        "matchAll"
                    ]
                })),
                DataView: new Map(Object.entries({
                    es2020: [
                        "setBigInt64",
                        "setBigUint64",
                        "getBigInt64",
                        "getBigUint64"
                    ]
                })),
                BigInt: new Map(Object.entries({
                    es2020: emptyArray
                })),
                RelativeTimeFormat: new Map(Object.entries({
                    es2020: [
                        "format",
                        "formatToParts",
                        "resolvedOptions"
                    ]
                })),
                Int8Array: new Map(Object.entries({
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Uint8Array: new Map(Object.entries({
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Uint8ClampedArray: new Map(Object.entries({
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Int16Array: new Map(Object.entries({
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Uint16Array: new Map(Object.entries({
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Int32Array: new Map(Object.entries({
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Uint32Array: new Map(Object.entries({
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Float32Array: new Map(Object.entries({
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Float64Array: new Map(Object.entries({
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                BigInt64Array: new Map(Object.entries({
                    es2020: emptyArray,
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                BigUint64Array: new Map(Object.entries({
                    es2020: emptyArray,
                    es2022: [
                        "at"
                    ],
                    es2023: [
                        "findLastIndex",
                        "findLast"
                    ]
                })),
                Error: new Map(Object.entries({
                    es2022: [
                        "cause"
                    ]
                }))
            }));
        }
        function getLiteralText(node, sourceFile, flags) {
            var _a2;
            if (sourceFile && canUseOriginalText(node, flags)) {
                return getSourceTextOfNodeFromSourceFile(sourceFile, node);
            }
            switch (node.kind) {
                case 10 /* StringLiteral */: {
                    const escapeText = flags & 2 /* JsxAttributeEscape */ ? escapeJsxAttributeString : flags & 1 /* NeverAsciiEscape */ || getEmitFlags(node) & 33554432 /* NoAsciiEscaping */ ? escapeString : escapeNonAsciiString;
                    if (node.singleQuote) {
                        return "'" + escapeText(node.text, 39 /* singleQuote */) + "'";
                    }
                    else {
                        return '"' + escapeText(node.text, 34 /* doubleQuote */) + '"';
                    }
                }
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 15 /* TemplateHead */:
                case 16 /* TemplateMiddle */:
                case 17 /* TemplateTail */: {
                    const escapeText = flags & 1 /* NeverAsciiEscape */ || getEmitFlags(node) & 33554432 /* NoAsciiEscaping */ ? escapeString : escapeNonAsciiString;
                    const rawText = (_a2 = node.rawText) != null ? _a2 : escapeTemplateSubstitution(escapeText(node.text, 96 /* backtick */));
                    switch (node.kind) {
                        case 14 /* NoSubstitutionTemplateLiteral */:
                            return "`" + rawText + "`";
                        case 15 /* TemplateHead */:
                            return "`" + rawText + "${";
                        case 16 /* TemplateMiddle */:
                            return "}" + rawText + "${";
                        case 17 /* TemplateTail */:
                            return "}" + rawText + "`";
                    }
                    break;
                }
                case 8 /* NumericLiteral */:
                case 9 /* BigIntLiteral */:
                    return node.text;
                case 13 /* RegularExpressionLiteral */:
                    if (flags & 4 /* TerminateUnterminatedLiterals */ && node.isUnterminated) {
                        return node.text + (node.text.charCodeAt(node.text.length - 1) === 92 /* backslash */ ? " /" : "/");
                    }
                    return node.text;
            }
            return Debug.fail(`Literal kind '${node.kind}' not accounted for.`);
        }
        function canUseOriginalText(node, flags) {
            if (nodeIsSynthesized(node) || !node.parent || flags & 4 /* TerminateUnterminatedLiterals */ && node.isUnterminated) {
                return false;
            }
            if (isNumericLiteral(node) && node.numericLiteralFlags & 512 /* ContainsSeparator */) {
                return !!(flags & 8 /* AllowNumericSeparator */);
            }
            return !isBigIntLiteral(node);
        }
        function getTextOfConstantValue(value) {
            return isString(value) ? '"' + escapeNonAsciiString(value) + '"' : "" + value;
        }
        function makeIdentifierFromModuleName(moduleName) {
            return getBaseFileName(moduleName).replace(/^(\d)/, "_$1").replace(/\W/g, "_");
        }
        function isBlockOrCatchScoped(declaration) {
            return (getCombinedNodeFlags(declaration) & 3 /* BlockScoped */) !== 0 || isCatchClauseVariableDeclarationOrBindingElement(declaration);
        }
        function isCatchClauseVariableDeclarationOrBindingElement(declaration) {
            const node = getRootDeclaration(declaration);
            return node.kind === 257 /* VariableDeclaration */ && node.parent.kind === 295 /* CatchClause */;
        }
        function isAmbientModule(node) {
            return isModuleDeclaration(node) && (node.name.kind === 10 /* StringLiteral */ || isGlobalScopeAugmentation(node));
        }
        function isModuleWithStringLiteralName(node) {
            return isModuleDeclaration(node) && node.name.kind === 10 /* StringLiteral */;
        }
        function isNonGlobalAmbientModule(node) {
            return isModuleDeclaration(node) && isStringLiteral(node.name);
        }
        function isEffectiveModuleDeclaration(node) {
            return isModuleDeclaration(node) || isIdentifier(node);
        }
        function isShorthandAmbientModuleSymbol(moduleSymbol) {
            return isShorthandAmbientModule(moduleSymbol.valueDeclaration);
        }
        function isShorthandAmbientModule(node) {
            return !!node && node.kind === 264 /* ModuleDeclaration */ && !node.body;
        }
        function isBlockScopedContainerTopLevel(node) {
            return node.kind === 308 /* SourceFile */ || node.kind === 264 /* ModuleDeclaration */ || isFunctionLikeOrClassStaticBlockDeclaration(node);
        }
        function isGlobalScopeAugmentation(module2) {
            return !!(module2.flags & 1024 /* GlobalAugmentation */);
        }
        function isExternalModuleAugmentation(node) {
            return isAmbientModule(node) && isModuleAugmentationExternal(node);
        }
        function isModuleAugmentationExternal(node) {
            switch (node.parent.kind) {
                case 308 /* SourceFile */:
                    return isExternalModule(node.parent);
                case 265 /* ModuleBlock */:
                    return isAmbientModule(node.parent.parent) && isSourceFile(node.parent.parent.parent) && !isExternalModule(node.parent.parent.parent);
            }
            return false;
        }
        function getNonAugmentationDeclaration(symbol) {
            var _a2;
            return (_a2 = symbol.declarations) == null ? void 0 : _a2.find((d) => !isExternalModuleAugmentation(d) && !(isModuleDeclaration(d) && isGlobalScopeAugmentation(d)));
        }
        function isCommonJSContainingModuleKind(kind) {
            return kind === 1 /* CommonJS */ || kind === 100 /* Node16 */ || kind === 199 /* NodeNext */;
        }
        function isEffectiveExternalModule(node, compilerOptions) {
            return isExternalModule(node) || getIsolatedModules(compilerOptions) || isCommonJSContainingModuleKind(getEmitModuleKind(compilerOptions)) && !!node.commonJsModuleIndicator;
        }
        function isEffectiveStrictModeSourceFile(node, compilerOptions) {
            switch (node.scriptKind) {
                case 1 /* JS */:
                case 3 /* TS */:
                case 2 /* JSX */:
                case 4 /* TSX */:
                    break;
                default:
                    return false;
            }
            if (node.isDeclarationFile) {
                return false;
            }
            if (getStrictOptionValue(compilerOptions, "alwaysStrict")) {
                return true;
            }
            if (startsWithUseStrict(node.statements)) {
                return true;
            }
            if (isExternalModule(node) || getIsolatedModules(compilerOptions)) {
                if (getEmitModuleKind(compilerOptions) >= 5 /* ES2015 */) {
                    return true;
                }
                return !compilerOptions.noImplicitUseStrict;
            }
            return false;
        }
        function isAmbientPropertyDeclaration(node) {
            return !!(node.flags & 16777216 /* Ambient */) || hasSyntacticModifier(node, 2 /* Ambient */);
        }
        function isBlockScope(node, parentNode) {
            switch (node.kind) {
                case 308 /* SourceFile */:
                case 266 /* CaseBlock */:
                case 295 /* CatchClause */:
                case 264 /* ModuleDeclaration */:
                case 245 /* ForStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                case 173 /* Constructor */:
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                case 169 /* PropertyDeclaration */:
                case 172 /* ClassStaticBlockDeclaration */:
                    return true;
                case 238 /* Block */:
                    return !isFunctionLikeOrClassStaticBlockDeclaration(parentNode);
            }
            return false;
        }
        function isDeclarationWithTypeParameters(node) {
            Debug.type(node);
            switch (node.kind) {
                case 341 /* JSDocCallbackTag */:
                case 349 /* JSDocTypedefTag */:
                case 326 /* JSDocSignature */:
                    return true;
                default:
                    assertType(node);
                    return isDeclarationWithTypeParameterChildren(node);
            }
        }
        function isDeclarationWithTypeParameterChildren(node) {
            Debug.type(node);
            switch (node.kind) {
                case 176 /* CallSignature */:
                case 177 /* ConstructSignature */:
                case 170 /* MethodSignature */:
                case 178 /* IndexSignature */:
                case 181 /* FunctionType */:
                case 182 /* ConstructorType */:
                case 320 /* JSDocFunctionType */:
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 261 /* InterfaceDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 348 /* JSDocTemplateTag */:
                case 259 /* FunctionDeclaration */:
                case 171 /* MethodDeclaration */:
                case 173 /* Constructor */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                    return true;
                default:
                    assertType(node);
                    return false;
            }
        }
        function isAnyImportSyntax(node) {
            switch (node.kind) {
                case 269 /* ImportDeclaration */:
                case 268 /* ImportEqualsDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function isAnyImportOrBareOrAccessedRequire(node) {
            return isAnyImportSyntax(node) || isVariableDeclarationInitializedToBareOrAccessedRequire(node);
        }
        function isLateVisibilityPaintedStatement(node) {
            switch (node.kind) {
                case 269 /* ImportDeclaration */:
                case 268 /* ImportEqualsDeclaration */:
                case 240 /* VariableStatement */:
                case 260 /* ClassDeclaration */:
                case 259 /* FunctionDeclaration */:
                case 264 /* ModuleDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 263 /* EnumDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function hasPossibleExternalModuleReference(node) {
            return isAnyImportOrReExport(node) || isModuleDeclaration(node) || isImportTypeNode(node) || isImportCall(node);
        }
        function isAnyImportOrReExport(node) {
            return isAnyImportSyntax(node) || isExportDeclaration(node);
        }
        function getEnclosingBlockScopeContainer(node) {
            return findAncestor(node.parent, (current) => isBlockScope(current, current.parent));
        }
        function forEachEnclosingBlockScopeContainer(node, cb) {
            let container = getEnclosingBlockScopeContainer(node);
            while (container) {
                cb(container);
                container = getEnclosingBlockScopeContainer(container);
            }
        }
        function declarationNameToString(name) {
            return !name || getFullWidth(name) === 0 ? "(Missing)" : getTextOfNode(name);
        }
        function getNameFromIndexInfo(info) {
            return info.declaration ? declarationNameToString(info.declaration.parameters[0].name) : void 0;
        }
        function isComputedNonLiteralName(name) {
            return name.kind === 164 /* ComputedPropertyName */ && !isStringOrNumericLiteralLike(name.expression);
        }
        function tryGetTextOfPropertyName(name) {
            var _a2;
            switch (name.kind) {
                case 79 /* Identifier */:
                case 80 /* PrivateIdentifier */:
                    return ((_a2 = name.emitNode) == null ? void 0 : _a2.autoGenerate) ? void 0 : name.escapedText;
                case 10 /* StringLiteral */:
                case 8 /* NumericLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                    return escapeLeadingUnderscores(name.text);
                case 164 /* ComputedPropertyName */:
                    if (isStringOrNumericLiteralLike(name.expression))
                        return escapeLeadingUnderscores(name.expression.text);
                    return void 0;
                default:
                    return Debug.assertNever(name);
            }
        }
        function getTextOfPropertyName(name) {
            return Debug.checkDefined(tryGetTextOfPropertyName(name));
        }
        function entityNameToString(name) {
            switch (name.kind) {
                case 108 /* ThisKeyword */:
                    return "this";
                case 80 /* PrivateIdentifier */:
                case 79 /* Identifier */:
                    return getFullWidth(name) === 0 ? idText(name) : getTextOfNode(name);
                case 163 /* QualifiedName */:
                    return entityNameToString(name.left) + "." + entityNameToString(name.right);
                case 208 /* PropertyAccessExpression */:
                    if (isIdentifier(name.name) || isPrivateIdentifier(name.name)) {
                        return entityNameToString(name.expression) + "." + entityNameToString(name.name);
                    }
                    else {
                        return Debug.assertNever(name.name);
                    }
                case 314 /* JSDocMemberName */:
                    return entityNameToString(name.left) + entityNameToString(name.right);
                default:
                    return Debug.assertNever(name);
            }
        }
        function createDiagnosticForNode(node, message, arg0, arg1, arg2, arg3) {
            const sourceFile = getSourceFileOfNode(node);
            return createDiagnosticForNodeInSourceFile(sourceFile, node, message, arg0, arg1, arg2, arg3);
        }
        function createDiagnosticForNodeArray(sourceFile, nodes, message, arg0, arg1, arg2, arg3) {
            const start = skipTrivia(sourceFile.text, nodes.pos);
            return createFileDiagnostic(sourceFile, start, nodes.end - start, message, arg0, arg1, arg2, arg3);
        }
        function createDiagnosticForNodeInSourceFile(sourceFile, node, message, arg0, arg1, arg2, arg3) {
            const span = getErrorSpanForNode(sourceFile, node);
            return createFileDiagnostic(sourceFile, span.start, span.length, message, arg0, arg1, arg2, arg3);
        }
        function createDiagnosticForNodeFromMessageChain(sourceFile, node, messageChain, relatedInformation) {
            const span = getErrorSpanForNode(sourceFile, node);
            return createFileDiagnosticFromMessageChain(sourceFile, span.start, span.length, messageChain, relatedInformation);
        }
        function createDiagnosticForNodeArrayFromMessageChain(sourceFile, nodes, messageChain, relatedInformation) {
            const start = skipTrivia(sourceFile.text, nodes.pos);
            return createFileDiagnosticFromMessageChain(sourceFile, start, nodes.end - start, messageChain, relatedInformation);
        }
        function assertDiagnosticLocation(file, start, length2) {
            Debug.assertGreaterThanOrEqual(start, 0);
            Debug.assertGreaterThanOrEqual(length2, 0);
            if (file) {
                Debug.assertLessThanOrEqual(start, file.text.length);
                Debug.assertLessThanOrEqual(start + length2, file.text.length);
            }
        }
        function createFileDiagnosticFromMessageChain(file, start, length2, messageChain, relatedInformation) {
            assertDiagnosticLocation(file, start, length2);
            return {
                file,
                start,
                length: length2,
                code: messageChain.code,
                category: messageChain.category,
                messageText: messageChain.next ? messageChain : messageChain.messageText,
                relatedInformation
            };
        }
        function createDiagnosticForFileFromMessageChain(sourceFile, messageChain, relatedInformation) {
            return {
                file: sourceFile,
                start: 0,
                length: 0,
                code: messageChain.code,
                category: messageChain.category,
                messageText: messageChain.next ? messageChain : messageChain.messageText,
                relatedInformation
            };
        }
        function createDiagnosticMessageChainFromDiagnostic(diagnostic) {
            return typeof diagnostic.messageText === "string" ? {
                code: diagnostic.code,
                category: diagnostic.category,
                messageText: diagnostic.messageText,
                next: diagnostic.next
            } : diagnostic.messageText;
        }
        function createDiagnosticForRange(sourceFile, range, message) {
            return {
                file: sourceFile,
                start: range.pos,
                length: range.end - range.pos,
                code: message.code,
                category: message.category,
                messageText: message.message
            };
        }
        function getSpanOfTokenAtPosition(sourceFile, pos) {
            const scanner2 = createScanner(sourceFile.languageVersion, 
            /*skipTrivia*/
            true, sourceFile.languageVariant, sourceFile.text, 
            /*onError:*/
            void 0, pos);
            scanner2.scan();
            const start = scanner2.getTokenPos();
            return createTextSpanFromBounds(start, scanner2.getTextPos());
        }
        function scanTokenAtPosition(sourceFile, pos) {
            const scanner2 = createScanner(sourceFile.languageVersion, 
            /*skipTrivia*/
            true, sourceFile.languageVariant, sourceFile.text, 
            /*onError:*/
            void 0, pos);
            scanner2.scan();
            return scanner2.getToken();
        }
        function getErrorSpanForArrowFunction(sourceFile, node) {
            const pos = skipTrivia(sourceFile.text, node.pos);
            if (node.body && node.body.kind === 238 /* Block */) {
                const { line: startLine } = getLineAndCharacterOfPosition(sourceFile, node.body.pos);
                const { line: endLine } = getLineAndCharacterOfPosition(sourceFile, node.body.end);
                if (startLine < endLine) {
                    return createTextSpan(pos, getEndLinePosition(startLine, sourceFile) - pos + 1);
                }
            }
            return createTextSpanFromBounds(pos, node.end);
        }
        function getErrorSpanForNode(sourceFile, node) {
            let errorNode = node;
            switch (node.kind) {
                case 308 /* SourceFile */:
                    const pos2 = skipTrivia(sourceFile.text, 0, 
                    /*stopAfterLineBreak*/
                    false);
                    if (pos2 === sourceFile.text.length) {
                        return createTextSpan(0, 0);
                    }
                    return getSpanOfTokenAtPosition(sourceFile, pos2);
                case 257 /* VariableDeclaration */:
                case 205 /* BindingElement */:
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 261 /* InterfaceDeclaration */:
                case 264 /* ModuleDeclaration */:
                case 263 /* EnumDeclaration */:
                case 302 /* EnumMember */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 262 /* TypeAliasDeclaration */:
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 271 /* NamespaceImport */:
                    errorNode = node.name;
                    break;
                case 216 /* ArrowFunction */:
                    return getErrorSpanForArrowFunction(sourceFile, node);
                case 292 /* CaseClause */:
                case 293 /* DefaultClause */:
                    const start = skipTrivia(sourceFile.text, node.pos);
                    const end = node.statements.length > 0 ? node.statements[0].pos : node.end;
                    return createTextSpanFromBounds(start, end);
            }
            if (errorNode === void 0) {
                return getSpanOfTokenAtPosition(sourceFile, node.pos);
            }
            Debug.assert(!isJSDoc(errorNode));
            const isMissing = nodeIsMissing(errorNode);
            const pos = isMissing || isJsxText(node) ? errorNode.pos : skipTrivia(sourceFile.text, errorNode.pos);
            if (isMissing) {
                Debug.assert(pos === errorNode.pos, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809");
                Debug.assert(pos === errorNode.end, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809");
            }
            else {
                Debug.assert(pos >= errorNode.pos, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809");
                Debug.assert(pos <= errorNode.end, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809");
            }
            return createTextSpanFromBounds(pos, errorNode.end);
        }
        function isExternalOrCommonJsModule(file) {
            return (file.externalModuleIndicator || file.commonJsModuleIndicator) !== void 0;
        }
        function isJsonSourceFile(file) {
            return file.scriptKind === 6 /* JSON */;
        }
        function isEnumConst(node) {
            return !!(getCombinedModifierFlags(node) & 2048 /* Const */);
        }
        function isDeclarationReadonly(declaration) {
            return !!(getCombinedModifierFlags(declaration) & 64 /* Readonly */ && !isParameterPropertyDeclaration(declaration, declaration.parent));
        }
        function isVarConst(node) {
            return !!(getCombinedNodeFlags(node) & 2 /* Const */);
        }
        function isLet(node) {
            return !!(getCombinedNodeFlags(node) & 1 /* Let */);
        }
        function isSuperCall(n) {
            return n.kind === 210 /* CallExpression */ && n.expression.kind === 106 /* SuperKeyword */;
        }
        function isImportCall(n) {
            return n.kind === 210 /* CallExpression */ && n.expression.kind === 100 /* ImportKeyword */;
        }
        function isImportMeta(n) {
            return isMetaProperty(n) && n.keywordToken === 100 /* ImportKeyword */ && n.name.escapedText === "meta";
        }
        function isLiteralImportTypeNode(n) {
            return isImportTypeNode(n) && isLiteralTypeNode(n.argument) && isStringLiteral(n.argument.literal);
        }
        function isPrologueDirective(node) {
            return node.kind === 241 /* ExpressionStatement */ && node.expression.kind === 10 /* StringLiteral */;
        }
        function isCustomPrologue(node) {
            return !!(getEmitFlags(node) & 2097152 /* CustomPrologue */);
        }
        function isHoistedFunction(node) {
            return isCustomPrologue(node) && isFunctionDeclaration(node);
        }
        function isHoistedVariable(node) {
            return isIdentifier(node.name) && !node.initializer;
        }
        function isHoistedVariableStatement(node) {
            return isCustomPrologue(node) && isVariableStatement(node) && every(node.declarationList.declarations, isHoistedVariable);
        }
        function getLeadingCommentRangesOfNode(node, sourceFileOfNode) {
            return node.kind !== 11 /* JsxText */ ? getLeadingCommentRanges(sourceFileOfNode.text, node.pos) : void 0;
        }
        function getJSDocCommentRanges(node, text) {
            const commentRanges = node.kind === 166 /* Parameter */ || node.kind === 165 /* TypeParameter */ || node.kind === 215 /* FunctionExpression */ || node.kind === 216 /* ArrowFunction */ || node.kind === 214 /* ParenthesizedExpression */ || node.kind === 257 /* VariableDeclaration */ || node.kind === 278 /* ExportSpecifier */ ? concatenate(getTrailingCommentRanges(text, node.pos), getLeadingCommentRanges(text, node.pos)) : getLeadingCommentRanges(text, node.pos);
            return filter(commentRanges, (comment) => text.charCodeAt(comment.pos + 1) === 42 /* asterisk */ && text.charCodeAt(comment.pos + 2) === 42 /* asterisk */ && text.charCodeAt(comment.pos + 3) !== 47 /* slash */);
        }
        function isPartOfTypeNode(node) {
            if (179 /* FirstTypeNode */ <= node.kind && node.kind <= 202 /* LastTypeNode */) {
                return true;
            }
            switch (node.kind) {
                case 131 /* AnyKeyword */:
                case 157 /* UnknownKeyword */:
                case 148 /* NumberKeyword */:
                case 160 /* BigIntKeyword */:
                case 152 /* StringKeyword */:
                case 134 /* BooleanKeyword */:
                case 153 /* SymbolKeyword */:
                case 149 /* ObjectKeyword */:
                case 155 /* UndefinedKeyword */:
                case 144 /* NeverKeyword */:
                    return true;
                case 114 /* VoidKeyword */:
                    return node.parent.kind !== 219 /* VoidExpression */;
                case 230 /* ExpressionWithTypeArguments */:
                    return isHeritageClause(node.parent) && !isExpressionWithTypeArgumentsInClassExtendsClause(node);
                case 165 /* TypeParameter */:
                    return node.parent.kind === 197 /* MappedType */ || node.parent.kind === 192 /* InferType */;
                case 79 /* Identifier */:
                    if (node.parent.kind === 163 /* QualifiedName */ && node.parent.right === node) {
                        node = node.parent;
                    }
                    else if (node.parent.kind === 208 /* PropertyAccessExpression */ && node.parent.name === node) {
                        node = node.parent;
                    }
                    Debug.assert(node.kind === 79 /* Identifier */ || node.kind === 163 /* QualifiedName */ || node.kind === 208 /* PropertyAccessExpression */, "'node' was expected to be a qualified name, identifier or property access in 'isPartOfTypeNode'.");
                case 163 /* QualifiedName */:
                case 208 /* PropertyAccessExpression */:
                case 108 /* ThisKeyword */: {
                    const { parent: parent2 } = node;
                    if (parent2.kind === 183 /* TypeQuery */) {
                        return false;
                    }
                    if (parent2.kind === 202 /* ImportType */) {
                        return !parent2.isTypeOf;
                    }
                    if (179 /* FirstTypeNode */ <= parent2.kind && parent2.kind <= 202 /* LastTypeNode */) {
                        return true;
                    }
                    switch (parent2.kind) {
                        case 230 /* ExpressionWithTypeArguments */:
                            return isHeritageClause(parent2.parent) && !isExpressionWithTypeArgumentsInClassExtendsClause(parent2);
                        case 165 /* TypeParameter */:
                            return node === parent2.constraint;
                        case 348 /* JSDocTemplateTag */:
                            return node === parent2.constraint;
                        case 169 /* PropertyDeclaration */:
                        case 168 /* PropertySignature */:
                        case 166 /* Parameter */:
                        case 257 /* VariableDeclaration */:
                            return node === parent2.type;
                        case 259 /* FunctionDeclaration */:
                        case 215 /* FunctionExpression */:
                        case 216 /* ArrowFunction */:
                        case 173 /* Constructor */:
                        case 171 /* MethodDeclaration */:
                        case 170 /* MethodSignature */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            return node === parent2.type;
                        case 176 /* CallSignature */:
                        case 177 /* ConstructSignature */:
                        case 178 /* IndexSignature */:
                            return node === parent2.type;
                        case 213 /* TypeAssertionExpression */:
                            return node === parent2.type;
                        case 210 /* CallExpression */:
                        case 211 /* NewExpression */:
                            return contains(parent2.typeArguments, node);
                        case 212 /* TaggedTemplateExpression */:
                            return false;
                    }
                }
            }
            return false;
        }
        function isChildOfNodeWithKind(node, kind) {
            while (node) {
                if (node.kind === kind) {
                    return true;
                }
                node = node.parent;
            }
            return false;
        }
        function forEachReturnStatement(body, visitor) {
            return traverse(body);
            function traverse(node) {
                switch (node.kind) {
                    case 250 /* ReturnStatement */:
                        return visitor(node);
                    case 266 /* CaseBlock */:
                    case 238 /* Block */:
                    case 242 /* IfStatement */:
                    case 243 /* DoStatement */:
                    case 244 /* WhileStatement */:
                    case 245 /* ForStatement */:
                    case 246 /* ForInStatement */:
                    case 247 /* ForOfStatement */:
                    case 251 /* WithStatement */:
                    case 252 /* SwitchStatement */:
                    case 292 /* CaseClause */:
                    case 293 /* DefaultClause */:
                    case 253 /* LabeledStatement */:
                    case 255 /* TryStatement */:
                    case 295 /* CatchClause */:
                        return forEachChild(node, traverse);
                }
            }
        }
        function forEachYieldExpression(body, visitor) {
            return traverse(body);
            function traverse(node) {
                switch (node.kind) {
                    case 226 /* YieldExpression */:
                        visitor(node);
                        const operand = node.expression;
                        if (operand) {
                            traverse(operand);
                        }
                        return;
                    case 263 /* EnumDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                    case 264 /* ModuleDeclaration */:
                    case 262 /* TypeAliasDeclaration */:
                        return;
                    default:
                        if (isFunctionLike(node)) {
                            if (node.name && node.name.kind === 164 /* ComputedPropertyName */) {
                                traverse(node.name.expression);
                                return;
                            }
                        }
                        else if (!isPartOfTypeNode(node)) {
                            forEachChild(node, traverse);
                        }
                }
            }
        }
        function getRestParameterElementType(node) {
            if (node && node.kind === 185 /* ArrayType */) {
                return node.elementType;
            }
            else if (node && node.kind === 180 /* TypeReference */) {
                return singleOrUndefined(node.typeArguments);
            }
            else {
                return void 0;
            }
        }
        function getMembersOfDeclaration(node) {
            switch (node.kind) {
                case 261 /* InterfaceDeclaration */:
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 184 /* TypeLiteral */:
                    return node.members;
                case 207 /* ObjectLiteralExpression */:
                    return node.properties;
            }
        }
        function isVariableLike(node) {
            if (node) {
                switch (node.kind) {
                    case 205 /* BindingElement */:
                    case 302 /* EnumMember */:
                    case 166 /* Parameter */:
                    case 299 /* PropertyAssignment */:
                    case 169 /* PropertyDeclaration */:
                    case 168 /* PropertySignature */:
                    case 300 /* ShorthandPropertyAssignment */:
                    case 257 /* VariableDeclaration */:
                        return true;
                }
            }
            return false;
        }
        function isVariableLikeOrAccessor(node) {
            return isVariableLike(node) || isAccessor(node);
        }
        function isVariableDeclarationInVariableStatement(node) {
            return node.parent.kind === 258 /* VariableDeclarationList */ && node.parent.parent.kind === 240 /* VariableStatement */;
        }
        function isCommonJsExportedExpression(node) {
            if (!isInJSFile(node))
                return false;
            return isObjectLiteralExpression(node.parent) && isBinaryExpression(node.parent.parent) && getAssignmentDeclarationKind(node.parent.parent) === 2 /* ModuleExports */ || isCommonJsExportPropertyAssignment(node.parent);
        }
        function isCommonJsExportPropertyAssignment(node) {
            if (!isInJSFile(node))
                return false;
            return isBinaryExpression(node) && getAssignmentDeclarationKind(node) === 1 /* ExportsProperty */;
        }
        function isValidESSymbolDeclaration(node) {
            return (isVariableDeclaration(node) ? isVarConst(node) && isIdentifier(node.name) && isVariableDeclarationInVariableStatement(node) : isPropertyDeclaration(node) ? hasEffectiveReadonlyModifier(node) && hasStaticModifier(node) : isPropertySignature(node) && hasEffectiveReadonlyModifier(node)) || isCommonJsExportPropertyAssignment(node);
        }
        function introducesArgumentsExoticObject(node) {
            switch (node.kind) {
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 173 /* Constructor */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                    return true;
            }
            return false;
        }
        function unwrapInnermostStatementOfLabel(node, beforeUnwrapLabelCallback) {
            while (true) {
                if (beforeUnwrapLabelCallback) {
                    beforeUnwrapLabelCallback(node);
                }
                if (node.statement.kind !== 253 /* LabeledStatement */) {
                    return node.statement;
                }
                node = node.statement;
            }
        }
        function isFunctionBlock(node) {
            return node && node.kind === 238 /* Block */ && isFunctionLike(node.parent);
        }
        function isObjectLiteralMethod(node) {
            return node && node.kind === 171 /* MethodDeclaration */ && node.parent.kind === 207 /* ObjectLiteralExpression */;
        }
        function isObjectLiteralOrClassExpressionMethodOrAccessor(node) {
            return (node.kind === 171 /* MethodDeclaration */ || node.kind === 174 /* GetAccessor */ || node.kind === 175 /* SetAccessor */) && (node.parent.kind === 207 /* ObjectLiteralExpression */ || node.parent.kind === 228 /* ClassExpression */);
        }
        function isIdentifierTypePredicate(predicate) {
            return predicate && predicate.kind === 1 /* Identifier */;
        }
        function isThisTypePredicate(predicate) {
            return predicate && predicate.kind === 0 /* This */;
        }
        function getPropertyAssignment(objectLiteral, key, key2) {
            return objectLiteral.properties.filter((property) => {
                if (property.kind === 299 /* PropertyAssignment */) {
                    const propName = tryGetTextOfPropertyName(property.name);
                    return key === propName || !!key2 && key2 === propName;
                }
                return false;
            });
        }
        function getPropertyArrayElementValue(objectLiteral, propKey, elementValue) {
            return firstDefined(getPropertyAssignment(objectLiteral, propKey), (property) => isArrayLiteralExpression(property.initializer) ? find(property.initializer.elements, (element) => isStringLiteral(element) && element.text === elementValue) : void 0);
        }
        function getTsConfigObjectLiteralExpression(tsConfigSourceFile) {
            if (tsConfigSourceFile && tsConfigSourceFile.statements.length) {
                const expression = tsConfigSourceFile.statements[0].expression;
                return tryCast(expression, isObjectLiteralExpression);
            }
        }
        function getTsConfigPropArrayElementValue(tsConfigSourceFile, propKey, elementValue) {
            return firstDefined(getTsConfigPropArray(tsConfigSourceFile, propKey), (property) => isArrayLiteralExpression(property.initializer) ? find(property.initializer.elements, (element) => isStringLiteral(element) && element.text === elementValue) : void 0);
        }
        function getTsConfigPropArray(tsConfigSourceFile, propKey) {
            const jsonObjectLiteral = getTsConfigObjectLiteralExpression(tsConfigSourceFile);
            return jsonObjectLiteral ? getPropertyAssignment(jsonObjectLiteral, propKey) : emptyArray;
        }
        function getContainingFunction(node) {
            return findAncestor(node.parent, isFunctionLike);
        }
        function getContainingFunctionDeclaration(node) {
            return findAncestor(node.parent, isFunctionLikeDeclaration);
        }
        function getContainingClass(node) {
            return findAncestor(node.parent, isClassLike);
        }
        function getContainingClassStaticBlock(node) {
            return findAncestor(node.parent, (n) => {
                if (isClassLike(n) || isFunctionLike(n)) {
                    return "quit";
                }
                return isClassStaticBlockDeclaration(n);
            });
        }
        function getContainingFunctionOrClassStaticBlock(node) {
            return findAncestor(node.parent, isFunctionLikeOrClassStaticBlockDeclaration);
        }
        function getThisContainer(node, includeArrowFunctions, includeClassComputedPropertyName) {
            Debug.assert(node.kind !== 308 /* SourceFile */);
            while (true) {
                node = node.parent;
                if (!node) {
                    return Debug.fail();
                }
                switch (node.kind) {
                    case 164 /* ComputedPropertyName */:
                        if (includeClassComputedPropertyName && isClassLike(node.parent.parent)) {
                            return node;
                        }
                        node = node.parent.parent;
                        break;
                    case 167 /* Decorator */:
                        if (node.parent.kind === 166 /* Parameter */ && isClassElement(node.parent.parent)) {
                            node = node.parent.parent;
                        }
                        else if (isClassElement(node.parent)) {
                            node = node.parent;
                        }
                        break;
                    case 216 /* ArrowFunction */:
                        if (!includeArrowFunctions) {
                            continue;
                        }
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                    case 264 /* ModuleDeclaration */:
                    case 172 /* ClassStaticBlockDeclaration */:
                    case 169 /* PropertyDeclaration */:
                    case 168 /* PropertySignature */:
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                    case 173 /* Constructor */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 176 /* CallSignature */:
                    case 177 /* ConstructSignature */:
                    case 178 /* IndexSignature */:
                    case 263 /* EnumDeclaration */:
                    case 308 /* SourceFile */:
                        return node;
                }
            }
        }
        function isThisContainerOrFunctionBlock(node) {
            switch (node.kind) {
                case 216 /* ArrowFunction */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 169 /* PropertyDeclaration */:
                    return true;
                case 238 /* Block */:
                    switch (node.parent.kind) {
                        case 173 /* Constructor */:
                        case 171 /* MethodDeclaration */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            return true;
                        default:
                            return false;
                    }
                default:
                    return false;
            }
        }
        function isInTopLevelContext(node) {
            if (isIdentifier(node) && (isClassDeclaration(node.parent) || isFunctionDeclaration(node.parent)) && node.parent.name === node) {
                node = node.parent;
            }
            const container = getThisContainer(node, 
            /*includeArrowFunctions*/
            true, 
            /*includeClassComputedPropertyName*/
            false);
            return isSourceFile(container);
        }
        function getNewTargetContainer(node) {
            const container = getThisContainer(node, 
            /*includeArrowFunctions*/
            false, 
            /*includeClassComputedPropertyName*/
            false);
            if (container) {
                switch (container.kind) {
                    case 173 /* Constructor */:
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                        return container;
                }
            }
            return void 0;
        }
        function getSuperContainer(node, stopOnFunctions) {
            while (true) {
                node = node.parent;
                if (!node) {
                    return void 0;
                }
                switch (node.kind) {
                    case 164 /* ComputedPropertyName */:
                        node = node.parent;
                        break;
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                        if (!stopOnFunctions) {
                            continue;
                        }
                    case 169 /* PropertyDeclaration */:
                    case 168 /* PropertySignature */:
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                    case 173 /* Constructor */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 172 /* ClassStaticBlockDeclaration */:
                        return node;
                    case 167 /* Decorator */:
                        if (node.parent.kind === 166 /* Parameter */ && isClassElement(node.parent.parent)) {
                            node = node.parent.parent;
                        }
                        else if (isClassElement(node.parent)) {
                            node = node.parent;
                        }
                        break;
                }
            }
        }
        function getImmediatelyInvokedFunctionExpression(func) {
            if (func.kind === 215 /* FunctionExpression */ || func.kind === 216 /* ArrowFunction */) {
                let prev = func;
                let parent2 = func.parent;
                while (parent2.kind === 214 /* ParenthesizedExpression */) {
                    prev = parent2;
                    parent2 = parent2.parent;
                }
                if (parent2.kind === 210 /* CallExpression */ && parent2.expression === prev) {
                    return parent2;
                }
            }
        }
        function isSuperOrSuperProperty(node) {
            return node.kind === 106 /* SuperKeyword */ || isSuperProperty(node);
        }
        function isSuperProperty(node) {
            const kind = node.kind;
            return (kind === 208 /* PropertyAccessExpression */ || kind === 209 /* ElementAccessExpression */) && node.expression.kind === 106 /* SuperKeyword */;
        }
        function isThisProperty(node) {
            const kind = node.kind;
            return (kind === 208 /* PropertyAccessExpression */ || kind === 209 /* ElementAccessExpression */) && node.expression.kind === 108 /* ThisKeyword */;
        }
        function isThisInitializedDeclaration(node) {
            var _a2;
            return !!node && isVariableDeclaration(node) && ((_a2 = node.initializer) == null ? void 0 : _a2.kind) === 108 /* ThisKeyword */;
        }
        function isThisInitializedObjectBindingExpression(node) {
            return !!node && (isShorthandPropertyAssignment(node) || isPropertyAssignment(node)) && isBinaryExpression(node.parent.parent) && node.parent.parent.operatorToken.kind === 63 /* EqualsToken */ && node.parent.parent.right.kind === 108 /* ThisKeyword */;
        }
        function getEntityNameFromTypeNode(node) {
            switch (node.kind) {
                case 180 /* TypeReference */:
                    return node.typeName;
                case 230 /* ExpressionWithTypeArguments */:
                    return isEntityNameExpression(node.expression) ? node.expression : void 0;
                case 79 /* Identifier */:
                case 163 /* QualifiedName */:
                    return node;
            }
            return void 0;
        }
        function getInvokedExpression(node) {
            switch (node.kind) {
                case 212 /* TaggedTemplateExpression */:
                    return node.tag;
                case 283 /* JsxOpeningElement */:
                case 282 /* JsxSelfClosingElement */:
                    return node.tagName;
                default:
                    return node.expression;
            }
        }
        function nodeCanBeDecorated(useLegacyDecorators, node, parent2, grandparent) {
            if (useLegacyDecorators && isNamedDeclaration(node) && isPrivateIdentifier(node.name)) {
                return false;
            }
            switch (node.kind) {
                case 260 /* ClassDeclaration */:
                    return true;
                case 228 /* ClassExpression */:
                    return !useLegacyDecorators;
                case 169 /* PropertyDeclaration */:
                    return parent2 !== void 0 && (useLegacyDecorators ? isClassDeclaration(parent2) : isClassLike(parent2) && !hasAbstractModifier(node) && !hasAmbientModifier(node));
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 171 /* MethodDeclaration */:
                    return node.body !== void 0 && parent2 !== void 0 && (useLegacyDecorators ? isClassDeclaration(parent2) : isClassLike(parent2));
                case 166 /* Parameter */:
                    if (!useLegacyDecorators)
                        return false;
                    return parent2 !== void 0 && parent2.body !== void 0 && (parent2.kind === 173 /* Constructor */ || parent2.kind === 171 /* MethodDeclaration */ || parent2.kind === 175 /* SetAccessor */) && getThisParameter(parent2) !== node && grandparent !== void 0 && grandparent.kind === 260 /* ClassDeclaration */;
            }
            return false;
        }
        function nodeIsDecorated(useLegacyDecorators, node, parent2, grandparent) {
            return hasDecorators(node) && nodeCanBeDecorated(useLegacyDecorators, node, parent2, grandparent);
        }
        function nodeOrChildIsDecorated(useLegacyDecorators, node, parent2, grandparent) {
            return nodeIsDecorated(useLegacyDecorators, node, parent2, grandparent) || childIsDecorated(useLegacyDecorators, node, parent2);
        }
        function childIsDecorated(useLegacyDecorators, node, parent2) {
            switch (node.kind) {
                case 260 /* ClassDeclaration */:
                    return some(node.members, (m) => nodeOrChildIsDecorated(useLegacyDecorators, m, node, parent2));
                case 228 /* ClassExpression */:
                    return !useLegacyDecorators && some(node.members, (m) => nodeOrChildIsDecorated(useLegacyDecorators, m, node, parent2));
                case 171 /* MethodDeclaration */:
                case 175 /* SetAccessor */:
                case 173 /* Constructor */:
                    return some(node.parameters, (p) => nodeIsDecorated(useLegacyDecorators, p, node, parent2));
                default:
                    return false;
            }
        }
        function classOrConstructorParameterIsDecorated(useLegacyDecorators, node) {
            if (nodeIsDecorated(useLegacyDecorators, node))
                return true;
            const constructor = getFirstConstructorWithBody(node);
            return !!constructor && childIsDecorated(useLegacyDecorators, constructor, node);
        }
        function classElementOrClassElementParameterIsDecorated(useLegacyDecorators, node, parent2) {
            let parameters;
            if (isAccessor(node)) {
                const { firstAccessor, secondAccessor, setAccessor } = getAllAccessorDeclarations(parent2.members, node);
                const firstAccessorWithDecorators = hasDecorators(firstAccessor) ? firstAccessor : secondAccessor && hasDecorators(secondAccessor) ? secondAccessor : void 0;
                if (!firstAccessorWithDecorators || node !== firstAccessorWithDecorators) {
                    return false;
                }
                parameters = setAccessor == null ? void 0 : setAccessor.parameters;
            }
            else if (isMethodDeclaration(node)) {
                parameters = node.parameters;
            }
            if (nodeIsDecorated(useLegacyDecorators, node, parent2)) {
                return true;
            }
            if (parameters) {
                for (const parameter of parameters) {
                    if (parameterIsThisKeyword(parameter))
                        continue;
                    if (nodeIsDecorated(useLegacyDecorators, parameter, node, parent2))
                        return true;
                }
            }
            return false;
        }
        function isEmptyStringLiteral(node) {
            if (node.textSourceNode) {
                switch (node.textSourceNode.kind) {
                    case 10 /* StringLiteral */:
                        return isEmptyStringLiteral(node.textSourceNode);
                    case 14 /* NoSubstitutionTemplateLiteral */:
                        return node.text === "";
                }
                return false;
            }
            return node.text === "";
        }
        function isJSXTagName(node) {
            const { parent: parent2 } = node;
            if (parent2.kind === 283 /* JsxOpeningElement */ || parent2.kind === 282 /* JsxSelfClosingElement */ || parent2.kind === 284 /* JsxClosingElement */) {
                return parent2.tagName === node;
            }
            return false;
        }
        function isExpressionNode(node) {
            switch (node.kind) {
                case 106 /* SuperKeyword */:
                case 104 /* NullKeyword */:
                case 110 /* TrueKeyword */:
                case 95 /* FalseKeyword */:
                case 13 /* RegularExpressionLiteral */:
                case 206 /* ArrayLiteralExpression */:
                case 207 /* ObjectLiteralExpression */:
                case 208 /* PropertyAccessExpression */:
                case 209 /* ElementAccessExpression */:
                case 210 /* CallExpression */:
                case 211 /* NewExpression */:
                case 212 /* TaggedTemplateExpression */:
                case 231 /* AsExpression */:
                case 213 /* TypeAssertionExpression */:
                case 235 /* SatisfiesExpression */:
                case 232 /* NonNullExpression */:
                case 214 /* ParenthesizedExpression */:
                case 215 /* FunctionExpression */:
                case 228 /* ClassExpression */:
                case 216 /* ArrowFunction */:
                case 219 /* VoidExpression */:
                case 217 /* DeleteExpression */:
                case 218 /* TypeOfExpression */:
                case 221 /* PrefixUnaryExpression */:
                case 222 /* PostfixUnaryExpression */:
                case 223 /* BinaryExpression */:
                case 224 /* ConditionalExpression */:
                case 227 /* SpreadElement */:
                case 225 /* TemplateExpression */:
                case 229 /* OmittedExpression */:
                case 281 /* JsxElement */:
                case 282 /* JsxSelfClosingElement */:
                case 285 /* JsxFragment */:
                case 226 /* YieldExpression */:
                case 220 /* AwaitExpression */:
                case 233 /* MetaProperty */:
                    return true;
                case 230 /* ExpressionWithTypeArguments */:
                    return !isHeritageClause(node.parent) && !isJSDocAugmentsTag(node.parent);
                case 163 /* QualifiedName */:
                    while (node.parent.kind === 163 /* QualifiedName */) {
                        node = node.parent;
                    }
                    return node.parent.kind === 183 /* TypeQuery */ || isJSDocLinkLike(node.parent) || isJSDocNameReference(node.parent) || isJSDocMemberName(node.parent) || isJSXTagName(node);
                case 314 /* JSDocMemberName */:
                    while (isJSDocMemberName(node.parent)) {
                        node = node.parent;
                    }
                    return node.parent.kind === 183 /* TypeQuery */ || isJSDocLinkLike(node.parent) || isJSDocNameReference(node.parent) || isJSDocMemberName(node.parent) || isJSXTagName(node);
                case 80 /* PrivateIdentifier */:
                    return isBinaryExpression(node.parent) && node.parent.left === node && node.parent.operatorToken.kind === 101 /* InKeyword */;
                case 79 /* Identifier */:
                    if (node.parent.kind === 183 /* TypeQuery */ || isJSDocLinkLike(node.parent) || isJSDocNameReference(node.parent) || isJSDocMemberName(node.parent) || isJSXTagName(node)) {
                        return true;
                    }
                case 8 /* NumericLiteral */:
                case 9 /* BigIntLiteral */:
                case 10 /* StringLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 108 /* ThisKeyword */:
                    return isInExpressionContext(node);
                default:
                    return false;
            }
        }
        function isInExpressionContext(node) {
            const { parent: parent2 } = node;
            switch (parent2.kind) {
                case 257 /* VariableDeclaration */:
                case 166 /* Parameter */:
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 302 /* EnumMember */:
                case 299 /* PropertyAssignment */:
                case 205 /* BindingElement */:
                    return parent2.initializer === node;
                case 241 /* ExpressionStatement */:
                case 242 /* IfStatement */:
                case 243 /* DoStatement */:
                case 244 /* WhileStatement */:
                case 250 /* ReturnStatement */:
                case 251 /* WithStatement */:
                case 252 /* SwitchStatement */:
                case 292 /* CaseClause */:
                case 254 /* ThrowStatement */:
                    return parent2.expression === node;
                case 245 /* ForStatement */:
                    const forStatement = parent2;
                    return forStatement.initializer === node && forStatement.initializer.kind !== 258 /* VariableDeclarationList */ || forStatement.condition === node || forStatement.incrementor === node;
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                    const forInStatement = parent2;
                    return forInStatement.initializer === node && forInStatement.initializer.kind !== 258 /* VariableDeclarationList */ || forInStatement.expression === node;
                case 213 /* TypeAssertionExpression */:
                case 231 /* AsExpression */:
                    return node === parent2.expression;
                case 236 /* TemplateSpan */:
                    return node === parent2.expression;
                case 164 /* ComputedPropertyName */:
                    return node === parent2.expression;
                case 167 /* Decorator */:
                case 291 /* JsxExpression */:
                case 290 /* JsxSpreadAttribute */:
                case 301 /* SpreadAssignment */:
                    return true;
                case 230 /* ExpressionWithTypeArguments */:
                    return parent2.expression === node && !isPartOfTypeNode(parent2);
                case 300 /* ShorthandPropertyAssignment */:
                    return parent2.objectAssignmentInitializer === node;
                case 235 /* SatisfiesExpression */:
                    return node === parent2.expression;
                default:
                    return isExpressionNode(parent2);
            }
        }
        function isPartOfTypeQuery(node) {
            while (node.kind === 163 /* QualifiedName */ || node.kind === 79 /* Identifier */) {
                node = node.parent;
            }
            return node.kind === 183 /* TypeQuery */;
        }
        function isNamespaceReexportDeclaration(node) {
            return isNamespaceExport(node) && !!node.parent.moduleSpecifier;
        }
        function isExternalModuleImportEqualsDeclaration(node) {
            return node.kind === 268 /* ImportEqualsDeclaration */ && node.moduleReference.kind === 280 /* ExternalModuleReference */;
        }
        function getExternalModuleImportEqualsDeclarationExpression(node) {
            Debug.assert(isExternalModuleImportEqualsDeclaration(node));
            return node.moduleReference.expression;
        }
        function getExternalModuleRequireArgument(node) {
            return isVariableDeclarationInitializedToBareOrAccessedRequire(node) && getLeftmostAccessExpression(node.initializer).arguments[0];
        }
        function isInternalModuleImportEqualsDeclaration(node) {
            return node.kind === 268 /* ImportEqualsDeclaration */ && node.moduleReference.kind !== 280 /* ExternalModuleReference */;
        }
        function isSourceFileJS(file) {
            return isInJSFile(file);
        }
        function isSourceFileNotJS(file) {
            return !isInJSFile(file);
        }
        function isInJSFile(node) {
            return !!node && !!(node.flags & 262144 /* JavaScriptFile */);
        }
        function isInJsonFile(node) {
            return !!node && !!(node.flags & 67108864 /* JsonFile */);
        }
        function isSourceFileNotJson(file) {
            return !isJsonSourceFile(file);
        }
        function isInJSDoc(node) {
            return !!node && !!(node.flags & 8388608 /* JSDoc */);
        }
        function isJSDocIndexSignature(node) {
            return isTypeReferenceNode(node) && isIdentifier(node.typeName) && node.typeName.escapedText === "Object" && node.typeArguments && node.typeArguments.length === 2 && (node.typeArguments[0].kind === 152 /* StringKeyword */ || node.typeArguments[0].kind === 148 /* NumberKeyword */);
        }
        function isRequireCall(callExpression, requireStringLiteralLikeArgument) {
            if (callExpression.kind !== 210 /* CallExpression */) {
                return false;
            }
            const { expression, arguments: args } = callExpression;
            if (expression.kind !== 79 /* Identifier */ || expression.escapedText !== "require") {
                return false;
            }
            if (args.length !== 1) {
                return false;
            }
            const arg = args[0];
            return !requireStringLiteralLikeArgument || isStringLiteralLike(arg);
        }
        function isVariableDeclarationInitializedToRequire(node) {
            return isVariableDeclarationInitializedWithRequireHelper(node, 
            /*allowAccessedRequire*/
            false);
        }
        function isVariableDeclarationInitializedToBareOrAccessedRequire(node) {
            return isVariableDeclarationInitializedWithRequireHelper(node, 
            /*allowAccessedRequire*/
            true);
        }
        function isBindingElementOfBareOrAccessedRequire(node) {
            return isBindingElement(node) && isVariableDeclarationInitializedToBareOrAccessedRequire(node.parent.parent);
        }
        function isVariableDeclarationInitializedWithRequireHelper(node, allowAccessedRequire) {
            return isVariableDeclaration(node) && !!node.initializer && isRequireCall(allowAccessedRequire ? getLeftmostAccessExpression(node.initializer) : node.initializer, 
            /*requireStringLiteralLikeArgument*/
            true);
        }
        function isRequireVariableStatement(node) {
            return isVariableStatement(node) && node.declarationList.declarations.length > 0 && every(node.declarationList.declarations, (decl) => isVariableDeclarationInitializedToRequire(decl));
        }
        function isSingleOrDoubleQuote(charCode) {
            return charCode === 39 /* singleQuote */ || charCode === 34 /* doubleQuote */;
        }
        function isStringDoubleQuoted(str, sourceFile) {
            return getSourceTextOfNodeFromSourceFile(sourceFile, str).charCodeAt(0) === 34 /* doubleQuote */;
        }
        function isAssignmentDeclaration(decl) {
            return isBinaryExpression(decl) || isAccessExpression(decl) || isIdentifier(decl) || isCallExpression(decl);
        }
        function getEffectiveInitializer(node) {
            if (isInJSFile(node) && node.initializer && isBinaryExpression(node.initializer) && (node.initializer.operatorToken.kind === 56 /* BarBarToken */ || node.initializer.operatorToken.kind === 60 /* QuestionQuestionToken */) && node.name && isEntityNameExpression(node.name) && isSameEntityName(node.name, node.initializer.left)) {
                return node.initializer.right;
            }
            return node.initializer;
        }
        function getDeclaredExpandoInitializer(node) {
            const init = getEffectiveInitializer(node);
            return init && getExpandoInitializer(init, isPrototypeAccess(node.name));
        }
        function hasExpandoValueProperty(node, isPrototypeAssignment) {
            return forEach(node.properties, (p) => isPropertyAssignment(p) && isIdentifier(p.name) && p.name.escapedText === "value" && p.initializer && getExpandoInitializer(p.initializer, isPrototypeAssignment));
        }
        function getAssignedExpandoInitializer(node) {
            if (node && node.parent && isBinaryExpression(node.parent) && node.parent.operatorToken.kind === 63 /* EqualsToken */) {
                const isPrototypeAssignment = isPrototypeAccess(node.parent.left);
                return getExpandoInitializer(node.parent.right, isPrototypeAssignment) || getDefaultedExpandoInitializer(node.parent.left, node.parent.right, isPrototypeAssignment);
            }
            if (node && isCallExpression(node) && isBindableObjectDefinePropertyCall(node)) {
                const result = hasExpandoValueProperty(node.arguments[2], node.arguments[1].text === "prototype");
                if (result) {
                    return result;
                }
            }
        }
        function getExpandoInitializer(initializer, isPrototypeAssignment) {
            if (isCallExpression(initializer)) {
                const e = skipParentheses(initializer.expression);
                return e.kind === 215 /* FunctionExpression */ || e.kind === 216 /* ArrowFunction */ ? initializer : void 0;
            }
            if (initializer.kind === 215 /* FunctionExpression */ || initializer.kind === 228 /* ClassExpression */ || initializer.kind === 216 /* ArrowFunction */) {
                return initializer;
            }
            if (isObjectLiteralExpression(initializer) && (initializer.properties.length === 0 || isPrototypeAssignment)) {
                return initializer;
            }
        }
        function getDefaultedExpandoInitializer(name, initializer, isPrototypeAssignment) {
            const e = isBinaryExpression(initializer) && (initializer.operatorToken.kind === 56 /* BarBarToken */ || initializer.operatorToken.kind === 60 /* QuestionQuestionToken */) && getExpandoInitializer(initializer.right, isPrototypeAssignment);
            if (e && isSameEntityName(name, initializer.left)) {
                return e;
            }
        }
        function isDefaultedExpandoInitializer(node) {
            const name = isVariableDeclaration(node.parent) ? node.parent.name : isBinaryExpression(node.parent) && node.parent.operatorToken.kind === 63 /* EqualsToken */ ? node.parent.left : void 0;
            return name && getExpandoInitializer(node.right, isPrototypeAccess(name)) && isEntityNameExpression(name) && isSameEntityName(name, node.left);
        }
        function getNameOfExpando(node) {
            if (isBinaryExpression(node.parent)) {
                const parent2 = (node.parent.operatorToken.kind === 56 /* BarBarToken */ || node.parent.operatorToken.kind === 60 /* QuestionQuestionToken */) && isBinaryExpression(node.parent.parent) ? node.parent.parent : node.parent;
                if (parent2.operatorToken.kind === 63 /* EqualsToken */ && isIdentifier(parent2.left)) {
                    return parent2.left;
                }
            }
            else if (isVariableDeclaration(node.parent)) {
                return node.parent.name;
            }
        }
        function isSameEntityName(name, initializer) {
            if (isPropertyNameLiteral(name) && isPropertyNameLiteral(initializer)) {
                return getTextOfIdentifierOrLiteral(name) === getTextOfIdentifierOrLiteral(initializer);
            }
            if (isMemberName(name) && isLiteralLikeAccess(initializer) && (initializer.expression.kind === 108 /* ThisKeyword */ || isIdentifier(initializer.expression) && (initializer.expression.escapedText === "window" || initializer.expression.escapedText === "self" || initializer.expression.escapedText === "global"))) {
                return isSameEntityName(name, getNameOrArgument(initializer));
            }
            if (isLiteralLikeAccess(name) && isLiteralLikeAccess(initializer)) {
                return getElementOrPropertyAccessName(name) === getElementOrPropertyAccessName(initializer) && isSameEntityName(name.expression, initializer.expression);
            }
            return false;
        }
        function getRightMostAssignedExpression(node) {
            while (isAssignmentExpression(node, 
            /*excludeCompoundAssignments*/
            true)) {
                node = node.right;
            }
            return node;
        }
        function isExportsIdentifier(node) {
            return isIdentifier(node) && node.escapedText === "exports";
        }
        function isModuleIdentifier(node) {
            return isIdentifier(node) && node.escapedText === "module";
        }
        function isModuleExportsAccessExpression(node) {
            return (isPropertyAccessExpression(node) || isLiteralLikeElementAccess(node)) && isModuleIdentifier(node.expression) && getElementOrPropertyAccessName(node) === "exports";
        }
        function getAssignmentDeclarationKind(expr) {
            const special = getAssignmentDeclarationKindWorker(expr);
            return special === 5 /* Property */ || isInJSFile(expr) ? special : 0 /* None */;
        }
        function isBindableObjectDefinePropertyCall(expr) {
            return length(expr.arguments) === 3 && isPropertyAccessExpression(expr.expression) && isIdentifier(expr.expression.expression) && idText(expr.expression.expression) === "Object" && idText(expr.expression.name) === "defineProperty" && isStringOrNumericLiteralLike(expr.arguments[1]) && isBindableStaticNameExpression(expr.arguments[0], 
            /*excludeThisKeyword*/
            true);
        }
        function isLiteralLikeAccess(node) {
            return isPropertyAccessExpression(node) || isLiteralLikeElementAccess(node);
        }
        function isLiteralLikeElementAccess(node) {
            return isElementAccessExpression(node) && isStringOrNumericLiteralLike(node.argumentExpression);
        }
        function isBindableStaticAccessExpression(node, excludeThisKeyword) {
            return isPropertyAccessExpression(node) && (!excludeThisKeyword && node.expression.kind === 108 /* ThisKeyword */ || isIdentifier(node.name) && isBindableStaticNameExpression(node.expression, 
            /*excludeThisKeyword*/
            true)) || isBindableStaticElementAccessExpression(node, excludeThisKeyword);
        }
        function isBindableStaticElementAccessExpression(node, excludeThisKeyword) {
            return isLiteralLikeElementAccess(node) && (!excludeThisKeyword && node.expression.kind === 108 /* ThisKeyword */ || isEntityNameExpression(node.expression) || isBindableStaticAccessExpression(node.expression, 
            /*excludeThisKeyword*/
            true));
        }
        function isBindableStaticNameExpression(node, excludeThisKeyword) {
            return isEntityNameExpression(node) || isBindableStaticAccessExpression(node, excludeThisKeyword);
        }
        function getNameOrArgument(expr) {
            if (isPropertyAccessExpression(expr)) {
                return expr.name;
            }
            return expr.argumentExpression;
        }
        function getAssignmentDeclarationKindWorker(expr) {
            if (isCallExpression(expr)) {
                if (!isBindableObjectDefinePropertyCall(expr)) {
                    return 0 /* None */;
                }
                const entityName = expr.arguments[0];
                if (isExportsIdentifier(entityName) || isModuleExportsAccessExpression(entityName)) {
                    return 8 /* ObjectDefinePropertyExports */;
                }
                if (isBindableStaticAccessExpression(entityName) && getElementOrPropertyAccessName(entityName) === "prototype") {
                    return 9 /* ObjectDefinePrototypeProperty */;
                }
                return 7 /* ObjectDefinePropertyValue */;
            }
            if (expr.operatorToken.kind !== 63 /* EqualsToken */ || !isAccessExpression(expr.left) || isVoidZero(getRightMostAssignedExpression(expr))) {
                return 0 /* None */;
            }
            if (isBindableStaticNameExpression(expr.left.expression, 
            /*excludeThisKeyword*/
            true) && getElementOrPropertyAccessName(expr.left) === "prototype" && isObjectLiteralExpression(getInitializerOfBinaryExpression(expr))) {
                return 6 /* Prototype */;
            }
            return getAssignmentDeclarationPropertyAccessKind(expr.left);
        }
        function isVoidZero(node) {
            return isVoidExpression(node) && isNumericLiteral(node.expression) && node.expression.text === "0";
        }
        function getElementOrPropertyAccessArgumentExpressionOrName(node) {
            if (isPropertyAccessExpression(node)) {
                return node.name;
            }
            const arg = skipParentheses(node.argumentExpression);
            if (isNumericLiteral(arg) || isStringLiteralLike(arg)) {
                return arg;
            }
            return node;
        }
        function getElementOrPropertyAccessName(node) {
            const name = getElementOrPropertyAccessArgumentExpressionOrName(node);
            if (name) {
                if (isIdentifier(name)) {
                    return name.escapedText;
                }
                if (isStringLiteralLike(name) || isNumericLiteral(name)) {
                    return escapeLeadingUnderscores(name.text);
                }
            }
            return void 0;
        }
        function getAssignmentDeclarationPropertyAccessKind(lhs) {
            if (lhs.expression.kind === 108 /* ThisKeyword */) {
                return 4 /* ThisProperty */;
            }
            else if (isModuleExportsAccessExpression(lhs)) {
                return 2 /* ModuleExports */;
            }
            else if (isBindableStaticNameExpression(lhs.expression, 
            /*excludeThisKeyword*/
            true)) {
                if (isPrototypeAccess(lhs.expression)) {
                    return 3 /* PrototypeProperty */;
                }
                let nextToLast = lhs;
                while (!isIdentifier(nextToLast.expression)) {
                    nextToLast = nextToLast.expression;
                }
                const id = nextToLast.expression;
                if ((id.escapedText === "exports" || id.escapedText === "module" && getElementOrPropertyAccessName(nextToLast) === "exports") && // ExportsProperty does not support binding with computed names
                    isBindableStaticAccessExpression(lhs)) {
                    return 1 /* ExportsProperty */;
                }
                if (isBindableStaticNameExpression(lhs, 
                /*excludeThisKeyword*/
                true) || isElementAccessExpression(lhs) && isDynamicName(lhs)) {
                    return 5 /* Property */;
                }
            }
            return 0 /* None */;
        }
        function getInitializerOfBinaryExpression(expr) {
            while (isBinaryExpression(expr.right)) {
                expr = expr.right;
            }
            return expr.right;
        }
        function isPrototypePropertyAssignment(node) {
            return isBinaryExpression(node) && getAssignmentDeclarationKind(node) === 3 /* PrototypeProperty */;
        }
        function isSpecialPropertyDeclaration(expr) {
            return isInJSFile(expr) && expr.parent && expr.parent.kind === 241 /* ExpressionStatement */ && (!isElementAccessExpression(expr) || isLiteralLikeElementAccess(expr)) && !!getJSDocTypeTag(expr.parent);
        }
        function setValueDeclaration(symbol, node) {
            const { valueDeclaration } = symbol;
            if (!valueDeclaration || !(node.flags & 16777216 /* Ambient */ && !isInJSFile(node) && !(valueDeclaration.flags & 16777216 /* Ambient */)) && (isAssignmentDeclaration(valueDeclaration) && !isAssignmentDeclaration(node)) || valueDeclaration.kind !== node.kind && isEffectiveModuleDeclaration(valueDeclaration)) {
                symbol.valueDeclaration = node;
            }
        }
        function isFunctionSymbol(symbol) {
            if (!symbol || !symbol.valueDeclaration) {
                return false;
            }
            const decl = symbol.valueDeclaration;
            return decl.kind === 259 /* FunctionDeclaration */ || isVariableDeclaration(decl) && decl.initializer && isFunctionLike(decl.initializer);
        }
        function tryGetModuleSpecifierFromDeclaration(node) {
            var _a2, _b;
            switch (node.kind) {
                case 257 /* VariableDeclaration */:
                case 205 /* BindingElement */:
                    return (_a2 = findAncestor(node.initializer, (node2) => isRequireCall(node2, 
                    /*requireStringLiteralLikeArgument*/
                    true))) == null ? void 0 : _a2.arguments[0];
                case 269 /* ImportDeclaration */:
                    return tryCast(node.moduleSpecifier, isStringLiteralLike);
                case 268 /* ImportEqualsDeclaration */:
                    return tryCast((_b = tryCast(node.moduleReference, isExternalModuleReference)) == null ? void 0 : _b.expression, isStringLiteralLike);
                case 270 /* ImportClause */:
                case 277 /* NamespaceExport */:
                    return tryCast(node.parent.moduleSpecifier, isStringLiteralLike);
                case 271 /* NamespaceImport */:
                case 278 /* ExportSpecifier */:
                    return tryCast(node.parent.parent.moduleSpecifier, isStringLiteralLike);
                case 273 /* ImportSpecifier */:
                    return tryCast(node.parent.parent.parent.moduleSpecifier, isStringLiteralLike);
                default:
                    Debug.assertNever(node);
            }
        }
        function importFromModuleSpecifier(node) {
            return tryGetImportFromModuleSpecifier(node) || Debug.failBadSyntaxKind(node.parent);
        }
        function tryGetImportFromModuleSpecifier(node) {
            switch (node.parent.kind) {
                case 269 /* ImportDeclaration */:
                case 275 /* ExportDeclaration */:
                    return node.parent;
                case 280 /* ExternalModuleReference */:
                    return node.parent.parent;
                case 210 /* CallExpression */:
                    return isImportCall(node.parent) || isRequireCall(node.parent, 
                    /*checkArg*/
                    false) ? node.parent : void 0;
                case 198 /* LiteralType */:
                    Debug.assert(isStringLiteral(node));
                    return tryCast(node.parent.parent, isImportTypeNode);
                default:
                    return void 0;
            }
        }
        function getExternalModuleName(node) {
            switch (node.kind) {
                case 269 /* ImportDeclaration */:
                case 275 /* ExportDeclaration */:
                    return node.moduleSpecifier;
                case 268 /* ImportEqualsDeclaration */:
                    return node.moduleReference.kind === 280 /* ExternalModuleReference */ ? node.moduleReference.expression : void 0;
                case 202 /* ImportType */:
                    return isLiteralImportTypeNode(node) ? node.argument.literal : void 0;
                case 210 /* CallExpression */:
                    return node.arguments[0];
                case 264 /* ModuleDeclaration */:
                    return node.name.kind === 10 /* StringLiteral */ ? node.name : void 0;
                default:
                    return Debug.assertNever(node);
            }
        }
        function getNamespaceDeclarationNode(node) {
            switch (node.kind) {
                case 269 /* ImportDeclaration */:
                    return node.importClause && tryCast(node.importClause.namedBindings, isNamespaceImport);
                case 268 /* ImportEqualsDeclaration */:
                    return node;
                case 275 /* ExportDeclaration */:
                    return node.exportClause && tryCast(node.exportClause, isNamespaceExport);
                default:
                    return Debug.assertNever(node);
            }
        }
        function isDefaultImport(node) {
            return node.kind === 269 /* ImportDeclaration */ && !!node.importClause && !!node.importClause.name;
        }
        function forEachImportClauseDeclaration(node, action) {
            if (node.name) {
                const result = action(node);
                if (result)
                    return result;
            }
            if (node.namedBindings) {
                const result = isNamespaceImport(node.namedBindings) ? action(node.namedBindings) : forEach(node.namedBindings.elements, action);
                if (result)
                    return result;
            }
        }
        function hasQuestionToken(node) {
            if (node) {
                switch (node.kind) {
                    case 166 /* Parameter */:
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                    case 300 /* ShorthandPropertyAssignment */:
                    case 299 /* PropertyAssignment */:
                    case 169 /* PropertyDeclaration */:
                    case 168 /* PropertySignature */:
                        return node.questionToken !== void 0;
                }
            }
            return false;
        }
        function isJSDocConstructSignature(node) {
            const param = isJSDocFunctionType(node) ? firstOrUndefined(node.parameters) : void 0;
            const name = tryCast(param && param.name, isIdentifier);
            return !!name && name.escapedText === "new";
        }
        function isJSDocTypeAlias(node) {
            return node.kind === 349 /* JSDocTypedefTag */ || node.kind === 341 /* JSDocCallbackTag */ || node.kind === 343 /* JSDocEnumTag */;
        }
        function isTypeAlias(node) {
            return isJSDocTypeAlias(node) || isTypeAliasDeclaration(node);
        }
        function getSourceOfAssignment(node) {
            return isExpressionStatement(node) && isBinaryExpression(node.expression) && node.expression.operatorToken.kind === 63 /* EqualsToken */ ? getRightMostAssignedExpression(node.expression) : void 0;
        }
        function getSourceOfDefaultedAssignment(node) {
            return isExpressionStatement(node) && isBinaryExpression(node.expression) && getAssignmentDeclarationKind(node.expression) !== 0 /* None */ && isBinaryExpression(node.expression.right) && (node.expression.right.operatorToken.kind === 56 /* BarBarToken */ || node.expression.right.operatorToken.kind === 60 /* QuestionQuestionToken */) ? node.expression.right.right : void 0;
        }
        function getSingleInitializerOfVariableStatementOrPropertyDeclaration(node) {
            switch (node.kind) {
                case 240 /* VariableStatement */:
                    const v = getSingleVariableOfVariableStatement(node);
                    return v && v.initializer;
                case 169 /* PropertyDeclaration */:
                    return node.initializer;
                case 299 /* PropertyAssignment */:
                    return node.initializer;
            }
        }
        function getSingleVariableOfVariableStatement(node) {
            return isVariableStatement(node) ? firstOrUndefined(node.declarationList.declarations) : void 0;
        }
        function getNestedModuleDeclaration(node) {
            return isModuleDeclaration(node) && node.body && node.body.kind === 264 /* ModuleDeclaration */ ? node.body : void 0;
        }
        function canHaveFlowNode(node) {
            if (node.kind >= 240 /* FirstStatement */ && node.kind <= 256 /* LastStatement */) {
                return true;
            }
            switch (node.kind) {
                case 79 /* Identifier */:
                case 108 /* ThisKeyword */:
                case 106 /* SuperKeyword */:
                case 163 /* QualifiedName */:
                case 233 /* MetaProperty */:
                case 209 /* ElementAccessExpression */:
                case 208 /* PropertyAccessExpression */:
                case 205 /* BindingElement */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    return true;
                default:
                    return false;
            }
        }
        function canHaveJSDoc(node) {
            switch (node.kind) {
                case 216 /* ArrowFunction */:
                case 223 /* BinaryExpression */:
                case 238 /* Block */:
                case 249 /* BreakStatement */:
                case 176 /* CallSignature */:
                case 292 /* CaseClause */:
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 172 /* ClassStaticBlockDeclaration */:
                case 173 /* Constructor */:
                case 182 /* ConstructorType */:
                case 177 /* ConstructSignature */:
                case 248 /* ContinueStatement */:
                case 256 /* DebuggerStatement */:
                case 243 /* DoStatement */:
                case 209 /* ElementAccessExpression */:
                case 239 /* EmptyStatement */:
                case 1 /* EndOfFileToken */:
                case 263 /* EnumDeclaration */:
                case 302 /* EnumMember */:
                case 274 /* ExportAssignment */:
                case 275 /* ExportDeclaration */:
                case 278 /* ExportSpecifier */:
                case 241 /* ExpressionStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                case 245 /* ForStatement */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 181 /* FunctionType */:
                case 174 /* GetAccessor */:
                case 79 /* Identifier */:
                case 242 /* IfStatement */:
                case 269 /* ImportDeclaration */:
                case 268 /* ImportEqualsDeclaration */:
                case 178 /* IndexSignature */:
                case 261 /* InterfaceDeclaration */:
                case 320 /* JSDocFunctionType */:
                case 326 /* JSDocSignature */:
                case 253 /* LabeledStatement */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 264 /* ModuleDeclaration */:
                case 199 /* NamedTupleMember */:
                case 267 /* NamespaceExportDeclaration */:
                case 207 /* ObjectLiteralExpression */:
                case 166 /* Parameter */:
                case 214 /* ParenthesizedExpression */:
                case 208 /* PropertyAccessExpression */:
                case 299 /* PropertyAssignment */:
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 250 /* ReturnStatement */:
                case 175 /* SetAccessor */:
                case 300 /* ShorthandPropertyAssignment */:
                case 301 /* SpreadAssignment */:
                case 252 /* SwitchStatement */:
                case 254 /* ThrowStatement */:
                case 255 /* TryStatement */:
                case 262 /* TypeAliasDeclaration */:
                case 165 /* TypeParameter */:
                case 257 /* VariableDeclaration */:
                case 240 /* VariableStatement */:
                case 244 /* WhileStatement */:
                case 251 /* WithStatement */:
                    return true;
                default:
                    return false;
            }
        }
        function getJSDocCommentsAndTags(hostNode, noCache) {
            let result;
            if (isVariableLike(hostNode) && hasInitializer(hostNode) && hasJSDocNodes(hostNode.initializer)) {
                result = addRange(result, filterOwnedJSDocTags(hostNode, last(hostNode.initializer.jsDoc)));
            }
            let node = hostNode;
            while (node && node.parent) {
                if (hasJSDocNodes(node)) {
                    result = addRange(result, filterOwnedJSDocTags(hostNode, last(node.jsDoc)));
                }
                if (node.kind === 166 /* Parameter */) {
                    result = addRange(result, (noCache ? getJSDocParameterTagsNoCache : getJSDocParameterTags)(node));
                    break;
                }
                if (node.kind === 165 /* TypeParameter */) {
                    result = addRange(result, (noCache ? getJSDocTypeParameterTagsNoCache : getJSDocTypeParameterTags)(node));
                    break;
                }
                node = getNextJSDocCommentLocation(node);
            }
            return result || emptyArray;
        }
        function filterOwnedJSDocTags(hostNode, jsDoc) {
            if (isJSDoc(jsDoc)) {
                const ownedTags = filter(jsDoc.tags, (tag) => ownsJSDocTag(hostNode, tag));
                return jsDoc.tags === ownedTags ? [jsDoc] : ownedTags;
            }
            return ownsJSDocTag(hostNode, jsDoc) ? [jsDoc] : void 0;
        }
        function ownsJSDocTag(hostNode, tag) {
            return !(isJSDocTypeTag(tag) || isJSDocSatisfiesTag(tag)) || !tag.parent || !isJSDoc(tag.parent) || !isParenthesizedExpression(tag.parent.parent) || tag.parent.parent === hostNode;
        }
        function getNextJSDocCommentLocation(node) {
            const parent2 = node.parent;
            if (parent2.kind === 299 /* PropertyAssignment */ || parent2.kind === 274 /* ExportAssignment */ || parent2.kind === 169 /* PropertyDeclaration */ || parent2.kind === 241 /* ExpressionStatement */ && node.kind === 208 /* PropertyAccessExpression */ || parent2.kind === 250 /* ReturnStatement */ || getNestedModuleDeclaration(parent2) || isBinaryExpression(node) && node.operatorToken.kind === 63 /* EqualsToken */) {
                return parent2;
            }
            else if (parent2.parent && (getSingleVariableOfVariableStatement(parent2.parent) === node || isBinaryExpression(parent2) && parent2.operatorToken.kind === 63 /* EqualsToken */)) {
                return parent2.parent;
            }
            else if (parent2.parent && parent2.parent.parent && (getSingleVariableOfVariableStatement(parent2.parent.parent) || getSingleInitializerOfVariableStatementOrPropertyDeclaration(parent2.parent.parent) === node || getSourceOfDefaultedAssignment(parent2.parent.parent))) {
                return parent2.parent.parent;
            }
        }
        function getParameterSymbolFromJSDoc(node) {
            if (node.symbol) {
                return node.symbol;
            }
            if (!isIdentifier(node.name)) {
                return void 0;
            }
            const name = node.name.escapedText;
            const decl = getHostSignatureFromJSDoc(node);
            if (!decl) {
                return void 0;
            }
            const parameter = find(decl.parameters, (p) => p.name.kind === 79 /* Identifier */ && p.name.escapedText === name);
            return parameter && parameter.symbol;
        }
        function getEffectiveContainerForJSDocTemplateTag(node) {
            if (isJSDoc(node.parent) && node.parent.tags) {
                const typeAlias = find(node.parent.tags, isJSDocTypeAlias);
                if (typeAlias) {
                    return typeAlias;
                }
            }
            return getHostSignatureFromJSDoc(node);
        }
        function getHostSignatureFromJSDoc(node) {
            const host = getEffectiveJSDocHost(node);
            if (host) {
                return isPropertySignature(host) && host.type && isFunctionLike(host.type) ? host.type : isFunctionLike(host) ? host : void 0;
            }
            return void 0;
        }
        function getEffectiveJSDocHost(node) {
            const host = getJSDocHost(node);
            if (host) {
                return getSourceOfDefaultedAssignment(host) || getSourceOfAssignment(host) || getSingleInitializerOfVariableStatementOrPropertyDeclaration(host) || getSingleVariableOfVariableStatement(host) || getNestedModuleDeclaration(host) || host;
            }
        }
        function getJSDocHost(node) {
            const jsDoc = getJSDocRoot(node);
            if (!jsDoc) {
                return void 0;
            }
            const host = jsDoc.parent;
            if (host && host.jsDoc && jsDoc === lastOrUndefined(host.jsDoc)) {
                return host;
            }
        }
        function getJSDocRoot(node) {
            return findAncestor(node.parent, isJSDoc);
        }
        function getTypeParameterFromJsDoc(node) {
            const name = node.name.escapedText;
            const { typeParameters } = node.parent.parent.parent;
            return typeParameters && find(typeParameters, (p) => p.name.escapedText === name);
        }
        function hasTypeArguments(node) {
            return !!node.typeArguments;
        }
        function getAssignmentTargetKind(node) {
            let parent2 = node.parent;
            while (true) {
                switch (parent2.kind) {
                    case 223 /* BinaryExpression */:
                        const binaryOperator = parent2.operatorToken.kind;
                        return isAssignmentOperator(binaryOperator) && parent2.left === node ? binaryOperator === 63 /* EqualsToken */ || isLogicalOrCoalescingAssignmentOperator(binaryOperator) ? 1 /* Definite */ : 2 /* Compound */ : 0 /* None */;
                    case 221 /* PrefixUnaryExpression */:
                    case 222 /* PostfixUnaryExpression */:
                        const unaryOperator = parent2.operator;
                        return unaryOperator === 45 /* PlusPlusToken */ || unaryOperator === 46 /* MinusMinusToken */ ? 2 /* Compound */ : 0 /* None */;
                    case 246 /* ForInStatement */:
                    case 247 /* ForOfStatement */:
                        return parent2.initializer === node ? 1 /* Definite */ : 0 /* None */;
                    case 214 /* ParenthesizedExpression */:
                    case 206 /* ArrayLiteralExpression */:
                    case 227 /* SpreadElement */:
                    case 232 /* NonNullExpression */:
                        node = parent2;
                        break;
                    case 301 /* SpreadAssignment */:
                        node = parent2.parent;
                        break;
                    case 300 /* ShorthandPropertyAssignment */:
                        if (parent2.name !== node) {
                            return 0 /* None */;
                        }
                        node = parent2.parent;
                        break;
                    case 299 /* PropertyAssignment */:
                        if (parent2.name === node) {
                            return 0 /* None */;
                        }
                        node = parent2.parent;
                        break;
                    default:
                        return 0 /* None */;
                }
                parent2 = node.parent;
            }
        }
        function isAssignmentTarget(node) {
            return getAssignmentTargetKind(node) !== 0 /* None */;
        }
        function isNodeWithPossibleHoistedDeclaration(node) {
            switch (node.kind) {
                case 238 /* Block */:
                case 240 /* VariableStatement */:
                case 251 /* WithStatement */:
                case 242 /* IfStatement */:
                case 252 /* SwitchStatement */:
                case 266 /* CaseBlock */:
                case 292 /* CaseClause */:
                case 293 /* DefaultClause */:
                case 253 /* LabeledStatement */:
                case 245 /* ForStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                case 243 /* DoStatement */:
                case 244 /* WhileStatement */:
                case 255 /* TryStatement */:
                case 295 /* CatchClause */:
                    return true;
            }
            return false;
        }
        function isValueSignatureDeclaration(node) {
            return isFunctionExpression(node) || isArrowFunction(node) || isMethodOrAccessor(node) || isFunctionDeclaration(node) || isConstructorDeclaration(node);
        }
        function walkUp(node, kind) {
            while (node && node.kind === kind) {
                node = node.parent;
            }
            return node;
        }
        function walkUpParenthesizedTypes(node) {
            return walkUp(node, 193 /* ParenthesizedType */);
        }
        function walkUpParenthesizedExpressions(node) {
            return walkUp(node, 214 /* ParenthesizedExpression */);
        }
        function walkUpParenthesizedTypesAndGetParentAndChild(node) {
            let child;
            while (node && node.kind === 193 /* ParenthesizedType */) {
                child = node;
                node = node.parent;
            }
            return [child, node];
        }
        function skipTypeParentheses(node) {
            while (isParenthesizedTypeNode(node))
                node = node.type;
            return node;
        }
        function skipParentheses(node, excludeJSDocTypeAssertions) {
            const flags = excludeJSDocTypeAssertions ? 1 /* Parentheses */ | 16 /* ExcludeJSDocTypeAssertion */ : 1 /* Parentheses */;
            return skipOuterExpressions(node, flags);
        }
        function isDeleteTarget(node) {
            if (node.kind !== 208 /* PropertyAccessExpression */ && node.kind !== 209 /* ElementAccessExpression */) {
                return false;
            }
            node = walkUpParenthesizedExpressions(node.parent);
            return node && node.kind === 217 /* DeleteExpression */;
        }
        function isNodeDescendantOf(node, ancestor) {
            while (node) {
                if (node === ancestor)
                    return true;
                node = node.parent;
            }
            return false;
        }
        function isDeclarationName(name) {
            return !isSourceFile(name) && !isBindingPattern(name) && isDeclaration(name.parent) && name.parent.name === name;
        }
        function getDeclarationFromName(name) {
            const parent2 = name.parent;
            switch (name.kind) {
                case 10 /* StringLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 8 /* NumericLiteral */:
                    if (isComputedPropertyName(parent2))
                        return parent2.parent;
                case 79 /* Identifier */:
                    if (isDeclaration(parent2)) {
                        return parent2.name === name ? parent2 : void 0;
                    }
                    else if (isQualifiedName(parent2)) {
                        const tag = parent2.parent;
                        return isJSDocParameterTag(tag) && tag.name === parent2 ? tag : void 0;
                    }
                    else {
                        const binExp = parent2.parent;
                        return isBinaryExpression(binExp) && getAssignmentDeclarationKind(binExp) !== 0 /* None */ && (binExp.left.symbol || binExp.symbol) && getNameOfDeclaration(binExp) === name ? binExp : void 0;
                    }
                case 80 /* PrivateIdentifier */:
                    return isDeclaration(parent2) && parent2.name === name ? parent2 : void 0;
                default:
                    return void 0;
            }
        }
        function isLiteralComputedPropertyDeclarationName(node) {
            return isStringOrNumericLiteralLike(node) && node.parent.kind === 164 /* ComputedPropertyName */ && isDeclaration(node.parent.parent);
        }
        function isIdentifierName(node) {
            const parent2 = node.parent;
            switch (parent2.kind) {
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 302 /* EnumMember */:
                case 299 /* PropertyAssignment */:
                case 208 /* PropertyAccessExpression */:
                    return parent2.name === node;
                case 163 /* QualifiedName */:
                    return parent2.right === node;
                case 205 /* BindingElement */:
                case 273 /* ImportSpecifier */:
                    return parent2.propertyName === node;
                case 278 /* ExportSpecifier */:
                case 288 /* JsxAttribute */:
                case 282 /* JsxSelfClosingElement */:
                case 283 /* JsxOpeningElement */:
                case 284 /* JsxClosingElement */:
                    return true;
            }
            return false;
        }
        function isAliasSymbolDeclaration(node) {
            if (node.kind === 268 /* ImportEqualsDeclaration */ || node.kind === 267 /* NamespaceExportDeclaration */ || node.kind === 270 /* ImportClause */ && !!node.name || node.kind === 271 /* NamespaceImport */ || node.kind === 277 /* NamespaceExport */ || node.kind === 273 /* ImportSpecifier */ || node.kind === 278 /* ExportSpecifier */ || node.kind === 274 /* ExportAssignment */ && exportAssignmentIsAlias(node)) {
                return true;
            }
            return isInJSFile(node) && (isBinaryExpression(node) && getAssignmentDeclarationKind(node) === 2 /* ModuleExports */ && exportAssignmentIsAlias(node) || isPropertyAccessExpression(node) && isBinaryExpression(node.parent) && node.parent.left === node && node.parent.operatorToken.kind === 63 /* EqualsToken */ && isAliasableExpression(node.parent.right));
        }
        function getAliasDeclarationFromName(node) {
            switch (node.parent.kind) {
                case 270 /* ImportClause */:
                case 273 /* ImportSpecifier */:
                case 271 /* NamespaceImport */:
                case 278 /* ExportSpecifier */:
                case 274 /* ExportAssignment */:
                case 268 /* ImportEqualsDeclaration */:
                case 277 /* NamespaceExport */:
                    return node.parent;
                case 163 /* QualifiedName */:
                    do {
                        node = node.parent;
                    } while (node.parent.kind === 163 /* QualifiedName */);
                    return getAliasDeclarationFromName(node);
            }
        }
        function isAliasableExpression(e) {
            return isEntityNameExpression(e) || isClassExpression(e);
        }
        function exportAssignmentIsAlias(node) {
            const e = getExportAssignmentExpression(node);
            return isAliasableExpression(e);
        }
        function getExportAssignmentExpression(node) {
            return isExportAssignment(node) ? node.expression : node.right;
        }
        function getPropertyAssignmentAliasLikeExpression(node) {
            return node.kind === 300 /* ShorthandPropertyAssignment */ ? node.name : node.kind === 299 /* PropertyAssignment */ ? node.initializer : node.parent.right;
        }
        function getEffectiveBaseTypeNode(node) {
            const baseType = getClassExtendsHeritageElement(node);
            if (baseType && isInJSFile(node)) {
                const tag = getJSDocAugmentsTag(node);
                if (tag) {
                    return tag.class;
                }
            }
            return baseType;
        }
        function getClassExtendsHeritageElement(node) {
            const heritageClause = getHeritageClause(node.heritageClauses, 94 /* ExtendsKeyword */);
            return heritageClause && heritageClause.types.length > 0 ? heritageClause.types[0] : void 0;
        }
        function getEffectiveImplementsTypeNodes(node) {
            if (isInJSFile(node)) {
                return getJSDocImplementsTags(node).map((n) => n.class);
            }
            else {
                const heritageClause = getHeritageClause(node.heritageClauses, 117 /* ImplementsKeyword */);
                return heritageClause == null ? void 0 : heritageClause.types;
            }
        }
        function getAllSuperTypeNodes(node) {
            return isInterfaceDeclaration(node) ? getInterfaceBaseTypeNodes(node) || emptyArray : isClassLike(node) ? concatenate(singleElementArray(getEffectiveBaseTypeNode(node)), getEffectiveImplementsTypeNodes(node)) || emptyArray : emptyArray;
        }
        function getInterfaceBaseTypeNodes(node) {
            const heritageClause = getHeritageClause(node.heritageClauses, 94 /* ExtendsKeyword */);
            return heritageClause ? heritageClause.types : void 0;
        }
        function getHeritageClause(clauses, kind) {
            if (clauses) {
                for (const clause of clauses) {
                    if (clause.token === kind) {
                        return clause;
                    }
                }
            }
            return void 0;
        }
        function getAncestor(node, kind) {
            while (node) {
                if (node.kind === kind) {
                    return node;
                }
                node = node.parent;
            }
            return void 0;
        }
        function isKeyword(token) {
            return 81 /* FirstKeyword */ <= token && token <= 162 /* LastKeyword */;
        }
        function isContextualKeyword(token) {
            return 126 /* FirstContextualKeyword */ <= token && token <= 162 /* LastContextualKeyword */;
        }
        function isNonContextualKeyword(token) {
            return isKeyword(token) && !isContextualKeyword(token);
        }
        function isFutureReservedKeyword(token) {
            return 117 /* FirstFutureReservedWord */ <= token && token <= 125 /* LastFutureReservedWord */;
        }
        function isStringANonContextualKeyword(name) {
            const token = stringToToken(name);
            return token !== void 0 && isNonContextualKeyword(token);
        }
        function isStringAKeyword(name) {
            const token = stringToToken(name);
            return token !== void 0 && isKeyword(token);
        }
        function isIdentifierANonContextualKeyword(node) {
            const originalKeywordKind = identifierToKeywordKind(node);
            return !!originalKeywordKind && !isContextualKeyword(originalKeywordKind);
        }
        function isTrivia(token) {
            return 2 /* FirstTriviaToken */ <= token && token <= 7 /* LastTriviaToken */;
        }
        function getFunctionFlags(node) {
            if (!node) {
                return 4 /* Invalid */;
            }
            let flags = 0 /* Normal */;
            switch (node.kind) {
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 171 /* MethodDeclaration */:
                    if (node.asteriskToken) {
                        flags |= 1 /* Generator */;
                    }
                case 216 /* ArrowFunction */:
                    if (hasSyntacticModifier(node, 512 /* Async */)) {
                        flags |= 2 /* Async */;
                    }
                    break;
            }
            if (!node.body) {
                flags |= 4 /* Invalid */;
            }
            return flags;
        }
        function isAsyncFunction(node) {
            switch (node.kind) {
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                case 171 /* MethodDeclaration */:
                    return node.body !== void 0 && node.asteriskToken === void 0 && hasSyntacticModifier(node, 512 /* Async */);
            }
            return false;
        }
        function isStringOrNumericLiteralLike(node) {
            return isStringLiteralLike(node) || isNumericLiteral(node);
        }
        function isSignedNumericLiteral(node) {
            return isPrefixUnaryExpression(node) && (node.operator === 39 /* PlusToken */ || node.operator === 40 /* MinusToken */) && isNumericLiteral(node.operand);
        }
        function hasDynamicName(declaration) {
            const name = getNameOfDeclaration(declaration);
            return !!name && isDynamicName(name);
        }
        function isDynamicName(name) {
            if (!(name.kind === 164 /* ComputedPropertyName */ || name.kind === 209 /* ElementAccessExpression */)) {
                return false;
            }
            const expr = isElementAccessExpression(name) ? skipParentheses(name.argumentExpression) : name.expression;
            return !isStringOrNumericLiteralLike(expr) && !isSignedNumericLiteral(expr);
        }
        function getPropertyNameForPropertyNameNode(name) {
            switch (name.kind) {
                case 79 /* Identifier */:
                case 80 /* PrivateIdentifier */:
                    return name.escapedText;
                case 10 /* StringLiteral */:
                case 8 /* NumericLiteral */:
                    return escapeLeadingUnderscores(name.text);
                case 164 /* ComputedPropertyName */:
                    const nameExpression = name.expression;
                    if (isStringOrNumericLiteralLike(nameExpression)) {
                        return escapeLeadingUnderscores(nameExpression.text);
                    }
                    else if (isSignedNumericLiteral(nameExpression)) {
                        if (nameExpression.operator === 40 /* MinusToken */) {
                            return tokenToString(nameExpression.operator) + nameExpression.operand.text;
                        }
                        return nameExpression.operand.text;
                    }
                    return void 0;
                default:
                    return Debug.assertNever(name);
            }
        }
        function isPropertyNameLiteral(node) {
            switch (node.kind) {
                case 79 /* Identifier */:
                case 10 /* StringLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 8 /* NumericLiteral */:
                    return true;
                default:
                    return false;
            }
        }
        function getTextOfIdentifierOrLiteral(node) {
            return isMemberName(node) ? idText(node) : node.text;
        }
        function getEscapedTextOfIdentifierOrLiteral(node) {
            return isMemberName(node) ? node.escapedText : escapeLeadingUnderscores(node.text);
        }
        function getPropertyNameForUniqueESSymbol(symbol) {
            return `__@${getSymbolId(symbol)}@${symbol.escapedName}`;
        }
        function getSymbolNameForPrivateIdentifier(containingClassSymbol, description2) {
            return `__#${getSymbolId(containingClassSymbol)}@${description2}`;
        }
        function isKnownSymbol(symbol) {
            return startsWith(symbol.escapedName, "__@");
        }
        function isPrivateIdentifierSymbol(symbol) {
            return startsWith(symbol.escapedName, "__#");
        }
        function isESSymbolIdentifier(node) {
            return node.kind === 79 /* Identifier */ && node.escapedText === "Symbol";
        }
        function isProtoSetter(node) {
            return isIdentifier(node) ? idText(node) === "__proto__" : isStringLiteral(node) && node.text === "__proto__";
        }
        function isAnonymousFunctionDefinition(node, cb) {
            node = skipOuterExpressions(node);
            switch (node.kind) {
                case 228 /* ClassExpression */:
                case 215 /* FunctionExpression */:
                    if (node.name) {
                        return false;
                    }
                    break;
                case 216 /* ArrowFunction */:
                    break;
                default:
                    return false;
            }
            return typeof cb === "function" ? cb(node) : true;
        }
        function isNamedEvaluationSource(node) {
            switch (node.kind) {
                case 299 /* PropertyAssignment */:
                    return !isProtoSetter(node.name);
                case 300 /* ShorthandPropertyAssignment */:
                    return !!node.objectAssignmentInitializer;
                case 257 /* VariableDeclaration */:
                    return isIdentifier(node.name) && !!node.initializer;
                case 166 /* Parameter */:
                    return isIdentifier(node.name) && !!node.initializer && !node.dotDotDotToken;
                case 205 /* BindingElement */:
                    return isIdentifier(node.name) && !!node.initializer && !node.dotDotDotToken;
                case 169 /* PropertyDeclaration */:
                    return !!node.initializer;
                case 223 /* BinaryExpression */:
                    switch (node.operatorToken.kind) {
                        case 63 /* EqualsToken */:
                        case 76 /* AmpersandAmpersandEqualsToken */:
                        case 75 /* BarBarEqualsToken */:
                        case 77 /* QuestionQuestionEqualsToken */:
                            return isIdentifier(node.left);
                    }
                    break;
                case 274 /* ExportAssignment */:
                    return true;
            }
            return false;
        }
        function isNamedEvaluation(node, cb) {
            if (!isNamedEvaluationSource(node))
                return false;
            switch (node.kind) {
                case 299 /* PropertyAssignment */:
                    return isAnonymousFunctionDefinition(node.initializer, cb);
                case 300 /* ShorthandPropertyAssignment */:
                    return isAnonymousFunctionDefinition(node.objectAssignmentInitializer, cb);
                case 257 /* VariableDeclaration */:
                case 166 /* Parameter */:
                case 205 /* BindingElement */:
                case 169 /* PropertyDeclaration */:
                    return isAnonymousFunctionDefinition(node.initializer, cb);
                case 223 /* BinaryExpression */:
                    return isAnonymousFunctionDefinition(node.right, cb);
                case 274 /* ExportAssignment */:
                    return isAnonymousFunctionDefinition(node.expression, cb);
            }
        }
        function isPushOrUnshiftIdentifier(node) {
            return node.escapedText === "push" || node.escapedText === "unshift";
        }
        function isParameterDeclaration(node) {
            const root = getRootDeclaration(node);
            return root.kind === 166 /* Parameter */;
        }
        function getRootDeclaration(node) {
            while (node.kind === 205 /* BindingElement */) {
                node = node.parent.parent;
            }
            return node;
        }
        function nodeStartsNewLexicalEnvironment(node) {
            const kind = node.kind;
            return kind === 173 /* Constructor */ || kind === 215 /* FunctionExpression */ || kind === 259 /* FunctionDeclaration */ || kind === 216 /* ArrowFunction */ || kind === 171 /* MethodDeclaration */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */ || kind === 264 /* ModuleDeclaration */ || kind === 308 /* SourceFile */;
        }
        function nodeIsSynthesized(range) {
            return positionIsSynthesized(range.pos) || positionIsSynthesized(range.end);
        }
        function getOriginalSourceFile(sourceFile) {
            return getParseTreeNode(sourceFile, isSourceFile) || sourceFile;
        }
        function getExpressionAssociativity(expression) {
            const operator = getOperator(expression);
            const hasArguments = expression.kind === 211 /* NewExpression */ && expression.arguments !== void 0;
            return getOperatorAssociativity(expression.kind, operator, hasArguments);
        }
        function getOperatorAssociativity(kind, operator, hasArguments) {
            switch (kind) {
                case 211 /* NewExpression */:
                    return hasArguments ? 0 /* Left */ : 1 /* Right */;
                case 221 /* PrefixUnaryExpression */:
                case 218 /* TypeOfExpression */:
                case 219 /* VoidExpression */:
                case 217 /* DeleteExpression */:
                case 220 /* AwaitExpression */:
                case 224 /* ConditionalExpression */:
                case 226 /* YieldExpression */:
                    return 1 /* Right */;
                case 223 /* BinaryExpression */:
                    switch (operator) {
                        case 42 /* AsteriskAsteriskToken */:
                        case 63 /* EqualsToken */:
                        case 64 /* PlusEqualsToken */:
                        case 65 /* MinusEqualsToken */:
                        case 67 /* AsteriskAsteriskEqualsToken */:
                        case 66 /* AsteriskEqualsToken */:
                        case 68 /* SlashEqualsToken */:
                        case 69 /* PercentEqualsToken */:
                        case 70 /* LessThanLessThanEqualsToken */:
                        case 71 /* GreaterThanGreaterThanEqualsToken */:
                        case 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                        case 73 /* AmpersandEqualsToken */:
                        case 78 /* CaretEqualsToken */:
                        case 74 /* BarEqualsToken */:
                        case 75 /* BarBarEqualsToken */:
                        case 76 /* AmpersandAmpersandEqualsToken */:
                        case 77 /* QuestionQuestionEqualsToken */:
                            return 1 /* Right */;
                    }
            }
            return 0 /* Left */;
        }
        function getExpressionPrecedence(expression) {
            const operator = getOperator(expression);
            const hasArguments = expression.kind === 211 /* NewExpression */ && expression.arguments !== void 0;
            return getOperatorPrecedence(expression.kind, operator, hasArguments);
        }
        function getOperator(expression) {
            if (expression.kind === 223 /* BinaryExpression */) {
                return expression.operatorToken.kind;
            }
            else if (expression.kind === 221 /* PrefixUnaryExpression */ || expression.kind === 222 /* PostfixUnaryExpression */) {
                return expression.operator;
            }
            else {
                return expression.kind;
            }
        }
        function getOperatorPrecedence(nodeKind, operatorKind, hasArguments) {
            switch (nodeKind) {
                case 357 /* CommaListExpression */:
                    return 0 /* Comma */;
                case 227 /* SpreadElement */:
                    return 1 /* Spread */;
                case 226 /* YieldExpression */:
                    return 2 /* Yield */;
                case 224 /* ConditionalExpression */:
                    return 4 /* Conditional */;
                case 223 /* BinaryExpression */:
                    switch (operatorKind) {
                        case 27 /* CommaToken */:
                            return 0 /* Comma */;
                        case 63 /* EqualsToken */:
                        case 64 /* PlusEqualsToken */:
                        case 65 /* MinusEqualsToken */:
                        case 67 /* AsteriskAsteriskEqualsToken */:
                        case 66 /* AsteriskEqualsToken */:
                        case 68 /* SlashEqualsToken */:
                        case 69 /* PercentEqualsToken */:
                        case 70 /* LessThanLessThanEqualsToken */:
                        case 71 /* GreaterThanGreaterThanEqualsToken */:
                        case 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                        case 73 /* AmpersandEqualsToken */:
                        case 78 /* CaretEqualsToken */:
                        case 74 /* BarEqualsToken */:
                        case 75 /* BarBarEqualsToken */:
                        case 76 /* AmpersandAmpersandEqualsToken */:
                        case 77 /* QuestionQuestionEqualsToken */:
                            return 3 /* Assignment */;
                        default:
                            return getBinaryOperatorPrecedence(operatorKind);
                    }
                case 213 /* TypeAssertionExpression */:
                case 232 /* NonNullExpression */:
                case 221 /* PrefixUnaryExpression */:
                case 218 /* TypeOfExpression */:
                case 219 /* VoidExpression */:
                case 217 /* DeleteExpression */:
                case 220 /* AwaitExpression */:
                    return 16 /* Unary */;
                case 222 /* PostfixUnaryExpression */:
                    return 17 /* Update */;
                case 210 /* CallExpression */:
                    return 18 /* LeftHandSide */;
                case 211 /* NewExpression */:
                    return hasArguments ? 19 /* Member */ : 18 /* LeftHandSide */;
                case 212 /* TaggedTemplateExpression */:
                case 208 /* PropertyAccessExpression */:
                case 209 /* ElementAccessExpression */:
                case 233 /* MetaProperty */:
                    return 19 /* Member */;
                case 231 /* AsExpression */:
                case 235 /* SatisfiesExpression */:
                    return 11 /* Relational */;
                case 108 /* ThisKeyword */:
                case 106 /* SuperKeyword */:
                case 79 /* Identifier */:
                case 80 /* PrivateIdentifier */:
                case 104 /* NullKeyword */:
                case 110 /* TrueKeyword */:
                case 95 /* FalseKeyword */:
                case 8 /* NumericLiteral */:
                case 9 /* BigIntLiteral */:
                case 10 /* StringLiteral */:
                case 206 /* ArrayLiteralExpression */:
                case 207 /* ObjectLiteralExpression */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                case 228 /* ClassExpression */:
                case 13 /* RegularExpressionLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 225 /* TemplateExpression */:
                case 214 /* ParenthesizedExpression */:
                case 229 /* OmittedExpression */:
                case 281 /* JsxElement */:
                case 282 /* JsxSelfClosingElement */:
                case 285 /* JsxFragment */:
                    return 20 /* Primary */;
                default:
                    return -1 /* Invalid */;
            }
        }
        function getBinaryOperatorPrecedence(kind) {
            switch (kind) {
                case 60 /* QuestionQuestionToken */:
                    return 4 /* Coalesce */;
                case 56 /* BarBarToken */:
                    return 5 /* LogicalOR */;
                case 55 /* AmpersandAmpersandToken */:
                    return 6 /* LogicalAND */;
                case 51 /* BarToken */:
                    return 7 /* BitwiseOR */;
                case 52 /* CaretToken */:
                    return 8 /* BitwiseXOR */;
                case 50 /* AmpersandToken */:
                    return 9 /* BitwiseAND */;
                case 34 /* EqualsEqualsToken */:
                case 35 /* ExclamationEqualsToken */:
                case 36 /* EqualsEqualsEqualsToken */:
                case 37 /* ExclamationEqualsEqualsToken */:
                    return 10 /* Equality */;
                case 29 /* LessThanToken */:
                case 31 /* GreaterThanToken */:
                case 32 /* LessThanEqualsToken */:
                case 33 /* GreaterThanEqualsToken */:
                case 102 /* InstanceOfKeyword */:
                case 101 /* InKeyword */:
                case 128 /* AsKeyword */:
                case 150 /* SatisfiesKeyword */:
                    return 11 /* Relational */;
                case 47 /* LessThanLessThanToken */:
                case 48 /* GreaterThanGreaterThanToken */:
                case 49 /* GreaterThanGreaterThanGreaterThanToken */:
                    return 12 /* Shift */;
                case 39 /* PlusToken */:
                case 40 /* MinusToken */:
                    return 13 /* Additive */;
                case 41 /* AsteriskToken */:
                case 43 /* SlashToken */:
                case 44 /* PercentToken */:
                    return 14 /* Multiplicative */;
                case 42 /* AsteriskAsteriskToken */:
                    return 15 /* Exponentiation */;
            }
            return -1;
        }
        function getSemanticJsxChildren(children) {
            return filter(children, (i) => {
                switch (i.kind) {
                    case 291 /* JsxExpression */:
                        return !!i.expression;
                    case 11 /* JsxText */:
                        return !i.containsOnlyTriviaWhiteSpaces;
                    default:
                        return true;
                }
            });
        }
        function createDiagnosticCollection() {
            let nonFileDiagnostics = [];
            const filesWithDiagnostics = [];
            const fileDiagnostics = /* @__PURE__ */ new Map();
            let hasReadNonFileDiagnostics = false;
            return {
                add,
                lookup,
                getGlobalDiagnostics,
                getDiagnostics: getDiagnostics2
            };
            function lookup(diagnostic) {
                let diagnostics;
                if (diagnostic.file) {
                    diagnostics = fileDiagnostics.get(diagnostic.file.fileName);
                }
                else {
                    diagnostics = nonFileDiagnostics;
                }
                if (!diagnostics) {
                    return void 0;
                }
                const result = binarySearch(diagnostics, diagnostic, identity, compareDiagnosticsSkipRelatedInformation);
                if (result >= 0) {
                    return diagnostics[result];
                }
                return void 0;
            }
            function add(diagnostic) {
                let diagnostics;
                if (diagnostic.file) {
                    diagnostics = fileDiagnostics.get(diagnostic.file.fileName);
                    if (!diagnostics) {
                        diagnostics = [];
                        fileDiagnostics.set(diagnostic.file.fileName, diagnostics);
                        insertSorted(filesWithDiagnostics, diagnostic.file.fileName, compareStringsCaseSensitive);
                    }
                }
                else {
                    if (hasReadNonFileDiagnostics) {
                        hasReadNonFileDiagnostics = false;
                        nonFileDiagnostics = nonFileDiagnostics.slice();
                    }
                    diagnostics = nonFileDiagnostics;
                }
                insertSorted(diagnostics, diagnostic, compareDiagnosticsSkipRelatedInformation);
            }
            function getGlobalDiagnostics() {
                hasReadNonFileDiagnostics = true;
                return nonFileDiagnostics;
            }
            function getDiagnostics2(fileName) {
                if (fileName) {
                    return fileDiagnostics.get(fileName) || [];
                }
                const fileDiags = flatMapToMutable(filesWithDiagnostics, (f) => fileDiagnostics.get(f));
                if (!nonFileDiagnostics.length) {
                    return fileDiags;
                }
                fileDiags.unshift(...nonFileDiagnostics);
                return fileDiags;
            }
        }
        function escapeTemplateSubstitution(str) {
            return str.replace(templateSubstitutionRegExp, "\\${");
        }
        function hasInvalidEscape(template) {
            return template && !!(isNoSubstitutionTemplateLiteral(template) ? template.templateFlags : template.head.templateFlags || some(template.templateSpans, (span) => !!span.literal.templateFlags));
        }
        function encodeUtf16EscapeSequence(charCode) {
            const hexCharCode = charCode.toString(16).toUpperCase();
            const paddedHexCode = ("0000" + hexCharCode).slice(-4);
            return "\\u" + paddedHexCode;
        }
        function getReplacement(c, offset, input) {
            if (c.charCodeAt(0) === 0 /* nullCharacter */) {
                const lookAhead = input.charCodeAt(offset + c.length);
                if (lookAhead >= 48 /* _0 */ && lookAhead <= 57 /* _9 */) {
                    return "\\x00";
                }
                return "\\0";
            }
            return escapedCharsMap.get(c) || encodeUtf16EscapeSequence(c.charCodeAt(0));
        }
        function escapeString(s, quoteChar) {
            const escapedCharsRegExp = quoteChar === 96 /* backtick */ ? backtickQuoteEscapedCharsRegExp : quoteChar === 39 /* singleQuote */ ? singleQuoteEscapedCharsRegExp : doubleQuoteEscapedCharsRegExp;
            return s.replace(escapedCharsRegExp, getReplacement);
        }
        function escapeNonAsciiString(s, quoteChar) {
            s = escapeString(s, quoteChar);
            return nonAsciiCharacters.test(s) ? s.replace(nonAsciiCharacters, (c) => encodeUtf16EscapeSequence(c.charCodeAt(0))) : s;
        }
        function encodeJsxCharacterEntity(charCode) {
            const hexCharCode = charCode.toString(16).toUpperCase();
            return "&#x" + hexCharCode + ";";
        }
        function getJsxAttributeStringReplacement(c) {
            if (c.charCodeAt(0) === 0 /* nullCharacter */) {
                return "&#0;";
            }
            return jsxEscapedCharsMap.get(c) || encodeJsxCharacterEntity(c.charCodeAt(0));
        }
        function escapeJsxAttributeString(s, quoteChar) {
            const escapedCharsRegExp = quoteChar === 39 /* singleQuote */ ? jsxSingleQuoteEscapedCharsRegExp : jsxDoubleQuoteEscapedCharsRegExp;
            return s.replace(escapedCharsRegExp, getJsxAttributeStringReplacement);
        }
        function stripQuotes(name) {
            const length2 = name.length;
            if (length2 >= 2 && name.charCodeAt(0) === name.charCodeAt(length2 - 1) && isQuoteOrBacktick(name.charCodeAt(0))) {
                return name.substring(1, length2 - 1);
            }
            return name;
        }
        function isQuoteOrBacktick(charCode) {
            return charCode === 39 /* singleQuote */ || charCode === 34 /* doubleQuote */ || charCode === 96 /* backtick */;
        }
        function isIntrinsicJsxName(name) {
            const ch = name.charCodeAt(0);
            return ch >= 97 /* a */ && ch <= 122 /* z */ || stringContains(name, "-") || stringContains(name, ":");
        }
        function getIndentString(level) {
            const singleLevel = indentStrings[1];
            for (let current = indentStrings.length; current <= level; current++) {
                indentStrings.push(indentStrings[current - 1] + singleLevel);
            }
            return indentStrings[level];
        }
        function getIndentSize() {
            return indentStrings[1].length;
        }
        function isNightly() {
            return stringContains(version, "-dev") || stringContains(version, "-insiders");
        }
        function createTextWriter(newLine) {
            var output;
            var indent2;
            var lineStart;
            var lineCount;
            var linePos;
            var hasTrailingComment = false;
            function updateLineCountAndPosFor(s) {
                const lineStartsOfS = computeLineStarts(s);
                if (lineStartsOfS.length > 1) {
                    lineCount = lineCount + lineStartsOfS.length - 1;
                    linePos = output.length - s.length + last(lineStartsOfS);
                    lineStart = linePos - output.length === 0;
                }
                else {
                    lineStart = false;
                }
            }
            function writeText(s) {
                if (s && s.length) {
                    if (lineStart) {
                        s = getIndentString(indent2) + s;
                        lineStart = false;
                    }
                    output += s;
                    updateLineCountAndPosFor(s);
                }
            }
            function write(s) {
                if (s)
                    hasTrailingComment = false;
                writeText(s);
            }
            function writeComment(s) {
                if (s)
                    hasTrailingComment = true;
                writeText(s);
            }
            function reset2() {
                output = "";
                indent2 = 0;
                lineStart = true;
                lineCount = 0;
                linePos = 0;
                hasTrailingComment = false;
            }
            function rawWrite(s) {
                if (s !== void 0) {
                    output += s;
                    updateLineCountAndPosFor(s);
                    hasTrailingComment = false;
                }
            }
            function writeLiteral(s) {
                if (s && s.length) {
                    write(s);
                }
            }
            function writeLine(force) {
                if (!lineStart || force) {
                    output += newLine;
                    lineCount++;
                    linePos = output.length;
                    lineStart = true;
                    hasTrailingComment = false;
                }
            }
            function getTextPosWithWriteLine() {
                return lineStart ? output.length : output.length + newLine.length;
            }
            reset2();
            return {
                write,
                rawWrite,
                writeLiteral,
                writeLine,
                increaseIndent: () => {
                    indent2++;
                },
                decreaseIndent: () => {
                    indent2--;
                },
                getIndent: () => indent2,
                getTextPos: () => output.length,
                getLine: () => lineCount,
                getColumn: () => lineStart ? indent2 * getIndentSize() : output.length - linePos,
                getText: () => output,
                isAtStartOfLine: () => lineStart,
                hasTrailingComment: () => hasTrailingComment,
                hasTrailingWhitespace: () => !!output.length && isWhiteSpaceLike(output.charCodeAt(output.length - 1)),
                clear: reset2,
                writeKeyword: write,
                writeOperator: write,
                writeParameter: write,
                writeProperty: write,
                writePunctuation: write,
                writeSpace: write,
                writeStringLiteral: write,
                writeSymbol: (s, _) => write(s),
                writeTrailingSemicolon: write,
                writeComment,
                getTextPosWithWriteLine
            };
        }
        function getTrailingSemicolonDeferringWriter(writer) {
            let pendingTrailingSemicolon = false;
            function commitPendingTrailingSemicolon() {
                if (pendingTrailingSemicolon) {
                    writer.writeTrailingSemicolon(";");
                    pendingTrailingSemicolon = false;
                }
            }
            return {
                ...writer,
                writeTrailingSemicolon() {
                    pendingTrailingSemicolon = true;
                },
                writeLiteral(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeLiteral(s);
                },
                writeStringLiteral(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeStringLiteral(s);
                },
                writeSymbol(s, sym) {
                    commitPendingTrailingSemicolon();
                    writer.writeSymbol(s, sym);
                },
                writePunctuation(s) {
                    commitPendingTrailingSemicolon();
                    writer.writePunctuation(s);
                },
                writeKeyword(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeKeyword(s);
                },
                writeOperator(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeOperator(s);
                },
                writeParameter(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeParameter(s);
                },
                writeSpace(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeSpace(s);
                },
                writeProperty(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeProperty(s);
                },
                writeComment(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeComment(s);
                },
                writeLine() {
                    commitPendingTrailingSemicolon();
                    writer.writeLine();
                },
                increaseIndent() {
                    commitPendingTrailingSemicolon();
                    writer.increaseIndent();
                },
                decreaseIndent() {
                    commitPendingTrailingSemicolon();
                    writer.decreaseIndent();
                }
            };
        }
        function hostUsesCaseSensitiveFileNames(host) {
            return host.useCaseSensitiveFileNames ? host.useCaseSensitiveFileNames() : false;
        }
        function hostGetCanonicalFileName(host) {
            return createGetCanonicalFileName(hostUsesCaseSensitiveFileNames(host));
        }
        function getResolvedExternalModuleName(host, file, referenceFile) {
            return file.moduleName || getExternalModuleNameFromPath(host, file.fileName, referenceFile && referenceFile.fileName);
        }
        function getCanonicalAbsolutePath(host, path) {
            return host.getCanonicalFileName(getNormalizedAbsolutePath(path, host.getCurrentDirectory()));
        }
        function getExternalModuleNameFromDeclaration(host, resolver, declaration) {
            const file = resolver.getExternalModuleFileFromDeclaration(declaration);
            if (!file || file.isDeclarationFile) {
                return void 0;
            }
            const specifier = getExternalModuleName(declaration);
            if (specifier && isStringLiteralLike(specifier) && !pathIsRelative(specifier.text) && getCanonicalAbsolutePath(host, file.path).indexOf(getCanonicalAbsolutePath(host, ensureTrailingDirectorySeparator(host.getCommonSourceDirectory()))) === -1) {
                return void 0;
            }
            return getResolvedExternalModuleName(host, file);
        }
        function getExternalModuleNameFromPath(host, fileName, referencePath) {
            const getCanonicalFileName = (f) => host.getCanonicalFileName(f);
            const dir = toPath(referencePath ? getDirectoryPath(referencePath) : host.getCommonSourceDirectory(), host.getCurrentDirectory(), getCanonicalFileName);
            const filePath = getNormalizedAbsolutePath(fileName, host.getCurrentDirectory());
            const relativePath = getRelativePathToDirectoryOrUrl(dir, filePath, dir, getCanonicalFileName, 
            /*isAbsolutePathAnUrl*/
            false);
            const extensionless = removeFileExtension(relativePath);
            return referencePath ? ensurePathIsNonModuleName(extensionless) : extensionless;
        }
        function getOwnEmitOutputFilePath(fileName, host, extension) {
            const compilerOptions = host.getCompilerOptions();
            let emitOutputFilePathWithoutExtension;
            if (compilerOptions.outDir) {
                emitOutputFilePathWithoutExtension = removeFileExtension(getSourceFilePathInNewDir(fileName, host, compilerOptions.outDir));
            }
            else {
                emitOutputFilePathWithoutExtension = removeFileExtension(fileName);
            }
            return emitOutputFilePathWithoutExtension + extension;
        }
        function getDeclarationEmitOutputFilePath(fileName, host) {
            return getDeclarationEmitOutputFilePathWorker(fileName, host.getCompilerOptions(), host.getCurrentDirectory(), host.getCommonSourceDirectory(), (f) => host.getCanonicalFileName(f));
        }
        function getDeclarationEmitOutputFilePathWorker(fileName, options, currentDirectory, commonSourceDirectory, getCanonicalFileName) {
            const outputDir = options.declarationDir || options.outDir;
            const path = outputDir ? getSourceFilePathInNewDirWorker(fileName, outputDir, currentDirectory, commonSourceDirectory, getCanonicalFileName) : fileName;
            const declarationExtension = getDeclarationEmitExtensionForPath(path);
            return removeFileExtension(path) + declarationExtension;
        }
        function getDeclarationEmitExtensionForPath(path) {
            return fileExtensionIsOneOf(path, [".mjs" /* Mjs */, ".mts" /* Mts */]) ? ".d.mts" /* Dmts */ : fileExtensionIsOneOf(path, [".cjs" /* Cjs */, ".cts" /* Cts */]) ? ".d.cts" /* Dcts */ : fileExtensionIsOneOf(path, [".json" /* Json */]) ? `.d.json.ts` : (
            // Drive-by redefinition of json declaration file output name so if it's ever enabled, it behaves well
            ".d.ts" /* Dts */);
        }
        function getPossibleOriginalInputExtensionForExtension(path) {
            return fileExtensionIsOneOf(path, [".d.mts" /* Dmts */, ".mjs" /* Mjs */, ".mts" /* Mts */]) ? [".mts" /* Mts */, ".mjs" /* Mjs */] : fileExtensionIsOneOf(path, [".d.cts" /* Dcts */, ".cjs" /* Cjs */, ".cts" /* Cts */]) ? [".cts" /* Cts */, ".cjs" /* Cjs */] : fileExtensionIsOneOf(path, [`.d.json.ts`]) ? [".json" /* Json */] : [".tsx" /* Tsx */, ".ts" /* Ts */, ".jsx" /* Jsx */, ".js" /* Js */];
        }
        function outFile(options) {
            return options.outFile || options.out;
        }
        function getPathsBasePath(options, host) {
            var _a2, _b;
            if (!options.paths)
                return void 0;
            return (_b = options.baseUrl) != null ? _b : Debug.checkDefined(options.pathsBasePath || ((_a2 = host.getCurrentDirectory) == null ? void 0 : _a2.call(host)), "Encountered 'paths' without a 'baseUrl', config file, or host 'getCurrentDirectory'.");
        }
        function getSourceFilesToEmit(host, targetSourceFile, forceDtsEmit) {
            const options = host.getCompilerOptions();
            if (outFile(options)) {
                const moduleKind = getEmitModuleKind(options);
                const moduleEmitEnabled = options.emitDeclarationOnly || moduleKind === 2 /* AMD */ || moduleKind === 4 /* System */;
                return filter(host.getSourceFiles(), (sourceFile) => (moduleEmitEnabled || !isExternalModule(sourceFile)) && sourceFileMayBeEmitted(sourceFile, host, forceDtsEmit));
            }
            else {
                const sourceFiles = targetSourceFile === void 0 ? host.getSourceFiles() : [targetSourceFile];
                return filter(sourceFiles, (sourceFile) => sourceFileMayBeEmitted(sourceFile, host, forceDtsEmit));
            }
        }
        function sourceFileMayBeEmitted(sourceFile, host, forceDtsEmit) {
            const options = host.getCompilerOptions();
            return !(options.noEmitForJsFiles && isSourceFileJS(sourceFile)) && !sourceFile.isDeclarationFile && !host.isSourceFileFromExternalLibrary(sourceFile) && (forceDtsEmit || !(isJsonSourceFile(sourceFile) && host.getResolvedProjectReferenceToRedirect(sourceFile.fileName)) && !host.isSourceOfProjectReferenceRedirect(sourceFile.fileName));
        }
        function getSourceFilePathInNewDir(fileName, host, newDirPath) {
            return getSourceFilePathInNewDirWorker(fileName, newDirPath, host.getCurrentDirectory(), host.getCommonSourceDirectory(), (f) => host.getCanonicalFileName(f));
        }
        function getSourceFilePathInNewDirWorker(fileName, newDirPath, currentDirectory, commonSourceDirectory, getCanonicalFileName) {
            let sourceFilePath = getNormalizedAbsolutePath(fileName, currentDirectory);
            const isSourceFileInCommonSourceDirectory = getCanonicalFileName(sourceFilePath).indexOf(getCanonicalFileName(commonSourceDirectory)) === 0;
            sourceFilePath = isSourceFileInCommonSourceDirectory ? sourceFilePath.substring(commonSourceDirectory.length) : sourceFilePath;
            return combinePaths(newDirPath, sourceFilePath);
        }
        function writeFile(host, diagnostics, fileName, text, writeByteOrderMark, sourceFiles, data) {
            host.writeFile(fileName, text, writeByteOrderMark, (hostErrorMessage) => {
                diagnostics.add(createCompilerDiagnostic(Diagnostics.Could_not_write_file_0_Colon_1, fileName, hostErrorMessage));
            }, sourceFiles, data);
        }
        function ensureDirectoriesExist(directoryPath, createDirectory, directoryExists) {
            if (directoryPath.length > getRootLength(directoryPath) && !directoryExists(directoryPath)) {
                const parentDirectory = getDirectoryPath(directoryPath);
                ensureDirectoriesExist(parentDirectory, createDirectory, directoryExists);
                createDirectory(directoryPath);
            }
        }
        function writeFileEnsuringDirectories(path, data, writeByteOrderMark, writeFile2, createDirectory, directoryExists) {
            try {
                writeFile2(path, data, writeByteOrderMark);
            }
            catch (e) {
                ensureDirectoriesExist(getDirectoryPath(normalizePath(path)), createDirectory, directoryExists);
                writeFile2(path, data, writeByteOrderMark);
            }
        }
        function getLineOfLocalPosition(sourceFile, pos) {
            const lineStarts = getLineStarts(sourceFile);
            return computeLineOfPosition(lineStarts, pos);
        }
        function getLineOfLocalPositionFromLineMap(lineMap, pos) {
            return computeLineOfPosition(lineMap, pos);
        }
        function getFirstConstructorWithBody(node) {
            return find(node.members, (member) => isConstructorDeclaration(member) && nodeIsPresent(member.body));
        }
        function getSetAccessorValueParameter(accessor) {
            if (accessor && accessor.parameters.length > 0) {
                const hasThis = accessor.parameters.length === 2 && parameterIsThisKeyword(accessor.parameters[0]);
                return accessor.parameters[hasThis ? 1 : 0];
            }
        }
        function getSetAccessorTypeAnnotationNode(accessor) {
            const parameter = getSetAccessorValueParameter(accessor);
            return parameter && parameter.type;
        }
        function getThisParameter(signature) {
            if (signature.parameters.length && !isJSDocSignature(signature)) {
                const thisParameter = signature.parameters[0];
                if (parameterIsThisKeyword(thisParameter)) {
                    return thisParameter;
                }
            }
        }
        function parameterIsThisKeyword(parameter) {
            return isThisIdentifier(parameter.name);
        }
        function isThisIdentifier(node) {
            return !!node && node.kind === 79 /* Identifier */ && identifierIsThisKeyword(node);
        }
        function isThisInTypeQuery(node) {
            if (!isThisIdentifier(node)) {
                return false;
            }
            while (isQualifiedName(node.parent) && node.parent.left === node) {
                node = node.parent;
            }
            return node.parent.kind === 183 /* TypeQuery */;
        }
        function identifierIsThisKeyword(id) {
            return id.escapedText === "this";
        }
        function getAllAccessorDeclarations(declarations, accessor) {
            let firstAccessor;
            let secondAccessor;
            let getAccessor;
            let setAccessor;
            if (hasDynamicName(accessor)) {
                firstAccessor = accessor;
                if (accessor.kind === 174 /* GetAccessor */) {
                    getAccessor = accessor;
                }
                else if (accessor.kind === 175 /* SetAccessor */) {
                    setAccessor = accessor;
                }
                else {
                    Debug.fail("Accessor has wrong kind");
                }
            }
            else {
                forEach(declarations, (member) => {
                    if (isAccessor(member) && isStatic(member) === isStatic(accessor)) {
                        const memberName = getPropertyNameForPropertyNameNode(member.name);
                        const accessorName = getPropertyNameForPropertyNameNode(accessor.name);
                        if (memberName === accessorName) {
                            if (!firstAccessor) {
                                firstAccessor = member;
                            }
                            else if (!secondAccessor) {
                                secondAccessor = member;
                            }
                            if (member.kind === 174 /* GetAccessor */ && !getAccessor) {
                                getAccessor = member;
                            }
                            if (member.kind === 175 /* SetAccessor */ && !setAccessor) {
                                setAccessor = member;
                            }
                        }
                    }
                });
            }
            return {
                firstAccessor,
                secondAccessor,
                getAccessor,
                setAccessor
            };
        }
        function getEffectiveTypeAnnotationNode(node) {
            if (!isInJSFile(node) && isFunctionDeclaration(node))
                return void 0;
            const type = node.type;
            if (type || !isInJSFile(node))
                return type;
            return isJSDocPropertyLikeTag(node) ? node.typeExpression && node.typeExpression.type : getJSDocType(node);
        }
        function getTypeAnnotationNode(node) {
            return node.type;
        }
        function getEffectiveReturnTypeNode(node) {
            return isJSDocSignature(node) ? node.type && node.type.typeExpression && node.type.typeExpression.type : node.type || (isInJSFile(node) ? getJSDocReturnType(node) : void 0);
        }
        function getJSDocTypeParameterDeclarations(node) {
            return flatMap(getJSDocTags(node), (tag) => isNonTypeAliasTemplate(tag) ? tag.typeParameters : void 0);
        }
        function isNonTypeAliasTemplate(tag) {
            return isJSDocTemplateTag(tag) && !(tag.parent.kind === 323 /* JSDoc */ && (tag.parent.tags.some(isJSDocTypeAlias) || tag.parent.tags.some(isJSDocOverloadTag)));
        }
        function getEffectiveSetAccessorTypeAnnotationNode(node) {
            const parameter = getSetAccessorValueParameter(node);
            return parameter && getEffectiveTypeAnnotationNode(parameter);
        }
        function emitNewLineBeforeLeadingComments(lineMap, writer, node, leadingComments) {
            emitNewLineBeforeLeadingCommentsOfPosition(lineMap, writer, node.pos, leadingComments);
        }
        function emitNewLineBeforeLeadingCommentsOfPosition(lineMap, writer, pos, leadingComments) {
            if (leadingComments && leadingComments.length && pos !== leadingComments[0].pos && getLineOfLocalPositionFromLineMap(lineMap, pos) !== getLineOfLocalPositionFromLineMap(lineMap, leadingComments[0].pos)) {
                writer.writeLine();
            }
        }
        function emitNewLineBeforeLeadingCommentOfPosition(lineMap, writer, pos, commentPos) {
            if (pos !== commentPos && getLineOfLocalPositionFromLineMap(lineMap, pos) !== getLineOfLocalPositionFromLineMap(lineMap, commentPos)) {
                writer.writeLine();
            }
        }
        function emitComments(text, lineMap, writer, comments, leadingSeparator, trailingSeparator, newLine, writeComment) {
            if (comments && comments.length > 0) {
                if (leadingSeparator) {
                    writer.writeSpace(" ");
                }
                let emitInterveningSeparator = false;
                for (const comment of comments) {
                    if (emitInterveningSeparator) {
                        writer.writeSpace(" ");
                        emitInterveningSeparator = false;
                    }
                    writeComment(text, lineMap, writer, comment.pos, comment.end, newLine);
                    if (comment.hasTrailingNewLine) {
                        writer.writeLine();
                    }
                    else {
                        emitInterveningSeparator = true;
                    }
                }
                if (emitInterveningSeparator && trailingSeparator) {
                    writer.writeSpace(" ");
                }
            }
        }
        function emitDetachedComments(text, lineMap, writer, writeComment, node, newLine, removeComments) {
            let leadingComments;
            let currentDetachedCommentInfo;
            if (removeComments) {
                if (node.pos === 0) {
                    leadingComments = filter(getLeadingCommentRanges(text, node.pos), isPinnedCommentLocal);
                }
            }
            else {
                leadingComments = getLeadingCommentRanges(text, node.pos);
            }
            if (leadingComments) {
                const detachedComments = [];
                let lastComment;
                for (const comment of leadingComments) {
                    if (lastComment) {
                        const lastCommentLine = getLineOfLocalPositionFromLineMap(lineMap, lastComment.end);
                        const commentLine = getLineOfLocalPositionFromLineMap(lineMap, comment.pos);
                        if (commentLine >= lastCommentLine + 2) {
                            break;
                        }
                    }
                    detachedComments.push(comment);
                    lastComment = comment;
                }
                if (detachedComments.length) {
                    const lastCommentLine = getLineOfLocalPositionFromLineMap(lineMap, last(detachedComments).end);
                    const nodeLine = getLineOfLocalPositionFromLineMap(lineMap, skipTrivia(text, node.pos));
                    if (nodeLine >= lastCommentLine + 2) {
                        emitNewLineBeforeLeadingComments(lineMap, writer, node, leadingComments);
                        emitComments(text, lineMap, writer, detachedComments, 
                        /*leadingSeparator*/
                        false, 
                        /*trailingSeparator*/
                        true, newLine, writeComment);
                        currentDetachedCommentInfo = { nodePos: node.pos, detachedCommentEndPos: last(detachedComments).end };
                    }
                }
            }
            return currentDetachedCommentInfo;
            function isPinnedCommentLocal(comment) {
                return isPinnedComment(text, comment.pos);
            }
        }
        function writeCommentRange(text, lineMap, writer, commentPos, commentEnd, newLine) {
            if (text.charCodeAt(commentPos + 1) === 42 /* asterisk */) {
                const firstCommentLineAndCharacter = computeLineAndCharacterOfPosition(lineMap, commentPos);
                const lineCount = lineMap.length;
                let firstCommentLineIndent;
                for (let pos = commentPos, currentLine = firstCommentLineAndCharacter.line; pos < commentEnd; currentLine++) {
                    const nextLineStart = currentLine + 1 === lineCount ? text.length + 1 : lineMap[currentLine + 1];
                    if (pos !== commentPos) {
                        if (firstCommentLineIndent === void 0) {
                            firstCommentLineIndent = calculateIndent(text, lineMap[firstCommentLineAndCharacter.line], commentPos);
                        }
                        const currentWriterIndentSpacing = writer.getIndent() * getIndentSize();
                        const spacesToEmit = currentWriterIndentSpacing - firstCommentLineIndent + calculateIndent(text, pos, nextLineStart);
                        if (spacesToEmit > 0) {
                            let numberOfSingleSpacesToEmit = spacesToEmit % getIndentSize();
                            const indentSizeSpaceString = getIndentString((spacesToEmit - numberOfSingleSpacesToEmit) / getIndentSize());
                            writer.rawWrite(indentSizeSpaceString);
                            while (numberOfSingleSpacesToEmit) {
                                writer.rawWrite(" ");
                                numberOfSingleSpacesToEmit--;
                            }
                        }
                        else {
                            writer.rawWrite("");
                        }
                    }
                    writeTrimmedCurrentLine(text, commentEnd, writer, newLine, pos, nextLineStart);
                    pos = nextLineStart;
                }
            }
            else {
                writer.writeComment(text.substring(commentPos, commentEnd));
            }
        }
        function writeTrimmedCurrentLine(text, commentEnd, writer, newLine, pos, nextLineStart) {
            const end = Math.min(commentEnd, nextLineStart - 1);
            const currentLineText = trimString(text.substring(pos, end));
            if (currentLineText) {
                writer.writeComment(currentLineText);
                if (end !== commentEnd) {
                    writer.writeLine();
                }
            }
            else {
                writer.rawWrite(newLine);
            }
        }
        function calculateIndent(text, pos, end) {
            let currentLineIndent = 0;
            for (; pos < end && isWhiteSpaceSingleLine(text.charCodeAt(pos)); pos++) {
                if (text.charCodeAt(pos) === 9 /* tab */) {
                    currentLineIndent += getIndentSize() - currentLineIndent % getIndentSize();
                }
                else {
                    currentLineIndent++;
                }
            }
            return currentLineIndent;
        }
        function hasEffectiveModifiers(node) {
            return getEffectiveModifierFlags(node) !== 0 /* None */;
        }
        function hasSyntacticModifiers(node) {
            return getSyntacticModifierFlags(node) !== 0 /* None */;
        }
        function hasEffectiveModifier(node, flags) {
            return !!getSelectedEffectiveModifierFlags(node, flags);
        }
        function hasSyntacticModifier(node, flags) {
            return !!getSelectedSyntacticModifierFlags(node, flags);
        }
        function isStatic(node) {
            return isClassElement(node) && hasStaticModifier(node) || isClassStaticBlockDeclaration(node);
        }
        function hasStaticModifier(node) {
            return hasSyntacticModifier(node, 32 /* Static */);
        }
        function hasOverrideModifier(node) {
            return hasEffectiveModifier(node, 16384 /* Override */);
        }
        function hasAbstractModifier(node) {
            return hasSyntacticModifier(node, 256 /* Abstract */);
        }
        function hasAmbientModifier(node) {
            return hasSyntacticModifier(node, 2 /* Ambient */);
        }
        function hasAccessorModifier(node) {
            return hasSyntacticModifier(node, 128 /* Accessor */);
        }
        function hasEffectiveReadonlyModifier(node) {
            return hasEffectiveModifier(node, 64 /* Readonly */);
        }
        function hasDecorators(node) {
            return hasSyntacticModifier(node, 131072 /* Decorator */);
        }
        function getSelectedEffectiveModifierFlags(node, flags) {
            return getEffectiveModifierFlags(node) & flags;
        }
        function getSelectedSyntacticModifierFlags(node, flags) {
            return getSyntacticModifierFlags(node) & flags;
        }
        function getModifierFlagsWorker(node, includeJSDoc, alwaysIncludeJSDoc) {
            if (node.kind >= 0 /* FirstToken */ && node.kind <= 162 /* LastToken */) {
                return 0 /* None */;
            }
            if (!(node.modifierFlagsCache & 536870912 /* HasComputedFlags */)) {
                node.modifierFlagsCache = getSyntacticModifierFlagsNoCache(node) | 536870912 /* HasComputedFlags */;
            }
            if (includeJSDoc && !(node.modifierFlagsCache & 4096 /* HasComputedJSDocModifiers */) && (alwaysIncludeJSDoc || isInJSFile(node)) && node.parent) {
                node.modifierFlagsCache |= getJSDocModifierFlagsNoCache(node) | 4096 /* HasComputedJSDocModifiers */;
            }
            return node.modifierFlagsCache & ~(536870912 /* HasComputedFlags */ | 4096 /* HasComputedJSDocModifiers */);
        }
        function getEffectiveModifierFlags(node) {
            return getModifierFlagsWorker(node, 
            /*includeJSDoc*/
            true);
        }
        function getEffectiveModifierFlagsAlwaysIncludeJSDoc(node) {
            return getModifierFlagsWorker(node, 
            /*includeJSDOc*/
            true, 
            /*alwaysIncludeJSDOc*/
            true);
        }
        function getSyntacticModifierFlags(node) {
            return getModifierFlagsWorker(node, 
            /*includeJSDoc*/
            false);
        }
        function getJSDocModifierFlagsNoCache(node) {
            let flags = 0 /* None */;
            if (!!node.parent && !isParameter(node)) {
                if (isInJSFile(node)) {
                    if (getJSDocPublicTagNoCache(node))
                        flags |= 4 /* Public */;
                    if (getJSDocPrivateTagNoCache(node))
                        flags |= 8 /* Private */;
                    if (getJSDocProtectedTagNoCache(node))
                        flags |= 16 /* Protected */;
                    if (getJSDocReadonlyTagNoCache(node))
                        flags |= 64 /* Readonly */;
                    if (getJSDocOverrideTagNoCache(node))
                        flags |= 16384 /* Override */;
                }
                if (getJSDocDeprecatedTagNoCache(node))
                    flags |= 8192 /* Deprecated */;
            }
            return flags;
        }
        function getEffectiveModifierFlagsNoCache(node) {
            return getSyntacticModifierFlagsNoCache(node) | getJSDocModifierFlagsNoCache(node);
        }
        function getSyntacticModifierFlagsNoCache(node) {
            let flags = canHaveModifiers(node) ? modifiersToFlags(node.modifiers) : 0 /* None */;
            if (node.flags & 4 /* NestedNamespace */ || node.kind === 79 /* Identifier */ && node.flags & 2048 /* IdentifierIsInJSDocNamespace */) {
                flags |= 1 /* Export */;
            }
            return flags;
        }
        function modifiersToFlags(modifiers) {
            let flags = 0 /* None */;
            if (modifiers) {
                for (const modifier of modifiers) {
                    flags |= modifierToFlag(modifier.kind);
                }
            }
            return flags;
        }
        function modifierToFlag(token) {
            switch (token) {
                case 124 /* StaticKeyword */:
                    return 32 /* Static */;
                case 123 /* PublicKeyword */:
                    return 4 /* Public */;
                case 122 /* ProtectedKeyword */:
                    return 16 /* Protected */;
                case 121 /* PrivateKeyword */:
                    return 8 /* Private */;
                case 126 /* AbstractKeyword */:
                    return 256 /* Abstract */;
                case 127 /* AccessorKeyword */:
                    return 128 /* Accessor */;
                case 93 /* ExportKeyword */:
                    return 1 /* Export */;
                case 136 /* DeclareKeyword */:
                    return 2 /* Ambient */;
                case 85 /* ConstKeyword */:
                    return 2048 /* Const */;
                case 88 /* DefaultKeyword */:
                    return 1024 /* Default */;
                case 132 /* AsyncKeyword */:
                    return 512 /* Async */;
                case 146 /* ReadonlyKeyword */:
                    return 64 /* Readonly */;
                case 161 /* OverrideKeyword */:
                    return 16384 /* Override */;
                case 101 /* InKeyword */:
                    return 32768 /* In */;
                case 145 /* OutKeyword */:
                    return 65536 /* Out */;
                case 167 /* Decorator */:
                    return 131072 /* Decorator */;
            }
            return 0 /* None */;
        }
        function isBinaryLogicalOperator(token) {
            return token === 56 /* BarBarToken */ || token === 55 /* AmpersandAmpersandToken */;
        }
        function isLogicalOperator(token) {
            return isBinaryLogicalOperator(token) || token === 53 /* ExclamationToken */;
        }
        function isLogicalOrCoalescingAssignmentOperator(token) {
            return token === 75 /* BarBarEqualsToken */ || token === 76 /* AmpersandAmpersandEqualsToken */ || token === 77 /* QuestionQuestionEqualsToken */;
        }
        function isLogicalOrCoalescingAssignmentExpression(expr) {
            return isBinaryExpression(expr) && isLogicalOrCoalescingAssignmentOperator(expr.operatorToken.kind);
        }
        function isLogicalOrCoalescingBinaryOperator(token) {
            return isBinaryLogicalOperator(token) || token === 60 /* QuestionQuestionToken */;
        }
        function isLogicalOrCoalescingBinaryExpression(expr) {
            return isBinaryExpression(expr) && isLogicalOrCoalescingBinaryOperator(expr.operatorToken.kind);
        }
        function isAssignmentOperator(token) {
            return token >= 63 /* FirstAssignment */ && token <= 78 /* LastAssignment */;
        }
        function tryGetClassExtendingExpressionWithTypeArguments(node) {
            const cls = tryGetClassImplementingOrExtendingExpressionWithTypeArguments(node);
            return cls && !cls.isImplements ? cls.class : void 0;
        }
        function tryGetClassImplementingOrExtendingExpressionWithTypeArguments(node) {
            if (isExpressionWithTypeArguments(node)) {
                if (isHeritageClause(node.parent) && isClassLike(node.parent.parent)) {
                    return { class: node.parent.parent, isImplements: node.parent.token === 117 /* ImplementsKeyword */ };
                }
                if (isJSDocAugmentsTag(node.parent)) {
                    const host = getEffectiveJSDocHost(node.parent);
                    if (host && isClassLike(host)) {
                        return { class: host, isImplements: false };
                    }
                }
            }
            return void 0;
        }
        function isAssignmentExpression(node, excludeCompoundAssignment) {
            return isBinaryExpression(node) && (excludeCompoundAssignment ? node.operatorToken.kind === 63 /* EqualsToken */ : isAssignmentOperator(node.operatorToken.kind)) && isLeftHandSideExpression(node.left);
        }
        function isLeftHandSideOfAssignment(node) {
            return isAssignmentExpression(node.parent) && node.parent.left === node;
        }
        function isDestructuringAssignment(node) {
            if (isAssignmentExpression(node, 
            /*excludeCompoundAssignment*/
            true)) {
                const kind = node.left.kind;
                return kind === 207 /* ObjectLiteralExpression */ || kind === 206 /* ArrayLiteralExpression */;
            }
            return false;
        }
        function isExpressionWithTypeArgumentsInClassExtendsClause(node) {
            return tryGetClassExtendingExpressionWithTypeArguments(node) !== void 0;
        }
        function isEntityNameExpression(node) {
            return node.kind === 79 /* Identifier */ || isPropertyAccessEntityNameExpression(node);
        }
        function getFirstIdentifier(node) {
            switch (node.kind) {
                case 79 /* Identifier */:
                    return node;
                case 163 /* QualifiedName */:
                    do {
                        node = node.left;
                    } while (node.kind !== 79 /* Identifier */);
                    return node;
                case 208 /* PropertyAccessExpression */:
                    do {
                        node = node.expression;
                    } while (node.kind !== 79 /* Identifier */);
                    return node;
            }
        }
        function isDottedName(node) {
            return node.kind === 79 /* Identifier */ || node.kind === 108 /* ThisKeyword */ || node.kind === 106 /* SuperKeyword */ || node.kind === 233 /* MetaProperty */ || node.kind === 208 /* PropertyAccessExpression */ && isDottedName(node.expression) || node.kind === 214 /* ParenthesizedExpression */ && isDottedName(node.expression);
        }
        function isPropertyAccessEntityNameExpression(node) {
            return isPropertyAccessExpression(node) && isIdentifier(node.name) && isEntityNameExpression(node.expression);
        }
        function tryGetPropertyAccessOrIdentifierToString(expr) {
            if (isPropertyAccessExpression(expr)) {
                const baseStr = tryGetPropertyAccessOrIdentifierToString(expr.expression);
                if (baseStr !== void 0) {
                    return baseStr + "." + entityNameToString(expr.name);
                }
            }
            else if (isElementAccessExpression(expr)) {
                const baseStr = tryGetPropertyAccessOrIdentifierToString(expr.expression);
                if (baseStr !== void 0 && isPropertyName(expr.argumentExpression)) {
                    return baseStr + "." + getPropertyNameForPropertyNameNode(expr.argumentExpression);
                }
            }
            else if (isIdentifier(expr)) {
                return unescapeLeadingUnderscores(expr.escapedText);
            }
            return void 0;
        }
        function isPrototypeAccess(node) {
            return isBindableStaticAccessExpression(node) && getElementOrPropertyAccessName(node) === "prototype";
        }
        function isRightSideOfQualifiedNameOrPropertyAccess(node) {
            return node.parent.kind === 163 /* QualifiedName */ && node.parent.right === node || node.parent.kind === 208 /* PropertyAccessExpression */ && node.parent.name === node;
        }
        function isRightSideOfAccessExpression(node) {
            return isPropertyAccessExpression(node.parent) && node.parent.name === node || isElementAccessExpression(node.parent) && node.parent.argumentExpression === node;
        }
        function isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName(node) {
            return isQualifiedName(node.parent) && node.parent.right === node || isPropertyAccessExpression(node.parent) && node.parent.name === node || isJSDocMemberName(node.parent) && node.parent.right === node;
        }
        function isEmptyObjectLiteral(expression) {
            return expression.kind === 207 /* ObjectLiteralExpression */ && expression.properties.length === 0;
        }
        function isEmptyArrayLiteral(expression) {
            return expression.kind === 206 /* ArrayLiteralExpression */ && expression.elements.length === 0;
        }
        function getLocalSymbolForExportDefault(symbol) {
            if (!isExportDefaultSymbol(symbol) || !symbol.declarations)
                return void 0;
            for (const decl of symbol.declarations) {
                if (decl.localSymbol)
                    return decl.localSymbol;
            }
            return void 0;
        }
        function isExportDefaultSymbol(symbol) {
            return symbol && length(symbol.declarations) > 0 && hasSyntacticModifier(symbol.declarations[0], 1024 /* Default */);
        }
        function tryExtractTSExtension(fileName) {
            return find(supportedTSExtensionsForExtractExtension, (extension) => fileExtensionIs(fileName, extension));
        }
        function getExpandedCharCodes(input) {
            const output = [];
            const length2 = input.length;
            for (let i = 0; i < length2; i++) {
                const charCode = input.charCodeAt(i);
                if (charCode < 128) {
                    output.push(charCode);
                }
                else if (charCode < 2048) {
                    output.push(charCode >> 6 | 192);
                    output.push(charCode & 63 | 128);
                }
                else if (charCode < 65536) {
                    output.push(charCode >> 12 | 224);
                    output.push(charCode >> 6 & 63 | 128);
                    output.push(charCode & 63 | 128);
                }
                else if (charCode < 131072) {
                    output.push(charCode >> 18 | 240);
                    output.push(charCode >> 12 & 63 | 128);
                    output.push(charCode >> 6 & 63 | 128);
                    output.push(charCode & 63 | 128);
                }
                else {
                    Debug.assert(false, "Unexpected code point");
                }
            }
            return output;
        }
        function convertToBase64(input) {
            let result = "";
            const charCodes = getExpandedCharCodes(input);
            let i = 0;
            const length2 = charCodes.length;
            let byte1, byte2, byte3, byte4;
            while (i < length2) {
                byte1 = charCodes[i] >> 2;
                byte2 = (charCodes[i] & 3) << 4 | charCodes[i + 1] >> 4;
                byte3 = (charCodes[i + 1] & 15) << 2 | charCodes[i + 2] >> 6;
                byte4 = charCodes[i + 2] & 63;
                if (i + 1 >= length2) {
                    byte3 = byte4 = 64;
                }
                else if (i + 2 >= length2) {
                    byte4 = 64;
                }
                result += base64Digits.charAt(byte1) + base64Digits.charAt(byte2) + base64Digits.charAt(byte3) + base64Digits.charAt(byte4);
                i += 3;
            }
            return result;
        }
        function getStringFromExpandedCharCodes(codes) {
            let output = "";
            let i = 0;
            const length2 = codes.length;
            while (i < length2) {
                const charCode = codes[i];
                if (charCode < 128) {
                    output += String.fromCharCode(charCode);
                    i++;
                }
                else if ((charCode & 192) === 192) {
                    let value = charCode & 63;
                    i++;
                    let nextCode = codes[i];
                    while ((nextCode & 192) === 128) {
                        value = value << 6 | nextCode & 63;
                        i++;
                        nextCode = codes[i];
                    }
                    output += String.fromCharCode(value);
                }
                else {
                    output += String.fromCharCode(charCode);
                    i++;
                }
            }
            return output;
        }
        function base64encode(host, input) {
            if (host && host.base64encode) {
                return host.base64encode(input);
            }
            return convertToBase64(input);
        }
        function base64decode(host, input) {
            if (host && host.base64decode) {
                return host.base64decode(input);
            }
            const length2 = input.length;
            const expandedCharCodes = [];
            let i = 0;
            while (i < length2) {
                if (input.charCodeAt(i) === base64Digits.charCodeAt(64)) {
                    break;
                }
                const ch1 = base64Digits.indexOf(input[i]);
                const ch2 = base64Digits.indexOf(input[i + 1]);
                const ch3 = base64Digits.indexOf(input[i + 2]);
                const ch4 = base64Digits.indexOf(input[i + 3]);
                const code1 = (ch1 & 63) << 2 | ch2 >> 4 & 3;
                const code2 = (ch2 & 15) << 4 | ch3 >> 2 & 15;
                const code3 = (ch3 & 3) << 6 | ch4 & 63;
                if (code2 === 0 && ch3 !== 0) {
                    expandedCharCodes.push(code1);
                }
                else if (code3 === 0 && ch4 !== 0) {
                    expandedCharCodes.push(code1, code2);
                }
                else {
                    expandedCharCodes.push(code1, code2, code3);
                }
                i += 4;
            }
            return getStringFromExpandedCharCodes(expandedCharCodes);
        }
        function readJsonOrUndefined(path, hostOrText) {
            const jsonText = isString(hostOrText) ? hostOrText : hostOrText.readFile(path);
            if (!jsonText)
                return void 0;
            const result = parseConfigFileTextToJson(path, jsonText);
            return !result.error ? result.config : void 0;
        }
        function readJson(path, host) {
            return readJsonOrUndefined(path, host) || {};
        }
        function directoryProbablyExists(directoryName, host) {
            return !host.directoryExists || host.directoryExists(directoryName);
        }
        function getNewLineCharacter(options) {
            switch (options.newLine) {
                case 0 /* CarriageReturnLineFeed */:
                    return carriageReturnLineFeed;
                case 1 /* LineFeed */:
                case void 0:
                    return lineFeed;
            }
        }
        function createRange(pos, end = pos) {
            Debug.assert(end >= pos || end === -1);
            return { pos, end };
        }
        function moveRangeEnd(range, end) {
            return createRange(range.pos, end);
        }
        function moveRangePos(range, pos) {
            return createRange(pos, range.end);
        }
        function moveRangePastDecorators(node) {
            const lastDecorator = canHaveModifiers(node) ? findLast(node.modifiers, isDecorator) : void 0;
            return lastDecorator && !positionIsSynthesized(lastDecorator.end) ? moveRangePos(node, lastDecorator.end) : node;
        }
        function moveRangePastModifiers(node) {
            if (isPropertyDeclaration(node) || isMethodDeclaration(node)) {
                return moveRangePos(node, node.name.pos);
            }
            const lastModifier = canHaveModifiers(node) ? lastOrUndefined(node.modifiers) : void 0;
            return lastModifier && !positionIsSynthesized(lastModifier.end) ? moveRangePos(node, lastModifier.end) : moveRangePastDecorators(node);
        }
        function isCollapsedRange(range) {
            return range.pos === range.end;
        }
        function createTokenRange(pos, token) {
            return createRange(pos, pos + tokenToString(token).length);
        }
        function rangeIsOnSingleLine(range, sourceFile) {
            return rangeStartIsOnSameLineAsRangeEnd(range, range, sourceFile);
        }
        function rangeStartPositionsAreOnSameLine(range1, range2, sourceFile) {
            return positionsAreOnSameLine(getStartPositionOfRange(range1, sourceFile, 
            /*includeComments*/
            false), getStartPositionOfRange(range2, sourceFile, 
            /*includeComments*/
            false), sourceFile);
        }
        function rangeEndPositionsAreOnSameLine(range1, range2, sourceFile) {
            return positionsAreOnSameLine(range1.end, range2.end, sourceFile);
        }
        function rangeStartIsOnSameLineAsRangeEnd(range1, range2, sourceFile) {
            return positionsAreOnSameLine(getStartPositionOfRange(range1, sourceFile, 
            /*includeComments*/
            false), range2.end, sourceFile);
        }
        function rangeEndIsOnSameLineAsRangeStart(range1, range2, sourceFile) {
            return positionsAreOnSameLine(range1.end, getStartPositionOfRange(range2, sourceFile, 
            /*includeComments*/
            false), sourceFile);
        }
        function getLinesBetweenRangeEndAndRangeStart(range1, range2, sourceFile, includeSecondRangeComments) {
            const range2Start = getStartPositionOfRange(range2, sourceFile, includeSecondRangeComments);
            return getLinesBetweenPositions(sourceFile, range1.end, range2Start);
        }
        function getLinesBetweenRangeEndPositions(range1, range2, sourceFile) {
            return getLinesBetweenPositions(sourceFile, range1.end, range2.end);
        }
        function isNodeArrayMultiLine(list, sourceFile) {
            return !positionsAreOnSameLine(list.pos, list.end, sourceFile);
        }
        function positionsAreOnSameLine(pos1, pos2, sourceFile) {
            return getLinesBetweenPositions(sourceFile, pos1, pos2) === 0;
        }
        function getStartPositionOfRange(range, sourceFile, includeComments) {
            return positionIsSynthesized(range.pos) ? -1 : skipTrivia(sourceFile.text, range.pos, 
            /*stopAfterLineBreak*/
            false, includeComments);
        }
        function getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter(pos, stopPos, sourceFile, includeComments) {
            const startPos = skipTrivia(sourceFile.text, pos, 
            /*stopAfterLineBreak*/
            false, includeComments);
            const prevPos = getPreviousNonWhitespacePosition(startPos, stopPos, sourceFile);
            return getLinesBetweenPositions(sourceFile, prevPos != null ? prevPos : stopPos, startPos);
        }
        function getLinesBetweenPositionAndNextNonWhitespaceCharacter(pos, stopPos, sourceFile, includeComments) {
            const nextPos = skipTrivia(sourceFile.text, pos, 
            /*stopAfterLineBreak*/
            false, includeComments);
            return getLinesBetweenPositions(sourceFile, pos, Math.min(stopPos, nextPos));
        }
        function getPreviousNonWhitespacePosition(pos, stopPos = 0, sourceFile) {
            while (pos-- > stopPos) {
                if (!isWhiteSpaceLike(sourceFile.text.charCodeAt(pos))) {
                    return pos;
                }
            }
        }
        function isDeclarationNameOfEnumOrNamespace(node) {
            const parseNode = getParseTreeNode(node);
            if (parseNode) {
                switch (parseNode.parent.kind) {
                    case 263 /* EnumDeclaration */:
                    case 264 /* ModuleDeclaration */:
                        return parseNode === parseNode.parent.name;
                }
            }
            return false;
        }
        function getInitializedVariables(node) {
            return filter(node.declarations, isInitializedVariable);
        }
        function isInitializedVariable(node) {
            return isVariableDeclaration(node) && node.initializer !== void 0;
        }
        function isWatchSet(options) {
            return options.watch && hasProperty(options, "watch");
        }
        function closeFileWatcher(watcher) {
            watcher.close();
        }
        function getCheckFlags(symbol) {
            return symbol.flags & 33554432 /* Transient */ ? symbol.links.checkFlags : 0;
        }
        function getDeclarationModifierFlagsFromSymbol(s, isWrite = false) {
            if (s.valueDeclaration) {
                const declaration = isWrite && s.declarations && find(s.declarations, isSetAccessorDeclaration) || s.flags & 32768 /* GetAccessor */ && find(s.declarations, isGetAccessorDeclaration) || s.valueDeclaration;
                const flags = getCombinedModifierFlags(declaration);
                return s.parent && s.parent.flags & 32 /* Class */ ? flags : flags & ~28 /* AccessibilityModifier */;
            }
            if (getCheckFlags(s) & 6 /* Synthetic */) {
                const checkFlags = s.links.checkFlags;
                const accessModifier = checkFlags & 1024 /* ContainsPrivate */ ? 8 /* Private */ : checkFlags & 256 /* ContainsPublic */ ? 4 /* Public */ : 16 /* Protected */;
                const staticModifier = checkFlags & 2048 /* ContainsStatic */ ? 32 /* Static */ : 0;
                return accessModifier | staticModifier;
            }
            if (s.flags & 4194304 /* Prototype */) {
                return 4 /* Public */ | 32 /* Static */;
            }
            return 0;
        }
        function skipAlias(symbol, checker) {
            return symbol.flags & 2097152 /* Alias */ ? checker.getAliasedSymbol(symbol) : symbol;
        }
        function getCombinedLocalAndExportSymbolFlags(symbol) {
            return symbol.exportSymbol ? symbol.exportSymbol.flags | symbol.flags : symbol.flags;
        }
        function isWriteOnlyAccess(node) {
            return accessKind(node) === 1 /* Write */;
        }
        function isWriteAccess(node) {
            return accessKind(node) !== 0 /* Read */;
        }
        function accessKind(node) {
            const { parent: parent2 } = node;
            if (!parent2)
                return 0 /* Read */;
            switch (parent2.kind) {
                case 214 /* ParenthesizedExpression */:
                    return accessKind(parent2);
                case 222 /* PostfixUnaryExpression */:
                case 221 /* PrefixUnaryExpression */:
                    const { operator } = parent2;
                    return operator === 45 /* PlusPlusToken */ || operator === 46 /* MinusMinusToken */ ? writeOrReadWrite() : 0 /* Read */;
                case 223 /* BinaryExpression */:
                    const { left, operatorToken } = parent2;
                    return left === node && isAssignmentOperator(operatorToken.kind) ? operatorToken.kind === 63 /* EqualsToken */ ? 1 /* Write */ : writeOrReadWrite() : 0 /* Read */;
                case 208 /* PropertyAccessExpression */:
                    return parent2.name !== node ? 0 /* Read */ : accessKind(parent2);
                case 299 /* PropertyAssignment */: {
                    const parentAccess = accessKind(parent2.parent);
                    return node === parent2.name ? reverseAccessKind(parentAccess) : parentAccess;
                }
                case 300 /* ShorthandPropertyAssignment */:
                    return node === parent2.objectAssignmentInitializer ? 0 /* Read */ : accessKind(parent2.parent);
                case 206 /* ArrayLiteralExpression */:
                    return accessKind(parent2);
                default:
                    return 0 /* Read */;
            }
            function writeOrReadWrite() {
                return parent2.parent && walkUpParenthesizedExpressions(parent2.parent).kind === 241 /* ExpressionStatement */ ? 1 /* Write */ : 2 /* ReadWrite */;
            }
        }
        function reverseAccessKind(a) {
            switch (a) {
                case 0 /* Read */:
                    return 1 /* Write */;
                case 1 /* Write */:
                    return 0 /* Read */;
                case 2 /* ReadWrite */:
                    return 2 /* ReadWrite */;
                default:
                    return Debug.assertNever(a);
            }
        }
        function compareDataObjects(dst, src) {
            if (!dst || !src || Object.keys(dst).length !== Object.keys(src).length) {
                return false;
            }
            for (const e in dst) {
                if (typeof dst[e] === "object") {
                    if (!compareDataObjects(dst[e], src[e])) {
                        return false;
                    }
                }
                else if (typeof dst[e] !== "function") {
                    if (dst[e] !== src[e]) {
                        return false;
                    }
                }
            }
            return true;
        }
        function clearMap(map2, onDeleteValue) {
            map2.forEach(onDeleteValue);
            map2.clear();
        }
        function mutateMapSkippingNewValues(map2, newMap, options) {
            const { onDeleteValue, onExistingValue } = options;
            map2.forEach((existingValue, key) => {
                const valueInNewMap = newMap.get(key);
                if (valueInNewMap === void 0) {
                    map2.delete(key);
                    onDeleteValue(existingValue, key);
                }
                else if (onExistingValue) {
                    onExistingValue(existingValue, valueInNewMap, key);
                }
            });
        }
        function mutateMap(map2, newMap, options) {
            mutateMapSkippingNewValues(map2, newMap, options);
            const { createNewValue } = options;
            newMap.forEach((valueInNewMap, key) => {
                if (!map2.has(key)) {
                    map2.set(key, createNewValue(key, valueInNewMap));
                }
            });
        }
        function isAbstractConstructorSymbol(symbol) {
            if (symbol.flags & 32 /* Class */) {
                const declaration = getClassLikeDeclarationOfSymbol(symbol);
                return !!declaration && hasSyntacticModifier(declaration, 256 /* Abstract */);
            }
            return false;
        }
        function getClassLikeDeclarationOfSymbol(symbol) {
            var _a2;
            return (_a2 = symbol.declarations) == null ? void 0 : _a2.find(isClassLike);
        }
        function getObjectFlags(type) {
            return type.flags & 3899393 /* ObjectFlagsType */ ? type.objectFlags : 0;
        }
        function forSomeAncestorDirectory(directory, callback) {
            return !!forEachAncestorDirectory(directory, (d) => callback(d) ? true : void 0);
        }
        function isUMDExportSymbol(symbol) {
            return !!symbol && !!symbol.declarations && !!symbol.declarations[0] && isNamespaceExportDeclaration(symbol.declarations[0]);
        }
        function showModuleSpecifier({ moduleSpecifier }) {
            return isStringLiteral(moduleSpecifier) ? moduleSpecifier.text : getTextOfNode(moduleSpecifier);
        }
        function getLastChild(node) {
            let lastChild;
            forEachChild(node, (child) => {
                if (nodeIsPresent(child))
                    lastChild = child;
            }, (children) => {
                for (let i = children.length - 1; i >= 0; i--) {
                    if (nodeIsPresent(children[i])) {
                        lastChild = children[i];
                        break;
                    }
                }
            });
            return lastChild;
        }
        function addToSeen(seen, key, value = true) {
            if (seen.has(key)) {
                return false;
            }
            seen.set(key, value);
            return true;
        }
        function isObjectTypeDeclaration(node) {
            return isClassLike(node) || isInterfaceDeclaration(node) || isTypeLiteralNode(node);
        }
        function isTypeNodeKind(kind) {
            return kind >= 179 /* FirstTypeNode */ && kind <= 202 /* LastTypeNode */ || kind === 131 /* AnyKeyword */ || kind === 157 /* UnknownKeyword */ || kind === 148 /* NumberKeyword */ || kind === 160 /* BigIntKeyword */ || kind === 149 /* ObjectKeyword */ || kind === 134 /* BooleanKeyword */ || kind === 152 /* StringKeyword */ || kind === 153 /* SymbolKeyword */ || kind === 114 /* VoidKeyword */ || kind === 155 /* UndefinedKeyword */ || kind === 144 /* NeverKeyword */ || kind === 139 /* IntrinsicKeyword */ || kind === 230 /* ExpressionWithTypeArguments */ || kind === 315 /* JSDocAllType */ || kind === 316 /* JSDocUnknownType */ || kind === 317 /* JSDocNullableType */ || kind === 318 /* JSDocNonNullableType */ || kind === 319 /* JSDocOptionalType */ || kind === 320 /* JSDocFunctionType */ || kind === 321 /* JSDocVariadicType */;
        }
        function isAccessExpression(node) {
            return node.kind === 208 /* PropertyAccessExpression */ || node.kind === 209 /* ElementAccessExpression */;
        }
        function getNameOfAccessExpression(node) {
            if (node.kind === 208 /* PropertyAccessExpression */) {
                return node.name;
            }
            Debug.assert(node.kind === 209 /* ElementAccessExpression */);
            return node.argumentExpression;
        }
        function isBundleFileTextLike(section) {
            switch (section.kind) {
                case "text" /* Text */:
                case "internal" /* Internal */:
                    return true;
                default:
                    return false;
            }
        }
        function isNamedImportsOrExports(node) {
            return node.kind === 272 /* NamedImports */ || node.kind === 276 /* NamedExports */;
        }
        function getLeftmostAccessExpression(expr) {
            while (isAccessExpression(expr)) {
                expr = expr.expression;
            }
            return expr;
        }
        function forEachNameInAccessChainWalkingLeft(name, action) {
            if (isAccessExpression(name.parent) && isRightSideOfAccessExpression(name)) {
                return walkAccessExpression(name.parent);
            }
            function walkAccessExpression(access) {
                if (access.kind === 208 /* PropertyAccessExpression */) {
                    const res = action(access.name);
                    if (res !== void 0) {
                        return res;
                    }
                }
                else if (access.kind === 209 /* ElementAccessExpression */) {
                    if (isIdentifier(access.argumentExpression) || isStringLiteralLike(access.argumentExpression)) {
                        const res = action(access.argumentExpression);
                        if (res !== void 0) {
                            return res;
                        }
                    }
                    else {
                        return void 0;
                    }
                }
                if (isAccessExpression(access.expression)) {
                    return walkAccessExpression(access.expression);
                }
                if (isIdentifier(access.expression)) {
                    return action(access.expression);
                }
                return void 0;
            }
        }
        function getLeftmostExpression(node, stopAtCallExpressions) {
            while (true) {
                switch (node.kind) {
                    case 222 /* PostfixUnaryExpression */:
                        node = node.operand;
                        continue;
                    case 223 /* BinaryExpression */:
                        node = node.left;
                        continue;
                    case 224 /* ConditionalExpression */:
                        node = node.condition;
                        continue;
                    case 212 /* TaggedTemplateExpression */:
                        node = node.tag;
                        continue;
                    case 210 /* CallExpression */:
                        if (stopAtCallExpressions) {
                            return node;
                        }
                    case 231 /* AsExpression */:
                    case 209 /* ElementAccessExpression */:
                    case 208 /* PropertyAccessExpression */:
                    case 232 /* NonNullExpression */:
                    case 356 /* PartiallyEmittedExpression */:
                    case 235 /* SatisfiesExpression */:
                        node = node.expression;
                        continue;
                }
                return node;
            }
        }
        function Symbol4(flags, name) {
            this.flags = flags;
            this.escapedName = name;
            this.declarations = void 0;
            this.valueDeclaration = void 0;
            this.id = 0;
            this.mergeId = 0;
            this.parent = void 0;
            this.members = void 0;
            this.exports = void 0;
            this.exportSymbol = void 0;
            this.constEnumOnlyModule = void 0;
            this.isReferenced = void 0;
            this.isAssigned = void 0;
            this.links = void 0;
        }
        function Type3(checker, flags) {
            this.flags = flags;
            if (Debug.isDebugging || tracing) {
                this.checker = checker;
            }
        }
        function Signature2(checker, flags) {
            this.flags = flags;
            if (Debug.isDebugging) {
                this.checker = checker;
            }
        }
        function Node4(kind, pos, end) {
            this.pos = pos;
            this.end = end;
            this.kind = kind;
            this.id = 0;
            this.flags = 0 /* None */;
            this.modifierFlagsCache = 0 /* None */;
            this.transformFlags = 0 /* None */;
            this.parent = void 0;
            this.original = void 0;
            this.emitNode = void 0;
        }
        function Token(kind, pos, end) {
            this.pos = pos;
            this.end = end;
            this.kind = kind;
            this.id = 0;
            this.flags = 0 /* None */;
            this.transformFlags = 0 /* None */;
            this.parent = void 0;
            this.emitNode = void 0;
        }
        function Identifier2(kind, pos, end) {
            this.pos = pos;
            this.end = end;
            this.kind = kind;
            this.id = 0;
            this.flags = 0 /* None */;
            this.transformFlags = 0 /* None */;
            this.parent = void 0;
            this.original = void 0;
            this.emitNode = void 0;
        }
        function SourceMapSource(fileName, text, skipTrivia2) {
            this.fileName = fileName;
            this.text = text;
            this.skipTrivia = skipTrivia2 || ((pos) => pos);
        }
        function addObjectAllocatorPatcher(fn) {
            objectAllocatorPatchers.push(fn);
            fn(objectAllocator);
        }
        function setObjectAllocator(alloc) {
            Object.assign(objectAllocator, alloc);
            forEach(objectAllocatorPatchers, (fn) => fn(objectAllocator));
        }
        function formatStringFromArgs(text, args, baseIndex = 0) {
            return text.replace(/{(\d+)}/g, (_match, index) => "" + Debug.checkDefined(args[+index + baseIndex]));
        }
        function setLocalizedDiagnosticMessages(messages) {
            localizedDiagnosticMessages = messages;
        }
        function maybeSetLocalizedDiagnosticMessages(getMessages) {
            if (!localizedDiagnosticMessages && getMessages) {
                localizedDiagnosticMessages = getMessages();
            }
        }
        function getLocaleSpecificMessage(message) {
            return localizedDiagnosticMessages && localizedDiagnosticMessages[message.key] || message.message;
        }
        function createDetachedDiagnostic(fileName, start, length2, message) {
            assertDiagnosticLocation(
            /*file*/
            void 0, start, length2);
            let text = getLocaleSpecificMessage(message);
            if (arguments.length > 4) {
                text = formatStringFromArgs(text, arguments, 4);
            }
            return {
                file: void 0,
                start,
                length: length2,
                messageText: text,
                category: message.category,
                code: message.code,
                reportsUnnecessary: message.reportsUnnecessary,
                fileName
            };
        }
        function isDiagnosticWithDetachedLocation(diagnostic) {
            return diagnostic.file === void 0 && diagnostic.start !== void 0 && diagnostic.length !== void 0 && typeof diagnostic.fileName === "string";
        }
        function attachFileToDiagnostic(diagnostic, file) {
            const fileName = file.fileName || "";
            const length2 = file.text.length;
            Debug.assertEqual(diagnostic.fileName, fileName);
            Debug.assertLessThanOrEqual(diagnostic.start, length2);
            Debug.assertLessThanOrEqual(diagnostic.start + diagnostic.length, length2);
            const diagnosticWithLocation = {
                file,
                start: diagnostic.start,
                length: diagnostic.length,
                messageText: diagnostic.messageText,
                category: diagnostic.category,
                code: diagnostic.code,
                reportsUnnecessary: diagnostic.reportsUnnecessary
            };
            if (diagnostic.relatedInformation) {
                diagnosticWithLocation.relatedInformation = [];
                for (const related of diagnostic.relatedInformation) {
                    if (isDiagnosticWithDetachedLocation(related) && related.fileName === fileName) {
                        Debug.assertLessThanOrEqual(related.start, length2);
                        Debug.assertLessThanOrEqual(related.start + related.length, length2);
                        diagnosticWithLocation.relatedInformation.push(attachFileToDiagnostic(related, file));
                    }
                    else {
                        diagnosticWithLocation.relatedInformation.push(related);
                    }
                }
            }
            return diagnosticWithLocation;
        }
        function attachFileToDiagnostics(diagnostics, file) {
            const diagnosticsWithLocation = [];
            for (const diagnostic of diagnostics) {
                diagnosticsWithLocation.push(attachFileToDiagnostic(diagnostic, file));
            }
            return diagnosticsWithLocation;
        }
        function createFileDiagnostic(file, start, length2, message) {
            assertDiagnosticLocation(file, start, length2);
            let text = getLocaleSpecificMessage(message);
            if (arguments.length > 4) {
                text = formatStringFromArgs(text, arguments, 4);
            }
            return {
                file,
                start,
                length: length2,
                messageText: text,
                category: message.category,
                code: message.code,
                reportsUnnecessary: message.reportsUnnecessary,
                reportsDeprecated: message.reportsDeprecated
            };
        }
        function formatMessage(_dummy, message) {
            let text = getLocaleSpecificMessage(message);
            if (arguments.length > 2) {
                text = formatStringFromArgs(text, arguments, 2);
            }
            return text;
        }
        function createCompilerDiagnostic(message) {
            let text = getLocaleSpecificMessage(message);
            if (arguments.length > 1) {
                text = formatStringFromArgs(text, arguments, 1);
            }
            return {
                file: void 0,
                start: void 0,
                length: void 0,
                messageText: text,
                category: message.category,
                code: message.code,
                reportsUnnecessary: message.reportsUnnecessary,
                reportsDeprecated: message.reportsDeprecated
            };
        }
        function createCompilerDiagnosticFromMessageChain(chain, relatedInformation) {
            return {
                file: void 0,
                start: void 0,
                length: void 0,
                code: chain.code,
                category: chain.category,
                messageText: chain.next ? chain : chain.messageText,
                relatedInformation
            };
        }
        function chainDiagnosticMessages(details, message) {
            let text = getLocaleSpecificMessage(message);
            if (arguments.length > 2) {
                text = formatStringFromArgs(text, arguments, 2);
            }
            return {
                messageText: text,
                category: message.category,
                code: message.code,
                next: details === void 0 || Array.isArray(details) ? details : [details]
            };
        }
        function concatenateDiagnosticMessageChains(headChain, tailChain) {
            let lastChain = headChain;
            while (lastChain.next) {
                lastChain = lastChain.next[0];
            }
            lastChain.next = [tailChain];
        }
        function getDiagnosticFilePath(diagnostic) {
            return diagnostic.file ? diagnostic.file.path : void 0;
        }
        function compareDiagnostics(d1, d2) {
            return compareDiagnosticsSkipRelatedInformation(d1, d2) || compareRelatedInformation(d1, d2) || 0 /* EqualTo */;
        }
        function compareDiagnosticsSkipRelatedInformation(d1, d2) {
            return compareStringsCaseSensitive(getDiagnosticFilePath(d1), getDiagnosticFilePath(d2)) || compareValues(d1.start, d2.start) || compareValues(d1.length, d2.length) || compareValues(d1.code, d2.code) || compareMessageText(d1.messageText, d2.messageText) || 0 /* EqualTo */;
        }
        function compareRelatedInformation(d1, d2) {
            if (!d1.relatedInformation && !d2.relatedInformation) {
                return 0 /* EqualTo */;
            }
            if (d1.relatedInformation && d2.relatedInformation) {
                return compareValues(d1.relatedInformation.length, d2.relatedInformation.length) || forEach(d1.relatedInformation, (d1i, index) => {
                    const d2i = d2.relatedInformation[index];
                    return compareDiagnostics(d1i, d2i);
                }) || 0 /* EqualTo */;
            }
            return d1.relatedInformation ? -1 /* LessThan */ : 1 /* GreaterThan */;
        }
        function compareMessageText(t1, t2) {
            if (typeof t1 === "string" && typeof t2 === "string") {
                return compareStringsCaseSensitive(t1, t2);
            }
            else if (typeof t1 === "string") {
                return -1 /* LessThan */;
            }
            else if (typeof t2 === "string") {
                return 1 /* GreaterThan */;
            }
            let res = compareStringsCaseSensitive(t1.messageText, t2.messageText);
            if (res) {
                return res;
            }
            if (!t1.next && !t2.next) {
                return 0 /* EqualTo */;
            }
            if (!t1.next) {
                return -1 /* LessThan */;
            }
            if (!t2.next) {
                return 1 /* GreaterThan */;
            }
            const len = Math.min(t1.next.length, t2.next.length);
            for (let i = 0; i < len; i++) {
                res = compareMessageText(t1.next[i], t2.next[i]);
                if (res) {
                    return res;
                }
            }
            if (t1.next.length < t2.next.length) {
                return -1 /* LessThan */;
            }
            else if (t1.next.length > t2.next.length) {
                return 1 /* GreaterThan */;
            }
            return 0 /* EqualTo */;
        }
        function getLanguageVariant(scriptKind) {
            return scriptKind === 4 /* TSX */ || scriptKind === 2 /* JSX */ || scriptKind === 1 /* JS */ || scriptKind === 6 /* JSON */ ? 1 /* JSX */ : 0 /* Standard */;
        }
        function walkTreeForJSXTags(node) {
            if (!(node.transformFlags & 2 /* ContainsJsx */))
                return void 0;
            return isJsxOpeningLikeElement(node) || isJsxFragment(node) ? node : forEachChild(node, walkTreeForJSXTags);
        }
        function isFileModuleFromUsingJSXTag(file) {
            return !file.isDeclarationFile ? walkTreeForJSXTags(file) : void 0;
        }
        function isFileForcedToBeModuleByFormat(file) {
            return (file.impliedNodeFormat === 99 /* ESNext */ || fileExtensionIsOneOf(file.fileName, [".cjs" /* Cjs */, ".cts" /* Cts */, ".mjs" /* Mjs */, ".mts" /* Mts */])) && !file.isDeclarationFile ? true : void 0;
        }
        function getSetExternalModuleIndicator(options) {
            switch (getEmitModuleDetectionKind(options)) {
                case 3 /* Force */:
                    return (file) => {
                        file.externalModuleIndicator = isFileProbablyExternalModule(file) || !file.isDeclarationFile || void 0;
                    };
                case 1 /* Legacy */:
                    return (file) => {
                        file.externalModuleIndicator = isFileProbablyExternalModule(file);
                    };
                case 2 /* Auto */:
                    const checks = [isFileProbablyExternalModule];
                    if (options.jsx === 4 /* ReactJSX */ || options.jsx === 5 /* ReactJSXDev */) {
                        checks.push(isFileModuleFromUsingJSXTag);
                    }
                    checks.push(isFileForcedToBeModuleByFormat);
                    const combined = or(...checks);
                    const callback = (file) => void (file.externalModuleIndicator = combined(file));
                    return callback;
            }
        }
        function getEmitScriptTarget(compilerOptions) {
            var _a2;
            return (_a2 = compilerOptions.target) != null ? _a2 : compilerOptions.module === 100 /* Node16 */ && 9 /* ES2022 */ || compilerOptions.module === 199 /* NodeNext */ && 99 /* ESNext */ || 1 /* ES5 */;
        }
        function getEmitModuleKind(compilerOptions) {
            return typeof compilerOptions.module === "number" ? compilerOptions.module : getEmitScriptTarget(compilerOptions) >= 2 /* ES2015 */ ? 5 /* ES2015 */ : 1 /* CommonJS */;
        }
        function emitModuleKindIsNonNodeESM(moduleKind) {
            return moduleKind >= 5 /* ES2015 */ && moduleKind <= 99 /* ESNext */;
        }
        function getEmitModuleResolutionKind(compilerOptions) {
            let moduleResolution = compilerOptions.moduleResolution;
            if (moduleResolution === void 0) {
                switch (getEmitModuleKind(compilerOptions)) {
                    case 1 /* CommonJS */:
                        moduleResolution = 2 /* Node10 */;
                        break;
                    case 100 /* Node16 */:
                        moduleResolution = 3 /* Node16 */;
                        break;
                    case 199 /* NodeNext */:
                        moduleResolution = 99 /* NodeNext */;
                        break;
                    default:
                        moduleResolution = 1 /* Classic */;
                        break;
                }
            }
            return moduleResolution;
        }
        function getEmitModuleDetectionKind(options) {
            return options.moduleDetection || (getEmitModuleKind(options) === 100 /* Node16 */ || getEmitModuleKind(options) === 199 /* NodeNext */ ? 3 /* Force */ : 2 /* Auto */);
        }
        function hasJsonModuleEmitEnabled(options) {
            switch (getEmitModuleKind(options)) {
                case 1 /* CommonJS */:
                case 2 /* AMD */:
                case 5 /* ES2015 */:
                case 6 /* ES2020 */:
                case 7 /* ES2022 */:
                case 99 /* ESNext */:
                case 100 /* Node16 */:
                case 199 /* NodeNext */:
                    return true;
                default:
                    return false;
            }
        }
        function getIsolatedModules(options) {
            return !!(options.isolatedModules || options.verbatimModuleSyntax);
        }
        function importNameElisionDisabled(options) {
            return options.verbatimModuleSyntax || options.isolatedModules && options.preserveValueImports;
        }
        function unreachableCodeIsError(options) {
            return options.allowUnreachableCode === false;
        }
        function unusedLabelIsError(options) {
            return options.allowUnusedLabels === false;
        }
        function getAreDeclarationMapsEnabled(options) {
            return !!(getEmitDeclarations(options) && options.declarationMap);
        }
        function getESModuleInterop(compilerOptions) {
            if (compilerOptions.esModuleInterop !== void 0) {
                return compilerOptions.esModuleInterop;
            }
            switch (getEmitModuleKind(compilerOptions)) {
                case 100 /* Node16 */:
                case 199 /* NodeNext */:
                    return true;
            }
            return void 0;
        }
        function getAllowSyntheticDefaultImports(compilerOptions) {
            if (compilerOptions.allowSyntheticDefaultImports !== void 0) {
                return compilerOptions.allowSyntheticDefaultImports;
            }
            return getESModuleInterop(compilerOptions) || getEmitModuleKind(compilerOptions) === 4 /* System */ || getEmitModuleResolutionKind(compilerOptions) === 100 /* Bundler */;
        }
        function moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution) {
            return moduleResolution >= 3 /* Node16 */ && moduleResolution <= 99 /* NodeNext */ || moduleResolution === 100 /* Bundler */;
        }
        function shouldResolveJsRequire(compilerOptions) {
            return !!compilerOptions.noDtsResolution || getEmitModuleResolutionKind(compilerOptions) !== 100 /* Bundler */;
        }
        function getResolvePackageJsonExports(compilerOptions) {
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            if (!moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                return false;
            }
            if (compilerOptions.resolvePackageJsonExports !== void 0) {
                return compilerOptions.resolvePackageJsonExports;
            }
            switch (moduleResolution) {
                case 3 /* Node16 */:
                case 99 /* NodeNext */:
                case 100 /* Bundler */:
                    return true;
            }
            return false;
        }
        function getResolvePackageJsonImports(compilerOptions) {
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            if (!moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                return false;
            }
            if (compilerOptions.resolvePackageJsonExports !== void 0) {
                return compilerOptions.resolvePackageJsonExports;
            }
            switch (moduleResolution) {
                case 3 /* Node16 */:
                case 99 /* NodeNext */:
                case 100 /* Bundler */:
                    return true;
            }
            return false;
        }
        function getResolveJsonModule(compilerOptions) {
            if (compilerOptions.resolveJsonModule !== void 0) {
                return compilerOptions.resolveJsonModule;
            }
            return getEmitModuleResolutionKind(compilerOptions) === 100 /* Bundler */;
        }
        function getEmitDeclarations(compilerOptions) {
            return !!(compilerOptions.declaration || compilerOptions.composite);
        }
        function shouldPreserveConstEnums(compilerOptions) {
            return !!(compilerOptions.preserveConstEnums || getIsolatedModules(compilerOptions));
        }
        function isIncrementalCompilation(options) {
            return !!(options.incremental || options.composite);
        }
        function getStrictOptionValue(compilerOptions, flag) {
            return compilerOptions[flag] === void 0 ? !!compilerOptions.strict : !!compilerOptions[flag];
        }
        function getAllowJSCompilerOption(compilerOptions) {
            return compilerOptions.allowJs === void 0 ? !!compilerOptions.checkJs : compilerOptions.allowJs;
        }
        function getUseDefineForClassFields(compilerOptions) {
            return compilerOptions.useDefineForClassFields === void 0 ? getEmitScriptTarget(compilerOptions) >= 9 /* ES2022 */ : compilerOptions.useDefineForClassFields;
        }
        function compilerOptionsAffectSemanticDiagnostics(newOptions, oldOptions) {
            return optionsHaveChanges(oldOptions, newOptions, semanticDiagnosticsOptionDeclarations);
        }
        function compilerOptionsAffectEmit(newOptions, oldOptions) {
            return optionsHaveChanges(oldOptions, newOptions, affectsEmitOptionDeclarations);
        }
        function compilerOptionsAffectDeclarationPath(newOptions, oldOptions) {
            return optionsHaveChanges(oldOptions, newOptions, affectsDeclarationPathOptionDeclarations);
        }
        function getCompilerOptionValue(options, option) {
            return option.strictFlag ? getStrictOptionValue(options, option.name) : options[option.name];
        }
        function getJSXTransformEnabled(options) {
            const jsx = options.jsx;
            return jsx === 2 /* React */ || jsx === 4 /* ReactJSX */ || jsx === 5 /* ReactJSXDev */;
        }
        function getJSXImplicitImportBase(compilerOptions, file) {
            const jsxImportSourcePragmas = file == null ? void 0 : file.pragmas.get("jsximportsource");
            const jsxImportSourcePragma = isArray(jsxImportSourcePragmas) ? jsxImportSourcePragmas[jsxImportSourcePragmas.length - 1] : jsxImportSourcePragmas;
            return compilerOptions.jsx === 4 /* ReactJSX */ || compilerOptions.jsx === 5 /* ReactJSXDev */ || compilerOptions.jsxImportSource || jsxImportSourcePragma ? (jsxImportSourcePragma == null ? void 0 : jsxImportSourcePragma.arguments.factory) || compilerOptions.jsxImportSource || "react" : void 0;
        }
        function getJSXRuntimeImport(base, options) {
            return base ? `${base}/${options.jsx === 5 /* ReactJSXDev */ ? "jsx-dev-runtime" : "jsx-runtime"}` : void 0;
        }
        function hasZeroOrOneAsteriskCharacter(str) {
            let seenAsterisk = false;
            for (let i = 0; i < str.length; i++) {
                if (str.charCodeAt(i) === 42 /* asterisk */) {
                    if (!seenAsterisk) {
                        seenAsterisk = true;
                    }
                    else {
                        return false;
                    }
                }
            }
            return true;
        }
        function createSymlinkCache(cwd, getCanonicalFileName) {
            let symlinkedDirectories;
            let symlinkedDirectoriesByRealpath;
            let symlinkedFiles;
            let hasProcessedResolutions = false;
            return {
                getSymlinkedFiles: () => symlinkedFiles,
                getSymlinkedDirectories: () => symlinkedDirectories,
                getSymlinkedDirectoriesByRealpath: () => symlinkedDirectoriesByRealpath,
                setSymlinkedFile: (path, real) => (symlinkedFiles || (symlinkedFiles = /* @__PURE__ */ new Map())).set(path, real),
                setSymlinkedDirectory: (symlink, real) => {
                    let symlinkPath = toPath(symlink, cwd, getCanonicalFileName);
                    if (!containsIgnoredPath(symlinkPath)) {
                        symlinkPath = ensureTrailingDirectorySeparator(symlinkPath);
                        if (real !== false && !(symlinkedDirectories == null ? void 0 : symlinkedDirectories.has(symlinkPath))) {
                            (symlinkedDirectoriesByRealpath || (symlinkedDirectoriesByRealpath = createMultiMap())).add(ensureTrailingDirectorySeparator(real.realPath), symlink);
                        }
                        (symlinkedDirectories || (symlinkedDirectories = /* @__PURE__ */ new Map())).set(symlinkPath, real);
                    }
                },
                setSymlinksFromResolutions(files, typeReferenceDirectives) {
                    var _a2, _b;
                    Debug.assert(!hasProcessedResolutions);
                    hasProcessedResolutions = true;
                    for (const file of files) {
                        (_a2 = file.resolvedModules) == null ? void 0 : _a2.forEach((resolution) => processResolution(this, resolution.resolvedModule));
                        (_b = file.resolvedTypeReferenceDirectiveNames) == null ? void 0 : _b.forEach((resolution) => processResolution(this, resolution.resolvedTypeReferenceDirective));
                    }
                    typeReferenceDirectives.forEach((resolution) => processResolution(this, resolution.resolvedTypeReferenceDirective));
                },
                hasProcessedResolutions: () => hasProcessedResolutions
            };
            function processResolution(cache, resolution) {
                if (!resolution || !resolution.originalPath || !resolution.resolvedFileName)
                    return;
                const { resolvedFileName, originalPath } = resolution;
                cache.setSymlinkedFile(toPath(originalPath, cwd, getCanonicalFileName), resolvedFileName);
                const [commonResolved, commonOriginal] = guessDirectorySymlink(resolvedFileName, originalPath, cwd, getCanonicalFileName) || emptyArray;
                if (commonResolved && commonOriginal) {
                    cache.setSymlinkedDirectory(commonOriginal, { real: commonResolved, realPath: toPath(commonResolved, cwd, getCanonicalFileName) });
                }
            }
        }
        function guessDirectorySymlink(a, b, cwd, getCanonicalFileName) {
            const aParts = getPathComponents(getNormalizedAbsolutePath(a, cwd));
            const bParts = getPathComponents(getNormalizedAbsolutePath(b, cwd));
            let isDirectory = false;
            while (aParts.length >= 2 && bParts.length >= 2 && !isNodeModulesOrScopedPackageDirectory(aParts[aParts.length - 2], getCanonicalFileName) && !isNodeModulesOrScopedPackageDirectory(bParts[bParts.length - 2], getCanonicalFileName) && getCanonicalFileName(aParts[aParts.length - 1]) === getCanonicalFileName(bParts[bParts.length - 1])) {
                aParts.pop();
                bParts.pop();
                isDirectory = true;
            }
            return isDirectory ? [getPathFromPathComponents(aParts), getPathFromPathComponents(bParts)] : void 0;
        }
        function isNodeModulesOrScopedPackageDirectory(s, getCanonicalFileName) {
            return s !== void 0 && (getCanonicalFileName(s) === "node_modules" || startsWith(s, "@"));
        }
        function stripLeadingDirectorySeparator(s) {
            return isAnyDirectorySeparator(s.charCodeAt(0)) ? s.slice(1) : void 0;
        }
        function tryRemoveDirectoryPrefix(path, dirPath, getCanonicalFileName) {
            const withoutPrefix = tryRemovePrefix(path, dirPath, getCanonicalFileName);
            return withoutPrefix === void 0 ? void 0 : stripLeadingDirectorySeparator(withoutPrefix);
        }
        function regExpEscape(text) {
            return text.replace(reservedCharacterPattern, escapeRegExpCharacter);
        }
        function escapeRegExpCharacter(match) {
            return "\\" + match;
        }
        function getRegularExpressionForWildcard(specs, basePath, usage) {
            const patterns = getRegularExpressionsForWildcards(specs, basePath, usage);
            if (!patterns || !patterns.length) {
                return void 0;
            }
            const pattern = patterns.map((pattern2) => `(${pattern2})`).join("|");
            const terminator = usage === "exclude" ? "($|/)" : "$";
            return `^(${pattern})${terminator}`;
        }
        function getRegularExpressionsForWildcards(specs, basePath, usage) {
            if (specs === void 0 || specs.length === 0) {
                return void 0;
            }
            return flatMap(specs, (spec) => spec && getSubPatternFromSpec(spec, basePath, usage, wildcardMatchers[usage]));
        }
        function isImplicitGlob(lastPathComponent) {
            return !/[.*?]/.test(lastPathComponent);
        }
        function getPatternFromSpec(spec, basePath, usage) {
            const pattern = spec && getSubPatternFromSpec(spec, basePath, usage, wildcardMatchers[usage]);
            return pattern && `^(${pattern})${usage === "exclude" ? "($|/)" : "$"}`;
        }
        function getSubPatternFromSpec(spec, basePath, usage, { singleAsteriskRegexFragment, doubleAsteriskRegexFragment, replaceWildcardCharacter: replaceWildcardCharacter2 }) {
            let subpattern = "";
            let hasWrittenComponent = false;
            const components = getNormalizedPathComponents(spec, basePath);
            const lastComponent = last(components);
            if (usage !== "exclude" && lastComponent === "**") {
                return void 0;
            }
            components[0] = removeTrailingDirectorySeparator(components[0]);
            if (isImplicitGlob(lastComponent)) {
                components.push("**", "*");
            }
            let optionalCount = 0;
            for (let component of components) {
                if (component === "**") {
                    subpattern += doubleAsteriskRegexFragment;
                }
                else {
                    if (usage === "directories") {
                        subpattern += "(";
                        optionalCount++;
                    }
                    if (hasWrittenComponent) {
                        subpattern += directorySeparator;
                    }
                    if (usage !== "exclude") {
                        let componentPattern = "";
                        if (component.charCodeAt(0) === 42 /* asterisk */) {
                            componentPattern += "([^./]" + singleAsteriskRegexFragment + ")?";
                            component = component.substr(1);
                        }
                        else if (component.charCodeAt(0) === 63 /* question */) {
                            componentPattern += "[^./]";
                            component = component.substr(1);
                        }
                        componentPattern += component.replace(reservedCharacterPattern, replaceWildcardCharacter2);
                        if (componentPattern !== component) {
                            subpattern += implicitExcludePathRegexPattern;
                        }
                        subpattern += componentPattern;
                    }
                    else {
                        subpattern += component.replace(reservedCharacterPattern, replaceWildcardCharacter2);
                    }
                }
                hasWrittenComponent = true;
            }
            while (optionalCount > 0) {
                subpattern += ")?";
                optionalCount--;
            }
            return subpattern;
        }
        function replaceWildcardCharacter(match, singleAsteriskRegexFragment) {
            return match === "*" ? singleAsteriskRegexFragment : match === "?" ? "[^/]" : "\\" + match;
        }
        function getFileMatcherPatterns(path, excludes, includes, useCaseSensitiveFileNames, currentDirectory) {
            path = normalizePath(path);
            currentDirectory = normalizePath(currentDirectory);
            const absolutePath = combinePaths(currentDirectory, path);
            return {
                includeFilePatterns: map(getRegularExpressionsForWildcards(includes, absolutePath, "files"), (pattern) => `^${pattern}$`),
                includeFilePattern: getRegularExpressionForWildcard(includes, absolutePath, "files"),
                includeDirectoryPattern: getRegularExpressionForWildcard(includes, absolutePath, "directories"),
                excludePattern: getRegularExpressionForWildcard(excludes, absolutePath, "exclude"),
                basePaths: getBasePaths(path, includes, useCaseSensitiveFileNames)
            };
        }
        function getRegexFromPattern(pattern, useCaseSensitiveFileNames) {
            return new RegExp(pattern, useCaseSensitiveFileNames ? "" : "i");
        }
        function matchFiles(path, extensions, excludes, includes, useCaseSensitiveFileNames, currentDirectory, depth, getFileSystemEntries, realpath) {
            path = normalizePath(path);
            currentDirectory = normalizePath(currentDirectory);
            const patterns = getFileMatcherPatterns(path, excludes, includes, useCaseSensitiveFileNames, currentDirectory);
            const includeFileRegexes = patterns.includeFilePatterns && patterns.includeFilePatterns.map((pattern) => getRegexFromPattern(pattern, useCaseSensitiveFileNames));
            const includeDirectoryRegex = patterns.includeDirectoryPattern && getRegexFromPattern(patterns.includeDirectoryPattern, useCaseSensitiveFileNames);
            const excludeRegex = patterns.excludePattern && getRegexFromPattern(patterns.excludePattern, useCaseSensitiveFileNames);
            const results = includeFileRegexes ? includeFileRegexes.map(() => []) : [[]];
            const visited = /* @__PURE__ */ new Map();
            const toCanonical = createGetCanonicalFileName(useCaseSensitiveFileNames);
            for (const basePath of patterns.basePaths) {
                visitDirectory(basePath, combinePaths(currentDirectory, basePath), depth);
            }
            return flatten(results);
            function visitDirectory(path2, absolutePath, depth2) {
                const canonicalPath = toCanonical(realpath(absolutePath));
                if (visited.has(canonicalPath))
                    return;
                visited.set(canonicalPath, true);
                const { files, directories } = getFileSystemEntries(path2);
                for (const current of sort(files, compareStringsCaseSensitive)) {
                    const name = combinePaths(path2, current);
                    const absoluteName = combinePaths(absolutePath, current);
                    if (extensions && !fileExtensionIsOneOf(name, extensions))
                        continue;
                    if (excludeRegex && excludeRegex.test(absoluteName))
                        continue;
                    if (!includeFileRegexes) {
                        results[0].push(name);
                    }
                    else {
                        const includeIndex = findIndex(includeFileRegexes, (re) => re.test(absoluteName));
                        if (includeIndex !== -1) {
                            results[includeIndex].push(name);
                        }
                    }
                }
                if (depth2 !== void 0) {
                    depth2--;
                    if (depth2 === 0) {
                        return;
                    }
                }
                for (const current of sort(directories, compareStringsCaseSensitive)) {
                    const name = combinePaths(path2, current);
                    const absoluteName = combinePaths(absolutePath, current);
                    if ((!includeDirectoryRegex || includeDirectoryRegex.test(absoluteName)) && (!excludeRegex || !excludeRegex.test(absoluteName))) {
                        visitDirectory(name, absoluteName, depth2);
                    }
                }
            }
        }
        function getBasePaths(path, includes, useCaseSensitiveFileNames) {
            const basePaths = [path];
            if (includes) {
                const includeBasePaths = [];
                for (const include of includes) {
                    const absolute = isRootedDiskPath(include) ? include : normalizePath(combinePaths(path, include));
                    includeBasePaths.push(getIncludeBasePath(absolute));
                }
                includeBasePaths.sort(getStringComparer(!useCaseSensitiveFileNames));
                for (const includeBasePath of includeBasePaths) {
                    if (every(basePaths, (basePath) => !containsPath(basePath, includeBasePath, path, !useCaseSensitiveFileNames))) {
                        basePaths.push(includeBasePath);
                    }
                }
            }
            return basePaths;
        }
        function getIncludeBasePath(absolute) {
            const wildcardOffset = indexOfAnyCharCode(absolute, wildcardCharCodes);
            if (wildcardOffset < 0) {
                return !hasExtension(absolute) ? absolute : removeTrailingDirectorySeparator(getDirectoryPath(absolute));
            }
            return absolute.substring(0, absolute.lastIndexOf(directorySeparator, wildcardOffset));
        }
        function ensureScriptKind(fileName, scriptKind) {
            return scriptKind || getScriptKindFromFileName(fileName) || 3 /* TS */;
        }
        function getScriptKindFromFileName(fileName) {
            const ext = fileName.substr(fileName.lastIndexOf("."));
            switch (ext.toLowerCase()) {
                case ".js" /* Js */:
                case ".cjs" /* Cjs */:
                case ".mjs" /* Mjs */:
                    return 1 /* JS */;
                case ".jsx" /* Jsx */:
                    return 2 /* JSX */;
                case ".ts" /* Ts */:
                case ".cts" /* Cts */:
                case ".mts" /* Mts */:
                    return 3 /* TS */;
                case ".tsx" /* Tsx */:
                    return 4 /* TSX */;
                case ".json" /* Json */:
                    return 6 /* JSON */;
                default:
                    return 0 /* Unknown */;
            }
        }
        function getSupportedExtensions(options, extraFileExtensions) {
            const needJsExtensions = options && getAllowJSCompilerOption(options);
            if (!extraFileExtensions || extraFileExtensions.length === 0) {
                return needJsExtensions ? allSupportedExtensions : supportedTSExtensions;
            }
            const builtins = needJsExtensions ? allSupportedExtensions : supportedTSExtensions;
            const flatBuiltins = flatten(builtins);
            const extensions = [
                ...builtins,
                ...mapDefined(extraFileExtensions, (x) => x.scriptKind === 7 /* Deferred */ || needJsExtensions && isJSLike(x.scriptKind) && flatBuiltins.indexOf(x.extension) === -1 ? [x.extension] : void 0)
            ];
            return extensions;
        }
        function getSupportedExtensionsWithJsonIfResolveJsonModule(options, supportedExtensions) {
            if (!options || !getResolveJsonModule(options))
                return supportedExtensions;
            if (supportedExtensions === allSupportedExtensions)
                return allSupportedExtensionsWithJson;
            if (supportedExtensions === supportedTSExtensions)
                return supportedTSExtensionsWithJson;
            return [...supportedExtensions, [".json" /* Json */]];
        }
        function isJSLike(scriptKind) {
            return scriptKind === 1 /* JS */ || scriptKind === 2 /* JSX */;
        }
        function hasJSFileExtension(fileName) {
            return some(supportedJSExtensionsFlat, (extension) => fileExtensionIs(fileName, extension));
        }
        function hasTSFileExtension(fileName) {
            return some(supportedTSExtensionsFlat, (extension) => fileExtensionIs(fileName, extension));
        }
        function usesExtensionsOnImports({ imports }, hasExtension2 = or(hasJSFileExtension, hasTSFileExtension)) {
            return firstDefined(imports, ({ text }) => pathIsRelative(text) ? hasExtension2(text) : void 0) || false;
        }
        function getModuleSpecifierEndingPreference(preference, resolutionMode, compilerOptions, sourceFile) {
            if (preference === "js" || resolutionMode === 99 /* ESNext */) {
                if (!shouldAllowImportingTsExtension(compilerOptions)) {
                    return 2 /* JsExtension */;
                }
                return inferPreference() !== 2 /* JsExtension */ ? 3 /* TsExtension */ : 2 /* JsExtension */;
            }
            if (preference === "minimal") {
                return 0 /* Minimal */;
            }
            if (preference === "index") {
                return 1 /* Index */;
            }
            if (!shouldAllowImportingTsExtension(compilerOptions)) {
                return usesExtensionsOnImports(sourceFile) ? 2 /* JsExtension */ : 0 /* Minimal */;
            }
            return inferPreference();
            function inferPreference() {
                let usesJsExtensions = false;
                const specifiers = sourceFile.imports.length ? sourceFile.imports.map((i) => i.text) : isSourceFileJS(sourceFile) ? getRequiresAtTopOfFile(sourceFile).map((r) => r.arguments[0].text) : emptyArray;
                for (const specifier of specifiers) {
                    if (pathIsRelative(specifier)) {
                        if (hasTSFileExtension(specifier)) {
                            return 3 /* TsExtension */;
                        }
                        if (hasJSFileExtension(specifier)) {
                            usesJsExtensions = true;
                        }
                    }
                }
                return usesJsExtensions ? 2 /* JsExtension */ : 0 /* Minimal */;
            }
        }
        function getRequiresAtTopOfFile(sourceFile) {
            let nonRequireStatementCount = 0;
            let requires;
            for (const statement of sourceFile.statements) {
                if (nonRequireStatementCount > 3) {
                    break;
                }
                if (isRequireVariableStatement(statement)) {
                    requires = concatenate(requires, statement.declarationList.declarations.map((d) => d.initializer));
                }
                else if (isExpressionStatement(statement) && isRequireCall(statement.expression, 
                /*requireStringLiteralLikeArgument*/
                true)) {
                    requires = append(requires, statement.expression);
                }
                else {
                    nonRequireStatementCount++;
                }
            }
            return requires || emptyArray;
        }
        function isSupportedSourceFileName(fileName, compilerOptions, extraFileExtensions) {
            if (!fileName)
                return false;
            const supportedExtensions = getSupportedExtensions(compilerOptions, extraFileExtensions);
            for (const extension of flatten(getSupportedExtensionsWithJsonIfResolveJsonModule(compilerOptions, supportedExtensions))) {
                if (fileExtensionIs(fileName, extension)) {
                    return true;
                }
            }
            return false;
        }
        function numberOfDirectorySeparators(str) {
            const match = str.match(/\//g);
            return match ? match.length : 0;
        }
        function compareNumberOfDirectorySeparators(path1, path2) {
            return compareValues(numberOfDirectorySeparators(path1), numberOfDirectorySeparators(path2));
        }
        function removeFileExtension(path) {
            for (const ext of extensionsToRemove) {
                const extensionless = tryRemoveExtension(path, ext);
                if (extensionless !== void 0) {
                    return extensionless;
                }
            }
            return path;
        }
        function tryRemoveExtension(path, extension) {
            return fileExtensionIs(path, extension) ? removeExtension(path, extension) : void 0;
        }
        function removeExtension(path, extension) {
            return path.substring(0, path.length - extension.length);
        }
        function changeExtension(path, newExtension) {
            return changeAnyExtension(path, newExtension, extensionsToRemove, 
            /*ignoreCase*/
            false);
        }
        function tryParsePattern(pattern) {
            const indexOfStar = pattern.indexOf("*");
            if (indexOfStar === -1) {
                return pattern;
            }
            return pattern.indexOf("*", indexOfStar + 1) !== -1 ? void 0 : {
                prefix: pattern.substr(0, indexOfStar),
                suffix: pattern.substr(indexOfStar + 1)
            };
        }
        function tryParsePatterns(paths) {
            return mapDefined(getOwnKeys(paths), (path) => tryParsePattern(path));
        }
        function positionIsSynthesized(pos) {
            return !(pos >= 0);
        }
        function extensionIsTS(ext) {
            return ext === ".ts" /* Ts */ || ext === ".tsx" /* Tsx */ || ext === ".d.ts" /* Dts */ || ext === ".cts" /* Cts */ || ext === ".mts" /* Mts */ || ext === ".d.mts" /* Dmts */ || ext === ".d.cts" /* Dcts */ || startsWith(ext, ".d.") && endsWith(ext, ".ts");
        }
        function resolutionExtensionIsTSOrJson(ext) {
            return extensionIsTS(ext) || ext === ".json" /* Json */;
        }
        function extensionFromPath(path) {
            const ext = tryGetExtensionFromPath2(path);
            return ext !== void 0 ? ext : Debug.fail(`File ${path} has unknown extension.`);
        }
        function isAnySupportedFileExtension(path) {
            return tryGetExtensionFromPath2(path) !== void 0;
        }
        function tryGetExtensionFromPath2(path) {
            return find(extensionsToRemove, (e) => fileExtensionIs(path, e));
        }
        function isCheckJsEnabledForFile(sourceFile, compilerOptions) {
            return sourceFile.checkJsDirective ? sourceFile.checkJsDirective.enabled : compilerOptions.checkJs;
        }
        function matchPatternOrExact(patternOrStrings, candidate) {
            const patterns = [];
            for (const patternOrString of patternOrStrings) {
                if (patternOrString === candidate) {
                    return candidate;
                }
                if (!isString(patternOrString)) {
                    patterns.push(patternOrString);
                }
            }
            return findBestPatternMatch(patterns, (_) => _, candidate);
        }
        function sliceAfter(arr, value) {
            const index = arr.indexOf(value);
            Debug.assert(index !== -1);
            return arr.slice(index);
        }
        function addRelatedInfo(diagnostic, ...relatedInformation) {
            if (!relatedInformation.length) {
                return diagnostic;
            }
            if (!diagnostic.relatedInformation) {
                diagnostic.relatedInformation = [];
            }
            Debug.assert(diagnostic.relatedInformation !== emptyArray, "Diagnostic had empty array singleton for related info, but is still being constructed!");
            diagnostic.relatedInformation.push(...relatedInformation);
            return diagnostic;
        }
        function minAndMax(arr, getValue) {
            Debug.assert(arr.length !== 0);
            let min2 = getValue(arr[0]);
            let max = min2;
            for (let i = 1; i < arr.length; i++) {
                const value = getValue(arr[i]);
                if (value < min2) {
                    min2 = value;
                }
                else if (value > max) {
                    max = value;
                }
            }
            return { min: min2, max };
        }
        function rangeOfNode(node) {
            return { pos: getTokenPosOfNode(node), end: node.end };
        }
        function rangeOfTypeParameters(sourceFile, typeParameters) {
            const pos = typeParameters.pos - 1;
            const end = Math.min(sourceFile.text.length, skipTrivia(sourceFile.text, typeParameters.end) + 1);
            return { pos, end };
        }
        function skipTypeChecking(sourceFile, options, host) {
            return options.skipLibCheck && sourceFile.isDeclarationFile || options.skipDefaultLibCheck && sourceFile.hasNoDefaultLib || host.isSourceOfProjectReferenceRedirect(sourceFile.fileName);
        }
        function isJsonEqual(a, b) {
            return a === b || typeof a === "object" && a !== null && typeof b === "object" && b !== null && equalOwnProperties(a, b, isJsonEqual);
        }
        function parsePseudoBigInt(stringValue) {
            let log2Base;
            switch (stringValue.charCodeAt(1)) {
                case 98 /* b */:
                case 66 /* B */:
                    log2Base = 1;
                    break;
                case 111 /* o */:
                case 79 /* O */:
                    log2Base = 3;
                    break;
                case 120 /* x */:
                case 88 /* X */:
                    log2Base = 4;
                    break;
                default:
                    const nIndex = stringValue.length - 1;
                    let nonZeroStart = 0;
                    while (stringValue.charCodeAt(nonZeroStart) === 48 /* _0 */) {
                        nonZeroStart++;
                    }
                    return stringValue.slice(nonZeroStart, nIndex) || "0";
            }
            const startIndex = 2, endIndex = stringValue.length - 1;
            const bitsNeeded = (endIndex - startIndex) * log2Base;
            const segments = new Uint16Array((bitsNeeded >>> 4) + (bitsNeeded & 15 ? 1 : 0));
            for (let i = endIndex - 1, bitOffset = 0; i >= startIndex; i--, bitOffset += log2Base) {
                const segment = bitOffset >>> 4;
                const digitChar = stringValue.charCodeAt(i);
                const digit = digitChar <= 57 /* _9 */ ? digitChar - 48 /* _0 */ : 10 + digitChar - (digitChar <= 70 /* F */ ? 65 /* A */ : 97 /* a */);
                const shiftedDigit = digit << (bitOffset & 15);
                segments[segment] |= shiftedDigit;
                const residual = shiftedDigit >>> 16;
                if (residual)
                    segments[segment + 1] |= residual;
            }
            let base10Value = "";
            let firstNonzeroSegment = segments.length - 1;
            let segmentsRemaining = true;
            while (segmentsRemaining) {
                let mod10 = 0;
                segmentsRemaining = false;
                for (let segment = firstNonzeroSegment; segment >= 0; segment--) {
                    const newSegment = mod10 << 16 | segments[segment];
                    const segmentValue = newSegment / 10 | 0;
                    segments[segment] = segmentValue;
                    mod10 = newSegment - segmentValue * 10;
                    if (segmentValue && !segmentsRemaining) {
                        firstNonzeroSegment = segment;
                        segmentsRemaining = true;
                    }
                }
                base10Value = mod10 + base10Value;
            }
            return base10Value;
        }
        function pseudoBigIntToString({ negative, base10Value }) {
            return (negative && base10Value !== "0" ? "-" : "") + base10Value;
        }
        function parseBigInt(text) {
            if (!isValidBigIntString(text, 
            /*roundTripOnly*/
            false)) {
                return void 0;
            }
            return parseValidBigInt(text);
        }
        function parseValidBigInt(text) {
            const negative = text.startsWith("-");
            const base10Value = parsePseudoBigInt(`${negative ? text.slice(1) : text}n`);
            return { negative, base10Value };
        }
        function isValidBigIntString(s, roundTripOnly) {
            if (s === "")
                return false;
            const scanner2 = createScanner(99 /* ESNext */, 
            /*skipTrivia*/
            false);
            let success = true;
            scanner2.setOnError(() => success = false);
            scanner2.setText(s + "n");
            let result = scanner2.scan();
            const negative = result === 40 /* MinusToken */;
            if (negative) {
                result = scanner2.scan();
            }
            const flags = scanner2.getTokenFlags();
            return success && result === 9 /* BigIntLiteral */ && scanner2.getTextPos() === s.length + 1 && !(flags & 512 /* ContainsSeparator */) && (!roundTripOnly || s === pseudoBigIntToString({ negative, base10Value: parsePseudoBigInt(scanner2.getTokenValue()) }));
        }
        function isValidTypeOnlyAliasUseSite(useSite) {
            return !!(useSite.flags & 16777216 /* Ambient */) || isPartOfTypeQuery(useSite) || isIdentifierInNonEmittingHeritageClause(useSite) || isPartOfPossiblyValidTypeOrAbstractComputedPropertyName(useSite) || !(isExpressionNode(useSite) || isShorthandPropertyNameUseSite(useSite));
        }
        function isShorthandPropertyNameUseSite(useSite) {
            return isIdentifier(useSite) && isShorthandPropertyAssignment(useSite.parent) && useSite.parent.name === useSite;
        }
        function isPartOfPossiblyValidTypeOrAbstractComputedPropertyName(node) {
            while (node.kind === 79 /* Identifier */ || node.kind === 208 /* PropertyAccessExpression */) {
                node = node.parent;
            }
            if (node.kind !== 164 /* ComputedPropertyName */) {
                return false;
            }
            if (hasSyntacticModifier(node.parent, 256 /* Abstract */)) {
                return true;
            }
            const containerKind = node.parent.parent.kind;
            return containerKind === 261 /* InterfaceDeclaration */ || containerKind === 184 /* TypeLiteral */;
        }
        function isIdentifierInNonEmittingHeritageClause(node) {
            if (node.kind !== 79 /* Identifier */)
                return false;
            const heritageClause = findAncestor(node.parent, (parent2) => {
                switch (parent2.kind) {
                    case 294 /* HeritageClause */:
                        return true;
                    case 208 /* PropertyAccessExpression */:
                    case 230 /* ExpressionWithTypeArguments */:
                        return false;
                    default:
                        return "quit";
                }
            });
            return (heritageClause == null ? void 0 : heritageClause.token) === 117 /* ImplementsKeyword */ || (heritageClause == null ? void 0 : heritageClause.parent.kind) === 261 /* InterfaceDeclaration */;
        }
        function isIdentifierTypeReference(node) {
            return isTypeReferenceNode(node) && isIdentifier(node.typeName);
        }
        function arrayIsHomogeneous(array, comparer = equateValues) {
            if (array.length < 2)
                return true;
            const first2 = array[0];
            for (let i = 1, length2 = array.length; i < length2; i++) {
                const target = array[i];
                if (!comparer(first2, target))
                    return false;
            }
            return true;
        }
        function setTextRangePos(range, pos) {
            range.pos = pos;
            return range;
        }
        function setTextRangeEnd(range, end) {
            range.end = end;
            return range;
        }
        function setTextRangePosEnd(range, pos, end) {
            return setTextRangeEnd(setTextRangePos(range, pos), end);
        }
        function setTextRangePosWidth(range, pos, width) {
            return setTextRangePosEnd(range, pos, pos + width);
        }
        function setNodeFlags(node, newFlags) {
            if (node) {
                node.flags = newFlags;
            }
            return node;
        }
        function setParent(child, parent2) {
            if (child && parent2) {
                child.parent = parent2;
            }
            return child;
        }
        function setEachParent(children, parent2) {
            if (children) {
                for (const child of children) {
                    setParent(child, parent2);
                }
            }
            return children;
        }
        function setParentRecursive(rootNode, incremental) {
            if (!rootNode)
                return rootNode;
            forEachChildRecursively(rootNode, isJSDocNode(rootNode) ? bindParentToChildIgnoringJSDoc : bindParentToChild);
            return rootNode;
            function bindParentToChildIgnoringJSDoc(child, parent2) {
                if (incremental && child.parent === parent2) {
                    return "skip";
                }
                setParent(child, parent2);
            }
            function bindJSDoc(child) {
                if (hasJSDocNodes(child)) {
                    for (const doc of child.jsDoc) {
                        bindParentToChildIgnoringJSDoc(doc, child);
                        forEachChildRecursively(doc, bindParentToChildIgnoringJSDoc);
                    }
                }
            }
            function bindParentToChild(child, parent2) {
                return bindParentToChildIgnoringJSDoc(child, parent2) || bindJSDoc(child);
            }
        }
        function isPackedElement(node) {
            return !isOmittedExpression(node);
        }
        function isPackedArrayLiteral(node) {
            return isArrayLiteralExpression(node) && every(node.elements, isPackedElement);
        }
        function expressionResultIsUnused(node) {
            Debug.assertIsDefined(node.parent);
            while (true) {
                const parent2 = node.parent;
                if (isParenthesizedExpression(parent2)) {
                    node = parent2;
                    continue;
                }
                if (isExpressionStatement(parent2) || isVoidExpression(parent2) || isForStatement(parent2) && (parent2.initializer === node || parent2.incrementor === node)) {
                    return true;
                }
                if (isCommaListExpression(parent2)) {
                    if (node !== last(parent2.elements))
                        return true;
                    node = parent2;
                    continue;
                }
                if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 27 /* CommaToken */) {
                    if (node === parent2.left)
                        return true;
                    node = parent2;
                    continue;
                }
                return false;
            }
        }
        function containsIgnoredPath(path) {
            return some(ignoredPaths, (p) => stringContains(path, p));
        }
        function getContainingNodeArray(node) {
            if (!node.parent)
                return void 0;
            switch (node.kind) {
                case 165 /* TypeParameter */:
                    const { parent: parent3 } = node;
                    return parent3.kind === 192 /* InferType */ ? void 0 : parent3.typeParameters;
                case 166 /* Parameter */:
                    return node.parent.parameters;
                case 201 /* TemplateLiteralTypeSpan */:
                    return node.parent.templateSpans;
                case 236 /* TemplateSpan */:
                    return node.parent.templateSpans;
                case 167 /* Decorator */: {
                    const { parent: parent4 } = node;
                    return canHaveDecorators(parent4) ? parent4.modifiers : void 0;
                }
                case 294 /* HeritageClause */:
                    return node.parent.heritageClauses;
            }
            const { parent: parent2 } = node;
            if (isJSDocTag(node)) {
                return isJSDocTypeLiteral(node.parent) ? void 0 : node.parent.tags;
            }
            switch (parent2.kind) {
                case 184 /* TypeLiteral */:
                case 261 /* InterfaceDeclaration */:
                    return isTypeElement(node) ? parent2.members : void 0;
                case 189 /* UnionType */:
                case 190 /* IntersectionType */:
                    return parent2.types;
                case 186 /* TupleType */:
                case 206 /* ArrayLiteralExpression */:
                case 357 /* CommaListExpression */:
                case 272 /* NamedImports */:
                case 276 /* NamedExports */:
                    return parent2.elements;
                case 207 /* ObjectLiteralExpression */:
                case 289 /* JsxAttributes */:
                    return parent2.properties;
                case 210 /* CallExpression */:
                case 211 /* NewExpression */:
                    return isTypeNode(node) ? parent2.typeArguments : parent2.expression === node ? void 0 : parent2.arguments;
                case 281 /* JsxElement */:
                case 285 /* JsxFragment */:
                    return isJsxChild(node) ? parent2.children : void 0;
                case 283 /* JsxOpeningElement */:
                case 282 /* JsxSelfClosingElement */:
                    return isTypeNode(node) ? parent2.typeArguments : void 0;
                case 238 /* Block */:
                case 292 /* CaseClause */:
                case 293 /* DefaultClause */:
                case 265 /* ModuleBlock */:
                    return parent2.statements;
                case 266 /* CaseBlock */:
                    return parent2.clauses;
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                    return isClassElement(node) ? parent2.members : void 0;
                case 263 /* EnumDeclaration */:
                    return isEnumMember(node) ? parent2.members : void 0;
                case 308 /* SourceFile */:
                    return parent2.statements;
            }
        }
        function hasContextSensitiveParameters(node) {
            if (!node.typeParameters) {
                if (some(node.parameters, (p) => !getEffectiveTypeAnnotationNode(p))) {
                    return true;
                }
                if (node.kind !== 216 /* ArrowFunction */) {
                    const parameter = firstOrUndefined(node.parameters);
                    if (!(parameter && parameterIsThisKeyword(parameter))) {
                        return true;
                    }
                }
            }
            return false;
        }
        function isInfinityOrNaNString(name) {
            return name === "Infinity" || name === "-Infinity" || name === "NaN";
        }
        function isCatchClauseVariableDeclaration(node) {
            return node.kind === 257 /* VariableDeclaration */ && node.parent.kind === 295 /* CatchClause */;
        }
        function isParameterOrCatchClauseVariable(symbol) {
            const declaration = symbol.valueDeclaration && getRootDeclaration(symbol.valueDeclaration);
            return !!declaration && (isParameter(declaration) || isCatchClauseVariableDeclaration(declaration));
        }
        function isFunctionExpressionOrArrowFunction(node) {
            return node.kind === 215 /* FunctionExpression */ || node.kind === 216 /* ArrowFunction */;
        }
        function escapeSnippetText(text) {
            return text.replace(/\$/gm, () => "\\$");
        }
        function isNumericLiteralName(name) {
            return (+name).toString() === name;
        }
        function createPropertyNameNodeForIdentifierOrLiteral(name, target, singleQuote, stringNamed) {
            return isIdentifierText(name, target) ? factory.createIdentifier(name) : !stringNamed && isNumericLiteralName(name) && +name >= 0 ? factory.createNumericLiteral(+name) : factory.createStringLiteral(name, !!singleQuote);
        }
        function isThisTypeParameter(type) {
            return !!(type.flags & 262144 /* TypeParameter */ && type.isThisType);
        }
        function getNodeModulePathParts(fullPath) {
            let topLevelNodeModulesIndex = 0;
            let topLevelPackageNameIndex = 0;
            let packageRootIndex = 0;
            let fileNameIndex = 0;
            let States;
            ((States2) => {
                States2[States2["BeforeNodeModules"] = 0] = "BeforeNodeModules";
                States2[States2["NodeModules"] = 1] = "NodeModules";
                States2[States2["Scope"] = 2] = "Scope";
                States2[States2["PackageContent"] = 3] = "PackageContent";
            })(States || (States = {}));
            let partStart = 0;
            let partEnd = 0;
            let state = 0 /* BeforeNodeModules */;
            while (partEnd >= 0) {
                partStart = partEnd;
                partEnd = fullPath.indexOf("/", partStart + 1);
                switch (state) {
                    case 0 /* BeforeNodeModules */:
                        if (fullPath.indexOf(nodeModulesPathPart, partStart) === partStart) {
                            topLevelNodeModulesIndex = partStart;
                            topLevelPackageNameIndex = partEnd;
                            state = 1 /* NodeModules */;
                        }
                        break;
                    case 1 /* NodeModules */:
                    case 2 /* Scope */:
                        if (state === 1 /* NodeModules */ && fullPath.charAt(partStart + 1) === "@") {
                            state = 2 /* Scope */;
                        }
                        else {
                            packageRootIndex = partEnd;
                            state = 3 /* PackageContent */;
                        }
                        break;
                    case 3 /* PackageContent */:
                        if (fullPath.indexOf(nodeModulesPathPart, partStart) === partStart) {
                            state = 1 /* NodeModules */;
                        }
                        else {
                            state = 3 /* PackageContent */;
                        }
                        break;
                }
            }
            fileNameIndex = partStart;
            return state > 1 /* NodeModules */ ? { topLevelNodeModulesIndex, topLevelPackageNameIndex, packageRootIndex, fileNameIndex } : void 0;
        }
        function getParameterTypeNode(parameter) {
            var _a2;
            return parameter.kind === 344 /* JSDocParameterTag */ ? (_a2 = parameter.typeExpression) == null ? void 0 : _a2.type : parameter.type;
        }
        function isTypeDeclaration(node) {
            switch (node.kind) {
                case 165 /* TypeParameter */:
                case 260 /* ClassDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 263 /* EnumDeclaration */:
                case 349 /* JSDocTypedefTag */:
                case 341 /* JSDocCallbackTag */:
                case 343 /* JSDocEnumTag */:
                    return true;
                case 270 /* ImportClause */:
                    return node.isTypeOnly;
                case 273 /* ImportSpecifier */:
                case 278 /* ExportSpecifier */:
                    return node.parent.parent.isTypeOnly;
                default:
                    return false;
            }
        }
        function canHaveExportModifier(node) {
            return isEnumDeclaration(node) || isVariableStatement(node) || isFunctionDeclaration(node) || isClassDeclaration(node) || isInterfaceDeclaration(node) || isTypeDeclaration(node) || isModuleDeclaration(node) && !isExternalModuleAugmentation(node) && !isGlobalScopeAugmentation(node);
        }
        function isOptionalJSDocPropertyLikeTag(node) {
            if (!isJSDocPropertyLikeTag(node)) {
                return false;
            }
            const { isBracketed, typeExpression } = node;
            return isBracketed || !!typeExpression && typeExpression.type.kind === 319 /* JSDocOptionalType */;
        }
        function canUsePropertyAccess(name, languageVersion) {
            if (name.length === 0) {
                return false;
            }
            const firstChar = name.charCodeAt(0);
            return firstChar === 35 /* hash */ ? name.length > 1 && isIdentifierStart(name.charCodeAt(1), languageVersion) : isIdentifierStart(firstChar, languageVersion);
        }
        function hasTabstop(node) {
            var _a2;
            return ((_a2 = getSnippetElement(node)) == null ? void 0 : _a2.kind) === 0 /* TabStop */;
        }
        function isJSDocOptionalParameter(node) {
            return isInJSFile(node) && // node.type should only be a JSDocOptionalType when node is a parameter of a JSDocFunctionType
                (node.type && node.type.kind === 319 /* JSDocOptionalType */ || getJSDocParameterTags(node).some(({ isBracketed, typeExpression }) => isBracketed || !!typeExpression && typeExpression.type.kind === 319 /* JSDocOptionalType */));
        }
        function isOptionalDeclaration(declaration) {
            switch (declaration.kind) {
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                    return !!declaration.questionToken;
                case 166 /* Parameter */:
                    return !!declaration.questionToken || isJSDocOptionalParameter(declaration);
                case 351 /* JSDocPropertyTag */:
                case 344 /* JSDocParameterTag */:
                    return isOptionalJSDocPropertyLikeTag(declaration);
                default:
                    return false;
            }
        }
        function isNonNullAccess(node) {
            const kind = node.kind;
            return (kind === 208 /* PropertyAccessExpression */ || kind === 209 /* ElementAccessExpression */) && isNonNullExpression(node.expression);
        }
        function isJSDocSatisfiesExpression(node) {
            return isInJSFile(node) && isParenthesizedExpression(node) && hasJSDocNodes(node) && !!getJSDocSatisfiesTag(node);
        }
        function getJSDocSatisfiesExpressionType(node) {
            return Debug.checkDefined(tryGetJSDocSatisfiesTypeNode(node));
        }
        function tryGetJSDocSatisfiesTypeNode(node) {
            const tag = getJSDocSatisfiesTag(node);
            return tag && tag.typeExpression && tag.typeExpression.type;
        }
        var resolvingEmptyArray, externalHelpersModuleNameText, defaultMaximumTruncationLength, noTruncationMaximumTruncationLength, stringWriter, GetLiteralTextFlags, fullTripleSlashReferencePathRegEx, fullTripleSlashReferenceTypeReferenceDirectiveRegEx, fullTripleSlashAMDReferencePathRegEx, defaultLibReferenceRegEx, AssignmentKind, FunctionFlags, Associativity, OperatorPrecedence, templateSubstitutionRegExp, doubleQuoteEscapedCharsRegExp, singleQuoteEscapedCharsRegExp, backtickQuoteEscapedCharsRegExp, escapedCharsMap, nonAsciiCharacters, jsxDoubleQuoteEscapedCharsRegExp, jsxSingleQuoteEscapedCharsRegExp, jsxEscapedCharsMap, indentStrings, base64Digits, carriageReturnLineFeed, lineFeed, objectAllocator, objectAllocatorPatchers, localizedDiagnosticMessages, reservedCharacterPattern, wildcardCharCodes, commonPackageFolders, implicitExcludePathRegexPattern, filesMatcher, directoriesMatcher, excludeMatcher, wildcardMatchers, supportedTSExtensions, supportedTSExtensionsFlat, supportedTSExtensionsWithJson, supportedTSExtensionsForExtractExtension, supportedJSExtensions, supportedJSExtensionsFlat, allSupportedExtensions, allSupportedExtensionsWithJson, supportedDeclarationExtensions, supportedTSImplementationExtensions, ModuleSpecifierEnding, extensionsToRemove, emptyFileSystemEntries;
        var init_utilities = __esm({
            "src/compiler/utilities.ts"() {
                "use strict";
                init_ts2();
                resolvingEmptyArray = [];
                externalHelpersModuleNameText = "tslib";
                defaultMaximumTruncationLength = 160;
                noTruncationMaximumTruncationLength = 1e6;
                stringWriter = createSingleLineStringWriter();
                GetLiteralTextFlags = /* @__PURE__ */ ((GetLiteralTextFlags2) => {
                    GetLiteralTextFlags2[GetLiteralTextFlags2["None"] = 0] = "None";
                    GetLiteralTextFlags2[GetLiteralTextFlags2["NeverAsciiEscape"] = 1] = "NeverAsciiEscape";
                    GetLiteralTextFlags2[GetLiteralTextFlags2["JsxAttributeEscape"] = 2] = "JsxAttributeEscape";
                    GetLiteralTextFlags2[GetLiteralTextFlags2["TerminateUnterminatedLiterals"] = 4] = "TerminateUnterminatedLiterals";
                    GetLiteralTextFlags2[GetLiteralTextFlags2["AllowNumericSeparator"] = 8] = "AllowNumericSeparator";
                    return GetLiteralTextFlags2;
                })(GetLiteralTextFlags || {});
                fullTripleSlashReferencePathRegEx = /^(\/\/\/\s*<reference\s+path\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
                fullTripleSlashReferenceTypeReferenceDirectiveRegEx = /^(\/\/\/\s*<reference\s+types\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
                fullTripleSlashAMDReferencePathRegEx = /^(\/\/\/\s*<amd-dependency\s+path\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
                defaultLibReferenceRegEx = /^(\/\/\/\s*<reference\s+no-default-lib\s*=\s*)(('[^']*')|("[^"]*"))\s*\/>/;
                AssignmentKind = /* @__PURE__ */ ((AssignmentKind2) => {
                    AssignmentKind2[AssignmentKind2["None"] = 0] = "None";
                    AssignmentKind2[AssignmentKind2["Definite"] = 1] = "Definite";
                    AssignmentKind2[AssignmentKind2["Compound"] = 2] = "Compound";
                    return AssignmentKind2;
                })(AssignmentKind || {});
                FunctionFlags = /* @__PURE__ */ ((FunctionFlags2) => {
                    FunctionFlags2[FunctionFlags2["Normal"] = 0] = "Normal";
                    FunctionFlags2[FunctionFlags2["Generator"] = 1] = "Generator";
                    FunctionFlags2[FunctionFlags2["Async"] = 2] = "Async";
                    FunctionFlags2[FunctionFlags2["Invalid"] = 4] = "Invalid";
                    FunctionFlags2[FunctionFlags2["AsyncGenerator"] = 3] = "AsyncGenerator";
                    return FunctionFlags2;
                })(FunctionFlags || {});
                Associativity = /* @__PURE__ */ ((Associativity2) => {
                    Associativity2[Associativity2["Left"] = 0] = "Left";
                    Associativity2[Associativity2["Right"] = 1] = "Right";
                    return Associativity2;
                })(Associativity || {});
                OperatorPrecedence = /* @__PURE__ */ ((OperatorPrecedence2) => {
                    OperatorPrecedence2[OperatorPrecedence2["Comma"] = 0] = "Comma";
                    OperatorPrecedence2[OperatorPrecedence2["Spread"] = 1] = "Spread";
                    OperatorPrecedence2[OperatorPrecedence2["Yield"] = 2] = "Yield";
                    OperatorPrecedence2[OperatorPrecedence2["Assignment"] = 3] = "Assignment";
                    OperatorPrecedence2[OperatorPrecedence2["Conditional"] = 4] = "Conditional";
                    OperatorPrecedence2[OperatorPrecedence2["Coalesce"] = 4 /* Conditional */] = "Coalesce";
                    OperatorPrecedence2[OperatorPrecedence2["LogicalOR"] = 5] = "LogicalOR";
                    OperatorPrecedence2[OperatorPrecedence2["LogicalAND"] = 6] = "LogicalAND";
                    OperatorPrecedence2[OperatorPrecedence2["BitwiseOR"] = 7] = "BitwiseOR";
                    OperatorPrecedence2[OperatorPrecedence2["BitwiseXOR"] = 8] = "BitwiseXOR";
                    OperatorPrecedence2[OperatorPrecedence2["BitwiseAND"] = 9] = "BitwiseAND";
                    OperatorPrecedence2[OperatorPrecedence2["Equality"] = 10] = "Equality";
                    OperatorPrecedence2[OperatorPrecedence2["Relational"] = 11] = "Relational";
                    OperatorPrecedence2[OperatorPrecedence2["Shift"] = 12] = "Shift";
                    OperatorPrecedence2[OperatorPrecedence2["Additive"] = 13] = "Additive";
                    OperatorPrecedence2[OperatorPrecedence2["Multiplicative"] = 14] = "Multiplicative";
                    OperatorPrecedence2[OperatorPrecedence2["Exponentiation"] = 15] = "Exponentiation";
                    OperatorPrecedence2[OperatorPrecedence2["Unary"] = 16] = "Unary";
                    OperatorPrecedence2[OperatorPrecedence2["Update"] = 17] = "Update";
                    OperatorPrecedence2[OperatorPrecedence2["LeftHandSide"] = 18] = "LeftHandSide";
                    OperatorPrecedence2[OperatorPrecedence2["Member"] = 19] = "Member";
                    OperatorPrecedence2[OperatorPrecedence2["Primary"] = 20] = "Primary";
                    OperatorPrecedence2[OperatorPrecedence2["Highest"] = 20 /* Primary */] = "Highest";
                    OperatorPrecedence2[OperatorPrecedence2["Lowest"] = 0 /* Comma */] = "Lowest";
                    OperatorPrecedence2[OperatorPrecedence2["Invalid"] = -1] = "Invalid";
                    return OperatorPrecedence2;
                })(OperatorPrecedence || {});
                templateSubstitutionRegExp = /\$\{/g;
                doubleQuoteEscapedCharsRegExp = /[\\\"\u0000-\u001f\t\v\f\b\r\n\u2028\u2029\u0085]/g;
                singleQuoteEscapedCharsRegExp = /[\\\'\u0000-\u001f\t\v\f\b\r\n\u2028\u2029\u0085]/g;
                backtickQuoteEscapedCharsRegExp = /\r\n|[\\\`\u0000-\u001f\t\v\f\b\r\u2028\u2029\u0085]/g;
                escapedCharsMap = new Map(Object.entries({
                    "	": "\\t",
                    "\v": "\\v",
                    "\f": "\\f",
                    "\b": "\\b",
                    "\r": "\\r",
                    "\n": "\\n",
                    "\\": "\\\\",
                    '"': '\\"',
                    "'": "\\'",
                    "`": "\\`",
                    "\u2028": "\\u2028",
                    // lineSeparator
                    "\u2029": "\\u2029",
                    // paragraphSeparator
                    "\x85": "\\u0085",
                    // nextLine
                    "\r\n": "\\r\\n"
                    // special case for CRLFs in backticks
                }));
                nonAsciiCharacters = /[^\u0000-\u007F]/g;
                jsxDoubleQuoteEscapedCharsRegExp = /[\"\u0000-\u001f\u2028\u2029\u0085]/g;
                jsxSingleQuoteEscapedCharsRegExp = /[\'\u0000-\u001f\u2028\u2029\u0085]/g;
                jsxEscapedCharsMap = new Map(Object.entries({
                    '"': "&quot;",
                    "'": "&apos;"
                }));
                indentStrings = ["", "    "];
                base64Digits = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
                carriageReturnLineFeed = "\r\n";
                lineFeed = "\n";
                objectAllocator = {
                    getNodeConstructor: () => Node4,
                    getTokenConstructor: () => Token,
                    getIdentifierConstructor: () => Identifier2,
                    getPrivateIdentifierConstructor: () => Node4,
                    getSourceFileConstructor: () => Node4,
                    getSymbolConstructor: () => Symbol4,
                    getTypeConstructor: () => Type3,
                    getSignatureConstructor: () => Signature2,
                    getSourceMapSourceConstructor: () => SourceMapSource
                };
                objectAllocatorPatchers = [];
                reservedCharacterPattern = /[^\w\s\/]/g;
                wildcardCharCodes = [42 /* asterisk */, 63 /* question */];
                commonPackageFolders = ["node_modules", "bower_components", "jspm_packages"];
                implicitExcludePathRegexPattern = `(?!(${commonPackageFolders.join("|")})(/|$))`;
                filesMatcher = {
                    /**
                     * Matches any single directory segment unless it is the last segment and a .min.js file
                     * Breakdown:
                     *  [^./]                   # matches everything up to the first . character (excluding directory separators)
                     *  (\\.(?!min\\.js$))?     # matches . characters but not if they are part of the .min.js file extension
                     */
                    singleAsteriskRegexFragment: "([^./]|(\\.(?!min\\.js$))?)*",
                    /**
                     * Regex for the ** wildcard. Matches any number of subdirectories. When used for including
                     * files or directories, does not match subdirectories that start with a . character
                     */
                    doubleAsteriskRegexFragment: `(/${implicitExcludePathRegexPattern}[^/.][^/]*)*?`,
                    replaceWildcardCharacter: (match) => replaceWildcardCharacter(match, filesMatcher.singleAsteriskRegexFragment)
                };
                directoriesMatcher = {
                    singleAsteriskRegexFragment: "[^/]*",
                    /**
                     * Regex for the ** wildcard. Matches any number of subdirectories. When used for including
                     * files or directories, does not match subdirectories that start with a . character
                     */
                    doubleAsteriskRegexFragment: `(/${implicitExcludePathRegexPattern}[^/.][^/]*)*?`,
                    replaceWildcardCharacter: (match) => replaceWildcardCharacter(match, directoriesMatcher.singleAsteriskRegexFragment)
                };
                excludeMatcher = {
                    singleAsteriskRegexFragment: "[^/]*",
                    doubleAsteriskRegexFragment: "(/.+?)?",
                    replaceWildcardCharacter: (match) => replaceWildcardCharacter(match, excludeMatcher.singleAsteriskRegexFragment)
                };
                wildcardMatchers = {
                    files: filesMatcher,
                    directories: directoriesMatcher,
                    exclude: excludeMatcher
                };
                supportedTSExtensions = [[".ts" /* Ts */, ".tsx" /* Tsx */, ".d.ts" /* Dts */], [".cts" /* Cts */, ".d.cts" /* Dcts */], [".mts" /* Mts */, ".d.mts" /* Dmts */]];
                supportedTSExtensionsFlat = flatten(supportedTSExtensions);
                supportedTSExtensionsWithJson = [...supportedTSExtensions, [".json" /* Json */]];
                supportedTSExtensionsForExtractExtension = [".d.ts" /* Dts */, ".d.cts" /* Dcts */, ".d.mts" /* Dmts */, ".cts" /* Cts */, ".mts" /* Mts */, ".ts" /* Ts */, ".tsx" /* Tsx */, ".cts" /* Cts */, ".mts" /* Mts */];
                supportedJSExtensions = [[".js" /* Js */, ".jsx" /* Jsx */], [".mjs" /* Mjs */], [".cjs" /* Cjs */]];
                supportedJSExtensionsFlat = flatten(supportedJSExtensions);
                allSupportedExtensions = [[".ts" /* Ts */, ".tsx" /* Tsx */, ".d.ts" /* Dts */, ".js" /* Js */, ".jsx" /* Jsx */], [".cts" /* Cts */, ".d.cts" /* Dcts */, ".cjs" /* Cjs */], [".mts" /* Mts */, ".d.mts" /* Dmts */, ".mjs" /* Mjs */]];
                allSupportedExtensionsWithJson = [...allSupportedExtensions, [".json" /* Json */]];
                supportedDeclarationExtensions = [".d.ts" /* Dts */, ".d.cts" /* Dcts */, ".d.mts" /* Dmts */];
                supportedTSImplementationExtensions = [".ts" /* Ts */, ".cts" /* Cts */, ".mts" /* Mts */, ".tsx" /* Tsx */];
                ModuleSpecifierEnding = /* @__PURE__ */ ((ModuleSpecifierEnding2) => {
                    ModuleSpecifierEnding2[ModuleSpecifierEnding2["Minimal"] = 0] = "Minimal";
                    ModuleSpecifierEnding2[ModuleSpecifierEnding2["Index"] = 1] = "Index";
                    ModuleSpecifierEnding2[ModuleSpecifierEnding2["JsExtension"] = 2] = "JsExtension";
                    ModuleSpecifierEnding2[ModuleSpecifierEnding2["TsExtension"] = 3] = "TsExtension";
                    return ModuleSpecifierEnding2;
                })(ModuleSpecifierEnding || {});
                extensionsToRemove = [".d.ts" /* Dts */, ".d.mts" /* Dmts */, ".d.cts" /* Dcts */, ".mjs" /* Mjs */, ".mts" /* Mts */, ".cjs" /* Cjs */, ".cts" /* Cts */, ".ts" /* Ts */, ".js" /* Js */, ".tsx" /* Tsx */, ".jsx" /* Jsx */, ".json" /* Json */];
                emptyFileSystemEntries = {
                    files: emptyArray,
                    directories: emptyArray
                };
            }
        });
        // src/compiler/factory/baseNodeFactory.ts
        function createBaseNodeFactory() {
            let NodeConstructor2;
            let TokenConstructor2;
            let IdentifierConstructor2;
            let PrivateIdentifierConstructor2;
            let SourceFileConstructor2;
            return {
                createBaseSourceFileNode,
                createBaseIdentifierNode,
                createBasePrivateIdentifierNode,
                createBaseTokenNode,
                createBaseNode
            };
            function createBaseSourceFileNode(kind) {
                return new (SourceFileConstructor2 || (SourceFileConstructor2 = objectAllocator.getSourceFileConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
            function createBaseIdentifierNode(kind) {
                return new (IdentifierConstructor2 || (IdentifierConstructor2 = objectAllocator.getIdentifierConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
            function createBasePrivateIdentifierNode(kind) {
                return new (PrivateIdentifierConstructor2 || (PrivateIdentifierConstructor2 = objectAllocator.getPrivateIdentifierConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
            function createBaseTokenNode(kind) {
                return new (TokenConstructor2 || (TokenConstructor2 = objectAllocator.getTokenConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
            function createBaseNode(kind) {
                return new (NodeConstructor2 || (NodeConstructor2 = objectAllocator.getNodeConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
        }
        var init_baseNodeFactory = __esm({
            "src/compiler/factory/baseNodeFactory.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/factory/parenthesizerRules.ts
        function createParenthesizerRules(factory2) {
            let binaryLeftOperandParenthesizerCache;
            let binaryRightOperandParenthesizerCache;
            return {
                getParenthesizeLeftSideOfBinaryForOperator,
                getParenthesizeRightSideOfBinaryForOperator,
                parenthesizeLeftSideOfBinary,
                parenthesizeRightSideOfBinary,
                parenthesizeExpressionOfComputedPropertyName,
                parenthesizeConditionOfConditionalExpression,
                parenthesizeBranchOfConditionalExpression,
                parenthesizeExpressionOfExportDefault,
                parenthesizeExpressionOfNew,
                parenthesizeLeftSideOfAccess,
                parenthesizeOperandOfPostfixUnary,
                parenthesizeOperandOfPrefixUnary,
                parenthesizeExpressionsOfCommaDelimitedList,
                parenthesizeExpressionForDisallowedComma,
                parenthesizeExpressionOfExpressionStatement,
                parenthesizeConciseBodyOfArrowFunction,
                parenthesizeCheckTypeOfConditionalType,
                parenthesizeExtendsTypeOfConditionalType,
                parenthesizeConstituentTypesOfUnionType,
                parenthesizeConstituentTypeOfUnionType,
                parenthesizeConstituentTypesOfIntersectionType,
                parenthesizeConstituentTypeOfIntersectionType,
                parenthesizeOperandOfTypeOperator,
                parenthesizeOperandOfReadonlyTypeOperator,
                parenthesizeNonArrayTypeOfPostfixType,
                parenthesizeElementTypesOfTupleType,
                parenthesizeElementTypeOfTupleType,
                parenthesizeTypeOfOptionalType,
                parenthesizeTypeArguments,
                parenthesizeLeadingTypeArgument
            };
            function getParenthesizeLeftSideOfBinaryForOperator(operatorKind) {
                binaryLeftOperandParenthesizerCache || (binaryLeftOperandParenthesizerCache = /* @__PURE__ */ new Map());
                let parenthesizerRule = binaryLeftOperandParenthesizerCache.get(operatorKind);
                if (!parenthesizerRule) {
                    parenthesizerRule = (node) => parenthesizeLeftSideOfBinary(operatorKind, node);
                    binaryLeftOperandParenthesizerCache.set(operatorKind, parenthesizerRule);
                }
                return parenthesizerRule;
            }
            function getParenthesizeRightSideOfBinaryForOperator(operatorKind) {
                binaryRightOperandParenthesizerCache || (binaryRightOperandParenthesizerCache = /* @__PURE__ */ new Map());
                let parenthesizerRule = binaryRightOperandParenthesizerCache.get(operatorKind);
                if (!parenthesizerRule) {
                    parenthesizerRule = (node) => parenthesizeRightSideOfBinary(operatorKind, 
                    /*leftSide*/
                    void 0, node);
                    binaryRightOperandParenthesizerCache.set(operatorKind, parenthesizerRule);
                }
                return parenthesizerRule;
            }
            function binaryOperandNeedsParentheses(binaryOperator, operand, isLeftSideOfBinary, leftOperand) {
                const binaryOperatorPrecedence = getOperatorPrecedence(223 /* BinaryExpression */, binaryOperator);
                const binaryOperatorAssociativity = getOperatorAssociativity(223 /* BinaryExpression */, binaryOperator);
                const emittedOperand = skipPartiallyEmittedExpressions(operand);
                if (!isLeftSideOfBinary && operand.kind === 216 /* ArrowFunction */ && binaryOperatorPrecedence > 3 /* Assignment */) {
                    return true;
                }
                const operandPrecedence = getExpressionPrecedence(emittedOperand);
                switch (compareValues(operandPrecedence, binaryOperatorPrecedence)) {
                    case -1 /* LessThan */:
                        if (!isLeftSideOfBinary && binaryOperatorAssociativity === 1 /* Right */ && operand.kind === 226 /* YieldExpression */) {
                            return false;
                        }
                        return true;
                    case 1 /* GreaterThan */:
                        return false;
                    case 0 /* EqualTo */:
                        if (isLeftSideOfBinary) {
                            return binaryOperatorAssociativity === 1 /* Right */;
                        }
                        else {
                            if (isBinaryExpression(emittedOperand) && emittedOperand.operatorToken.kind === binaryOperator) {
                                if (operatorHasAssociativeProperty(binaryOperator)) {
                                    return false;
                                }
                                if (binaryOperator === 39 /* PlusToken */) {
                                    const leftKind = leftOperand ? getLiteralKindOfBinaryPlusOperand(leftOperand) : 0 /* Unknown */;
                                    if (isLiteralKind(leftKind) && leftKind === getLiteralKindOfBinaryPlusOperand(emittedOperand)) {
                                        return false;
                                    }
                                }
                            }
                            const operandAssociativity = getExpressionAssociativity(emittedOperand);
                            return operandAssociativity === 0 /* Left */;
                        }
                }
            }
            function operatorHasAssociativeProperty(binaryOperator) {
                return binaryOperator === 41 /* AsteriskToken */ || binaryOperator === 51 /* BarToken */ || binaryOperator === 50 /* AmpersandToken */ || binaryOperator === 52 /* CaretToken */ || binaryOperator === 27 /* CommaToken */;
            }
            function getLiteralKindOfBinaryPlusOperand(node) {
                node = skipPartiallyEmittedExpressions(node);
                if (isLiteralKind(node.kind)) {
                    return node.kind;
                }
                if (node.kind === 223 /* BinaryExpression */ && node.operatorToken.kind === 39 /* PlusToken */) {
                    if (node.cachedLiteralKind !== void 0) {
                        return node.cachedLiteralKind;
                    }
                    const leftKind = getLiteralKindOfBinaryPlusOperand(node.left);
                    const literalKind = isLiteralKind(leftKind) && leftKind === getLiteralKindOfBinaryPlusOperand(node.right) ? leftKind : 0 /* Unknown */;
                    node.cachedLiteralKind = literalKind;
                    return literalKind;
                }
                return 0 /* Unknown */;
            }
            function parenthesizeBinaryOperand(binaryOperator, operand, isLeftSideOfBinary, leftOperand) {
                const skipped = skipPartiallyEmittedExpressions(operand);
                if (skipped.kind === 214 /* ParenthesizedExpression */) {
                    return operand;
                }
                return binaryOperandNeedsParentheses(binaryOperator, operand, isLeftSideOfBinary, leftOperand) ? factory2.createParenthesizedExpression(operand) : operand;
            }
            function parenthesizeLeftSideOfBinary(binaryOperator, leftSide) {
                return parenthesizeBinaryOperand(binaryOperator, leftSide, 
                /*isLeftSideOfBinary*/
                true);
            }
            function parenthesizeRightSideOfBinary(binaryOperator, leftSide, rightSide) {
                return parenthesizeBinaryOperand(binaryOperator, rightSide, 
                /*isLeftSideOfBinary*/
                false, leftSide);
            }
            function parenthesizeExpressionOfComputedPropertyName(expression) {
                return isCommaSequence(expression) ? factory2.createParenthesizedExpression(expression) : expression;
            }
            function parenthesizeConditionOfConditionalExpression(condition) {
                const conditionalPrecedence = getOperatorPrecedence(224 /* ConditionalExpression */, 57 /* QuestionToken */);
                const emittedCondition = skipPartiallyEmittedExpressions(condition);
                const conditionPrecedence = getExpressionPrecedence(emittedCondition);
                if (compareValues(conditionPrecedence, conditionalPrecedence) !== 1 /* GreaterThan */) {
                    return factory2.createParenthesizedExpression(condition);
                }
                return condition;
            }
            function parenthesizeBranchOfConditionalExpression(branch) {
                const emittedExpression = skipPartiallyEmittedExpressions(branch);
                return isCommaSequence(emittedExpression) ? factory2.createParenthesizedExpression(branch) : branch;
            }
            function parenthesizeExpressionOfExportDefault(expression) {
                const check = skipPartiallyEmittedExpressions(expression);
                let needsParens = isCommaSequence(check);
                if (!needsParens) {
                    switch (getLeftmostExpression(check, 
                    /*stopAtCallExpression*/
                    false).kind) {
                        case 228 /* ClassExpression */:
                        case 215 /* FunctionExpression */:
                            needsParens = true;
                    }
                }
                return needsParens ? factory2.createParenthesizedExpression(expression) : expression;
            }
            function parenthesizeExpressionOfNew(expression) {
                const leftmostExpr = getLeftmostExpression(expression, 
                /*stopAtCallExpressions*/
                true);
                switch (leftmostExpr.kind) {
                    case 210 /* CallExpression */:
                        return factory2.createParenthesizedExpression(expression);
                    case 211 /* NewExpression */:
                        return !leftmostExpr.arguments ? factory2.createParenthesizedExpression(expression) : expression;
                }
                return parenthesizeLeftSideOfAccess(expression);
            }
            function parenthesizeLeftSideOfAccess(expression, optionalChain) {
                const emittedExpression = skipPartiallyEmittedExpressions(expression);
                if (isLeftHandSideExpression(emittedExpression) && (emittedExpression.kind !== 211 /* NewExpression */ || emittedExpression.arguments) && (optionalChain || !isOptionalChain(emittedExpression))) {
                    return expression;
                }
                return setTextRange(factory2.createParenthesizedExpression(expression), expression);
            }
            function parenthesizeOperandOfPostfixUnary(operand) {
                return isLeftHandSideExpression(operand) ? operand : setTextRange(factory2.createParenthesizedExpression(operand), operand);
            }
            function parenthesizeOperandOfPrefixUnary(operand) {
                return isUnaryExpression(operand) ? operand : setTextRange(factory2.createParenthesizedExpression(operand), operand);
            }
            function parenthesizeExpressionsOfCommaDelimitedList(elements) {
                const result = sameMap(elements, parenthesizeExpressionForDisallowedComma);
                return setTextRange(factory2.createNodeArray(result, elements.hasTrailingComma), elements);
            }
            function parenthesizeExpressionForDisallowedComma(expression) {
                const emittedExpression = skipPartiallyEmittedExpressions(expression);
                const expressionPrecedence = getExpressionPrecedence(emittedExpression);
                const commaPrecedence = getOperatorPrecedence(223 /* BinaryExpression */, 27 /* CommaToken */);
                return expressionPrecedence > commaPrecedence ? expression : setTextRange(factory2.createParenthesizedExpression(expression), expression);
            }
            function parenthesizeExpressionOfExpressionStatement(expression) {
                const emittedExpression = skipPartiallyEmittedExpressions(expression);
                if (isCallExpression(emittedExpression)) {
                    const callee = emittedExpression.expression;
                    const kind = skipPartiallyEmittedExpressions(callee).kind;
                    if (kind === 215 /* FunctionExpression */ || kind === 216 /* ArrowFunction */) {
                        const updated = factory2.updateCallExpression(emittedExpression, setTextRange(factory2.createParenthesizedExpression(callee), callee), emittedExpression.typeArguments, emittedExpression.arguments);
                        return factory2.restoreOuterExpressions(expression, updated, 8 /* PartiallyEmittedExpressions */);
                    }
                }
                const leftmostExpressionKind = getLeftmostExpression(emittedExpression, 
                /*stopAtCallExpressions*/
                false).kind;
                if (leftmostExpressionKind === 207 /* ObjectLiteralExpression */ || leftmostExpressionKind === 215 /* FunctionExpression */) {
                    return setTextRange(factory2.createParenthesizedExpression(expression), expression);
                }
                return expression;
            }
            function parenthesizeConciseBodyOfArrowFunction(body) {
                if (!isBlock(body) && (isCommaSequence(body) || getLeftmostExpression(body, 
                /*stopAtCallExpressions*/
                false).kind === 207 /* ObjectLiteralExpression */)) {
                    return setTextRange(factory2.createParenthesizedExpression(body), body);
                }
                return body;
            }
            function parenthesizeCheckTypeOfConditionalType(checkType) {
                switch (checkType.kind) {
                    case 181 /* FunctionType */:
                    case 182 /* ConstructorType */:
                    case 191 /* ConditionalType */:
                        return factory2.createParenthesizedType(checkType);
                }
                return checkType;
            }
            function parenthesizeExtendsTypeOfConditionalType(extendsType) {
                switch (extendsType.kind) {
                    case 191 /* ConditionalType */:
                        return factory2.createParenthesizedType(extendsType);
                }
                return extendsType;
            }
            function parenthesizeConstituentTypeOfUnionType(type) {
                switch (type.kind) {
                    case 189 /* UnionType */:
                    case 190 /* IntersectionType */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeCheckTypeOfConditionalType(type);
            }
            function parenthesizeConstituentTypesOfUnionType(members) {
                return factory2.createNodeArray(sameMap(members, parenthesizeConstituentTypeOfUnionType));
            }
            function parenthesizeConstituentTypeOfIntersectionType(type) {
                switch (type.kind) {
                    case 189 /* UnionType */:
                    case 190 /* IntersectionType */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeConstituentTypeOfUnionType(type);
            }
            function parenthesizeConstituentTypesOfIntersectionType(members) {
                return factory2.createNodeArray(sameMap(members, parenthesizeConstituentTypeOfIntersectionType));
            }
            function parenthesizeOperandOfTypeOperator(type) {
                switch (type.kind) {
                    case 190 /* IntersectionType */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeConstituentTypeOfIntersectionType(type);
            }
            function parenthesizeOperandOfReadonlyTypeOperator(type) {
                switch (type.kind) {
                    case 195 /* TypeOperator */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeOperandOfTypeOperator(type);
            }
            function parenthesizeNonArrayTypeOfPostfixType(type) {
                switch (type.kind) {
                    case 192 /* InferType */:
                    case 195 /* TypeOperator */:
                    case 183 /* TypeQuery */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeOperandOfTypeOperator(type);
            }
            function parenthesizeElementTypesOfTupleType(types) {
                return factory2.createNodeArray(sameMap(types, parenthesizeElementTypeOfTupleType));
            }
            function parenthesizeElementTypeOfTupleType(type) {
                if (hasJSDocPostfixQuestion(type))
                    return factory2.createParenthesizedType(type);
                return type;
            }
            function hasJSDocPostfixQuestion(type) {
                if (isJSDocNullableType(type))
                    return type.postfix;
                if (isNamedTupleMember(type))
                    return hasJSDocPostfixQuestion(type.type);
                if (isFunctionTypeNode(type) || isConstructorTypeNode(type) || isTypeOperatorNode(type))
                    return hasJSDocPostfixQuestion(type.type);
                if (isConditionalTypeNode(type))
                    return hasJSDocPostfixQuestion(type.falseType);
                if (isUnionTypeNode(type))
                    return hasJSDocPostfixQuestion(last(type.types));
                if (isIntersectionTypeNode(type))
                    return hasJSDocPostfixQuestion(last(type.types));
                if (isInferTypeNode(type))
                    return !!type.typeParameter.constraint && hasJSDocPostfixQuestion(type.typeParameter.constraint);
                return false;
            }
            function parenthesizeTypeOfOptionalType(type) {
                if (hasJSDocPostfixQuestion(type))
                    return factory2.createParenthesizedType(type);
                return parenthesizeNonArrayTypeOfPostfixType(type);
            }
            function parenthesizeLeadingTypeArgument(node) {
                return isFunctionOrConstructorTypeNode(node) && node.typeParameters ? factory2.createParenthesizedType(node) : node;
            }
            function parenthesizeOrdinalTypeArgument(node, i) {
                return i === 0 ? parenthesizeLeadingTypeArgument(node) : node;
            }
            function parenthesizeTypeArguments(typeArguments) {
                if (some(typeArguments)) {
                    return factory2.createNodeArray(sameMap(typeArguments, parenthesizeOrdinalTypeArgument));
                }
            }
        }
        var nullParenthesizerRules;
        var init_parenthesizerRules = __esm({
            "src/compiler/factory/parenthesizerRules.ts"() {
                "use strict";
                init_ts2();
                nullParenthesizerRules = {
                    getParenthesizeLeftSideOfBinaryForOperator: (_) => identity,
                    getParenthesizeRightSideOfBinaryForOperator: (_) => identity,
                    parenthesizeLeftSideOfBinary: (_binaryOperator, leftSide) => leftSide,
                    parenthesizeRightSideOfBinary: (_binaryOperator, _leftSide, rightSide) => rightSide,
                    parenthesizeExpressionOfComputedPropertyName: identity,
                    parenthesizeConditionOfConditionalExpression: identity,
                    parenthesizeBranchOfConditionalExpression: identity,
                    parenthesizeExpressionOfExportDefault: identity,
                    parenthesizeExpressionOfNew: (expression) => cast(expression, isLeftHandSideExpression),
                    parenthesizeLeftSideOfAccess: (expression) => cast(expression, isLeftHandSideExpression),
                    parenthesizeOperandOfPostfixUnary: (operand) => cast(operand, isLeftHandSideExpression),
                    parenthesizeOperandOfPrefixUnary: (operand) => cast(operand, isUnaryExpression),
                    parenthesizeExpressionsOfCommaDelimitedList: (nodes) => cast(nodes, isNodeArray),
                    parenthesizeExpressionForDisallowedComma: identity,
                    parenthesizeExpressionOfExpressionStatement: identity,
                    parenthesizeConciseBodyOfArrowFunction: identity,
                    parenthesizeCheckTypeOfConditionalType: identity,
                    parenthesizeExtendsTypeOfConditionalType: identity,
                    parenthesizeConstituentTypesOfUnionType: (nodes) => cast(nodes, isNodeArray),
                    parenthesizeConstituentTypeOfUnionType: identity,
                    parenthesizeConstituentTypesOfIntersectionType: (nodes) => cast(nodes, isNodeArray),
                    parenthesizeConstituentTypeOfIntersectionType: identity,
                    parenthesizeOperandOfTypeOperator: identity,
                    parenthesizeOperandOfReadonlyTypeOperator: identity,
                    parenthesizeNonArrayTypeOfPostfixType: identity,
                    parenthesizeElementTypesOfTupleType: (nodes) => cast(nodes, isNodeArray),
                    parenthesizeElementTypeOfTupleType: identity,
                    parenthesizeTypeOfOptionalType: identity,
                    parenthesizeTypeArguments: (nodes) => nodes && cast(nodes, isNodeArray),
                    parenthesizeLeadingTypeArgument: identity
                };
            }
        });
        // src/compiler/factory/nodeConverters.ts
        function createNodeConverters(factory2) {
            return {
                convertToFunctionBlock,
                convertToFunctionExpression,
                convertToArrayAssignmentElement,
                convertToObjectAssignmentElement,
                convertToAssignmentPattern,
                convertToObjectAssignmentPattern,
                convertToArrayAssignmentPattern,
                convertToAssignmentElementTarget
            };
            function convertToFunctionBlock(node, multiLine) {
                if (isBlock(node))
                    return node;
                const returnStatement = factory2.createReturnStatement(node);
                setTextRange(returnStatement, node);
                const body = factory2.createBlock([returnStatement], multiLine);
                setTextRange(body, node);
                return body;
            }
            function convertToFunctionExpression(node) {
                if (!node.body)
                    return Debug.fail(`Cannot convert a FunctionDeclaration without a body`);
                const updated = factory2.createFunctionExpression(getModifiers(node), node.asteriskToken, node.name, node.typeParameters, node.parameters, node.type, node.body);
                setOriginalNode(updated, node);
                setTextRange(updated, node);
                if (getStartsOnNewLine(node)) {
                    setStartsOnNewLine(updated, 
                    /*newLine*/
                    true);
                }
                return updated;
            }
            function convertToArrayAssignmentElement(element) {
                if (isBindingElement(element)) {
                    if (element.dotDotDotToken) {
                        Debug.assertNode(element.name, isIdentifier);
                        return setOriginalNode(setTextRange(factory2.createSpreadElement(element.name), element), element);
                    }
                    const expression = convertToAssignmentElementTarget(element.name);
                    return element.initializer ? setOriginalNode(setTextRange(factory2.createAssignment(expression, element.initializer), element), element) : expression;
                }
                return cast(element, isExpression);
            }
            function convertToObjectAssignmentElement(element) {
                if (isBindingElement(element)) {
                    if (element.dotDotDotToken) {
                        Debug.assertNode(element.name, isIdentifier);
                        return setOriginalNode(setTextRange(factory2.createSpreadAssignment(element.name), element), element);
                    }
                    if (element.propertyName) {
                        const expression = convertToAssignmentElementTarget(element.name);
                        return setOriginalNode(setTextRange(factory2.createPropertyAssignment(element.propertyName, element.initializer ? factory2.createAssignment(expression, element.initializer) : expression), element), element);
                    }
                    Debug.assertNode(element.name, isIdentifier);
                    return setOriginalNode(setTextRange(factory2.createShorthandPropertyAssignment(element.name, element.initializer), element), element);
                }
                return cast(element, isObjectLiteralElementLike);
            }
            function convertToAssignmentPattern(node) {
                switch (node.kind) {
                    case 204 /* ArrayBindingPattern */:
                    case 206 /* ArrayLiteralExpression */:
                        return convertToArrayAssignmentPattern(node);
                    case 203 /* ObjectBindingPattern */:
                    case 207 /* ObjectLiteralExpression */:
                        return convertToObjectAssignmentPattern(node);
                }
            }
            function convertToObjectAssignmentPattern(node) {
                if (isObjectBindingPattern(node)) {
                    return setOriginalNode(setTextRange(factory2.createObjectLiteralExpression(map(node.elements, convertToObjectAssignmentElement)), node), node);
                }
                return cast(node, isObjectLiteralExpression);
            }
            function convertToArrayAssignmentPattern(node) {
                if (isArrayBindingPattern(node)) {
                    return setOriginalNode(setTextRange(factory2.createArrayLiteralExpression(map(node.elements, convertToArrayAssignmentElement)), node), node);
                }
                return cast(node, isArrayLiteralExpression);
            }
            function convertToAssignmentElementTarget(node) {
                if (isBindingPattern(node)) {
                    return convertToAssignmentPattern(node);
                }
                return cast(node, isExpression);
            }
        }
        var nullNodeConverters;
        var init_nodeConverters = __esm({
            "src/compiler/factory/nodeConverters.ts"() {
                "use strict";
                init_ts2();
                nullNodeConverters = {
                    convertToFunctionBlock: notImplemented,
                    convertToFunctionExpression: notImplemented,
                    convertToArrayAssignmentElement: notImplemented,
                    convertToObjectAssignmentElement: notImplemented,
                    convertToAssignmentPattern: notImplemented,
                    convertToObjectAssignmentPattern: notImplemented,
                    convertToArrayAssignmentPattern: notImplemented,
                    convertToAssignmentElementTarget: notImplemented
                };
            }
        });
        // src/compiler/factory/nodeFactory.ts
        function addNodeFactoryPatcher(fn) {
            nodeFactoryPatchers.push(fn);
        }
        function createNodeFactory(flags, baseFactory2) {
            const update = flags & 8 /* NoOriginalNode */ ? updateWithoutOriginal : updateWithOriginal;
            const parenthesizerRules = memoize(() => flags & 1 /* NoParenthesizerRules */ ? nullParenthesizerRules : createParenthesizerRules(factory2));
            const converters = memoize(() => flags & 2 /* NoNodeConverters */ ? nullNodeConverters : createNodeConverters(factory2));
            const getBinaryCreateFunction = memoizeOne((operator) => (left, right) => createBinaryExpression(left, operator, right));
            const getPrefixUnaryCreateFunction = memoizeOne((operator) => (operand) => createPrefixUnaryExpression(operator, operand));
            const getPostfixUnaryCreateFunction = memoizeOne((operator) => (operand) => createPostfixUnaryExpression(operand, operator));
            const getJSDocPrimaryTypeCreateFunction = memoizeOne((kind) => () => createJSDocPrimaryTypeWorker(kind));
            const getJSDocUnaryTypeCreateFunction = memoizeOne((kind) => (type) => createJSDocUnaryTypeWorker(kind, type));
            const getJSDocUnaryTypeUpdateFunction = memoizeOne((kind) => (node, type) => updateJSDocUnaryTypeWorker(kind, node, type));
            const getJSDocPrePostfixUnaryTypeCreateFunction = memoizeOne((kind) => (type, postfix) => createJSDocPrePostfixUnaryTypeWorker(kind, type, postfix));
            const getJSDocPrePostfixUnaryTypeUpdateFunction = memoizeOne((kind) => (node, type) => updateJSDocPrePostfixUnaryTypeWorker(kind, node, type));
            const getJSDocSimpleTagCreateFunction = memoizeOne((kind) => (tagName, comment) => createJSDocSimpleTagWorker(kind, tagName, comment));
            const getJSDocSimpleTagUpdateFunction = memoizeOne((kind) => (node, tagName, comment) => updateJSDocSimpleTagWorker(kind, node, tagName, comment));
            const getJSDocTypeLikeTagCreateFunction = memoizeOne((kind) => (tagName, typeExpression, comment) => createJSDocTypeLikeTagWorker(kind, tagName, typeExpression, comment));
            const getJSDocTypeLikeTagUpdateFunction = memoizeOne((kind) => (node, tagName, typeExpression, comment) => updateJSDocTypeLikeTagWorker(kind, node, tagName, typeExpression, comment));
            const factory2 = {
                get parenthesizer() {
                    return parenthesizerRules();
                },
                get converters() {
                    return converters();
                },
                baseFactory: baseFactory2,
                flags,
                createNodeArray,
                createNumericLiteral,
                createBigIntLiteral,
                createStringLiteral,
                createStringLiteralFromNode,
                createRegularExpressionLiteral,
                createLiteralLikeNode,
                createIdentifier,
                createTempVariable,
                createLoopVariable,
                createUniqueName,
                getGeneratedNameForNode,
                createPrivateIdentifier,
                createUniquePrivateName,
                getGeneratedPrivateNameForNode,
                createToken,
                createSuper,
                createThis,
                createNull,
                createTrue,
                createFalse,
                createModifier,
                createModifiersFromModifierFlags,
                createQualifiedName,
                updateQualifiedName,
                createComputedPropertyName,
                updateComputedPropertyName,
                createTypeParameterDeclaration,
                updateTypeParameterDeclaration,
                createParameterDeclaration,
                updateParameterDeclaration,
                createDecorator,
                updateDecorator,
                createPropertySignature,
                updatePropertySignature,
                createPropertyDeclaration,
                updatePropertyDeclaration: updatePropertyDeclaration2,
                createMethodSignature,
                updateMethodSignature,
                createMethodDeclaration,
                updateMethodDeclaration,
                createConstructorDeclaration,
                updateConstructorDeclaration,
                createGetAccessorDeclaration,
                updateGetAccessorDeclaration,
                createSetAccessorDeclaration,
                updateSetAccessorDeclaration,
                createCallSignature,
                updateCallSignature,
                createConstructSignature,
                updateConstructSignature,
                createIndexSignature,
                updateIndexSignature,
                createClassStaticBlockDeclaration,
                updateClassStaticBlockDeclaration,
                createTemplateLiteralTypeSpan,
                updateTemplateLiteralTypeSpan,
                createKeywordTypeNode,
                createTypePredicateNode,
                updateTypePredicateNode,
                createTypeReferenceNode,
                updateTypeReferenceNode,
                createFunctionTypeNode,
                updateFunctionTypeNode,
                createConstructorTypeNode,
                updateConstructorTypeNode,
                createTypeQueryNode,
                updateTypeQueryNode,
                createTypeLiteralNode,
                updateTypeLiteralNode,
                createArrayTypeNode,
                updateArrayTypeNode,
                createTupleTypeNode,
                updateTupleTypeNode,
                createNamedTupleMember,
                updateNamedTupleMember,
                createOptionalTypeNode,
                updateOptionalTypeNode,
                createRestTypeNode,
                updateRestTypeNode,
                createUnionTypeNode,
                updateUnionTypeNode,
                createIntersectionTypeNode,
                updateIntersectionTypeNode,
                createConditionalTypeNode,
                updateConditionalTypeNode,
                createInferTypeNode,
                updateInferTypeNode,
                createImportTypeNode,
                updateImportTypeNode,
                createParenthesizedType,
                updateParenthesizedType,
                createThisTypeNode,
                createTypeOperatorNode,
                updateTypeOperatorNode,
                createIndexedAccessTypeNode,
                updateIndexedAccessTypeNode,
                createMappedTypeNode,
                updateMappedTypeNode,
                createLiteralTypeNode,
                updateLiteralTypeNode,
                createTemplateLiteralType,
                updateTemplateLiteralType,
                createObjectBindingPattern,
                updateObjectBindingPattern,
                createArrayBindingPattern,
                updateArrayBindingPattern,
                createBindingElement,
                updateBindingElement,
                createArrayLiteralExpression,
                updateArrayLiteralExpression,
                createObjectLiteralExpression,
                updateObjectLiteralExpression,
                createPropertyAccessExpression: flags & 4 /* NoIndentationOnFreshPropertyAccess */ ? (expression, name) => setEmitFlags(createPropertyAccessExpression(expression, name), 262144 /* NoIndentation */) : createPropertyAccessExpression,
                updatePropertyAccessExpression,
                createPropertyAccessChain: flags & 4 /* NoIndentationOnFreshPropertyAccess */ ? (expression, questionDotToken, name) => setEmitFlags(createPropertyAccessChain(expression, questionDotToken, name), 262144 /* NoIndentation */) : createPropertyAccessChain,
                updatePropertyAccessChain,
                createElementAccessExpression,
                updateElementAccessExpression,
                createElementAccessChain,
                updateElementAccessChain,
                createCallExpression,
                updateCallExpression,
                createCallChain,
                updateCallChain,
                createNewExpression,
                updateNewExpression,
                createTaggedTemplateExpression,
                updateTaggedTemplateExpression,
                createTypeAssertion,
                updateTypeAssertion,
                createParenthesizedExpression,
                updateParenthesizedExpression,
                createFunctionExpression,
                updateFunctionExpression,
                createArrowFunction,
                updateArrowFunction,
                createDeleteExpression,
                updateDeleteExpression,
                createTypeOfExpression,
                updateTypeOfExpression,
                createVoidExpression,
                updateVoidExpression,
                createAwaitExpression,
                updateAwaitExpression,
                createPrefixUnaryExpression,
                updatePrefixUnaryExpression,
                createPostfixUnaryExpression,
                updatePostfixUnaryExpression,
                createBinaryExpression,
                updateBinaryExpression,
                createConditionalExpression,
                updateConditionalExpression,
                createTemplateExpression,
                updateTemplateExpression,
                createTemplateHead,
                createTemplateMiddle,
                createTemplateTail,
                createNoSubstitutionTemplateLiteral,
                createTemplateLiteralLikeNode,
                createYieldExpression,
                updateYieldExpression,
                createSpreadElement,
                updateSpreadElement,
                createClassExpression,
                updateClassExpression,
                createOmittedExpression,
                createExpressionWithTypeArguments,
                updateExpressionWithTypeArguments,
                createAsExpression,
                updateAsExpression,
                createNonNullExpression,
                updateNonNullExpression,
                createSatisfiesExpression,
                updateSatisfiesExpression,
                createNonNullChain,
                updateNonNullChain,
                createMetaProperty,
                updateMetaProperty,
                createTemplateSpan,
                updateTemplateSpan,
                createSemicolonClassElement,
                createBlock,
                updateBlock,
                createVariableStatement,
                updateVariableStatement,
                createEmptyStatement,
                createExpressionStatement,
                updateExpressionStatement,
                createIfStatement,
                updateIfStatement,
                createDoStatement,
                updateDoStatement,
                createWhileStatement,
                updateWhileStatement,
                createForStatement,
                updateForStatement,
                createForInStatement,
                updateForInStatement,
                createForOfStatement,
                updateForOfStatement,
                createContinueStatement,
                updateContinueStatement,
                createBreakStatement,
                updateBreakStatement,
                createReturnStatement,
                updateReturnStatement,
                createWithStatement,
                updateWithStatement,
                createSwitchStatement,
                updateSwitchStatement,
                createLabeledStatement,
                updateLabeledStatement,
                createThrowStatement,
                updateThrowStatement,
                createTryStatement,
                updateTryStatement,
                createDebuggerStatement,
                createVariableDeclaration,
                updateVariableDeclaration,
                createVariableDeclarationList,
                updateVariableDeclarationList,
                createFunctionDeclaration,
                updateFunctionDeclaration,
                createClassDeclaration,
                updateClassDeclaration,
                createInterfaceDeclaration,
                updateInterfaceDeclaration,
                createTypeAliasDeclaration,
                updateTypeAliasDeclaration,
                createEnumDeclaration,
                updateEnumDeclaration,
                createModuleDeclaration,
                updateModuleDeclaration,
                createModuleBlock,
                updateModuleBlock,
                createCaseBlock,
                updateCaseBlock,
                createNamespaceExportDeclaration,
                updateNamespaceExportDeclaration,
                createImportEqualsDeclaration,
                updateImportEqualsDeclaration,
                createImportDeclaration,
                updateImportDeclaration,
                createImportClause,
                updateImportClause,
                createAssertClause,
                updateAssertClause,
                createAssertEntry,
                updateAssertEntry,
                createImportTypeAssertionContainer,
                updateImportTypeAssertionContainer,
                createNamespaceImport,
                updateNamespaceImport,
                createNamespaceExport,
                updateNamespaceExport,
                createNamedImports,
                updateNamedImports,
                createImportSpecifier,
                updateImportSpecifier,
                createExportAssignment: createExportAssignment2,
                updateExportAssignment,
                createExportDeclaration,
                updateExportDeclaration,
                createNamedExports,
                updateNamedExports,
                createExportSpecifier,
                updateExportSpecifier,
                createMissingDeclaration,
                createExternalModuleReference,
                updateExternalModuleReference,
                // lazily load factory members for JSDoc types with similar structure
                get createJSDocAllType() {
                    return getJSDocPrimaryTypeCreateFunction(315 /* JSDocAllType */);
                },
                get createJSDocUnknownType() {
                    return getJSDocPrimaryTypeCreateFunction(316 /* JSDocUnknownType */);
                },
                get createJSDocNonNullableType() {
                    return getJSDocPrePostfixUnaryTypeCreateFunction(318 /* JSDocNonNullableType */);
                },
                get updateJSDocNonNullableType() {
                    return getJSDocPrePostfixUnaryTypeUpdateFunction(318 /* JSDocNonNullableType */);
                },
                get createJSDocNullableType() {
                    return getJSDocPrePostfixUnaryTypeCreateFunction(317 /* JSDocNullableType */);
                },
                get updateJSDocNullableType() {
                    return getJSDocPrePostfixUnaryTypeUpdateFunction(317 /* JSDocNullableType */);
                },
                get createJSDocOptionalType() {
                    return getJSDocUnaryTypeCreateFunction(319 /* JSDocOptionalType */);
                },
                get updateJSDocOptionalType() {
                    return getJSDocUnaryTypeUpdateFunction(319 /* JSDocOptionalType */);
                },
                get createJSDocVariadicType() {
                    return getJSDocUnaryTypeCreateFunction(321 /* JSDocVariadicType */);
                },
                get updateJSDocVariadicType() {
                    return getJSDocUnaryTypeUpdateFunction(321 /* JSDocVariadicType */);
                },
                get createJSDocNamepathType() {
                    return getJSDocUnaryTypeCreateFunction(322 /* JSDocNamepathType */);
                },
                get updateJSDocNamepathType() {
                    return getJSDocUnaryTypeUpdateFunction(322 /* JSDocNamepathType */);
                },
                createJSDocFunctionType,
                updateJSDocFunctionType,
                createJSDocTypeLiteral,
                updateJSDocTypeLiteral,
                createJSDocTypeExpression,
                updateJSDocTypeExpression,
                createJSDocSignature,
                updateJSDocSignature,
                createJSDocTemplateTag,
                updateJSDocTemplateTag,
                createJSDocTypedefTag,
                updateJSDocTypedefTag,
                createJSDocParameterTag,
                updateJSDocParameterTag,
                createJSDocPropertyTag,
                updateJSDocPropertyTag,
                createJSDocCallbackTag,
                updateJSDocCallbackTag,
                createJSDocOverloadTag,
                updateJSDocOverloadTag,
                createJSDocAugmentsTag,
                updateJSDocAugmentsTag,
                createJSDocImplementsTag,
                updateJSDocImplementsTag,
                createJSDocSeeTag,
                updateJSDocSeeTag,
                createJSDocNameReference,
                updateJSDocNameReference,
                createJSDocMemberName,
                updateJSDocMemberName,
                createJSDocLink,
                updateJSDocLink,
                createJSDocLinkCode,
                updateJSDocLinkCode,
                createJSDocLinkPlain,
                updateJSDocLinkPlain,
                // lazily load factory members for JSDoc tags with similar structure
                get createJSDocTypeTag() {
                    return getJSDocTypeLikeTagCreateFunction(347 /* JSDocTypeTag */);
                },
                get updateJSDocTypeTag() {
                    return getJSDocTypeLikeTagUpdateFunction(347 /* JSDocTypeTag */);
                },
                get createJSDocReturnTag() {
                    return getJSDocTypeLikeTagCreateFunction(345 /* JSDocReturnTag */);
                },
                get updateJSDocReturnTag() {
                    return getJSDocTypeLikeTagUpdateFunction(345 /* JSDocReturnTag */);
                },
                get createJSDocThisTag() {
                    return getJSDocTypeLikeTagCreateFunction(346 /* JSDocThisTag */);
                },
                get updateJSDocThisTag() {
                    return getJSDocTypeLikeTagUpdateFunction(346 /* JSDocThisTag */);
                },
                get createJSDocAuthorTag() {
                    return getJSDocSimpleTagCreateFunction(333 /* JSDocAuthorTag */);
                },
                get updateJSDocAuthorTag() {
                    return getJSDocSimpleTagUpdateFunction(333 /* JSDocAuthorTag */);
                },
                get createJSDocClassTag() {
                    return getJSDocSimpleTagCreateFunction(335 /* JSDocClassTag */);
                },
                get updateJSDocClassTag() {
                    return getJSDocSimpleTagUpdateFunction(335 /* JSDocClassTag */);
                },
                get createJSDocPublicTag() {
                    return getJSDocSimpleTagCreateFunction(336 /* JSDocPublicTag */);
                },
                get updateJSDocPublicTag() {
                    return getJSDocSimpleTagUpdateFunction(336 /* JSDocPublicTag */);
                },
                get createJSDocPrivateTag() {
                    return getJSDocSimpleTagCreateFunction(337 /* JSDocPrivateTag */);
                },
                get updateJSDocPrivateTag() {
                    return getJSDocSimpleTagUpdateFunction(337 /* JSDocPrivateTag */);
                },
                get createJSDocProtectedTag() {
                    return getJSDocSimpleTagCreateFunction(338 /* JSDocProtectedTag */);
                },
                get updateJSDocProtectedTag() {
                    return getJSDocSimpleTagUpdateFunction(338 /* JSDocProtectedTag */);
                },
                get createJSDocReadonlyTag() {
                    return getJSDocSimpleTagCreateFunction(339 /* JSDocReadonlyTag */);
                },
                get updateJSDocReadonlyTag() {
                    return getJSDocSimpleTagUpdateFunction(339 /* JSDocReadonlyTag */);
                },
                get createJSDocOverrideTag() {
                    return getJSDocSimpleTagCreateFunction(340 /* JSDocOverrideTag */);
                },
                get updateJSDocOverrideTag() {
                    return getJSDocSimpleTagUpdateFunction(340 /* JSDocOverrideTag */);
                },
                get createJSDocDeprecatedTag() {
                    return getJSDocSimpleTagCreateFunction(334 /* JSDocDeprecatedTag */);
                },
                get updateJSDocDeprecatedTag() {
                    return getJSDocSimpleTagUpdateFunction(334 /* JSDocDeprecatedTag */);
                },
                get createJSDocThrowsTag() {
                    return getJSDocTypeLikeTagCreateFunction(352 /* JSDocThrowsTag */);
                },
                get updateJSDocThrowsTag() {
                    return getJSDocTypeLikeTagUpdateFunction(352 /* JSDocThrowsTag */);
                },
                get createJSDocSatisfiesTag() {
                    return getJSDocTypeLikeTagCreateFunction(353 /* JSDocSatisfiesTag */);
                },
                get updateJSDocSatisfiesTag() {
                    return getJSDocTypeLikeTagUpdateFunction(353 /* JSDocSatisfiesTag */);
                },
                createJSDocEnumTag,
                updateJSDocEnumTag,
                createJSDocUnknownTag,
                updateJSDocUnknownTag,
                createJSDocText,
                updateJSDocText,
                createJSDocComment,
                updateJSDocComment,
                createJsxElement,
                updateJsxElement,
                createJsxSelfClosingElement,
                updateJsxSelfClosingElement,
                createJsxOpeningElement,
                updateJsxOpeningElement,
                createJsxClosingElement,
                updateJsxClosingElement,
                createJsxFragment,
                createJsxText,
                updateJsxText,
                createJsxOpeningFragment,
                createJsxJsxClosingFragment,
                updateJsxFragment,
                createJsxAttribute,
                updateJsxAttribute,
                createJsxAttributes,
                updateJsxAttributes,
                createJsxSpreadAttribute,
                updateJsxSpreadAttribute,
                createJsxExpression,
                updateJsxExpression,
                createCaseClause,
                updateCaseClause,
                createDefaultClause,
                updateDefaultClause,
                createHeritageClause,
                updateHeritageClause,
                createCatchClause,
                updateCatchClause,
                createPropertyAssignment,
                updatePropertyAssignment,
                createShorthandPropertyAssignment,
                updateShorthandPropertyAssignment,
                createSpreadAssignment,
                updateSpreadAssignment,
                createEnumMember,
                updateEnumMember,
                createSourceFile: createSourceFile2,
                updateSourceFile: updateSourceFile2,
                createRedirectedSourceFile,
                createBundle,
                updateBundle,
                createUnparsedSource,
                createUnparsedPrologue,
                createUnparsedPrepend,
                createUnparsedTextLike,
                createUnparsedSyntheticReference,
                createInputFiles: createInputFiles2,
                createSyntheticExpression,
                createSyntaxList: createSyntaxList3,
                createNotEmittedStatement,
                createPartiallyEmittedExpression,
                updatePartiallyEmittedExpression,
                createCommaListExpression,
                updateCommaListExpression,
                createEndOfDeclarationMarker,
                createMergeDeclarationMarker,
                createSyntheticReferenceExpression,
                updateSyntheticReferenceExpression,
                cloneNode,
                // Lazily load factory methods for common operator factories and utilities
                get createComma() {
                    return getBinaryCreateFunction(27 /* CommaToken */);
                },
                get createAssignment() {
                    return getBinaryCreateFunction(63 /* EqualsToken */);
                },
                get createLogicalOr() {
                    return getBinaryCreateFunction(56 /* BarBarToken */);
                },
                get createLogicalAnd() {
                    return getBinaryCreateFunction(55 /* AmpersandAmpersandToken */);
                },
                get createBitwiseOr() {
                    return getBinaryCreateFunction(51 /* BarToken */);
                },
                get createBitwiseXor() {
                    return getBinaryCreateFunction(52 /* CaretToken */);
                },
                get createBitwiseAnd() {
                    return getBinaryCreateFunction(50 /* AmpersandToken */);
                },
                get createStrictEquality() {
                    return getBinaryCreateFunction(36 /* EqualsEqualsEqualsToken */);
                },
                get createStrictInequality() {
                    return getBinaryCreateFunction(37 /* ExclamationEqualsEqualsToken */);
                },
                get createEquality() {
                    return getBinaryCreateFunction(34 /* EqualsEqualsToken */);
                },
                get createInequality() {
                    return getBinaryCreateFunction(35 /* ExclamationEqualsToken */);
                },
                get createLessThan() {
                    return getBinaryCreateFunction(29 /* LessThanToken */);
                },
                get createLessThanEquals() {
                    return getBinaryCreateFunction(32 /* LessThanEqualsToken */);
                },
                get createGreaterThan() {
                    return getBinaryCreateFunction(31 /* GreaterThanToken */);
                },
                get createGreaterThanEquals() {
                    return getBinaryCreateFunction(33 /* GreaterThanEqualsToken */);
                },
                get createLeftShift() {
                    return getBinaryCreateFunction(47 /* LessThanLessThanToken */);
                },
                get createRightShift() {
                    return getBinaryCreateFunction(48 /* GreaterThanGreaterThanToken */);
                },
                get createUnsignedRightShift() {
                    return getBinaryCreateFunction(49 /* GreaterThanGreaterThanGreaterThanToken */);
                },
                get createAdd() {
                    return getBinaryCreateFunction(39 /* PlusToken */);
                },
                get createSubtract() {
                    return getBinaryCreateFunction(40 /* MinusToken */);
                },
                get createMultiply() {
                    return getBinaryCreateFunction(41 /* AsteriskToken */);
                },
                get createDivide() {
                    return getBinaryCreateFunction(43 /* SlashToken */);
                },
                get createModulo() {
                    return getBinaryCreateFunction(44 /* PercentToken */);
                },
                get createExponent() {
                    return getBinaryCreateFunction(42 /* AsteriskAsteriskToken */);
                },
                get createPrefixPlus() {
                    return getPrefixUnaryCreateFunction(39 /* PlusToken */);
                },
                get createPrefixMinus() {
                    return getPrefixUnaryCreateFunction(40 /* MinusToken */);
                },
                get createPrefixIncrement() {
                    return getPrefixUnaryCreateFunction(45 /* PlusPlusToken */);
                },
                get createPrefixDecrement() {
                    return getPrefixUnaryCreateFunction(46 /* MinusMinusToken */);
                },
                get createBitwiseNot() {
                    return getPrefixUnaryCreateFunction(54 /* TildeToken */);
                },
                get createLogicalNot() {
                    return getPrefixUnaryCreateFunction(53 /* ExclamationToken */);
                },
                get createPostfixIncrement() {
                    return getPostfixUnaryCreateFunction(45 /* PlusPlusToken */);
                },
                get createPostfixDecrement() {
                    return getPostfixUnaryCreateFunction(46 /* MinusMinusToken */);
                },
                // Compound nodes
                createImmediatelyInvokedFunctionExpression,
                createImmediatelyInvokedArrowFunction,
                createVoidZero,
                createExportDefault,
                createExternalModuleExport,
                createTypeCheck,
                createMethodCall,
                createGlobalMethodCall,
                createFunctionBindCall,
                createFunctionCallCall,
                createFunctionApplyCall,
                createArraySliceCall,
                createArrayConcatCall,
                createObjectDefinePropertyCall,
                createObjectGetOwnPropertyDescriptorCall,
                createReflectGetCall,
                createReflectSetCall,
                createPropertyDescriptor,
                createCallBinding,
                createAssignmentTargetWrapper,
                // Utilities
                inlineExpressions,
                getInternalName,
                getLocalName,
                getExportName,
                getDeclarationName,
                getNamespaceMemberName,
                getExternalModuleOrNamespaceExportName,
                restoreOuterExpressions,
                restoreEnclosingLabel,
                createUseStrictPrologue,
                copyPrologue,
                copyStandardPrologue,
                copyCustomPrologue,
                ensureUseStrict,
                liftToBlock,
                mergeLexicalEnvironment,
                updateModifiers
            };
            forEach(nodeFactoryPatchers, (fn) => fn(factory2));
            return factory2;
            function createNodeArray(elements, hasTrailingComma) {
                if (elements === void 0 || elements === emptyArray) {
                    elements = [];
                }
                else if (isNodeArray(elements)) {
                    if (hasTrailingComma === void 0 || elements.hasTrailingComma === hasTrailingComma) {
                        if (elements.transformFlags === void 0) {
                            aggregateChildrenFlags(elements);
                        }
                        Debug.attachNodeArrayDebugInfo(elements);
                        return elements;
                    }
                    const array2 = elements.slice();
                    array2.pos = elements.pos;
                    array2.end = elements.end;
                    array2.hasTrailingComma = hasTrailingComma;
                    array2.transformFlags = elements.transformFlags;
                    Debug.attachNodeArrayDebugInfo(array2);
                    return array2;
                }
                const length2 = elements.length;
                const array = length2 >= 1 && length2 <= 4 ? elements.slice() : elements;
                array.pos = -1;
                array.end = -1;
                array.hasTrailingComma = !!hasTrailingComma;
                array.transformFlags = 0 /* None */;
                aggregateChildrenFlags(array);
                Debug.attachNodeArrayDebugInfo(array);
                return array;
            }
            function createBaseNode(kind) {
                return baseFactory2.createBaseNode(kind);
            }
            function createBaseDeclaration(kind) {
                const node = createBaseNode(kind);
                node.symbol = void 0;
                node.localSymbol = void 0;
                return node;
            }
            function finishUpdateBaseSignatureDeclaration(updated, original) {
                if (updated !== original) {
                    updated.typeArguments = original.typeArguments;
                }
                return update(updated, original);
            }
            function createNumericLiteral(value, numericLiteralFlags = 0 /* None */) {
                const node = createBaseDeclaration(8 /* NumericLiteral */);
                node.text = typeof value === "number" ? value + "" : value;
                node.numericLiteralFlags = numericLiteralFlags;
                if (numericLiteralFlags & 384 /* BinaryOrOctalSpecifier */)
                    node.transformFlags |= 1024 /* ContainsES2015 */;
                return node;
            }
            function createBigIntLiteral(value) {
                const node = createBaseToken(9 /* BigIntLiteral */);
                node.text = typeof value === "string" ? value : pseudoBigIntToString(value) + "n";
                node.transformFlags |= 4 /* ContainsESNext */;
                return node;
            }
            function createBaseStringLiteral(text, isSingleQuote) {
                const node = createBaseDeclaration(10 /* StringLiteral */);
                node.text = text;
                node.singleQuote = isSingleQuote;
                return node;
            }
            function createStringLiteral(text, isSingleQuote, hasExtendedUnicodeEscape) {
                const node = createBaseStringLiteral(text, isSingleQuote);
                node.hasExtendedUnicodeEscape = hasExtendedUnicodeEscape;
                if (hasExtendedUnicodeEscape)
                    node.transformFlags |= 1024 /* ContainsES2015 */;
                return node;
            }
            function createStringLiteralFromNode(sourceNode) {
                const node = createBaseStringLiteral(getTextOfIdentifierOrLiteral(sourceNode), 
                /*isSingleQuote*/
                void 0);
                node.textSourceNode = sourceNode;
                return node;
            }
            function createRegularExpressionLiteral(text) {
                const node = createBaseToken(13 /* RegularExpressionLiteral */);
                node.text = text;
                return node;
            }
            function createLiteralLikeNode(kind, text) {
                switch (kind) {
                    case 8 /* NumericLiteral */:
                        return createNumericLiteral(text, 
                        /*numericLiteralFlags*/
                        0);
                    case 9 /* BigIntLiteral */:
                        return createBigIntLiteral(text);
                    case 10 /* StringLiteral */:
                        return createStringLiteral(text, 
                        /*isSingleQuote*/
                        void 0);
                    case 11 /* JsxText */:
                        return createJsxText(text, 
                        /*containsOnlyTriviaWhiteSpaces*/
                        false);
                    case 12 /* JsxTextAllWhiteSpaces */:
                        return createJsxText(text, 
                        /*containsOnlyTriviaWhiteSpaces*/
                        true);
                    case 13 /* RegularExpressionLiteral */:
                        return createRegularExpressionLiteral(text);
                    case 14 /* NoSubstitutionTemplateLiteral */:
                        return createTemplateLiteralLikeNode(kind, text, 
                        /*rawText*/
                        void 0, 
                        /*templateFlags*/
                        0);
                }
            }
            function createBaseIdentifier(escapedText) {
                const node = baseFactory2.createBaseIdentifierNode(79 /* Identifier */);
                node.escapedText = escapedText;
                node.jsDoc = void 0;
                node.flowNode = void 0;
                node.symbol = void 0;
                return node;
            }
            function createBaseGeneratedIdentifier(text, autoGenerateFlags, prefix, suffix) {
                const node = createBaseIdentifier(escapeLeadingUnderscores(text));
                setIdentifierAutoGenerate(node, {
                    flags: autoGenerateFlags,
                    id: nextAutoGenerateId,
                    prefix,
                    suffix
                });
                nextAutoGenerateId++;
                return node;
            }
            function createIdentifier(text, originalKeywordKind, hasExtendedUnicodeEscape) {
                if (originalKeywordKind === void 0 && text) {
                    originalKeywordKind = stringToToken(text);
                }
                if (originalKeywordKind === 79 /* Identifier */) {
                    originalKeywordKind = void 0;
                }
                const node = createBaseIdentifier(escapeLeadingUnderscores(text));
                if (hasExtendedUnicodeEscape)
                    node.flags |= 128 /* IdentifierHasExtendedUnicodeEscape */;
                if (node.escapedText === "await") {
                    node.transformFlags |= 67108864 /* ContainsPossibleTopLevelAwait */;
                }
                if (node.flags & 128 /* IdentifierHasExtendedUnicodeEscape */) {
                    node.transformFlags |= 1024 /* ContainsES2015 */;
                }
                return node;
            }
            function createTempVariable(recordTempVariable, reservedInNestedScopes, prefix, suffix) {
                let flags2 = 1 /* Auto */;
                if (reservedInNestedScopes)
                    flags2 |= 8 /* ReservedInNestedScopes */;
                const name = createBaseGeneratedIdentifier("", flags2, prefix, suffix);
                if (recordTempVariable) {
                    recordTempVariable(name);
                }
                return name;
            }
            function createLoopVariable(reservedInNestedScopes) {
                let flags2 = 2 /* Loop */;
                if (reservedInNestedScopes)
                    flags2 |= 8 /* ReservedInNestedScopes */;
                return createBaseGeneratedIdentifier("", flags2, 
                /*prefix*/
                void 0, 
                /*suffix*/
                void 0);
            }
            function createUniqueName(text, flags2 = 0 /* None */, prefix, suffix) {
                Debug.assert(!(flags2 & 7 /* KindMask */), "Argument out of range: flags");
                Debug.assert((flags2 & (16 /* Optimistic */ | 32 /* FileLevel */)) !== 32 /* FileLevel */, "GeneratedIdentifierFlags.FileLevel cannot be set without also setting GeneratedIdentifierFlags.Optimistic");
                return createBaseGeneratedIdentifier(text, 3 /* Unique */ | flags2, prefix, suffix);
            }
            function getGeneratedNameForNode(node, flags2 = 0, prefix, suffix) {
                Debug.assert(!(flags2 & 7 /* KindMask */), "Argument out of range: flags");
                const text = !node ? "" : isMemberName(node) ? formatGeneratedName(
                /*privateName*/
                false, prefix, node, suffix, idText) : `generated@${getNodeId(node)}`;
                if (prefix || suffix)
                    flags2 |= 16 /* Optimistic */;
                const name = createBaseGeneratedIdentifier(text, 4 /* Node */ | flags2, prefix, suffix);
                name.original = node;
                return name;
            }
            function createBasePrivateIdentifier(escapedText) {
                const node = baseFactory2.createBasePrivateIdentifierNode(80 /* PrivateIdentifier */);
                node.escapedText = escapedText;
                node.transformFlags |= 16777216 /* ContainsClassFields */;
                return node;
            }
            function createPrivateIdentifier(text) {
                if (!startsWith(text, "#"))
                    Debug.fail("First character of private identifier must be #: " + text);
                return createBasePrivateIdentifier(escapeLeadingUnderscores(text));
            }
            function createBaseGeneratedPrivateIdentifier(text, autoGenerateFlags, prefix, suffix) {
                const node = createBasePrivateIdentifier(escapeLeadingUnderscores(text));
                setIdentifierAutoGenerate(node, {
                    flags: autoGenerateFlags,
                    id: nextAutoGenerateId,
                    prefix,
                    suffix
                });
                nextAutoGenerateId++;
                return node;
            }
            function createUniquePrivateName(text, prefix, suffix) {
                if (text && !startsWith(text, "#"))
                    Debug.fail("First character of private identifier must be #: " + text);
                const autoGenerateFlags = 8 /* ReservedInNestedScopes */ | (text ? 3 /* Unique */ : 1 /* Auto */);
                return createBaseGeneratedPrivateIdentifier(text != null ? text : "", autoGenerateFlags, prefix, suffix);
            }
            function getGeneratedPrivateNameForNode(node, prefix, suffix) {
                const text = isMemberName(node) ? formatGeneratedName(
                /*privateName*/
                true, prefix, node, suffix, idText) : `#generated@${getNodeId(node)}`;
                const flags2 = prefix || suffix ? 16 /* Optimistic */ : 0 /* None */;
                const name = createBaseGeneratedPrivateIdentifier(text, 4 /* Node */ | flags2, prefix, suffix);
                name.original = node;
                return name;
            }
            function createBaseToken(kind) {
                return baseFactory2.createBaseTokenNode(kind);
            }
            function createToken(token) {
                Debug.assert(token >= 0 /* FirstToken */ && token <= 162 /* LastToken */, "Invalid token");
                Debug.assert(token <= 14 /* FirstTemplateToken */ || token >= 17 /* LastTemplateToken */, "Invalid token. Use 'createTemplateLiteralLikeNode' to create template literals.");
                Debug.assert(token <= 8 /* FirstLiteralToken */ || token >= 14 /* LastLiteralToken */, "Invalid token. Use 'createLiteralLikeNode' to create literals.");
                Debug.assert(token !== 79 /* Identifier */, "Invalid token. Use 'createIdentifier' to create identifiers");
                const node = createBaseToken(token);
                let transformFlags = 0 /* None */;
                switch (token) {
                    case 132 /* AsyncKeyword */:
                        transformFlags = 256 /* ContainsES2017 */ | 128 /* ContainsES2018 */;
                        break;
                    case 123 /* PublicKeyword */:
                    case 121 /* PrivateKeyword */:
                    case 122 /* ProtectedKeyword */:
                    case 146 /* ReadonlyKeyword */:
                    case 126 /* AbstractKeyword */:
                    case 136 /* DeclareKeyword */:
                    case 85 /* ConstKeyword */:
                    case 131 /* AnyKeyword */:
                    case 148 /* NumberKeyword */:
                    case 160 /* BigIntKeyword */:
                    case 144 /* NeverKeyword */:
                    case 149 /* ObjectKeyword */:
                    case 101 /* InKeyword */:
                    case 145 /* OutKeyword */:
                    case 161 /* OverrideKeyword */:
                    case 152 /* StringKeyword */:
                    case 134 /* BooleanKeyword */:
                    case 153 /* SymbolKeyword */:
                    case 114 /* VoidKeyword */:
                    case 157 /* UnknownKeyword */:
                    case 155 /* UndefinedKeyword */:
                        transformFlags = 1 /* ContainsTypeScript */;
                        break;
                    case 106 /* SuperKeyword */:
                        transformFlags = 1024 /* ContainsES2015 */ | 134217728 /* ContainsLexicalSuper */;
                        node.flowNode = void 0;
                        break;
                    case 124 /* StaticKeyword */:
                        transformFlags = 1024 /* ContainsES2015 */;
                        break;
                    case 127 /* AccessorKeyword */:
                        transformFlags = 16777216 /* ContainsClassFields */;
                        break;
                    case 108 /* ThisKeyword */:
                        transformFlags = 16384 /* ContainsLexicalThis */;
                        node.flowNode = void 0;
                        break;
                }
                if (transformFlags) {
                    node.transformFlags |= transformFlags;
                }
                return node;
            }
            function createSuper() {
                return createToken(106 /* SuperKeyword */);
            }
            function createThis() {
                return createToken(108 /* ThisKeyword */);
            }
            function createNull() {
                return createToken(104 /* NullKeyword */);
            }
            function createTrue() {
                return createToken(110 /* TrueKeyword */);
            }
            function createFalse() {
                return createToken(95 /* FalseKeyword */);
            }
            function createModifier(kind) {
                return createToken(kind);
            }
            function createModifiersFromModifierFlags(flags2) {
                const result = [];
                if (flags2 & 1 /* Export */)
                    result.push(createModifier(93 /* ExportKeyword */));
                if (flags2 & 2 /* Ambient */)
                    result.push(createModifier(136 /* DeclareKeyword */));
                if (flags2 & 1024 /* Default */)
                    result.push(createModifier(88 /* DefaultKeyword */));
                if (flags2 & 2048 /* Const */)
                    result.push(createModifier(85 /* ConstKeyword */));
                if (flags2 & 4 /* Public */)
                    result.push(createModifier(123 /* PublicKeyword */));
                if (flags2 & 8 /* Private */)
                    result.push(createModifier(121 /* PrivateKeyword */));
                if (flags2 & 16 /* Protected */)
                    result.push(createModifier(122 /* ProtectedKeyword */));
                if (flags2 & 256 /* Abstract */)
                    result.push(createModifier(126 /* AbstractKeyword */));
                if (flags2 & 32 /* Static */)
                    result.push(createModifier(124 /* StaticKeyword */));
                if (flags2 & 16384 /* Override */)
                    result.push(createModifier(161 /* OverrideKeyword */));
                if (flags2 & 64 /* Readonly */)
                    result.push(createModifier(146 /* ReadonlyKeyword */));
                if (flags2 & 128 /* Accessor */)
                    result.push(createModifier(127 /* AccessorKeyword */));
                if (flags2 & 512 /* Async */)
                    result.push(createModifier(132 /* AsyncKeyword */));
                if (flags2 & 32768 /* In */)
                    result.push(createModifier(101 /* InKeyword */));
                if (flags2 & 65536 /* Out */)
                    result.push(createModifier(145 /* OutKeyword */));
                return result.length ? result : void 0;
            }
            function createQualifiedName(left, right) {
                const node = createBaseNode(163 /* QualifiedName */);
                node.left = left;
                node.right = asName(right);
                node.transformFlags |= propagateChildFlags(node.left) | propagateIdentifierNameFlags(node.right);
                node.flowNode = void 0;
                return node;
            }
            function updateQualifiedName(node, left, right) {
                return node.left !== left || node.right !== right ? update(createQualifiedName(left, right), node) : node;
            }
            function createComputedPropertyName(expression) {
                const node = createBaseNode(164 /* ComputedPropertyName */);
                node.expression = parenthesizerRules().parenthesizeExpressionOfComputedPropertyName(expression);
                node.transformFlags |= propagateChildFlags(node.expression) | 1024 /* ContainsES2015 */ | 131072 /* ContainsComputedPropertyName */;
                return node;
            }
            function updateComputedPropertyName(node, expression) {
                return node.expression !== expression ? update(createComputedPropertyName(expression), node) : node;
            }
            function createTypeParameterDeclaration(modifiers, name, constraint, defaultType) {
                const node = createBaseDeclaration(165 /* TypeParameter */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.constraint = constraint;
                node.default = defaultType;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.expression = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updateTypeParameterDeclaration(node, modifiers, name, constraint, defaultType) {
                return node.modifiers !== modifiers || node.name !== name || node.constraint !== constraint || node.default !== defaultType ? update(createTypeParameterDeclaration(modifiers, name, constraint, defaultType), node) : node;
            }
            function createParameterDeclaration(modifiers, dotDotDotToken, name, questionToken, type, initializer) {
                var _a2, _b;
                const node = createBaseDeclaration(166 /* Parameter */);
                node.modifiers = asNodeArray(modifiers);
                node.dotDotDotToken = dotDotDotToken;
                node.name = asName(name);
                node.questionToken = questionToken;
                node.type = type;
                node.initializer = asInitializer(initializer);
                if (isThisIdentifier(node.name)) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.dotDotDotToken) | propagateNameFlags(node.name) | propagateChildFlags(node.questionToken) | propagateChildFlags(node.initializer) | (((_a2 = node.questionToken) != null ? _a2 : node.type) ? 1 /* ContainsTypeScript */ : 0 /* None */) | (((_b = node.dotDotDotToken) != null ? _b : node.initializer) ? 1024 /* ContainsES2015 */ : 0 /* None */) | (modifiersToFlags(node.modifiers) & 16476 /* ParameterPropertyModifier */ ? 8192 /* ContainsTypeScriptClassSyntax */ : 0 /* None */);
                }
                node.jsDoc = void 0;
                return node;
            }
            function updateParameterDeclaration(node, modifiers, dotDotDotToken, name, questionToken, type, initializer) {
                return node.modifiers !== modifiers || node.dotDotDotToken !== dotDotDotToken || node.name !== name || node.questionToken !== questionToken || node.type !== type || node.initializer !== initializer ? update(createParameterDeclaration(modifiers, dotDotDotToken, name, questionToken, type, initializer), node) : node;
            }
            function createDecorator(expression) {
                const node = createBaseNode(167 /* Decorator */);
                node.expression = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false);
                node.transformFlags |= propagateChildFlags(node.expression) | 1 /* ContainsTypeScript */ | 8192 /* ContainsTypeScriptClassSyntax */ | 33554432 /* ContainsDecorators */;
                return node;
            }
            function updateDecorator(node, expression) {
                return node.expression !== expression ? update(createDecorator(expression), node) : node;
            }
            function createPropertySignature(modifiers, name, questionToken, type) {
                const node = createBaseDeclaration(168 /* PropertySignature */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.type = type;
                node.questionToken = questionToken;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.initializer = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updatePropertySignature(node, modifiers, name, questionToken, type) {
                return node.modifiers !== modifiers || node.name !== name || node.questionToken !== questionToken || node.type !== type ? finishUpdatePropertySignature(createPropertySignature(modifiers, name, questionToken, type), node) : node;
            }
            function finishUpdatePropertySignature(updated, original) {
                if (updated !== original) {
                    updated.initializer = original.initializer;
                }
                return update(updated, original);
            }
            function createPropertyDeclaration(modifiers, name, questionOrExclamationToken, type, initializer) {
                const node = createBaseDeclaration(169 /* PropertyDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.questionToken = questionOrExclamationToken && isQuestionToken(questionOrExclamationToken) ? questionOrExclamationToken : void 0;
                node.exclamationToken = questionOrExclamationToken && isExclamationToken(questionOrExclamationToken) ? questionOrExclamationToken : void 0;
                node.type = type;
                node.initializer = asInitializer(initializer);
                const isAmbient = node.flags & 16777216 /* Ambient */ || modifiersToFlags(node.modifiers) & 2 /* Ambient */;
                node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildFlags(node.initializer) | (isAmbient || node.questionToken || node.exclamationToken || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | (isComputedPropertyName(node.name) || modifiersToFlags(node.modifiers) & 32 /* Static */ && node.initializer ? 8192 /* ContainsTypeScriptClassSyntax */ : 0 /* None */) | 16777216 /* ContainsClassFields */;
                node.jsDoc = void 0;
                return node;
            }
            function updatePropertyDeclaration2(node, modifiers, name, questionOrExclamationToken, type, initializer) {
                return node.modifiers !== modifiers || node.name !== name || node.questionToken !== (questionOrExclamationToken !== void 0 && isQuestionToken(questionOrExclamationToken) ? questionOrExclamationToken : void 0) || node.exclamationToken !== (questionOrExclamationToken !== void 0 && isExclamationToken(questionOrExclamationToken) ? questionOrExclamationToken : void 0) || node.type !== type || node.initializer !== initializer ? update(createPropertyDeclaration(modifiers, name, questionOrExclamationToken, type, initializer), node) : node;
            }
            function createMethodSignature(modifiers, name, questionToken, typeParameters, parameters, type) {
                const node = createBaseDeclaration(170 /* MethodSignature */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.questionToken = questionToken;
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateMethodSignature(node, modifiers, name, questionToken, typeParameters, parameters, type) {
                return node.modifiers !== modifiers || node.name !== name || node.questionToken !== questionToken || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateBaseSignatureDeclaration(createMethodSignature(modifiers, name, questionToken, typeParameters, parameters, type), node) : node;
            }
            function createMethodDeclaration(modifiers, asteriskToken, name, questionToken, typeParameters, parameters, type, body) {
                const node = createBaseDeclaration(171 /* MethodDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.asteriskToken = asteriskToken;
                node.name = asName(name);
                node.questionToken = questionToken;
                node.exclamationToken = void 0;
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.body = body;
                if (!node.body) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    const isAsync = modifiersToFlags(node.modifiers) & 512 /* Async */;
                    const isGenerator = !!node.asteriskToken;
                    const isAsyncGenerator = isAsync && isGenerator;
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.asteriskToken) | propagateNameFlags(node.name) | propagateChildFlags(node.questionToken) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (isAsyncGenerator ? 128 /* ContainsES2018 */ : isAsync ? 256 /* ContainsES2017 */ : isGenerator ? 2048 /* ContainsGenerator */ : 0 /* None */) | (node.questionToken || node.typeParameters || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                }
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateMethodDeclaration(node, modifiers, asteriskToken, name, questionToken, typeParameters, parameters, type, body) {
                return node.modifiers !== modifiers || node.asteriskToken !== asteriskToken || node.name !== name || node.questionToken !== questionToken || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type || node.body !== body ? finishUpdateMethodDeclaration(createMethodDeclaration(modifiers, asteriskToken, name, questionToken, typeParameters, parameters, type, body), node) : node;
            }
            function finishUpdateMethodDeclaration(updated, original) {
                if (updated !== original) {
                    updated.exclamationToken = original.exclamationToken;
                }
                return update(updated, original);
            }
            function createClassStaticBlockDeclaration(body) {
                const node = createBaseDeclaration(172 /* ClassStaticBlockDeclaration */);
                node.body = body;
                node.transformFlags = propagateChildFlags(body) | 16777216 /* ContainsClassFields */;
                node.modifiers = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateClassStaticBlockDeclaration(node, body) {
                return node.body !== body ? finishUpdateClassStaticBlockDeclaration(createClassStaticBlockDeclaration(body), node) : node;
            }
            function finishUpdateClassStaticBlockDeclaration(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                }
                return update(updated, original);
            }
            function createConstructorDeclaration(modifiers, parameters, body) {
                const node = createBaseDeclaration(173 /* Constructor */);
                node.modifiers = asNodeArray(modifiers);
                node.parameters = createNodeArray(parameters);
                node.body = body;
                node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | 1024 /* ContainsES2015 */;
                node.typeParameters = void 0;
                node.type = void 0;
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateConstructorDeclaration(node, modifiers, parameters, body) {
                return node.modifiers !== modifiers || node.parameters !== parameters || node.body !== body ? finishUpdateConstructorDeclaration(createConstructorDeclaration(modifiers, parameters, body), node) : node;
            }
            function finishUpdateConstructorDeclaration(updated, original) {
                if (updated !== original) {
                    updated.typeParameters = original.typeParameters;
                    updated.type = original.type;
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createGetAccessorDeclaration(modifiers, name, parameters, type, body) {
                const node = createBaseDeclaration(174 /* GetAccessor */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.body = body;
                if (!node.body) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (node.type ? 1 /* ContainsTypeScript */ : 0 /* None */);
                }
                node.typeArguments = void 0;
                node.typeParameters = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateGetAccessorDeclaration(node, modifiers, name, parameters, type, body) {
                return node.modifiers !== modifiers || node.name !== name || node.parameters !== parameters || node.type !== type || node.body !== body ? finishUpdateGetAccessorDeclaration(createGetAccessorDeclaration(modifiers, name, parameters, type, body), node) : node;
            }
            function finishUpdateGetAccessorDeclaration(updated, original) {
                if (updated !== original) {
                    updated.typeParameters = original.typeParameters;
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createSetAccessorDeclaration(modifiers, name, parameters, body) {
                const node = createBaseDeclaration(175 /* SetAccessor */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.parameters = createNodeArray(parameters);
                node.body = body;
                if (!node.body) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (node.type ? 1 /* ContainsTypeScript */ : 0 /* None */);
                }
                node.typeArguments = void 0;
                node.typeParameters = void 0;
                node.type = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateSetAccessorDeclaration(node, modifiers, name, parameters, body) {
                return node.modifiers !== modifiers || node.name !== name || node.parameters !== parameters || node.body !== body ? finishUpdateSetAccessorDeclaration(createSetAccessorDeclaration(modifiers, name, parameters, body), node) : node;
            }
            function finishUpdateSetAccessorDeclaration(updated, original) {
                if (updated !== original) {
                    updated.typeParameters = original.typeParameters;
                    updated.type = original.type;
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createCallSignature(typeParameters, parameters, type) {
                const node = createBaseDeclaration(176 /* CallSignature */);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateCallSignature(node, typeParameters, parameters, type) {
                return node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateBaseSignatureDeclaration(createCallSignature(typeParameters, parameters, type), node) : node;
            }
            function createConstructSignature(typeParameters, parameters, type) {
                const node = createBaseDeclaration(177 /* ConstructSignature */);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateConstructSignature(node, typeParameters, parameters, type) {
                return node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateBaseSignatureDeclaration(createConstructSignature(typeParameters, parameters, type), node) : node;
            }
            function createIndexSignature(modifiers, parameters, type) {
                const node = createBaseDeclaration(178 /* IndexSignature */);
                node.modifiers = asNodeArray(modifiers);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateIndexSignature(node, modifiers, parameters, type) {
                return node.parameters !== parameters || node.type !== type || node.modifiers !== modifiers ? finishUpdateBaseSignatureDeclaration(createIndexSignature(modifiers, parameters, type), node) : node;
            }
            function createTemplateLiteralTypeSpan(type, literal) {
                const node = createBaseNode(201 /* TemplateLiteralTypeSpan */);
                node.type = type;
                node.literal = literal;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTemplateLiteralTypeSpan(node, type, literal) {
                return node.type !== type || node.literal !== literal ? update(createTemplateLiteralTypeSpan(type, literal), node) : node;
            }
            function createKeywordTypeNode(kind) {
                return createToken(kind);
            }
            function createTypePredicateNode(assertsModifier, parameterName, type) {
                const node = createBaseNode(179 /* TypePredicate */);
                node.assertsModifier = assertsModifier;
                node.parameterName = asName(parameterName);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypePredicateNode(node, assertsModifier, parameterName, type) {
                return node.assertsModifier !== assertsModifier || node.parameterName !== parameterName || node.type !== type ? update(createTypePredicateNode(assertsModifier, parameterName, type), node) : node;
            }
            function createTypeReferenceNode(typeName, typeArguments) {
                const node = createBaseNode(180 /* TypeReference */);
                node.typeName = asName(typeName);
                node.typeArguments = typeArguments && parenthesizerRules().parenthesizeTypeArguments(createNodeArray(typeArguments));
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeReferenceNode(node, typeName, typeArguments) {
                return node.typeName !== typeName || node.typeArguments !== typeArguments ? update(createTypeReferenceNode(typeName, typeArguments), node) : node;
            }
            function createFunctionTypeNode(typeParameters, parameters, type) {
                const node = createBaseDeclaration(181 /* FunctionType */);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.modifiers = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateFunctionTypeNode(node, typeParameters, parameters, type) {
                return node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateFunctionTypeNode(createFunctionTypeNode(typeParameters, parameters, type), node) : node;
            }
            function finishUpdateFunctionTypeNode(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createConstructorTypeNode(...args) {
                return args.length === 4 ? createConstructorTypeNode1(...args) : args.length === 3 ? createConstructorTypeNode2(...args) : Debug.fail("Incorrect number of arguments specified.");
            }
            function createConstructorTypeNode1(modifiers, typeParameters, parameters, type) {
                const node = createBaseDeclaration(182 /* ConstructorType */);
                node.modifiers = asNodeArray(modifiers);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function createConstructorTypeNode2(typeParameters, parameters, type) {
                return createConstructorTypeNode1(
                /*modifiers*/
                void 0, typeParameters, parameters, type);
            }
            function updateConstructorTypeNode(...args) {
                return args.length === 5 ? updateConstructorTypeNode1(...args) : args.length === 4 ? updateConstructorTypeNode2(...args) : Debug.fail("Incorrect number of arguments specified.");
            }
            function updateConstructorTypeNode1(node, modifiers, typeParameters, parameters, type) {
                return node.modifiers !== modifiers || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateBaseSignatureDeclaration(createConstructorTypeNode(modifiers, typeParameters, parameters, type), node) : node;
            }
            function updateConstructorTypeNode2(node, typeParameters, parameters, type) {
                return updateConstructorTypeNode1(node, node.modifiers, typeParameters, parameters, type);
            }
            function createTypeQueryNode(exprName, typeArguments) {
                const node = createBaseNode(183 /* TypeQuery */);
                node.exprName = exprName;
                node.typeArguments = typeArguments && parenthesizerRules().parenthesizeTypeArguments(typeArguments);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeQueryNode(node, exprName, typeArguments) {
                return node.exprName !== exprName || node.typeArguments !== typeArguments ? update(createTypeQueryNode(exprName, typeArguments), node) : node;
            }
            function createTypeLiteralNode(members) {
                const node = createBaseDeclaration(184 /* TypeLiteral */);
                node.members = createNodeArray(members);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeLiteralNode(node, members) {
                return node.members !== members ? update(createTypeLiteralNode(members), node) : node;
            }
            function createArrayTypeNode(elementType) {
                const node = createBaseNode(185 /* ArrayType */);
                node.elementType = parenthesizerRules().parenthesizeNonArrayTypeOfPostfixType(elementType);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateArrayTypeNode(node, elementType) {
                return node.elementType !== elementType ? update(createArrayTypeNode(elementType), node) : node;
            }
            function createTupleTypeNode(elements) {
                const node = createBaseNode(186 /* TupleType */);
                node.elements = createNodeArray(parenthesizerRules().parenthesizeElementTypesOfTupleType(elements));
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTupleTypeNode(node, elements) {
                return node.elements !== elements ? update(createTupleTypeNode(elements), node) : node;
            }
            function createNamedTupleMember(dotDotDotToken, name, questionToken, type) {
                const node = createBaseDeclaration(199 /* NamedTupleMember */);
                node.dotDotDotToken = dotDotDotToken;
                node.name = name;
                node.questionToken = questionToken;
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                return node;
            }
            function updateNamedTupleMember(node, dotDotDotToken, name, questionToken, type) {
                return node.dotDotDotToken !== dotDotDotToken || node.name !== name || node.questionToken !== questionToken || node.type !== type ? update(createNamedTupleMember(dotDotDotToken, name, questionToken, type), node) : node;
            }
            function createOptionalTypeNode(type) {
                const node = createBaseNode(187 /* OptionalType */);
                node.type = parenthesizerRules().parenthesizeTypeOfOptionalType(type);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateOptionalTypeNode(node, type) {
                return node.type !== type ? update(createOptionalTypeNode(type), node) : node;
            }
            function createRestTypeNode(type) {
                const node = createBaseNode(188 /* RestType */);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateRestTypeNode(node, type) {
                return node.type !== type ? update(createRestTypeNode(type), node) : node;
            }
            function createUnionOrIntersectionTypeNode(kind, types, parenthesize) {
                const node = createBaseNode(kind);
                node.types = factory2.createNodeArray(parenthesize(types));
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateUnionOrIntersectionTypeNode(node, types, parenthesize) {
                return node.types !== types ? update(createUnionOrIntersectionTypeNode(node.kind, types, parenthesize), node) : node;
            }
            function createUnionTypeNode(types) {
                return createUnionOrIntersectionTypeNode(189 /* UnionType */, types, parenthesizerRules().parenthesizeConstituentTypesOfUnionType);
            }
            function updateUnionTypeNode(node, types) {
                return updateUnionOrIntersectionTypeNode(node, types, parenthesizerRules().parenthesizeConstituentTypesOfUnionType);
            }
            function createIntersectionTypeNode(types) {
                return createUnionOrIntersectionTypeNode(190 /* IntersectionType */, types, parenthesizerRules().parenthesizeConstituentTypesOfIntersectionType);
            }
            function updateIntersectionTypeNode(node, types) {
                return updateUnionOrIntersectionTypeNode(node, types, parenthesizerRules().parenthesizeConstituentTypesOfIntersectionType);
            }
            function createConditionalTypeNode(checkType, extendsType, trueType, falseType) {
                const node = createBaseNode(191 /* ConditionalType */);
                node.checkType = parenthesizerRules().parenthesizeCheckTypeOfConditionalType(checkType);
                node.extendsType = parenthesizerRules().parenthesizeExtendsTypeOfConditionalType(extendsType);
                node.trueType = trueType;
                node.falseType = falseType;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateConditionalTypeNode(node, checkType, extendsType, trueType, falseType) {
                return node.checkType !== checkType || node.extendsType !== extendsType || node.trueType !== trueType || node.falseType !== falseType ? update(createConditionalTypeNode(checkType, extendsType, trueType, falseType), node) : node;
            }
            function createInferTypeNode(typeParameter) {
                const node = createBaseNode(192 /* InferType */);
                node.typeParameter = typeParameter;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateInferTypeNode(node, typeParameter) {
                return node.typeParameter !== typeParameter ? update(createInferTypeNode(typeParameter), node) : node;
            }
            function createTemplateLiteralType(head, templateSpans) {
                const node = createBaseNode(200 /* TemplateLiteralType */);
                node.head = head;
                node.templateSpans = createNodeArray(templateSpans);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTemplateLiteralType(node, head, templateSpans) {
                return node.head !== head || node.templateSpans !== templateSpans ? update(createTemplateLiteralType(head, templateSpans), node) : node;
            }
            function createImportTypeNode(argument, assertions, qualifier, typeArguments, isTypeOf = false) {
                const node = createBaseNode(202 /* ImportType */);
                node.argument = argument;
                node.assertions = assertions;
                node.qualifier = qualifier;
                node.typeArguments = typeArguments && parenthesizerRules().parenthesizeTypeArguments(typeArguments);
                node.isTypeOf = isTypeOf;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateImportTypeNode(node, argument, assertions, qualifier, typeArguments, isTypeOf = node.isTypeOf) {
                return node.argument !== argument || node.assertions !== assertions || node.qualifier !== qualifier || node.typeArguments !== typeArguments || node.isTypeOf !== isTypeOf ? update(createImportTypeNode(argument, assertions, qualifier, typeArguments, isTypeOf), node) : node;
            }
            function createParenthesizedType(type) {
                const node = createBaseNode(193 /* ParenthesizedType */);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateParenthesizedType(node, type) {
                return node.type !== type ? update(createParenthesizedType(type), node) : node;
            }
            function createThisTypeNode() {
                const node = createBaseNode(194 /* ThisType */);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function createTypeOperatorNode(operator, type) {
                const node = createBaseNode(195 /* TypeOperator */);
                node.operator = operator;
                node.type = operator === 146 /* ReadonlyKeyword */ ? parenthesizerRules().parenthesizeOperandOfReadonlyTypeOperator(type) : parenthesizerRules().parenthesizeOperandOfTypeOperator(type);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeOperatorNode(node, type) {
                return node.type !== type ? update(createTypeOperatorNode(node.operator, type), node) : node;
            }
            function createIndexedAccessTypeNode(objectType, indexType) {
                const node = createBaseNode(196 /* IndexedAccessType */);
                node.objectType = parenthesizerRules().parenthesizeNonArrayTypeOfPostfixType(objectType);
                node.indexType = indexType;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateIndexedAccessTypeNode(node, objectType, indexType) {
                return node.objectType !== objectType || node.indexType !== indexType ? update(createIndexedAccessTypeNode(objectType, indexType), node) : node;
            }
            function createMappedTypeNode(readonlyToken, typeParameter, nameType, questionToken, type, members) {
                const node = createBaseDeclaration(197 /* MappedType */);
                node.readonlyToken = readonlyToken;
                node.typeParameter = typeParameter;
                node.nameType = nameType;
                node.questionToken = questionToken;
                node.type = type;
                node.members = members && createNodeArray(members);
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateMappedTypeNode(node, readonlyToken, typeParameter, nameType, questionToken, type, members) {
                return node.readonlyToken !== readonlyToken || node.typeParameter !== typeParameter || node.nameType !== nameType || node.questionToken !== questionToken || node.type !== type || node.members !== members ? update(createMappedTypeNode(readonlyToken, typeParameter, nameType, questionToken, type, members), node) : node;
            }
            function createLiteralTypeNode(literal) {
                const node = createBaseNode(198 /* LiteralType */);
                node.literal = literal;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateLiteralTypeNode(node, literal) {
                return node.literal !== literal ? update(createLiteralTypeNode(literal), node) : node;
            }
            function createObjectBindingPattern(elements) {
                const node = createBaseNode(203 /* ObjectBindingPattern */);
                node.elements = createNodeArray(elements);
                node.transformFlags |= propagateChildrenFlags(node.elements) | 1024 /* ContainsES2015 */ | 524288 /* ContainsBindingPattern */;
                if (node.transformFlags & 32768 /* ContainsRestOrSpread */) {
                    node.transformFlags |= 128 /* ContainsES2018 */ | 65536 /* ContainsObjectRestOrSpread */;
                }
                return node;
            }
            function updateObjectBindingPattern(node, elements) {
                return node.elements !== elements ? update(createObjectBindingPattern(elements), node) : node;
            }
            function createArrayBindingPattern(elements) {
                const node = createBaseNode(204 /* ArrayBindingPattern */);
                node.elements = createNodeArray(elements);
                node.transformFlags |= propagateChildrenFlags(node.elements) | 1024 /* ContainsES2015 */ | 524288 /* ContainsBindingPattern */;
                return node;
            }
            function updateArrayBindingPattern(node, elements) {
                return node.elements !== elements ? update(createArrayBindingPattern(elements), node) : node;
            }
            function createBindingElement(dotDotDotToken, propertyName, name, initializer) {
                const node = createBaseDeclaration(205 /* BindingElement */);
                node.dotDotDotToken = dotDotDotToken;
                node.propertyName = asName(propertyName);
                node.name = asName(name);
                node.initializer = asInitializer(initializer);
                node.transformFlags |= propagateChildFlags(node.dotDotDotToken) | propagateNameFlags(node.propertyName) | propagateNameFlags(node.name) | propagateChildFlags(node.initializer) | (node.dotDotDotToken ? 32768 /* ContainsRestOrSpread */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                node.flowNode = void 0;
                return node;
            }
            function updateBindingElement(node, dotDotDotToken, propertyName, name, initializer) {
                return node.propertyName !== propertyName || node.dotDotDotToken !== dotDotDotToken || node.name !== name || node.initializer !== initializer ? update(createBindingElement(dotDotDotToken, propertyName, name, initializer), node) : node;
            }
            function createArrayLiteralExpression(elements, multiLine) {
                const node = createBaseNode(206 /* ArrayLiteralExpression */);
                const lastElement = elements && lastOrUndefined(elements);
                const elementsArray = createNodeArray(elements, lastElement && isOmittedExpression(lastElement) ? true : void 0);
                node.elements = parenthesizerRules().parenthesizeExpressionsOfCommaDelimitedList(elementsArray);
                node.multiLine = multiLine;
                node.transformFlags |= propagateChildrenFlags(node.elements);
                return node;
            }
            function updateArrayLiteralExpression(node, elements) {
                return node.elements !== elements ? update(createArrayLiteralExpression(elements, node.multiLine), node) : node;
            }
            function createObjectLiteralExpression(properties, multiLine) {
                const node = createBaseDeclaration(207 /* ObjectLiteralExpression */);
                node.properties = createNodeArray(properties);
                node.multiLine = multiLine;
                node.transformFlags |= propagateChildrenFlags(node.properties);
                node.jsDoc = void 0;
                return node;
            }
            function updateObjectLiteralExpression(node, properties) {
                return node.properties !== properties ? update(createObjectLiteralExpression(properties, node.multiLine), node) : node;
            }
            function createBasePropertyAccessExpression(expression, questionDotToken, name) {
                const node = createBaseDeclaration(208 /* PropertyAccessExpression */);
                node.expression = expression;
                node.questionDotToken = questionDotToken;
                node.name = name;
                node.transformFlags = propagateChildFlags(node.expression) | propagateChildFlags(node.questionDotToken) | (isIdentifier(node.name) ? propagateIdentifierNameFlags(node.name) : propagateChildFlags(node.name) | 536870912 /* ContainsPrivateIdentifierInExpression */);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function createPropertyAccessExpression(expression, name) {
                const node = createBasePropertyAccessExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false), 
                /*questionDotToken*/
                void 0, asName(name));
                if (isSuperKeyword(expression)) {
                    node.transformFlags |= 256 /* ContainsES2017 */ | 128 /* ContainsES2018 */;
                }
                return node;
            }
            function updatePropertyAccessExpression(node, expression, name) {
                if (isPropertyAccessChain(node)) {
                    return updatePropertyAccessChain(node, expression, node.questionDotToken, cast(name, isIdentifier));
                }
                return node.expression !== expression || node.name !== name ? update(createPropertyAccessExpression(expression, name), node) : node;
            }
            function createPropertyAccessChain(expression, questionDotToken, name) {
                const node = createBasePropertyAccessExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                true), questionDotToken, asName(name));
                node.flags |= 32 /* OptionalChain */;
                node.transformFlags |= 32 /* ContainsES2020 */;
                return node;
            }
            function updatePropertyAccessChain(node, expression, questionDotToken, name) {
                Debug.assert(!!(node.flags & 32 /* OptionalChain */), "Cannot update a PropertyAccessExpression using updatePropertyAccessChain. Use updatePropertyAccess instead.");
                return node.expression !== expression || node.questionDotToken !== questionDotToken || node.name !== name ? update(createPropertyAccessChain(expression, questionDotToken, name), node) : node;
            }
            function createBaseElementAccessExpression(expression, questionDotToken, argumentExpression) {
                const node = createBaseDeclaration(209 /* ElementAccessExpression */);
                node.expression = expression;
                node.questionDotToken = questionDotToken;
                node.argumentExpression = argumentExpression;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.questionDotToken) | propagateChildFlags(node.argumentExpression);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function createElementAccessExpression(expression, index) {
                const node = createBaseElementAccessExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false), 
                /*questionDotToken*/
                void 0, asExpression(index));
                if (isSuperKeyword(expression)) {
                    node.transformFlags |= 256 /* ContainsES2017 */ | 128 /* ContainsES2018 */;
                }
                return node;
            }
            function updateElementAccessExpression(node, expression, argumentExpression) {
                if (isElementAccessChain(node)) {
                    return updateElementAccessChain(node, expression, node.questionDotToken, argumentExpression);
                }
                return node.expression !== expression || node.argumentExpression !== argumentExpression ? update(createElementAccessExpression(expression, argumentExpression), node) : node;
            }
            function createElementAccessChain(expression, questionDotToken, index) {
                const node = createBaseElementAccessExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                true), questionDotToken, asExpression(index));
                node.flags |= 32 /* OptionalChain */;
                node.transformFlags |= 32 /* ContainsES2020 */;
                return node;
            }
            function updateElementAccessChain(node, expression, questionDotToken, argumentExpression) {
                Debug.assert(!!(node.flags & 32 /* OptionalChain */), "Cannot update a ElementAccessExpression using updateElementAccessChain. Use updateElementAccess instead.");
                return node.expression !== expression || node.questionDotToken !== questionDotToken || node.argumentExpression !== argumentExpression ? update(createElementAccessChain(expression, questionDotToken, argumentExpression), node) : node;
            }
            function createBaseCallExpression(expression, questionDotToken, typeArguments, argumentsArray) {
                const node = createBaseDeclaration(210 /* CallExpression */);
                node.expression = expression;
                node.questionDotToken = questionDotToken;
                node.typeArguments = typeArguments;
                node.arguments = argumentsArray;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.questionDotToken) | propagateChildrenFlags(node.typeArguments) | propagateChildrenFlags(node.arguments);
                if (node.typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                if (isSuperProperty(node.expression)) {
                    node.transformFlags |= 16384 /* ContainsLexicalThis */;
                }
                return node;
            }
            function createCallExpression(expression, typeArguments, argumentsArray) {
                const node = createBaseCallExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false), 
                /*questionDotToken*/
                void 0, asNodeArray(typeArguments), parenthesizerRules().parenthesizeExpressionsOfCommaDelimitedList(createNodeArray(argumentsArray)));
                if (isImportKeyword(node.expression)) {
                    node.transformFlags |= 8388608 /* ContainsDynamicImport */;
                }
                return node;
            }
            function updateCallExpression(node, expression, typeArguments, argumentsArray) {
                if (isCallChain(node)) {
                    return updateCallChain(node, expression, node.questionDotToken, typeArguments, argumentsArray);
                }
                return node.expression !== expression || node.typeArguments !== typeArguments || node.arguments !== argumentsArray ? update(createCallExpression(expression, typeArguments, argumentsArray), node) : node;
            }
            function createCallChain(expression, questionDotToken, typeArguments, argumentsArray) {
                const node = createBaseCallExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                true), questionDotToken, asNodeArray(typeArguments), parenthesizerRules().parenthesizeExpressionsOfCommaDelimitedList(createNodeArray(argumentsArray)));
                node.flags |= 32 /* OptionalChain */;
                node.transformFlags |= 32 /* ContainsES2020 */;
                return node;
            }
            function updateCallChain(node, expression, questionDotToken, typeArguments, argumentsArray) {
                Debug.assert(!!(node.flags & 32 /* OptionalChain */), "Cannot update a CallExpression using updateCallChain. Use updateCall instead.");
                return node.expression !== expression || node.questionDotToken !== questionDotToken || node.typeArguments !== typeArguments || node.arguments !== argumentsArray ? update(createCallChain(expression, questionDotToken, typeArguments, argumentsArray), node) : node;
            }
            function createNewExpression(expression, typeArguments, argumentsArray) {
                const node = createBaseDeclaration(211 /* NewExpression */);
                node.expression = parenthesizerRules().parenthesizeExpressionOfNew(expression);
                node.typeArguments = asNodeArray(typeArguments);
                node.arguments = argumentsArray ? parenthesizerRules().parenthesizeExpressionsOfCommaDelimitedList(argumentsArray) : void 0;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildrenFlags(node.typeArguments) | propagateChildrenFlags(node.arguments) | 32 /* ContainsES2020 */;
                if (node.typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                return node;
            }
            function updateNewExpression(node, expression, typeArguments, argumentsArray) {
                return node.expression !== expression || node.typeArguments !== typeArguments || node.arguments !== argumentsArray ? update(createNewExpression(expression, typeArguments, argumentsArray), node) : node;
            }
            function createTaggedTemplateExpression(tag, typeArguments, template) {
                const node = createBaseNode(212 /* TaggedTemplateExpression */);
                node.tag = parenthesizerRules().parenthesizeLeftSideOfAccess(tag, 
                /*optionalChain*/
                false);
                node.typeArguments = asNodeArray(typeArguments);
                node.template = template;
                node.transformFlags |= propagateChildFlags(node.tag) | propagateChildrenFlags(node.typeArguments) | propagateChildFlags(node.template) | 1024 /* ContainsES2015 */;
                if (node.typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                if (hasInvalidEscape(node.template)) {
                    node.transformFlags |= 128 /* ContainsES2018 */;
                }
                return node;
            }
            function updateTaggedTemplateExpression(node, tag, typeArguments, template) {
                return node.tag !== tag || node.typeArguments !== typeArguments || node.template !== template ? update(createTaggedTemplateExpression(tag, typeArguments, template), node) : node;
            }
            function createTypeAssertion(type, expression) {
                const node = createBaseNode(213 /* TypeAssertionExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.type = type;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.type) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeAssertion(node, type, expression) {
                return node.type !== type || node.expression !== expression ? update(createTypeAssertion(type, expression), node) : node;
            }
            function createParenthesizedExpression(expression) {
                const node = createBaseNode(214 /* ParenthesizedExpression */);
                node.expression = expression;
                node.transformFlags = propagateChildFlags(node.expression);
                node.jsDoc = void 0;
                return node;
            }
            function updateParenthesizedExpression(node, expression) {
                return node.expression !== expression ? update(createParenthesizedExpression(expression), node) : node;
            }
            function createFunctionExpression(modifiers, asteriskToken, name, typeParameters, parameters, type, body) {
                const node = createBaseDeclaration(215 /* FunctionExpression */);
                node.modifiers = asNodeArray(modifiers);
                node.asteriskToken = asteriskToken;
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.body = body;
                const isAsync = modifiersToFlags(node.modifiers) & 512 /* Async */;
                const isGenerator = !!node.asteriskToken;
                const isAsyncGenerator = isAsync && isGenerator;
                node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.asteriskToken) | propagateNameFlags(node.name) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (isAsyncGenerator ? 128 /* ContainsES2018 */ : isAsync ? 256 /* ContainsES2017 */ : isGenerator ? 2048 /* ContainsGenerator */ : 0 /* None */) | (node.typeParameters || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateFunctionExpression(node, modifiers, asteriskToken, name, typeParameters, parameters, type, body) {
                return node.name !== name || node.modifiers !== modifiers || node.asteriskToken !== asteriskToken || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type || node.body !== body ? finishUpdateBaseSignatureDeclaration(createFunctionExpression(modifiers, asteriskToken, name, typeParameters, parameters, type, body), node) : node;
            }
            function createArrowFunction(modifiers, typeParameters, parameters, type, equalsGreaterThanToken, body) {
                const node = createBaseDeclaration(216 /* ArrowFunction */);
                node.modifiers = asNodeArray(modifiers);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.equalsGreaterThanToken = equalsGreaterThanToken != null ? equalsGreaterThanToken : createToken(38 /* EqualsGreaterThanToken */);
                node.body = parenthesizerRules().parenthesizeConciseBodyOfArrowFunction(body);
                const isAsync = modifiersToFlags(node.modifiers) & 512 /* Async */;
                node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.equalsGreaterThanToken) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (node.typeParameters || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | (isAsync ? 256 /* ContainsES2017 */ | 16384 /* ContainsLexicalThis */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateArrowFunction(node, modifiers, typeParameters, parameters, type, equalsGreaterThanToken, body) {
                return node.modifiers !== modifiers || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type || node.equalsGreaterThanToken !== equalsGreaterThanToken || node.body !== body ? finishUpdateBaseSignatureDeclaration(createArrowFunction(modifiers, typeParameters, parameters, type, equalsGreaterThanToken, body), node) : node;
            }
            function createDeleteExpression(expression) {
                const node = createBaseNode(217 /* DeleteExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.transformFlags |= propagateChildFlags(node.expression);
                return node;
            }
            function updateDeleteExpression(node, expression) {
                return node.expression !== expression ? update(createDeleteExpression(expression), node) : node;
            }
            function createTypeOfExpression(expression) {
                const node = createBaseNode(218 /* TypeOfExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.transformFlags |= propagateChildFlags(node.expression);
                return node;
            }
            function updateTypeOfExpression(node, expression) {
                return node.expression !== expression ? update(createTypeOfExpression(expression), node) : node;
            }
            function createVoidExpression(expression) {
                const node = createBaseNode(219 /* VoidExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.transformFlags |= propagateChildFlags(node.expression);
                return node;
            }
            function updateVoidExpression(node, expression) {
                return node.expression !== expression ? update(createVoidExpression(expression), node) : node;
            }
            function createAwaitExpression(expression) {
                const node = createBaseNode(220 /* AwaitExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.transformFlags |= propagateChildFlags(node.expression) | 256 /* ContainsES2017 */ | 128 /* ContainsES2018 */ | 2097152 /* ContainsAwait */;
                return node;
            }
            function updateAwaitExpression(node, expression) {
                return node.expression !== expression ? update(createAwaitExpression(expression), node) : node;
            }
            function createPrefixUnaryExpression(operator, operand) {
                const node = createBaseNode(221 /* PrefixUnaryExpression */);
                node.operator = operator;
                node.operand = parenthesizerRules().parenthesizeOperandOfPrefixUnary(operand);
                node.transformFlags |= propagateChildFlags(node.operand);
                if ((operator === 45 /* PlusPlusToken */ || operator === 46 /* MinusMinusToken */) && isIdentifier(node.operand) && !isGeneratedIdentifier(node.operand) && !isLocalName(node.operand)) {
                    node.transformFlags |= 268435456 /* ContainsUpdateExpressionForIdentifier */;
                }
                return node;
            }
            function updatePrefixUnaryExpression(node, operand) {
                return node.operand !== operand ? update(createPrefixUnaryExpression(node.operator, operand), node) : node;
            }
            function createPostfixUnaryExpression(operand, operator) {
                const node = createBaseNode(222 /* PostfixUnaryExpression */);
                node.operator = operator;
                node.operand = parenthesizerRules().parenthesizeOperandOfPostfixUnary(operand);
                node.transformFlags |= propagateChildFlags(node.operand);
                if (isIdentifier(node.operand) && !isGeneratedIdentifier(node.operand) && !isLocalName(node.operand)) {
                    node.transformFlags |= 268435456 /* ContainsUpdateExpressionForIdentifier */;
                }
                return node;
            }
            function updatePostfixUnaryExpression(node, operand) {
                return node.operand !== operand ? update(createPostfixUnaryExpression(operand, node.operator), node) : node;
            }
            function createBinaryExpression(left, operator, right) {
                const node = createBaseDeclaration(223 /* BinaryExpression */);
                const operatorToken = asToken(operator);
                const operatorKind = operatorToken.kind;
                node.left = parenthesizerRules().parenthesizeLeftSideOfBinary(operatorKind, left);
                node.operatorToken = operatorToken;
                node.right = parenthesizerRules().parenthesizeRightSideOfBinary(operatorKind, node.left, right);
                node.transformFlags |= propagateChildFlags(node.left) | propagateChildFlags(node.operatorToken) | propagateChildFlags(node.right);
                if (operatorKind === 60 /* QuestionQuestionToken */) {
                    node.transformFlags |= 32 /* ContainsES2020 */;
                }
                else if (operatorKind === 63 /* EqualsToken */) {
                    if (isObjectLiteralExpression(node.left)) {
                        node.transformFlags |= 1024 /* ContainsES2015 */ | 128 /* ContainsES2018 */ | 4096 /* ContainsDestructuringAssignment */ | propagateAssignmentPatternFlags(node.left);
                    }
                    else if (isArrayLiteralExpression(node.left)) {
                        node.transformFlags |= 1024 /* ContainsES2015 */ | 4096 /* ContainsDestructuringAssignment */ | propagateAssignmentPatternFlags(node.left);
                    }
                }
                else if (operatorKind === 42 /* AsteriskAsteriskToken */ || operatorKind === 67 /* AsteriskAsteriskEqualsToken */) {
                    node.transformFlags |= 512 /* ContainsES2016 */;
                }
                else if (isLogicalOrCoalescingAssignmentOperator(operatorKind)) {
                    node.transformFlags |= 16 /* ContainsES2021 */;
                }
                if (operatorKind === 101 /* InKeyword */ && isPrivateIdentifier(node.left)) {
                    node.transformFlags |= 536870912 /* ContainsPrivateIdentifierInExpression */;
                }
                node.jsDoc = void 0;
                return node;
            }
            function propagateAssignmentPatternFlags(node) {
                return containsObjectRestOrSpread(node) ? 65536 /* ContainsObjectRestOrSpread */ : 0 /* None */;
            }
            function updateBinaryExpression(node, left, operator, right) {
                return node.left !== left || node.operatorToken !== operator || node.right !== right ? update(createBinaryExpression(left, operator, right), node) : node;
            }
            function createConditionalExpression(condition, questionToken, whenTrue, colonToken, whenFalse) {
                const node = createBaseNode(224 /* ConditionalExpression */);
                node.condition = parenthesizerRules().parenthesizeConditionOfConditionalExpression(condition);
                node.questionToken = questionToken != null ? questionToken : createToken(57 /* QuestionToken */);
                node.whenTrue = parenthesizerRules().parenthesizeBranchOfConditionalExpression(whenTrue);
                node.colonToken = colonToken != null ? colonToken : createToken(58 /* ColonToken */);
                node.whenFalse = parenthesizerRules().parenthesizeBranchOfConditionalExpression(whenFalse);
                node.transformFlags |= propagateChildFlags(node.condition) | propagateChildFlags(node.questionToken) | propagateChildFlags(node.whenTrue) | propagateChildFlags(node.colonToken) | propagateChildFlags(node.whenFalse);
                return node;
            }
            function updateConditionalExpression(node, condition, questionToken, whenTrue, colonToken, whenFalse) {
                return node.condition !== condition || node.questionToken !== questionToken || node.whenTrue !== whenTrue || node.colonToken !== colonToken || node.whenFalse !== whenFalse ? update(createConditionalExpression(condition, questionToken, whenTrue, colonToken, whenFalse), node) : node;
            }
            function createTemplateExpression(head, templateSpans) {
                const node = createBaseNode(225 /* TemplateExpression */);
                node.head = head;
                node.templateSpans = createNodeArray(templateSpans);
                node.transformFlags |= propagateChildFlags(node.head) | propagateChildrenFlags(node.templateSpans) | 1024 /* ContainsES2015 */;
                return node;
            }
            function updateTemplateExpression(node, head, templateSpans) {
                return node.head !== head || node.templateSpans !== templateSpans ? update(createTemplateExpression(head, templateSpans), node) : node;
            }
            function checkTemplateLiteralLikeNode(kind, text, rawText, templateFlags = 0 /* None */) {
                Debug.assert(!(templateFlags & ~2048 /* TemplateLiteralLikeFlags */), "Unsupported template flags.");
                let cooked = void 0;
                if (rawText !== void 0 && rawText !== text) {
                    cooked = getCookedText(kind, rawText);
                    if (typeof cooked === "object") {
                        return Debug.fail("Invalid raw text");
                    }
                }
                if (text === void 0) {
                    if (cooked === void 0) {
                        return Debug.fail("Arguments 'text' and 'rawText' may not both be undefined.");
                    }
                    text = cooked;
                }
                else if (cooked !== void 0) {
                    Debug.assert(text === cooked, "Expected argument 'text' to be the normalized (i.e. 'cooked') version of argument 'rawText'.");
                }
                return text;
            }
            function getTransformFlagsOfTemplateLiteralLike(templateFlags) {
                let transformFlags = 1024 /* ContainsES2015 */;
                if (templateFlags) {
                    transformFlags |= 128 /* ContainsES2018 */;
                }
                return transformFlags;
            }
            function createTemplateLiteralLikeToken(kind, text, rawText, templateFlags) {
                const node = createBaseToken(kind);
                node.text = text;
                node.rawText = rawText;
                node.templateFlags = templateFlags & 2048 /* TemplateLiteralLikeFlags */;
                node.transformFlags = getTransformFlagsOfTemplateLiteralLike(node.templateFlags);
                return node;
            }
            function createTemplateLiteralLikeDeclaration(kind, text, rawText, templateFlags) {
                const node = createBaseDeclaration(kind);
                node.text = text;
                node.rawText = rawText;
                node.templateFlags = templateFlags & 2048 /* TemplateLiteralLikeFlags */;
                node.transformFlags = getTransformFlagsOfTemplateLiteralLike(node.templateFlags);
                return node;
            }
            function createTemplateLiteralLikeNode(kind, text, rawText, templateFlags) {
                if (kind === 14 /* NoSubstitutionTemplateLiteral */) {
                    return createTemplateLiteralLikeDeclaration(kind, text, rawText, templateFlags);
                }
                return createTemplateLiteralLikeToken(kind, text, rawText, templateFlags);
            }
            function createTemplateHead(text, rawText, templateFlags) {
                text = checkTemplateLiteralLikeNode(15 /* TemplateHead */, text, rawText, templateFlags);
                return createTemplateLiteralLikeNode(15 /* TemplateHead */, text, rawText, templateFlags);
            }
            function createTemplateMiddle(text, rawText, templateFlags) {
                text = checkTemplateLiteralLikeNode(15 /* TemplateHead */, text, rawText, templateFlags);
                return createTemplateLiteralLikeNode(16 /* TemplateMiddle */, text, rawText, templateFlags);
            }
            function createTemplateTail(text, rawText, templateFlags) {
                text = checkTemplateLiteralLikeNode(15 /* TemplateHead */, text, rawText, templateFlags);
                return createTemplateLiteralLikeNode(17 /* TemplateTail */, text, rawText, templateFlags);
            }
            function createNoSubstitutionTemplateLiteral(text, rawText, templateFlags) {
                text = checkTemplateLiteralLikeNode(15 /* TemplateHead */, text, rawText, templateFlags);
                return createTemplateLiteralLikeDeclaration(14 /* NoSubstitutionTemplateLiteral */, text, rawText, templateFlags);
            }
            function createYieldExpression(asteriskToken, expression) {
                Debug.assert(!asteriskToken || !!expression, "A `YieldExpression` with an asteriskToken must have an expression.");
                const node = createBaseNode(226 /* YieldExpression */);
                node.expression = expression && parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.asteriskToken = asteriskToken;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.asteriskToken) | 1024 /* ContainsES2015 */ | 128 /* ContainsES2018 */ | 1048576 /* ContainsYield */;
                return node;
            }
            function updateYieldExpression(node, asteriskToken, expression) {
                return node.expression !== expression || node.asteriskToken !== asteriskToken ? update(createYieldExpression(asteriskToken, expression), node) : node;
            }
            function createSpreadElement(expression) {
                const node = createBaseNode(227 /* SpreadElement */);
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.transformFlags |= propagateChildFlags(node.expression) | 1024 /* ContainsES2015 */ | 32768 /* ContainsRestOrSpread */;
                return node;
            }
            function updateSpreadElement(node, expression) {
                return node.expression !== expression ? update(createSpreadElement(expression), node) : node;
            }
            function createClassExpression(modifiers, name, typeParameters, heritageClauses, members) {
                const node = createBaseDeclaration(228 /* ClassExpression */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.heritageClauses = asNodeArray(heritageClauses);
                node.members = createNodeArray(members);
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.heritageClauses) | propagateChildrenFlags(node.members) | (node.typeParameters ? 1 /* ContainsTypeScript */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                node.jsDoc = void 0;
                return node;
            }
            function updateClassExpression(node, modifiers, name, typeParameters, heritageClauses, members) {
                return node.modifiers !== modifiers || node.name !== name || node.typeParameters !== typeParameters || node.heritageClauses !== heritageClauses || node.members !== members ? update(createClassExpression(modifiers, name, typeParameters, heritageClauses, members), node) : node;
            }
            function createOmittedExpression() {
                return createBaseNode(229 /* OmittedExpression */);
            }
            function createExpressionWithTypeArguments(expression, typeArguments) {
                const node = createBaseNode(230 /* ExpressionWithTypeArguments */);
                node.expression = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false);
                node.typeArguments = typeArguments && parenthesizerRules().parenthesizeTypeArguments(typeArguments);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildrenFlags(node.typeArguments) | 1024 /* ContainsES2015 */;
                return node;
            }
            function updateExpressionWithTypeArguments(node, expression, typeArguments) {
                return node.expression !== expression || node.typeArguments !== typeArguments ? update(createExpressionWithTypeArguments(expression, typeArguments), node) : node;
            }
            function createAsExpression(expression, type) {
                const node = createBaseNode(231 /* AsExpression */);
                node.expression = expression;
                node.type = type;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.type) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateAsExpression(node, expression, type) {
                return node.expression !== expression || node.type !== type ? update(createAsExpression(expression, type), node) : node;
            }
            function createNonNullExpression(expression) {
                const node = createBaseNode(232 /* NonNullExpression */);
                node.expression = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false);
                node.transformFlags |= propagateChildFlags(node.expression) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateNonNullExpression(node, expression) {
                if (isNonNullChain(node)) {
                    return updateNonNullChain(node, expression);
                }
                return node.expression !== expression ? update(createNonNullExpression(expression), node) : node;
            }
            function createSatisfiesExpression(expression, type) {
                const node = createBaseNode(235 /* SatisfiesExpression */);
                node.expression = expression;
                node.type = type;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.type) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateSatisfiesExpression(node, expression, type) {
                return node.expression !== expression || node.type !== type ? update(createSatisfiesExpression(expression, type), node) : node;
            }
            function createNonNullChain(expression) {
                const node = createBaseNode(232 /* NonNullExpression */);
                node.flags |= 32 /* OptionalChain */;
                node.expression = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                true);
                node.transformFlags |= propagateChildFlags(node.expression) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateNonNullChain(node, expression) {
                Debug.assert(!!(node.flags & 32 /* OptionalChain */), "Cannot update a NonNullExpression using updateNonNullChain. Use updateNonNullExpression instead.");
                return node.expression !== expression ? update(createNonNullChain(expression), node) : node;
            }
            function createMetaProperty(keywordToken, name) {
                const node = createBaseNode(233 /* MetaProperty */);
                node.keywordToken = keywordToken;
                node.name = name;
                node.transformFlags |= propagateChildFlags(node.name);
                switch (keywordToken) {
                    case 103 /* NewKeyword */:
                        node.transformFlags |= 1024 /* ContainsES2015 */;
                        break;
                    case 100 /* ImportKeyword */:
                        node.transformFlags |= 4 /* ContainsESNext */;
                        break;
                    default:
                        return Debug.assertNever(keywordToken);
                }
                node.flowNode = void 0;
                return node;
            }
            function updateMetaProperty(node, name) {
                return node.name !== name ? update(createMetaProperty(node.keywordToken, name), node) : node;
            }
            function createTemplateSpan(expression, literal) {
                const node = createBaseNode(236 /* TemplateSpan */);
                node.expression = expression;
                node.literal = literal;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.literal) | 1024 /* ContainsES2015 */;
                return node;
            }
            function updateTemplateSpan(node, expression, literal) {
                return node.expression !== expression || node.literal !== literal ? update(createTemplateSpan(expression, literal), node) : node;
            }
            function createSemicolonClassElement() {
                const node = createBaseNode(237 /* SemicolonClassElement */);
                node.transformFlags |= 1024 /* ContainsES2015 */;
                return node;
            }
            function createBlock(statements, multiLine) {
                const node = createBaseNode(238 /* Block */);
                node.statements = createNodeArray(statements);
                node.multiLine = multiLine;
                node.transformFlags |= propagateChildrenFlags(node.statements);
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateBlock(node, statements) {
                return node.statements !== statements ? update(createBlock(statements, node.multiLine), node) : node;
            }
            function createVariableStatement(modifiers, declarationList) {
                const node = createBaseNode(240 /* VariableStatement */);
                node.modifiers = asNodeArray(modifiers);
                node.declarationList = isArray(declarationList) ? createVariableDeclarationList(declarationList) : declarationList;
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.declarationList);
                if (modifiersToFlags(node.modifiers) & 2 /* Ambient */) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateVariableStatement(node, modifiers, declarationList) {
                return node.modifiers !== modifiers || node.declarationList !== declarationList ? update(createVariableStatement(modifiers, declarationList), node) : node;
            }
            function createEmptyStatement() {
                const node = createBaseNode(239 /* EmptyStatement */);
                node.jsDoc = void 0;
                return node;
            }
            function createExpressionStatement(expression) {
                const node = createBaseNode(241 /* ExpressionStatement */);
                node.expression = parenthesizerRules().parenthesizeExpressionOfExpressionStatement(expression);
                node.transformFlags |= propagateChildFlags(node.expression);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateExpressionStatement(node, expression) {
                return node.expression !== expression ? update(createExpressionStatement(expression), node) : node;
            }
            function createIfStatement(expression, thenStatement, elseStatement) {
                const node = createBaseNode(242 /* IfStatement */);
                node.expression = expression;
                node.thenStatement = asEmbeddedStatement(thenStatement);
                node.elseStatement = asEmbeddedStatement(elseStatement);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.thenStatement) | propagateChildFlags(node.elseStatement);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateIfStatement(node, expression, thenStatement, elseStatement) {
                return node.expression !== expression || node.thenStatement !== thenStatement || node.elseStatement !== elseStatement ? update(createIfStatement(expression, thenStatement, elseStatement), node) : node;
            }
            function createDoStatement(statement, expression) {
                const node = createBaseNode(243 /* DoStatement */);
                node.statement = asEmbeddedStatement(statement);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.statement) | propagateChildFlags(node.expression);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateDoStatement(node, statement, expression) {
                return node.statement !== statement || node.expression !== expression ? update(createDoStatement(statement, expression), node) : node;
            }
            function createWhileStatement(expression, statement) {
                const node = createBaseNode(244 /* WhileStatement */);
                node.expression = expression;
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateWhileStatement(node, expression, statement) {
                return node.expression !== expression || node.statement !== statement ? update(createWhileStatement(expression, statement), node) : node;
            }
            function createForStatement(initializer, condition, incrementor, statement) {
                const node = createBaseNode(245 /* ForStatement */);
                node.initializer = initializer;
                node.condition = condition;
                node.incrementor = incrementor;
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.initializer) | propagateChildFlags(node.condition) | propagateChildFlags(node.incrementor) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateForStatement(node, initializer, condition, incrementor, statement) {
                return node.initializer !== initializer || node.condition !== condition || node.incrementor !== incrementor || node.statement !== statement ? update(createForStatement(initializer, condition, incrementor, statement), node) : node;
            }
            function createForInStatement(initializer, expression, statement) {
                const node = createBaseNode(246 /* ForInStatement */);
                node.initializer = initializer;
                node.expression = expression;
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.initializer) | propagateChildFlags(node.expression) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateForInStatement(node, initializer, expression, statement) {
                return node.initializer !== initializer || node.expression !== expression || node.statement !== statement ? update(createForInStatement(initializer, expression, statement), node) : node;
            }
            function createForOfStatement(awaitModifier, initializer, expression, statement) {
                const node = createBaseNode(247 /* ForOfStatement */);
                node.awaitModifier = awaitModifier;
                node.initializer = initializer;
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.awaitModifier) | propagateChildFlags(node.initializer) | propagateChildFlags(node.expression) | propagateChildFlags(node.statement) | 1024 /* ContainsES2015 */;
                if (awaitModifier)
                    node.transformFlags |= 128 /* ContainsES2018 */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateForOfStatement(node, awaitModifier, initializer, expression, statement) {
                return node.awaitModifier !== awaitModifier || node.initializer !== initializer || node.expression !== expression || node.statement !== statement ? update(createForOfStatement(awaitModifier, initializer, expression, statement), node) : node;
            }
            function createContinueStatement(label) {
                const node = createBaseNode(248 /* ContinueStatement */);
                node.label = asName(label);
                node.transformFlags |= propagateChildFlags(node.label) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateContinueStatement(node, label) {
                return node.label !== label ? update(createContinueStatement(label), node) : node;
            }
            function createBreakStatement(label) {
                const node = createBaseNode(249 /* BreakStatement */);
                node.label = asName(label);
                node.transformFlags |= propagateChildFlags(node.label) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateBreakStatement(node, label) {
                return node.label !== label ? update(createBreakStatement(label), node) : node;
            }
            function createReturnStatement(expression) {
                const node = createBaseNode(250 /* ReturnStatement */);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.expression) | 128 /* ContainsES2018 */ | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateReturnStatement(node, expression) {
                return node.expression !== expression ? update(createReturnStatement(expression), node) : node;
            }
            function createWithStatement(expression, statement) {
                const node = createBaseNode(251 /* WithStatement */);
                node.expression = expression;
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateWithStatement(node, expression, statement) {
                return node.expression !== expression || node.statement !== statement ? update(createWithStatement(expression, statement), node) : node;
            }
            function createSwitchStatement(expression, caseBlock) {
                const node = createBaseNode(252 /* SwitchStatement */);
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.caseBlock = caseBlock;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.caseBlock);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                node.possiblyExhaustive = false;
                return node;
            }
            function updateSwitchStatement(node, expression, caseBlock) {
                return node.expression !== expression || node.caseBlock !== caseBlock ? update(createSwitchStatement(expression, caseBlock), node) : node;
            }
            function createLabeledStatement(label, statement) {
                const node = createBaseNode(253 /* LabeledStatement */);
                node.label = asName(label);
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.label) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateLabeledStatement(node, label, statement) {
                return node.label !== label || node.statement !== statement ? update(createLabeledStatement(label, statement), node) : node;
            }
            function createThrowStatement(expression) {
                const node = createBaseNode(254 /* ThrowStatement */);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.expression);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateThrowStatement(node, expression) {
                return node.expression !== expression ? update(createThrowStatement(expression), node) : node;
            }
            function createTryStatement(tryBlock, catchClause, finallyBlock) {
                const node = createBaseNode(255 /* TryStatement */);
                node.tryBlock = tryBlock;
                node.catchClause = catchClause;
                node.finallyBlock = finallyBlock;
                node.transformFlags |= propagateChildFlags(node.tryBlock) | propagateChildFlags(node.catchClause) | propagateChildFlags(node.finallyBlock);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateTryStatement(node, tryBlock, catchClause, finallyBlock) {
                return node.tryBlock !== tryBlock || node.catchClause !== catchClause || node.finallyBlock !== finallyBlock ? update(createTryStatement(tryBlock, catchClause, finallyBlock), node) : node;
            }
            function createDebuggerStatement() {
                const node = createBaseNode(256 /* DebuggerStatement */);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function createVariableDeclaration(name, exclamationToken, type, initializer) {
                var _a2;
                const node = createBaseDeclaration(257 /* VariableDeclaration */);
                node.name = asName(name);
                node.exclamationToken = exclamationToken;
                node.type = type;
                node.initializer = asInitializer(initializer);
                node.transformFlags |= propagateNameFlags(node.name) | propagateChildFlags(node.initializer) | (((_a2 = node.exclamationToken) != null ? _a2 : node.type) ? 1 /* ContainsTypeScript */ : 0 /* None */);
                node.jsDoc = void 0;
                return node;
            }
            function updateVariableDeclaration(node, name, exclamationToken, type, initializer) {
                return node.name !== name || node.type !== type || node.exclamationToken !== exclamationToken || node.initializer !== initializer ? update(createVariableDeclaration(name, exclamationToken, type, initializer), node) : node;
            }
            function createVariableDeclarationList(declarations, flags2 = 0 /* None */) {
                const node = createBaseNode(258 /* VariableDeclarationList */);
                node.flags |= flags2 & 3 /* BlockScoped */;
                node.declarations = createNodeArray(declarations);
                node.transformFlags |= propagateChildrenFlags(node.declarations) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                if (flags2 & 3 /* BlockScoped */) {
                    node.transformFlags |= 1024 /* ContainsES2015 */ | 262144 /* ContainsBlockScopedBinding */;
                }
                return node;
            }
            function updateVariableDeclarationList(node, declarations) {
                return node.declarations !== declarations ? update(createVariableDeclarationList(declarations, node.flags), node) : node;
            }
            function createFunctionDeclaration(modifiers, asteriskToken, name, typeParameters, parameters, type, body) {
                const node = createBaseDeclaration(259 /* FunctionDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.asteriskToken = asteriskToken;
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.body = body;
                if (!node.body || modifiersToFlags(node.modifiers) & 2 /* Ambient */) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    const isAsync = modifiersToFlags(node.modifiers) & 512 /* Async */;
                    const isGenerator = !!node.asteriskToken;
                    const isAsyncGenerator = isAsync && isGenerator;
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.asteriskToken) | propagateNameFlags(node.name) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (isAsyncGenerator ? 128 /* ContainsES2018 */ : isAsync ? 256 /* ContainsES2017 */ : isGenerator ? 2048 /* ContainsGenerator */ : 0 /* None */) | (node.typeParameters || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                }
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateFunctionDeclaration(node, modifiers, asteriskToken, name, typeParameters, parameters, type, body) {
                return node.modifiers !== modifiers || node.asteriskToken !== asteriskToken || node.name !== name || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type || node.body !== body ? finishUpdateFunctionDeclaration(createFunctionDeclaration(modifiers, asteriskToken, name, typeParameters, parameters, type, body), node) : node;
            }
            function finishUpdateFunctionDeclaration(updated, original) {
                if (updated !== original) {
                    if (updated.modifiers === original.modifiers) {
                        updated.modifiers = original.modifiers;
                    }
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createClassDeclaration(modifiers, name, typeParameters, heritageClauses, members) {
                const node = createBaseDeclaration(260 /* ClassDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.heritageClauses = asNodeArray(heritageClauses);
                node.members = createNodeArray(members);
                if (modifiersToFlags(node.modifiers) & 2 /* Ambient */) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.heritageClauses) | propagateChildrenFlags(node.members) | (node.typeParameters ? 1 /* ContainsTypeScript */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                    if (node.transformFlags & 8192 /* ContainsTypeScriptClassSyntax */) {
                        node.transformFlags |= 1 /* ContainsTypeScript */;
                    }
                }
                node.jsDoc = void 0;
                return node;
            }
            function updateClassDeclaration(node, modifiers, name, typeParameters, heritageClauses, members) {
                return node.modifiers !== modifiers || node.name !== name || node.typeParameters !== typeParameters || node.heritageClauses !== heritageClauses || node.members !== members ? update(createClassDeclaration(modifiers, name, typeParameters, heritageClauses, members), node) : node;
            }
            function createInterfaceDeclaration(modifiers, name, typeParameters, heritageClauses, members) {
                const node = createBaseDeclaration(261 /* InterfaceDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.heritageClauses = asNodeArray(heritageClauses);
                node.members = createNodeArray(members);
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                return node;
            }
            function updateInterfaceDeclaration(node, modifiers, name, typeParameters, heritageClauses, members) {
                return node.modifiers !== modifiers || node.name !== name || node.typeParameters !== typeParameters || node.heritageClauses !== heritageClauses || node.members !== members ? update(createInterfaceDeclaration(modifiers, name, typeParameters, heritageClauses, members), node) : node;
            }
            function createTypeAliasDeclaration(modifiers, name, typeParameters, type) {
                const node = createBaseDeclaration(262 /* TypeAliasDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateTypeAliasDeclaration(node, modifiers, name, typeParameters, type) {
                return node.modifiers !== modifiers || node.name !== name || node.typeParameters !== typeParameters || node.type !== type ? update(createTypeAliasDeclaration(modifiers, name, typeParameters, type), node) : node;
            }
            function createEnumDeclaration(modifiers, name, members) {
                const node = createBaseDeclaration(263 /* EnumDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.members = createNodeArray(members);
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.name) | propagateChildrenFlags(node.members) | 1 /* ContainsTypeScript */;
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateEnumDeclaration(node, modifiers, name, members) {
                return node.modifiers !== modifiers || node.name !== name || node.members !== members ? update(createEnumDeclaration(modifiers, name, members), node) : node;
            }
            function createModuleDeclaration(modifiers, name, body, flags2 = 0 /* None */) {
                const node = createBaseDeclaration(264 /* ModuleDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.flags |= flags2 & (16 /* Namespace */ | 4 /* NestedNamespace */ | 1024 /* GlobalAugmentation */);
                node.name = name;
                node.body = body;
                if (modifiersToFlags(node.modifiers) & 2 /* Ambient */) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.name) | propagateChildFlags(node.body) | 1 /* ContainsTypeScript */;
                }
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateModuleDeclaration(node, modifiers, name, body) {
                return node.modifiers !== modifiers || node.name !== name || node.body !== body ? update(createModuleDeclaration(modifiers, name, body, node.flags), node) : node;
            }
            function createModuleBlock(statements) {
                const node = createBaseNode(265 /* ModuleBlock */);
                node.statements = createNodeArray(statements);
                node.transformFlags |= propagateChildrenFlags(node.statements);
                node.jsDoc = void 0;
                return node;
            }
            function updateModuleBlock(node, statements) {
                return node.statements !== statements ? update(createModuleBlock(statements), node) : node;
            }
            function createCaseBlock(clauses) {
                const node = createBaseNode(266 /* CaseBlock */);
                node.clauses = createNodeArray(clauses);
                node.transformFlags |= propagateChildrenFlags(node.clauses);
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateCaseBlock(node, clauses) {
                return node.clauses !== clauses ? update(createCaseBlock(clauses), node) : node;
            }
            function createNamespaceExportDeclaration(name) {
                const node = createBaseDeclaration(267 /* NamespaceExportDeclaration */);
                node.name = asName(name);
                node.transformFlags |= propagateIdentifierNameFlags(node.name) | 1 /* ContainsTypeScript */;
                node.modifiers = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updateNamespaceExportDeclaration(node, name) {
                return node.name !== name ? finishUpdateNamespaceExportDeclaration(createNamespaceExportDeclaration(name), node) : node;
            }
            function finishUpdateNamespaceExportDeclaration(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                }
                return update(updated, original);
            }
            function createImportEqualsDeclaration(modifiers, isTypeOnly, name, moduleReference) {
                const node = createBaseDeclaration(268 /* ImportEqualsDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.isTypeOnly = isTypeOnly;
                node.moduleReference = moduleReference;
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateIdentifierNameFlags(node.name) | propagateChildFlags(node.moduleReference);
                if (!isExternalModuleReference(node.moduleReference)) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateImportEqualsDeclaration(node, modifiers, isTypeOnly, name, moduleReference) {
                return node.modifiers !== modifiers || node.isTypeOnly !== isTypeOnly || node.name !== name || node.moduleReference !== moduleReference ? update(createImportEqualsDeclaration(modifiers, isTypeOnly, name, moduleReference), node) : node;
            }
            function createImportDeclaration(modifiers, importClause, moduleSpecifier, assertClause) {
                const node = createBaseNode(269 /* ImportDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.importClause = importClause;
                node.moduleSpecifier = moduleSpecifier;
                node.assertClause = assertClause;
                node.transformFlags |= propagateChildFlags(node.importClause) | propagateChildFlags(node.moduleSpecifier);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateImportDeclaration(node, modifiers, importClause, moduleSpecifier, assertClause) {
                return node.modifiers !== modifiers || node.importClause !== importClause || node.moduleSpecifier !== moduleSpecifier || node.assertClause !== assertClause ? update(createImportDeclaration(modifiers, importClause, moduleSpecifier, assertClause), node) : node;
            }
            function createImportClause(isTypeOnly, name, namedBindings) {
                const node = createBaseDeclaration(270 /* ImportClause */);
                node.isTypeOnly = isTypeOnly;
                node.name = name;
                node.namedBindings = namedBindings;
                node.transformFlags |= propagateChildFlags(node.name) | propagateChildFlags(node.namedBindings);
                if (isTypeOnly) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateImportClause(node, isTypeOnly, name, namedBindings) {
                return node.isTypeOnly !== isTypeOnly || node.name !== name || node.namedBindings !== namedBindings ? update(createImportClause(isTypeOnly, name, namedBindings), node) : node;
            }
            function createAssertClause(elements, multiLine) {
                const node = createBaseNode(296 /* AssertClause */);
                node.elements = createNodeArray(elements);
                node.multiLine = multiLine;
                node.transformFlags |= 4 /* ContainsESNext */;
                return node;
            }
            function updateAssertClause(node, elements, multiLine) {
                return node.elements !== elements || node.multiLine !== multiLine ? update(createAssertClause(elements, multiLine), node) : node;
            }
            function createAssertEntry(name, value) {
                const node = createBaseNode(297 /* AssertEntry */);
                node.name = name;
                node.value = value;
                node.transformFlags |= 4 /* ContainsESNext */;
                return node;
            }
            function updateAssertEntry(node, name, value) {
                return node.name !== name || node.value !== value ? update(createAssertEntry(name, value), node) : node;
            }
            function createImportTypeAssertionContainer(clause, multiLine) {
                const node = createBaseNode(298 /* ImportTypeAssertionContainer */);
                node.assertClause = clause;
                node.multiLine = multiLine;
                return node;
            }
            function updateImportTypeAssertionContainer(node, clause, multiLine) {
                return node.assertClause !== clause || node.multiLine !== multiLine ? update(createImportTypeAssertionContainer(clause, multiLine), node) : node;
            }
            function createNamespaceImport(name) {
                const node = createBaseDeclaration(271 /* NamespaceImport */);
                node.name = name;
                node.transformFlags |= propagateChildFlags(node.name);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateNamespaceImport(node, name) {
                return node.name !== name ? update(createNamespaceImport(name), node) : node;
            }
            function createNamespaceExport(name) {
                const node = createBaseDeclaration(277 /* NamespaceExport */);
                node.name = name;
                node.transformFlags |= propagateChildFlags(node.name) | 4 /* ContainsESNext */;
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateNamespaceExport(node, name) {
                return node.name !== name ? update(createNamespaceExport(name), node) : node;
            }
            function createNamedImports(elements) {
                const node = createBaseNode(272 /* NamedImports */);
                node.elements = createNodeArray(elements);
                node.transformFlags |= propagateChildrenFlags(node.elements);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateNamedImports(node, elements) {
                return node.elements !== elements ? update(createNamedImports(elements), node) : node;
            }
            function createImportSpecifier(isTypeOnly, propertyName, name) {
                const node = createBaseDeclaration(273 /* ImportSpecifier */);
                node.isTypeOnly = isTypeOnly;
                node.propertyName = propertyName;
                node.name = name;
                node.transformFlags |= propagateChildFlags(node.propertyName) | propagateChildFlags(node.name);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateImportSpecifier(node, isTypeOnly, propertyName, name) {
                return node.isTypeOnly !== isTypeOnly || node.propertyName !== propertyName || node.name !== name ? update(createImportSpecifier(isTypeOnly, propertyName, name), node) : node;
            }
            function createExportAssignment2(modifiers, isExportEquals, expression) {
                const node = createBaseDeclaration(274 /* ExportAssignment */);
                node.modifiers = asNodeArray(modifiers);
                node.isExportEquals = isExportEquals;
                node.expression = isExportEquals ? parenthesizerRules().parenthesizeRightSideOfBinary(63 /* EqualsToken */, 
                /*leftSide*/
                void 0, expression) : parenthesizerRules().parenthesizeExpressionOfExportDefault(expression);
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.expression);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateExportAssignment(node, modifiers, expression) {
                return node.modifiers !== modifiers || node.expression !== expression ? update(createExportAssignment2(modifiers, node.isExportEquals, expression), node) : node;
            }
            function createExportDeclaration(modifiers, isTypeOnly, exportClause, moduleSpecifier, assertClause) {
                const node = createBaseDeclaration(275 /* ExportDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.isTypeOnly = isTypeOnly;
                node.exportClause = exportClause;
                node.moduleSpecifier = moduleSpecifier;
                node.assertClause = assertClause;
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.exportClause) | propagateChildFlags(node.moduleSpecifier);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateExportDeclaration(node, modifiers, isTypeOnly, exportClause, moduleSpecifier, assertClause) {
                return node.modifiers !== modifiers || node.isTypeOnly !== isTypeOnly || node.exportClause !== exportClause || node.moduleSpecifier !== moduleSpecifier || node.assertClause !== assertClause ? finishUpdateExportDeclaration(createExportDeclaration(modifiers, isTypeOnly, exportClause, moduleSpecifier, assertClause), node) : node;
            }
            function finishUpdateExportDeclaration(updated, original) {
                if (updated !== original) {
                    if (updated.modifiers === original.modifiers) {
                        updated.modifiers = original.modifiers;
                    }
                }
                return update(updated, original);
            }
            function createNamedExports(elements) {
                const node = createBaseNode(276 /* NamedExports */);
                node.elements = createNodeArray(elements);
                node.transformFlags |= propagateChildrenFlags(node.elements);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateNamedExports(node, elements) {
                return node.elements !== elements ? update(createNamedExports(elements), node) : node;
            }
            function createExportSpecifier(isTypeOnly, propertyName, name) {
                const node = createBaseNode(278 /* ExportSpecifier */);
                node.isTypeOnly = isTypeOnly;
                node.propertyName = asName(propertyName);
                node.name = asName(name);
                node.transformFlags |= propagateChildFlags(node.propertyName) | propagateChildFlags(node.name);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateExportSpecifier(node, isTypeOnly, propertyName, name) {
                return node.isTypeOnly !== isTypeOnly || node.propertyName !== propertyName || node.name !== name ? update(createExportSpecifier(isTypeOnly, propertyName, name), node) : node;
            }
            function createMissingDeclaration() {
                const node = createBaseDeclaration(279 /* MissingDeclaration */);
                node.jsDoc = void 0;
                return node;
            }
            function createExternalModuleReference(expression) {
                const node = createBaseNode(280 /* ExternalModuleReference */);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.expression);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateExternalModuleReference(node, expression) {
                return node.expression !== expression ? update(createExternalModuleReference(expression), node) : node;
            }
            function createJSDocPrimaryTypeWorker(kind) {
                return createBaseNode(kind);
            }
            function createJSDocPrePostfixUnaryTypeWorker(kind, type, postfix = false) {
                const node = createJSDocUnaryTypeWorker(kind, postfix ? type && parenthesizerRules().parenthesizeNonArrayTypeOfPostfixType(type) : type);
                node.postfix = postfix;
                return node;
            }
            function createJSDocUnaryTypeWorker(kind, type) {
                const node = createBaseNode(kind);
                node.type = type;
                return node;
            }
            function updateJSDocPrePostfixUnaryTypeWorker(kind, node, type) {
                return node.type !== type ? update(createJSDocPrePostfixUnaryTypeWorker(kind, type, node.postfix), node) : node;
            }
            function updateJSDocUnaryTypeWorker(kind, node, type) {
                return node.type !== type ? update(createJSDocUnaryTypeWorker(kind, type), node) : node;
            }
            function createJSDocFunctionType(parameters, type) {
                const node = createBaseDeclaration(320 /* JSDocFunctionType */);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = propagateChildrenFlags(node.parameters) | (node.type ? 1 /* ContainsTypeScript */ : 0 /* None */);
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateJSDocFunctionType(node, parameters, type) {
                return node.parameters !== parameters || node.type !== type ? update(createJSDocFunctionType(parameters, type), node) : node;
            }
            function createJSDocTypeLiteral(propertyTags, isArrayType = false) {
                const node = createBaseDeclaration(325 /* JSDocTypeLiteral */);
                node.jsDocPropertyTags = asNodeArray(propertyTags);
                node.isArrayType = isArrayType;
                return node;
            }
            function updateJSDocTypeLiteral(node, propertyTags, isArrayType) {
                return node.jsDocPropertyTags !== propertyTags || node.isArrayType !== isArrayType ? update(createJSDocTypeLiteral(propertyTags, isArrayType), node) : node;
            }
            function createJSDocTypeExpression(type) {
                const node = createBaseNode(312 /* JSDocTypeExpression */);
                node.type = type;
                return node;
            }
            function updateJSDocTypeExpression(node, type) {
                return node.type !== type ? update(createJSDocTypeExpression(type), node) : node;
            }
            function createJSDocSignature(typeParameters, parameters, type) {
                const node = createBaseDeclaration(326 /* JSDocSignature */);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateJSDocSignature(node, typeParameters, parameters, type) {
                return node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? update(createJSDocSignature(typeParameters, parameters, type), node) : node;
            }
            function getDefaultTagName(node) {
                const defaultTagName = getDefaultTagNameForKind(node.kind);
                return node.tagName.escapedText === escapeLeadingUnderscores(defaultTagName) ? node.tagName : createIdentifier(defaultTagName);
            }
            function createBaseJSDocTag(kind, tagName, comment) {
                const node = createBaseNode(kind);
                node.tagName = tagName;
                node.comment = comment;
                return node;
            }
            function createBaseJSDocTagDeclaration(kind, tagName, comment) {
                const node = createBaseDeclaration(kind);
                node.tagName = tagName;
                node.comment = comment;
                return node;
            }
            function createJSDocTemplateTag(tagName, constraint, typeParameters, comment) {
                const node = createBaseJSDocTag(348 /* JSDocTemplateTag */, tagName != null ? tagName : createIdentifier("template"), comment);
                node.constraint = constraint;
                node.typeParameters = createNodeArray(typeParameters);
                return node;
            }
            function updateJSDocTemplateTag(node, tagName = getDefaultTagName(node), constraint, typeParameters, comment) {
                return node.tagName !== tagName || node.constraint !== constraint || node.typeParameters !== typeParameters || node.comment !== comment ? update(createJSDocTemplateTag(tagName, constraint, typeParameters, comment), node) : node;
            }
            function createJSDocTypedefTag(tagName, typeExpression, fullName, comment) {
                const node = createBaseJSDocTagDeclaration(349 /* JSDocTypedefTag */, tagName != null ? tagName : createIdentifier("typedef"), comment);
                node.typeExpression = typeExpression;
                node.fullName = fullName;
                node.name = getJSDocTypeAliasName(fullName);
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateJSDocTypedefTag(node, tagName = getDefaultTagName(node), typeExpression, fullName, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.fullName !== fullName || node.comment !== comment ? update(createJSDocTypedefTag(tagName, typeExpression, fullName, comment), node) : node;
            }
            function createJSDocParameterTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment) {
                const node = createBaseJSDocTagDeclaration(344 /* JSDocParameterTag */, tagName != null ? tagName : createIdentifier("param"), comment);
                node.typeExpression = typeExpression;
                node.name = name;
                node.isNameFirst = !!isNameFirst;
                node.isBracketed = isBracketed;
                return node;
            }
            function updateJSDocParameterTag(node, tagName = getDefaultTagName(node), name, isBracketed, typeExpression, isNameFirst, comment) {
                return node.tagName !== tagName || node.name !== name || node.isBracketed !== isBracketed || node.typeExpression !== typeExpression || node.isNameFirst !== isNameFirst || node.comment !== comment ? update(createJSDocParameterTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment), node) : node;
            }
            function createJSDocPropertyTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment) {
                const node = createBaseJSDocTagDeclaration(351 /* JSDocPropertyTag */, tagName != null ? tagName : createIdentifier("prop"), comment);
                node.typeExpression = typeExpression;
                node.name = name;
                node.isNameFirst = !!isNameFirst;
                node.isBracketed = isBracketed;
                return node;
            }
            function updateJSDocPropertyTag(node, tagName = getDefaultTagName(node), name, isBracketed, typeExpression, isNameFirst, comment) {
                return node.tagName !== tagName || node.name !== name || node.isBracketed !== isBracketed || node.typeExpression !== typeExpression || node.isNameFirst !== isNameFirst || node.comment !== comment ? update(createJSDocPropertyTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment), node) : node;
            }
            function createJSDocCallbackTag(tagName, typeExpression, fullName, comment) {
                const node = createBaseJSDocTagDeclaration(341 /* JSDocCallbackTag */, tagName != null ? tagName : createIdentifier("callback"), comment);
                node.typeExpression = typeExpression;
                node.fullName = fullName;
                node.name = getJSDocTypeAliasName(fullName);
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateJSDocCallbackTag(node, tagName = getDefaultTagName(node), typeExpression, fullName, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.fullName !== fullName || node.comment !== comment ? update(createJSDocCallbackTag(tagName, typeExpression, fullName, comment), node) : node;
            }
            function createJSDocOverloadTag(tagName, typeExpression, comment) {
                const node = createBaseJSDocTag(342 /* JSDocOverloadTag */, tagName != null ? tagName : createIdentifier("overload"), comment);
                node.typeExpression = typeExpression;
                return node;
            }
            function updateJSDocOverloadTag(node, tagName = getDefaultTagName(node), typeExpression, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.comment !== comment ? update(createJSDocOverloadTag(tagName, typeExpression, comment), node) : node;
            }
            function createJSDocAugmentsTag(tagName, className, comment) {
                const node = createBaseJSDocTag(331 /* JSDocAugmentsTag */, tagName != null ? tagName : createIdentifier("augments"), comment);
                node.class = className;
                return node;
            }
            function updateJSDocAugmentsTag(node, tagName = getDefaultTagName(node), className, comment) {
                return node.tagName !== tagName || node.class !== className || node.comment !== comment ? update(createJSDocAugmentsTag(tagName, className, comment), node) : node;
            }
            function createJSDocImplementsTag(tagName, className, comment) {
                const node = createBaseJSDocTag(332 /* JSDocImplementsTag */, tagName != null ? tagName : createIdentifier("implements"), comment);
                node.class = className;
                return node;
            }
            function createJSDocSeeTag(tagName, name, comment) {
                const node = createBaseJSDocTag(350 /* JSDocSeeTag */, tagName != null ? tagName : createIdentifier("see"), comment);
                node.name = name;
                return node;
            }
            function updateJSDocSeeTag(node, tagName, name, comment) {
                return node.tagName !== tagName || node.name !== name || node.comment !== comment ? update(createJSDocSeeTag(tagName, name, comment), node) : node;
            }
            function createJSDocNameReference(name) {
                const node = createBaseNode(313 /* JSDocNameReference */);
                node.name = name;
                return node;
            }
            function updateJSDocNameReference(node, name) {
                return node.name !== name ? update(createJSDocNameReference(name), node) : node;
            }
            function createJSDocMemberName(left, right) {
                const node = createBaseNode(314 /* JSDocMemberName */);
                node.left = left;
                node.right = right;
                node.transformFlags |= propagateChildFlags(node.left) | propagateChildFlags(node.right);
                return node;
            }
            function updateJSDocMemberName(node, left, right) {
                return node.left !== left || node.right !== right ? update(createJSDocMemberName(left, right), node) : node;
            }
            function createJSDocLink(name, text) {
                const node = createBaseNode(327 /* JSDocLink */);
                node.name = name;
                node.text = text;
                return node;
            }
            function updateJSDocLink(node, name, text) {
                return node.name !== name ? update(createJSDocLink(name, text), node) : node;
            }
            function createJSDocLinkCode(name, text) {
                const node = createBaseNode(328 /* JSDocLinkCode */);
                node.name = name;
                node.text = text;
                return node;
            }
            function updateJSDocLinkCode(node, name, text) {
                return node.name !== name ? update(createJSDocLinkCode(name, text), node) : node;
            }
            function createJSDocLinkPlain(name, text) {
                const node = createBaseNode(329 /* JSDocLinkPlain */);
                node.name = name;
                node.text = text;
                return node;
            }
            function updateJSDocLinkPlain(node, name, text) {
                return node.name !== name ? update(createJSDocLinkPlain(name, text), node) : node;
            }
            function updateJSDocImplementsTag(node, tagName = getDefaultTagName(node), className, comment) {
                return node.tagName !== tagName || node.class !== className || node.comment !== comment ? update(createJSDocImplementsTag(tagName, className, comment), node) : node;
            }
            function createJSDocSimpleTagWorker(kind, tagName, comment) {
                const node = createBaseJSDocTag(kind, tagName != null ? tagName : createIdentifier(getDefaultTagNameForKind(kind)), comment);
                return node;
            }
            function updateJSDocSimpleTagWorker(kind, node, tagName = getDefaultTagName(node), comment) {
                return node.tagName !== tagName || node.comment !== comment ? update(createJSDocSimpleTagWorker(kind, tagName, comment), node) : node;
            }
            function createJSDocTypeLikeTagWorker(kind, tagName, typeExpression, comment) {
                const node = createBaseJSDocTag(kind, tagName != null ? tagName : createIdentifier(getDefaultTagNameForKind(kind)), comment);
                node.typeExpression = typeExpression;
                return node;
            }
            function updateJSDocTypeLikeTagWorker(kind, node, tagName = getDefaultTagName(node), typeExpression, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.comment !== comment ? update(createJSDocTypeLikeTagWorker(kind, tagName, typeExpression, comment), node) : node;
            }
            function createJSDocUnknownTag(tagName, comment) {
                const node = createBaseJSDocTag(330 /* JSDocTag */, tagName, comment);
                return node;
            }
            function updateJSDocUnknownTag(node, tagName, comment) {
                return node.tagName !== tagName || node.comment !== comment ? update(createJSDocUnknownTag(tagName, comment), node) : node;
            }
            function createJSDocEnumTag(tagName, typeExpression, comment) {
                const node = createBaseJSDocTagDeclaration(343 /* JSDocEnumTag */, tagName != null ? tagName : createIdentifier(getDefaultTagNameForKind(343 /* JSDocEnumTag */)), comment);
                node.typeExpression = typeExpression;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateJSDocEnumTag(node, tagName = getDefaultTagName(node), typeExpression, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.comment !== comment ? update(createJSDocEnumTag(tagName, typeExpression, comment), node) : node;
            }
            function createJSDocText(text) {
                const node = createBaseNode(324 /* JSDocText */);
                node.text = text;
                return node;
            }
            function updateJSDocText(node, text) {
                return node.text !== text ? update(createJSDocText(text), node) : node;
            }
            function createJSDocComment(comment, tags) {
                const node = createBaseNode(323 /* JSDoc */);
                node.comment = comment;
                node.tags = asNodeArray(tags);
                return node;
            }
            function updateJSDocComment(node, comment, tags) {
                return node.comment !== comment || node.tags !== tags ? update(createJSDocComment(comment, tags), node) : node;
            }
            function createJsxElement(openingElement, children, closingElement) {
                const node = createBaseNode(281 /* JsxElement */);
                node.openingElement = openingElement;
                node.children = createNodeArray(children);
                node.closingElement = closingElement;
                node.transformFlags |= propagateChildFlags(node.openingElement) | propagateChildrenFlags(node.children) | propagateChildFlags(node.closingElement) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxElement(node, openingElement, children, closingElement) {
                return node.openingElement !== openingElement || node.children !== children || node.closingElement !== closingElement ? update(createJsxElement(openingElement, children, closingElement), node) : node;
            }
            function createJsxSelfClosingElement(tagName, typeArguments, attributes) {
                const node = createBaseNode(282 /* JsxSelfClosingElement */);
                node.tagName = tagName;
                node.typeArguments = asNodeArray(typeArguments);
                node.attributes = attributes;
                node.transformFlags |= propagateChildFlags(node.tagName) | propagateChildrenFlags(node.typeArguments) | propagateChildFlags(node.attributes) | 2 /* ContainsJsx */;
                if (node.typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                return node;
            }
            function updateJsxSelfClosingElement(node, tagName, typeArguments, attributes) {
                return node.tagName !== tagName || node.typeArguments !== typeArguments || node.attributes !== attributes ? update(createJsxSelfClosingElement(tagName, typeArguments, attributes), node) : node;
            }
            function createJsxOpeningElement(tagName, typeArguments, attributes) {
                const node = createBaseNode(283 /* JsxOpeningElement */);
                node.tagName = tagName;
                node.typeArguments = asNodeArray(typeArguments);
                node.attributes = attributes;
                node.transformFlags |= propagateChildFlags(node.tagName) | propagateChildrenFlags(node.typeArguments) | propagateChildFlags(node.attributes) | 2 /* ContainsJsx */;
                if (typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                return node;
            }
            function updateJsxOpeningElement(node, tagName, typeArguments, attributes) {
                return node.tagName !== tagName || node.typeArguments !== typeArguments || node.attributes !== attributes ? update(createJsxOpeningElement(tagName, typeArguments, attributes), node) : node;
            }
            function createJsxClosingElement(tagName) {
                const node = createBaseNode(284 /* JsxClosingElement */);
                node.tagName = tagName;
                node.transformFlags |= propagateChildFlags(node.tagName) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxClosingElement(node, tagName) {
                return node.tagName !== tagName ? update(createJsxClosingElement(tagName), node) : node;
            }
            function createJsxFragment(openingFragment, children, closingFragment) {
                const node = createBaseNode(285 /* JsxFragment */);
                node.openingFragment = openingFragment;
                node.children = createNodeArray(children);
                node.closingFragment = closingFragment;
                node.transformFlags |= propagateChildFlags(node.openingFragment) | propagateChildrenFlags(node.children) | propagateChildFlags(node.closingFragment) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxFragment(node, openingFragment, children, closingFragment) {
                return node.openingFragment !== openingFragment || node.children !== children || node.closingFragment !== closingFragment ? update(createJsxFragment(openingFragment, children, closingFragment), node) : node;
            }
            function createJsxText(text, containsOnlyTriviaWhiteSpaces) {
                const node = createBaseNode(11 /* JsxText */);
                node.text = text;
                node.containsOnlyTriviaWhiteSpaces = !!containsOnlyTriviaWhiteSpaces;
                node.transformFlags |= 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxText(node, text, containsOnlyTriviaWhiteSpaces) {
                return node.text !== text || node.containsOnlyTriviaWhiteSpaces !== containsOnlyTriviaWhiteSpaces ? update(createJsxText(text, containsOnlyTriviaWhiteSpaces), node) : node;
            }
            function createJsxOpeningFragment() {
                const node = createBaseNode(286 /* JsxOpeningFragment */);
                node.transformFlags |= 2 /* ContainsJsx */;
                return node;
            }
            function createJsxJsxClosingFragment() {
                const node = createBaseNode(287 /* JsxClosingFragment */);
                node.transformFlags |= 2 /* ContainsJsx */;
                return node;
            }
            function createJsxAttribute(name, initializer) {
                const node = createBaseDeclaration(288 /* JsxAttribute */);
                node.name = name;
                node.initializer = initializer;
                node.transformFlags |= propagateChildFlags(node.name) | propagateChildFlags(node.initializer) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxAttribute(node, name, initializer) {
                return node.name !== name || node.initializer !== initializer ? update(createJsxAttribute(name, initializer), node) : node;
            }
            function createJsxAttributes(properties) {
                const node = createBaseDeclaration(289 /* JsxAttributes */);
                node.properties = createNodeArray(properties);
                node.transformFlags |= propagateChildrenFlags(node.properties) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxAttributes(node, properties) {
                return node.properties !== properties ? update(createJsxAttributes(properties), node) : node;
            }
            function createJsxSpreadAttribute(expression) {
                const node = createBaseNode(290 /* JsxSpreadAttribute */);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.expression) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxSpreadAttribute(node, expression) {
                return node.expression !== expression ? update(createJsxSpreadAttribute(expression), node) : node;
            }
            function createJsxExpression(dotDotDotToken, expression) {
                const node = createBaseNode(291 /* JsxExpression */);
                node.dotDotDotToken = dotDotDotToken;
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.dotDotDotToken) | propagateChildFlags(node.expression) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxExpression(node, expression) {
                return node.expression !== expression ? update(createJsxExpression(node.dotDotDotToken, expression), node) : node;
            }
            function createCaseClause(expression, statements) {
                const node = createBaseNode(292 /* CaseClause */);
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.statements = createNodeArray(statements);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildrenFlags(node.statements);
                node.jsDoc = void 0;
                return node;
            }
            function updateCaseClause(node, expression, statements) {
                return node.expression !== expression || node.statements !== statements ? update(createCaseClause(expression, statements), node) : node;
            }
            function createDefaultClause(statements) {
                const node = createBaseNode(293 /* DefaultClause */);
                node.statements = createNodeArray(statements);
                node.transformFlags = propagateChildrenFlags(node.statements);
                return node;
            }
            function updateDefaultClause(node, statements) {
                return node.statements !== statements ? update(createDefaultClause(statements), node) : node;
            }
            function createHeritageClause(token, types) {
                const node = createBaseNode(294 /* HeritageClause */);
                node.token = token;
                node.types = createNodeArray(types);
                node.transformFlags |= propagateChildrenFlags(node.types);
                switch (token) {
                    case 94 /* ExtendsKeyword */:
                        node.transformFlags |= 1024 /* ContainsES2015 */;
                        break;
                    case 117 /* ImplementsKeyword */:
                        node.transformFlags |= 1 /* ContainsTypeScript */;
                        break;
                    default:
                        return Debug.assertNever(token);
                }
                return node;
            }
            function updateHeritageClause(node, types) {
                return node.types !== types ? update(createHeritageClause(node.token, types), node) : node;
            }
            function createCatchClause(variableDeclaration, block) {
                const node = createBaseNode(295 /* CatchClause */);
                node.variableDeclaration = asVariableDeclaration(variableDeclaration);
                node.block = block;
                node.transformFlags |= propagateChildFlags(node.variableDeclaration) | propagateChildFlags(node.block) | (!variableDeclaration ? 64 /* ContainsES2019 */ : 0 /* None */);
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateCatchClause(node, variableDeclaration, block) {
                return node.variableDeclaration !== variableDeclaration || node.block !== block ? update(createCatchClause(variableDeclaration, block), node) : node;
            }
            function createPropertyAssignment(name, initializer) {
                const node = createBaseDeclaration(299 /* PropertyAssignment */);
                node.name = asName(name);
                node.initializer = parenthesizerRules().parenthesizeExpressionForDisallowedComma(initializer);
                node.transformFlags |= propagateNameFlags(node.name) | propagateChildFlags(node.initializer);
                node.modifiers = void 0;
                node.questionToken = void 0;
                node.exclamationToken = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updatePropertyAssignment(node, name, initializer) {
                return node.name !== name || node.initializer !== initializer ? finishUpdatePropertyAssignment(createPropertyAssignment(name, initializer), node) : node;
            }
            function finishUpdatePropertyAssignment(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                    updated.questionToken = original.questionToken;
                    updated.exclamationToken = original.exclamationToken;
                }
                return update(updated, original);
            }
            function createShorthandPropertyAssignment(name, objectAssignmentInitializer) {
                const node = createBaseDeclaration(300 /* ShorthandPropertyAssignment */);
                node.name = asName(name);
                node.objectAssignmentInitializer = objectAssignmentInitializer && parenthesizerRules().parenthesizeExpressionForDisallowedComma(objectAssignmentInitializer);
                node.transformFlags |= propagateIdentifierNameFlags(node.name) | propagateChildFlags(node.objectAssignmentInitializer) | 1024 /* ContainsES2015 */;
                node.equalsToken = void 0;
                node.modifiers = void 0;
                node.questionToken = void 0;
                node.exclamationToken = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updateShorthandPropertyAssignment(node, name, objectAssignmentInitializer) {
                return node.name !== name || node.objectAssignmentInitializer !== objectAssignmentInitializer ? finishUpdateShorthandPropertyAssignment(createShorthandPropertyAssignment(name, objectAssignmentInitializer), node) : node;
            }
            function finishUpdateShorthandPropertyAssignment(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                    updated.questionToken = original.questionToken;
                    updated.exclamationToken = original.exclamationToken;
                    updated.equalsToken = original.equalsToken;
                }
                return update(updated, original);
            }
            function createSpreadAssignment(expression) {
                const node = createBaseDeclaration(301 /* SpreadAssignment */);
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.transformFlags |= propagateChildFlags(node.expression) | 128 /* ContainsES2018 */ | 65536 /* ContainsObjectRestOrSpread */;
                node.jsDoc = void 0;
                return node;
            }
            function updateSpreadAssignment(node, expression) {
                return node.expression !== expression ? update(createSpreadAssignment(expression), node) : node;
            }
            function createEnumMember(name, initializer) {
                const node = createBaseDeclaration(302 /* EnumMember */);
                node.name = asName(name);
                node.initializer = initializer && parenthesizerRules().parenthesizeExpressionForDisallowedComma(initializer);
                node.transformFlags |= propagateChildFlags(node.name) | propagateChildFlags(node.initializer) | 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                return node;
            }
            function updateEnumMember(node, name, initializer) {
                return node.name !== name || node.initializer !== initializer ? update(createEnumMember(name, initializer), node) : node;
            }
            function createSourceFile2(statements, endOfFileToken, flags2) {
                const node = baseFactory2.createBaseSourceFileNode(308 /* SourceFile */);
                node.statements = createNodeArray(statements);
                node.endOfFileToken = endOfFileToken;
                node.flags |= flags2;
                node.text = "";
                node.fileName = "";
                node.path = "";
                node.resolvedPath = "";
                node.originalFileName = "";
                node.languageVersion = 0;
                node.languageVariant = 0;
                node.scriptKind = 0;
                node.isDeclarationFile = false;
                node.hasNoDefaultLib = false;
                node.transformFlags |= propagateChildrenFlags(node.statements) | propagateChildFlags(node.endOfFileToken);
                node.locals = void 0;
                node.nextContainer = void 0;
                node.endFlowNode = void 0;
                node.nodeCount = 0;
                node.identifierCount = 0;
                node.symbolCount = 0;
                node.parseDiagnostics = void 0;
                node.bindDiagnostics = void 0;
                node.bindSuggestionDiagnostics = void 0;
                node.lineMap = void 0;
                node.externalModuleIndicator = void 0;
                node.setExternalModuleIndicator = void 0;
                node.pragmas = void 0;
                node.checkJsDirective = void 0;
                node.referencedFiles = void 0;
                node.typeReferenceDirectives = void 0;
                node.libReferenceDirectives = void 0;
                node.amdDependencies = void 0;
                node.commentDirectives = void 0;
                node.identifiers = void 0;
                node.packageJsonLocations = void 0;
                node.packageJsonScope = void 0;
                node.imports = void 0;
                node.moduleAugmentations = void 0;
                node.ambientModuleNames = void 0;
                node.resolvedModules = void 0;
                node.classifiableNames = void 0;
                node.impliedNodeFormat = void 0;
                return node;
            }
            function createRedirectedSourceFile(redirectInfo) {
                const node = Object.create(redirectInfo.redirectTarget);
                Object.defineProperties(node, {
                    id: {
                        get() {
                            return this.redirectInfo.redirectTarget.id;
                        },
                        set(value) {
                            this.redirectInfo.redirectTarget.id = value;
                        }
                    },
                    symbol: {
                        get() {
                            return this.redirectInfo.redirectTarget.symbol;
                        },
                        set(value) {
                            this.redirectInfo.redirectTarget.symbol = value;
                        }
                    }
                });
                node.redirectInfo = redirectInfo;
                return node;
            }
            function cloneRedirectedSourceFile(source) {
                const node = createRedirectedSourceFile(source.redirectInfo);
                node.flags |= source.flags & ~8 /* Synthesized */;
                node.fileName = source.fileName;
                node.path = source.path;
                node.resolvedPath = source.resolvedPath;
                node.originalFileName = source.originalFileName;
                node.packageJsonLocations = source.packageJsonLocations;
                node.packageJsonScope = source.packageJsonScope;
                node.emitNode = void 0;
                return node;
            }
            function cloneSourceFileWorker(source) {
                const node = baseFactory2.createBaseSourceFileNode(308 /* SourceFile */);
                node.flags |= source.flags & ~8 /* Synthesized */;
                for (const p in source) {
                    if (hasProperty(node, p) || !hasProperty(source, p)) {
                        continue;
                    }
                    if (p === "emitNode") {
                        node.emitNode = void 0;
                        continue;
                    }
                    node[p] = source[p];
                }
                return node;
            }
            function cloneSourceFile(source) {
                const node = source.redirectInfo ? cloneRedirectedSourceFile(source) : cloneSourceFileWorker(source);
                setOriginalNode(node, source);
                return node;
            }
            function cloneSourceFileWithChanges(source, statements, isDeclarationFile, referencedFiles, typeReferences, hasNoDefaultLib, libReferences) {
                const node = cloneSourceFile(source);
                node.statements = createNodeArray(statements);
                node.isDeclarationFile = isDeclarationFile;
                node.referencedFiles = referencedFiles;
                node.typeReferenceDirectives = typeReferences;
                node.hasNoDefaultLib = hasNoDefaultLib;
                node.libReferenceDirectives = libReferences;
                node.transformFlags = propagateChildrenFlags(node.statements) | propagateChildFlags(node.endOfFileToken);
                return node;
            }
            function updateSourceFile2(node, statements, isDeclarationFile = node.isDeclarationFile, referencedFiles = node.referencedFiles, typeReferenceDirectives = node.typeReferenceDirectives, hasNoDefaultLib = node.hasNoDefaultLib, libReferenceDirectives = node.libReferenceDirectives) {
                return node.statements !== statements || node.isDeclarationFile !== isDeclarationFile || node.referencedFiles !== referencedFiles || node.typeReferenceDirectives !== typeReferenceDirectives || node.hasNoDefaultLib !== hasNoDefaultLib || node.libReferenceDirectives !== libReferenceDirectives ? update(cloneSourceFileWithChanges(node, statements, isDeclarationFile, referencedFiles, typeReferenceDirectives, hasNoDefaultLib, libReferenceDirectives), node) : node;
            }
            function createBundle(sourceFiles, prepends = emptyArray) {
                const node = createBaseNode(309 /* Bundle */);
                node.prepends = prepends;
                node.sourceFiles = sourceFiles;
                node.syntheticFileReferences = void 0;
                node.syntheticTypeReferences = void 0;
                node.syntheticLibReferences = void 0;
                node.hasNoDefaultLib = void 0;
                return node;
            }
            function updateBundle(node, sourceFiles, prepends = emptyArray) {
                return node.sourceFiles !== sourceFiles || node.prepends !== prepends ? update(createBundle(sourceFiles, prepends), node) : node;
            }
            function createUnparsedSource(prologues, syntheticReferences, texts) {
                const node = createBaseNode(310 /* UnparsedSource */);
                node.prologues = prologues;
                node.syntheticReferences = syntheticReferences;
                node.texts = texts;
                node.fileName = "";
                node.text = "";
                node.referencedFiles = emptyArray;
                node.libReferenceDirectives = emptyArray;
                node.getLineAndCharacterOfPosition = (pos) => getLineAndCharacterOfPosition(node, pos);
                return node;
            }
            function createBaseUnparsedNode(kind, data) {
                const node = createBaseNode(kind);
                node.data = data;
                return node;
            }
            function createUnparsedPrologue(data) {
                return createBaseUnparsedNode(303 /* UnparsedPrologue */, data);
            }
            function createUnparsedPrepend(data, texts) {
                const node = createBaseUnparsedNode(304 /* UnparsedPrepend */, data);
                node.texts = texts;
                return node;
            }
            function createUnparsedTextLike(data, internal) {
                return createBaseUnparsedNode(internal ? 306 /* UnparsedInternalText */ : 305 /* UnparsedText */, data);
            }
            function createUnparsedSyntheticReference(section) {
                const node = createBaseNode(307 /* UnparsedSyntheticReference */);
                node.data = section.data;
                node.section = section;
                return node;
            }
            function createInputFiles2() {
                const node = createBaseNode(311 /* InputFiles */);
                node.javascriptText = "";
                node.declarationText = "";
                return node;
            }
            function createSyntheticExpression(type, isSpread = false, tupleNameSource) {
                const node = createBaseNode(234 /* SyntheticExpression */);
                node.type = type;
                node.isSpread = isSpread;
                node.tupleNameSource = tupleNameSource;
                return node;
            }
            function createSyntaxList3(children) {
                const node = createBaseNode(354 /* SyntaxList */);
                node._children = children;
                return node;
            }
            function createNotEmittedStatement(original) {
                const node = createBaseNode(355 /* NotEmittedStatement */);
                node.original = original;
                setTextRange(node, original);
                return node;
            }
            function createPartiallyEmittedExpression(expression, original) {
                const node = createBaseNode(356 /* PartiallyEmittedExpression */);
                node.expression = expression;
                node.original = original;
                node.transformFlags |= propagateChildFlags(node.expression) | 1 /* ContainsTypeScript */;
                setTextRange(node, original);
                return node;
            }
            function updatePartiallyEmittedExpression(node, expression) {
                return node.expression !== expression ? update(createPartiallyEmittedExpression(expression, node.original), node) : node;
            }
            function flattenCommaElements(node) {
                if (nodeIsSynthesized(node) && !isParseTreeNode(node) && !node.original && !node.emitNode && !node.id) {
                    if (isCommaListExpression(node)) {
                        return node.elements;
                    }
                    if (isBinaryExpression(node) && isCommaToken(node.operatorToken)) {
                        return [node.left, node.right];
                    }
                }
                return node;
            }
            function createCommaListExpression(elements) {
                const node = createBaseNode(357 /* CommaListExpression */);
                node.elements = createNodeArray(sameFlatMap(elements, flattenCommaElements));
                node.transformFlags |= propagateChildrenFlags(node.elements);
                return node;
            }
            function updateCommaListExpression(node, elements) {
                return node.elements !== elements ? update(createCommaListExpression(elements), node) : node;
            }
            function createEndOfDeclarationMarker(original) {
                const node = createBaseNode(359 /* EndOfDeclarationMarker */);
                node.emitNode = {};
                node.original = original;
                return node;
            }
            function createMergeDeclarationMarker(original) {
                const node = createBaseNode(358 /* MergeDeclarationMarker */);
                node.emitNode = {};
                node.original = original;
                return node;
            }
            function createSyntheticReferenceExpression(expression, thisArg) {
                const node = createBaseNode(360 /* SyntheticReferenceExpression */);
                node.expression = expression;
                node.thisArg = thisArg;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.thisArg);
                return node;
            }
            function updateSyntheticReferenceExpression(node, expression, thisArg) {
                return node.expression !== expression || node.thisArg !== thisArg ? update(createSyntheticReferenceExpression(expression, thisArg), node) : node;
            }
            function cloneGeneratedIdentifier(node) {
                const clone2 = createBaseIdentifier(node.escapedText);
                clone2.flags |= node.flags & ~8 /* Synthesized */;
                clone2.transformFlags = node.transformFlags;
                setOriginalNode(clone2, node);
                setIdentifierAutoGenerate(clone2, { ...node.emitNode.autoGenerate });
                return clone2;
            }
            function cloneIdentifier(node) {
                const clone2 = createBaseIdentifier(node.escapedText);
                clone2.flags |= node.flags & ~8 /* Synthesized */;
                clone2.jsDoc = node.jsDoc;
                clone2.flowNode = node.flowNode;
                clone2.symbol = node.symbol;
                clone2.transformFlags = node.transformFlags;
                setOriginalNode(clone2, node);
                const typeArguments = getIdentifierTypeArguments(node);
                if (typeArguments)
                    setIdentifierTypeArguments(clone2, typeArguments);
                return clone2;
            }
            function cloneGeneratedPrivateIdentifier(node) {
                const clone2 = createBasePrivateIdentifier(node.escapedText);
                clone2.flags |= node.flags & ~8 /* Synthesized */;
                clone2.transformFlags = node.transformFlags;
                setOriginalNode(clone2, node);
                setIdentifierAutoGenerate(clone2, { ...node.emitNode.autoGenerate });
                return clone2;
            }
            function clonePrivateIdentifier(node) {
                const clone2 = createBasePrivateIdentifier(node.escapedText);
                clone2.flags |= node.flags & ~8 /* Synthesized */;
                clone2.transformFlags = node.transformFlags;
                setOriginalNode(clone2, node);
                return clone2;
            }
            function cloneNode(node) {
                if (node === void 0) {
                    return node;
                }
                if (isSourceFile(node)) {
                    return cloneSourceFile(node);
                }
                if (isGeneratedIdentifier(node)) {
                    return cloneGeneratedIdentifier(node);
                }
                if (isIdentifier(node)) {
                    return cloneIdentifier(node);
                }
                if (isGeneratedPrivateIdentifier(node)) {
                    return cloneGeneratedPrivateIdentifier(node);
                }
                if (isPrivateIdentifier(node)) {
                    return clonePrivateIdentifier(node);
                }
                const clone2 = !isNodeKind(node.kind) ? baseFactory2.createBaseTokenNode(node.kind) : baseFactory2.createBaseNode(node.kind);
                clone2.flags |= node.flags & ~8 /* Synthesized */;
                clone2.transformFlags = node.transformFlags;
                setOriginalNode(clone2, node);
                for (const key in node) {
                    if (hasProperty(clone2, key) || !hasProperty(node, key)) {
                        continue;
                    }
                    clone2[key] = node[key];
                }
                return clone2;
            }
            function createImmediatelyInvokedFunctionExpression(statements, param, paramValue) {
                return createCallExpression(createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, 
                /*parameters*/
                param ? [param] : [], 
                /*type*/
                void 0, createBlock(statements, 
                /*multiLine*/
                true)), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                paramValue ? [paramValue] : []);
            }
            function createImmediatelyInvokedArrowFunction(statements, param, paramValue) {
                return createCallExpression(createArrowFunction(
                /*modifiers*/
                void 0, 
                /*typeParameters*/
                void 0, 
                /*parameters*/
                param ? [param] : [], 
                /*type*/
                void 0, 
                /*equalsGreaterThanToken*/
                void 0, createBlock(statements, 
                /*multiLine*/
                true)), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                paramValue ? [paramValue] : []);
            }
            function createVoidZero() {
                return createVoidExpression(createNumericLiteral("0"));
            }
            function createExportDefault(expression) {
                return createExportAssignment2(
                /*modifiers*/
                void 0, 
                /*isExportEquals*/
                false, expression);
            }
            function createExternalModuleExport(exportName) {
                return createExportDeclaration(
                /*modifiers*/
                void 0, 
                /*isTypeOnly*/
                false, createNamedExports([
                    createExportSpecifier(
                    /*isTypeOnly*/
                    false, 
                    /*propertyName*/
                    void 0, exportName)
                ]));
            }
            function createTypeCheck(value, tag) {
                return tag === "undefined" ? factory2.createStrictEquality(value, createVoidZero()) : factory2.createStrictEquality(createTypeOfExpression(value), createStringLiteral(tag));
            }
            function createMethodCall(object, methodName, argumentsList) {
                if (isCallChain(object)) {
                    return createCallChain(createPropertyAccessChain(object, 
                    /*questionDotToken*/
                    void 0, methodName), 
                    /*questionDotToken*/
                    void 0, 
                    /*typeArguments*/
                    void 0, argumentsList);
                }
                return createCallExpression(createPropertyAccessExpression(object, methodName), 
                /*typeArguments*/
                void 0, argumentsList);
            }
            function createFunctionBindCall(target, thisArg, argumentsList) {
                return createMethodCall(target, "bind", [thisArg, ...argumentsList]);
            }
            function createFunctionCallCall(target, thisArg, argumentsList) {
                return createMethodCall(target, "call", [thisArg, ...argumentsList]);
            }
            function createFunctionApplyCall(target, thisArg, argumentsExpression) {
                return createMethodCall(target, "apply", [thisArg, argumentsExpression]);
            }
            function createGlobalMethodCall(globalObjectName, methodName, argumentsList) {
                return createMethodCall(createIdentifier(globalObjectName), methodName, argumentsList);
            }
            function createArraySliceCall(array, start) {
                return createMethodCall(array, "slice", start === void 0 ? [] : [asExpression(start)]);
            }
            function createArrayConcatCall(array, argumentsList) {
                return createMethodCall(array, "concat", argumentsList);
            }
            function createObjectDefinePropertyCall(target, propertyName, attributes) {
                return createGlobalMethodCall("Object", "defineProperty", [target, asExpression(propertyName), attributes]);
            }
            function createObjectGetOwnPropertyDescriptorCall(target, propertyName) {
                return createGlobalMethodCall("Object", "getOwnPropertyDescriptor", [target, asExpression(propertyName)]);
            }
            function createReflectGetCall(target, propertyKey, receiver) {
                return createGlobalMethodCall("Reflect", "get", receiver ? [target, propertyKey, receiver] : [target, propertyKey]);
            }
            function createReflectSetCall(target, propertyKey, value, receiver) {
                return createGlobalMethodCall("Reflect", "set", receiver ? [target, propertyKey, value, receiver] : [target, propertyKey, value]);
            }
            function tryAddPropertyAssignment(properties, propertyName, expression) {
                if (expression) {
                    properties.push(createPropertyAssignment(propertyName, expression));
                    return true;
                }
                return false;
            }
            function createPropertyDescriptor(attributes, singleLine) {
                const properties = [];
                tryAddPropertyAssignment(properties, "enumerable", asExpression(attributes.enumerable));
                tryAddPropertyAssignment(properties, "configurable", asExpression(attributes.configurable));
                let isData = tryAddPropertyAssignment(properties, "writable", asExpression(attributes.writable));
                isData = tryAddPropertyAssignment(properties, "value", attributes.value) || isData;
                let isAccessor2 = tryAddPropertyAssignment(properties, "get", attributes.get);
                isAccessor2 = tryAddPropertyAssignment(properties, "set", attributes.set) || isAccessor2;
                Debug.assert(!(isData && isAccessor2), "A PropertyDescriptor may not be both an accessor descriptor and a data descriptor.");
                return createObjectLiteralExpression(properties, !singleLine);
            }
            function updateOuterExpression(outerExpression, expression) {
                switch (outerExpression.kind) {
                    case 214 /* ParenthesizedExpression */:
                        return updateParenthesizedExpression(outerExpression, expression);
                    case 213 /* TypeAssertionExpression */:
                        return updateTypeAssertion(outerExpression, outerExpression.type, expression);
                    case 231 /* AsExpression */:
                        return updateAsExpression(outerExpression, expression, outerExpression.type);
                    case 235 /* SatisfiesExpression */:
                        return updateSatisfiesExpression(outerExpression, expression, outerExpression.type);
                    case 232 /* NonNullExpression */:
                        return updateNonNullExpression(outerExpression, expression);
                    case 356 /* PartiallyEmittedExpression */:
                        return updatePartiallyEmittedExpression(outerExpression, expression);
                }
            }
            function isIgnorableParen(node) {
                return isParenthesizedExpression(node) && nodeIsSynthesized(node) && nodeIsSynthesized(getSourceMapRange(node)) && nodeIsSynthesized(getCommentRange(node)) && !some(getSyntheticLeadingComments(node)) && !some(getSyntheticTrailingComments(node));
            }
            function restoreOuterExpressions(outerExpression, innerExpression, kinds = 15 /* All */) {
                if (outerExpression && isOuterExpression(outerExpression, kinds) && !isIgnorableParen(outerExpression)) {
                    return updateOuterExpression(outerExpression, restoreOuterExpressions(outerExpression.expression, innerExpression));
                }
                return innerExpression;
            }
            function restoreEnclosingLabel(node, outermostLabeledStatement, afterRestoreLabelCallback) {
                if (!outermostLabeledStatement) {
                    return node;
                }
                const updated = updateLabeledStatement(outermostLabeledStatement, outermostLabeledStatement.label, isLabeledStatement(outermostLabeledStatement.statement) ? restoreEnclosingLabel(node, outermostLabeledStatement.statement) : node);
                if (afterRestoreLabelCallback) {
                    afterRestoreLabelCallback(outermostLabeledStatement);
                }
                return updated;
            }
            function shouldBeCapturedInTempVariable(node, cacheIdentifiers) {
                const target = skipParentheses(node);
                switch (target.kind) {
                    case 79 /* Identifier */:
                        return cacheIdentifiers;
                    case 108 /* ThisKeyword */:
                    case 8 /* NumericLiteral */:
                    case 9 /* BigIntLiteral */:
                    case 10 /* StringLiteral */:
                        return false;
                    case 206 /* ArrayLiteralExpression */:
                        const elements = target.elements;
                        if (elements.length === 0) {
                            return false;
                        }
                        return true;
                    case 207 /* ObjectLiteralExpression */:
                        return target.properties.length > 0;
                    default:
                        return true;
                }
            }
            function createCallBinding(expression, recordTempVariable, languageVersion, cacheIdentifiers = false) {
                const callee = skipOuterExpressions(expression, 15 /* All */);
                let thisArg;
                let target;
                if (isSuperProperty(callee)) {
                    thisArg = createThis();
                    target = callee;
                }
                else if (isSuperKeyword(callee)) {
                    thisArg = createThis();
                    target = languageVersion !== void 0 && languageVersion < 2 /* ES2015 */ ? setTextRange(createIdentifier("_super"), callee) : callee;
                }
                else if (getEmitFlags(callee) & 8192 /* HelperName */) {
                    thisArg = createVoidZero();
                    target = parenthesizerRules().parenthesizeLeftSideOfAccess(callee, 
                    /*optionalChain*/
                    false);
                }
                else if (isPropertyAccessExpression(callee)) {
                    if (shouldBeCapturedInTempVariable(callee.expression, cacheIdentifiers)) {
                        thisArg = createTempVariable(recordTempVariable);
                        target = createPropertyAccessExpression(setTextRange(factory2.createAssignment(thisArg, callee.expression), callee.expression), callee.name);
                        setTextRange(target, callee);
                    }
                    else {
                        thisArg = callee.expression;
                        target = callee;
                    }
                }
                else if (isElementAccessExpression(callee)) {
                    if (shouldBeCapturedInTempVariable(callee.expression, cacheIdentifiers)) {
                        thisArg = createTempVariable(recordTempVariable);
                        target = createElementAccessExpression(setTextRange(factory2.createAssignment(thisArg, callee.expression), callee.expression), callee.argumentExpression);
                        setTextRange(target, callee);
                    }
                    else {
                        thisArg = callee.expression;
                        target = callee;
                    }
                }
                else {
                    thisArg = createVoidZero();
                    target = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                    /*optionalChain*/
                    false);
                }
                return { target, thisArg };
            }
            function createAssignmentTargetWrapper(paramName, expression) {
                return createPropertyAccessExpression(
                // Explicit parens required because of v8 regression (https://bugs.chromium.org/p/v8/issues/detail?id=9560)
                createParenthesizedExpression(createObjectLiteralExpression([
                    createSetAccessorDeclaration(
                    /*modifiers*/
                    void 0, "value", [createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, paramName, 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0)], createBlock([
                        createExpressionStatement(expression)
                    ]))
                ])), "value");
            }
            function inlineExpressions(expressions) {
                return expressions.length > 10 ? createCommaListExpression(expressions) : reduceLeft(expressions, factory2.createComma);
            }
            function getName(node, allowComments, allowSourceMaps, emitFlags = 0) {
                const nodeName = getNameOfDeclaration(node);
                if (nodeName && isIdentifier(nodeName) && !isGeneratedIdentifier(nodeName)) {
                    const name = setParent(setTextRange(cloneNode(nodeName), nodeName), nodeName.parent);
                    emitFlags |= getEmitFlags(nodeName);
                    if (!allowSourceMaps)
                        emitFlags |= 96 /* NoSourceMap */;
                    if (!allowComments)
                        emitFlags |= 3072 /* NoComments */;
                    if (emitFlags)
                        setEmitFlags(name, emitFlags);
                    return name;
                }
                return getGeneratedNameForNode(node);
            }
            function getInternalName(node, allowComments, allowSourceMaps) {
                return getName(node, allowComments, allowSourceMaps, 32768 /* LocalName */ | 65536 /* InternalName */);
            }
            function getLocalName(node, allowComments, allowSourceMaps) {
                return getName(node, allowComments, allowSourceMaps, 32768 /* LocalName */);
            }
            function getExportName(node, allowComments, allowSourceMaps) {
                return getName(node, allowComments, allowSourceMaps, 16384 /* ExportName */);
            }
            function getDeclarationName(node, allowComments, allowSourceMaps) {
                return getName(node, allowComments, allowSourceMaps);
            }
            function getNamespaceMemberName(ns, name, allowComments, allowSourceMaps) {
                const qualifiedName = createPropertyAccessExpression(ns, nodeIsSynthesized(name) ? name : cloneNode(name));
                setTextRange(qualifiedName, name);
                let emitFlags = 0;
                if (!allowSourceMaps)
                    emitFlags |= 96 /* NoSourceMap */;
                if (!allowComments)
                    emitFlags |= 3072 /* NoComments */;
                if (emitFlags)
                    setEmitFlags(qualifiedName, emitFlags);
                return qualifiedName;
            }
            function getExternalModuleOrNamespaceExportName(ns, node, allowComments, allowSourceMaps) {
                if (ns && hasSyntacticModifier(node, 1 /* Export */)) {
                    return getNamespaceMemberName(ns, getName(node), allowComments, allowSourceMaps);
                }
                return getExportName(node, allowComments, allowSourceMaps);
            }
            function copyPrologue(source, target, ensureUseStrict2, visitor) {
                const offset = copyStandardPrologue(source, target, 0, ensureUseStrict2);
                return copyCustomPrologue(source, target, offset, visitor);
            }
            function isUseStrictPrologue2(node) {
                return isStringLiteral(node.expression) && node.expression.text === "use strict";
            }
            function createUseStrictPrologue() {
                return startOnNewLine(createExpressionStatement(createStringLiteral("use strict")));
            }
            function copyStandardPrologue(source, target, statementOffset = 0, ensureUseStrict2) {
                Debug.assert(target.length === 0, "Prologue directives should be at the first statement in the target statements array");
                let foundUseStrict = false;
                const numStatements = source.length;
                while (statementOffset < numStatements) {
                    const statement = source[statementOffset];
                    if (isPrologueDirective(statement)) {
                        if (isUseStrictPrologue2(statement)) {
                            foundUseStrict = true;
                        }
                        target.push(statement);
                    }
                    else {
                        break;
                    }
                    statementOffset++;
                }
                if (ensureUseStrict2 && !foundUseStrict) {
                    target.push(createUseStrictPrologue());
                }
                return statementOffset;
            }
            function copyCustomPrologue(source, target, statementOffset, visitor, filter2 = returnTrue) {
                const numStatements = source.length;
                while (statementOffset !== void 0 && statementOffset < numStatements) {
                    const statement = source[statementOffset];
                    if (getEmitFlags(statement) & 2097152 /* CustomPrologue */ && filter2(statement)) {
                        append(target, visitor ? visitNode(statement, visitor, isStatement) : statement);
                    }
                    else {
                        break;
                    }
                    statementOffset++;
                }
                return statementOffset;
            }
            function ensureUseStrict(statements) {
                const foundUseStrict = findUseStrictPrologue(statements);
                if (!foundUseStrict) {
                    return setTextRange(createNodeArray([createUseStrictPrologue(), ...statements]), statements);
                }
                return statements;
            }
            function liftToBlock(nodes) {
                Debug.assert(every(nodes, isStatementOrBlock), "Cannot lift nodes to a Block.");
                return singleOrUndefined(nodes) || createBlock(nodes);
            }
            function findSpanEnd(array, test, start) {
                let i = start;
                while (i < array.length && test(array[i])) {
                    i++;
                }
                return i;
            }
            function mergeLexicalEnvironment(statements, declarations) {
                if (!some(declarations)) {
                    return statements;
                }
                const leftStandardPrologueEnd = findSpanEnd(statements, isPrologueDirective, 0);
                const leftHoistedFunctionsEnd = findSpanEnd(statements, isHoistedFunction, leftStandardPrologueEnd);
                const leftHoistedVariablesEnd = findSpanEnd(statements, isHoistedVariableStatement, leftHoistedFunctionsEnd);
                const rightStandardPrologueEnd = findSpanEnd(declarations, isPrologueDirective, 0);
                const rightHoistedFunctionsEnd = findSpanEnd(declarations, isHoistedFunction, rightStandardPrologueEnd);
                const rightHoistedVariablesEnd = findSpanEnd(declarations, isHoistedVariableStatement, rightHoistedFunctionsEnd);
                const rightCustomPrologueEnd = findSpanEnd(declarations, isCustomPrologue, rightHoistedVariablesEnd);
                Debug.assert(rightCustomPrologueEnd === declarations.length, "Expected declarations to be valid standard or custom prologues");
                const left = isNodeArray(statements) ? statements.slice() : statements;
                if (rightCustomPrologueEnd > rightHoistedVariablesEnd) {
                    left.splice(leftHoistedVariablesEnd, 0, ...declarations.slice(rightHoistedVariablesEnd, rightCustomPrologueEnd));
                }
                if (rightHoistedVariablesEnd > rightHoistedFunctionsEnd) {
                    left.splice(leftHoistedFunctionsEnd, 0, ...declarations.slice(rightHoistedFunctionsEnd, rightHoistedVariablesEnd));
                }
                if (rightHoistedFunctionsEnd > rightStandardPrologueEnd) {
                    left.splice(leftStandardPrologueEnd, 0, ...declarations.slice(rightStandardPrologueEnd, rightHoistedFunctionsEnd));
                }
                if (rightStandardPrologueEnd > 0) {
                    if (leftStandardPrologueEnd === 0) {
                        left.splice(0, 0, ...declarations.slice(0, rightStandardPrologueEnd));
                    }
                    else {
                        const leftPrologues = /* @__PURE__ */ new Map();
                        for (let i = 0; i < leftStandardPrologueEnd; i++) {
                            const leftPrologue = statements[i];
                            leftPrologues.set(leftPrologue.expression.text, true);
                        }
                        for (let i = rightStandardPrologueEnd - 1; i >= 0; i--) {
                            const rightPrologue = declarations[i];
                            if (!leftPrologues.has(rightPrologue.expression.text)) {
                                left.unshift(rightPrologue);
                            }
                        }
                    }
                }
                if (isNodeArray(statements)) {
                    return setTextRange(createNodeArray(left, statements.hasTrailingComma), statements);
                }
                return statements;
            }
            function updateModifiers(node, modifiers) {
                var _a2;
                let modifierArray;
                if (typeof modifiers === "number") {
                    modifierArray = createModifiersFromModifierFlags(modifiers);
                }
                else {
                    modifierArray = modifiers;
                }
                return isTypeParameterDeclaration(node) ? updateTypeParameterDeclaration(node, modifierArray, node.name, node.constraint, node.default) : isParameter(node) ? updateParameterDeclaration(node, modifierArray, node.dotDotDotToken, node.name, node.questionToken, node.type, node.initializer) : isConstructorTypeNode(node) ? updateConstructorTypeNode1(node, modifierArray, node.typeParameters, node.parameters, node.type) : isPropertySignature(node) ? updatePropertySignature(node, modifierArray, node.name, node.questionToken, node.type) : isPropertyDeclaration(node) ? updatePropertyDeclaration2(node, modifierArray, node.name, (_a2 = node.questionToken) != null ? _a2 : node.exclamationToken, node.type, node.initializer) : isMethodSignature(node) ? updateMethodSignature(node, modifierArray, node.name, node.questionToken, node.typeParameters, node.parameters, node.type) : isMethodDeclaration(node) ? updateMethodDeclaration(node, modifierArray, node.asteriskToken, node.name, node.questionToken, node.typeParameters, node.parameters, node.type, node.body) : isConstructorDeclaration(node) ? updateConstructorDeclaration(node, modifierArray, node.parameters, node.body) : isGetAccessorDeclaration(node) ? updateGetAccessorDeclaration(node, modifierArray, node.name, node.parameters, node.type, node.body) : isSetAccessorDeclaration(node) ? updateSetAccessorDeclaration(node, modifierArray, node.name, node.parameters, node.body) : isIndexSignatureDeclaration(node) ? updateIndexSignature(node, modifierArray, node.parameters, node.type) : isFunctionExpression(node) ? updateFunctionExpression(node, modifierArray, node.asteriskToken, node.name, node.typeParameters, node.parameters, node.type, node.body) : isArrowFunction(node) ? updateArrowFunction(node, modifierArray, node.typeParameters, node.parameters, node.type, node.equalsGreaterThanToken, node.body) : isClassExpression(node) ? updateClassExpression(node, modifierArray, node.name, node.typeParameters, node.heritageClauses, node.members) : isVariableStatement(node) ? updateVariableStatement(node, modifierArray, node.declarationList) : isFunctionDeclaration(node) ? updateFunctionDeclaration(node, modifierArray, node.asteriskToken, node.name, node.typeParameters, node.parameters, node.type, node.body) : isClassDeclaration(node) ? updateClassDeclaration(node, modifierArray, node.name, node.typeParameters, node.heritageClauses, node.members) : isInterfaceDeclaration(node) ? updateInterfaceDeclaration(node, modifierArray, node.name, node.typeParameters, node.heritageClauses, node.members) : isTypeAliasDeclaration(node) ? updateTypeAliasDeclaration(node, modifierArray, node.name, node.typeParameters, node.type) : isEnumDeclaration(node) ? updateEnumDeclaration(node, modifierArray, node.name, node.members) : isModuleDeclaration(node) ? updateModuleDeclaration(node, modifierArray, node.name, node.body) : isImportEqualsDeclaration(node) ? updateImportEqualsDeclaration(node, modifierArray, node.isTypeOnly, node.name, node.moduleReference) : isImportDeclaration(node) ? updateImportDeclaration(node, modifierArray, node.importClause, node.moduleSpecifier, node.assertClause) : isExportAssignment(node) ? updateExportAssignment(node, modifierArray, node.expression) : isExportDeclaration(node) ? updateExportDeclaration(node, modifierArray, node.isTypeOnly, node.exportClause, node.moduleSpecifier, node.assertClause) : Debug.assertNever(node);
            }
            function asNodeArray(array) {
                return array ? createNodeArray(array) : void 0;
            }
            function asName(name) {
                return typeof name === "string" ? createIdentifier(name) : name;
            }
            function asExpression(value) {
                return typeof value === "string" ? createStringLiteral(value) : typeof value === "number" ? createNumericLiteral(value) : typeof value === "boolean" ? value ? createTrue() : createFalse() : value;
            }
            function asInitializer(node) {
                return node && parenthesizerRules().parenthesizeExpressionForDisallowedComma(node);
            }
            function asToken(value) {
                return typeof value === "number" ? createToken(value) : value;
            }
            function asEmbeddedStatement(statement) {
                return statement && isNotEmittedStatement(statement) ? setTextRange(setOriginalNode(createEmptyStatement(), statement), statement) : statement;
            }
            function asVariableDeclaration(variableDeclaration) {
                if (typeof variableDeclaration === "string" || variableDeclaration && !isVariableDeclaration(variableDeclaration)) {
                    return createVariableDeclaration(variableDeclaration, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0);
                }
                return variableDeclaration;
            }
        }
        function updateWithoutOriginal(updated, original) {
            if (updated !== original) {
                setTextRange(updated, original);
            }
            return updated;
        }
        function updateWithOriginal(updated, original) {
            if (updated !== original) {
                setOriginalNode(updated, original);
                setTextRange(updated, original);
            }
            return updated;
        }
        function getDefaultTagNameForKind(kind) {
            switch (kind) {
                case 347 /* JSDocTypeTag */:
                    return "type";
                case 345 /* JSDocReturnTag */:
                    return "returns";
                case 346 /* JSDocThisTag */:
                    return "this";
                case 343 /* JSDocEnumTag */:
                    return "enum";
                case 333 /* JSDocAuthorTag */:
                    return "author";
                case 335 /* JSDocClassTag */:
                    return "class";
                case 336 /* JSDocPublicTag */:
                    return "public";
                case 337 /* JSDocPrivateTag */:
                    return "private";
                case 338 /* JSDocProtectedTag */:
                    return "protected";
                case 339 /* JSDocReadonlyTag */:
                    return "readonly";
                case 340 /* JSDocOverrideTag */:
                    return "override";
                case 348 /* JSDocTemplateTag */:
                    return "template";
                case 349 /* JSDocTypedefTag */:
                    return "typedef";
                case 344 /* JSDocParameterTag */:
                    return "param";
                case 351 /* JSDocPropertyTag */:
                    return "prop";
                case 341 /* JSDocCallbackTag */:
                    return "callback";
                case 342 /* JSDocOverloadTag */:
                    return "overload";
                case 331 /* JSDocAugmentsTag */:
                    return "augments";
                case 332 /* JSDocImplementsTag */:
                    return "implements";
                default:
                    return Debug.fail(`Unsupported kind: ${Debug.formatSyntaxKind(kind)}`);
            }
        }
        function getCookedText(kind, rawText) {
            if (!rawTextScanner) {
                rawTextScanner = createScanner(99 /* Latest */, 
                /*skipTrivia*/
                false, 0 /* Standard */);
            }
            switch (kind) {
                case 14 /* NoSubstitutionTemplateLiteral */:
                    rawTextScanner.setText("`" + rawText + "`");
                    break;
                case 15 /* TemplateHead */:
                    rawTextScanner.setText("`" + rawText + "${");
                    break;
                case 16 /* TemplateMiddle */:
                    rawTextScanner.setText("}" + rawText + "${");
                    break;
                case 17 /* TemplateTail */:
                    rawTextScanner.setText("}" + rawText + "`");
                    break;
            }
            let token = rawTextScanner.scan();
            if (token === 19 /* CloseBraceToken */) {
                token = rawTextScanner.reScanTemplateToken(
                /*isTaggedTemplate*/
                false);
            }
            if (rawTextScanner.isUnterminated()) {
                rawTextScanner.setText(void 0);
                return invalidValueSentinel;
            }
            let tokenValue;
            switch (token) {
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 15 /* TemplateHead */:
                case 16 /* TemplateMiddle */:
                case 17 /* TemplateTail */:
                    tokenValue = rawTextScanner.getTokenValue();
                    break;
            }
            if (tokenValue === void 0 || rawTextScanner.scan() !== 1 /* EndOfFileToken */) {
                rawTextScanner.setText(void 0);
                return invalidValueSentinel;
            }
            rawTextScanner.setText(void 0);
            return tokenValue;
        }
        function propagateNameFlags(node) {
            return node && isIdentifier(node) ? propagateIdentifierNameFlags(node) : propagateChildFlags(node);
        }
        function propagateIdentifierNameFlags(node) {
            return propagateChildFlags(node) & ~67108864 /* ContainsPossibleTopLevelAwait */;
        }
        function propagatePropertyNameFlagsOfChild(node, transformFlags) {
            return transformFlags | node.transformFlags & 134234112 /* PropertyNamePropagatingFlags */;
        }
        function propagateChildFlags(child) {
            if (!child)
                return 0 /* None */;
            const childFlags = child.transformFlags & ~getTransformFlagsSubtreeExclusions(child.kind);
            return isNamedDeclaration(child) && isPropertyName(child.name) ? propagatePropertyNameFlagsOfChild(child.name, childFlags) : childFlags;
        }
        function propagateChildrenFlags(children) {
            return children ? children.transformFlags : 0 /* None */;
        }
        function aggregateChildrenFlags(children) {
            let subtreeFlags = 0 /* None */;
            for (const child of children) {
                subtreeFlags |= propagateChildFlags(child);
            }
            children.transformFlags = subtreeFlags;
        }
        function getTransformFlagsSubtreeExclusions(kind) {
            if (kind >= 179 /* FirstTypeNode */ && kind <= 202 /* LastTypeNode */) {
                return -2 /* TypeExcludes */;
            }
            switch (kind) {
                case 210 /* CallExpression */:
                case 211 /* NewExpression */:
                case 206 /* ArrayLiteralExpression */:
                    return -2147450880 /* ArrayLiteralOrCallOrNewExcludes */;
                case 264 /* ModuleDeclaration */:
                    return -1941676032 /* ModuleExcludes */;
                case 166 /* Parameter */:
                    return -2147483648 /* ParameterExcludes */;
                case 216 /* ArrowFunction */:
                    return -2072174592 /* ArrowFunctionExcludes */;
                case 215 /* FunctionExpression */:
                case 259 /* FunctionDeclaration */:
                    return -1937940480 /* FunctionExcludes */;
                case 258 /* VariableDeclarationList */:
                    return -2146893824 /* VariableDeclarationListExcludes */;
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                    return -2147344384 /* ClassExcludes */;
                case 173 /* Constructor */:
                    return -1937948672 /* ConstructorExcludes */;
                case 169 /* PropertyDeclaration */:
                    return -2013249536 /* PropertyExcludes */;
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    return -2005057536 /* MethodOrAccessorExcludes */;
                case 131 /* AnyKeyword */:
                case 148 /* NumberKeyword */:
                case 160 /* BigIntKeyword */:
                case 144 /* NeverKeyword */:
                case 152 /* StringKeyword */:
                case 149 /* ObjectKeyword */:
                case 134 /* BooleanKeyword */:
                case 153 /* SymbolKeyword */:
                case 114 /* VoidKeyword */:
                case 165 /* TypeParameter */:
                case 168 /* PropertySignature */:
                case 170 /* MethodSignature */:
                case 176 /* CallSignature */:
                case 177 /* ConstructSignature */:
                case 178 /* IndexSignature */:
                case 261 /* InterfaceDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                    return -2 /* TypeExcludes */;
                case 207 /* ObjectLiteralExpression */:
                    return -2147278848 /* ObjectLiteralExcludes */;
                case 295 /* CatchClause */:
                    return -2147418112 /* CatchClauseExcludes */;
                case 203 /* ObjectBindingPattern */:
                case 204 /* ArrayBindingPattern */:
                    return -2147450880 /* BindingPatternExcludes */;
                case 213 /* TypeAssertionExpression */:
                case 235 /* SatisfiesExpression */:
                case 231 /* AsExpression */:
                case 356 /* PartiallyEmittedExpression */:
                case 214 /* ParenthesizedExpression */:
                case 106 /* SuperKeyword */:
                    return -2147483648 /* OuterExpressionExcludes */;
                case 208 /* PropertyAccessExpression */:
                case 209 /* ElementAccessExpression */:
                    return -2147483648 /* PropertyAccessExcludes */;
                default:
                    return -2147483648 /* NodeExcludes */;
            }
        }
        function makeSynthetic(node) {
            node.flags |= 8 /* Synthesized */;
            return node;
        }
        function createUnparsedSourceFile(textOrInputFiles, mapPathOrType, mapTextOrStripInternal) {
            let stripInternal;
            let bundleFileInfo;
            let fileName;
            let text;
            let length2;
            let sourceMapPath;
            let sourceMapText;
            let getText;
            let getSourceMapText;
            let oldFileOfCurrentEmit;
            if (!isString(textOrInputFiles)) {
                Debug.assert(mapPathOrType === "js" || mapPathOrType === "dts");
                fileName = (mapPathOrType === "js" ? textOrInputFiles.javascriptPath : textOrInputFiles.declarationPath) || "";
                sourceMapPath = mapPathOrType === "js" ? textOrInputFiles.javascriptMapPath : textOrInputFiles.declarationMapPath;
                getText = () => mapPathOrType === "js" ? textOrInputFiles.javascriptText : textOrInputFiles.declarationText;
                getSourceMapText = () => mapPathOrType === "js" ? textOrInputFiles.javascriptMapText : textOrInputFiles.declarationMapText;
                length2 = () => getText().length;
                if (textOrInputFiles.buildInfo && textOrInputFiles.buildInfo.bundle) {
                    Debug.assert(mapTextOrStripInternal === void 0 || typeof mapTextOrStripInternal === "boolean");
                    stripInternal = mapTextOrStripInternal;
                    bundleFileInfo = mapPathOrType === "js" ? textOrInputFiles.buildInfo.bundle.js : textOrInputFiles.buildInfo.bundle.dts;
                    oldFileOfCurrentEmit = textOrInputFiles.oldFileOfCurrentEmit;
                }
            }
            else {
                fileName = "";
                text = textOrInputFiles;
                length2 = textOrInputFiles.length;
                sourceMapPath = mapPathOrType;
                sourceMapText = mapTextOrStripInternal;
            }
            const node = oldFileOfCurrentEmit ? parseOldFileOfCurrentEmit(Debug.checkDefined(bundleFileInfo)) : parseUnparsedSourceFile(bundleFileInfo, stripInternal, length2);
            node.fileName = fileName;
            node.sourceMapPath = sourceMapPath;
            node.oldFileOfCurrentEmit = oldFileOfCurrentEmit;
            if (getText && getSourceMapText) {
                Object.defineProperty(node, "text", { get: getText });
                Object.defineProperty(node, "sourceMapText", { get: getSourceMapText });
            }
            else {
                Debug.assert(!oldFileOfCurrentEmit);
                node.text = text != null ? text : "";
                node.sourceMapText = sourceMapText;
            }
            return node;
        }
        function parseUnparsedSourceFile(bundleFileInfo, stripInternal, length2) {
            let prologues;
            let helpers;
            let referencedFiles;
            let typeReferenceDirectives;
            let libReferenceDirectives;
            let prependChildren;
            let texts;
            let hasNoDefaultLib;
            for (const section of bundleFileInfo ? bundleFileInfo.sections : emptyArray) {
                switch (section.kind) {
                    case "prologue" /* Prologue */:
                        prologues = append(prologues, setTextRange(factory.createUnparsedPrologue(section.data), section));
                        break;
                    case "emitHelpers" /* EmitHelpers */:
                        helpers = append(helpers, getAllUnscopedEmitHelpers().get(section.data));
                        break;
                    case "no-default-lib" /* NoDefaultLib */:
                        hasNoDefaultLib = true;
                        break;
                    case "reference" /* Reference */:
                        referencedFiles = append(referencedFiles, { pos: -1, end: -1, fileName: section.data });
                        break;
                    case "type" /* Type */:
                        typeReferenceDirectives = append(typeReferenceDirectives, { pos: -1, end: -1, fileName: section.data });
                        break;
                    case "type-import" /* TypeResolutionModeImport */:
                        typeReferenceDirectives = append(typeReferenceDirectives, { pos: -1, end: -1, fileName: section.data, resolutionMode: 99 /* ESNext */ });
                        break;
                    case "type-require" /* TypeResolutionModeRequire */:
                        typeReferenceDirectives = append(typeReferenceDirectives, { pos: -1, end: -1, fileName: section.data, resolutionMode: 1 /* CommonJS */ });
                        break;
                    case "lib" /* Lib */:
                        libReferenceDirectives = append(libReferenceDirectives, { pos: -1, end: -1, fileName: section.data });
                        break;
                    case "prepend" /* Prepend */:
                        let prependTexts;
                        for (const text of section.texts) {
                            if (!stripInternal || text.kind !== "internal" /* Internal */) {
                                prependTexts = append(prependTexts, setTextRange(factory.createUnparsedTextLike(text.data, text.kind === "internal" /* Internal */), text));
                            }
                        }
                        prependChildren = addRange(prependChildren, prependTexts);
                        texts = append(texts, factory.createUnparsedPrepend(section.data, prependTexts != null ? prependTexts : emptyArray));
                        break;
                    case "internal" /* Internal */:
                        if (stripInternal) {
                            if (!texts)
                                texts = [];
                            break;
                        }
                    case "text" /* Text */:
                        texts = append(texts, setTextRange(factory.createUnparsedTextLike(section.data, section.kind === "internal" /* Internal */), section));
                        break;
                    default:
                        Debug.assertNever(section);
                }
            }
            if (!texts) {
                const textNode = factory.createUnparsedTextLike(
                /*data*/
                void 0, 
                /*internal*/
                false);
                setTextRangePosWidth(textNode, 0, typeof length2 === "function" ? length2() : length2);
                texts = [textNode];
            }
            const node = parseNodeFactory.createUnparsedSource(prologues != null ? prologues : emptyArray, 
            /*syntheticReferences*/
            void 0, texts);
            setEachParent(prologues, node);
            setEachParent(texts, node);
            setEachParent(prependChildren, node);
            node.hasNoDefaultLib = hasNoDefaultLib;
            node.helpers = helpers;
            node.referencedFiles = referencedFiles || emptyArray;
            node.typeReferenceDirectives = typeReferenceDirectives;
            node.libReferenceDirectives = libReferenceDirectives || emptyArray;
            return node;
        }
        function parseOldFileOfCurrentEmit(bundleFileInfo) {
            let texts;
            let syntheticReferences;
            for (const section of bundleFileInfo.sections) {
                switch (section.kind) {
                    case "internal" /* Internal */:
                    case "text" /* Text */:
                        texts = append(texts, setTextRange(factory.createUnparsedTextLike(section.data, section.kind === "internal" /* Internal */), section));
                        break;
                    case "no-default-lib" /* NoDefaultLib */:
                    case "reference" /* Reference */:
                    case "type" /* Type */:
                    case "type-import" /* TypeResolutionModeImport */:
                    case "type-require" /* TypeResolutionModeRequire */:
                    case "lib" /* Lib */:
                        syntheticReferences = append(syntheticReferences, setTextRange(factory.createUnparsedSyntheticReference(section), section));
                        break;
                    case "prologue" /* Prologue */:
                    case "emitHelpers" /* EmitHelpers */:
                    case "prepend" /* Prepend */:
                        break;
                    default:
                        Debug.assertNever(section);
                }
            }
            const node = factory.createUnparsedSource(emptyArray, syntheticReferences, texts != null ? texts : emptyArray);
            setEachParent(syntheticReferences, node);
            setEachParent(texts, node);
            node.helpers = map(bundleFileInfo.sources && bundleFileInfo.sources.helpers, (name) => getAllUnscopedEmitHelpers().get(name));
            return node;
        }
        function createInputFiles(javascriptTextOrReadFileText, declarationTextOrJavascriptPath, javascriptMapPath, javascriptMapTextOrDeclarationPath, declarationMapPath, declarationMapTextOrBuildInfoPath) {
            return !isString(javascriptTextOrReadFileText) ? createInputFilesWithFilePaths(javascriptTextOrReadFileText, declarationTextOrJavascriptPath, javascriptMapPath, javascriptMapTextOrDeclarationPath, declarationMapPath, declarationMapTextOrBuildInfoPath) : createInputFilesWithFileTexts(
            /*javascriptPath*/
            void 0, javascriptTextOrReadFileText, javascriptMapPath, javascriptMapTextOrDeclarationPath, 
            /*declarationPath*/
            void 0, declarationTextOrJavascriptPath, declarationMapPath, declarationMapTextOrBuildInfoPath);
        }
        function createInputFilesWithFilePaths(readFileText, javascriptPath, javascriptMapPath, declarationPath, declarationMapPath, buildInfoPath, host, options) {
            const node = parseNodeFactory.createInputFiles();
            node.javascriptPath = javascriptPath;
            node.javascriptMapPath = javascriptMapPath;
            node.declarationPath = declarationPath;
            node.declarationMapPath = declarationMapPath;
            node.buildInfoPath = buildInfoPath;
            const cache = /* @__PURE__ */ new Map();
            const textGetter = (path) => {
                if (path === void 0)
                    return void 0;
                let value = cache.get(path);
                if (value === void 0) {
                    value = readFileText(path);
                    cache.set(path, value !== void 0 ? value : false);
                }
                return value !== false ? value : void 0;
            };
            const definedTextGetter = (path) => {
                const result = textGetter(path);
                return result !== void 0 ? result : `/* Input file ${path} was missing */\r
`;
            };
            let buildInfo;
            const getAndCacheBuildInfo = () => {
                var _a2, _b;
                if (buildInfo === void 0 && buildInfoPath) {
                    if (host == null ? void 0 : host.getBuildInfo) {
                        buildInfo = (_a2 = host.getBuildInfo(buildInfoPath, options.configFilePath)) != null ? _a2 : false;
                    }
                    else {
                        const result = textGetter(buildInfoPath);
                        buildInfo = result !== void 0 ? (_b = getBuildInfo(buildInfoPath, result)) != null ? _b : false : false;
                    }
                }
                return buildInfo || void 0;
            };
            Object.defineProperties(node, {
                javascriptText: { get: () => definedTextGetter(javascriptPath) },
                javascriptMapText: { get: () => textGetter(javascriptMapPath) },
                // TODO:: if there is inline sourceMap in jsFile, use that
                declarationText: { get: () => definedTextGetter(Debug.checkDefined(declarationPath)) },
                declarationMapText: { get: () => textGetter(declarationMapPath) },
                // TODO:: if there is inline sourceMap in dtsFile, use that
                buildInfo: { get: getAndCacheBuildInfo }
            });
            return node;
        }
        function createInputFilesWithFileTexts(javascriptPath, javascriptText, javascriptMapPath, javascriptMapText, declarationPath, declarationText, declarationMapPath, declarationMapText, buildInfoPath, buildInfo, oldFileOfCurrentEmit) {
            const node = parseNodeFactory.createInputFiles();
            node.javascriptPath = javascriptPath;
            node.javascriptText = javascriptText;
            node.javascriptMapPath = javascriptMapPath;
            node.javascriptMapText = javascriptMapText;
            node.declarationPath = declarationPath;
            node.declarationText = declarationText;
            node.declarationMapPath = declarationMapPath;
            node.declarationMapText = declarationMapText;
            node.buildInfoPath = buildInfoPath;
            node.buildInfo = buildInfo;
            node.oldFileOfCurrentEmit = oldFileOfCurrentEmit;
            return node;
        }
        function createSourceMapSource(fileName, text, skipTrivia2) {
            return new (SourceMapSource2 || (SourceMapSource2 = objectAllocator.getSourceMapSourceConstructor()))(fileName, text, skipTrivia2);
        }
        function setOriginalNode(node, original) {
            node.original = original;
            if (original) {
                const emitNode = original.emitNode;
                if (emitNode)
                    node.emitNode = mergeEmitNode(emitNode, node.emitNode);
            }
            return node;
        }
        function mergeEmitNode(sourceEmitNode, destEmitNode) {
            const { flags, internalFlags, leadingComments, trailingComments, commentRange, sourceMapRange, tokenSourceMapRanges, constantValue, helpers, startsOnNewLine, snippetElement } = sourceEmitNode;
            if (!destEmitNode)
                destEmitNode = {};
            if (leadingComments)
                destEmitNode.leadingComments = addRange(leadingComments.slice(), destEmitNode.leadingComments);
            if (trailingComments)
                destEmitNode.trailingComments = addRange(trailingComments.slice(), destEmitNode.trailingComments);
            if (flags)
                destEmitNode.flags = flags;
            if (internalFlags)
                destEmitNode.internalFlags = internalFlags & ~8 /* Immutable */;
            if (commentRange)
                destEmitNode.commentRange = commentRange;
            if (sourceMapRange)
                destEmitNode.sourceMapRange = sourceMapRange;
            if (tokenSourceMapRanges)
                destEmitNode.tokenSourceMapRanges = mergeTokenSourceMapRanges(tokenSourceMapRanges, destEmitNode.tokenSourceMapRanges);
            if (constantValue !== void 0)
                destEmitNode.constantValue = constantValue;
            if (helpers) {
                for (const helper of helpers) {
                    destEmitNode.helpers = appendIfUnique(destEmitNode.helpers, helper);
                }
            }
            if (startsOnNewLine !== void 0)
                destEmitNode.startsOnNewLine = startsOnNewLine;
            if (snippetElement !== void 0)
                destEmitNode.snippetElement = snippetElement;
            return destEmitNode;
        }
        function mergeTokenSourceMapRanges(sourceRanges, destRanges) {
            if (!destRanges)
                destRanges = [];
            for (const key in sourceRanges) {
                destRanges[key] = sourceRanges[key];
            }
            return destRanges;
        }
        var nextAutoGenerateId, NodeFactoryFlags, nodeFactoryPatchers, rawTextScanner, invalidValueSentinel, baseFactory, syntheticFactory, factory, SourceMapSource2;
        var init_nodeFactory = __esm({
            "src/compiler/factory/nodeFactory.ts"() {
                "use strict";
                init_ts2();
                nextAutoGenerateId = 0;
                NodeFactoryFlags = /* @__PURE__ */ ((NodeFactoryFlags2) => {
                    NodeFactoryFlags2[NodeFactoryFlags2["None"] = 0] = "None";
                    NodeFactoryFlags2[NodeFactoryFlags2["NoParenthesizerRules"] = 1] = "NoParenthesizerRules";
                    NodeFactoryFlags2[NodeFactoryFlags2["NoNodeConverters"] = 2] = "NoNodeConverters";
                    NodeFactoryFlags2[NodeFactoryFlags2["NoIndentationOnFreshPropertyAccess"] = 4] = "NoIndentationOnFreshPropertyAccess";
                    NodeFactoryFlags2[NodeFactoryFlags2["NoOriginalNode"] = 8] = "NoOriginalNode";
                    return NodeFactoryFlags2;
                })(NodeFactoryFlags || {});
                nodeFactoryPatchers = [];
                invalidValueSentinel = {};
                baseFactory = createBaseNodeFactory();
                syntheticFactory = {
                    createBaseSourceFileNode: (kind) => makeSynthetic(baseFactory.createBaseSourceFileNode(kind)),
                    createBaseIdentifierNode: (kind) => makeSynthetic(baseFactory.createBaseIdentifierNode(kind)),
                    createBasePrivateIdentifierNode: (kind) => makeSynthetic(baseFactory.createBasePrivateIdentifierNode(kind)),
                    createBaseTokenNode: (kind) => makeSynthetic(baseFactory.createBaseTokenNode(kind)),
                    createBaseNode: (kind) => makeSynthetic(baseFactory.createBaseNode(kind))
                };
                factory = createNodeFactory(4 /* NoIndentationOnFreshPropertyAccess */, syntheticFactory);
            }
        });
        // src/compiler/factory/emitNode.ts
        function getOrCreateEmitNode(node) {
            var _a2;
            if (!node.emitNode) {
                if (isParseTreeNode(node)) {
                    if (node.kind === 308 /* SourceFile */) {
                        return node.emitNode = { annotatedNodes: [node] };
                    }
                    const sourceFile = (_a2 = getSourceFileOfNode(getParseTreeNode(getSourceFileOfNode(node)))) != null ? _a2 : Debug.fail("Could not determine parsed source file.");
                    getOrCreateEmitNode(sourceFile).annotatedNodes.push(node);
                }
                node.emitNode = {};
            }
            else {
                Debug.assert(!(node.emitNode.internalFlags & 8 /* Immutable */), "Invalid attempt to mutate an immutable node.");
            }
            return node.emitNode;
        }
        function disposeEmitNodes(sourceFile) {
            var _a2, _b;
            const annotatedNodes = (_b = (_a2 = getSourceFileOfNode(getParseTreeNode(sourceFile))) == null ? void 0 : _a2.emitNode) == null ? void 0 : _b.annotatedNodes;
            if (annotatedNodes) {
                for (const node of annotatedNodes) {
                    node.emitNode = void 0;
                }
            }
        }
        function removeAllComments(node) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.flags |= 3072 /* NoComments */;
            emitNode.leadingComments = void 0;
            emitNode.trailingComments = void 0;
            return node;
        }
        function setEmitFlags(node, emitFlags) {
            getOrCreateEmitNode(node).flags = emitFlags;
            return node;
        }
        function addEmitFlags(node, emitFlags) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.flags = emitNode.flags | emitFlags;
            return node;
        }
        function setInternalEmitFlags(node, emitFlags) {
            getOrCreateEmitNode(node).internalFlags = emitFlags;
            return node;
        }
        function addInternalEmitFlags(node, emitFlags) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.internalFlags = emitNode.internalFlags | emitFlags;
            return node;
        }
        function getSourceMapRange(node) {
            var _a2, _b;
            return (_b = (_a2 = node.emitNode) == null ? void 0 : _a2.sourceMapRange) != null ? _b : node;
        }
        function setSourceMapRange(node, range) {
            getOrCreateEmitNode(node).sourceMapRange = range;
            return node;
        }
        function getTokenSourceMapRange(node, token) {
            var _a2, _b;
            return (_b = (_a2 = node.emitNode) == null ? void 0 : _a2.tokenSourceMapRanges) == null ? void 0 : _b[token];
        }
        function setTokenSourceMapRange(node, token, range) {
            var _a2;
            const emitNode = getOrCreateEmitNode(node);
            const tokenSourceMapRanges = (_a2 = emitNode.tokenSourceMapRanges) != null ? _a2 : emitNode.tokenSourceMapRanges = [];
            tokenSourceMapRanges[token] = range;
            return node;
        }
        function getStartsOnNewLine(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.startsOnNewLine;
        }
        function setStartsOnNewLine(node, newLine) {
            getOrCreateEmitNode(node).startsOnNewLine = newLine;
            return node;
        }
        function getCommentRange(node) {
            var _a2, _b;
            return (_b = (_a2 = node.emitNode) == null ? void 0 : _a2.commentRange) != null ? _b : node;
        }
        function setCommentRange(node, range) {
            getOrCreateEmitNode(node).commentRange = range;
            return node;
        }
        function getSyntheticLeadingComments(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.leadingComments;
        }
        function setSyntheticLeadingComments(node, comments) {
            getOrCreateEmitNode(node).leadingComments = comments;
            return node;
        }
        function addSyntheticLeadingComment(node, kind, text, hasTrailingNewLine) {
            return setSyntheticLeadingComments(node, append(getSyntheticLeadingComments(node), { kind, pos: -1, end: -1, hasTrailingNewLine, text }));
        }
        function getSyntheticTrailingComments(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.trailingComments;
        }
        function setSyntheticTrailingComments(node, comments) {
            getOrCreateEmitNode(node).trailingComments = comments;
            return node;
        }
        function addSyntheticTrailingComment(node, kind, text, hasTrailingNewLine) {
            return setSyntheticTrailingComments(node, append(getSyntheticTrailingComments(node), { kind, pos: -1, end: -1, hasTrailingNewLine, text }));
        }
        function moveSyntheticComments(node, original) {
            setSyntheticLeadingComments(node, getSyntheticLeadingComments(original));
            setSyntheticTrailingComments(node, getSyntheticTrailingComments(original));
            const emit = getOrCreateEmitNode(original);
            emit.leadingComments = void 0;
            emit.trailingComments = void 0;
            return node;
        }
        function getConstantValue(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.constantValue;
        }
        function setConstantValue(node, value) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.constantValue = value;
            return node;
        }
        function addEmitHelper(node, helper) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.helpers = append(emitNode.helpers, helper);
            return node;
        }
        function addEmitHelpers(node, helpers) {
            if (some(helpers)) {
                const emitNode = getOrCreateEmitNode(node);
                for (const helper of helpers) {
                    emitNode.helpers = appendIfUnique(emitNode.helpers, helper);
                }
            }
            return node;
        }
        function removeEmitHelper(node, helper) {
            var _a2;
            const helpers = (_a2 = node.emitNode) == null ? void 0 : _a2.helpers;
            if (helpers) {
                return orderedRemoveItem(helpers, helper);
            }
            return false;
        }
        function getEmitHelpers(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.helpers;
        }
        function moveEmitHelpers(source, target, predicate) {
            const sourceEmitNode = source.emitNode;
            const sourceEmitHelpers = sourceEmitNode && sourceEmitNode.helpers;
            if (!some(sourceEmitHelpers))
                return;
            const targetEmitNode = getOrCreateEmitNode(target);
            let helpersRemoved = 0;
            for (let i = 0; i < sourceEmitHelpers.length; i++) {
                const helper = sourceEmitHelpers[i];
                if (predicate(helper)) {
                    helpersRemoved++;
                    targetEmitNode.helpers = appendIfUnique(targetEmitNode.helpers, helper);
                }
                else if (helpersRemoved > 0) {
                    sourceEmitHelpers[i - helpersRemoved] = helper;
                }
            }
            if (helpersRemoved > 0) {
                sourceEmitHelpers.length -= helpersRemoved;
            }
        }
        function getSnippetElement(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.snippetElement;
        }
        function setSnippetElement(node, snippet) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.snippetElement = snippet;
            return node;
        }
        function ignoreSourceNewlines(node) {
            getOrCreateEmitNode(node).internalFlags |= 4 /* IgnoreSourceNewlines */;
            return node;
        }
        function setTypeNode(node, type) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.typeNode = type;
            return node;
        }
        function getTypeNode(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.typeNode;
        }
        function setIdentifierTypeArguments(node, typeArguments) {
            getOrCreateEmitNode(node).identifierTypeArguments = typeArguments;
            return node;
        }
        function getIdentifierTypeArguments(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.identifierTypeArguments;
        }
        function setIdentifierAutoGenerate(node, autoGenerate) {
            getOrCreateEmitNode(node).autoGenerate = autoGenerate;
            return node;
        }
        function getIdentifierAutoGenerate(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.autoGenerate;
        }
        function setIdentifierGeneratedImportReference(node, value) {
            getOrCreateEmitNode(node).generatedImportReference = value;
            return node;
        }
        function getIdentifierGeneratedImportReference(node) {
            var _a2;
            return (_a2 = node.emitNode) == null ? void 0 : _a2.generatedImportReference;
        }
        var init_emitNode = __esm({
            "src/compiler/factory/emitNode.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/factory/emitHelpers.ts
        function createEmitHelperFactory(context) {
            const factory2 = context.factory;
            const immutableTrue = memoize(() => setInternalEmitFlags(factory2.createTrue(), 8 /* Immutable */));
            const immutableFalse = memoize(() => setInternalEmitFlags(factory2.createFalse(), 8 /* Immutable */));
            return {
                getUnscopedHelperName,
                // TypeScript Helpers
                createDecorateHelper,
                createMetadataHelper,
                createParamHelper,
                // ES Decorators Helpers
                createESDecorateHelper,
                createRunInitializersHelper,
                // ES2018 Helpers
                createAssignHelper,
                createAwaitHelper,
                createAsyncGeneratorHelper,
                createAsyncDelegatorHelper,
                createAsyncValuesHelper,
                // ES2018 Destructuring Helpers
                createRestHelper,
                // ES2017 Helpers
                createAwaiterHelper,
                // ES2015 Helpers
                createExtendsHelper,
                createTemplateObjectHelper,
                createSpreadArrayHelper,
                createPropKeyHelper,
                createSetFunctionNameHelper,
                // ES2015 Destructuring Helpers
                createValuesHelper,
                createReadHelper,
                // ES2015 Generator Helpers
                createGeneratorHelper,
                // ES Module Helpers
                createCreateBindingHelper,
                createImportStarHelper,
                createImportStarCallbackHelper,
                createImportDefaultHelper,
                createExportStarHelper,
                // Class Fields Helpers
                createClassPrivateFieldGetHelper,
                createClassPrivateFieldSetHelper,
                createClassPrivateFieldInHelper
            };
            function getUnscopedHelperName(name) {
                return setEmitFlags(factory2.createIdentifier(name), 8192 /* HelperName */ | 4 /* AdviseOnEmitNode */);
            }
            function createDecorateHelper(decoratorExpressions, target, memberName, descriptor) {
                context.requestEmitHelper(decorateHelper);
                const argumentsArray = [];
                argumentsArray.push(factory2.createArrayLiteralExpression(decoratorExpressions, 
                /*multiLine*/
                true));
                argumentsArray.push(target);
                if (memberName) {
                    argumentsArray.push(memberName);
                    if (descriptor) {
                        argumentsArray.push(descriptor);
                    }
                }
                return factory2.createCallExpression(getUnscopedHelperName("__decorate"), 
                /*typeArguments*/
                void 0, argumentsArray);
            }
            function createMetadataHelper(metadataKey, metadataValue) {
                context.requestEmitHelper(metadataHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__metadata"), 
                /*typeArguments*/
                void 0, [
                    factory2.createStringLiteral(metadataKey),
                    metadataValue
                ]);
            }
            function createParamHelper(expression, parameterOffset, location) {
                context.requestEmitHelper(paramHelper);
                return setTextRange(factory2.createCallExpression(getUnscopedHelperName("__param"), 
                /*typeArguments*/
                void 0, [
                    factory2.createNumericLiteral(parameterOffset + ""),
                    expression
                ]), location);
            }
            function createESDecorateClassContextObject(contextIn) {
                return factory2.createObjectLiteralExpression([
                    factory2.createPropertyAssignment(factory2.createIdentifier("kind"), factory2.createStringLiteral("class")),
                    factory2.createPropertyAssignment(factory2.createIdentifier("name"), contextIn.name)
                ]);
            }
            function createESDecorateClassElementAccessGetMethod(elementName) {
                const accessor = elementName.computed ? factory2.createElementAccessExpression(factory2.createIdentifier("obj"), elementName.name) : factory2.createPropertyAccessExpression(factory2.createIdentifier("obj"), elementName.name);
                return factory2.createPropertyAssignment("get", factory2.createArrowFunction(
                /*modifiers*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.createIdentifier("obj"))], 
                /*type*/
                void 0, 
                /*equalsGreaterThanToken*/
                void 0, accessor));
            }
            function createESDecorateClassElementAccessSetMethod(elementName) {
                const accessor = elementName.computed ? factory2.createElementAccessExpression(factory2.createIdentifier("obj"), elementName.name) : factory2.createPropertyAccessExpression(factory2.createIdentifier("obj"), elementName.name);
                return factory2.createPropertyAssignment("set", factory2.createArrowFunction(
                /*modifiers*/
                void 0, 
                /*typeParameters*/
                void 0, [
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.createIdentifier("obj")),
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.createIdentifier("value"))
                ], 
                /*type*/
                void 0, 
                /*equalsGreaterThanToken*/
                void 0, factory2.createBlock([
                    factory2.createExpressionStatement(factory2.createAssignment(accessor, factory2.createIdentifier("value")))
                ])));
            }
            function createESDecorateClassElementAccessHasMethod(elementName) {
                const propertyName = elementName.computed ? elementName.name : isIdentifier(elementName.name) ? factory2.createStringLiteralFromNode(elementName.name) : elementName.name;
                return factory2.createPropertyAssignment("has", factory2.createArrowFunction(
                /*modifiers*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.createIdentifier("obj"))], 
                /*type*/
                void 0, 
                /*equalsGreaterThanToken*/
                void 0, factory2.createBinaryExpression(propertyName, 101 /* InKeyword */, factory2.createIdentifier("obj"))));
            }
            function createESDecorateClassElementAccessObject(name, access) {
                const properties = [];
                properties.push(createESDecorateClassElementAccessHasMethod(name));
                if (access.get)
                    properties.push(createESDecorateClassElementAccessGetMethod(name));
                if (access.set)
                    properties.push(createESDecorateClassElementAccessSetMethod(name));
                return factory2.createObjectLiteralExpression(properties);
            }
            function createESDecorateClassElementContextObject(contextIn) {
                return factory2.createObjectLiteralExpression([
                    factory2.createPropertyAssignment(factory2.createIdentifier("kind"), factory2.createStringLiteral(contextIn.kind)),
                    factory2.createPropertyAssignment(factory2.createIdentifier("name"), contextIn.name.computed ? contextIn.name.name : factory2.createStringLiteralFromNode(contextIn.name.name)),
                    factory2.createPropertyAssignment(factory2.createIdentifier("static"), contextIn.static ? factory2.createTrue() : factory2.createFalse()),
                    factory2.createPropertyAssignment(factory2.createIdentifier("private"), contextIn.private ? factory2.createTrue() : factory2.createFalse()),
                    factory2.createPropertyAssignment(factory2.createIdentifier("access"), createESDecorateClassElementAccessObject(contextIn.name, contextIn.access))
                ]);
            }
            function createESDecorateContextObject(contextIn) {
                return contextIn.kind === "class" ? createESDecorateClassContextObject(contextIn) : createESDecorateClassElementContextObject(contextIn);
            }
            function createESDecorateHelper(ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
                context.requestEmitHelper(esDecorateHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__esDecorate"), 
                /*typeArguments*/
                void 0, [
                    ctor != null ? ctor : factory2.createNull(),
                    descriptorIn != null ? descriptorIn : factory2.createNull(),
                    decorators,
                    createESDecorateContextObject(contextIn),
                    initializers,
                    extraInitializers
                ]);
            }
            function createRunInitializersHelper(thisArg, initializers, value) {
                context.requestEmitHelper(runInitializersHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__runInitializers"), 
                /*typeArguments*/
                void 0, value ? [thisArg, initializers, value] : [thisArg, initializers]);
            }
            function createAssignHelper(attributesSegments) {
                if (getEmitScriptTarget(context.getCompilerOptions()) >= 2 /* ES2015 */) {
                    return factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "assign"), 
                    /*typeArguments*/
                    void 0, attributesSegments);
                }
                context.requestEmitHelper(assignHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__assign"), 
                /*typeArguments*/
                void 0, attributesSegments);
            }
            function createAwaitHelper(expression) {
                context.requestEmitHelper(awaitHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__await"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createAsyncGeneratorHelper(generatorFunc, hasLexicalThis) {
                context.requestEmitHelper(awaitHelper);
                context.requestEmitHelper(asyncGeneratorHelper);
                (generatorFunc.emitNode || (generatorFunc.emitNode = {})).flags |= 524288 /* AsyncFunctionBody */ | 1048576 /* ReuseTempVariableScope */;
                return factory2.createCallExpression(getUnscopedHelperName("__asyncGenerator"), 
                /*typeArguments*/
                void 0, [
                    hasLexicalThis ? factory2.createThis() : factory2.createVoidZero(),
                    factory2.createIdentifier("arguments"),
                    generatorFunc
                ]);
            }
            function createAsyncDelegatorHelper(expression) {
                context.requestEmitHelper(awaitHelper);
                context.requestEmitHelper(asyncDelegator);
                return factory2.createCallExpression(getUnscopedHelperName("__asyncDelegator"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createAsyncValuesHelper(expression) {
                context.requestEmitHelper(asyncValues);
                return factory2.createCallExpression(getUnscopedHelperName("__asyncValues"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createRestHelper(value, elements, computedTempVariables, location) {
                context.requestEmitHelper(restHelper);
                const propertyNames = [];
                let computedTempVariableOffset = 0;
                for (let i = 0; i < elements.length - 1; i++) {
                    const propertyName = getPropertyNameOfBindingOrAssignmentElement(elements[i]);
                    if (propertyName) {
                        if (isComputedPropertyName(propertyName)) {
                            Debug.assertIsDefined(computedTempVariables, "Encountered computed property name but 'computedTempVariables' argument was not provided.");
                            const temp = computedTempVariables[computedTempVariableOffset];
                            computedTempVariableOffset++;
                            propertyNames.push(factory2.createConditionalExpression(factory2.createTypeCheck(temp, "symbol"), 
                            /*questionToken*/
                            void 0, temp, 
                            /*colonToken*/
                            void 0, factory2.createAdd(temp, factory2.createStringLiteral(""))));
                        }
                        else {
                            propertyNames.push(factory2.createStringLiteralFromNode(propertyName));
                        }
                    }
                }
                return factory2.createCallExpression(getUnscopedHelperName("__rest"), 
                /*typeArguments*/
                void 0, [
                    value,
                    setTextRange(factory2.createArrayLiteralExpression(propertyNames), location)
                ]);
            }
            function createAwaiterHelper(hasLexicalThis, hasLexicalArguments, promiseConstructor, body) {
                context.requestEmitHelper(awaiterHelper);
                const generatorFunc = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, factory2.createToken(41 /* AsteriskToken */), 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, 
                /*parameters*/
                [], 
                /*type*/
                void 0, body);
                (generatorFunc.emitNode || (generatorFunc.emitNode = {})).flags |= 524288 /* AsyncFunctionBody */ | 1048576 /* ReuseTempVariableScope */;
                return factory2.createCallExpression(getUnscopedHelperName("__awaiter"), 
                /*typeArguments*/
                void 0, [
                    hasLexicalThis ? factory2.createThis() : factory2.createVoidZero(),
                    hasLexicalArguments ? factory2.createIdentifier("arguments") : factory2.createVoidZero(),
                    promiseConstructor ? createExpressionFromEntityName(factory2, promiseConstructor) : factory2.createVoidZero(),
                    generatorFunc
                ]);
            }
            function createExtendsHelper(name) {
                context.requestEmitHelper(extendsHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__extends"), 
                /*typeArguments*/
                void 0, [name, factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */)]);
            }
            function createTemplateObjectHelper(cooked, raw) {
                context.requestEmitHelper(templateObjectHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__makeTemplateObject"), 
                /*typeArguments*/
                void 0, [cooked, raw]);
            }
            function createSpreadArrayHelper(to, from, packFrom) {
                context.requestEmitHelper(spreadArrayHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__spreadArray"), 
                /*typeArguments*/
                void 0, [to, from, packFrom ? immutableTrue() : immutableFalse()]);
            }
            function createPropKeyHelper(expr) {
                context.requestEmitHelper(propKeyHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__propKey"), 
                /*typeArguments*/
                void 0, [expr]);
            }
            function createSetFunctionNameHelper(f, name, prefix) {
                context.requestEmitHelper(setFunctionNameHelper);
                return context.factory.createCallExpression(getUnscopedHelperName("__setFunctionName"), 
                /*typeArguments*/
                void 0, prefix ? [f, name, context.factory.createStringLiteral(prefix)] : [f, name]);
            }
            function createValuesHelper(expression) {
                context.requestEmitHelper(valuesHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__values"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createReadHelper(iteratorRecord, count) {
                context.requestEmitHelper(readHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__read"), 
                /*typeArguments*/
                void 0, count !== void 0 ? [iteratorRecord, factory2.createNumericLiteral(count + "")] : [iteratorRecord]);
            }
            function createGeneratorHelper(body) {
                context.requestEmitHelper(generatorHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__generator"), 
                /*typeArguments*/
                void 0, [factory2.createThis(), body]);
            }
            function createCreateBindingHelper(module2, inputName, outputName) {
                context.requestEmitHelper(createBindingHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__createBinding"), 
                /*typeArguments*/
                void 0, [factory2.createIdentifier("exports"), module2, inputName, ...outputName ? [outputName] : []]);
            }
            function createImportStarHelper(expression) {
                context.requestEmitHelper(importStarHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__importStar"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createImportStarCallbackHelper() {
                context.requestEmitHelper(importStarHelper);
                return getUnscopedHelperName("__importStar");
            }
            function createImportDefaultHelper(expression) {
                context.requestEmitHelper(importDefaultHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__importDefault"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createExportStarHelper(moduleExpression, exportsExpression = factory2.createIdentifier("exports")) {
                context.requestEmitHelper(exportStarHelper);
                context.requestEmitHelper(createBindingHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__exportStar"), 
                /*typeArguments*/
                void 0, [moduleExpression, exportsExpression]);
            }
            function createClassPrivateFieldGetHelper(receiver, state, kind, f) {
                context.requestEmitHelper(classPrivateFieldGetHelper);
                let args;
                if (!f) {
                    args = [receiver, state, factory2.createStringLiteral(kind)];
                }
                else {
                    args = [receiver, state, factory2.createStringLiteral(kind), f];
                }
                return factory2.createCallExpression(getUnscopedHelperName("__classPrivateFieldGet"), 
                /*typeArguments*/
                void 0, args);
            }
            function createClassPrivateFieldSetHelper(receiver, state, value, kind, f) {
                context.requestEmitHelper(classPrivateFieldSetHelper);
                let args;
                if (!f) {
                    args = [receiver, state, value, factory2.createStringLiteral(kind)];
                }
                else {
                    args = [receiver, state, value, factory2.createStringLiteral(kind), f];
                }
                return factory2.createCallExpression(getUnscopedHelperName("__classPrivateFieldSet"), 
                /*typeArguments*/
                void 0, args);
            }
            function createClassPrivateFieldInHelper(state, receiver) {
                context.requestEmitHelper(classPrivateFieldInHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__classPrivateFieldIn"), 
                /* typeArguments*/
                void 0, [state, receiver]);
            }
        }
        function compareEmitHelpers(x, y) {
            if (x === y)
                return 0 /* EqualTo */;
            if (x.priority === y.priority)
                return 0 /* EqualTo */;
            if (x.priority === void 0)
                return 1 /* GreaterThan */;
            if (y.priority === void 0)
                return -1 /* LessThan */;
            return compareValues(x.priority, y.priority);
        }
        function helperString(input, ...args) {
            return (uniqueName) => {
                let result = "";
                for (let i = 0; i < args.length; i++) {
                    result += input[i];
                    result += uniqueName(args[i]);
                }
                result += input[input.length - 1];
                return result;
            };
        }
        function getAllUnscopedEmitHelpers() {
            return allUnscopedEmitHelpers || (allUnscopedEmitHelpers = arrayToMap([
                decorateHelper,
                metadataHelper,
                paramHelper,
                esDecorateHelper,
                runInitializersHelper,
                assignHelper,
                awaitHelper,
                asyncGeneratorHelper,
                asyncDelegator,
                asyncValues,
                restHelper,
                awaiterHelper,
                extendsHelper,
                templateObjectHelper,
                spreadArrayHelper,
                valuesHelper,
                readHelper,
                propKeyHelper,
                setFunctionNameHelper,
                generatorHelper,
                importStarHelper,
                importDefaultHelper,
                exportStarHelper,
                classPrivateFieldGetHelper,
                classPrivateFieldSetHelper,
                classPrivateFieldInHelper,
                createBindingHelper,
                setModuleDefaultHelper
            ], (helper) => helper.name));
        }
        function isCallToHelper(firstSegment, helperName) {
            return isCallExpression(firstSegment) && isIdentifier(firstSegment.expression) && (getEmitFlags(firstSegment.expression) & 8192 /* HelperName */) !== 0 && firstSegment.expression.escapedText === helperName;
        }
        var PrivateIdentifierKind, decorateHelper, metadataHelper, paramHelper, esDecorateHelper, runInitializersHelper, assignHelper, awaitHelper, asyncGeneratorHelper, asyncDelegator, asyncValues, restHelper, awaiterHelper, extendsHelper, templateObjectHelper, readHelper, spreadArrayHelper, propKeyHelper, setFunctionNameHelper, valuesHelper, generatorHelper, createBindingHelper, setModuleDefaultHelper, importStarHelper, importDefaultHelper, exportStarHelper, classPrivateFieldGetHelper, classPrivateFieldSetHelper, classPrivateFieldInHelper, allUnscopedEmitHelpers, asyncSuperHelper, advancedAsyncSuperHelper;
        var init_emitHelpers = __esm({
            "src/compiler/factory/emitHelpers.ts"() {
                "use strict";
                init_ts2();
                PrivateIdentifierKind = /* @__PURE__ */ ((PrivateIdentifierKind2) => {
                    PrivateIdentifierKind2["Field"] = "f";
                    PrivateIdentifierKind2["Method"] = "m";
                    PrivateIdentifierKind2["Accessor"] = "a";
                    return PrivateIdentifierKind2;
                })(PrivateIdentifierKind || {});
                decorateHelper = {
                    name: "typescript:decorate",
                    importName: "__decorate",
                    scoped: false,
                    priority: 2,
                    text: `
            var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
                var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
                if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
                else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
                return c > 3 && r && Object.defineProperty(target, key, r), r;
            };`
                };
                metadataHelper = {
                    name: "typescript:metadata",
                    importName: "__metadata",
                    scoped: false,
                    priority: 3,
                    text: `
            var __metadata = (this && this.__metadata) || function (k, v) {
                if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
            };`
                };
                paramHelper = {
                    name: "typescript:param",
                    importName: "__param",
                    scoped: false,
                    priority: 4,
                    text: `
            var __param = (this && this.__param) || function (paramIndex, decorator) {
                return function (target, key) { decorator(target, key, paramIndex); }
            };`
                };
                esDecorateHelper = {
                    name: "typescript:esDecorate",
                    importName: "__esDecorate",
                    scoped: false,
                    priority: 2,
                    text: `
        var __esDecorate = (this && this.__esDecorate) || function (ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
            function accept(f) { if (f !== void 0 && typeof f !== "function") throw new TypeError("Function expected"); return f; }
            var kind = contextIn.kind, key = kind === "getter" ? "get" : kind === "setter" ? "set" : "value";
            var target = !descriptorIn && ctor ? contextIn["static"] ? ctor : ctor.prototype : null;
            var descriptor = descriptorIn || (target ? Object.getOwnPropertyDescriptor(target, contextIn.name) : {});
            var _, done = false;
            for (var i = decorators.length - 1; i >= 0; i--) {
                var context = {};
                for (var p in contextIn) context[p] = p === "access" ? {} : contextIn[p];
                for (var p in contextIn.access) context.access[p] = contextIn.access[p];
                context.addInitializer = function (f) { if (done) throw new TypeError("Cannot add initializers after decoration has completed"); extraInitializers.push(accept(f || null)); };
                var result = (0, decorators[i])(kind === "accessor" ? { get: descriptor.get, set: descriptor.set } : descriptor[key], context);
                if (kind === "accessor") {
                    if (result === void 0) continue;
                    if (result === null || typeof result !== "object") throw new TypeError("Object expected");
                    if (_ = accept(result.get)) descriptor.get = _;
                    if (_ = accept(result.set)) descriptor.set = _;
                    if (_ = accept(result.init)) initializers.push(_);
                }
                else if (_ = accept(result)) {
                    if (kind === "field") initializers.push(_);
                    else descriptor[key] = _;
                }
            }
            if (target) Object.defineProperty(target, contextIn.name, descriptor);
            done = true;
        };`
                };
                runInitializersHelper = {
                    name: "typescript:runInitializers",
                    importName: "__runInitializers",
                    scoped: false,
                    priority: 2,
                    text: `
        var __runInitializers = (this && this.__runInitializers) || function (thisArg, initializers, value) {
            var useValue = arguments.length > 2;
            for (var i = 0; i < initializers.length; i++) {
                value = useValue ? initializers[i].call(thisArg, value) : initializers[i].call(thisArg);
            }
            return useValue ? value : void 0;
        };`
                };
                assignHelper = {
                    name: "typescript:assign",
                    importName: "__assign",
                    scoped: false,
                    priority: 1,
                    text: `
            var __assign = (this && this.__assign) || function () {
                __assign = Object.assign || function(t) {
                    for (var s, i = 1, n = arguments.length; i < n; i++) {
                        s = arguments[i];
                        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                            t[p] = s[p];
                    }
                    return t;
                };
                return __assign.apply(this, arguments);
            };`
                };
                awaitHelper = {
                    name: "typescript:await",
                    importName: "__await",
                    scoped: false,
                    text: `
            var __await = (this && this.__await) || function (v) { return this instanceof __await ? (this.v = v, this) : new __await(v); }`
                };
                asyncGeneratorHelper = {
                    name: "typescript:asyncGenerator",
                    importName: "__asyncGenerator",
                    scoped: false,
                    dependencies: [awaitHelper],
                    text: `
            var __asyncGenerator = (this && this.__asyncGenerator) || function (thisArg, _arguments, generator) {
                if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
                var g = generator.apply(thisArg, _arguments || []), i, q = [];
                return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
                function verb(n) { if (g[n]) i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
                function resume(n, v) { try { step(g[n](v)); } catch (e) { settle(q[0][3], e); } }
                function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
                function fulfill(value) { resume("next", value); }
                function reject(value) { resume("throw", value); }
                function settle(f, v) { if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]); }
            };`
                };
                asyncDelegator = {
                    name: "typescript:asyncDelegator",
                    importName: "__asyncDelegator",
                    scoped: false,
                    dependencies: [awaitHelper],
                    text: `
            var __asyncDelegator = (this && this.__asyncDelegator) || function (o) {
                var i, p;
                return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
                function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: false } : f ? f(v) : v; } : f; }
            };`
                };
                asyncValues = {
                    name: "typescript:asyncValues",
                    importName: "__asyncValues",
                    scoped: false,
                    text: `
            var __asyncValues = (this && this.__asyncValues) || function (o) {
                if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
                var m = o[Symbol.asyncIterator], i;
                return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
                function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
                function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
            };`
                };
                restHelper = {
                    name: "typescript:rest",
                    importName: "__rest",
                    scoped: false,
                    text: `
            var __rest = (this && this.__rest) || function (s, e) {
                var t = {};
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                    t[p] = s[p];
                if (s != null && typeof Object.getOwnPropertySymbols === "function")
                    for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                        if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                            t[p[i]] = s[p[i]];
                    }
                return t;
            };`
                };
                awaiterHelper = {
                    name: "typescript:awaiter",
                    importName: "__awaiter",
                    scoped: false,
                    priority: 5,
                    text: `
            var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
                function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
                return new (P || (P = Promise))(function (resolve, reject) {
                    function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
                    function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
                    function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
                    step((generator = generator.apply(thisArg, _arguments || [])).next());
                });
            };`
                };
                extendsHelper = {
                    name: "typescript:extends",
                    importName: "__extends",
                    scoped: false,
                    priority: 0,
                    text: `
            var __extends = (this && this.__extends) || (function () {
                var extendStatics = function (d, b) {
                    extendStatics = Object.setPrototypeOf ||
                        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
                    return extendStatics(d, b);
                };

                return function (d, b) {
                    if (typeof b !== "function" && b !== null)
                        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
                    extendStatics(d, b);
                    function __() { this.constructor = d; }
                    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
                };
            })();`
                };
                templateObjectHelper = {
                    name: "typescript:makeTemplateObject",
                    importName: "__makeTemplateObject",
                    scoped: false,
                    priority: 0,
                    text: `
            var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
                if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
                return cooked;
            };`
                };
                readHelper = {
                    name: "typescript:read",
                    importName: "__read",
                    scoped: false,
                    text: `
            var __read = (this && this.__read) || function (o, n) {
                var m = typeof Symbol === "function" && o[Symbol.iterator];
                if (!m) return o;
                var i = m.call(o), r, ar = [], e;
                try {
                    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
                }
                catch (error) { e = { error: error }; }
                finally {
                    try {
                        if (r && !r.done && (m = i["return"])) m.call(i);
                    }
                    finally { if (e) throw e.error; }
                }
                return ar;
            };`
                };
                spreadArrayHelper = {
                    name: "typescript:spreadArray",
                    importName: "__spreadArray",
                    scoped: false,
                    text: `
            var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
                if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
                    if (ar || !(i in from)) {
                        if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                        ar[i] = from[i];
                    }
                }
                return to.concat(ar || Array.prototype.slice.call(from));
            };`
                };
                propKeyHelper = {
                    name: "typescript:propKey",
                    importName: "__propKey",
                    scoped: false,
                    text: `
        var __propKey = (this && this.__propKey) || function (x) {
            return typeof x === "symbol" ? x : "".concat(x);
        };`
                };
                setFunctionNameHelper = {
                    name: "typescript:setFunctionName",
                    importName: "__setFunctionName",
                    scoped: false,
                    text: `
        var __setFunctionName = (this && this.__setFunctionName) || function (f, name, prefix) {
            if (typeof name === "symbol") name = name.description ? "[".concat(name.description, "]") : "";
            return Object.defineProperty(f, "name", { configurable: true, value: prefix ? "".concat(prefix, " ", name) : name });
        };`
                };
                valuesHelper = {
                    name: "typescript:values",
                    importName: "__values",
                    scoped: false,
                    text: `
            var __values = (this && this.__values) || function(o) {
                var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
                if (m) return m.call(o);
                if (o && typeof o.length === "number") return {
                    next: function () {
                        if (o && i >= o.length) o = void 0;
                        return { value: o && o[i++], done: !o };
                    }
                };
                throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
            };`
                };
                generatorHelper = {
                    name: "typescript:generator",
                    importName: "__generator",
                    scoped: false,
                    priority: 6,
                    text: `
            var __generator = (this && this.__generator) || function (thisArg, body) {
                var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
                return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
                function verb(n) { return function (v) { return step([n, v]); }; }
                function step(op) {
                    if (f) throw new TypeError("Generator is already executing.");
                    while (g && (g = 0, op[0] && (_ = 0)), _) try {
                        if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                        if (y = 0, t) op = [op[0] & 2, t.value];
                        switch (op[0]) {
                            case 0: case 1: t = op; break;
                            case 4: _.label++; return { value: op[1], done: false };
                            case 5: _.label++; y = op[1]; op = [0]; continue;
                            case 7: op = _.ops.pop(); _.trys.pop(); continue;
                            default:
                                if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                                if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                                if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                                if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                                if (t[2]) _.ops.pop();
                                _.trys.pop(); continue;
                        }
                        op = body.call(thisArg, _);
                    } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
                    if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
                }
            };`
                };
                createBindingHelper = {
                    name: "typescript:commonjscreatebinding",
                    importName: "__createBinding",
                    scoped: false,
                    priority: 1,
                    text: `
            var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
                if (k2 === undefined) k2 = k;
                var desc = Object.getOwnPropertyDescriptor(m, k);
                if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
                  desc = { enumerable: true, get: function() { return m[k]; } };
                }
                Object.defineProperty(o, k2, desc);
            }) : (function(o, m, k, k2) {
                if (k2 === undefined) k2 = k;
                o[k2] = m[k];
            }));`
                };
                setModuleDefaultHelper = {
                    name: "typescript:commonjscreatevalue",
                    importName: "__setModuleDefault",
                    scoped: false,
                    priority: 1,
                    text: `
            var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
                Object.defineProperty(o, "default", { enumerable: true, value: v });
            }) : function(o, v) {
                o["default"] = v;
            });`
                };
                importStarHelper = {
                    name: "typescript:commonjsimportstar",
                    importName: "__importStar",
                    scoped: false,
                    dependencies: [createBindingHelper, setModuleDefaultHelper],
                    priority: 2,
                    text: `
            var __importStar = (this && this.__importStar) || function (mod) {
                if (mod && mod.__esModule) return mod;
                var result = {};
                if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
                __setModuleDefault(result, mod);
                return result;
            };`
                };
                importDefaultHelper = {
                    name: "typescript:commonjsimportdefault",
                    importName: "__importDefault",
                    scoped: false,
                    text: `
            var __importDefault = (this && this.__importDefault) || function (mod) {
                return (mod && mod.__esModule) ? mod : { "default": mod };
            };`
                };
                exportStarHelper = {
                    name: "typescript:export-star",
                    importName: "__exportStar",
                    scoped: false,
                    dependencies: [createBindingHelper],
                    priority: 2,
                    text: `
            var __exportStar = (this && this.__exportStar) || function(m, exports) {
                for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
            };`
                };
                classPrivateFieldGetHelper = {
                    name: "typescript:classPrivateFieldGet",
                    importName: "__classPrivateFieldGet",
                    scoped: false,
                    text: `
            var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
                if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
                if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
                return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
            };`
                };
                classPrivateFieldSetHelper = {
                    name: "typescript:classPrivateFieldSet",
                    importName: "__classPrivateFieldSet",
                    scoped: false,
                    text: `
            var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
                if (kind === "m") throw new TypeError("Private method is not writable");
                if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
                if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
                return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
            };`
                };
                classPrivateFieldInHelper = {
                    name: "typescript:classPrivateFieldIn",
                    importName: "__classPrivateFieldIn",
                    scoped: false,
                    text: `
            var __classPrivateFieldIn = (this && this.__classPrivateFieldIn) || function(state, receiver) {
                if (receiver === null || (typeof receiver !== "object" && typeof receiver !== "function")) throw new TypeError("Cannot use 'in' operator on non-object");
                return typeof state === "function" ? receiver === state : state.has(receiver);
            };`
                };
                asyncSuperHelper = {
                    name: "typescript:async-super",
                    scoped: true,
                    text: helperString `
            const ${"_superIndex"} = name => super[name];`
                };
                advancedAsyncSuperHelper = {
                    name: "typescript:advanced-async-super",
                    scoped: true,
                    text: helperString `
            const ${"_superIndex"} = (function (geti, seti) {
                const cache = Object.create(null);
                return name => cache[name] || (cache[name] = { get value() { return geti(name); }, set value(v) { seti(name, v); } });
            })(name => super[name], (name, value) => super[name] = value);`
                };
            }
        });
        // src/compiler/factory/nodeTests.ts
        function isNumericLiteral(node) {
            return node.kind === 8 /* NumericLiteral */;
        }
        function isBigIntLiteral(node) {
            return node.kind === 9 /* BigIntLiteral */;
        }
        function isStringLiteral(node) {
            return node.kind === 10 /* StringLiteral */;
        }
        function isJsxText(node) {
            return node.kind === 11 /* JsxText */;
        }
        function isRegularExpressionLiteral(node) {
            return node.kind === 13 /* RegularExpressionLiteral */;
        }
        function isNoSubstitutionTemplateLiteral(node) {
            return node.kind === 14 /* NoSubstitutionTemplateLiteral */;
        }
        function isTemplateHead(node) {
            return node.kind === 15 /* TemplateHead */;
        }
        function isTemplateMiddle(node) {
            return node.kind === 16 /* TemplateMiddle */;
        }
        function isTemplateTail(node) {
            return node.kind === 17 /* TemplateTail */;
        }
        function isDotDotDotToken(node) {
            return node.kind === 25 /* DotDotDotToken */;
        }
        function isCommaToken(node) {
            return node.kind === 27 /* CommaToken */;
        }
        function isPlusToken(node) {
            return node.kind === 39 /* PlusToken */;
        }
        function isMinusToken(node) {
            return node.kind === 40 /* MinusToken */;
        }
        function isAsteriskToken(node) {
            return node.kind === 41 /* AsteriskToken */;
        }
        function isExclamationToken(node) {
            return node.kind === 53 /* ExclamationToken */;
        }
        function isQuestionToken(node) {
            return node.kind === 57 /* QuestionToken */;
        }
        function isColonToken(node) {
            return node.kind === 58 /* ColonToken */;
        }
        function isQuestionDotToken(node) {
            return node.kind === 28 /* QuestionDotToken */;
        }
        function isEqualsGreaterThanToken(node) {
            return node.kind === 38 /* EqualsGreaterThanToken */;
        }
        function isIdentifier(node) {
            return node.kind === 79 /* Identifier */;
        }
        function isPrivateIdentifier(node) {
            return node.kind === 80 /* PrivateIdentifier */;
        }
        function isExportModifier(node) {
            return node.kind === 93 /* ExportKeyword */;
        }
        function isDefaultModifier(node) {
            return node.kind === 88 /* DefaultKeyword */;
        }
        function isAsyncModifier(node) {
            return node.kind === 132 /* AsyncKeyword */;
        }
        function isAssertsKeyword(node) {
            return node.kind === 129 /* AssertsKeyword */;
        }
        function isAwaitKeyword(node) {
            return node.kind === 133 /* AwaitKeyword */;
        }
        function isReadonlyKeyword(node) {
            return node.kind === 146 /* ReadonlyKeyword */;
        }
        function isStaticModifier(node) {
            return node.kind === 124 /* StaticKeyword */;
        }
        function isAbstractModifier(node) {
            return node.kind === 126 /* AbstractKeyword */;
        }
        function isOverrideModifier(node) {
            return node.kind === 161 /* OverrideKeyword */;
        }
        function isAccessorModifier(node) {
            return node.kind === 127 /* AccessorKeyword */;
        }
        function isSuperKeyword(node) {
            return node.kind === 106 /* SuperKeyword */;
        }
        function isImportKeyword(node) {
            return node.kind === 100 /* ImportKeyword */;
        }
        function isCaseKeyword(node) {
            return node.kind === 82 /* CaseKeyword */;
        }
        function isQualifiedName(node) {
            return node.kind === 163 /* QualifiedName */;
        }
        function isComputedPropertyName(node) {
            return node.kind === 164 /* ComputedPropertyName */;
        }
        function isTypeParameterDeclaration(node) {
            return node.kind === 165 /* TypeParameter */;
        }
        function isParameter(node) {
            return node.kind === 166 /* Parameter */;
        }
        function isDecorator(node) {
            return node.kind === 167 /* Decorator */;
        }
        function isPropertySignature(node) {
            return node.kind === 168 /* PropertySignature */;
        }
        function isPropertyDeclaration(node) {
            return node.kind === 169 /* PropertyDeclaration */;
        }
        function isMethodSignature(node) {
            return node.kind === 170 /* MethodSignature */;
        }
        function isMethodDeclaration(node) {
            return node.kind === 171 /* MethodDeclaration */;
        }
        function isClassStaticBlockDeclaration(node) {
            return node.kind === 172 /* ClassStaticBlockDeclaration */;
        }
        function isConstructorDeclaration(node) {
            return node.kind === 173 /* Constructor */;
        }
        function isGetAccessorDeclaration(node) {
            return node.kind === 174 /* GetAccessor */;
        }
        function isSetAccessorDeclaration(node) {
            return node.kind === 175 /* SetAccessor */;
        }
        function isCallSignatureDeclaration(node) {
            return node.kind === 176 /* CallSignature */;
        }
        function isConstructSignatureDeclaration(node) {
            return node.kind === 177 /* ConstructSignature */;
        }
        function isIndexSignatureDeclaration(node) {
            return node.kind === 178 /* IndexSignature */;
        }
        function isTypePredicateNode(node) {
            return node.kind === 179 /* TypePredicate */;
        }
        function isTypeReferenceNode(node) {
            return node.kind === 180 /* TypeReference */;
        }
        function isFunctionTypeNode(node) {
            return node.kind === 181 /* FunctionType */;
        }
        function isConstructorTypeNode(node) {
            return node.kind === 182 /* ConstructorType */;
        }
        function isTypeQueryNode(node) {
            return node.kind === 183 /* TypeQuery */;
        }
        function isTypeLiteralNode(node) {
            return node.kind === 184 /* TypeLiteral */;
        }
        function isArrayTypeNode(node) {
            return node.kind === 185 /* ArrayType */;
        }
        function isTupleTypeNode(node) {
            return node.kind === 186 /* TupleType */;
        }
        function isNamedTupleMember(node) {
            return node.kind === 199 /* NamedTupleMember */;
        }
        function isOptionalTypeNode(node) {
            return node.kind === 187 /* OptionalType */;
        }
        function isRestTypeNode(node) {
            return node.kind === 188 /* RestType */;
        }
        function isUnionTypeNode(node) {
            return node.kind === 189 /* UnionType */;
        }
        function isIntersectionTypeNode(node) {
            return node.kind === 190 /* IntersectionType */;
        }
        function isConditionalTypeNode(node) {
            return node.kind === 191 /* ConditionalType */;
        }
        function isInferTypeNode(node) {
            return node.kind === 192 /* InferType */;
        }
        function isParenthesizedTypeNode(node) {
            return node.kind === 193 /* ParenthesizedType */;
        }
        function isThisTypeNode(node) {
            return node.kind === 194 /* ThisType */;
        }
        function isTypeOperatorNode(node) {
            return node.kind === 195 /* TypeOperator */;
        }
        function isIndexedAccessTypeNode(node) {
            return node.kind === 196 /* IndexedAccessType */;
        }
        function isMappedTypeNode(node) {
            return node.kind === 197 /* MappedType */;
        }
        function isLiteralTypeNode(node) {
            return node.kind === 198 /* LiteralType */;
        }
        function isImportTypeNode(node) {
            return node.kind === 202 /* ImportType */;
        }
        function isTemplateLiteralTypeSpan(node) {
            return node.kind === 201 /* TemplateLiteralTypeSpan */;
        }
        function isTemplateLiteralTypeNode(node) {
            return node.kind === 200 /* TemplateLiteralType */;
        }
        function isObjectBindingPattern(node) {
            return node.kind === 203 /* ObjectBindingPattern */;
        }
        function isArrayBindingPattern(node) {
            return node.kind === 204 /* ArrayBindingPattern */;
        }
        function isBindingElement(node) {
            return node.kind === 205 /* BindingElement */;
        }
        function isArrayLiteralExpression(node) {
            return node.kind === 206 /* ArrayLiteralExpression */;
        }
        function isObjectLiteralExpression(node) {
            return node.kind === 207 /* ObjectLiteralExpression */;
        }
        function isPropertyAccessExpression(node) {
            return node.kind === 208 /* PropertyAccessExpression */;
        }
        function isElementAccessExpression(node) {
            return node.kind === 209 /* ElementAccessExpression */;
        }
        function isCallExpression(node) {
            return node.kind === 210 /* CallExpression */;
        }
        function isNewExpression(node) {
            return node.kind === 211 /* NewExpression */;
        }
        function isTaggedTemplateExpression(node) {
            return node.kind === 212 /* TaggedTemplateExpression */;
        }
        function isTypeAssertionExpression(node) {
            return node.kind === 213 /* TypeAssertionExpression */;
        }
        function isParenthesizedExpression(node) {
            return node.kind === 214 /* ParenthesizedExpression */;
        }
        function isFunctionExpression(node) {
            return node.kind === 215 /* FunctionExpression */;
        }
        function isArrowFunction(node) {
            return node.kind === 216 /* ArrowFunction */;
        }
        function isDeleteExpression(node) {
            return node.kind === 217 /* DeleteExpression */;
        }
        function isTypeOfExpression(node) {
            return node.kind === 218 /* TypeOfExpression */;
        }
        function isVoidExpression(node) {
            return node.kind === 219 /* VoidExpression */;
        }
        function isAwaitExpression(node) {
            return node.kind === 220 /* AwaitExpression */;
        }
        function isPrefixUnaryExpression(node) {
            return node.kind === 221 /* PrefixUnaryExpression */;
        }
        function isPostfixUnaryExpression(node) {
            return node.kind === 222 /* PostfixUnaryExpression */;
        }
        function isBinaryExpression(node) {
            return node.kind === 223 /* BinaryExpression */;
        }
        function isConditionalExpression(node) {
            return node.kind === 224 /* ConditionalExpression */;
        }
        function isTemplateExpression(node) {
            return node.kind === 225 /* TemplateExpression */;
        }
        function isYieldExpression(node) {
            return node.kind === 226 /* YieldExpression */;
        }
        function isSpreadElement(node) {
            return node.kind === 227 /* SpreadElement */;
        }
        function isClassExpression(node) {
            return node.kind === 228 /* ClassExpression */;
        }
        function isOmittedExpression(node) {
            return node.kind === 229 /* OmittedExpression */;
        }
        function isExpressionWithTypeArguments(node) {
            return node.kind === 230 /* ExpressionWithTypeArguments */;
        }
        function isAsExpression(node) {
            return node.kind === 231 /* AsExpression */;
        }
        function isSatisfiesExpression(node) {
            return node.kind === 235 /* SatisfiesExpression */;
        }
        function isNonNullExpression(node) {
            return node.kind === 232 /* NonNullExpression */;
        }
        function isMetaProperty(node) {
            return node.kind === 233 /* MetaProperty */;
        }
        function isSyntheticExpression(node) {
            return node.kind === 234 /* SyntheticExpression */;
        }
        function isPartiallyEmittedExpression(node) {
            return node.kind === 356 /* PartiallyEmittedExpression */;
        }
        function isCommaListExpression(node) {
            return node.kind === 357 /* CommaListExpression */;
        }
        function isTemplateSpan(node) {
            return node.kind === 236 /* TemplateSpan */;
        }
        function isSemicolonClassElement(node) {
            return node.kind === 237 /* SemicolonClassElement */;
        }
        function isBlock(node) {
            return node.kind === 238 /* Block */;
        }
        function isVariableStatement(node) {
            return node.kind === 240 /* VariableStatement */;
        }
        function isEmptyStatement(node) {
            return node.kind === 239 /* EmptyStatement */;
        }
        function isExpressionStatement(node) {
            return node.kind === 241 /* ExpressionStatement */;
        }
        function isIfStatement(node) {
            return node.kind === 242 /* IfStatement */;
        }
        function isDoStatement(node) {
            return node.kind === 243 /* DoStatement */;
        }
        function isWhileStatement(node) {
            return node.kind === 244 /* WhileStatement */;
        }
        function isForStatement(node) {
            return node.kind === 245 /* ForStatement */;
        }
        function isForInStatement(node) {
            return node.kind === 246 /* ForInStatement */;
        }
        function isForOfStatement(node) {
            return node.kind === 247 /* ForOfStatement */;
        }
        function isContinueStatement(node) {
            return node.kind === 248 /* ContinueStatement */;
        }
        function isBreakStatement(node) {
            return node.kind === 249 /* BreakStatement */;
        }
        function isReturnStatement(node) {
            return node.kind === 250 /* ReturnStatement */;
        }
        function isWithStatement(node) {
            return node.kind === 251 /* WithStatement */;
        }
        function isSwitchStatement(node) {
            return node.kind === 252 /* SwitchStatement */;
        }
        function isLabeledStatement(node) {
            return node.kind === 253 /* LabeledStatement */;
        }
        function isThrowStatement(node) {
            return node.kind === 254 /* ThrowStatement */;
        }
        function isTryStatement(node) {
            return node.kind === 255 /* TryStatement */;
        }
        function isDebuggerStatement(node) {
            return node.kind === 256 /* DebuggerStatement */;
        }
        function isVariableDeclaration(node) {
            return node.kind === 257 /* VariableDeclaration */;
        }
        function isVariableDeclarationList(node) {
            return node.kind === 258 /* VariableDeclarationList */;
        }
        function isFunctionDeclaration(node) {
            return node.kind === 259 /* FunctionDeclaration */;
        }
        function isClassDeclaration(node) {
            return node.kind === 260 /* ClassDeclaration */;
        }
        function isInterfaceDeclaration(node) {
            return node.kind === 261 /* InterfaceDeclaration */;
        }
        function isTypeAliasDeclaration(node) {
            return node.kind === 262 /* TypeAliasDeclaration */;
        }
        function isEnumDeclaration(node) {
            return node.kind === 263 /* EnumDeclaration */;
        }
        function isModuleDeclaration(node) {
            return node.kind === 264 /* ModuleDeclaration */;
        }
        function isModuleBlock(node) {
            return node.kind === 265 /* ModuleBlock */;
        }
        function isCaseBlock(node) {
            return node.kind === 266 /* CaseBlock */;
        }
        function isNamespaceExportDeclaration(node) {
            return node.kind === 267 /* NamespaceExportDeclaration */;
        }
        function isImportEqualsDeclaration(node) {
            return node.kind === 268 /* ImportEqualsDeclaration */;
        }
        function isImportDeclaration(node) {
            return node.kind === 269 /* ImportDeclaration */;
        }
        function isImportClause(node) {
            return node.kind === 270 /* ImportClause */;
        }
        function isImportTypeAssertionContainer(node) {
            return node.kind === 298 /* ImportTypeAssertionContainer */;
        }
        function isAssertClause(node) {
            return node.kind === 296 /* AssertClause */;
        }
        function isAssertEntry(node) {
            return node.kind === 297 /* AssertEntry */;
        }
        function isNamespaceImport(node) {
            return node.kind === 271 /* NamespaceImport */;
        }
        function isNamespaceExport(node) {
            return node.kind === 277 /* NamespaceExport */;
        }
        function isNamedImports(node) {
            return node.kind === 272 /* NamedImports */;
        }
        function isImportSpecifier(node) {
            return node.kind === 273 /* ImportSpecifier */;
        }
        function isExportAssignment(node) {
            return node.kind === 274 /* ExportAssignment */;
        }
        function isExportDeclaration(node) {
            return node.kind === 275 /* ExportDeclaration */;
        }
        function isNamedExports(node) {
            return node.kind === 276 /* NamedExports */;
        }
        function isExportSpecifier(node) {
            return node.kind === 278 /* ExportSpecifier */;
        }
        function isMissingDeclaration(node) {
            return node.kind === 279 /* MissingDeclaration */;
        }
        function isNotEmittedStatement(node) {
            return node.kind === 355 /* NotEmittedStatement */;
        }
        function isSyntheticReference(node) {
            return node.kind === 360 /* SyntheticReferenceExpression */;
        }
        function isMergeDeclarationMarker(node) {
            return node.kind === 358 /* MergeDeclarationMarker */;
        }
        function isEndOfDeclarationMarker(node) {
            return node.kind === 359 /* EndOfDeclarationMarker */;
        }
        function isExternalModuleReference(node) {
            return node.kind === 280 /* ExternalModuleReference */;
        }
        function isJsxElement(node) {
            return node.kind === 281 /* JsxElement */;
        }
        function isJsxSelfClosingElement(node) {
            return node.kind === 282 /* JsxSelfClosingElement */;
        }
        function isJsxOpeningElement(node) {
            return node.kind === 283 /* JsxOpeningElement */;
        }
        function isJsxClosingElement(node) {
            return node.kind === 284 /* JsxClosingElement */;
        }
        function isJsxFragment(node) {
            return node.kind === 285 /* JsxFragment */;
        }
        function isJsxOpeningFragment(node) {
            return node.kind === 286 /* JsxOpeningFragment */;
        }
        function isJsxClosingFragment(node) {
            return node.kind === 287 /* JsxClosingFragment */;
        }
        function isJsxAttribute(node) {
            return node.kind === 288 /* JsxAttribute */;
        }
        function isJsxAttributes(node) {
            return node.kind === 289 /* JsxAttributes */;
        }
        function isJsxSpreadAttribute(node) {
            return node.kind === 290 /* JsxSpreadAttribute */;
        }
        function isJsxExpression(node) {
            return node.kind === 291 /* JsxExpression */;
        }
        function isCaseClause(node) {
            return node.kind === 292 /* CaseClause */;
        }
        function isDefaultClause(node) {
            return node.kind === 293 /* DefaultClause */;
        }
        function isHeritageClause(node) {
            return node.kind === 294 /* HeritageClause */;
        }
        function isCatchClause(node) {
            return node.kind === 295 /* CatchClause */;
        }
        function isPropertyAssignment(node) {
            return node.kind === 299 /* PropertyAssignment */;
        }
        function isShorthandPropertyAssignment(node) {
            return node.kind === 300 /* ShorthandPropertyAssignment */;
        }
        function isSpreadAssignment(node) {
            return node.kind === 301 /* SpreadAssignment */;
        }
        function isEnumMember(node) {
            return node.kind === 302 /* EnumMember */;
        }
        function isUnparsedPrepend(node) {
            return node.kind === 304 /* UnparsedPrepend */;
        }
        function isSourceFile(node) {
            return node.kind === 308 /* SourceFile */;
        }
        function isBundle(node) {
            return node.kind === 309 /* Bundle */;
        }
        function isUnparsedSource(node) {
            return node.kind === 310 /* UnparsedSource */;
        }
        function isJSDocTypeExpression(node) {
            return node.kind === 312 /* JSDocTypeExpression */;
        }
        function isJSDocNameReference(node) {
            return node.kind === 313 /* JSDocNameReference */;
        }
        function isJSDocMemberName(node) {
            return node.kind === 314 /* JSDocMemberName */;
        }
        function isJSDocLink(node) {
            return node.kind === 327 /* JSDocLink */;
        }
        function isJSDocLinkCode(node) {
            return node.kind === 328 /* JSDocLinkCode */;
        }
        function isJSDocLinkPlain(node) {
            return node.kind === 329 /* JSDocLinkPlain */;
        }
        function isJSDocAllType(node) {
            return node.kind === 315 /* JSDocAllType */;
        }
        function isJSDocUnknownType(node) {
            return node.kind === 316 /* JSDocUnknownType */;
        }
        function isJSDocNullableType(node) {
            return node.kind === 317 /* JSDocNullableType */;
        }
        function isJSDocNonNullableType(node) {
            return node.kind === 318 /* JSDocNonNullableType */;
        }
        function isJSDocOptionalType(node) {
            return node.kind === 319 /* JSDocOptionalType */;
        }
        function isJSDocFunctionType(node) {
            return node.kind === 320 /* JSDocFunctionType */;
        }
        function isJSDocVariadicType(node) {
            return node.kind === 321 /* JSDocVariadicType */;
        }
        function isJSDocNamepathType(node) {
            return node.kind === 322 /* JSDocNamepathType */;
        }
        function isJSDoc(node) {
            return node.kind === 323 /* JSDoc */;
        }
        function isJSDocTypeLiteral(node) {
            return node.kind === 325 /* JSDocTypeLiteral */;
        }
        function isJSDocSignature(node) {
            return node.kind === 326 /* JSDocSignature */;
        }
        function isJSDocAugmentsTag(node) {
            return node.kind === 331 /* JSDocAugmentsTag */;
        }
        function isJSDocAuthorTag(node) {
            return node.kind === 333 /* JSDocAuthorTag */;
        }
        function isJSDocClassTag(node) {
            return node.kind === 335 /* JSDocClassTag */;
        }
        function isJSDocCallbackTag(node) {
            return node.kind === 341 /* JSDocCallbackTag */;
        }
        function isJSDocPublicTag(node) {
            return node.kind === 336 /* JSDocPublicTag */;
        }
        function isJSDocPrivateTag(node) {
            return node.kind === 337 /* JSDocPrivateTag */;
        }
        function isJSDocProtectedTag(node) {
            return node.kind === 338 /* JSDocProtectedTag */;
        }
        function isJSDocReadonlyTag(node) {
            return node.kind === 339 /* JSDocReadonlyTag */;
        }
        function isJSDocOverrideTag(node) {
            return node.kind === 340 /* JSDocOverrideTag */;
        }
        function isJSDocOverloadTag(node) {
            return node.kind === 342 /* JSDocOverloadTag */;
        }
        function isJSDocDeprecatedTag(node) {
            return node.kind === 334 /* JSDocDeprecatedTag */;
        }
        function isJSDocSeeTag(node) {
            return node.kind === 350 /* JSDocSeeTag */;
        }
        function isJSDocEnumTag(node) {
            return node.kind === 343 /* JSDocEnumTag */;
        }
        function isJSDocParameterTag(node) {
            return node.kind === 344 /* JSDocParameterTag */;
        }
        function isJSDocReturnTag(node) {
            return node.kind === 345 /* JSDocReturnTag */;
        }
        function isJSDocThisTag(node) {
            return node.kind === 346 /* JSDocThisTag */;
        }
        function isJSDocTypeTag(node) {
            return node.kind === 347 /* JSDocTypeTag */;
        }
        function isJSDocTemplateTag(node) {
            return node.kind === 348 /* JSDocTemplateTag */;
        }
        function isJSDocTypedefTag(node) {
            return node.kind === 349 /* JSDocTypedefTag */;
        }
        function isJSDocUnknownTag(node) {
            return node.kind === 330 /* JSDocTag */;
        }
        function isJSDocPropertyTag(node) {
            return node.kind === 351 /* JSDocPropertyTag */;
        }
        function isJSDocImplementsTag(node) {
            return node.kind === 332 /* JSDocImplementsTag */;
        }
        function isJSDocSatisfiesTag(node) {
            return node.kind === 353 /* JSDocSatisfiesTag */;
        }
        function isJSDocThrowsTag(node) {
            return node.kind === 352 /* JSDocThrowsTag */;
        }
        function isSyntaxList(n) {
            return n.kind === 354 /* SyntaxList */;
        }
        var init_nodeTests = __esm({
            "src/compiler/factory/nodeTests.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/factory/utilities.ts
        function createEmptyExports(factory2) {
            return factory2.createExportDeclaration(
            /*modifiers*/
            void 0, 
            /*isTypeOnly*/
            false, factory2.createNamedExports([]), 
            /*moduleSpecifier*/
            void 0);
        }
        function createMemberAccessForPropertyName(factory2, target, memberName, location) {
            if (isComputedPropertyName(memberName)) {
                return setTextRange(factory2.createElementAccessExpression(target, memberName.expression), location);
            }
            else {
                const expression = setTextRange(isMemberName(memberName) ? factory2.createPropertyAccessExpression(target, memberName) : factory2.createElementAccessExpression(target, memberName), memberName);
                addEmitFlags(expression, 128 /* NoNestedSourceMaps */);
                return expression;
            }
        }
        function createReactNamespace(reactNamespace, parent2) {
            const react = parseNodeFactory.createIdentifier(reactNamespace || "React");
            setParent(react, getParseTreeNode(parent2));
            return react;
        }
        function createJsxFactoryExpressionFromEntityName(factory2, jsxFactory, parent2) {
            if (isQualifiedName(jsxFactory)) {
                const left = createJsxFactoryExpressionFromEntityName(factory2, jsxFactory.left, parent2);
                const right = factory2.createIdentifier(idText(jsxFactory.right));
                right.escapedText = jsxFactory.right.escapedText;
                return factory2.createPropertyAccessExpression(left, right);
            }
            else {
                return createReactNamespace(idText(jsxFactory), parent2);
            }
        }
        function createJsxFactoryExpression(factory2, jsxFactoryEntity, reactNamespace, parent2) {
            return jsxFactoryEntity ? createJsxFactoryExpressionFromEntityName(factory2, jsxFactoryEntity, parent2) : factory2.createPropertyAccessExpression(createReactNamespace(reactNamespace, parent2), "createElement");
        }
        function createJsxFragmentFactoryExpression(factory2, jsxFragmentFactoryEntity, reactNamespace, parent2) {
            return jsxFragmentFactoryEntity ? createJsxFactoryExpressionFromEntityName(factory2, jsxFragmentFactoryEntity, parent2) : factory2.createPropertyAccessExpression(createReactNamespace(reactNamespace, parent2), "Fragment");
        }
        function createExpressionForJsxElement(factory2, callee, tagName, props, children, location) {
            const argumentsList = [tagName];
            if (props) {
                argumentsList.push(props);
            }
            if (children && children.length > 0) {
                if (!props) {
                    argumentsList.push(factory2.createNull());
                }
                if (children.length > 1) {
                    for (const child of children) {
                        startOnNewLine(child);
                        argumentsList.push(child);
                    }
                }
                else {
                    argumentsList.push(children[0]);
                }
            }
            return setTextRange(factory2.createCallExpression(callee, 
            /*typeArguments*/
            void 0, argumentsList), location);
        }
        function createExpressionForJsxFragment(factory2, jsxFactoryEntity, jsxFragmentFactoryEntity, reactNamespace, children, parentElement, location) {
            const tagName = createJsxFragmentFactoryExpression(factory2, jsxFragmentFactoryEntity, reactNamespace, parentElement);
            const argumentsList = [tagName, factory2.createNull()];
            if (children && children.length > 0) {
                if (children.length > 1) {
                    for (const child of children) {
                        startOnNewLine(child);
                        argumentsList.push(child);
                    }
                }
                else {
                    argumentsList.push(children[0]);
                }
            }
            return setTextRange(factory2.createCallExpression(createJsxFactoryExpression(factory2, jsxFactoryEntity, reactNamespace, parentElement), 
            /*typeArguments*/
            void 0, argumentsList), location);
        }
        function createForOfBindingStatement(factory2, node, boundValue) {
            if (isVariableDeclarationList(node)) {
                const firstDeclaration = first(node.declarations);
                const updatedDeclaration = factory2.updateVariableDeclaration(firstDeclaration, firstDeclaration.name, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, boundValue);
                return setTextRange(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.updateVariableDeclarationList(node, [updatedDeclaration])), 
                /*location*/
                node);
            }
            else {
                const updatedExpression = setTextRange(factory2.createAssignment(node, boundValue), 
                /*location*/
                node);
                return setTextRange(factory2.createExpressionStatement(updatedExpression), 
                /*location*/
                node);
            }
        }
        function insertLeadingStatement(factory2, dest, source) {
            if (isBlock(dest)) {
                return factory2.updateBlock(dest, setTextRange(factory2.createNodeArray([source, ...dest.statements]), dest.statements));
            }
            else {
                return factory2.createBlock(factory2.createNodeArray([dest, source]), 
                /*multiLine*/
                true);
            }
        }
        function createExpressionFromEntityName(factory2, node) {
            if (isQualifiedName(node)) {
                const left = createExpressionFromEntityName(factory2, node.left);
                const right = setParent(setTextRange(factory2.cloneNode(node.right), node.right), node.right.parent);
                return setTextRange(factory2.createPropertyAccessExpression(left, right), node);
            }
            else {
                return setParent(setTextRange(factory2.cloneNode(node), node), node.parent);
            }
        }
        function createExpressionForPropertyName(factory2, memberName) {
            if (isIdentifier(memberName)) {
                return factory2.createStringLiteralFromNode(memberName);
            }
            else if (isComputedPropertyName(memberName)) {
                return setParent(setTextRange(factory2.cloneNode(memberName.expression), memberName.expression), memberName.expression.parent);
            }
            else {
                return setParent(setTextRange(factory2.cloneNode(memberName), memberName), memberName.parent);
            }
        }
        function createExpressionForAccessorDeclaration(factory2, properties, property, receiver, multiLine) {
            const { firstAccessor, getAccessor, setAccessor } = getAllAccessorDeclarations(properties, property);
            if (property === firstAccessor) {
                return setTextRange(factory2.createObjectDefinePropertyCall(receiver, createExpressionForPropertyName(factory2, property.name), factory2.createPropertyDescriptor({
                    enumerable: factory2.createFalse(),
                    configurable: true,
                    get: getAccessor && setTextRange(setOriginalNode(factory2.createFunctionExpression(getModifiers(getAccessor), 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, getAccessor.parameters, 
                    /*type*/
                    void 0, getAccessor.body
                    // TODO: GH#18217
                    ), getAccessor), getAccessor),
                    set: setAccessor && setTextRange(setOriginalNode(factory2.createFunctionExpression(getModifiers(setAccessor), 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, setAccessor.parameters, 
                    /*type*/
                    void 0, setAccessor.body
                    // TODO: GH#18217
                    ), setAccessor), setAccessor)
                }, !multiLine)), firstAccessor);
            }
            return void 0;
        }
        function createExpressionForPropertyAssignment(factory2, property, receiver) {
            return setOriginalNode(setTextRange(factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, property.name, 
            /*location*/
            property.name), property.initializer), property), property);
        }
        function createExpressionForShorthandPropertyAssignment(factory2, property, receiver) {
            return setOriginalNode(setTextRange(factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, property.name, 
            /*location*/
            property.name), factory2.cloneNode(property.name)), 
            /*location*/
            property), 
            /*original*/
            property);
        }
        function createExpressionForMethodDeclaration(factory2, method, receiver) {
            return setOriginalNode(setTextRange(factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, method.name, 
            /*location*/
            method.name), setOriginalNode(setTextRange(factory2.createFunctionExpression(getModifiers(method), method.asteriskToken, 
            /*name*/
            void 0, 
            /*typeParameters*/
            void 0, method.parameters, 
            /*type*/
            void 0, method.body
            // TODO: GH#18217
            ), 
            /*location*/
            method), 
            /*original*/
            method)), 
            /*location*/
            method), 
            /*original*/
            method);
        }
        function createExpressionForObjectLiteralElementLike(factory2, node, property, receiver) {
            if (property.name && isPrivateIdentifier(property.name)) {
                Debug.failBadSyntaxKind(property.name, "Private identifiers are not allowed in object literals.");
            }
            switch (property.kind) {
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    return createExpressionForAccessorDeclaration(factory2, node.properties, property, receiver, !!node.multiLine);
                case 299 /* PropertyAssignment */:
                    return createExpressionForPropertyAssignment(factory2, property, receiver);
                case 300 /* ShorthandPropertyAssignment */:
                    return createExpressionForShorthandPropertyAssignment(factory2, property, receiver);
                case 171 /* MethodDeclaration */:
                    return createExpressionForMethodDeclaration(factory2, property, receiver);
            }
        }
        function expandPreOrPostfixIncrementOrDecrementExpression(factory2, node, expression, recordTempVariable, resultVariable) {
            const operator = node.operator;
            Debug.assert(operator === 45 /* PlusPlusToken */ || operator === 46 /* MinusMinusToken */, "Expected 'node' to be a pre- or post-increment or pre- or post-decrement expression");
            const temp = factory2.createTempVariable(recordTempVariable);
            expression = factory2.createAssignment(temp, expression);
            setTextRange(expression, node.operand);
            let operation = isPrefixUnaryExpression(node) ? factory2.createPrefixUnaryExpression(operator, temp) : factory2.createPostfixUnaryExpression(temp, operator);
            setTextRange(operation, node);
            if (resultVariable) {
                operation = factory2.createAssignment(resultVariable, operation);
                setTextRange(operation, node);
            }
            expression = factory2.createComma(expression, operation);
            setTextRange(expression, node);
            if (isPostfixUnaryExpression(node)) {
                expression = factory2.createComma(expression, temp);
                setTextRange(expression, node);
            }
            return expression;
        }
        function isInternalName(node) {
            return (getEmitFlags(node) & 65536 /* InternalName */) !== 0;
        }
        function isLocalName(node) {
            return (getEmitFlags(node) & 32768 /* LocalName */) !== 0;
        }
        function isExportName(node) {
            return (getEmitFlags(node) & 16384 /* ExportName */) !== 0;
        }
        function isUseStrictPrologue(node) {
            return isStringLiteral(node.expression) && node.expression.text === "use strict";
        }
        function findUseStrictPrologue(statements) {
            for (const statement of statements) {
                if (isPrologueDirective(statement)) {
                    if (isUseStrictPrologue(statement)) {
                        return statement;
                    }
                }
                else {
                    break;
                }
            }
            return void 0;
        }
        function startsWithUseStrict(statements) {
            const firstStatement = firstOrUndefined(statements);
            return firstStatement !== void 0 && isPrologueDirective(firstStatement) && isUseStrictPrologue(firstStatement);
        }
        function isCommaExpression(node) {
            return node.kind === 223 /* BinaryExpression */ && node.operatorToken.kind === 27 /* CommaToken */;
        }
        function isCommaSequence(node) {
            return isCommaExpression(node) || isCommaListExpression(node);
        }
        function isJSDocTypeAssertion(node) {
            return isParenthesizedExpression(node) && isInJSFile(node) && !!getJSDocTypeTag(node);
        }
        function getJSDocTypeAssertionType(node) {
            const type = getJSDocType(node);
            Debug.assertIsDefined(type);
            return type;
        }
        function isOuterExpression(node, kinds = 15 /* All */) {
            switch (node.kind) {
                case 214 /* ParenthesizedExpression */:
                    if (kinds & 16 /* ExcludeJSDocTypeAssertion */ && isJSDocTypeAssertion(node)) {
                        return false;
                    }
                    return (kinds & 1 /* Parentheses */) !== 0;
                case 213 /* TypeAssertionExpression */:
                case 231 /* AsExpression */:
                case 230 /* ExpressionWithTypeArguments */:
                case 235 /* SatisfiesExpression */:
                    return (kinds & 2 /* TypeAssertions */) !== 0;
                case 232 /* NonNullExpression */:
                    return (kinds & 4 /* NonNullAssertions */) !== 0;
                case 356 /* PartiallyEmittedExpression */:
                    return (kinds & 8 /* PartiallyEmittedExpressions */) !== 0;
            }
            return false;
        }
        function skipOuterExpressions(node, kinds = 15 /* All */) {
            while (isOuterExpression(node, kinds)) {
                node = node.expression;
            }
            return node;
        }
        function walkUpOuterExpressions(node, kinds = 15 /* All */) {
            let parent2 = node.parent;
            while (isOuterExpression(parent2, kinds)) {
                parent2 = parent2.parent;
                Debug.assert(parent2);
            }
            return parent2;
        }
        function skipAssertions(node) {
            return skipOuterExpressions(node, 6 /* Assertions */);
        }
        function startOnNewLine(node) {
            return setStartsOnNewLine(node, 
            /*newLine*/
            true);
        }
        function getExternalHelpersModuleName(node) {
            const parseNode = getOriginalNode(node, isSourceFile);
            const emitNode = parseNode && parseNode.emitNode;
            return emitNode && emitNode.externalHelpersModuleName;
        }
        function hasRecordedExternalHelpers(sourceFile) {
            const parseNode = getOriginalNode(sourceFile, isSourceFile);
            const emitNode = parseNode && parseNode.emitNode;
            return !!emitNode && (!!emitNode.externalHelpersModuleName || !!emitNode.externalHelpers);
        }
        function createExternalHelpersImportDeclarationIfNeeded(nodeFactory, helperFactory, sourceFile, compilerOptions, hasExportStarsToExportValues, hasImportStar, hasImportDefault) {
            if (compilerOptions.importHelpers && isEffectiveExternalModule(sourceFile, compilerOptions)) {
                let namedBindings;
                const moduleKind = getEmitModuleKind(compilerOptions);
                if (moduleKind >= 5 /* ES2015 */ && moduleKind <= 99 /* ESNext */ || sourceFile.impliedNodeFormat === 99 /* ESNext */) {
                    const helpers = getEmitHelpers(sourceFile);
                    if (helpers) {
                        const helperNames = [];
                        for (const helper of helpers) {
                            if (!helper.scoped) {
                                const importName = helper.importName;
                                if (importName) {
                                    pushIfUnique(helperNames, importName);
                                }
                            }
                        }
                        if (some(helperNames)) {
                            helperNames.sort(compareStringsCaseSensitive);
                            namedBindings = nodeFactory.createNamedImports(map(helperNames, (name) => isFileLevelUniqueName(sourceFile, name) ? nodeFactory.createImportSpecifier(
                            /*isTypeOnly*/
                            false, 
                            /*propertyName*/
                            void 0, nodeFactory.createIdentifier(name)) : nodeFactory.createImportSpecifier(
                            /*isTypeOnly*/
                            false, nodeFactory.createIdentifier(name), helperFactory.getUnscopedHelperName(name))));
                            const parseNode = getOriginalNode(sourceFile, isSourceFile);
                            const emitNode = getOrCreateEmitNode(parseNode);
                            emitNode.externalHelpers = true;
                        }
                    }
                }
                else {
                    const externalHelpersModuleName = getOrCreateExternalHelpersModuleNameIfNeeded(nodeFactory, sourceFile, compilerOptions, hasExportStarsToExportValues, hasImportStar || hasImportDefault);
                    if (externalHelpersModuleName) {
                        namedBindings = nodeFactory.createNamespaceImport(externalHelpersModuleName);
                    }
                }
                if (namedBindings) {
                    const externalHelpersImportDeclaration = nodeFactory.createImportDeclaration(
                    /*modifiers*/
                    void 0, nodeFactory.createImportClause(
                    /*isTypeOnly*/
                    false, 
                    /*name*/
                    void 0, namedBindings), nodeFactory.createStringLiteral(externalHelpersModuleNameText), 
                    /*assertClause*/
                    void 0);
                    addInternalEmitFlags(externalHelpersImportDeclaration, 2 /* NeverApplyImportHelper */);
                    return externalHelpersImportDeclaration;
                }
            }
        }
        function getOrCreateExternalHelpersModuleNameIfNeeded(factory2, node, compilerOptions, hasExportStarsToExportValues, hasImportStarOrImportDefault) {
            if (compilerOptions.importHelpers && isEffectiveExternalModule(node, compilerOptions)) {
                const externalHelpersModuleName = getExternalHelpersModuleName(node);
                if (externalHelpersModuleName) {
                    return externalHelpersModuleName;
                }
                const moduleKind = getEmitModuleKind(compilerOptions);
                let create = (hasExportStarsToExportValues || getESModuleInterop(compilerOptions) && hasImportStarOrImportDefault) && moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || node.impliedNodeFormat === 1 /* CommonJS */);
                if (!create) {
                    const helpers = getEmitHelpers(node);
                    if (helpers) {
                        for (const helper of helpers) {
                            if (!helper.scoped) {
                                create = true;
                                break;
                            }
                        }
                    }
                }
                if (create) {
                    const parseNode = getOriginalNode(node, isSourceFile);
                    const emitNode = getOrCreateEmitNode(parseNode);
                    return emitNode.externalHelpersModuleName || (emitNode.externalHelpersModuleName = factory2.createUniqueName(externalHelpersModuleNameText));
                }
            }
        }
        function getLocalNameForExternalImport(factory2, node, sourceFile) {
            const namespaceDeclaration = getNamespaceDeclarationNode(node);
            if (namespaceDeclaration && !isDefaultImport(node) && !isExportNamespaceAsDefaultDeclaration(node)) {
                const name = namespaceDeclaration.name;
                return isGeneratedIdentifier(name) ? name : factory2.createIdentifier(getSourceTextOfNodeFromSourceFile(sourceFile, name) || idText(name));
            }
            if (node.kind === 269 /* ImportDeclaration */ && node.importClause) {
                return factory2.getGeneratedNameForNode(node);
            }
            if (node.kind === 275 /* ExportDeclaration */ && node.moduleSpecifier) {
                return factory2.getGeneratedNameForNode(node);
            }
            return void 0;
        }
        function getExternalModuleNameLiteral(factory2, importNode, sourceFile, host, resolver, compilerOptions) {
            const moduleName = getExternalModuleName(importNode);
            if (moduleName && isStringLiteral(moduleName)) {
                return tryGetModuleNameFromDeclaration(importNode, host, factory2, resolver, compilerOptions) || tryRenameExternalModule(factory2, moduleName, sourceFile) || factory2.cloneNode(moduleName);
            }
            return void 0;
        }
        function tryRenameExternalModule(factory2, moduleName, sourceFile) {
            const rename = sourceFile.renamedDependencies && sourceFile.renamedDependencies.get(moduleName.text);
            return rename ? factory2.createStringLiteral(rename) : void 0;
        }
        function tryGetModuleNameFromFile(factory2, file, host, options) {
            if (!file) {
                return void 0;
            }
            if (file.moduleName) {
                return factory2.createStringLiteral(file.moduleName);
            }
            if (!file.isDeclarationFile && outFile(options)) {
                return factory2.createStringLiteral(getExternalModuleNameFromPath(host, file.fileName));
            }
            return void 0;
        }
        function tryGetModuleNameFromDeclaration(declaration, host, factory2, resolver, compilerOptions) {
            return tryGetModuleNameFromFile(factory2, resolver.getExternalModuleFileFromDeclaration(declaration), host, compilerOptions);
        }
        function getInitializerOfBindingOrAssignmentElement(bindingElement) {
            if (isDeclarationBindingElement(bindingElement)) {
                return bindingElement.initializer;
            }
            if (isPropertyAssignment(bindingElement)) {
                const initializer = bindingElement.initializer;
                return isAssignmentExpression(initializer, 
                /*excludeCompoundAssignment*/
                true) ? initializer.right : void 0;
            }
            if (isShorthandPropertyAssignment(bindingElement)) {
                return bindingElement.objectAssignmentInitializer;
            }
            if (isAssignmentExpression(bindingElement, 
            /*excludeCompoundAssignment*/
            true)) {
                return bindingElement.right;
            }
            if (isSpreadElement(bindingElement)) {
                return getInitializerOfBindingOrAssignmentElement(bindingElement.expression);
            }
        }
        function getTargetOfBindingOrAssignmentElement(bindingElement) {
            if (isDeclarationBindingElement(bindingElement)) {
                return bindingElement.name;
            }
            if (isObjectLiteralElementLike(bindingElement)) {
                switch (bindingElement.kind) {
                    case 299 /* PropertyAssignment */:
                        return getTargetOfBindingOrAssignmentElement(bindingElement.initializer);
                    case 300 /* ShorthandPropertyAssignment */:
                        return bindingElement.name;
                    case 301 /* SpreadAssignment */:
                        return getTargetOfBindingOrAssignmentElement(bindingElement.expression);
                }
                return void 0;
            }
            if (isAssignmentExpression(bindingElement, 
            /*excludeCompoundAssignment*/
            true)) {
                return getTargetOfBindingOrAssignmentElement(bindingElement.left);
            }
            if (isSpreadElement(bindingElement)) {
                return getTargetOfBindingOrAssignmentElement(bindingElement.expression);
            }
            return bindingElement;
        }
        function getRestIndicatorOfBindingOrAssignmentElement(bindingElement) {
            switch (bindingElement.kind) {
                case 166 /* Parameter */:
                case 205 /* BindingElement */:
                    return bindingElement.dotDotDotToken;
                case 227 /* SpreadElement */:
                case 301 /* SpreadAssignment */:
                    return bindingElement;
            }
            return void 0;
        }
        function getPropertyNameOfBindingOrAssignmentElement(bindingElement) {
            const propertyName = tryGetPropertyNameOfBindingOrAssignmentElement(bindingElement);
            Debug.assert(!!propertyName || isSpreadAssignment(bindingElement), "Invalid property name for binding element.");
            return propertyName;
        }
        function tryGetPropertyNameOfBindingOrAssignmentElement(bindingElement) {
            switch (bindingElement.kind) {
                case 205 /* BindingElement */:
                    if (bindingElement.propertyName) {
                        const propertyName = bindingElement.propertyName;
                        if (isPrivateIdentifier(propertyName)) {
                            return Debug.failBadSyntaxKind(propertyName);
                        }
                        return isComputedPropertyName(propertyName) && isStringOrNumericLiteral(propertyName.expression) ? propertyName.expression : propertyName;
                    }
                    break;
                case 299 /* PropertyAssignment */:
                    if (bindingElement.name) {
                        const propertyName = bindingElement.name;
                        if (isPrivateIdentifier(propertyName)) {
                            return Debug.failBadSyntaxKind(propertyName);
                        }
                        return isComputedPropertyName(propertyName) && isStringOrNumericLiteral(propertyName.expression) ? propertyName.expression : propertyName;
                    }
                    break;
                case 301 /* SpreadAssignment */:
                    if (bindingElement.name && isPrivateIdentifier(bindingElement.name)) {
                        return Debug.failBadSyntaxKind(bindingElement.name);
                    }
                    return bindingElement.name;
            }
            const target = getTargetOfBindingOrAssignmentElement(bindingElement);
            if (target && isPropertyName(target)) {
                return target;
            }
        }
        function isStringOrNumericLiteral(node) {
            const kind = node.kind;
            return kind === 10 /* StringLiteral */ || kind === 8 /* NumericLiteral */;
        }
        function getElementsOfBindingOrAssignmentPattern(name) {
            switch (name.kind) {
                case 203 /* ObjectBindingPattern */:
                case 204 /* ArrayBindingPattern */:
                case 206 /* ArrayLiteralExpression */:
                    return name.elements;
                case 207 /* ObjectLiteralExpression */:
                    return name.properties;
            }
        }
        function getJSDocTypeAliasName(fullName) {
            if (fullName) {
                let rightNode = fullName;
                while (true) {
                    if (isIdentifier(rightNode) || !rightNode.body) {
                        return isIdentifier(rightNode) ? rightNode : rightNode.name;
                    }
                    rightNode = rightNode.body;
                }
            }
        }
        function canHaveIllegalType(node) {
            const kind = node.kind;
            return kind === 173 /* Constructor */ || kind === 175 /* SetAccessor */;
        }
        function canHaveIllegalTypeParameters(node) {
            const kind = node.kind;
            return kind === 173 /* Constructor */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */;
        }
        function canHaveIllegalDecorators(node) {
            const kind = node.kind;
            return kind === 299 /* PropertyAssignment */ || kind === 300 /* ShorthandPropertyAssignment */ || kind === 259 /* FunctionDeclaration */ || kind === 173 /* Constructor */ || kind === 178 /* IndexSignature */ || kind === 172 /* ClassStaticBlockDeclaration */ || kind === 279 /* MissingDeclaration */ || kind === 240 /* VariableStatement */ || kind === 261 /* InterfaceDeclaration */ || kind === 262 /* TypeAliasDeclaration */ || kind === 263 /* EnumDeclaration */ || kind === 264 /* ModuleDeclaration */ || kind === 268 /* ImportEqualsDeclaration */ || kind === 269 /* ImportDeclaration */ || kind === 267 /* NamespaceExportDeclaration */ || kind === 275 /* ExportDeclaration */ || kind === 274 /* ExportAssignment */;
        }
        function canHaveIllegalModifiers(node) {
            const kind = node.kind;
            return kind === 172 /* ClassStaticBlockDeclaration */ || kind === 299 /* PropertyAssignment */ || kind === 300 /* ShorthandPropertyAssignment */ || kind === 279 /* MissingDeclaration */ || kind === 267 /* NamespaceExportDeclaration */;
        }
        function isQuestionOrExclamationToken(node) {
            return isQuestionToken(node) || isExclamationToken(node);
        }
        function isIdentifierOrThisTypeNode(node) {
            return isIdentifier(node) || isThisTypeNode(node);
        }
        function isReadonlyKeywordOrPlusOrMinusToken(node) {
            return isReadonlyKeyword(node) || isPlusToken(node) || isMinusToken(node);
        }
        function isQuestionOrPlusOrMinusToken(node) {
            return isQuestionToken(node) || isPlusToken(node) || isMinusToken(node);
        }
        function isModuleName(node) {
            return isIdentifier(node) || isStringLiteral(node);
        }
        function isLiteralTypeLikeExpression(node) {
            const kind = node.kind;
            return kind === 104 /* NullKeyword */ || kind === 110 /* TrueKeyword */ || kind === 95 /* FalseKeyword */ || isLiteralExpression(node) || isPrefixUnaryExpression(node);
        }
        function isExponentiationOperator(kind) {
            return kind === 42 /* AsteriskAsteriskToken */;
        }
        function isMultiplicativeOperator(kind) {
            return kind === 41 /* AsteriskToken */ || kind === 43 /* SlashToken */ || kind === 44 /* PercentToken */;
        }
        function isMultiplicativeOperatorOrHigher(kind) {
            return isExponentiationOperator(kind) || isMultiplicativeOperator(kind);
        }
        function isAdditiveOperator(kind) {
            return kind === 39 /* PlusToken */ || kind === 40 /* MinusToken */;
        }
        function isAdditiveOperatorOrHigher(kind) {
            return isAdditiveOperator(kind) || isMultiplicativeOperatorOrHigher(kind);
        }
        function isShiftOperator(kind) {
            return kind === 47 /* LessThanLessThanToken */ || kind === 48 /* GreaterThanGreaterThanToken */ || kind === 49 /* GreaterThanGreaterThanGreaterThanToken */;
        }
        function isShiftOperatorOrHigher(kind) {
            return isShiftOperator(kind) || isAdditiveOperatorOrHigher(kind);
        }
        function isRelationalOperator(kind) {
            return kind === 29 /* LessThanToken */ || kind === 32 /* LessThanEqualsToken */ || kind === 31 /* GreaterThanToken */ || kind === 33 /* GreaterThanEqualsToken */ || kind === 102 /* InstanceOfKeyword */ || kind === 101 /* InKeyword */;
        }
        function isRelationalOperatorOrHigher(kind) {
            return isRelationalOperator(kind) || isShiftOperatorOrHigher(kind);
        }
        function isEqualityOperator(kind) {
            return kind === 34 /* EqualsEqualsToken */ || kind === 36 /* EqualsEqualsEqualsToken */ || kind === 35 /* ExclamationEqualsToken */ || kind === 37 /* ExclamationEqualsEqualsToken */;
        }
        function isEqualityOperatorOrHigher(kind) {
            return isEqualityOperator(kind) || isRelationalOperatorOrHigher(kind);
        }
        function isBitwiseOperator(kind) {
            return kind === 50 /* AmpersandToken */ || kind === 51 /* BarToken */ || kind === 52 /* CaretToken */;
        }
        function isBitwiseOperatorOrHigher(kind) {
            return isBitwiseOperator(kind) || isEqualityOperatorOrHigher(kind);
        }
        function isLogicalOperator2(kind) {
            return kind === 55 /* AmpersandAmpersandToken */ || kind === 56 /* BarBarToken */;
        }
        function isLogicalOperatorOrHigher(kind) {
            return isLogicalOperator2(kind) || isBitwiseOperatorOrHigher(kind);
        }
        function isAssignmentOperatorOrHigher(kind) {
            return kind === 60 /* QuestionQuestionToken */ || isLogicalOperatorOrHigher(kind) || isAssignmentOperator(kind);
        }
        function isBinaryOperator(kind) {
            return isAssignmentOperatorOrHigher(kind) || kind === 27 /* CommaToken */;
        }
        function isBinaryOperatorToken(node) {
            return isBinaryOperator(node.kind);
        }
        function createBinaryExpressionTrampoline(onEnter, onLeft, onOperator, onRight, onExit, foldState) {
            const machine = new BinaryExpressionStateMachine(onEnter, onLeft, onOperator, onRight, onExit, foldState);
            return trampoline;
            function trampoline(node, outerState) {
                const resultHolder = { value: void 0 };
                const stateStack = [BinaryExpressionState.enter];
                const nodeStack = [node];
                const userStateStack = [void 0];
                let stackIndex = 0;
                while (stateStack[stackIndex] !== BinaryExpressionState.done) {
                    stackIndex = stateStack[stackIndex](machine, stackIndex, stateStack, nodeStack, userStateStack, resultHolder, outerState);
                }
                Debug.assertEqual(stackIndex, 0);
                return resultHolder.value;
            }
        }
        function isExportOrDefaultKeywordKind(kind) {
            return kind === 93 /* ExportKeyword */ || kind === 88 /* DefaultKeyword */;
        }
        function isExportOrDefaultModifier(node) {
            const kind = node.kind;
            return isExportOrDefaultKeywordKind(kind);
        }
        function isNonExportDefaultModifier(node) {
            const kind = node.kind;
            return isModifierKind(kind) && !isExportOrDefaultKeywordKind(kind);
        }
        function elideNodes(factory2, nodes) {
            if (nodes === void 0)
                return void 0;
            if (nodes.length === 0)
                return nodes;
            return setTextRange(factory2.createNodeArray([], nodes.hasTrailingComma), nodes);
        }
        function getNodeForGeneratedName(name) {
            var _a2;
            const autoGenerate = name.emitNode.autoGenerate;
            if (autoGenerate.flags & 4 /* Node */) {
                const autoGenerateId = autoGenerate.id;
                let node = name;
                let original = node.original;
                while (original) {
                    node = original;
                    const autoGenerate2 = (_a2 = node.emitNode) == null ? void 0 : _a2.autoGenerate;
                    if (isMemberName(node) && (autoGenerate2 === void 0 || !!(autoGenerate2.flags & 4 /* Node */) && autoGenerate2.id !== autoGenerateId)) {
                        break;
                    }
                    original = node.original;
                }
                return node;
            }
            return name;
        }
        function formatGeneratedNamePart(part, generateName) {
            return typeof part === "object" ? formatGeneratedName(
            /*privateName*/
            false, part.prefix, part.node, part.suffix, generateName) : typeof part === "string" ? part.length > 0 && part.charCodeAt(0) === 35 /* hash */ ? part.slice(1) : part : "";
        }
        function formatIdentifier(name, generateName) {
            return typeof name === "string" ? name : formatIdentifierWorker(name, Debug.checkDefined(generateName));
        }
        function formatIdentifierWorker(node, generateName) {
            return isGeneratedPrivateIdentifier(node) ? generateName(node).slice(1) : isGeneratedIdentifier(node) ? generateName(node) : isPrivateIdentifier(node) ? node.escapedText.slice(1) : idText(node);
        }
        function formatGeneratedName(privateName, prefix, baseName, suffix, generateName) {
            prefix = formatGeneratedNamePart(prefix, generateName);
            suffix = formatGeneratedNamePart(suffix, generateName);
            baseName = formatIdentifier(baseName, generateName);
            return `${privateName ? "#" : ""}${prefix}${baseName}${suffix}`;
        }
        function createAccessorPropertyBackingField(factory2, node, modifiers, initializer) {
            return factory2.updatePropertyDeclaration(node, modifiers, factory2.getGeneratedPrivateNameForNode(node.name, 
            /*prefix*/
            void 0, "_accessor_storage"), 
            /*questionOrExclamationToken*/
            void 0, 
            /*type*/
            void 0, initializer);
        }
        function createAccessorPropertyGetRedirector(factory2, node, modifiers, name) {
            return factory2.createGetAccessorDeclaration(modifiers, name, [], 
            /*type*/
            void 0, factory2.createBlock([
                factory2.createReturnStatement(factory2.createPropertyAccessExpression(factory2.createThis(), factory2.getGeneratedPrivateNameForNode(node.name, 
                /*prefix*/
                void 0, "_accessor_storage")))
            ]));
        }
        function createAccessorPropertySetRedirector(factory2, node, modifiers, name) {
            return factory2.createSetAccessorDeclaration(modifiers, name, [factory2.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotdotDotToken*/
                void 0, "value")], factory2.createBlock([
                factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createThis(), factory2.getGeneratedPrivateNameForNode(node.name, 
                /*prefix*/
                void 0, "_accessor_storage")), factory2.createIdentifier("value")))
            ]));
        }
        function findComputedPropertyNameCacheAssignment(name) {
            let node = name.expression;
            while (true) {
                node = skipOuterExpressions(node);
                if (isCommaListExpression(node)) {
                    node = last(node.elements);
                    continue;
                }
                if (isCommaExpression(node)) {
                    node = node.right;
                    continue;
                }
                if (isAssignmentExpression(node, 
                /*excludeCompoundAssignment*/
                true) && isGeneratedIdentifier(node.left)) {
                    return node;
                }
                break;
            }
        }
        function isSyntheticParenthesizedExpression(node) {
            return isParenthesizedExpression(node) && nodeIsSynthesized(node) && !node.emitNode;
        }
        function flattenCommaListWorker(node, expressions) {
            if (isSyntheticParenthesizedExpression(node)) {
                flattenCommaListWorker(node.expression, expressions);
            }
            else if (isCommaExpression(node)) {
                flattenCommaListWorker(node.left, expressions);
                flattenCommaListWorker(node.right, expressions);
            }
            else if (isCommaListExpression(node)) {
                for (const child of node.elements) {
                    flattenCommaListWorker(child, expressions);
                }
            }
            else {
                expressions.push(node);
            }
        }
        function flattenCommaList(node) {
            const expressions = [];
            flattenCommaListWorker(node, expressions);
            return expressions;
        }
        function containsObjectRestOrSpread(node) {
            if (node.transformFlags & 65536 /* ContainsObjectRestOrSpread */)
                return true;
            if (node.transformFlags & 128 /* ContainsES2018 */) {
                for (const element of getElementsOfBindingOrAssignmentPattern(node)) {
                    const target = getTargetOfBindingOrAssignmentElement(element);
                    if (target && isAssignmentPattern(target)) {
                        if (target.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                            return true;
                        }
                        if (target.transformFlags & 128 /* ContainsES2018 */) {
                            if (containsObjectRestOrSpread(target))
                                return true;
                        }
                    }
                }
            }
            return false;
        }
        var BinaryExpressionState, BinaryExpressionStateMachine;
        var init_utilities2 = __esm({
            "src/compiler/factory/utilities.ts"() {
                "use strict";
                init_ts2();
                ((BinaryExpressionState2) => {
                    function enter(machine, stackIndex, stateStack, nodeStack, userStateStack, _resultHolder, outerState) {
                        const prevUserState = stackIndex > 0 ? userStateStack[stackIndex - 1] : void 0;
                        Debug.assertEqual(stateStack[stackIndex], enter);
                        userStateStack[stackIndex] = machine.onEnter(nodeStack[stackIndex], prevUserState, outerState);
                        stateStack[stackIndex] = nextState(machine, enter);
                        return stackIndex;
                    }
                    BinaryExpressionState2.enter = enter;
                    function left(machine, stackIndex, stateStack, nodeStack, userStateStack, _resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], left);
                        Debug.assertIsDefined(machine.onLeft);
                        stateStack[stackIndex] = nextState(machine, left);
                        const nextNode = machine.onLeft(nodeStack[stackIndex].left, userStateStack[stackIndex], nodeStack[stackIndex]);
                        if (nextNode) {
                            checkCircularity(stackIndex, nodeStack, nextNode);
                            return pushStack(stackIndex, stateStack, nodeStack, userStateStack, nextNode);
                        }
                        return stackIndex;
                    }
                    BinaryExpressionState2.left = left;
                    function operator(machine, stackIndex, stateStack, nodeStack, userStateStack, _resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], operator);
                        Debug.assertIsDefined(machine.onOperator);
                        stateStack[stackIndex] = nextState(machine, operator);
                        machine.onOperator(nodeStack[stackIndex].operatorToken, userStateStack[stackIndex], nodeStack[stackIndex]);
                        return stackIndex;
                    }
                    BinaryExpressionState2.operator = operator;
                    function right(machine, stackIndex, stateStack, nodeStack, userStateStack, _resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], right);
                        Debug.assertIsDefined(machine.onRight);
                        stateStack[stackIndex] = nextState(machine, right);
                        const nextNode = machine.onRight(nodeStack[stackIndex].right, userStateStack[stackIndex], nodeStack[stackIndex]);
                        if (nextNode) {
                            checkCircularity(stackIndex, nodeStack, nextNode);
                            return pushStack(stackIndex, stateStack, nodeStack, userStateStack, nextNode);
                        }
                        return stackIndex;
                    }
                    BinaryExpressionState2.right = right;
                    function exit(machine, stackIndex, stateStack, nodeStack, userStateStack, resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], exit);
                        stateStack[stackIndex] = nextState(machine, exit);
                        const result = machine.onExit(nodeStack[stackIndex], userStateStack[stackIndex]);
                        if (stackIndex > 0) {
                            stackIndex--;
                            if (machine.foldState) {
                                const side = stateStack[stackIndex] === exit ? "right" : "left";
                                userStateStack[stackIndex] = machine.foldState(userStateStack[stackIndex], result, side);
                            }
                        }
                        else {
                            resultHolder.value = result;
                        }
                        return stackIndex;
                    }
                    BinaryExpressionState2.exit = exit;
                    function done(_machine, stackIndex, stateStack, _nodeStack, _userStateStack, _resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], done);
                        return stackIndex;
                    }
                    BinaryExpressionState2.done = done;
                    function nextState(machine, currentState) {
                        switch (currentState) {
                            case enter:
                                if (machine.onLeft)
                                    return left;
                            case left:
                                if (machine.onOperator)
                                    return operator;
                            case operator:
                                if (machine.onRight)
                                    return right;
                            case right:
                                return exit;
                            case exit:
                                return done;
                            case done:
                                return done;
                            default:
                                Debug.fail("Invalid state");
                        }
                    }
                    BinaryExpressionState2.nextState = nextState;
                    function pushStack(stackIndex, stateStack, nodeStack, userStateStack, node) {
                        stackIndex++;
                        stateStack[stackIndex] = enter;
                        nodeStack[stackIndex] = node;
                        userStateStack[stackIndex] = void 0;
                        return stackIndex;
                    }
                    function checkCircularity(stackIndex, nodeStack, node) {
                        if (Debug.shouldAssert(2 /* Aggressive */)) {
                            while (stackIndex >= 0) {
                                Debug.assert(nodeStack[stackIndex] !== node, "Circular traversal detected.");
                                stackIndex--;
                            }
                        }
                    }
                })(BinaryExpressionState || (BinaryExpressionState = {}));
                BinaryExpressionStateMachine = class {
                    constructor(onEnter, onLeft, onOperator, onRight, onExit, foldState) {
                        this.onEnter = onEnter;
                        this.onLeft = onLeft;
                        this.onOperator = onOperator;
                        this.onRight = onRight;
                        this.onExit = onExit;
                        this.foldState = foldState;
                    }
                };
            }
        });
        // src/compiler/factory/utilitiesPublic.ts
        function setTextRange(range, location) {
            return location ? setTextRangePosEnd(range, location.pos, location.end) : range;
        }
        function canHaveModifiers(node) {
            const kind = node.kind;
            return kind === 165 /* TypeParameter */ || kind === 166 /* Parameter */ || kind === 168 /* PropertySignature */ || kind === 169 /* PropertyDeclaration */ || kind === 170 /* MethodSignature */ || kind === 171 /* MethodDeclaration */ || kind === 173 /* Constructor */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */ || kind === 178 /* IndexSignature */ || kind === 182 /* ConstructorType */ || kind === 215 /* FunctionExpression */ || kind === 216 /* ArrowFunction */ || kind === 228 /* ClassExpression */ || kind === 240 /* VariableStatement */ || kind === 259 /* FunctionDeclaration */ || kind === 260 /* ClassDeclaration */ || kind === 261 /* InterfaceDeclaration */ || kind === 262 /* TypeAliasDeclaration */ || kind === 263 /* EnumDeclaration */ || kind === 264 /* ModuleDeclaration */ || kind === 268 /* ImportEqualsDeclaration */ || kind === 269 /* ImportDeclaration */ || kind === 274 /* ExportAssignment */ || kind === 275 /* ExportDeclaration */;
        }
        function canHaveDecorators(node) {
            const kind = node.kind;
            return kind === 166 /* Parameter */ || kind === 169 /* PropertyDeclaration */ || kind === 171 /* MethodDeclaration */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */ || kind === 228 /* ClassExpression */ || kind === 260 /* ClassDeclaration */;
        }
        var init_utilitiesPublic2 = __esm({
            "src/compiler/factory/utilitiesPublic.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/parser.ts
        function visitNode2(cbNode, node) {
            return node && cbNode(node);
        }
        function visitNodes(cbNode, cbNodes, nodes) {
            if (nodes) {
                if (cbNodes) {
                    return cbNodes(nodes);
                }
                for (const node of nodes) {
                    const result = cbNode(node);
                    if (result) {
                        return result;
                    }
                }
            }
        }
        function isJSDocLikeText(text, start) {
            return text.charCodeAt(start + 1) === 42 /* asterisk */ && text.charCodeAt(start + 2) === 42 /* asterisk */ && text.charCodeAt(start + 3) !== 47 /* slash */;
        }
        function isFileProbablyExternalModule(sourceFile) {
            return forEach(sourceFile.statements, isAnExternalModuleIndicatorNode) || getImportMetaIfNecessary(sourceFile);
        }
        function isAnExternalModuleIndicatorNode(node) {
            return canHaveModifiers(node) && hasModifierOfKind(node, 93 /* ExportKeyword */) || isImportEqualsDeclaration(node) && isExternalModuleReference(node.moduleReference) || isImportDeclaration(node) || isExportAssignment(node) || isExportDeclaration(node) ? node : void 0;
        }
        function getImportMetaIfNecessary(sourceFile) {
            return sourceFile.flags & 4194304 /* PossiblyContainsImportMeta */ ? walkTreeForImportMeta(sourceFile) : void 0;
        }
        function walkTreeForImportMeta(node) {
            return isImportMeta2(node) ? node : forEachChild(node, walkTreeForImportMeta);
        }
        function hasModifierOfKind(node, kind) {
            return some(node.modifiers, (m) => m.kind === kind);
        }
        function isImportMeta2(node) {
            return isMetaProperty(node) && node.keywordToken === 100 /* ImportKeyword */ && node.name.escapedText === "meta";
        }
        function forEachChildInCallOrConstructSignature(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
        }
        function forEachChildInUnionOrIntersectionType(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.types);
        }
        function forEachChildInParenthesizedTypeOrTypeOperator(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.type);
        }
        function forEachChildInObjectOrArrayBindingPattern(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.elements);
        }
        function forEachChildInCallOrNewExpression(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.expression) || // TODO: should we separate these branches out?
                visitNode2(cbNode, node.questionDotToken) || visitNodes(cbNode, cbNodes, node.typeArguments) || visitNodes(cbNode, cbNodes, node.arguments);
        }
        function forEachChildInBlock(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.statements);
        }
        function forEachChildInContinueOrBreakStatement(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.label);
        }
        function forEachChildInClassDeclarationOrExpression(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.heritageClauses) || visitNodes(cbNode, cbNodes, node.members);
        }
        function forEachChildInNamedImportsOrExports(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.elements);
        }
        function forEachChildInImportOrExportSpecifier(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.propertyName) || visitNode2(cbNode, node.name);
        }
        function forEachChildInJsxOpeningOrSelfClosingElement(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.tagName) || visitNodes(cbNode, cbNodes, node.typeArguments) || visitNode2(cbNode, node.attributes);
        }
        function forEachChildInOptionalRestOrJSDocParameterModifier(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.type);
        }
        function forEachChildInJSDocParameterOrPropertyTag(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.tagName) || (node.isNameFirst ? visitNode2(cbNode, node.name) || visitNode2(cbNode, node.typeExpression) : visitNode2(cbNode, node.typeExpression) || visitNode2(cbNode, node.name)) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
        }
        function forEachChildInJSDocTypeLikeTag(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.typeExpression) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
        }
        function forEachChildInJSDocLinkCodeOrPlain(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.name);
        }
        function forEachChildInJSDocTag(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.tagName) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
        }
        function forEachChildInPartiallyEmittedExpression(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.expression);
        }
        function forEachChild(node, cbNode, cbNodes) {
            if (node === void 0 || node.kind <= 162 /* LastToken */) {
                return;
            }
            const fn = forEachChildTable[node.kind];
            return fn === void 0 ? void 0 : fn(node, cbNode, cbNodes);
        }
        function forEachChildRecursively(rootNode, cbNode, cbNodes) {
            const queue = gatherPossibleChildren(rootNode);
            const parents = [];
            while (parents.length < queue.length) {
                parents.push(rootNode);
            }
            while (queue.length !== 0) {
                const current = queue.pop();
                const parent2 = parents.pop();
                if (isArray(current)) {
                    if (cbNodes) {
                        const res = cbNodes(current, parent2);
                        if (res) {
                            if (res === "skip")
                                continue;
                            return res;
                        }
                    }
                    for (let i = current.length - 1; i >= 0; --i) {
                        queue.push(current[i]);
                        parents.push(parent2);
                    }
                }
                else {
                    const res = cbNode(current, parent2);
                    if (res) {
                        if (res === "skip")
                            continue;
                        return res;
                    }
                    if (current.kind >= 163 /* FirstNode */) {
                        for (const child of gatherPossibleChildren(current)) {
                            queue.push(child);
                            parents.push(current);
                        }
                    }
                }
            }
        }
        function gatherPossibleChildren(node) {
            const children = [];
            forEachChild(node, addWorkItem, addWorkItem);
            return children;
            function addWorkItem(n) {
                children.unshift(n);
            }
        }
        function setExternalModuleIndicator(sourceFile) {
            sourceFile.externalModuleIndicator = isFileProbablyExternalModule(sourceFile);
        }
        function createSourceFile(fileName, sourceText, languageVersionOrOptions, setParentNodes = false, scriptKind) {
            var _a2, _b;
            (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Parse, "createSourceFile", { path: fileName }, 
            /*separateBeginAndEnd*/
            true);
            mark("beforeParse");
            let result;
            perfLogger.logStartParseSourceFile(fileName);
            const { languageVersion, setExternalModuleIndicator: overrideSetExternalModuleIndicator, impliedNodeFormat: format } = typeof languageVersionOrOptions === "object" ? languageVersionOrOptions : { languageVersion: languageVersionOrOptions };
            if (languageVersion === 100 /* JSON */) {
                result = Parser.parseSourceFile(fileName, sourceText, languageVersion, 
                /*syntaxCursor*/
                void 0, setParentNodes, 6 /* JSON */, noop);
            }
            else {
                const setIndicator = format === void 0 ? overrideSetExternalModuleIndicator : (file) => {
                    file.impliedNodeFormat = format;
                    return (overrideSetExternalModuleIndicator || setExternalModuleIndicator)(file);
                };
                result = Parser.parseSourceFile(fileName, sourceText, languageVersion, 
                /*syntaxCursor*/
                void 0, setParentNodes, scriptKind, setIndicator);
            }
            perfLogger.logStopParseSourceFile();
            mark("afterParse");
            measure("Parse", "beforeParse", "afterParse");
            (_b = tracing) == null ? void 0 : _b.pop();
            return result;
        }
        function parseIsolatedEntityName(text, languageVersion) {
            return Parser.parseIsolatedEntityName(text, languageVersion);
        }
        function parseJsonText(fileName, sourceText) {
            return Parser.parseJsonText(fileName, sourceText);
        }
        function isExternalModule(file) {
            return file.externalModuleIndicator !== void 0;
        }
        function updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks = false) {
            const newSourceFile = IncrementalParser.updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks);
            newSourceFile.flags |= sourceFile.flags & 6291456 /* PermanentlySetIncrementalFlags */;
            return newSourceFile;
        }
        function parseIsolatedJSDocComment(content, start, length2) {
            const result = Parser.JSDocParser.parseIsolatedJSDocComment(content, start, length2);
            if (result && result.jsDoc) {
                Parser.fixupParentReferences(result.jsDoc);
            }
            return result;
        }
        function parseJSDocTypeExpressionForTests(content, start, length2) {
            return Parser.JSDocParser.parseJSDocTypeExpressionForTests(content, start, length2);
        }
        function isDeclarationFileName(fileName) {
            return fileExtensionIsOneOf(fileName, supportedDeclarationExtensions) || fileExtensionIs(fileName, ".ts" /* Ts */) && stringContains(getBaseFileName(fileName), ".d.");
        }
        function parseResolutionMode(mode, pos, end, reportDiagnostic) {
            if (!mode) {
                return void 0;
            }
            if (mode === "import") {
                return 99 /* ESNext */;
            }
            if (mode === "require") {
                return 1 /* CommonJS */;
            }
            reportDiagnostic(pos, end - pos, Diagnostics.resolution_mode_should_be_either_require_or_import);
            return void 0;
        }
        function processCommentPragmas(context, sourceText) {
            const pragmas = [];
            for (const range of getLeadingCommentRanges(sourceText, 0) || emptyArray) {
                const comment = sourceText.substring(range.pos, range.end);
                extractPragmas(pragmas, range, comment);
            }
            context.pragmas = /* @__PURE__ */ new Map();
            for (const pragma of pragmas) {
                if (context.pragmas.has(pragma.name)) {
                    const currentValue = context.pragmas.get(pragma.name);
                    if (currentValue instanceof Array) {
                        currentValue.push(pragma.args);
                    }
                    else {
                        context.pragmas.set(pragma.name, [currentValue, pragma.args]);
                    }
                    continue;
                }
                context.pragmas.set(pragma.name, pragma.args);
            }
        }
        function processPragmasIntoFields(context, reportDiagnostic) {
            context.checkJsDirective = void 0;
            context.referencedFiles = [];
            context.typeReferenceDirectives = [];
            context.libReferenceDirectives = [];
            context.amdDependencies = [];
            context.hasNoDefaultLib = false;
            context.pragmas.forEach((entryOrList, key) => {
                switch (key) {
                    case "reference": {
                        const referencedFiles = context.referencedFiles;
                        const typeReferenceDirectives = context.typeReferenceDirectives;
                        const libReferenceDirectives = context.libReferenceDirectives;
                        forEach(toArray(entryOrList), (arg) => {
                            const { types, lib, path, ["resolution-mode"]: res } = arg.arguments;
                            if (arg.arguments["no-default-lib"]) {
                                context.hasNoDefaultLib = true;
                            }
                            else if (types) {
                                const parsed = parseResolutionMode(res, types.pos, types.end, reportDiagnostic);
                                typeReferenceDirectives.push({ pos: types.pos, end: types.end, fileName: types.value, ...parsed ? { resolutionMode: parsed } : {} });
                            }
                            else if (lib) {
                                libReferenceDirectives.push({ pos: lib.pos, end: lib.end, fileName: lib.value });
                            }
                            else if (path) {
                                referencedFiles.push({ pos: path.pos, end: path.end, fileName: path.value });
                            }
                            else {
                                reportDiagnostic(arg.range.pos, arg.range.end - arg.range.pos, Diagnostics.Invalid_reference_directive_syntax);
                            }
                        });
                        break;
                    }
                    case "amd-dependency": {
                        context.amdDependencies = map(toArray(entryOrList), (x) => ({ name: x.arguments.name, path: x.arguments.path }));
                        break;
                    }
                    case "amd-module": {
                        if (entryOrList instanceof Array) {
                            for (const entry of entryOrList) {
                                if (context.moduleName) {
                                    reportDiagnostic(entry.range.pos, entry.range.end - entry.range.pos, Diagnostics.An_AMD_module_cannot_have_multiple_name_assignments);
                                }
                                context.moduleName = entry.arguments.name;
                            }
                        }
                        else {
                            context.moduleName = entryOrList.arguments.name;
                        }
                        break;
                    }
                    case "ts-nocheck":
                    case "ts-check": {
                        forEach(toArray(entryOrList), (entry) => {
                            if (!context.checkJsDirective || entry.range.pos > context.checkJsDirective.pos) {
                                context.checkJsDirective = {
                                    enabled: key === "ts-check",
                                    end: entry.range.end,
                                    pos: entry.range.pos
                                };
                            }
                        });
                        break;
                    }
                    case "jsx":
                    case "jsxfrag":
                    case "jsximportsource":
                    case "jsxruntime":
                        return;
                    default:
                        Debug.fail("Unhandled pragma kind");
                }
            });
        }
        function getNamedArgRegEx(name) {
            if (namedArgRegExCache.has(name)) {
                return namedArgRegExCache.get(name);
            }
            const result = new RegExp(`(\\s${name}\\s*=\\s*)(?:(?:'([^']*)')|(?:"([^"]*)"))`, "im");
            namedArgRegExCache.set(name, result);
            return result;
        }
        function extractPragmas(pragmas, range, text) {
            const tripleSlash = range.kind === 2 /* SingleLineCommentTrivia */ && tripleSlashXMLCommentStartRegEx.exec(text);
            if (tripleSlash) {
                const name = tripleSlash[1].toLowerCase();
                const pragma = commentPragmas[name];
                if (!pragma || !(pragma.kind & 1 /* TripleSlashXML */)) {
                    return;
                }
                if (pragma.args) {
                    const argument = {};
                    for (const arg of pragma.args) {
                        const matcher = getNamedArgRegEx(arg.name);
                        const matchResult = matcher.exec(text);
                        if (!matchResult && !arg.optional) {
                            return;
                        }
                        else if (matchResult) {
                            const value = matchResult[2] || matchResult[3];
                            if (arg.captureSpan) {
                                const startPos = range.pos + matchResult.index + matchResult[1].length + 1;
                                argument[arg.name] = {
                                    value,
                                    pos: startPos,
                                    end: startPos + value.length
                                };
                            }
                            else {
                                argument[arg.name] = value;
                            }
                        }
                    }
                    pragmas.push({ name, args: { arguments: argument, range } });
                }
                else {
                    pragmas.push({ name, args: { arguments: {}, range } });
                }
                return;
            }
            const singleLine = range.kind === 2 /* SingleLineCommentTrivia */ && singleLinePragmaRegEx.exec(text);
            if (singleLine) {
                return addPragmaForMatch(pragmas, range, 2 /* SingleLine */, singleLine);
            }
            if (range.kind === 3 /* MultiLineCommentTrivia */) {
                const multiLinePragmaRegEx = /@(\S+)(\s+.*)?$/gim;
                let multiLineMatch;
                while (multiLineMatch = multiLinePragmaRegEx.exec(text)) {
                    addPragmaForMatch(pragmas, range, 4 /* MultiLine */, multiLineMatch);
                }
            }
        }
        function addPragmaForMatch(pragmas, range, kind, match) {
            if (!match)
                return;
            const name = match[1].toLowerCase();
            const pragma = commentPragmas[name];
            if (!pragma || !(pragma.kind & kind)) {
                return;
            }
            const args = match[2];
            const argument = getNamedPragmaArguments(pragma, args);
            if (argument === "fail")
                return;
            pragmas.push({ name, args: { arguments: argument, range } });
            return;
        }
        function getNamedPragmaArguments(pragma, text) {
            if (!text)
                return {};
            if (!pragma.args)
                return {};
            const args = trimString(text).split(/\s+/);
            const argMap = {};
            for (let i = 0; i < pragma.args.length; i++) {
                const argument = pragma.args[i];
                if (!args[i] && !argument.optional) {
                    return "fail";
                }
                if (argument.captureSpan) {
                    return Debug.fail("Capture spans not yet implemented for non-xml pragmas");
                }
                argMap[argument.name] = args[i];
            }
            return argMap;
        }
        function tagNamesAreEquivalent(lhs, rhs) {
            if (lhs.kind !== rhs.kind) {
                return false;
            }
            if (lhs.kind === 79 /* Identifier */) {
                return lhs.escapedText === rhs.escapedText;
            }
            if (lhs.kind === 108 /* ThisKeyword */) {
                return true;
            }
            return lhs.name.escapedText === rhs.name.escapedText && tagNamesAreEquivalent(lhs.expression, rhs.expression);
        }
        var NodeConstructor, TokenConstructor, IdentifierConstructor, PrivateIdentifierConstructor, SourceFileConstructor, parseBaseNodeFactory, parseNodeFactory, forEachChildTable, Parser, IncrementalParser, namedArgRegExCache, tripleSlashXMLCommentStartRegEx, singleLinePragmaRegEx;
        var init_parser = __esm({
            "src/compiler/parser.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
                init_ts_performance();
                parseBaseNodeFactory = {
                    createBaseSourceFileNode: (kind) => new (SourceFileConstructor || (SourceFileConstructor = objectAllocator.getSourceFileConstructor()))(kind, -1, -1),
                    createBaseIdentifierNode: (kind) => new (IdentifierConstructor || (IdentifierConstructor = objectAllocator.getIdentifierConstructor()))(kind, -1, -1),
                    createBasePrivateIdentifierNode: (kind) => new (PrivateIdentifierConstructor || (PrivateIdentifierConstructor = objectAllocator.getPrivateIdentifierConstructor()))(kind, -1, -1),
                    createBaseTokenNode: (kind) => new (TokenConstructor || (TokenConstructor = objectAllocator.getTokenConstructor()))(kind, -1, -1),
                    createBaseNode: (kind) => new (NodeConstructor || (NodeConstructor = objectAllocator.getNodeConstructor()))(kind, -1, -1)
                };
                parseNodeFactory = createNodeFactory(1 /* NoParenthesizerRules */, parseBaseNodeFactory);
                forEachChildTable = {
                    [163 /* QualifiedName */]: function forEachChildInQualifiedName(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.left) || visitNode2(cbNode, node.right);
                    },
                    [165 /* TypeParameter */]: function forEachChildInTypeParameter(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.constraint) || visitNode2(cbNode, node.default) || visitNode2(cbNode, node.expression);
                    },
                    [300 /* ShorthandPropertyAssignment */]: function forEachChildInShorthandPropertyAssignment(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.exclamationToken) || visitNode2(cbNode, node.equalsToken) || visitNode2(cbNode, node.objectAssignmentInitializer);
                    },
                    [301 /* SpreadAssignment */]: function forEachChildInSpreadAssignment(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [166 /* Parameter */]: function forEachChildInParameter(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.dotDotDotToken) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.initializer);
                    },
                    [169 /* PropertyDeclaration */]: function forEachChildInPropertyDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.exclamationToken) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.initializer);
                    },
                    [168 /* PropertySignature */]: function forEachChildInPropertySignature(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.initializer);
                    },
                    [299 /* PropertyAssignment */]: function forEachChildInPropertyAssignment(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.exclamationToken) || visitNode2(cbNode, node.initializer);
                    },
                    [257 /* VariableDeclaration */]: function forEachChildInVariableDeclaration(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.exclamationToken) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.initializer);
                    },
                    [205 /* BindingElement */]: function forEachChildInBindingElement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.dotDotDotToken) || visitNode2(cbNode, node.propertyName) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.initializer);
                    },
                    [178 /* IndexSignature */]: function forEachChildInIndexSignature(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [182 /* ConstructorType */]: function forEachChildInConstructorType(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [181 /* FunctionType */]: function forEachChildInFunctionType(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [176 /* CallSignature */]: forEachChildInCallOrConstructSignature,
                    [177 /* ConstructSignature */]: forEachChildInCallOrConstructSignature,
                    [171 /* MethodDeclaration */]: function forEachChildInMethodDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.asteriskToken) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.exclamationToken) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [170 /* MethodSignature */]: function forEachChildInMethodSignature(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [173 /* Constructor */]: function forEachChildInConstructor(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [174 /* GetAccessor */]: function forEachChildInGetAccessor(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [175 /* SetAccessor */]: function forEachChildInSetAccessor(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [259 /* FunctionDeclaration */]: function forEachChildInFunctionDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.asteriskToken) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [215 /* FunctionExpression */]: function forEachChildInFunctionExpression(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.asteriskToken) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [216 /* ArrowFunction */]: function forEachChildInArrowFunction(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.equalsGreaterThanToken) || visitNode2(cbNode, node.body);
                    },
                    [172 /* ClassStaticBlockDeclaration */]: function forEachChildInClassStaticBlockDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.body);
                    },
                    [180 /* TypeReference */]: function forEachChildInTypeReference(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.typeName) || visitNodes(cbNode, cbNodes, node.typeArguments);
                    },
                    [179 /* TypePredicate */]: function forEachChildInTypePredicate(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.assertsModifier) || visitNode2(cbNode, node.parameterName) || visitNode2(cbNode, node.type);
                    },
                    [183 /* TypeQuery */]: function forEachChildInTypeQuery(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.exprName) || visitNodes(cbNode, cbNodes, node.typeArguments);
                    },
                    [184 /* TypeLiteral */]: function forEachChildInTypeLiteral(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.members);
                    },
                    [185 /* ArrayType */]: function forEachChildInArrayType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.elementType);
                    },
                    [186 /* TupleType */]: function forEachChildInTupleType(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.elements);
                    },
                    [189 /* UnionType */]: forEachChildInUnionOrIntersectionType,
                    [190 /* IntersectionType */]: forEachChildInUnionOrIntersectionType,
                    [191 /* ConditionalType */]: function forEachChildInConditionalType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.checkType) || visitNode2(cbNode, node.extendsType) || visitNode2(cbNode, node.trueType) || visitNode2(cbNode, node.falseType);
                    },
                    [192 /* InferType */]: function forEachChildInInferType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.typeParameter);
                    },
                    [202 /* ImportType */]: function forEachChildInImportType(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.argument) || visitNode2(cbNode, node.assertions) || visitNode2(cbNode, node.qualifier) || visitNodes(cbNode, cbNodes, node.typeArguments);
                    },
                    [298 /* ImportTypeAssertionContainer */]: function forEachChildInImportTypeAssertionContainer(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.assertClause);
                    },
                    [193 /* ParenthesizedType */]: forEachChildInParenthesizedTypeOrTypeOperator,
                    [195 /* TypeOperator */]: forEachChildInParenthesizedTypeOrTypeOperator,
                    [196 /* IndexedAccessType */]: function forEachChildInIndexedAccessType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.objectType) || visitNode2(cbNode, node.indexType);
                    },
                    [197 /* MappedType */]: function forEachChildInMappedType(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.readonlyToken) || visitNode2(cbNode, node.typeParameter) || visitNode2(cbNode, node.nameType) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.type) || visitNodes(cbNode, cbNodes, node.members);
                    },
                    [198 /* LiteralType */]: function forEachChildInLiteralType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.literal);
                    },
                    [199 /* NamedTupleMember */]: function forEachChildInNamedTupleMember(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.dotDotDotToken) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.type);
                    },
                    [203 /* ObjectBindingPattern */]: forEachChildInObjectOrArrayBindingPattern,
                    [204 /* ArrayBindingPattern */]: forEachChildInObjectOrArrayBindingPattern,
                    [206 /* ArrayLiteralExpression */]: function forEachChildInArrayLiteralExpression(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.elements);
                    },
                    [207 /* ObjectLiteralExpression */]: function forEachChildInObjectLiteralExpression(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.properties);
                    },
                    [208 /* PropertyAccessExpression */]: function forEachChildInPropertyAccessExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.questionDotToken) || visitNode2(cbNode, node.name);
                    },
                    [209 /* ElementAccessExpression */]: function forEachChildInElementAccessExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.questionDotToken) || visitNode2(cbNode, node.argumentExpression);
                    },
                    [210 /* CallExpression */]: forEachChildInCallOrNewExpression,
                    [211 /* NewExpression */]: forEachChildInCallOrNewExpression,
                    [212 /* TaggedTemplateExpression */]: function forEachChildInTaggedTemplateExpression(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tag) || visitNode2(cbNode, node.questionDotToken) || visitNodes(cbNode, cbNodes, node.typeArguments) || visitNode2(cbNode, node.template);
                    },
                    [213 /* TypeAssertionExpression */]: function forEachChildInTypeAssertionExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.type) || visitNode2(cbNode, node.expression);
                    },
                    [214 /* ParenthesizedExpression */]: function forEachChildInParenthesizedExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [217 /* DeleteExpression */]: function forEachChildInDeleteExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [218 /* TypeOfExpression */]: function forEachChildInTypeOfExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [219 /* VoidExpression */]: function forEachChildInVoidExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [221 /* PrefixUnaryExpression */]: function forEachChildInPrefixUnaryExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.operand);
                    },
                    [226 /* YieldExpression */]: function forEachChildInYieldExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.asteriskToken) || visitNode2(cbNode, node.expression);
                    },
                    [220 /* AwaitExpression */]: function forEachChildInAwaitExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [222 /* PostfixUnaryExpression */]: function forEachChildInPostfixUnaryExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.operand);
                    },
                    [223 /* BinaryExpression */]: function forEachChildInBinaryExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.left) || visitNode2(cbNode, node.operatorToken) || visitNode2(cbNode, node.right);
                    },
                    [231 /* AsExpression */]: function forEachChildInAsExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.type);
                    },
                    [232 /* NonNullExpression */]: function forEachChildInNonNullExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [235 /* SatisfiesExpression */]: function forEachChildInSatisfiesExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.type);
                    },
                    [233 /* MetaProperty */]: function forEachChildInMetaProperty(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name);
                    },
                    [224 /* ConditionalExpression */]: function forEachChildInConditionalExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.condition) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.whenTrue) || visitNode2(cbNode, node.colonToken) || visitNode2(cbNode, node.whenFalse);
                    },
                    [227 /* SpreadElement */]: function forEachChildInSpreadElement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [238 /* Block */]: forEachChildInBlock,
                    [265 /* ModuleBlock */]: forEachChildInBlock,
                    [308 /* SourceFile */]: function forEachChildInSourceFile(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.statements) || visitNode2(cbNode, node.endOfFileToken);
                    },
                    [240 /* VariableStatement */]: function forEachChildInVariableStatement(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.declarationList);
                    },
                    [258 /* VariableDeclarationList */]: function forEachChildInVariableDeclarationList(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.declarations);
                    },
                    [241 /* ExpressionStatement */]: function forEachChildInExpressionStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [242 /* IfStatement */]: function forEachChildInIfStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.thenStatement) || visitNode2(cbNode, node.elseStatement);
                    },
                    [243 /* DoStatement */]: function forEachChildInDoStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.statement) || visitNode2(cbNode, node.expression);
                    },
                    [244 /* WhileStatement */]: function forEachChildInWhileStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.statement);
                    },
                    [245 /* ForStatement */]: function forEachChildInForStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.initializer) || visitNode2(cbNode, node.condition) || visitNode2(cbNode, node.incrementor) || visitNode2(cbNode, node.statement);
                    },
                    [246 /* ForInStatement */]: function forEachChildInForInStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.initializer) || visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.statement);
                    },
                    [247 /* ForOfStatement */]: function forEachChildInForOfStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.awaitModifier) || visitNode2(cbNode, node.initializer) || visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.statement);
                    },
                    [248 /* ContinueStatement */]: forEachChildInContinueOrBreakStatement,
                    [249 /* BreakStatement */]: forEachChildInContinueOrBreakStatement,
                    [250 /* ReturnStatement */]: function forEachChildInReturnStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [251 /* WithStatement */]: function forEachChildInWithStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.statement);
                    },
                    [252 /* SwitchStatement */]: function forEachChildInSwitchStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.caseBlock);
                    },
                    [266 /* CaseBlock */]: function forEachChildInCaseBlock(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.clauses);
                    },
                    [292 /* CaseClause */]: function forEachChildInCaseClause(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNodes(cbNode, cbNodes, node.statements);
                    },
                    [293 /* DefaultClause */]: function forEachChildInDefaultClause(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.statements);
                    },
                    [253 /* LabeledStatement */]: function forEachChildInLabeledStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.label) || visitNode2(cbNode, node.statement);
                    },
                    [254 /* ThrowStatement */]: function forEachChildInThrowStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [255 /* TryStatement */]: function forEachChildInTryStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.tryBlock) || visitNode2(cbNode, node.catchClause) || visitNode2(cbNode, node.finallyBlock);
                    },
                    [295 /* CatchClause */]: function forEachChildInCatchClause(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.variableDeclaration) || visitNode2(cbNode, node.block);
                    },
                    [167 /* Decorator */]: function forEachChildInDecorator(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [260 /* ClassDeclaration */]: forEachChildInClassDeclarationOrExpression,
                    [228 /* ClassExpression */]: forEachChildInClassDeclarationOrExpression,
                    [261 /* InterfaceDeclaration */]: function forEachChildInInterfaceDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.heritageClauses) || visitNodes(cbNode, cbNodes, node.members);
                    },
                    [262 /* TypeAliasDeclaration */]: function forEachChildInTypeAliasDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNode2(cbNode, node.type);
                    },
                    [263 /* EnumDeclaration */]: function forEachChildInEnumDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.members);
                    },
                    [302 /* EnumMember */]: function forEachChildInEnumMember(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.initializer);
                    },
                    [264 /* ModuleDeclaration */]: function forEachChildInModuleDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.body);
                    },
                    [268 /* ImportEqualsDeclaration */]: function forEachChildInImportEqualsDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.moduleReference);
                    },
                    [269 /* ImportDeclaration */]: function forEachChildInImportDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.importClause) || visitNode2(cbNode, node.moduleSpecifier) || visitNode2(cbNode, node.assertClause);
                    },
                    [270 /* ImportClause */]: function forEachChildInImportClause(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.namedBindings);
                    },
                    [296 /* AssertClause */]: function forEachChildInAssertClause(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.elements);
                    },
                    [297 /* AssertEntry */]: function forEachChildInAssertEntry(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.value);
                    },
                    [267 /* NamespaceExportDeclaration */]: function forEachChildInNamespaceExportDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name);
                    },
                    [271 /* NamespaceImport */]: function forEachChildInNamespaceImport(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name);
                    },
                    [277 /* NamespaceExport */]: function forEachChildInNamespaceExport(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name);
                    },
                    [272 /* NamedImports */]: forEachChildInNamedImportsOrExports,
                    [276 /* NamedExports */]: forEachChildInNamedImportsOrExports,
                    [275 /* ExportDeclaration */]: function forEachChildInExportDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.exportClause) || visitNode2(cbNode, node.moduleSpecifier) || visitNode2(cbNode, node.assertClause);
                    },
                    [273 /* ImportSpecifier */]: forEachChildInImportOrExportSpecifier,
                    [278 /* ExportSpecifier */]: forEachChildInImportOrExportSpecifier,
                    [274 /* ExportAssignment */]: function forEachChildInExportAssignment(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.expression);
                    },
                    [225 /* TemplateExpression */]: function forEachChildInTemplateExpression(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.head) || visitNodes(cbNode, cbNodes, node.templateSpans);
                    },
                    [236 /* TemplateSpan */]: function forEachChildInTemplateSpan(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.literal);
                    },
                    [200 /* TemplateLiteralType */]: function forEachChildInTemplateLiteralType(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.head) || visitNodes(cbNode, cbNodes, node.templateSpans);
                    },
                    [201 /* TemplateLiteralTypeSpan */]: function forEachChildInTemplateLiteralTypeSpan(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.type) || visitNode2(cbNode, node.literal);
                    },
                    [164 /* ComputedPropertyName */]: function forEachChildInComputedPropertyName(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [294 /* HeritageClause */]: function forEachChildInHeritageClause(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.types);
                    },
                    [230 /* ExpressionWithTypeArguments */]: function forEachChildInExpressionWithTypeArguments(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNodes(cbNode, cbNodes, node.typeArguments);
                    },
                    [280 /* ExternalModuleReference */]: function forEachChildInExternalModuleReference(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [279 /* MissingDeclaration */]: function forEachChildInMissingDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers);
                    },
                    [357 /* CommaListExpression */]: function forEachChildInCommaListExpression(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.elements);
                    },
                    [281 /* JsxElement */]: function forEachChildInJsxElement(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.openingElement) || visitNodes(cbNode, cbNodes, node.children) || visitNode2(cbNode, node.closingElement);
                    },
                    [285 /* JsxFragment */]: function forEachChildInJsxFragment(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.openingFragment) || visitNodes(cbNode, cbNodes, node.children) || visitNode2(cbNode, node.closingFragment);
                    },
                    [282 /* JsxSelfClosingElement */]: forEachChildInJsxOpeningOrSelfClosingElement,
                    [283 /* JsxOpeningElement */]: forEachChildInJsxOpeningOrSelfClosingElement,
                    [289 /* JsxAttributes */]: function forEachChildInJsxAttributes(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.properties);
                    },
                    [288 /* JsxAttribute */]: function forEachChildInJsxAttribute(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.initializer);
                    },
                    [290 /* JsxSpreadAttribute */]: function forEachChildInJsxSpreadAttribute(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [291 /* JsxExpression */]: function forEachChildInJsxExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.dotDotDotToken) || visitNode2(cbNode, node.expression);
                    },
                    [284 /* JsxClosingElement */]: function forEachChildInJsxClosingElement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.tagName);
                    },
                    [187 /* OptionalType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [188 /* RestType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [312 /* JSDocTypeExpression */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [318 /* JSDocNonNullableType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [317 /* JSDocNullableType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [319 /* JSDocOptionalType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [321 /* JSDocVariadicType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [320 /* JSDocFunctionType */]: function forEachChildInJSDocFunctionType(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [323 /* JSDoc */]: function forEachChildInJSDoc(node, cbNode, cbNodes) {
                        return (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment)) || visitNodes(cbNode, cbNodes, node.tags);
                    },
                    [350 /* JSDocSeeTag */]: function forEachChildInJSDocSeeTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.name) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [313 /* JSDocNameReference */]: function forEachChildInJSDocNameReference(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name);
                    },
                    [314 /* JSDocMemberName */]: function forEachChildInJSDocMemberName(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.left) || visitNode2(cbNode, node.right);
                    },
                    [344 /* JSDocParameterTag */]: forEachChildInJSDocParameterOrPropertyTag,
                    [351 /* JSDocPropertyTag */]: forEachChildInJSDocParameterOrPropertyTag,
                    [333 /* JSDocAuthorTag */]: function forEachChildInJSDocAuthorTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [332 /* JSDocImplementsTag */]: function forEachChildInJSDocImplementsTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.class) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [331 /* JSDocAugmentsTag */]: function forEachChildInJSDocAugmentsTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.class) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [348 /* JSDocTemplateTag */]: function forEachChildInJSDocTemplateTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.constraint) || visitNodes(cbNode, cbNodes, node.typeParameters) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [349 /* JSDocTypedefTag */]: function forEachChildInJSDocTypedefTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || (node.typeExpression && node.typeExpression.kind === 312 /* JSDocTypeExpression */ ? visitNode2(cbNode, node.typeExpression) || visitNode2(cbNode, node.fullName) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment)) : visitNode2(cbNode, node.fullName) || visitNode2(cbNode, node.typeExpression) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment)));
                    },
                    [341 /* JSDocCallbackTag */]: function forEachChildInJSDocCallbackTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.fullName) || visitNode2(cbNode, node.typeExpression) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [345 /* JSDocReturnTag */]: forEachChildInJSDocTypeLikeTag,
                    [347 /* JSDocTypeTag */]: forEachChildInJSDocTypeLikeTag,
                    [346 /* JSDocThisTag */]: forEachChildInJSDocTypeLikeTag,
                    [343 /* JSDocEnumTag */]: forEachChildInJSDocTypeLikeTag,
                    [353 /* JSDocSatisfiesTag */]: forEachChildInJSDocTypeLikeTag,
                    [352 /* JSDocThrowsTag */]: forEachChildInJSDocTypeLikeTag,
                    [342 /* JSDocOverloadTag */]: forEachChildInJSDocTypeLikeTag,
                    [326 /* JSDocSignature */]: function forEachChildInJSDocSignature(node, cbNode, _cbNodes) {
                        return forEach(node.typeParameters, cbNode) || forEach(node.parameters, cbNode) || visitNode2(cbNode, node.type);
                    },
                    [327 /* JSDocLink */]: forEachChildInJSDocLinkCodeOrPlain,
                    [328 /* JSDocLinkCode */]: forEachChildInJSDocLinkCodeOrPlain,
                    [329 /* JSDocLinkPlain */]: forEachChildInJSDocLinkCodeOrPlain,
                    [325 /* JSDocTypeLiteral */]: function forEachChildInJSDocTypeLiteral(node, cbNode, _cbNodes) {
                        return forEach(node.jsDocPropertyTags, cbNode);
                    },
                    [330 /* JSDocTag */]: forEachChildInJSDocTag,
                    [335 /* JSDocClassTag */]: forEachChildInJSDocTag,
                    [336 /* JSDocPublicTag */]: forEachChildInJSDocTag,
                    [337 /* JSDocPrivateTag */]: forEachChildInJSDocTag,
                    [338 /* JSDocProtectedTag */]: forEachChildInJSDocTag,
                    [339 /* JSDocReadonlyTag */]: forEachChildInJSDocTag,
                    [334 /* JSDocDeprecatedTag */]: forEachChildInJSDocTag,
                    [340 /* JSDocOverrideTag */]: forEachChildInJSDocTag,
                    [356 /* PartiallyEmittedExpression */]: forEachChildInPartiallyEmittedExpression
                };
                ((Parser2) => {
                    var scanner2 = createScanner(99 /* Latest */, 
                    /*skipTrivia*/
                    true);
                    var disallowInAndDecoratorContext = 4096 /* DisallowInContext */ | 16384 /* DecoratorContext */;
                    var NodeConstructor2;
                    var TokenConstructor2;
                    var IdentifierConstructor2;
                    var PrivateIdentifierConstructor2;
                    var SourceFileConstructor2;
                    function countNode(node) {
                        nodeCount++;
                        return node;
                    }
                    var baseNodeFactory = {
                        createBaseSourceFileNode: (kind) => countNode(new SourceFileConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0)),
                        createBaseIdentifierNode: (kind) => countNode(new IdentifierConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0)),
                        createBasePrivateIdentifierNode: (kind) => countNode(new PrivateIdentifierConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0)),
                        createBaseTokenNode: (kind) => countNode(new TokenConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0)),
                        createBaseNode: (kind) => countNode(new NodeConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0))
                    };
                    var factory2 = createNodeFactory(1 /* NoParenthesizerRules */ | 2 /* NoNodeConverters */ | 8 /* NoOriginalNode */, baseNodeFactory);
                    var { createNodeArray: factoryCreateNodeArray, createNumericLiteral: factoryCreateNumericLiteral, createStringLiteral: factoryCreateStringLiteral, createLiteralLikeNode: factoryCreateLiteralLikeNode, createIdentifier: factoryCreateIdentifier, createPrivateIdentifier: factoryCreatePrivateIdentifier, createToken: factoryCreateToken, createArrayLiteralExpression: factoryCreateArrayLiteralExpression, createObjectLiteralExpression: factoryCreateObjectLiteralExpression, createPropertyAccessExpression: factoryCreatePropertyAccessExpression, createPropertyAccessChain: factoryCreatePropertyAccessChain, createElementAccessExpression: factoryCreateElementAccessExpression, createElementAccessChain: factoryCreateElementAccessChain, createCallExpression: factoryCreateCallExpression, createCallChain: factoryCreateCallChain, createNewExpression: factoryCreateNewExpression, createParenthesizedExpression: factoryCreateParenthesizedExpression, createBlock: factoryCreateBlock, createVariableStatement: factoryCreateVariableStatement, createExpressionStatement: factoryCreateExpressionStatement, createIfStatement: factoryCreateIfStatement, createWhileStatement: factoryCreateWhileStatement, createForStatement: factoryCreateForStatement, createForOfStatement: factoryCreateForOfStatement, createVariableDeclaration: factoryCreateVariableDeclaration, createVariableDeclarationList: factoryCreateVariableDeclarationList } = factory2;
                    var fileName;
                    var sourceFlags;
                    var sourceText;
                    var languageVersion;
                    var scriptKind;
                    var languageVariant;
                    var parseDiagnostics;
                    var jsDocDiagnostics;
                    var syntaxCursor;
                    var currentToken;
                    var nodeCount;
                    var identifiers;
                    var identifierCount;
                    var parsingContext;
                    var notParenthesizedArrow;
                    var contextFlags;
                    var topLevel = true;
                    var parseErrorBeforeNextFinishedNode = false;
                    function parseSourceFile(fileName2, sourceText2, languageVersion2, syntaxCursor2, setParentNodes = false, scriptKind2, setExternalModuleIndicatorOverride) {
                        var _a2;
                        scriptKind2 = ensureScriptKind(fileName2, scriptKind2);
                        if (scriptKind2 === 6 /* JSON */) {
                            const result2 = parseJsonText2(fileName2, sourceText2, languageVersion2, syntaxCursor2, setParentNodes);
                            convertToObjectWorker(result2, (_a2 = result2.statements[0]) == null ? void 0 : _a2.expression, result2.parseDiagnostics, 
                            /*returnValue*/
                            false, 
                            /*knownRootOptions*/
                            void 0, 
                            /*jsonConversionNotifier*/
                            void 0);
                            result2.referencedFiles = emptyArray;
                            result2.typeReferenceDirectives = emptyArray;
                            result2.libReferenceDirectives = emptyArray;
                            result2.amdDependencies = emptyArray;
                            result2.hasNoDefaultLib = false;
                            result2.pragmas = emptyMap;
                            return result2;
                        }
                        initializeState(fileName2, sourceText2, languageVersion2, syntaxCursor2, scriptKind2);
                        const result = parseSourceFileWorker(languageVersion2, setParentNodes, scriptKind2, setExternalModuleIndicatorOverride || setExternalModuleIndicator);
                        clearState();
                        return result;
                    }
                    Parser2.parseSourceFile = parseSourceFile;
                    function parseIsolatedEntityName2(content, languageVersion2) {
                        initializeState("", content, languageVersion2, 
                        /*syntaxCursor*/
                        void 0, 1 /* JS */);
                        nextToken();
                        const entityName = parseEntityName(
                        /*allowReservedWords*/
                        true);
                        const isInvalid = token() === 1 /* EndOfFileToken */ && !parseDiagnostics.length;
                        clearState();
                        return isInvalid ? entityName : void 0;
                    }
                    Parser2.parseIsolatedEntityName = parseIsolatedEntityName2;
                    function parseJsonText2(fileName2, sourceText2, languageVersion2 = 2 /* ES2015 */, syntaxCursor2, setParentNodes = false) {
                        initializeState(fileName2, sourceText2, languageVersion2, syntaxCursor2, 6 /* JSON */);
                        sourceFlags = contextFlags;
                        nextToken();
                        const pos = getNodePos();
                        let statements, endOfFileToken;
                        if (token() === 1 /* EndOfFileToken */) {
                            statements = createNodeArray([], pos, pos);
                            endOfFileToken = parseTokenNode();
                        }
                        else {
                            let expressions;
                            while (token() !== 1 /* EndOfFileToken */) {
                                let expression2;
                                switch (token()) {
                                    case 22 /* OpenBracketToken */:
                                        expression2 = parseArrayLiteralExpression();
                                        break;
                                    case 110 /* TrueKeyword */:
                                    case 95 /* FalseKeyword */:
                                    case 104 /* NullKeyword */:
                                        expression2 = parseTokenNode();
                                        break;
                                    case 40 /* MinusToken */:
                                        if (lookAhead(() => nextToken() === 8 /* NumericLiteral */ && nextToken() !== 58 /* ColonToken */)) {
                                            expression2 = parsePrefixUnaryExpression();
                                        }
                                        else {
                                            expression2 = parseObjectLiteralExpression();
                                        }
                                        break;
                                    case 8 /* NumericLiteral */:
                                    case 10 /* StringLiteral */:
                                        if (lookAhead(() => nextToken() !== 58 /* ColonToken */)) {
                                            expression2 = parseLiteralNode();
                                            break;
                                        }
                                    default:
                                        expression2 = parseObjectLiteralExpression();
                                        break;
                                }
                                if (expressions && isArray(expressions)) {
                                    expressions.push(expression2);
                                }
                                else if (expressions) {
                                    expressions = [expressions, expression2];
                                }
                                else {
                                    expressions = expression2;
                                    if (token() !== 1 /* EndOfFileToken */) {
                                        parseErrorAtCurrentToken(Diagnostics.Unexpected_token);
                                    }
                                }
                            }
                            const expression = isArray(expressions) ? finishNode(factoryCreateArrayLiteralExpression(expressions), pos) : Debug.checkDefined(expressions);
                            const statement = factoryCreateExpressionStatement(expression);
                            finishNode(statement, pos);
                            statements = createNodeArray([statement], pos);
                            endOfFileToken = parseExpectedToken(1 /* EndOfFileToken */, Diagnostics.Unexpected_token);
                        }
                        const sourceFile = createSourceFile2(fileName2, 2 /* ES2015 */, 6 /* JSON */, 
                        /*isDeclaration*/
                        false, statements, endOfFileToken, sourceFlags, noop);
                        if (setParentNodes) {
                            fixupParentReferences(sourceFile);
                        }
                        sourceFile.nodeCount = nodeCount;
                        sourceFile.identifierCount = identifierCount;
                        sourceFile.identifiers = identifiers;
                        sourceFile.parseDiagnostics = attachFileToDiagnostics(parseDiagnostics, sourceFile);
                        if (jsDocDiagnostics) {
                            sourceFile.jsDocDiagnostics = attachFileToDiagnostics(jsDocDiagnostics, sourceFile);
                        }
                        const result = sourceFile;
                        clearState();
                        return result;
                    }
                    Parser2.parseJsonText = parseJsonText2;
                    function initializeState(_fileName, _sourceText, _languageVersion, _syntaxCursor, _scriptKind) {
                        NodeConstructor2 = objectAllocator.getNodeConstructor();
                        TokenConstructor2 = objectAllocator.getTokenConstructor();
                        IdentifierConstructor2 = objectAllocator.getIdentifierConstructor();
                        PrivateIdentifierConstructor2 = objectAllocator.getPrivateIdentifierConstructor();
                        SourceFileConstructor2 = objectAllocator.getSourceFileConstructor();
                        fileName = normalizePath(_fileName);
                        sourceText = _sourceText;
                        languageVersion = _languageVersion;
                        syntaxCursor = _syntaxCursor;
                        scriptKind = _scriptKind;
                        languageVariant = getLanguageVariant(_scriptKind);
                        parseDiagnostics = [];
                        parsingContext = 0;
                        identifiers = /* @__PURE__ */ new Map();
                        identifierCount = 0;
                        nodeCount = 0;
                        sourceFlags = 0;
                        topLevel = true;
                        switch (scriptKind) {
                            case 1 /* JS */:
                            case 2 /* JSX */:
                                contextFlags = 262144 /* JavaScriptFile */;
                                break;
                            case 6 /* JSON */:
                                contextFlags = 262144 /* JavaScriptFile */ | 67108864 /* JsonFile */;
                                break;
                            default:
                                contextFlags = 0 /* None */;
                                break;
                        }
                        parseErrorBeforeNextFinishedNode = false;
                        scanner2.setText(sourceText);
                        scanner2.setOnError(scanError);
                        scanner2.setScriptTarget(languageVersion);
                        scanner2.setLanguageVariant(languageVariant);
                    }
                    function clearState() {
                        scanner2.clearCommentDirectives();
                        scanner2.setText("");
                        scanner2.setOnError(void 0);
                        sourceText = void 0;
                        languageVersion = void 0;
                        syntaxCursor = void 0;
                        scriptKind = void 0;
                        languageVariant = void 0;
                        sourceFlags = 0;
                        parseDiagnostics = void 0;
                        jsDocDiagnostics = void 0;
                        parsingContext = 0;
                        identifiers = void 0;
                        notParenthesizedArrow = void 0;
                        topLevel = true;
                    }
                    function parseSourceFileWorker(languageVersion2, setParentNodes, scriptKind2, setExternalModuleIndicator2) {
                        const isDeclarationFile = isDeclarationFileName(fileName);
                        if (isDeclarationFile) {
                            contextFlags |= 16777216 /* Ambient */;
                        }
                        sourceFlags = contextFlags;
                        nextToken();
                        const statements = parseList(0 /* SourceElements */, parseStatement);
                        Debug.assert(token() === 1 /* EndOfFileToken */);
                        const endOfFileToken = addJSDocComment(parseTokenNode());
                        const sourceFile = createSourceFile2(fileName, languageVersion2, scriptKind2, isDeclarationFile, statements, endOfFileToken, sourceFlags, setExternalModuleIndicator2);
                        processCommentPragmas(sourceFile, sourceText);
                        processPragmasIntoFields(sourceFile, reportPragmaDiagnostic);
                        sourceFile.commentDirectives = scanner2.getCommentDirectives();
                        sourceFile.nodeCount = nodeCount;
                        sourceFile.identifierCount = identifierCount;
                        sourceFile.identifiers = identifiers;
                        sourceFile.parseDiagnostics = attachFileToDiagnostics(parseDiagnostics, sourceFile);
                        if (jsDocDiagnostics) {
                            sourceFile.jsDocDiagnostics = attachFileToDiagnostics(jsDocDiagnostics, sourceFile);
                        }
                        if (setParentNodes) {
                            fixupParentReferences(sourceFile);
                        }
                        return sourceFile;
                        function reportPragmaDiagnostic(pos, end, diagnostic) {
                            parseDiagnostics.push(createDetachedDiagnostic(fileName, pos, end, diagnostic));
                        }
                    }
                    function withJSDoc(node, hasJSDoc) {
                        return hasJSDoc ? addJSDocComment(node) : node;
                    }
                    let hasDeprecatedTag = false;
                    function addJSDocComment(node) {
                        Debug.assert(!node.jsDoc);
                        const jsDoc = mapDefined(getJSDocCommentRanges(node, sourceText), (comment) => JSDocParser.parseJSDocComment(node, comment.pos, comment.end - comment.pos));
                        if (jsDoc.length)
                            node.jsDoc = jsDoc;
                        if (hasDeprecatedTag) {
                            hasDeprecatedTag = false;
                            node.flags |= 268435456 /* Deprecated */;
                        }
                        return node;
                    }
                    function reparseTopLevelAwait(sourceFile) {
                        const savedSyntaxCursor = syntaxCursor;
                        const baseSyntaxCursor = IncrementalParser.createSyntaxCursor(sourceFile);
                        syntaxCursor = { currentNode: currentNode2 };
                        const statements = [];
                        const savedParseDiagnostics = parseDiagnostics;
                        parseDiagnostics = [];
                        let pos = 0;
                        let start = findNextStatementWithAwait(sourceFile.statements, 0);
                        while (start !== -1) {
                            const prevStatement = sourceFile.statements[pos];
                            const nextStatement = sourceFile.statements[start];
                            addRange(statements, sourceFile.statements, pos, start);
                            pos = findNextStatementWithoutAwait(sourceFile.statements, start);
                            const diagnosticStart = findIndex(savedParseDiagnostics, (diagnostic) => diagnostic.start >= prevStatement.pos);
                            const diagnosticEnd = diagnosticStart >= 0 ? findIndex(savedParseDiagnostics, (diagnostic) => diagnostic.start >= nextStatement.pos, diagnosticStart) : -1;
                            if (diagnosticStart >= 0) {
                                addRange(parseDiagnostics, savedParseDiagnostics, diagnosticStart, diagnosticEnd >= 0 ? diagnosticEnd : void 0);
                            }
                            speculationHelper(() => {
                                const savedContextFlags = contextFlags;
                                contextFlags |= 32768 /* AwaitContext */;
                                scanner2.setTextPos(nextStatement.pos);
                                nextToken();
                                while (token() !== 1 /* EndOfFileToken */) {
                                    const startPos = scanner2.getStartPos();
                                    const statement = parseListElement(0 /* SourceElements */, parseStatement);
                                    statements.push(statement);
                                    if (startPos === scanner2.getStartPos()) {
                                        nextToken();
                                    }
                                    if (pos >= 0) {
                                        const nonAwaitStatement = sourceFile.statements[pos];
                                        if (statement.end === nonAwaitStatement.pos) {
                                            break;
                                        }
                                        if (statement.end > nonAwaitStatement.pos) {
                                            pos = findNextStatementWithoutAwait(sourceFile.statements, pos + 1);
                                        }
                                    }
                                }
                                contextFlags = savedContextFlags;
                            }, 2 /* Reparse */);
                            start = pos >= 0 ? findNextStatementWithAwait(sourceFile.statements, pos) : -1;
                        }
                        if (pos >= 0) {
                            const prevStatement = sourceFile.statements[pos];
                            addRange(statements, sourceFile.statements, pos);
                            const diagnosticStart = findIndex(savedParseDiagnostics, (diagnostic) => diagnostic.start >= prevStatement.pos);
                            if (diagnosticStart >= 0) {
                                addRange(parseDiagnostics, savedParseDiagnostics, diagnosticStart);
                            }
                        }
                        syntaxCursor = savedSyntaxCursor;
                        return factory2.updateSourceFile(sourceFile, setTextRange(factoryCreateNodeArray(statements), sourceFile.statements));
                        function containsPossibleTopLevelAwait(node) {
                            return !(node.flags & 32768 /* AwaitContext */) && !!(node.transformFlags & 67108864 /* ContainsPossibleTopLevelAwait */);
                        }
                        function findNextStatementWithAwait(statements2, start2) {
                            for (let i = start2; i < statements2.length; i++) {
                                if (containsPossibleTopLevelAwait(statements2[i])) {
                                    return i;
                                }
                            }
                            return -1;
                        }
                        function findNextStatementWithoutAwait(statements2, start2) {
                            for (let i = start2; i < statements2.length; i++) {
                                if (!containsPossibleTopLevelAwait(statements2[i])) {
                                    return i;
                                }
                            }
                            return -1;
                        }
                        function currentNode2(position) {
                            const node = baseSyntaxCursor.currentNode(position);
                            if (topLevel && node && containsPossibleTopLevelAwait(node)) {
                                node.intersectsChange = true;
                            }
                            return node;
                        }
                    }
                    function fixupParentReferences(rootNode) {
                        setParentRecursive(rootNode, 
                        /*incremental*/
                        true);
                    }
                    Parser2.fixupParentReferences = fixupParentReferences;
                    function createSourceFile2(fileName2, languageVersion2, scriptKind2, isDeclarationFile, statements, endOfFileToken, flags, setExternalModuleIndicator2) {
                        let sourceFile = factory2.createSourceFile(statements, endOfFileToken, flags);
                        setTextRangePosWidth(sourceFile, 0, sourceText.length);
                        setFields(sourceFile);
                        if (!isDeclarationFile && isExternalModule(sourceFile) && sourceFile.transformFlags & 67108864 /* ContainsPossibleTopLevelAwait */) {
                            sourceFile = reparseTopLevelAwait(sourceFile);
                            setFields(sourceFile);
                        }
                        return sourceFile;
                        function setFields(sourceFile2) {
                            sourceFile2.text = sourceText;
                            sourceFile2.bindDiagnostics = [];
                            sourceFile2.bindSuggestionDiagnostics = void 0;
                            sourceFile2.languageVersion = languageVersion2;
                            sourceFile2.fileName = fileName2;
                            sourceFile2.languageVariant = getLanguageVariant(scriptKind2);
                            sourceFile2.isDeclarationFile = isDeclarationFile;
                            sourceFile2.scriptKind = scriptKind2;
                            setExternalModuleIndicator2(sourceFile2);
                            sourceFile2.setExternalModuleIndicator = setExternalModuleIndicator2;
                        }
                    }
                    function setContextFlag(val, flag) {
                        if (val) {
                            contextFlags |= flag;
                        }
                        else {
                            contextFlags &= ~flag;
                        }
                    }
                    function setDisallowInContext(val) {
                        setContextFlag(val, 4096 /* DisallowInContext */);
                    }
                    function setYieldContext(val) {
                        setContextFlag(val, 8192 /* YieldContext */);
                    }
                    function setDecoratorContext(val) {
                        setContextFlag(val, 16384 /* DecoratorContext */);
                    }
                    function setAwaitContext(val) {
                        setContextFlag(val, 32768 /* AwaitContext */);
                    }
                    function doOutsideOfContext(context, func) {
                        const contextFlagsToClear = context & contextFlags;
                        if (contextFlagsToClear) {
                            setContextFlag(
                            /*val*/
                            false, contextFlagsToClear);
                            const result = func();
                            setContextFlag(
                            /*val*/
                            true, contextFlagsToClear);
                            return result;
                        }
                        return func();
                    }
                    function doInsideOfContext(context, func) {
                        const contextFlagsToSet = context & ~contextFlags;
                        if (contextFlagsToSet) {
                            setContextFlag(
                            /*val*/
                            true, contextFlagsToSet);
                            const result = func();
                            setContextFlag(
                            /*val*/
                            false, contextFlagsToSet);
                            return result;
                        }
                        return func();
                    }
                    function allowInAnd(func) {
                        return doOutsideOfContext(4096 /* DisallowInContext */, func);
                    }
                    function disallowInAnd(func) {
                        return doInsideOfContext(4096 /* DisallowInContext */, func);
                    }
                    function allowConditionalTypesAnd(func) {
                        return doOutsideOfContext(65536 /* DisallowConditionalTypesContext */, func);
                    }
                    function disallowConditionalTypesAnd(func) {
                        return doInsideOfContext(65536 /* DisallowConditionalTypesContext */, func);
                    }
                    function doInYieldContext(func) {
                        return doInsideOfContext(8192 /* YieldContext */, func);
                    }
                    function doInDecoratorContext(func) {
                        return doInsideOfContext(16384 /* DecoratorContext */, func);
                    }
                    function doInAwaitContext(func) {
                        return doInsideOfContext(32768 /* AwaitContext */, func);
                    }
                    function doOutsideOfAwaitContext(func) {
                        return doOutsideOfContext(32768 /* AwaitContext */, func);
                    }
                    function doInYieldAndAwaitContext(func) {
                        return doInsideOfContext(8192 /* YieldContext */ | 32768 /* AwaitContext */, func);
                    }
                    function doOutsideOfYieldAndAwaitContext(func) {
                        return doOutsideOfContext(8192 /* YieldContext */ | 32768 /* AwaitContext */, func);
                    }
                    function inContext(flags) {
                        return (contextFlags & flags) !== 0;
                    }
                    function inYieldContext() {
                        return inContext(8192 /* YieldContext */);
                    }
                    function inDisallowInContext() {
                        return inContext(4096 /* DisallowInContext */);
                    }
                    function inDisallowConditionalTypesContext() {
                        return inContext(65536 /* DisallowConditionalTypesContext */);
                    }
                    function inDecoratorContext() {
                        return inContext(16384 /* DecoratorContext */);
                    }
                    function inAwaitContext() {
                        return inContext(32768 /* AwaitContext */);
                    }
                    function parseErrorAtCurrentToken(message, arg0) {
                        return parseErrorAt(scanner2.getTokenPos(), scanner2.getTextPos(), message, arg0);
                    }
                    function parseErrorAtPosition(start, length2, message, arg0) {
                        const lastError = lastOrUndefined(parseDiagnostics);
                        let result;
                        if (!lastError || start !== lastError.start) {
                            result = createDetachedDiagnostic(fileName, start, length2, message, arg0);
                            parseDiagnostics.push(result);
                        }
                        parseErrorBeforeNextFinishedNode = true;
                        return result;
                    }
                    function parseErrorAt(start, end, message, arg0) {
                        return parseErrorAtPosition(start, end - start, message, arg0);
                    }
                    function parseErrorAtRange(range, message, arg0) {
                        parseErrorAt(range.pos, range.end, message, arg0);
                    }
                    function scanError(message, length2) {
                        parseErrorAtPosition(scanner2.getTextPos(), length2, message);
                    }
                    function getNodePos() {
                        return scanner2.getStartPos();
                    }
                    function hasPrecedingJSDocComment() {
                        return scanner2.hasPrecedingJSDocComment();
                    }
                    function token() {
                        return currentToken;
                    }
                    function nextTokenWithoutCheck() {
                        return currentToken = scanner2.scan();
                    }
                    function nextTokenAnd(func) {
                        nextToken();
                        return func();
                    }
                    function nextToken() {
                        if (isKeyword(currentToken) && (scanner2.hasUnicodeEscape() || scanner2.hasExtendedUnicodeEscape())) {
                            parseErrorAt(scanner2.getTokenPos(), scanner2.getTextPos(), Diagnostics.Keywords_cannot_contain_escape_characters);
                        }
                        return nextTokenWithoutCheck();
                    }
                    function nextTokenJSDoc() {
                        return currentToken = scanner2.scanJsDocToken();
                    }
                    function reScanGreaterToken() {
                        return currentToken = scanner2.reScanGreaterToken();
                    }
                    function reScanSlashToken() {
                        return currentToken = scanner2.reScanSlashToken();
                    }
                    function reScanTemplateToken(isTaggedTemplate) {
                        return currentToken = scanner2.reScanTemplateToken(isTaggedTemplate);
                    }
                    function reScanTemplateHeadOrNoSubstitutionTemplate() {
                        return currentToken = scanner2.reScanTemplateHeadOrNoSubstitutionTemplate();
                    }
                    function reScanLessThanToken() {
                        return currentToken = scanner2.reScanLessThanToken();
                    }
                    function reScanHashToken() {
                        return currentToken = scanner2.reScanHashToken();
                    }
                    function scanJsxIdentifier() {
                        return currentToken = scanner2.scanJsxIdentifier();
                    }
                    function scanJsxText() {
                        return currentToken = scanner2.scanJsxToken();
                    }
                    function scanJsxAttributeValue() {
                        return currentToken = scanner2.scanJsxAttributeValue();
                    }
                    function speculationHelper(callback, speculationKind) {
                        const saveToken = currentToken;
                        const saveParseDiagnosticsLength = parseDiagnostics.length;
                        const saveParseErrorBeforeNextFinishedNode = parseErrorBeforeNextFinishedNode;
                        const saveContextFlags = contextFlags;
                        const result = speculationKind !== 0 /* TryParse */ ? scanner2.lookAhead(callback) : scanner2.tryScan(callback);
                        Debug.assert(saveContextFlags === contextFlags);
                        if (!result || speculationKind !== 0 /* TryParse */) {
                            currentToken = saveToken;
                            if (speculationKind !== 2 /* Reparse */) {
                                parseDiagnostics.length = saveParseDiagnosticsLength;
                            }
                            parseErrorBeforeNextFinishedNode = saveParseErrorBeforeNextFinishedNode;
                        }
                        return result;
                    }
                    function lookAhead(callback) {
                        return speculationHelper(callback, 1 /* Lookahead */);
                    }
                    function tryParse(callback) {
                        return speculationHelper(callback, 0 /* TryParse */);
                    }
                    function isBindingIdentifier() {
                        if (token() === 79 /* Identifier */) {
                            return true;
                        }
                        return token() > 116 /* LastReservedWord */;
                    }
                    function isIdentifier2() {
                        if (token() === 79 /* Identifier */) {
                            return true;
                        }
                        if (token() === 125 /* YieldKeyword */ && inYieldContext()) {
                            return false;
                        }
                        if (token() === 133 /* AwaitKeyword */ && inAwaitContext()) {
                            return false;
                        }
                        return token() > 116 /* LastReservedWord */;
                    }
                    function parseExpected(kind, diagnosticMessage, shouldAdvance = true) {
                        if (token() === kind) {
                            if (shouldAdvance) {
                                nextToken();
                            }
                            return true;
                        }
                        if (diagnosticMessage) {
                            parseErrorAtCurrentToken(diagnosticMessage);
                        }
                        else {
                            parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(kind));
                        }
                        return false;
                    }
                    const viableKeywordSuggestions = Object.keys(textToKeywordObj).filter((keyword) => keyword.length > 2);
                    function parseErrorForMissingSemicolonAfter(node) {
                        var _a2;
                        if (isTaggedTemplateExpression(node)) {
                            parseErrorAt(skipTrivia(sourceText, node.template.pos), node.template.end, Diagnostics.Module_declaration_names_may_only_use_or_quoted_strings);
                            return;
                        }
                        const expressionText = isIdentifier(node) ? idText(node) : void 0;
                        if (!expressionText || !isIdentifierText(expressionText, languageVersion)) {
                            parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(26 /* SemicolonToken */));
                            return;
                        }
                        const pos = skipTrivia(sourceText, node.pos);
                        switch (expressionText) {
                            case "const":
                            case "let":
                            case "var":
                                parseErrorAt(pos, node.end, Diagnostics.Variable_declaration_not_allowed_at_this_location);
                                return;
                            case "declare":
                                return;
                            case "interface":
                                parseErrorForInvalidName(Diagnostics.Interface_name_cannot_be_0, Diagnostics.Interface_must_be_given_a_name, 18 /* OpenBraceToken */);
                                return;
                            case "is":
                                parseErrorAt(pos, scanner2.getTextPos(), Diagnostics.A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods);
                                return;
                            case "module":
                            case "namespace":
                                parseErrorForInvalidName(Diagnostics.Namespace_name_cannot_be_0, Diagnostics.Namespace_must_be_given_a_name, 18 /* OpenBraceToken */);
                                return;
                            case "type":
                                parseErrorForInvalidName(Diagnostics.Type_alias_name_cannot_be_0, Diagnostics.Type_alias_must_be_given_a_name, 63 /* EqualsToken */);
                                return;
                        }
                        const suggestion = (_a2 = getSpellingSuggestion(expressionText, viableKeywordSuggestions, (n) => n)) != null ? _a2 : getSpaceSuggestion(expressionText);
                        if (suggestion) {
                            parseErrorAt(pos, node.end, Diagnostics.Unknown_keyword_or_identifier_Did_you_mean_0, suggestion);
                            return;
                        }
                        if (token() === 0 /* Unknown */) {
                            return;
                        }
                        parseErrorAt(pos, node.end, Diagnostics.Unexpected_keyword_or_identifier);
                    }
                    function parseErrorForInvalidName(nameDiagnostic, blankDiagnostic, tokenIfBlankName) {
                        if (token() === tokenIfBlankName) {
                            parseErrorAtCurrentToken(blankDiagnostic);
                        }
                        else {
                            parseErrorAtCurrentToken(nameDiagnostic, scanner2.getTokenValue());
                        }
                    }
                    function getSpaceSuggestion(expressionText) {
                        for (const keyword of viableKeywordSuggestions) {
                            if (expressionText.length > keyword.length + 2 && startsWith(expressionText, keyword)) {
                                return `${keyword} ${expressionText.slice(keyword.length)}`;
                            }
                        }
                        return void 0;
                    }
                    function parseSemicolonAfterPropertyName(name, type, initializer) {
                        if (token() === 59 /* AtToken */ && !scanner2.hasPrecedingLineBreak()) {
                            parseErrorAtCurrentToken(Diagnostics.Decorators_must_precede_the_name_and_all_keywords_of_property_declarations);
                            return;
                        }
                        if (token() === 20 /* OpenParenToken */) {
                            parseErrorAtCurrentToken(Diagnostics.Cannot_start_a_function_call_in_a_type_annotation);
                            nextToken();
                            return;
                        }
                        if (type && !canParseSemicolon()) {
                            if (initializer) {
                                parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(26 /* SemicolonToken */));
                            }
                            else {
                                parseErrorAtCurrentToken(Diagnostics.Expected_for_property_initializer);
                            }
                            return;
                        }
                        if (tryParseSemicolon()) {
                            return;
                        }
                        if (initializer) {
                            parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(26 /* SemicolonToken */));
                            return;
                        }
                        parseErrorForMissingSemicolonAfter(name);
                    }
                    function parseExpectedJSDoc(kind) {
                        if (token() === kind) {
                            nextTokenJSDoc();
                            return true;
                        }
                        parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(kind));
                        return false;
                    }
                    function parseExpectedMatchingBrackets(openKind, closeKind, openParsed, openPosition) {
                        if (token() === closeKind) {
                            nextToken();
                            return;
                        }
                        const lastError = parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(closeKind));
                        if (!openParsed) {
                            return;
                        }
                        if (lastError) {
                            addRelatedInfo(lastError, createDetachedDiagnostic(fileName, openPosition, 1, Diagnostics.The_parser_expected_to_find_a_1_to_match_the_0_token_here, tokenToString(openKind), tokenToString(closeKind)));
                        }
                    }
                    function parseOptional(t) {
                        if (token() === t) {
                            nextToken();
                            return true;
                        }
                        return false;
                    }
                    function parseOptionalToken(t) {
                        if (token() === t) {
                            return parseTokenNode();
                        }
                        return void 0;
                    }
                    function parseOptionalTokenJSDoc(t) {
                        if (token() === t) {
                            return parseTokenNodeJSDoc();
                        }
                        return void 0;
                    }
                    function parseExpectedToken(t, diagnosticMessage, arg0) {
                        return parseOptionalToken(t) || createMissingNode(t, 
                        /*reportAtCurrentPosition*/
                        false, diagnosticMessage || Diagnostics._0_expected, arg0 || tokenToString(t));
                    }
                    function parseExpectedTokenJSDoc(t) {
                        return parseOptionalTokenJSDoc(t) || createMissingNode(t, 
                        /*reportAtCurrentPosition*/
                        false, Diagnostics._0_expected, tokenToString(t));
                    }
                    function parseTokenNode() {
                        const pos = getNodePos();
                        const kind = token();
                        nextToken();
                        return finishNode(factoryCreateToken(kind), pos);
                    }
                    function parseTokenNodeJSDoc() {
                        const pos = getNodePos();
                        const kind = token();
                        nextTokenJSDoc();
                        return finishNode(factoryCreateToken(kind), pos);
                    }
                    function canParseSemicolon() {
                        if (token() === 26 /* SemicolonToken */) {
                            return true;
                        }
                        return token() === 19 /* CloseBraceToken */ || token() === 1 /* EndOfFileToken */ || scanner2.hasPrecedingLineBreak();
                    }
                    function tryParseSemicolon() {
                        if (!canParseSemicolon()) {
                            return false;
                        }
                        if (token() === 26 /* SemicolonToken */) {
                            nextToken();
                        }
                        return true;
                    }
                    function parseSemicolon() {
                        return tryParseSemicolon() || parseExpected(26 /* SemicolonToken */);
                    }
                    function createNodeArray(elements, pos, end, hasTrailingComma) {
                        const array = factoryCreateNodeArray(elements, hasTrailingComma);
                        setTextRangePosEnd(array, pos, end != null ? end : scanner2.getStartPos());
                        return array;
                    }
                    function finishNode(node, pos, end) {
                        setTextRangePosEnd(node, pos, end != null ? end : scanner2.getStartPos());
                        if (contextFlags) {
                            node.flags |= contextFlags;
                        }
                        if (parseErrorBeforeNextFinishedNode) {
                            parseErrorBeforeNextFinishedNode = false;
                            node.flags |= 131072 /* ThisNodeHasError */;
                        }
                        return node;
                    }
                    function createMissingNode(kind, reportAtCurrentPosition, diagnosticMessage, arg0) {
                        if (reportAtCurrentPosition) {
                            parseErrorAtPosition(scanner2.getStartPos(), 0, diagnosticMessage, arg0);
                        }
                        else if (diagnosticMessage) {
                            parseErrorAtCurrentToken(diagnosticMessage, arg0);
                        }
                        const pos = getNodePos();
                        const result = kind === 79 /* Identifier */ ? factoryCreateIdentifier("", 
                        /*originalKeywordKind*/
                        void 0) : isTemplateLiteralKind(kind) ? factory2.createTemplateLiteralLikeNode(kind, "", "", 
                        /*templateFlags*/
                        void 0) : kind === 8 /* NumericLiteral */ ? factoryCreateNumericLiteral("", 
                        /*numericLiteralFlags*/
                        void 0) : kind === 10 /* StringLiteral */ ? factoryCreateStringLiteral("", 
                        /*isSingleQuote*/
                        void 0) : kind === 279 /* MissingDeclaration */ ? factory2.createMissingDeclaration() : factoryCreateToken(kind);
                        return finishNode(result, pos);
                    }
                    function internIdentifier(text) {
                        let identifier = identifiers.get(text);
                        if (identifier === void 0) {
                            identifiers.set(text, identifier = text);
                        }
                        return identifier;
                    }
                    function createIdentifier(isIdentifier3, diagnosticMessage, privateIdentifierDiagnosticMessage) {
                        if (isIdentifier3) {
                            identifierCount++;
                            const pos = getNodePos();
                            const originalKeywordKind = token();
                            const text = internIdentifier(scanner2.getTokenValue());
                            const hasExtendedUnicodeEscape = scanner2.hasExtendedUnicodeEscape();
                            nextTokenWithoutCheck();
                            return finishNode(factoryCreateIdentifier(text, originalKeywordKind, hasExtendedUnicodeEscape), pos);
                        }
                        if (token() === 80 /* PrivateIdentifier */) {
                            parseErrorAtCurrentToken(privateIdentifierDiagnosticMessage || Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                            return createIdentifier(
                            /*isIdentifier*/
                            true);
                        }
                        if (token() === 0 /* Unknown */ && scanner2.tryScan(() => scanner2.reScanInvalidIdentifier() === 79 /* Identifier */)) {
                            return createIdentifier(
                            /*isIdentifier*/
                            true);
                        }
                        identifierCount++;
                        const reportAtCurrentPosition = token() === 1 /* EndOfFileToken */;
                        const isReservedWord = scanner2.isReservedWord();
                        const msgArg = scanner2.getTokenText();
                        const defaultMessage = isReservedWord ? Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here : Diagnostics.Identifier_expected;
                        return createMissingNode(79 /* Identifier */, reportAtCurrentPosition, diagnosticMessage || defaultMessage, msgArg);
                    }
                    function parseBindingIdentifier(privateIdentifierDiagnosticMessage) {
                        return createIdentifier(isBindingIdentifier(), 
                        /*diagnosticMessage*/
                        void 0, privateIdentifierDiagnosticMessage);
                    }
                    function parseIdentifier(diagnosticMessage, privateIdentifierDiagnosticMessage) {
                        return createIdentifier(isIdentifier2(), diagnosticMessage, privateIdentifierDiagnosticMessage);
                    }
                    function parseIdentifierName(diagnosticMessage) {
                        return createIdentifier(tokenIsIdentifierOrKeyword(token()), diagnosticMessage);
                    }
                    function isLiteralPropertyName() {
                        return tokenIsIdentifierOrKeyword(token()) || token() === 10 /* StringLiteral */ || token() === 8 /* NumericLiteral */;
                    }
                    function isAssertionKey2() {
                        return tokenIsIdentifierOrKeyword(token()) || token() === 10 /* StringLiteral */;
                    }
                    function parsePropertyNameWorker(allowComputedPropertyNames) {
                        if (token() === 10 /* StringLiteral */ || token() === 8 /* NumericLiteral */) {
                            const node = parseLiteralNode();
                            node.text = internIdentifier(node.text);
                            return node;
                        }
                        if (allowComputedPropertyNames && token() === 22 /* OpenBracketToken */) {
                            return parseComputedPropertyName();
                        }
                        if (token() === 80 /* PrivateIdentifier */) {
                            return parsePrivateIdentifier();
                        }
                        return parseIdentifierName();
                    }
                    function parsePropertyName() {
                        return parsePropertyNameWorker(
                        /*allowComputedPropertyNames*/
                        true);
                    }
                    function parseComputedPropertyName() {
                        const pos = getNodePos();
                        parseExpected(22 /* OpenBracketToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpected(23 /* CloseBracketToken */);
                        return finishNode(factory2.createComputedPropertyName(expression), pos);
                    }
                    function parsePrivateIdentifier() {
                        const pos = getNodePos();
                        const node = factoryCreatePrivateIdentifier(internIdentifier(scanner2.getTokenValue()));
                        nextToken();
                        return finishNode(node, pos);
                    }
                    function parseContextualModifier(t) {
                        return token() === t && tryParse(nextTokenCanFollowModifier);
                    }
                    function nextTokenIsOnSameLineAndCanFollowModifier() {
                        nextToken();
                        if (scanner2.hasPrecedingLineBreak()) {
                            return false;
                        }
                        return canFollowModifier();
                    }
                    function nextTokenCanFollowModifier() {
                        switch (token()) {
                            case 85 /* ConstKeyword */:
                                return nextToken() === 92 /* EnumKeyword */;
                            case 93 /* ExportKeyword */:
                                nextToken();
                                if (token() === 88 /* DefaultKeyword */) {
                                    return lookAhead(nextTokenCanFollowDefaultKeyword);
                                }
                                if (token() === 154 /* TypeKeyword */) {
                                    return lookAhead(nextTokenCanFollowExportModifier);
                                }
                                return canFollowExportModifier();
                            case 88 /* DefaultKeyword */:
                                return nextTokenCanFollowDefaultKeyword();
                            case 124 /* StaticKeyword */:
                            case 137 /* GetKeyword */:
                            case 151 /* SetKeyword */:
                                nextToken();
                                return canFollowModifier();
                            default:
                                return nextTokenIsOnSameLineAndCanFollowModifier();
                        }
                    }
                    function canFollowExportModifier() {
                        return token() === 59 /* AtToken */ || token() !== 41 /* AsteriskToken */ && token() !== 128 /* AsKeyword */ && token() !== 18 /* OpenBraceToken */ && canFollowModifier();
                    }
                    function nextTokenCanFollowExportModifier() {
                        nextToken();
                        return canFollowExportModifier();
                    }
                    function parseAnyContextualModifier() {
                        return isModifierKind(token()) && tryParse(nextTokenCanFollowModifier);
                    }
                    function canFollowModifier() {
                        return token() === 22 /* OpenBracketToken */ || token() === 18 /* OpenBraceToken */ || token() === 41 /* AsteriskToken */ || token() === 25 /* DotDotDotToken */ || isLiteralPropertyName();
                    }
                    function nextTokenCanFollowDefaultKeyword() {
                        nextToken();
                        return token() === 84 /* ClassKeyword */ || token() === 98 /* FunctionKeyword */ || token() === 118 /* InterfaceKeyword */ || token() === 59 /* AtToken */ || token() === 126 /* AbstractKeyword */ && lookAhead(nextTokenIsClassKeywordOnSameLine) || token() === 132 /* AsyncKeyword */ && lookAhead(nextTokenIsFunctionKeywordOnSameLine);
                    }
                    function isListElement2(parsingContext2, inErrorRecovery) {
                        const node = currentNode(parsingContext2);
                        if (node) {
                            return true;
                        }
                        switch (parsingContext2) {
                            case 0 /* SourceElements */:
                            case 1 /* BlockStatements */:
                            case 3 /* SwitchClauseStatements */:
                                return !(token() === 26 /* SemicolonToken */ && inErrorRecovery) && isStartOfStatement();
                            case 2 /* SwitchClauses */:
                                return token() === 82 /* CaseKeyword */ || token() === 88 /* DefaultKeyword */;
                            case 4 /* TypeMembers */:
                                return lookAhead(isTypeMemberStart);
                            case 5 /* ClassMembers */:
                                return lookAhead(isClassMemberStart) || token() === 26 /* SemicolonToken */ && !inErrorRecovery;
                            case 6 /* EnumMembers */:
                                return token() === 22 /* OpenBracketToken */ || isLiteralPropertyName();
                            case 12 /* ObjectLiteralMembers */:
                                switch (token()) {
                                    case 22 /* OpenBracketToken */:
                                    case 41 /* AsteriskToken */:
                                    case 25 /* DotDotDotToken */:
                                    case 24 /* DotToken */:
                                        return true;
                                    default:
                                        return isLiteralPropertyName();
                                }
                            case 18 /* RestProperties */:
                                return isLiteralPropertyName();
                            case 9 /* ObjectBindingElements */:
                                return token() === 22 /* OpenBracketToken */ || token() === 25 /* DotDotDotToken */ || isLiteralPropertyName();
                            case 24 /* AssertEntries */:
                                return isAssertionKey2();
                            case 7 /* HeritageClauseElement */:
                                if (token() === 18 /* OpenBraceToken */) {
                                    return lookAhead(isValidHeritageClauseObjectLiteral);
                                }
                                if (!inErrorRecovery) {
                                    return isStartOfLeftHandSideExpression() && !isHeritageClauseExtendsOrImplementsKeyword();
                                }
                                else {
                                    return isIdentifier2() && !isHeritageClauseExtendsOrImplementsKeyword();
                                }
                            case 8 /* VariableDeclarations */:
                                return isBindingIdentifierOrPrivateIdentifierOrPattern();
                            case 10 /* ArrayBindingElements */:
                                return token() === 27 /* CommaToken */ || token() === 25 /* DotDotDotToken */ || isBindingIdentifierOrPrivateIdentifierOrPattern();
                            case 19 /* TypeParameters */:
                                return token() === 101 /* InKeyword */ || token() === 85 /* ConstKeyword */ || isIdentifier2();
                            case 15 /* ArrayLiteralMembers */:
                                switch (token()) {
                                    case 27 /* CommaToken */:
                                    case 24 /* DotToken */:
                                        return true;
                                }
                            case 11 /* ArgumentExpressions */:
                                return token() === 25 /* DotDotDotToken */ || isStartOfExpression();
                            case 16 /* Parameters */:
                                return isStartOfParameter(
                                /*isJSDocParameter*/
                                false);
                            case 17 /* JSDocParameters */:
                                return isStartOfParameter(
                                /*isJSDocParameter*/
                                true);
                            case 20 /* TypeArguments */:
                            case 21 /* TupleElementTypes */:
                                return token() === 27 /* CommaToken */ || isStartOfType();
                            case 22 /* HeritageClauses */:
                                return isHeritageClause2();
                            case 23 /* ImportOrExportSpecifiers */:
                                return tokenIsIdentifierOrKeyword(token());
                            case 13 /* JsxAttributes */:
                                return tokenIsIdentifierOrKeyword(token()) || token() === 18 /* OpenBraceToken */;
                            case 14 /* JsxChildren */:
                                return true;
                        }
                        return Debug.fail("Non-exhaustive case in 'isListElement'.");
                    }
                    function isValidHeritageClauseObjectLiteral() {
                        Debug.assert(token() === 18 /* OpenBraceToken */);
                        if (nextToken() === 19 /* CloseBraceToken */) {
                            const next = nextToken();
                            return next === 27 /* CommaToken */ || next === 18 /* OpenBraceToken */ || next === 94 /* ExtendsKeyword */ || next === 117 /* ImplementsKeyword */;
                        }
                        return true;
                    }
                    function nextTokenIsIdentifier() {
                        nextToken();
                        return isIdentifier2();
                    }
                    function nextTokenIsIdentifierOrKeyword() {
                        nextToken();
                        return tokenIsIdentifierOrKeyword(token());
                    }
                    function nextTokenIsIdentifierOrKeywordOrGreaterThan() {
                        nextToken();
                        return tokenIsIdentifierOrKeywordOrGreaterThan(token());
                    }
                    function isHeritageClauseExtendsOrImplementsKeyword() {
                        if (token() === 117 /* ImplementsKeyword */ || token() === 94 /* ExtendsKeyword */) {
                            return lookAhead(nextTokenIsStartOfExpression);
                        }
                        return false;
                    }
                    function nextTokenIsStartOfExpression() {
                        nextToken();
                        return isStartOfExpression();
                    }
                    function nextTokenIsStartOfType() {
                        nextToken();
                        return isStartOfType();
                    }
                    function isListTerminator(kind) {
                        if (token() === 1 /* EndOfFileToken */) {
                            return true;
                        }
                        switch (kind) {
                            case 1 /* BlockStatements */:
                            case 2 /* SwitchClauses */:
                            case 4 /* TypeMembers */:
                            case 5 /* ClassMembers */:
                            case 6 /* EnumMembers */:
                            case 12 /* ObjectLiteralMembers */:
                            case 9 /* ObjectBindingElements */:
                            case 23 /* ImportOrExportSpecifiers */:
                            case 24 /* AssertEntries */:
                                return token() === 19 /* CloseBraceToken */;
                            case 3 /* SwitchClauseStatements */:
                                return token() === 19 /* CloseBraceToken */ || token() === 82 /* CaseKeyword */ || token() === 88 /* DefaultKeyword */;
                            case 7 /* HeritageClauseElement */:
                                return token() === 18 /* OpenBraceToken */ || token() === 94 /* ExtendsKeyword */ || token() === 117 /* ImplementsKeyword */;
                            case 8 /* VariableDeclarations */:
                                return isVariableDeclaratorListTerminator();
                            case 19 /* TypeParameters */:
                                return token() === 31 /* GreaterThanToken */ || token() === 20 /* OpenParenToken */ || token() === 18 /* OpenBraceToken */ || token() === 94 /* ExtendsKeyword */ || token() === 117 /* ImplementsKeyword */;
                            case 11 /* ArgumentExpressions */:
                                return token() === 21 /* CloseParenToken */ || token() === 26 /* SemicolonToken */;
                            case 15 /* ArrayLiteralMembers */:
                            case 21 /* TupleElementTypes */:
                            case 10 /* ArrayBindingElements */:
                                return token() === 23 /* CloseBracketToken */;
                            case 17 /* JSDocParameters */:
                            case 16 /* Parameters */:
                            case 18 /* RestProperties */:
                                return token() === 21 /* CloseParenToken */ || token() === 23 /* CloseBracketToken */;
                            case 20 /* TypeArguments */:
                                return token() !== 27 /* CommaToken */;
                            case 22 /* HeritageClauses */:
                                return token() === 18 /* OpenBraceToken */ || token() === 19 /* CloseBraceToken */;
                            case 13 /* JsxAttributes */:
                                return token() === 31 /* GreaterThanToken */ || token() === 43 /* SlashToken */;
                            case 14 /* JsxChildren */:
                                return token() === 29 /* LessThanToken */ && lookAhead(nextTokenIsSlash);
                            default:
                                return false;
                        }
                    }
                    function isVariableDeclaratorListTerminator() {
                        if (canParseSemicolon()) {
                            return true;
                        }
                        if (isInOrOfKeyword(token())) {
                            return true;
                        }
                        if (token() === 38 /* EqualsGreaterThanToken */) {
                            return true;
                        }
                        return false;
                    }
                    function isInSomeParsingContext() {
                        for (let kind = 0; kind < 25 /* Count */; kind++) {
                            if (parsingContext & 1 << kind) {
                                if (isListElement2(kind, 
                                /*inErrorRecovery*/
                                true) || isListTerminator(kind)) {
                                    return true;
                                }
                            }
                        }
                        return false;
                    }
                    function parseList(kind, parseElement) {
                        const saveParsingContext = parsingContext;
                        parsingContext |= 1 << kind;
                        const list = [];
                        const listPos = getNodePos();
                        while (!isListTerminator(kind)) {
                            if (isListElement2(kind, 
                            /*inErrorRecovery*/
                            false)) {
                                list.push(parseListElement(kind, parseElement));
                                continue;
                            }
                            if (abortParsingListOrMoveToNextToken(kind)) {
                                break;
                            }
                        }
                        parsingContext = saveParsingContext;
                        return createNodeArray(list, listPos);
                    }
                    function parseListElement(parsingContext2, parseElement) {
                        const node = currentNode(parsingContext2);
                        if (node) {
                            return consumeNode(node);
                        }
                        return parseElement();
                    }
                    function currentNode(parsingContext2, pos) {
                        var _a2;
                        if (!syntaxCursor || !isReusableParsingContext(parsingContext2) || parseErrorBeforeNextFinishedNode) {
                            return void 0;
                        }
                        const node = syntaxCursor.currentNode(pos != null ? pos : scanner2.getStartPos());
                        if (nodeIsMissing(node) || node.intersectsChange || containsParseError(node)) {
                            return void 0;
                        }
                        const nodeContextFlags = node.flags & 50720768 /* ContextFlags */;
                        if (nodeContextFlags !== contextFlags) {
                            return void 0;
                        }
                        if (!canReuseNode(node, parsingContext2)) {
                            return void 0;
                        }
                        if (canHaveJSDoc(node) && ((_a2 = node.jsDoc) == null ? void 0 : _a2.jsDocCache)) {
                            node.jsDoc.jsDocCache = void 0;
                        }
                        return node;
                    }
                    function consumeNode(node) {
                        scanner2.setTextPos(node.end);
                        nextToken();
                        return node;
                    }
                    function isReusableParsingContext(parsingContext2) {
                        switch (parsingContext2) {
                            case 5 /* ClassMembers */:
                            case 2 /* SwitchClauses */:
                            case 0 /* SourceElements */:
                            case 1 /* BlockStatements */:
                            case 3 /* SwitchClauseStatements */:
                            case 6 /* EnumMembers */:
                            case 4 /* TypeMembers */:
                            case 8 /* VariableDeclarations */:
                            case 17 /* JSDocParameters */:
                            case 16 /* Parameters */:
                                return true;
                        }
                        return false;
                    }
                    function canReuseNode(node, parsingContext2) {
                        switch (parsingContext2) {
                            case 5 /* ClassMembers */:
                                return isReusableClassMember(node);
                            case 2 /* SwitchClauses */:
                                return isReusableSwitchClause(node);
                            case 0 /* SourceElements */:
                            case 1 /* BlockStatements */:
                            case 3 /* SwitchClauseStatements */:
                                return isReusableStatement(node);
                            case 6 /* EnumMembers */:
                                return isReusableEnumMember(node);
                            case 4 /* TypeMembers */:
                                return isReusableTypeMember(node);
                            case 8 /* VariableDeclarations */:
                                return isReusableVariableDeclaration(node);
                            case 17 /* JSDocParameters */:
                            case 16 /* Parameters */:
                                return isReusableParameter(node);
                        }
                        return false;
                    }
                    function isReusableClassMember(node) {
                        if (node) {
                            switch (node.kind) {
                                case 173 /* Constructor */:
                                case 178 /* IndexSignature */:
                                case 174 /* GetAccessor */:
                                case 175 /* SetAccessor */:
                                case 169 /* PropertyDeclaration */:
                                case 237 /* SemicolonClassElement */:
                                    return true;
                                case 171 /* MethodDeclaration */:
                                    const methodDeclaration = node;
                                    const nameIsConstructor = methodDeclaration.name.kind === 79 /* Identifier */ && methodDeclaration.name.escapedText === "constructor";
                                    return !nameIsConstructor;
                            }
                        }
                        return false;
                    }
                    function isReusableSwitchClause(node) {
                        if (node) {
                            switch (node.kind) {
                                case 292 /* CaseClause */:
                                case 293 /* DefaultClause */:
                                    return true;
                            }
                        }
                        return false;
                    }
                    function isReusableStatement(node) {
                        if (node) {
                            switch (node.kind) {
                                case 259 /* FunctionDeclaration */:
                                case 240 /* VariableStatement */:
                                case 238 /* Block */:
                                case 242 /* IfStatement */:
                                case 241 /* ExpressionStatement */:
                                case 254 /* ThrowStatement */:
                                case 250 /* ReturnStatement */:
                                case 252 /* SwitchStatement */:
                                case 249 /* BreakStatement */:
                                case 248 /* ContinueStatement */:
                                case 246 /* ForInStatement */:
                                case 247 /* ForOfStatement */:
                                case 245 /* ForStatement */:
                                case 244 /* WhileStatement */:
                                case 251 /* WithStatement */:
                                case 239 /* EmptyStatement */:
                                case 255 /* TryStatement */:
                                case 253 /* LabeledStatement */:
                                case 243 /* DoStatement */:
                                case 256 /* DebuggerStatement */:
                                case 269 /* ImportDeclaration */:
                                case 268 /* ImportEqualsDeclaration */:
                                case 275 /* ExportDeclaration */:
                                case 274 /* ExportAssignment */:
                                case 264 /* ModuleDeclaration */:
                                case 260 /* ClassDeclaration */:
                                case 261 /* InterfaceDeclaration */:
                                case 263 /* EnumDeclaration */:
                                case 262 /* TypeAliasDeclaration */:
                                    return true;
                            }
                        }
                        return false;
                    }
                    function isReusableEnumMember(node) {
                        return node.kind === 302 /* EnumMember */;
                    }
                    function isReusableTypeMember(node) {
                        if (node) {
                            switch (node.kind) {
                                case 177 /* ConstructSignature */:
                                case 170 /* MethodSignature */:
                                case 178 /* IndexSignature */:
                                case 168 /* PropertySignature */:
                                case 176 /* CallSignature */:
                                    return true;
                            }
                        }
                        return false;
                    }
                    function isReusableVariableDeclaration(node) {
                        if (node.kind !== 257 /* VariableDeclaration */) {
                            return false;
                        }
                        const variableDeclarator = node;
                        return variableDeclarator.initializer === void 0;
                    }
                    function isReusableParameter(node) {
                        if (node.kind !== 166 /* Parameter */) {
                            return false;
                        }
                        const parameter = node;
                        return parameter.initializer === void 0;
                    }
                    function abortParsingListOrMoveToNextToken(kind) {
                        parsingContextErrors(kind);
                        if (isInSomeParsingContext()) {
                            return true;
                        }
                        nextToken();
                        return false;
                    }
                    function parsingContextErrors(context) {
                        switch (context) {
                            case 0 /* SourceElements */:
                                return token() === 88 /* DefaultKeyword */ ? parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(93 /* ExportKeyword */)) : parseErrorAtCurrentToken(Diagnostics.Declaration_or_statement_expected);
                            case 1 /* BlockStatements */:
                                return parseErrorAtCurrentToken(Diagnostics.Declaration_or_statement_expected);
                            case 2 /* SwitchClauses */:
                                return parseErrorAtCurrentToken(Diagnostics.case_or_default_expected);
                            case 3 /* SwitchClauseStatements */:
                                return parseErrorAtCurrentToken(Diagnostics.Statement_expected);
                            case 18 /* RestProperties */:
                            case 4 /* TypeMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Property_or_signature_expected);
                            case 5 /* ClassMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Unexpected_token_A_constructor_method_accessor_or_property_was_expected);
                            case 6 /* EnumMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Enum_member_expected);
                            case 7 /* HeritageClauseElement */:
                                return parseErrorAtCurrentToken(Diagnostics.Expression_expected);
                            case 8 /* VariableDeclarations */:
                                return isKeyword(token()) ? parseErrorAtCurrentToken(Diagnostics._0_is_not_allowed_as_a_variable_declaration_name, tokenToString(token())) : parseErrorAtCurrentToken(Diagnostics.Variable_declaration_expected);
                            case 9 /* ObjectBindingElements */:
                                return parseErrorAtCurrentToken(Diagnostics.Property_destructuring_pattern_expected);
                            case 10 /* ArrayBindingElements */:
                                return parseErrorAtCurrentToken(Diagnostics.Array_element_destructuring_pattern_expected);
                            case 11 /* ArgumentExpressions */:
                                return parseErrorAtCurrentToken(Diagnostics.Argument_expression_expected);
                            case 12 /* ObjectLiteralMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Property_assignment_expected);
                            case 15 /* ArrayLiteralMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Expression_or_comma_expected);
                            case 17 /* JSDocParameters */:
                                return parseErrorAtCurrentToken(Diagnostics.Parameter_declaration_expected);
                            case 16 /* Parameters */:
                                return isKeyword(token()) ? parseErrorAtCurrentToken(Diagnostics._0_is_not_allowed_as_a_parameter_name, tokenToString(token())) : parseErrorAtCurrentToken(Diagnostics.Parameter_declaration_expected);
                            case 19 /* TypeParameters */:
                                return parseErrorAtCurrentToken(Diagnostics.Type_parameter_declaration_expected);
                            case 20 /* TypeArguments */:
                                return parseErrorAtCurrentToken(Diagnostics.Type_argument_expected);
                            case 21 /* TupleElementTypes */:
                                return parseErrorAtCurrentToken(Diagnostics.Type_expected);
                            case 22 /* HeritageClauses */:
                                return parseErrorAtCurrentToken(Diagnostics.Unexpected_token_expected);
                            case 23 /* ImportOrExportSpecifiers */:
                                return parseErrorAtCurrentToken(Diagnostics.Identifier_expected);
                            case 13 /* JsxAttributes */:
                                return parseErrorAtCurrentToken(Diagnostics.Identifier_expected);
                            case 14 /* JsxChildren */:
                                return parseErrorAtCurrentToken(Diagnostics.Identifier_expected);
                            case 24 /* AssertEntries */:
                                return parseErrorAtCurrentToken(Diagnostics.Identifier_or_string_literal_expected);
                            case 25 /* Count */:
                                return Debug.fail("ParsingContext.Count used as a context");
                            default:
                                Debug.assertNever(context);
                        }
                    }
                    function parseDelimitedList(kind, parseElement, considerSemicolonAsDelimiter) {
                        const saveParsingContext = parsingContext;
                        parsingContext |= 1 << kind;
                        const list = [];
                        const listPos = getNodePos();
                        let commaStart = -1;
                        while (true) {
                            if (isListElement2(kind, 
                            /*inErrorRecovery*/
                            false)) {
                                const startPos = scanner2.getStartPos();
                                const result = parseListElement(kind, parseElement);
                                if (!result) {
                                    parsingContext = saveParsingContext;
                                    return void 0;
                                }
                                list.push(result);
                                commaStart = scanner2.getTokenPos();
                                if (parseOptional(27 /* CommaToken */)) {
                                    continue;
                                }
                                commaStart = -1;
                                if (isListTerminator(kind)) {
                                    break;
                                }
                                parseExpected(27 /* CommaToken */, getExpectedCommaDiagnostic(kind));
                                if (considerSemicolonAsDelimiter && token() === 26 /* SemicolonToken */ && !scanner2.hasPrecedingLineBreak()) {
                                    nextToken();
                                }
                                if (startPos === scanner2.getStartPos()) {
                                    nextToken();
                                }
                                continue;
                            }
                            if (isListTerminator(kind)) {
                                break;
                            }
                            if (abortParsingListOrMoveToNextToken(kind)) {
                                break;
                            }
                        }
                        parsingContext = saveParsingContext;
                        return createNodeArray(list, listPos, 
                        /*end*/
                        void 0, commaStart >= 0);
                    }
                    function getExpectedCommaDiagnostic(kind) {
                        return kind === 6 /* EnumMembers */ ? Diagnostics.An_enum_member_name_must_be_followed_by_a_or : void 0;
                    }
                    function createMissingList() {
                        const list = createNodeArray([], getNodePos());
                        list.isMissingList = true;
                        return list;
                    }
                    function isMissingList(arr) {
                        return !!arr.isMissingList;
                    }
                    function parseBracketedList(kind, parseElement, open, close) {
                        if (parseExpected(open)) {
                            const result = parseDelimitedList(kind, parseElement);
                            parseExpected(close);
                            return result;
                        }
                        return createMissingList();
                    }
                    function parseEntityName(allowReservedWords, diagnosticMessage) {
                        const pos = getNodePos();
                        let entity = allowReservedWords ? parseIdentifierName(diagnosticMessage) : parseIdentifier(diagnosticMessage);
                        while (parseOptional(24 /* DotToken */)) {
                            if (token() === 29 /* LessThanToken */) {
                                break;
                            }
                            entity = finishNode(factory2.createQualifiedName(entity, parseRightSideOfDot(allowReservedWords, 
                            /* allowPrivateIdentifiers */
                            false)), pos);
                        }
                        return entity;
                    }
                    function createQualifiedName(entity, name) {
                        return finishNode(factory2.createQualifiedName(entity, name), entity.pos);
                    }
                    function parseRightSideOfDot(allowIdentifierNames, allowPrivateIdentifiers) {
                        if (scanner2.hasPrecedingLineBreak() && tokenIsIdentifierOrKeyword(token())) {
                            const matchesPattern = lookAhead(nextTokenIsIdentifierOrKeywordOnSameLine);
                            if (matchesPattern) {
                                return createMissingNode(79 /* Identifier */, 
                                /*reportAtCurrentPosition*/
                                true, Diagnostics.Identifier_expected);
                            }
                        }
                        if (token() === 80 /* PrivateIdentifier */) {
                            const node = parsePrivateIdentifier();
                            return allowPrivateIdentifiers ? node : createMissingNode(79 /* Identifier */, 
                            /*reportAtCurrentPosition*/
                            true, Diagnostics.Identifier_expected);
                        }
                        return allowIdentifierNames ? parseIdentifierName() : parseIdentifier();
                    }
                    function parseTemplateSpans(isTaggedTemplate) {
                        const pos = getNodePos();
                        const list = [];
                        let node;
                        do {
                            node = parseTemplateSpan(isTaggedTemplate);
                            list.push(node);
                        } while (node.literal.kind === 16 /* TemplateMiddle */);
                        return createNodeArray(list, pos);
                    }
                    function parseTemplateExpression(isTaggedTemplate) {
                        const pos = getNodePos();
                        return finishNode(factory2.createTemplateExpression(parseTemplateHead(isTaggedTemplate), parseTemplateSpans(isTaggedTemplate)), pos);
                    }
                    function parseTemplateType() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTemplateLiteralType(parseTemplateHead(
                        /*isTaggedTemplate*/
                        false), parseTemplateTypeSpans()), pos);
                    }
                    function parseTemplateTypeSpans() {
                        const pos = getNodePos();
                        const list = [];
                        let node;
                        do {
                            node = parseTemplateTypeSpan();
                            list.push(node);
                        } while (node.literal.kind === 16 /* TemplateMiddle */);
                        return createNodeArray(list, pos);
                    }
                    function parseTemplateTypeSpan() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTemplateLiteralTypeSpan(parseType(), parseLiteralOfTemplateSpan(
                        /*isTaggedTemplate*/
                        false)), pos);
                    }
                    function parseLiteralOfTemplateSpan(isTaggedTemplate) {
                        if (token() === 19 /* CloseBraceToken */) {
                            reScanTemplateToken(isTaggedTemplate);
                            return parseTemplateMiddleOrTemplateTail();
                        }
                        else {
                            return parseExpectedToken(17 /* TemplateTail */, Diagnostics._0_expected, tokenToString(19 /* CloseBraceToken */));
                        }
                    }
                    function parseTemplateSpan(isTaggedTemplate) {
                        const pos = getNodePos();
                        return finishNode(factory2.createTemplateSpan(allowInAnd(parseExpression), parseLiteralOfTemplateSpan(isTaggedTemplate)), pos);
                    }
                    function parseLiteralNode() {
                        return parseLiteralLikeNode(token());
                    }
                    function parseTemplateHead(isTaggedTemplate) {
                        if (isTaggedTemplate) {
                            reScanTemplateHeadOrNoSubstitutionTemplate();
                        }
                        const fragment = parseLiteralLikeNode(token());
                        Debug.assert(fragment.kind === 15 /* TemplateHead */, "Template head has wrong token kind");
                        return fragment;
                    }
                    function parseTemplateMiddleOrTemplateTail() {
                        const fragment = parseLiteralLikeNode(token());
                        Debug.assert(fragment.kind === 16 /* TemplateMiddle */ || fragment.kind === 17 /* TemplateTail */, "Template fragment has wrong token kind");
                        return fragment;
                    }
                    function getTemplateLiteralRawText(kind) {
                        const isLast = kind === 14 /* NoSubstitutionTemplateLiteral */ || kind === 17 /* TemplateTail */;
                        const tokenText = scanner2.getTokenText();
                        return tokenText.substring(1, tokenText.length - (scanner2.isUnterminated() ? 0 : isLast ? 1 : 2));
                    }
                    function parseLiteralLikeNode(kind) {
                        const pos = getNodePos();
                        const node = isTemplateLiteralKind(kind) ? factory2.createTemplateLiteralLikeNode(kind, scanner2.getTokenValue(), getTemplateLiteralRawText(kind), scanner2.getTokenFlags() & 2048 /* TemplateLiteralLikeFlags */) : (
                        // Octal literals are not allowed in strict mode or ES5
                        // Note that theoretically the following condition would hold true literals like 009,
                        // which is not octal. But because of how the scanner separates the tokens, we would
                        // never get a token like this. Instead, we would get 00 and 9 as two separate tokens.
                        // We also do not need to check for negatives because any prefix operator would be part of a
                        // parent unary expression.
                        kind === 8 /* NumericLiteral */ ? factoryCreateNumericLiteral(scanner2.getTokenValue(), scanner2.getNumericLiteralFlags()) : kind === 10 /* StringLiteral */ ? factoryCreateStringLiteral(scanner2.getTokenValue(), 
                        /*isSingleQuote*/
                        void 0, scanner2.hasExtendedUnicodeEscape()) : isLiteralKind(kind) ? factoryCreateLiteralLikeNode(kind, scanner2.getTokenValue()) : Debug.fail());
                        if (scanner2.hasExtendedUnicodeEscape()) {
                            node.hasExtendedUnicodeEscape = true;
                        }
                        if (scanner2.isUnterminated()) {
                            node.isUnterminated = true;
                        }
                        nextToken();
                        return finishNode(node, pos);
                    }
                    function parseEntityNameOfTypeReference() {
                        return parseEntityName(
                        /*allowReservedWords*/
                        true, Diagnostics.Type_expected);
                    }
                    function parseTypeArgumentsOfTypeReference() {
                        if (!scanner2.hasPrecedingLineBreak() && reScanLessThanToken() === 29 /* LessThanToken */) {
                            return parseBracketedList(20 /* TypeArguments */, parseType, 29 /* LessThanToken */, 31 /* GreaterThanToken */);
                        }
                    }
                    function parseTypeReference() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTypeReferenceNode(parseEntityNameOfTypeReference(), parseTypeArgumentsOfTypeReference()), pos);
                    }
                    function typeHasArrowFunctionBlockingParseError(node) {
                        switch (node.kind) {
                            case 180 /* TypeReference */:
                                return nodeIsMissing(node.typeName);
                            case 181 /* FunctionType */:
                            case 182 /* ConstructorType */: {
                                const { parameters, type } = node;
                                return isMissingList(parameters) || typeHasArrowFunctionBlockingParseError(type);
                            }
                            case 193 /* ParenthesizedType */:
                                return typeHasArrowFunctionBlockingParseError(node.type);
                            default:
                                return false;
                        }
                    }
                    function parseThisTypePredicate(lhs) {
                        nextToken();
                        return finishNode(factory2.createTypePredicateNode(
                        /*assertsModifier*/
                        void 0, lhs, parseType()), lhs.pos);
                    }
                    function parseThisTypeNode() {
                        const pos = getNodePos();
                        nextToken();
                        return finishNode(factory2.createThisTypeNode(), pos);
                    }
                    function parseJSDocAllType() {
                        const pos = getNodePos();
                        nextToken();
                        return finishNode(factory2.createJSDocAllType(), pos);
                    }
                    function parseJSDocNonNullableType() {
                        const pos = getNodePos();
                        nextToken();
                        return finishNode(factory2.createJSDocNonNullableType(parseNonArrayType(), 
                        /*postfix*/
                        false), pos);
                    }
                    function parseJSDocUnknownOrNullableType() {
                        const pos = getNodePos();
                        nextToken();
                        if (token() === 27 /* CommaToken */ || token() === 19 /* CloseBraceToken */ || token() === 21 /* CloseParenToken */ || token() === 31 /* GreaterThanToken */ || token() === 63 /* EqualsToken */ || token() === 51 /* BarToken */) {
                            return finishNode(factory2.createJSDocUnknownType(), pos);
                        }
                        else {
                            return finishNode(factory2.createJSDocNullableType(parseType(), 
                            /*postfix*/
                            false), pos);
                        }
                    }
                    function parseJSDocFunctionType() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        if (lookAhead(nextTokenIsOpenParen)) {
                            nextToken();
                            const parameters = parseParameters(4 /* Type */ | 32 /* JSDoc */);
                            const type = parseReturnType(58 /* ColonToken */, 
                            /*isType*/
                            false);
                            return withJSDoc(finishNode(factory2.createJSDocFunctionType(parameters, type), pos), hasJSDoc);
                        }
                        return finishNode(factory2.createTypeReferenceNode(parseIdentifierName(), 
                        /*typeArguments*/
                        void 0), pos);
                    }
                    function parseJSDocParameter() {
                        const pos = getNodePos();
                        let name;
                        if (token() === 108 /* ThisKeyword */ || token() === 103 /* NewKeyword */) {
                            name = parseIdentifierName();
                            parseExpected(58 /* ColonToken */);
                        }
                        return finishNode(factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, 
                        // TODO(rbuckton): JSDoc parameters don't have names (except `this`/`new`), should we manufacture an empty identifier?
                        name, 
                        /*questionToken*/
                        void 0, parseJSDocType(), 
                        /*initializer*/
                        void 0), pos);
                    }
                    function parseJSDocType() {
                        scanner2.setInJSDocType(true);
                        const pos = getNodePos();
                        if (parseOptional(142 /* ModuleKeyword */)) {
                            const moduleTag = factory2.createJSDocNamepathType(
                            /*type*/
                            void 0);
                            terminate: while (true) {
                                switch (token()) {
                                    case 19 /* CloseBraceToken */:
                                    case 1 /* EndOfFileToken */:
                                    case 27 /* CommaToken */:
                                    case 5 /* WhitespaceTrivia */:
                                        break terminate;
                                    default:
                                        nextTokenJSDoc();
                                }
                            }
                            scanner2.setInJSDocType(false);
                            return finishNode(moduleTag, pos);
                        }
                        const hasDotDotDot = parseOptional(25 /* DotDotDotToken */);
                        let type = parseTypeOrTypePredicate();
                        scanner2.setInJSDocType(false);
                        if (hasDotDotDot) {
                            type = finishNode(factory2.createJSDocVariadicType(type), pos);
                        }
                        if (token() === 63 /* EqualsToken */) {
                            nextToken();
                            return finishNode(factory2.createJSDocOptionalType(type), pos);
                        }
                        return type;
                    }
                    function parseTypeQuery() {
                        const pos = getNodePos();
                        parseExpected(112 /* TypeOfKeyword */);
                        const entityName = parseEntityName(
                        /*allowReservedWords*/
                        true);
                        const typeArguments = !scanner2.hasPrecedingLineBreak() ? tryParseTypeArguments() : void 0;
                        return finishNode(factory2.createTypeQueryNode(entityName, typeArguments), pos);
                    }
                    function parseTypeParameter() {
                        const pos = getNodePos();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        false, 
                        /*permitConstAsModifier*/
                        true);
                        const name = parseIdentifier();
                        let constraint;
                        let expression;
                        if (parseOptional(94 /* ExtendsKeyword */)) {
                            if (isStartOfType() || !isStartOfExpression()) {
                                constraint = parseType();
                            }
                            else {
                                expression = parseUnaryExpressionOrHigher();
                            }
                        }
                        const defaultType = parseOptional(63 /* EqualsToken */) ? parseType() : void 0;
                        const node = factory2.createTypeParameterDeclaration(modifiers, name, constraint, defaultType);
                        node.expression = expression;
                        return finishNode(node, pos);
                    }
                    function parseTypeParameters() {
                        if (token() === 29 /* LessThanToken */) {
                            return parseBracketedList(19 /* TypeParameters */, parseTypeParameter, 29 /* LessThanToken */, 31 /* GreaterThanToken */);
                        }
                    }
                    function isStartOfParameter(isJSDocParameter) {
                        return token() === 25 /* DotDotDotToken */ || isBindingIdentifierOrPrivateIdentifierOrPattern() || isModifierKind(token()) || token() === 59 /* AtToken */ || isStartOfType(
                        /*inStartOfParameter*/
                        !isJSDocParameter);
                    }
                    function parseNameOfParameter(modifiers) {
                        const name = parseIdentifierOrPattern(Diagnostics.Private_identifiers_cannot_be_used_as_parameters);
                        if (getFullWidth(name) === 0 && !some(modifiers) && isModifierKind(token())) {
                            nextToken();
                        }
                        return name;
                    }
                    function isParameterNameStart() {
                        return isBindingIdentifier() || token() === 22 /* OpenBracketToken */ || token() === 18 /* OpenBraceToken */;
                    }
                    function parseParameter(inOuterAwaitContext) {
                        return parseParameterWorker(inOuterAwaitContext);
                    }
                    function parseParameterForSpeculation(inOuterAwaitContext) {
                        return parseParameterWorker(inOuterAwaitContext, 
                        /*allowAmbiguity*/
                        false);
                    }
                    function parseParameterWorker(inOuterAwaitContext, allowAmbiguity = true) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = inOuterAwaitContext ? doInAwaitContext(() => parseModifiers(
                        /*allowDecorators*/
                        true)) : doOutsideOfAwaitContext(() => parseModifiers(
                        /*allowDecorators*/
                        true));
                        if (token() === 108 /* ThisKeyword */) {
                            const node2 = factory2.createParameterDeclaration(modifiers, 
                            /*dotDotDotToken*/
                            void 0, createIdentifier(
                            /*isIdentifier*/
                            true), 
                            /*questionToken*/
                            void 0, parseTypeAnnotation(), 
                            /*initializer*/
                            void 0);
                            const modifier = firstOrUndefined(modifiers);
                            if (modifier) {
                                parseErrorAtRange(modifier, Diagnostics.Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters);
                            }
                            return withJSDoc(finishNode(node2, pos), hasJSDoc);
                        }
                        const savedTopLevel = topLevel;
                        topLevel = false;
                        const dotDotDotToken = parseOptionalToken(25 /* DotDotDotToken */);
                        if (!allowAmbiguity && !isParameterNameStart()) {
                            return void 0;
                        }
                        const node = withJSDoc(finishNode(factory2.createParameterDeclaration(modifiers, dotDotDotToken, parseNameOfParameter(modifiers), parseOptionalToken(57 /* QuestionToken */), parseTypeAnnotation(), parseInitializer()), pos), hasJSDoc);
                        topLevel = savedTopLevel;
                        return node;
                    }
                    function parseReturnType(returnToken, isType) {
                        if (shouldParseReturnType(returnToken, isType)) {
                            return allowConditionalTypesAnd(parseTypeOrTypePredicate);
                        }
                    }
                    function shouldParseReturnType(returnToken, isType) {
                        if (returnToken === 38 /* EqualsGreaterThanToken */) {
                            parseExpected(returnToken);
                            return true;
                        }
                        else if (parseOptional(58 /* ColonToken */)) {
                            return true;
                        }
                        else if (isType && token() === 38 /* EqualsGreaterThanToken */) {
                            parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(58 /* ColonToken */));
                            nextToken();
                            return true;
                        }
                        return false;
                    }
                    function parseParametersWorker(flags, allowAmbiguity) {
                        const savedYieldContext = inYieldContext();
                        const savedAwaitContext = inAwaitContext();
                        setYieldContext(!!(flags & 1 /* Yield */));
                        setAwaitContext(!!(flags & 2 /* Await */));
                        const parameters = flags & 32 /* JSDoc */ ? parseDelimitedList(17 /* JSDocParameters */, parseJSDocParameter) : parseDelimitedList(16 /* Parameters */, () => allowAmbiguity ? parseParameter(savedAwaitContext) : parseParameterForSpeculation(savedAwaitContext));
                        setYieldContext(savedYieldContext);
                        setAwaitContext(savedAwaitContext);
                        return parameters;
                    }
                    function parseParameters(flags) {
                        if (!parseExpected(20 /* OpenParenToken */)) {
                            return createMissingList();
                        }
                        const parameters = parseParametersWorker(flags, 
                        /*allowAmbiguity*/
                        true);
                        parseExpected(21 /* CloseParenToken */);
                        return parameters;
                    }
                    function parseTypeMemberSemicolon() {
                        if (parseOptional(27 /* CommaToken */)) {
                            return;
                        }
                        parseSemicolon();
                    }
                    function parseSignatureMember(kind) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        if (kind === 177 /* ConstructSignature */) {
                            parseExpected(103 /* NewKeyword */);
                        }
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(4 /* Type */);
                        const type = parseReturnType(58 /* ColonToken */, 
                        /*isType*/
                        true);
                        parseTypeMemberSemicolon();
                        const node = kind === 176 /* CallSignature */ ? factory2.createCallSignature(typeParameters, parameters, type) : factory2.createConstructSignature(typeParameters, parameters, type);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function isIndexSignature() {
                        return token() === 22 /* OpenBracketToken */ && lookAhead(isUnambiguouslyIndexSignature);
                    }
                    function isUnambiguouslyIndexSignature() {
                        nextToken();
                        if (token() === 25 /* DotDotDotToken */ || token() === 23 /* CloseBracketToken */) {
                            return true;
                        }
                        if (isModifierKind(token())) {
                            nextToken();
                            if (isIdentifier2()) {
                                return true;
                            }
                        }
                        else if (!isIdentifier2()) {
                            return false;
                        }
                        else {
                            nextToken();
                        }
                        if (token() === 58 /* ColonToken */ || token() === 27 /* CommaToken */) {
                            return true;
                        }
                        if (token() !== 57 /* QuestionToken */) {
                            return false;
                        }
                        nextToken();
                        return token() === 58 /* ColonToken */ || token() === 27 /* CommaToken */ || token() === 23 /* CloseBracketToken */;
                    }
                    function parseIndexSignatureDeclaration(pos, hasJSDoc, modifiers) {
                        const parameters = parseBracketedList(16 /* Parameters */, () => parseParameter(
                        /*inOuterAwaitContext*/
                        false), 22 /* OpenBracketToken */, 23 /* CloseBracketToken */);
                        const type = parseTypeAnnotation();
                        parseTypeMemberSemicolon();
                        const node = factory2.createIndexSignature(modifiers, parameters, type);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parsePropertyOrMethodSignature(pos, hasJSDoc, modifiers) {
                        const name = parsePropertyName();
                        const questionToken = parseOptionalToken(57 /* QuestionToken */);
                        let node;
                        if (token() === 20 /* OpenParenToken */ || token() === 29 /* LessThanToken */) {
                            const typeParameters = parseTypeParameters();
                            const parameters = parseParameters(4 /* Type */);
                            const type = parseReturnType(58 /* ColonToken */, 
                            /*isType*/
                            true);
                            node = factory2.createMethodSignature(modifiers, name, questionToken, typeParameters, parameters, type);
                        }
                        else {
                            const type = parseTypeAnnotation();
                            node = factory2.createPropertySignature(modifiers, name, questionToken, type);
                            if (token() === 63 /* EqualsToken */)
                                node.initializer = parseInitializer();
                        }
                        parseTypeMemberSemicolon();
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function isTypeMemberStart() {
                        if (token() === 20 /* OpenParenToken */ || token() === 29 /* LessThanToken */ || token() === 137 /* GetKeyword */ || token() === 151 /* SetKeyword */) {
                            return true;
                        }
                        let idToken = false;
                        while (isModifierKind(token())) {
                            idToken = true;
                            nextToken();
                        }
                        if (token() === 22 /* OpenBracketToken */) {
                            return true;
                        }
                        if (isLiteralPropertyName()) {
                            idToken = true;
                            nextToken();
                        }
                        if (idToken) {
                            return token() === 20 /* OpenParenToken */ || token() === 29 /* LessThanToken */ || token() === 57 /* QuestionToken */ || token() === 58 /* ColonToken */ || token() === 27 /* CommaToken */ || canParseSemicolon();
                        }
                        return false;
                    }
                    function parseTypeMember() {
                        if (token() === 20 /* OpenParenToken */ || token() === 29 /* LessThanToken */) {
                            return parseSignatureMember(176 /* CallSignature */);
                        }
                        if (token() === 103 /* NewKeyword */ && lookAhead(nextTokenIsOpenParenOrLessThan)) {
                            return parseSignatureMember(177 /* ConstructSignature */);
                        }
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        false);
                        if (parseContextualModifier(137 /* GetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 174 /* GetAccessor */, 4 /* Type */);
                        }
                        if (parseContextualModifier(151 /* SetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 175 /* SetAccessor */, 4 /* Type */);
                        }
                        if (isIndexSignature()) {
                            return parseIndexSignatureDeclaration(pos, hasJSDoc, modifiers);
                        }
                        return parsePropertyOrMethodSignature(pos, hasJSDoc, modifiers);
                    }
                    function nextTokenIsOpenParenOrLessThan() {
                        nextToken();
                        return token() === 20 /* OpenParenToken */ || token() === 29 /* LessThanToken */;
                    }
                    function nextTokenIsDot() {
                        return nextToken() === 24 /* DotToken */;
                    }
                    function nextTokenIsOpenParenOrLessThanOrDot() {
                        switch (nextToken()) {
                            case 20 /* OpenParenToken */:
                            case 29 /* LessThanToken */:
                            case 24 /* DotToken */:
                                return true;
                        }
                        return false;
                    }
                    function parseTypeLiteral() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTypeLiteralNode(parseObjectTypeMembers()), pos);
                    }
                    function parseObjectTypeMembers() {
                        let members;
                        if (parseExpected(18 /* OpenBraceToken */)) {
                            members = parseList(4 /* TypeMembers */, parseTypeMember);
                            parseExpected(19 /* CloseBraceToken */);
                        }
                        else {
                            members = createMissingList();
                        }
                        return members;
                    }
                    function isStartOfMappedType() {
                        nextToken();
                        if (token() === 39 /* PlusToken */ || token() === 40 /* MinusToken */) {
                            return nextToken() === 146 /* ReadonlyKeyword */;
                        }
                        if (token() === 146 /* ReadonlyKeyword */) {
                            nextToken();
                        }
                        return token() === 22 /* OpenBracketToken */ && nextTokenIsIdentifier() && nextToken() === 101 /* InKeyword */;
                    }
                    function parseMappedTypeParameter() {
                        const pos = getNodePos();
                        const name = parseIdentifierName();
                        parseExpected(101 /* InKeyword */);
                        const type = parseType();
                        return finishNode(factory2.createTypeParameterDeclaration(
                        /*modifiers*/
                        void 0, name, type, 
                        /*defaultType*/
                        void 0), pos);
                    }
                    function parseMappedType() {
                        const pos = getNodePos();
                        parseExpected(18 /* OpenBraceToken */);
                        let readonlyToken;
                        if (token() === 146 /* ReadonlyKeyword */ || token() === 39 /* PlusToken */ || token() === 40 /* MinusToken */) {
                            readonlyToken = parseTokenNode();
                            if (readonlyToken.kind !== 146 /* ReadonlyKeyword */) {
                                parseExpected(146 /* ReadonlyKeyword */);
                            }
                        }
                        parseExpected(22 /* OpenBracketToken */);
                        const typeParameter = parseMappedTypeParameter();
                        const nameType = parseOptional(128 /* AsKeyword */) ? parseType() : void 0;
                        parseExpected(23 /* CloseBracketToken */);
                        let questionToken;
                        if (token() === 57 /* QuestionToken */ || token() === 39 /* PlusToken */ || token() === 40 /* MinusToken */) {
                            questionToken = parseTokenNode();
                            if (questionToken.kind !== 57 /* QuestionToken */) {
                                parseExpected(57 /* QuestionToken */);
                            }
                        }
                        const type = parseTypeAnnotation();
                        parseSemicolon();
                        const members = parseList(4 /* TypeMembers */, parseTypeMember);
                        parseExpected(19 /* CloseBraceToken */);
                        return finishNode(factory2.createMappedTypeNode(readonlyToken, typeParameter, nameType, questionToken, type, members), pos);
                    }
                    function parseTupleElementType() {
                        const pos = getNodePos();
                        if (parseOptional(25 /* DotDotDotToken */)) {
                            return finishNode(factory2.createRestTypeNode(parseType()), pos);
                        }
                        const type = parseType();
                        if (isJSDocNullableType(type) && type.pos === type.type.pos) {
                            const node = factory2.createOptionalTypeNode(type.type);
                            setTextRange(node, type);
                            node.flags = type.flags;
                            return node;
                        }
                        return type;
                    }
                    function isNextTokenColonOrQuestionColon() {
                        return nextToken() === 58 /* ColonToken */ || token() === 57 /* QuestionToken */ && nextToken() === 58 /* ColonToken */;
                    }
                    function isTupleElementName() {
                        if (token() === 25 /* DotDotDotToken */) {
                            return tokenIsIdentifierOrKeyword(nextToken()) && isNextTokenColonOrQuestionColon();
                        }
                        return tokenIsIdentifierOrKeyword(token()) && isNextTokenColonOrQuestionColon();
                    }
                    function parseTupleElementNameOrTupleElementType() {
                        if (lookAhead(isTupleElementName)) {
                            const pos = getNodePos();
                            const hasJSDoc = hasPrecedingJSDocComment();
                            const dotDotDotToken = parseOptionalToken(25 /* DotDotDotToken */);
                            const name = parseIdentifierName();
                            const questionToken = parseOptionalToken(57 /* QuestionToken */);
                            parseExpected(58 /* ColonToken */);
                            const type = parseTupleElementType();
                            const node = factory2.createNamedTupleMember(dotDotDotToken, name, questionToken, type);
                            return withJSDoc(finishNode(node, pos), hasJSDoc);
                        }
                        return parseTupleElementType();
                    }
                    function parseTupleType() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTupleTypeNode(parseBracketedList(21 /* TupleElementTypes */, parseTupleElementNameOrTupleElementType, 22 /* OpenBracketToken */, 23 /* CloseBracketToken */)), pos);
                    }
                    function parseParenthesizedType() {
                        const pos = getNodePos();
                        parseExpected(20 /* OpenParenToken */);
                        const type = parseType();
                        parseExpected(21 /* CloseParenToken */);
                        return finishNode(factory2.createParenthesizedType(type), pos);
                    }
                    function parseModifiersForConstructorType() {
                        let modifiers;
                        if (token() === 126 /* AbstractKeyword */) {
                            const pos = getNodePos();
                            nextToken();
                            const modifier = finishNode(factoryCreateToken(126 /* AbstractKeyword */), pos);
                            modifiers = createNodeArray([modifier], pos);
                        }
                        return modifiers;
                    }
                    function parseFunctionOrConstructorType() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiersForConstructorType();
                        const isConstructorType = parseOptional(103 /* NewKeyword */);
                        Debug.assert(!modifiers || isConstructorType, "Per isStartOfFunctionOrConstructorType, a function type cannot have modifiers.");
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(4 /* Type */);
                        const type = parseReturnType(38 /* EqualsGreaterThanToken */, 
                        /*isType*/
                        false);
                        const node = isConstructorType ? factory2.createConstructorTypeNode(modifiers, typeParameters, parameters, type) : factory2.createFunctionTypeNode(typeParameters, parameters, type);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseKeywordAndNoDot() {
                        const node = parseTokenNode();
                        return token() === 24 /* DotToken */ ? void 0 : node;
                    }
                    function parseLiteralTypeNode(negative) {
                        const pos = getNodePos();
                        if (negative) {
                            nextToken();
                        }
                        let expression = token() === 110 /* TrueKeyword */ || token() === 95 /* FalseKeyword */ || token() === 104 /* NullKeyword */ ? parseTokenNode() : parseLiteralLikeNode(token());
                        if (negative) {
                            expression = finishNode(factory2.createPrefixUnaryExpression(40 /* MinusToken */, expression), pos);
                        }
                        return finishNode(factory2.createLiteralTypeNode(expression), pos);
                    }
                    function isStartOfTypeOfImportType() {
                        nextToken();
                        return token() === 100 /* ImportKeyword */;
                    }
                    function parseImportTypeAssertions() {
                        const pos = getNodePos();
                        const openBracePosition = scanner2.getTokenPos();
                        parseExpected(18 /* OpenBraceToken */);
                        const multiLine = scanner2.hasPrecedingLineBreak();
                        parseExpected(130 /* AssertKeyword */);
                        parseExpected(58 /* ColonToken */);
                        const clause = parseAssertClause(
                        /*skipAssertKeyword*/
                        true);
                        if (!parseExpected(19 /* CloseBraceToken */)) {
                            const lastError = lastOrUndefined(parseDiagnostics);
                            if (lastError && lastError.code === Diagnostics._0_expected.code) {
                                addRelatedInfo(lastError, createDetachedDiagnostic(fileName, openBracePosition, 1, Diagnostics.The_parser_expected_to_find_a_1_to_match_the_0_token_here, "{", "}"));
                            }
                        }
                        return finishNode(factory2.createImportTypeAssertionContainer(clause, multiLine), pos);
                    }
                    function parseImportType() {
                        sourceFlags |= 2097152 /* PossiblyContainsDynamicImport */;
                        const pos = getNodePos();
                        const isTypeOf = parseOptional(112 /* TypeOfKeyword */);
                        parseExpected(100 /* ImportKeyword */);
                        parseExpected(20 /* OpenParenToken */);
                        const type = parseType();
                        let assertions;
                        if (parseOptional(27 /* CommaToken */)) {
                            assertions = parseImportTypeAssertions();
                        }
                        parseExpected(21 /* CloseParenToken */);
                        const qualifier = parseOptional(24 /* DotToken */) ? parseEntityNameOfTypeReference() : void 0;
                        const typeArguments = parseTypeArgumentsOfTypeReference();
                        return finishNode(factory2.createImportTypeNode(type, assertions, qualifier, typeArguments, isTypeOf), pos);
                    }
                    function nextTokenIsNumericOrBigIntLiteral() {
                        nextToken();
                        return token() === 8 /* NumericLiteral */ || token() === 9 /* BigIntLiteral */;
                    }
                    function parseNonArrayType() {
                        switch (token()) {
                            case 131 /* AnyKeyword */:
                            case 157 /* UnknownKeyword */:
                            case 152 /* StringKeyword */:
                            case 148 /* NumberKeyword */:
                            case 160 /* BigIntKeyword */:
                            case 153 /* SymbolKeyword */:
                            case 134 /* BooleanKeyword */:
                            case 155 /* UndefinedKeyword */:
                            case 144 /* NeverKeyword */:
                            case 149 /* ObjectKeyword */:
                                return tryParse(parseKeywordAndNoDot) || parseTypeReference();
                            case 66 /* AsteriskEqualsToken */:
                                scanner2.reScanAsteriskEqualsToken();
                            case 41 /* AsteriskToken */:
                                return parseJSDocAllType();
                            case 60 /* QuestionQuestionToken */:
                                scanner2.reScanQuestionToken();
                            case 57 /* QuestionToken */:
                                return parseJSDocUnknownOrNullableType();
                            case 98 /* FunctionKeyword */:
                                return parseJSDocFunctionType();
                            case 53 /* ExclamationToken */:
                                return parseJSDocNonNullableType();
                            case 14 /* NoSubstitutionTemplateLiteral */:
                            case 10 /* StringLiteral */:
                            case 8 /* NumericLiteral */:
                            case 9 /* BigIntLiteral */:
                            case 110 /* TrueKeyword */:
                            case 95 /* FalseKeyword */:
                            case 104 /* NullKeyword */:
                                return parseLiteralTypeNode();
                            case 40 /* MinusToken */:
                                return lookAhead(nextTokenIsNumericOrBigIntLiteral) ? parseLiteralTypeNode(
                                /*negative*/
                                true) : parseTypeReference();
                            case 114 /* VoidKeyword */:
                                return parseTokenNode();
                            case 108 /* ThisKeyword */: {
                                const thisKeyword = parseThisTypeNode();
                                if (token() === 140 /* IsKeyword */ && !scanner2.hasPrecedingLineBreak()) {
                                    return parseThisTypePredicate(thisKeyword);
                                }
                                else {
                                    return thisKeyword;
                                }
                            }
                            case 112 /* TypeOfKeyword */:
                                return lookAhead(isStartOfTypeOfImportType) ? parseImportType() : parseTypeQuery();
                            case 18 /* OpenBraceToken */:
                                return lookAhead(isStartOfMappedType) ? parseMappedType() : parseTypeLiteral();
                            case 22 /* OpenBracketToken */:
                                return parseTupleType();
                            case 20 /* OpenParenToken */:
                                return parseParenthesizedType();
                            case 100 /* ImportKeyword */:
                                return parseImportType();
                            case 129 /* AssertsKeyword */:
                                return lookAhead(nextTokenIsIdentifierOrKeywordOnSameLine) ? parseAssertsTypePredicate() : parseTypeReference();
                            case 15 /* TemplateHead */:
                                return parseTemplateType();
                            default:
                                return parseTypeReference();
                        }
                    }
                    function isStartOfType(inStartOfParameter) {
                        switch (token()) {
                            case 131 /* AnyKeyword */:
                            case 157 /* UnknownKeyword */:
                            case 152 /* StringKeyword */:
                            case 148 /* NumberKeyword */:
                            case 160 /* BigIntKeyword */:
                            case 134 /* BooleanKeyword */:
                            case 146 /* ReadonlyKeyword */:
                            case 153 /* SymbolKeyword */:
                            case 156 /* UniqueKeyword */:
                            case 114 /* VoidKeyword */:
                            case 155 /* UndefinedKeyword */:
                            case 104 /* NullKeyword */:
                            case 108 /* ThisKeyword */:
                            case 112 /* TypeOfKeyword */:
                            case 144 /* NeverKeyword */:
                            case 18 /* OpenBraceToken */:
                            case 22 /* OpenBracketToken */:
                            case 29 /* LessThanToken */:
                            case 51 /* BarToken */:
                            case 50 /* AmpersandToken */:
                            case 103 /* NewKeyword */:
                            case 10 /* StringLiteral */:
                            case 8 /* NumericLiteral */:
                            case 9 /* BigIntLiteral */:
                            case 110 /* TrueKeyword */:
                            case 95 /* FalseKeyword */:
                            case 149 /* ObjectKeyword */:
                            case 41 /* AsteriskToken */:
                            case 57 /* QuestionToken */:
                            case 53 /* ExclamationToken */:
                            case 25 /* DotDotDotToken */:
                            case 138 /* InferKeyword */:
                            case 100 /* ImportKeyword */:
                            case 129 /* AssertsKeyword */:
                            case 14 /* NoSubstitutionTemplateLiteral */:
                            case 15 /* TemplateHead */:
                                return true;
                            case 98 /* FunctionKeyword */:
                                return !inStartOfParameter;
                            case 40 /* MinusToken */:
                                return !inStartOfParameter && lookAhead(nextTokenIsNumericOrBigIntLiteral);
                            case 20 /* OpenParenToken */:
                                return !inStartOfParameter && lookAhead(isStartOfParenthesizedOrFunctionType);
                            default:
                                return isIdentifier2();
                        }
                    }
                    function isStartOfParenthesizedOrFunctionType() {
                        nextToken();
                        return token() === 21 /* CloseParenToken */ || isStartOfParameter(
                        /*isJSDocParameter*/
                        false) || isStartOfType();
                    }
                    function parsePostfixTypeOrHigher() {
                        const pos = getNodePos();
                        let type = parseNonArrayType();
                        while (!scanner2.hasPrecedingLineBreak()) {
                            switch (token()) {
                                case 53 /* ExclamationToken */:
                                    nextToken();
                                    type = finishNode(factory2.createJSDocNonNullableType(type, 
                                    /*postfix*/
                                    true), pos);
                                    break;
                                case 57 /* QuestionToken */:
                                    if (lookAhead(nextTokenIsStartOfType)) {
                                        return type;
                                    }
                                    nextToken();
                                    type = finishNode(factory2.createJSDocNullableType(type, 
                                    /*postfix*/
                                    true), pos);
                                    break;
                                case 22 /* OpenBracketToken */:
                                    parseExpected(22 /* OpenBracketToken */);
                                    if (isStartOfType()) {
                                        const indexType = parseType();
                                        parseExpected(23 /* CloseBracketToken */);
                                        type = finishNode(factory2.createIndexedAccessTypeNode(type, indexType), pos);
                                    }
                                    else {
                                        parseExpected(23 /* CloseBracketToken */);
                                        type = finishNode(factory2.createArrayTypeNode(type), pos);
                                    }
                                    break;
                                default:
                                    return type;
                            }
                        }
                        return type;
                    }
                    function parseTypeOperator(operator) {
                        const pos = getNodePos();
                        parseExpected(operator);
                        return finishNode(factory2.createTypeOperatorNode(operator, parseTypeOperatorOrHigher()), pos);
                    }
                    function tryParseConstraintOfInferType() {
                        if (parseOptional(94 /* ExtendsKeyword */)) {
                            const constraint = disallowConditionalTypesAnd(parseType);
                            if (inDisallowConditionalTypesContext() || token() !== 57 /* QuestionToken */) {
                                return constraint;
                            }
                        }
                    }
                    function parseTypeParameterOfInferType() {
                        const pos = getNodePos();
                        const name = parseIdentifier();
                        const constraint = tryParse(tryParseConstraintOfInferType);
                        const node = factory2.createTypeParameterDeclaration(
                        /*modifiers*/
                        void 0, name, constraint);
                        return finishNode(node, pos);
                    }
                    function parseInferType() {
                        const pos = getNodePos();
                        parseExpected(138 /* InferKeyword */);
                        return finishNode(factory2.createInferTypeNode(parseTypeParameterOfInferType()), pos);
                    }
                    function parseTypeOperatorOrHigher() {
                        const operator = token();
                        switch (operator) {
                            case 141 /* KeyOfKeyword */:
                            case 156 /* UniqueKeyword */:
                            case 146 /* ReadonlyKeyword */:
                                return parseTypeOperator(operator);
                            case 138 /* InferKeyword */:
                                return parseInferType();
                        }
                        return allowConditionalTypesAnd(parsePostfixTypeOrHigher);
                    }
                    function parseFunctionOrConstructorTypeToError(isInUnionType) {
                        if (isStartOfFunctionTypeOrConstructorType()) {
                            const type = parseFunctionOrConstructorType();
                            let diagnostic;
                            if (isFunctionTypeNode(type)) {
                                diagnostic = isInUnionType ? Diagnostics.Function_type_notation_must_be_parenthesized_when_used_in_a_union_type : Diagnostics.Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type;
                            }
                            else {
                                diagnostic = isInUnionType ? Diagnostics.Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type : Diagnostics.Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type;
                            }
                            parseErrorAtRange(type, diagnostic);
                            return type;
                        }
                        return void 0;
                    }
                    function parseUnionOrIntersectionType(operator, parseConstituentType, createTypeNode) {
                        const pos = getNodePos();
                        const isUnionType = operator === 51 /* BarToken */;
                        const hasLeadingOperator = parseOptional(operator);
                        let type = hasLeadingOperator && parseFunctionOrConstructorTypeToError(isUnionType) || parseConstituentType();
                        if (token() === operator || hasLeadingOperator) {
                            const types = [type];
                            while (parseOptional(operator)) {
                                types.push(parseFunctionOrConstructorTypeToError(isUnionType) || parseConstituentType());
                            }
                            type = finishNode(createTypeNode(createNodeArray(types, pos)), pos);
                        }
                        return type;
                    }
                    function parseIntersectionTypeOrHigher() {
                        return parseUnionOrIntersectionType(50 /* AmpersandToken */, parseTypeOperatorOrHigher, factory2.createIntersectionTypeNode);
                    }
                    function parseUnionTypeOrHigher() {
                        return parseUnionOrIntersectionType(51 /* BarToken */, parseIntersectionTypeOrHigher, factory2.createUnionTypeNode);
                    }
                    function nextTokenIsNewKeyword() {
                        nextToken();
                        return token() === 103 /* NewKeyword */;
                    }
                    function isStartOfFunctionTypeOrConstructorType() {
                        if (token() === 29 /* LessThanToken */) {
                            return true;
                        }
                        if (token() === 20 /* OpenParenToken */ && lookAhead(isUnambiguouslyStartOfFunctionType)) {
                            return true;
                        }
                        return token() === 103 /* NewKeyword */ || token() === 126 /* AbstractKeyword */ && lookAhead(nextTokenIsNewKeyword);
                    }
                    function skipParameterStart() {
                        if (isModifierKind(token())) {
                            parseModifiers(
                            /*allowDecorators*/
                            false);
                        }
                        if (isIdentifier2() || token() === 108 /* ThisKeyword */) {
                            nextToken();
                            return true;
                        }
                        if (token() === 22 /* OpenBracketToken */ || token() === 18 /* OpenBraceToken */) {
                            const previousErrorCount = parseDiagnostics.length;
                            parseIdentifierOrPattern();
                            return previousErrorCount === parseDiagnostics.length;
                        }
                        return false;
                    }
                    function isUnambiguouslyStartOfFunctionType() {
                        nextToken();
                        if (token() === 21 /* CloseParenToken */ || token() === 25 /* DotDotDotToken */) {
                            return true;
                        }
                        if (skipParameterStart()) {
                            if (token() === 58 /* ColonToken */ || token() === 27 /* CommaToken */ || token() === 57 /* QuestionToken */ || token() === 63 /* EqualsToken */) {
                                return true;
                            }
                            if (token() === 21 /* CloseParenToken */) {
                                nextToken();
                                if (token() === 38 /* EqualsGreaterThanToken */) {
                                    return true;
                                }
                            }
                        }
                        return false;
                    }
                    function parseTypeOrTypePredicate() {
                        const pos = getNodePos();
                        const typePredicateVariable = isIdentifier2() && tryParse(parseTypePredicatePrefix);
                        const type = parseType();
                        if (typePredicateVariable) {
                            return finishNode(factory2.createTypePredicateNode(
                            /*assertsModifier*/
                            void 0, typePredicateVariable, type), pos);
                        }
                        else {
                            return type;
                        }
                    }
                    function parseTypePredicatePrefix() {
                        const id = parseIdentifier();
                        if (token() === 140 /* IsKeyword */ && !scanner2.hasPrecedingLineBreak()) {
                            nextToken();
                            return id;
                        }
                    }
                    function parseAssertsTypePredicate() {
                        const pos = getNodePos();
                        const assertsModifier = parseExpectedToken(129 /* AssertsKeyword */);
                        const parameterName = token() === 108 /* ThisKeyword */ ? parseThisTypeNode() : parseIdentifier();
                        const type = parseOptional(140 /* IsKeyword */) ? parseType() : void 0;
                        return finishNode(factory2.createTypePredicateNode(assertsModifier, parameterName, type), pos);
                    }
                    function parseType() {
                        if (contextFlags & 40960 /* TypeExcludesFlags */) {
                            return doOutsideOfContext(40960 /* TypeExcludesFlags */, parseType);
                        }
                        if (isStartOfFunctionTypeOrConstructorType()) {
                            return parseFunctionOrConstructorType();
                        }
                        const pos = getNodePos();
                        const type = parseUnionTypeOrHigher();
                        if (!inDisallowConditionalTypesContext() && !scanner2.hasPrecedingLineBreak() && parseOptional(94 /* ExtendsKeyword */)) {
                            const extendsType = disallowConditionalTypesAnd(parseType);
                            parseExpected(57 /* QuestionToken */);
                            const trueType = allowConditionalTypesAnd(parseType);
                            parseExpected(58 /* ColonToken */);
                            const falseType = allowConditionalTypesAnd(parseType);
                            return finishNode(factory2.createConditionalTypeNode(type, extendsType, trueType, falseType), pos);
                        }
                        return type;
                    }
                    function parseTypeAnnotation() {
                        return parseOptional(58 /* ColonToken */) ? parseType() : void 0;
                    }
                    function isStartOfLeftHandSideExpression() {
                        switch (token()) {
                            case 108 /* ThisKeyword */:
                            case 106 /* SuperKeyword */:
                            case 104 /* NullKeyword */:
                            case 110 /* TrueKeyword */:
                            case 95 /* FalseKeyword */:
                            case 8 /* NumericLiteral */:
                            case 9 /* BigIntLiteral */:
                            case 10 /* StringLiteral */:
                            case 14 /* NoSubstitutionTemplateLiteral */:
                            case 15 /* TemplateHead */:
                            case 20 /* OpenParenToken */:
                            case 22 /* OpenBracketToken */:
                            case 18 /* OpenBraceToken */:
                            case 98 /* FunctionKeyword */:
                            case 84 /* ClassKeyword */:
                            case 103 /* NewKeyword */:
                            case 43 /* SlashToken */:
                            case 68 /* SlashEqualsToken */:
                            case 79 /* Identifier */:
                                return true;
                            case 100 /* ImportKeyword */:
                                return lookAhead(nextTokenIsOpenParenOrLessThanOrDot);
                            default:
                                return isIdentifier2();
                        }
                    }
                    function isStartOfExpression() {
                        if (isStartOfLeftHandSideExpression()) {
                            return true;
                        }
                        switch (token()) {
                            case 39 /* PlusToken */:
                            case 40 /* MinusToken */:
                            case 54 /* TildeToken */:
                            case 53 /* ExclamationToken */:
                            case 89 /* DeleteKeyword */:
                            case 112 /* TypeOfKeyword */:
                            case 114 /* VoidKeyword */:
                            case 45 /* PlusPlusToken */:
                            case 46 /* MinusMinusToken */:
                            case 29 /* LessThanToken */:
                            case 133 /* AwaitKeyword */:
                            case 125 /* YieldKeyword */:
                            case 80 /* PrivateIdentifier */:
                            case 59 /* AtToken */:
                                return true;
                            default:
                                if (isBinaryOperator2()) {
                                    return true;
                                }
                                return isIdentifier2();
                        }
                    }
                    function isStartOfExpressionStatement() {
                        return token() !== 18 /* OpenBraceToken */ && token() !== 98 /* FunctionKeyword */ && token() !== 84 /* ClassKeyword */ && token() !== 59 /* AtToken */ && isStartOfExpression();
                    }
                    function parseExpression() {
                        const saveDecoratorContext = inDecoratorContext();
                        if (saveDecoratorContext) {
                            setDecoratorContext(
                            /*val*/
                            false);
                        }
                        const pos = getNodePos();
                        let expr = parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                        let operatorToken;
                        while (operatorToken = parseOptionalToken(27 /* CommaToken */)) {
                            expr = makeBinaryExpression(expr, operatorToken, parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true), pos);
                        }
                        if (saveDecoratorContext) {
                            setDecoratorContext(
                            /*val*/
                            true);
                        }
                        return expr;
                    }
                    function parseInitializer() {
                        return parseOptional(63 /* EqualsToken */) ? parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true) : void 0;
                    }
                    function parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction) {
                        if (isYieldExpression2()) {
                            return parseYieldExpression();
                        }
                        const arrowExpression = tryParseParenthesizedArrowFunctionExpression(allowReturnTypeInArrowFunction) || tryParseAsyncSimpleArrowFunctionExpression(allowReturnTypeInArrowFunction);
                        if (arrowExpression) {
                            return arrowExpression;
                        }
                        const pos = getNodePos();
                        const expr = parseBinaryExpressionOrHigher(0 /* Lowest */);
                        if (expr.kind === 79 /* Identifier */ && token() === 38 /* EqualsGreaterThanToken */) {
                            return parseSimpleArrowFunctionExpression(pos, expr, allowReturnTypeInArrowFunction, 
                            /*asyncModifier*/
                            void 0);
                        }
                        if (isLeftHandSideExpression(expr) && isAssignmentOperator(reScanGreaterToken())) {
                            return makeBinaryExpression(expr, parseTokenNode(), parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction), pos);
                        }
                        return parseConditionalExpressionRest(expr, pos, allowReturnTypeInArrowFunction);
                    }
                    function isYieldExpression2() {
                        if (token() === 125 /* YieldKeyword */) {
                            if (inYieldContext()) {
                                return true;
                            }
                            return lookAhead(nextTokenIsIdentifierOrKeywordOrLiteralOnSameLine);
                        }
                        return false;
                    }
                    function nextTokenIsIdentifierOnSameLine() {
                        nextToken();
                        return !scanner2.hasPrecedingLineBreak() && isIdentifier2();
                    }
                    function parseYieldExpression() {
                        const pos = getNodePos();
                        nextToken();
                        if (!scanner2.hasPrecedingLineBreak() && (token() === 41 /* AsteriskToken */ || isStartOfExpression())) {
                            return finishNode(factory2.createYieldExpression(parseOptionalToken(41 /* AsteriskToken */), parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true)), pos);
                        }
                        else {
                            return finishNode(factory2.createYieldExpression(
                            /*asteriskToken*/
                            void 0, 
                            /*expression*/
                            void 0), pos);
                        }
                    }
                    function parseSimpleArrowFunctionExpression(pos, identifier, allowReturnTypeInArrowFunction, asyncModifier) {
                        Debug.assert(token() === 38 /* EqualsGreaterThanToken */, "parseSimpleArrowFunctionExpression should only have been called if we had a =>");
                        const parameter = factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, identifier, 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0);
                        finishNode(parameter, identifier.pos);
                        const parameters = createNodeArray([parameter], parameter.pos, parameter.end);
                        const equalsGreaterThanToken = parseExpectedToken(38 /* EqualsGreaterThanToken */);
                        const body = parseArrowFunctionExpressionBody(
                        /*isAsync*/
                        !!asyncModifier, allowReturnTypeInArrowFunction);
                        const node = factory2.createArrowFunction(asyncModifier, 
                        /*typeParameters*/
                        void 0, parameters, 
                        /*type*/
                        void 0, equalsGreaterThanToken, body);
                        return addJSDocComment(finishNode(node, pos));
                    }
                    function tryParseParenthesizedArrowFunctionExpression(allowReturnTypeInArrowFunction) {
                        const triState = isParenthesizedArrowFunctionExpression();
                        if (triState === 0 /* False */) {
                            return void 0;
                        }
                        return triState === 1 /* True */ ? parseParenthesizedArrowFunctionExpression(
                        /*allowAmbiguity*/
                        true, 
                        /*allowReturnTypeInArrowFunction*/
                        true) : tryParse(() => parsePossibleParenthesizedArrowFunctionExpression(allowReturnTypeInArrowFunction));
                    }
                    function isParenthesizedArrowFunctionExpression() {
                        if (token() === 20 /* OpenParenToken */ || token() === 29 /* LessThanToken */ || token() === 132 /* AsyncKeyword */) {
                            return lookAhead(isParenthesizedArrowFunctionExpressionWorker);
                        }
                        if (token() === 38 /* EqualsGreaterThanToken */) {
                            return 1 /* True */;
                        }
                        return 0 /* False */;
                    }
                    function isParenthesizedArrowFunctionExpressionWorker() {
                        if (token() === 132 /* AsyncKeyword */) {
                            nextToken();
                            if (scanner2.hasPrecedingLineBreak()) {
                                return 0 /* False */;
                            }
                            if (token() !== 20 /* OpenParenToken */ && token() !== 29 /* LessThanToken */) {
                                return 0 /* False */;
                            }
                        }
                        const first2 = token();
                        const second = nextToken();
                        if (first2 === 20 /* OpenParenToken */) {
                            if (second === 21 /* CloseParenToken */) {
                                const third = nextToken();
                                switch (third) {
                                    case 38 /* EqualsGreaterThanToken */:
                                    case 58 /* ColonToken */:
                                    case 18 /* OpenBraceToken */:
                                        return 1 /* True */;
                                    default:
                                        return 0 /* False */;
                                }
                            }
                            if (second === 22 /* OpenBracketToken */ || second === 18 /* OpenBraceToken */) {
                                return 2 /* Unknown */;
                            }
                            if (second === 25 /* DotDotDotToken */) {
                                return 1 /* True */;
                            }
                            if (isModifierKind(second) && second !== 132 /* AsyncKeyword */ && lookAhead(nextTokenIsIdentifier)) {
                                if (nextToken() === 128 /* AsKeyword */) {
                                    return 0 /* False */;
                                }
                                return 1 /* True */;
                            }
                            if (!isIdentifier2() && second !== 108 /* ThisKeyword */) {
                                return 0 /* False */;
                            }
                            switch (nextToken()) {
                                case 58 /* ColonToken */:
                                    return 1 /* True */;
                                case 57 /* QuestionToken */:
                                    nextToken();
                                    if (token() === 58 /* ColonToken */ || token() === 27 /* CommaToken */ || token() === 63 /* EqualsToken */ || token() === 21 /* CloseParenToken */) {
                                        return 1 /* True */;
                                    }
                                    return 0 /* False */;
                                case 27 /* CommaToken */:
                                case 63 /* EqualsToken */:
                                case 21 /* CloseParenToken */:
                                    return 2 /* Unknown */;
                            }
                            return 0 /* False */;
                        }
                        else {
                            Debug.assert(first2 === 29 /* LessThanToken */);
                            if (!isIdentifier2() && token() !== 85 /* ConstKeyword */) {
                                return 0 /* False */;
                            }
                            if (languageVariant === 1 /* JSX */) {
                                const isArrowFunctionInJsx = lookAhead(() => {
                                    parseOptional(85 /* ConstKeyword */);
                                    const third = nextToken();
                                    if (third === 94 /* ExtendsKeyword */) {
                                        const fourth = nextToken();
                                        switch (fourth) {
                                            case 63 /* EqualsToken */:
                                            case 31 /* GreaterThanToken */:
                                            case 43 /* SlashToken */:
                                                return false;
                                            default:
                                                return true;
                                        }
                                    }
                                    else if (third === 27 /* CommaToken */ || third === 63 /* EqualsToken */) {
                                        return true;
                                    }
                                    return false;
                                });
                                if (isArrowFunctionInJsx) {
                                    return 1 /* True */;
                                }
                                return 0 /* False */;
                            }
                            return 2 /* Unknown */;
                        }
                    }
                    function parsePossibleParenthesizedArrowFunctionExpression(allowReturnTypeInArrowFunction) {
                        const tokenPos = scanner2.getTokenPos();
                        if (notParenthesizedArrow == null ? void 0 : notParenthesizedArrow.has(tokenPos)) {
                            return void 0;
                        }
                        const result = parseParenthesizedArrowFunctionExpression(
                        /*allowAmbiguity*/
                        false, allowReturnTypeInArrowFunction);
                        if (!result) {
                            (notParenthesizedArrow || (notParenthesizedArrow = /* @__PURE__ */ new Set())).add(tokenPos);
                        }
                        return result;
                    }
                    function tryParseAsyncSimpleArrowFunctionExpression(allowReturnTypeInArrowFunction) {
                        if (token() === 132 /* AsyncKeyword */) {
                            if (lookAhead(isUnParenthesizedAsyncArrowFunctionWorker) === 1 /* True */) {
                                const pos = getNodePos();
                                const asyncModifier = parseModifiersForArrowFunction();
                                const expr = parseBinaryExpressionOrHigher(0 /* Lowest */);
                                return parseSimpleArrowFunctionExpression(pos, expr, allowReturnTypeInArrowFunction, asyncModifier);
                            }
                        }
                        return void 0;
                    }
                    function isUnParenthesizedAsyncArrowFunctionWorker() {
                        if (token() === 132 /* AsyncKeyword */) {
                            nextToken();
                            if (scanner2.hasPrecedingLineBreak() || token() === 38 /* EqualsGreaterThanToken */) {
                                return 0 /* False */;
                            }
                            const expr = parseBinaryExpressionOrHigher(0 /* Lowest */);
                            if (!scanner2.hasPrecedingLineBreak() && expr.kind === 79 /* Identifier */ && token() === 38 /* EqualsGreaterThanToken */) {
                                return 1 /* True */;
                            }
                        }
                        return 0 /* False */;
                    }
                    function parseParenthesizedArrowFunctionExpression(allowAmbiguity, allowReturnTypeInArrowFunction) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiersForArrowFunction();
                        const isAsync = some(modifiers, isAsyncModifier) ? 2 /* Await */ : 0 /* None */;
                        const typeParameters = parseTypeParameters();
                        let parameters;
                        if (!parseExpected(20 /* OpenParenToken */)) {
                            if (!allowAmbiguity) {
                                return void 0;
                            }
                            parameters = createMissingList();
                        }
                        else {
                            if (!allowAmbiguity) {
                                const maybeParameters = parseParametersWorker(isAsync, allowAmbiguity);
                                if (!maybeParameters) {
                                    return void 0;
                                }
                                parameters = maybeParameters;
                            }
                            else {
                                parameters = parseParametersWorker(isAsync, allowAmbiguity);
                            }
                            if (!parseExpected(21 /* CloseParenToken */) && !allowAmbiguity) {
                                return void 0;
                            }
                        }
                        const hasReturnColon = token() === 58 /* ColonToken */;
                        const type = parseReturnType(58 /* ColonToken */, 
                        /*isType*/
                        false);
                        if (type && !allowAmbiguity && typeHasArrowFunctionBlockingParseError(type)) {
                            return void 0;
                        }
                        let unwrappedType = type;
                        while ((unwrappedType == null ? void 0 : unwrappedType.kind) === 193 /* ParenthesizedType */) {
                            unwrappedType = unwrappedType.type;
                        }
                        const hasJSDocFunctionType = unwrappedType && isJSDocFunctionType(unwrappedType);
                        if (!allowAmbiguity && token() !== 38 /* EqualsGreaterThanToken */ && (hasJSDocFunctionType || token() !== 18 /* OpenBraceToken */)) {
                            return void 0;
                        }
                        const lastToken = token();
                        const equalsGreaterThanToken = parseExpectedToken(38 /* EqualsGreaterThanToken */);
                        const body = lastToken === 38 /* EqualsGreaterThanToken */ || lastToken === 18 /* OpenBraceToken */ ? parseArrowFunctionExpressionBody(some(modifiers, isAsyncModifier), allowReturnTypeInArrowFunction) : parseIdentifier();
                        if (!allowReturnTypeInArrowFunction && hasReturnColon) {
                            if (token() !== 58 /* ColonToken */) {
                                return void 0;
                            }
                        }
                        const node = factory2.createArrowFunction(modifiers, typeParameters, parameters, type, equalsGreaterThanToken, body);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseArrowFunctionExpressionBody(isAsync, allowReturnTypeInArrowFunction) {
                        if (token() === 18 /* OpenBraceToken */) {
                            return parseFunctionBlock(isAsync ? 2 /* Await */ : 0 /* None */);
                        }
                        if (token() !== 26 /* SemicolonToken */ && token() !== 98 /* FunctionKeyword */ && token() !== 84 /* ClassKeyword */ && isStartOfStatement() && !isStartOfExpressionStatement()) {
                            return parseFunctionBlock(16 /* IgnoreMissingOpenBrace */ | (isAsync ? 2 /* Await */ : 0 /* None */));
                        }
                        const savedTopLevel = topLevel;
                        topLevel = false;
                        const node = isAsync ? doInAwaitContext(() => parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction)) : doOutsideOfAwaitContext(() => parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction));
                        topLevel = savedTopLevel;
                        return node;
                    }
                    function parseConditionalExpressionRest(leftOperand, pos, allowReturnTypeInArrowFunction) {
                        const questionToken = parseOptionalToken(57 /* QuestionToken */);
                        if (!questionToken) {
                            return leftOperand;
                        }
                        let colonToken;
                        return finishNode(factory2.createConditionalExpression(leftOperand, questionToken, doOutsideOfContext(disallowInAndDecoratorContext, () => parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        false)), colonToken = parseExpectedToken(58 /* ColonToken */), nodeIsPresent(colonToken) ? parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction) : createMissingNode(79 /* Identifier */, 
                        /*reportAtCurrentPosition*/
                        false, Diagnostics._0_expected, tokenToString(58 /* ColonToken */))), pos);
                    }
                    function parseBinaryExpressionOrHigher(precedence) {
                        const pos = getNodePos();
                        const leftOperand = parseUnaryExpressionOrHigher();
                        return parseBinaryExpressionRest(precedence, leftOperand, pos);
                    }
                    function isInOrOfKeyword(t) {
                        return t === 101 /* InKeyword */ || t === 162 /* OfKeyword */;
                    }
                    function parseBinaryExpressionRest(precedence, leftOperand, pos) {
                        while (true) {
                            reScanGreaterToken();
                            const newPrecedence = getBinaryOperatorPrecedence(token());
                            const consumeCurrentOperator = token() === 42 /* AsteriskAsteriskToken */ ? newPrecedence >= precedence : newPrecedence > precedence;
                            if (!consumeCurrentOperator) {
                                break;
                            }
                            if (token() === 101 /* InKeyword */ && inDisallowInContext()) {
                                break;
                            }
                            if (token() === 128 /* AsKeyword */ || token() === 150 /* SatisfiesKeyword */) {
                                if (scanner2.hasPrecedingLineBreak()) {
                                    break;
                                }
                                else {
                                    const keywordKind = token();
                                    nextToken();
                                    leftOperand = keywordKind === 150 /* SatisfiesKeyword */ ? makeSatisfiesExpression(leftOperand, parseType()) : makeAsExpression(leftOperand, parseType());
                                }
                            }
                            else {
                                leftOperand = makeBinaryExpression(leftOperand, parseTokenNode(), parseBinaryExpressionOrHigher(newPrecedence), pos);
                            }
                        }
                        return leftOperand;
                    }
                    function isBinaryOperator2() {
                        if (inDisallowInContext() && token() === 101 /* InKeyword */) {
                            return false;
                        }
                        return getBinaryOperatorPrecedence(token()) > 0;
                    }
                    function makeSatisfiesExpression(left, right) {
                        return finishNode(factory2.createSatisfiesExpression(left, right), left.pos);
                    }
                    function makeBinaryExpression(left, operatorToken, right, pos) {
                        return finishNode(factory2.createBinaryExpression(left, operatorToken, right), pos);
                    }
                    function makeAsExpression(left, right) {
                        return finishNode(factory2.createAsExpression(left, right), left.pos);
                    }
                    function parsePrefixUnaryExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createPrefixUnaryExpression(token(), nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function parseDeleteExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createDeleteExpression(nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function parseTypeOfExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTypeOfExpression(nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function parseVoidExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createVoidExpression(nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function isAwaitExpression2() {
                        if (token() === 133 /* AwaitKeyword */) {
                            if (inAwaitContext()) {
                                return true;
                            }
                            return lookAhead(nextTokenIsIdentifierOrKeywordOrLiteralOnSameLine);
                        }
                        return false;
                    }
                    function parseAwaitExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createAwaitExpression(nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function parseUnaryExpressionOrHigher() {
                        if (isUpdateExpression()) {
                            const pos = getNodePos();
                            const updateExpression = parseUpdateExpression();
                            return token() === 42 /* AsteriskAsteriskToken */ ? parseBinaryExpressionRest(getBinaryOperatorPrecedence(token()), updateExpression, pos) : updateExpression;
                        }
                        const unaryOperator = token();
                        const simpleUnaryExpression = parseSimpleUnaryExpression();
                        if (token() === 42 /* AsteriskAsteriskToken */) {
                            const pos = skipTrivia(sourceText, simpleUnaryExpression.pos);
                            const { end } = simpleUnaryExpression;
                            if (simpleUnaryExpression.kind === 213 /* TypeAssertionExpression */) {
                                parseErrorAt(pos, end, Diagnostics.A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses);
                            }
                            else {
                                parseErrorAt(pos, end, Diagnostics.An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses, tokenToString(unaryOperator));
                            }
                        }
                        return simpleUnaryExpression;
                    }
                    function parseSimpleUnaryExpression() {
                        switch (token()) {
                            case 39 /* PlusToken */:
                            case 40 /* MinusToken */:
                            case 54 /* TildeToken */:
                            case 53 /* ExclamationToken */:
                                return parsePrefixUnaryExpression();
                            case 89 /* DeleteKeyword */:
                                return parseDeleteExpression();
                            case 112 /* TypeOfKeyword */:
                                return parseTypeOfExpression();
                            case 114 /* VoidKeyword */:
                                return parseVoidExpression();
                            case 29 /* LessThanToken */:
                                if (languageVariant === 1 /* JSX */) {
                                    return parseJsxElementOrSelfClosingElementOrFragment(
                                    /*inExpressionContext*/
                                    true, 
                                    /*topInvalidNodePosition*/
                                    void 0, 
                                    /*openingTag*/
                                    void 0, 
                                    /*mustBeUnary*/
                                    true);
                                }
                                return parseTypeAssertion();
                            case 133 /* AwaitKeyword */:
                                if (isAwaitExpression2()) {
                                    return parseAwaitExpression();
                                }
                            default:
                                return parseUpdateExpression();
                        }
                    }
                    function isUpdateExpression() {
                        switch (token()) {
                            case 39 /* PlusToken */:
                            case 40 /* MinusToken */:
                            case 54 /* TildeToken */:
                            case 53 /* ExclamationToken */:
                            case 89 /* DeleteKeyword */:
                            case 112 /* TypeOfKeyword */:
                            case 114 /* VoidKeyword */:
                            case 133 /* AwaitKeyword */:
                                return false;
                            case 29 /* LessThanToken */:
                                if (languageVariant !== 1 /* JSX */) {
                                    return false;
                                }
                            default:
                                return true;
                        }
                    }
                    function parseUpdateExpression() {
                        if (token() === 45 /* PlusPlusToken */ || token() === 46 /* MinusMinusToken */) {
                            const pos = getNodePos();
                            return finishNode(factory2.createPrefixUnaryExpression(token(), nextTokenAnd(parseLeftHandSideExpressionOrHigher)), pos);
                        }
                        else if (languageVariant === 1 /* JSX */ && token() === 29 /* LessThanToken */ && lookAhead(nextTokenIsIdentifierOrKeywordOrGreaterThan)) {
                            return parseJsxElementOrSelfClosingElementOrFragment(
                            /*inExpressionContext*/
                            true);
                        }
                        const expression = parseLeftHandSideExpressionOrHigher();
                        Debug.assert(isLeftHandSideExpression(expression));
                        if ((token() === 45 /* PlusPlusToken */ || token() === 46 /* MinusMinusToken */) && !scanner2.hasPrecedingLineBreak()) {
                            const operator = token();
                            nextToken();
                            return finishNode(factory2.createPostfixUnaryExpression(expression, operator), expression.pos);
                        }
                        return expression;
                    }
                    function parseLeftHandSideExpressionOrHigher() {
                        const pos = getNodePos();
                        let expression;
                        if (token() === 100 /* ImportKeyword */) {
                            if (lookAhead(nextTokenIsOpenParenOrLessThan)) {
                                sourceFlags |= 2097152 /* PossiblyContainsDynamicImport */;
                                expression = parseTokenNode();
                            }
                            else if (lookAhead(nextTokenIsDot)) {
                                nextToken();
                                nextToken();
                                expression = finishNode(factory2.createMetaProperty(100 /* ImportKeyword */, parseIdentifierName()), pos);
                                sourceFlags |= 4194304 /* PossiblyContainsImportMeta */;
                            }
                            else {
                                expression = parseMemberExpressionOrHigher();
                            }
                        }
                        else {
                            expression = token() === 106 /* SuperKeyword */ ? parseSuperExpression() : parseMemberExpressionOrHigher();
                        }
                        return parseCallExpressionRest(pos, expression);
                    }
                    function parseMemberExpressionOrHigher() {
                        const pos = getNodePos();
                        const expression = parsePrimaryExpression();
                        return parseMemberExpressionRest(pos, expression, 
                        /*allowOptionalChain*/
                        true);
                    }
                    function parseSuperExpression() {
                        const pos = getNodePos();
                        let expression = parseTokenNode();
                        if (token() === 29 /* LessThanToken */) {
                            const startPos = getNodePos();
                            const typeArguments = tryParse(parseTypeArgumentsInExpression);
                            if (typeArguments !== void 0) {
                                parseErrorAt(startPos, getNodePos(), Diagnostics.super_may_not_use_type_arguments);
                                if (!isTemplateStartOfTaggedTemplate()) {
                                    expression = factory2.createExpressionWithTypeArguments(expression, typeArguments);
                                }
                            }
                        }
                        if (token() === 20 /* OpenParenToken */ || token() === 24 /* DotToken */ || token() === 22 /* OpenBracketToken */) {
                            return expression;
                        }
                        parseExpectedToken(24 /* DotToken */, Diagnostics.super_must_be_followed_by_an_argument_list_or_member_access);
                        return finishNode(factoryCreatePropertyAccessExpression(expression, parseRightSideOfDot(
                        /*allowIdentifierNames*/
                        true, 
                        /*allowPrivateIdentifiers*/
                        true)), pos);
                    }
                    function parseJsxElementOrSelfClosingElementOrFragment(inExpressionContext, topInvalidNodePosition, openingTag, mustBeUnary = false) {
                        const pos = getNodePos();
                        const opening = parseJsxOpeningOrSelfClosingElementOrOpeningFragment(inExpressionContext);
                        let result;
                        if (opening.kind === 283 /* JsxOpeningElement */) {
                            let children = parseJsxChildren(opening);
                            let closingElement;
                            const lastChild = children[children.length - 1];
                            if ((lastChild == null ? void 0 : lastChild.kind) === 281 /* JsxElement */ && !tagNamesAreEquivalent(lastChild.openingElement.tagName, lastChild.closingElement.tagName) && tagNamesAreEquivalent(opening.tagName, lastChild.closingElement.tagName)) {
                                const end = lastChild.children.end;
                                const newLast = finishNode(factory2.createJsxElement(lastChild.openingElement, lastChild.children, finishNode(factory2.createJsxClosingElement(finishNode(factoryCreateIdentifier(""), end, end)), end, end)), lastChild.openingElement.pos, end);
                                children = createNodeArray([...children.slice(0, children.length - 1), newLast], children.pos, end);
                                closingElement = lastChild.closingElement;
                            }
                            else {
                                closingElement = parseJsxClosingElement(opening, inExpressionContext);
                                if (!tagNamesAreEquivalent(opening.tagName, closingElement.tagName)) {
                                    if (openingTag && isJsxOpeningElement(openingTag) && tagNamesAreEquivalent(closingElement.tagName, openingTag.tagName)) {
                                        parseErrorAtRange(opening.tagName, Diagnostics.JSX_element_0_has_no_corresponding_closing_tag, getTextOfNodeFromSourceText(sourceText, opening.tagName));
                                    }
                                    else {
                                        parseErrorAtRange(closingElement.tagName, Diagnostics.Expected_corresponding_JSX_closing_tag_for_0, getTextOfNodeFromSourceText(sourceText, opening.tagName));
                                    }
                                }
                            }
                            result = finishNode(factory2.createJsxElement(opening, children, closingElement), pos);
                        }
                        else if (opening.kind === 286 /* JsxOpeningFragment */) {
                            result = finishNode(factory2.createJsxFragment(opening, parseJsxChildren(opening), parseJsxClosingFragment(inExpressionContext)), pos);
                        }
                        else {
                            Debug.assert(opening.kind === 282 /* JsxSelfClosingElement */);
                            result = opening;
                        }
                        if (!mustBeUnary && inExpressionContext && token() === 29 /* LessThanToken */) {
                            const topBadPos = typeof topInvalidNodePosition === "undefined" ? result.pos : topInvalidNodePosition;
                            const invalidElement = tryParse(() => parseJsxElementOrSelfClosingElementOrFragment(
                            /*inExpressionContext*/
                            true, topBadPos));
                            if (invalidElement) {
                                const operatorToken = createMissingNode(27 /* CommaToken */, 
                                /*reportAtCurrentPosition*/
                                false);
                                setTextRangePosWidth(operatorToken, invalidElement.pos, 0);
                                parseErrorAt(skipTrivia(sourceText, topBadPos), invalidElement.end, Diagnostics.JSX_expressions_must_have_one_parent_element);
                                return finishNode(factory2.createBinaryExpression(result, operatorToken, invalidElement), pos);
                            }
                        }
                        return result;
                    }
                    function parseJsxText() {
                        const pos = getNodePos();
                        const node = factory2.createJsxText(scanner2.getTokenValue(), currentToken === 12 /* JsxTextAllWhiteSpaces */);
                        currentToken = scanner2.scanJsxToken();
                        return finishNode(node, pos);
                    }
                    function parseJsxChild(openingTag, token2) {
                        switch (token2) {
                            case 1 /* EndOfFileToken */:
                                if (isJsxOpeningFragment(openingTag)) {
                                    parseErrorAtRange(openingTag, Diagnostics.JSX_fragment_has_no_corresponding_closing_tag);
                                }
                                else {
                                    const tag = openingTag.tagName;
                                    const start = skipTrivia(sourceText, tag.pos);
                                    parseErrorAt(start, tag.end, Diagnostics.JSX_element_0_has_no_corresponding_closing_tag, getTextOfNodeFromSourceText(sourceText, openingTag.tagName));
                                }
                                return void 0;
                            case 30 /* LessThanSlashToken */:
                            case 7 /* ConflictMarkerTrivia */:
                                return void 0;
                            case 11 /* JsxText */:
                            case 12 /* JsxTextAllWhiteSpaces */:
                                return parseJsxText();
                            case 18 /* OpenBraceToken */:
                                return parseJsxExpression(
                                /*inExpressionContext*/
                                false);
                            case 29 /* LessThanToken */:
                                return parseJsxElementOrSelfClosingElementOrFragment(
                                /*inExpressionContext*/
                                false, 
                                /*topInvalidNodePosition*/
                                void 0, openingTag);
                            default:
                                return Debug.assertNever(token2);
                        }
                    }
                    function parseJsxChildren(openingTag) {
                        const list = [];
                        const listPos = getNodePos();
                        const saveParsingContext = parsingContext;
                        parsingContext |= 1 << 14 /* JsxChildren */;
                        while (true) {
                            const child = parseJsxChild(openingTag, currentToken = scanner2.reScanJsxToken());
                            if (!child)
                                break;
                            list.push(child);
                            if (isJsxOpeningElement(openingTag) && (child == null ? void 0 : child.kind) === 281 /* JsxElement */ && !tagNamesAreEquivalent(child.openingElement.tagName, child.closingElement.tagName) && tagNamesAreEquivalent(openingTag.tagName, child.closingElement.tagName)) {
                                break;
                            }
                        }
                        parsingContext = saveParsingContext;
                        return createNodeArray(list, listPos);
                    }
                    function parseJsxAttributes() {
                        const pos = getNodePos();
                        return finishNode(factory2.createJsxAttributes(parseList(13 /* JsxAttributes */, parseJsxAttribute)), pos);
                    }
                    function parseJsxOpeningOrSelfClosingElementOrOpeningFragment(inExpressionContext) {
                        const pos = getNodePos();
                        parseExpected(29 /* LessThanToken */);
                        if (token() === 31 /* GreaterThanToken */) {
                            scanJsxText();
                            return finishNode(factory2.createJsxOpeningFragment(), pos);
                        }
                        const tagName = parseJsxElementName();
                        const typeArguments = (contextFlags & 262144 /* JavaScriptFile */) === 0 ? tryParseTypeArguments() : void 0;
                        const attributes = parseJsxAttributes();
                        let node;
                        if (token() === 31 /* GreaterThanToken */) {
                            scanJsxText();
                            node = factory2.createJsxOpeningElement(tagName, typeArguments, attributes);
                        }
                        else {
                            parseExpected(43 /* SlashToken */);
                            if (parseExpected(31 /* GreaterThanToken */, 
                            /*diagnostic*/
                            void 0, 
                            /*shouldAdvance*/
                            false)) {
                                if (inExpressionContext) {
                                    nextToken();
                                }
                                else {
                                    scanJsxText();
                                }
                            }
                            node = factory2.createJsxSelfClosingElement(tagName, typeArguments, attributes);
                        }
                        return finishNode(node, pos);
                    }
                    function parseJsxElementName() {
                        const pos = getNodePos();
                        scanJsxIdentifier();
                        let expression = token() === 108 /* ThisKeyword */ ? parseTokenNode() : parseIdentifierName();
                        while (parseOptional(24 /* DotToken */)) {
                            expression = finishNode(factoryCreatePropertyAccessExpression(expression, parseRightSideOfDot(
                            /*allowIdentifierNames*/
                            true, 
                            /*allowPrivateIdentifiers*/
                            false)), pos);
                        }
                        return expression;
                    }
                    function parseJsxExpression(inExpressionContext) {
                        const pos = getNodePos();
                        if (!parseExpected(18 /* OpenBraceToken */)) {
                            return void 0;
                        }
                        let dotDotDotToken;
                        let expression;
                        if (token() !== 19 /* CloseBraceToken */) {
                            dotDotDotToken = parseOptionalToken(25 /* DotDotDotToken */);
                            expression = parseExpression();
                        }
                        if (inExpressionContext) {
                            parseExpected(19 /* CloseBraceToken */);
                        }
                        else {
                            if (parseExpected(19 /* CloseBraceToken */, 
                            /*message*/
                            void 0, 
                            /*shouldAdvance*/
                            false)) {
                                scanJsxText();
                            }
                        }
                        return finishNode(factory2.createJsxExpression(dotDotDotToken, expression), pos);
                    }
                    function parseJsxAttribute() {
                        if (token() === 18 /* OpenBraceToken */) {
                            return parseJsxSpreadAttribute();
                        }
                        scanJsxIdentifier();
                        const pos = getNodePos();
                        return finishNode(factory2.createJsxAttribute(parseIdentifierName(), parseJsxAttributeValue()), pos);
                    }
                    function parseJsxAttributeValue() {
                        if (token() === 63 /* EqualsToken */) {
                            if (scanJsxAttributeValue() === 10 /* StringLiteral */) {
                                return parseLiteralNode();
                            }
                            if (token() === 18 /* OpenBraceToken */) {
                                return parseJsxExpression(
                                /*inExpressionContext*/
                                true);
                            }
                            if (token() === 29 /* LessThanToken */) {
                                return parseJsxElementOrSelfClosingElementOrFragment(
                                /*inExpressionContext*/
                                true);
                            }
                            parseErrorAtCurrentToken(Diagnostics.or_JSX_element_expected);
                        }
                        return void 0;
                    }
                    function parseJsxSpreadAttribute() {
                        const pos = getNodePos();
                        parseExpected(18 /* OpenBraceToken */);
                        parseExpected(25 /* DotDotDotToken */);
                        const expression = parseExpression();
                        parseExpected(19 /* CloseBraceToken */);
                        return finishNode(factory2.createJsxSpreadAttribute(expression), pos);
                    }
                    function parseJsxClosingElement(open, inExpressionContext) {
                        const pos = getNodePos();
                        parseExpected(30 /* LessThanSlashToken */);
                        const tagName = parseJsxElementName();
                        if (parseExpected(31 /* GreaterThanToken */, 
                        /*diagnostic*/
                        void 0, 
                        /*shouldAdvance*/
                        false)) {
                            if (inExpressionContext || !tagNamesAreEquivalent(open.tagName, tagName)) {
                                nextToken();
                            }
                            else {
                                scanJsxText();
                            }
                        }
                        return finishNode(factory2.createJsxClosingElement(tagName), pos);
                    }
                    function parseJsxClosingFragment(inExpressionContext) {
                        const pos = getNodePos();
                        parseExpected(30 /* LessThanSlashToken */);
                        if (parseExpected(31 /* GreaterThanToken */, Diagnostics.Expected_corresponding_closing_tag_for_JSX_fragment, 
                        /*shouldAdvance*/
                        false)) {
                            if (inExpressionContext) {
                                nextToken();
                            }
                            else {
                                scanJsxText();
                            }
                        }
                        return finishNode(factory2.createJsxJsxClosingFragment(), pos);
                    }
                    function parseTypeAssertion() {
                        Debug.assert(languageVariant !== 1 /* JSX */, "Type assertions should never be parsed in JSX; they should be parsed as comparisons or JSX elements/fragments.");
                        const pos = getNodePos();
                        parseExpected(29 /* LessThanToken */);
                        const type = parseType();
                        parseExpected(31 /* GreaterThanToken */);
                        const expression = parseSimpleUnaryExpression();
                        return finishNode(factory2.createTypeAssertion(type, expression), pos);
                    }
                    function nextTokenIsIdentifierOrKeywordOrOpenBracketOrTemplate() {
                        nextToken();
                        return tokenIsIdentifierOrKeyword(token()) || token() === 22 /* OpenBracketToken */ || isTemplateStartOfTaggedTemplate();
                    }
                    function isStartOfOptionalPropertyOrElementAccessChain() {
                        return token() === 28 /* QuestionDotToken */ && lookAhead(nextTokenIsIdentifierOrKeywordOrOpenBracketOrTemplate);
                    }
                    function tryReparseOptionalChain(node) {
                        if (node.flags & 32 /* OptionalChain */) {
                            return true;
                        }
                        if (isNonNullExpression(node)) {
                            let expr = node.expression;
                            while (isNonNullExpression(expr) && !(expr.flags & 32 /* OptionalChain */)) {
                                expr = expr.expression;
                            }
                            if (expr.flags & 32 /* OptionalChain */) {
                                while (isNonNullExpression(node)) {
                                    node.flags |= 32 /* OptionalChain */;
                                    node = node.expression;
                                }
                                return true;
                            }
                        }
                        return false;
                    }
                    function parsePropertyAccessExpressionRest(pos, expression, questionDotToken) {
                        const name = parseRightSideOfDot(
                        /*allowIdentifierNames*/
                        true, 
                        /*allowPrivateIdentifiers*/
                        true);
                        const isOptionalChain2 = questionDotToken || tryReparseOptionalChain(expression);
                        const propertyAccess = isOptionalChain2 ? factoryCreatePropertyAccessChain(expression, questionDotToken, name) : factoryCreatePropertyAccessExpression(expression, name);
                        if (isOptionalChain2 && isPrivateIdentifier(propertyAccess.name)) {
                            parseErrorAtRange(propertyAccess.name, Diagnostics.An_optional_chain_cannot_contain_private_identifiers);
                        }
                        if (isExpressionWithTypeArguments(expression) && expression.typeArguments) {
                            const pos2 = expression.typeArguments.pos - 1;
                            const end = skipTrivia(sourceText, expression.typeArguments.end) + 1;
                            parseErrorAt(pos2, end, Diagnostics.An_instantiation_expression_cannot_be_followed_by_a_property_access);
                        }
                        return finishNode(propertyAccess, pos);
                    }
                    function parseElementAccessExpressionRest(pos, expression, questionDotToken) {
                        let argumentExpression;
                        if (token() === 23 /* CloseBracketToken */) {
                            argumentExpression = createMissingNode(79 /* Identifier */, 
                            /*reportAtCurrentPosition*/
                            true, Diagnostics.An_element_access_expression_should_take_an_argument);
                        }
                        else {
                            const argument = allowInAnd(parseExpression);
                            if (isStringOrNumericLiteralLike(argument)) {
                                argument.text = internIdentifier(argument.text);
                            }
                            argumentExpression = argument;
                        }
                        parseExpected(23 /* CloseBracketToken */);
                        const indexedAccess = questionDotToken || tryReparseOptionalChain(expression) ? factoryCreateElementAccessChain(expression, questionDotToken, argumentExpression) : factoryCreateElementAccessExpression(expression, argumentExpression);
                        return finishNode(indexedAccess, pos);
                    }
                    function parseMemberExpressionRest(pos, expression, allowOptionalChain) {
                        while (true) {
                            let questionDotToken;
                            let isPropertyAccess = false;
                            if (allowOptionalChain && isStartOfOptionalPropertyOrElementAccessChain()) {
                                questionDotToken = parseExpectedToken(28 /* QuestionDotToken */);
                                isPropertyAccess = tokenIsIdentifierOrKeyword(token());
                            }
                            else {
                                isPropertyAccess = parseOptional(24 /* DotToken */);
                            }
                            if (isPropertyAccess) {
                                expression = parsePropertyAccessExpressionRest(pos, expression, questionDotToken);
                                continue;
                            }
                            if ((questionDotToken || !inDecoratorContext()) && parseOptional(22 /* OpenBracketToken */)) {
                                expression = parseElementAccessExpressionRest(pos, expression, questionDotToken);
                                continue;
                            }
                            if (isTemplateStartOfTaggedTemplate()) {
                                expression = !questionDotToken && expression.kind === 230 /* ExpressionWithTypeArguments */ ? parseTaggedTemplateRest(pos, expression.expression, questionDotToken, expression.typeArguments) : parseTaggedTemplateRest(pos, expression, questionDotToken, 
                                /*typeArguments*/
                                void 0);
                                continue;
                            }
                            if (!questionDotToken) {
                                if (token() === 53 /* ExclamationToken */ && !scanner2.hasPrecedingLineBreak()) {
                                    nextToken();
                                    expression = finishNode(factory2.createNonNullExpression(expression), pos);
                                    continue;
                                }
                                const typeArguments = tryParse(parseTypeArgumentsInExpression);
                                if (typeArguments) {
                                    expression = finishNode(factory2.createExpressionWithTypeArguments(expression, typeArguments), pos);
                                    continue;
                                }
                            }
                            return expression;
                        }
                    }
                    function isTemplateStartOfTaggedTemplate() {
                        return token() === 14 /* NoSubstitutionTemplateLiteral */ || token() === 15 /* TemplateHead */;
                    }
                    function parseTaggedTemplateRest(pos, tag, questionDotToken, typeArguments) {
                        const tagExpression = factory2.createTaggedTemplateExpression(tag, typeArguments, token() === 14 /* NoSubstitutionTemplateLiteral */ ? (reScanTemplateHeadOrNoSubstitutionTemplate(), parseLiteralNode()) : parseTemplateExpression(
                        /*isTaggedTemplate*/
                        true));
                        if (questionDotToken || tag.flags & 32 /* OptionalChain */) {
                            tagExpression.flags |= 32 /* OptionalChain */;
                        }
                        tagExpression.questionDotToken = questionDotToken;
                        return finishNode(tagExpression, pos);
                    }
                    function parseCallExpressionRest(pos, expression) {
                        while (true) {
                            expression = parseMemberExpressionRest(pos, expression, 
                            /*allowOptionalChain*/
                            true);
                            let typeArguments;
                            const questionDotToken = parseOptionalToken(28 /* QuestionDotToken */);
                            if (questionDotToken) {
                                typeArguments = tryParse(parseTypeArgumentsInExpression);
                                if (isTemplateStartOfTaggedTemplate()) {
                                    expression = parseTaggedTemplateRest(pos, expression, questionDotToken, typeArguments);
                                    continue;
                                }
                            }
                            if (typeArguments || token() === 20 /* OpenParenToken */) {
                                if (!questionDotToken && expression.kind === 230 /* ExpressionWithTypeArguments */) {
                                    typeArguments = expression.typeArguments;
                                    expression = expression.expression;
                                }
                                const argumentList = parseArgumentList();
                                const callExpr = questionDotToken || tryReparseOptionalChain(expression) ? factoryCreateCallChain(expression, questionDotToken, typeArguments, argumentList) : factoryCreateCallExpression(expression, typeArguments, argumentList);
                                expression = finishNode(callExpr, pos);
                                continue;
                            }
                            if (questionDotToken) {
                                const name = createMissingNode(79 /* Identifier */, 
                                /*reportAtCurrentPosition*/
                                false, Diagnostics.Identifier_expected);
                                expression = finishNode(factoryCreatePropertyAccessChain(expression, questionDotToken, name), pos);
                            }
                            break;
                        }
                        return expression;
                    }
                    function parseArgumentList() {
                        parseExpected(20 /* OpenParenToken */);
                        const result = parseDelimitedList(11 /* ArgumentExpressions */, parseArgumentExpression);
                        parseExpected(21 /* CloseParenToken */);
                        return result;
                    }
                    function parseTypeArgumentsInExpression() {
                        if ((contextFlags & 262144 /* JavaScriptFile */) !== 0) {
                            return void 0;
                        }
                        if (reScanLessThanToken() !== 29 /* LessThanToken */) {
                            return void 0;
                        }
                        nextToken();
                        const typeArguments = parseDelimitedList(20 /* TypeArguments */, parseType);
                        if (reScanGreaterToken() !== 31 /* GreaterThanToken */) {
                            return void 0;
                        }
                        nextToken();
                        return typeArguments && canFollowTypeArgumentsInExpression() ? typeArguments : void 0;
                    }
                    function canFollowTypeArgumentsInExpression() {
                        switch (token()) {
                            case 20 /* OpenParenToken */:
                            case 14 /* NoSubstitutionTemplateLiteral */:
                            case 15 /* TemplateHead */:
                                return true;
                            case 29 /* LessThanToken */:
                            case 31 /* GreaterThanToken */:
                            case 39 /* PlusToken */:
                            case 40 /* MinusToken */:
                                return false;
                        }
                        return scanner2.hasPrecedingLineBreak() || isBinaryOperator2() || !isStartOfExpression();
                    }
                    function parsePrimaryExpression() {
                        switch (token()) {
                            case 8 /* NumericLiteral */:
                            case 9 /* BigIntLiteral */:
                            case 10 /* StringLiteral */:
                            case 14 /* NoSubstitutionTemplateLiteral */:
                                return parseLiteralNode();
                            case 108 /* ThisKeyword */:
                            case 106 /* SuperKeyword */:
                            case 104 /* NullKeyword */:
                            case 110 /* TrueKeyword */:
                            case 95 /* FalseKeyword */:
                                return parseTokenNode();
                            case 20 /* OpenParenToken */:
                                return parseParenthesizedExpression();
                            case 22 /* OpenBracketToken */:
                                return parseArrayLiteralExpression();
                            case 18 /* OpenBraceToken */:
                                return parseObjectLiteralExpression();
                            case 132 /* AsyncKeyword */:
                                if (!lookAhead(nextTokenIsFunctionKeywordOnSameLine)) {
                                    break;
                                }
                                return parseFunctionExpression();
                            case 59 /* AtToken */:
                                return parseDecoratedExpression();
                            case 84 /* ClassKeyword */:
                                return parseClassExpression();
                            case 98 /* FunctionKeyword */:
                                return parseFunctionExpression();
                            case 103 /* NewKeyword */:
                                return parseNewExpressionOrNewDotTarget();
                            case 43 /* SlashToken */:
                            case 68 /* SlashEqualsToken */:
                                if (reScanSlashToken() === 13 /* RegularExpressionLiteral */) {
                                    return parseLiteralNode();
                                }
                                break;
                            case 15 /* TemplateHead */:
                                return parseTemplateExpression(
                                /* isTaggedTemplate */
                                false);
                            case 80 /* PrivateIdentifier */:
                                return parsePrivateIdentifier();
                        }
                        return parseIdentifier(Diagnostics.Expression_expected);
                    }
                    function parseParenthesizedExpression() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(20 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpected(21 /* CloseParenToken */);
                        return withJSDoc(finishNode(factoryCreateParenthesizedExpression(expression), pos), hasJSDoc);
                    }
                    function parseSpreadElement() {
                        const pos = getNodePos();
                        parseExpected(25 /* DotDotDotToken */);
                        const expression = parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                        return finishNode(factory2.createSpreadElement(expression), pos);
                    }
                    function parseArgumentOrArrayLiteralElement() {
                        return token() === 25 /* DotDotDotToken */ ? parseSpreadElement() : token() === 27 /* CommaToken */ ? finishNode(factory2.createOmittedExpression(), getNodePos()) : parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                    }
                    function parseArgumentExpression() {
                        return doOutsideOfContext(disallowInAndDecoratorContext, parseArgumentOrArrayLiteralElement);
                    }
                    function parseArrayLiteralExpression() {
                        const pos = getNodePos();
                        const openBracketPosition = scanner2.getTokenPos();
                        const openBracketParsed = parseExpected(22 /* OpenBracketToken */);
                        const multiLine = scanner2.hasPrecedingLineBreak();
                        const elements = parseDelimitedList(15 /* ArrayLiteralMembers */, parseArgumentOrArrayLiteralElement);
                        parseExpectedMatchingBrackets(22 /* OpenBracketToken */, 23 /* CloseBracketToken */, openBracketParsed, openBracketPosition);
                        return finishNode(factoryCreateArrayLiteralExpression(elements, multiLine), pos);
                    }
                    function parseObjectLiteralElement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        if (parseOptionalToken(25 /* DotDotDotToken */)) {
                            const expression = parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true);
                            return withJSDoc(finishNode(factory2.createSpreadAssignment(expression), pos), hasJSDoc);
                        }
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        true);
                        if (parseContextualModifier(137 /* GetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 174 /* GetAccessor */, 0 /* None */);
                        }
                        if (parseContextualModifier(151 /* SetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 175 /* SetAccessor */, 0 /* None */);
                        }
                        const asteriskToken = parseOptionalToken(41 /* AsteriskToken */);
                        const tokenIsIdentifier = isIdentifier2();
                        const name = parsePropertyName();
                        const questionToken = parseOptionalToken(57 /* QuestionToken */);
                        const exclamationToken = parseOptionalToken(53 /* ExclamationToken */);
                        if (asteriskToken || token() === 20 /* OpenParenToken */ || token() === 29 /* LessThanToken */) {
                            return parseMethodDeclaration(pos, hasJSDoc, modifiers, asteriskToken, name, questionToken, exclamationToken);
                        }
                        let node;
                        const isShorthandPropertyAssignment2 = tokenIsIdentifier && token() !== 58 /* ColonToken */;
                        if (isShorthandPropertyAssignment2) {
                            const equalsToken = parseOptionalToken(63 /* EqualsToken */);
                            const objectAssignmentInitializer = equalsToken ? allowInAnd(() => parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true)) : void 0;
                            node = factory2.createShorthandPropertyAssignment(name, objectAssignmentInitializer);
                            node.equalsToken = equalsToken;
                        }
                        else {
                            parseExpected(58 /* ColonToken */);
                            const initializer = allowInAnd(() => parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true));
                            node = factory2.createPropertyAssignment(name, initializer);
                        }
                        node.modifiers = modifiers;
                        node.questionToken = questionToken;
                        node.exclamationToken = exclamationToken;
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseObjectLiteralExpression() {
                        const pos = getNodePos();
                        const openBracePosition = scanner2.getTokenPos();
                        const openBraceParsed = parseExpected(18 /* OpenBraceToken */);
                        const multiLine = scanner2.hasPrecedingLineBreak();
                        const properties = parseDelimitedList(12 /* ObjectLiteralMembers */, parseObjectLiteralElement, 
                        /*considerSemicolonAsDelimiter*/
                        true);
                        parseExpectedMatchingBrackets(18 /* OpenBraceToken */, 19 /* CloseBraceToken */, openBraceParsed, openBracePosition);
                        return finishNode(factoryCreateObjectLiteralExpression(properties, multiLine), pos);
                    }
                    function parseFunctionExpression() {
                        const savedDecoratorContext = inDecoratorContext();
                        setDecoratorContext(
                        /*val*/
                        false);
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        false);
                        parseExpected(98 /* FunctionKeyword */);
                        const asteriskToken = parseOptionalToken(41 /* AsteriskToken */);
                        const isGenerator = asteriskToken ? 1 /* Yield */ : 0 /* None */;
                        const isAsync = some(modifiers, isAsyncModifier) ? 2 /* Await */ : 0 /* None */;
                        const name = isGenerator && isAsync ? doInYieldAndAwaitContext(parseOptionalBindingIdentifier) : isGenerator ? doInYieldContext(parseOptionalBindingIdentifier) : isAsync ? doInAwaitContext(parseOptionalBindingIdentifier) : parseOptionalBindingIdentifier();
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(isGenerator | isAsync);
                        const type = parseReturnType(58 /* ColonToken */, 
                        /*isType*/
                        false);
                        const body = parseFunctionBlock(isGenerator | isAsync);
                        setDecoratorContext(savedDecoratorContext);
                        const node = factory2.createFunctionExpression(modifiers, asteriskToken, name, typeParameters, parameters, type, body);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseOptionalBindingIdentifier() {
                        return isBindingIdentifier() ? parseBindingIdentifier() : void 0;
                    }
                    function parseNewExpressionOrNewDotTarget() {
                        const pos = getNodePos();
                        parseExpected(103 /* NewKeyword */);
                        if (parseOptional(24 /* DotToken */)) {
                            const name = parseIdentifierName();
                            return finishNode(factory2.createMetaProperty(103 /* NewKeyword */, name), pos);
                        }
                        const expressionPos = getNodePos();
                        let expression = parseMemberExpressionRest(expressionPos, parsePrimaryExpression(), 
                        /*allowOptionalChain*/
                        false);
                        let typeArguments;
                        if (expression.kind === 230 /* ExpressionWithTypeArguments */) {
                            typeArguments = expression.typeArguments;
                            expression = expression.expression;
                        }
                        if (token() === 28 /* QuestionDotToken */) {
                            parseErrorAtCurrentToken(Diagnostics.Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0, getTextOfNodeFromSourceText(sourceText, expression));
                        }
                        const argumentList = token() === 20 /* OpenParenToken */ ? parseArgumentList() : void 0;
                        return finishNode(factoryCreateNewExpression(expression, typeArguments, argumentList), pos);
                    }
                    function parseBlock(ignoreMissingOpenBrace, diagnosticMessage) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const openBracePosition = scanner2.getTokenPos();
                        const openBraceParsed = parseExpected(18 /* OpenBraceToken */, diagnosticMessage);
                        if (openBraceParsed || ignoreMissingOpenBrace) {
                            const multiLine = scanner2.hasPrecedingLineBreak();
                            const statements = parseList(1 /* BlockStatements */, parseStatement);
                            parseExpectedMatchingBrackets(18 /* OpenBraceToken */, 19 /* CloseBraceToken */, openBraceParsed, openBracePosition);
                            const result = withJSDoc(finishNode(factoryCreateBlock(statements, multiLine), pos), hasJSDoc);
                            if (token() === 63 /* EqualsToken */) {
                                parseErrorAtCurrentToken(Diagnostics.Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_whole_assignment_in_parentheses);
                                nextToken();
                            }
                            return result;
                        }
                        else {
                            const statements = createMissingList();
                            return withJSDoc(finishNode(factoryCreateBlock(statements, 
                            /*multiLine*/
                            void 0), pos), hasJSDoc);
                        }
                    }
                    function parseFunctionBlock(flags, diagnosticMessage) {
                        const savedYieldContext = inYieldContext();
                        setYieldContext(!!(flags & 1 /* Yield */));
                        const savedAwaitContext = inAwaitContext();
                        setAwaitContext(!!(flags & 2 /* Await */));
                        const savedTopLevel = topLevel;
                        topLevel = false;
                        const saveDecoratorContext = inDecoratorContext();
                        if (saveDecoratorContext) {
                            setDecoratorContext(
                            /*val*/
                            false);
                        }
                        const block = parseBlock(!!(flags & 16 /* IgnoreMissingOpenBrace */), diagnosticMessage);
                        if (saveDecoratorContext) {
                            setDecoratorContext(
                            /*val*/
                            true);
                        }
                        topLevel = savedTopLevel;
                        setYieldContext(savedYieldContext);
                        setAwaitContext(savedAwaitContext);
                        return block;
                    }
                    function parseEmptyStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(26 /* SemicolonToken */);
                        return withJSDoc(finishNode(factory2.createEmptyStatement(), pos), hasJSDoc);
                    }
                    function parseIfStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(99 /* IfKeyword */);
                        const openParenPosition = scanner2.getTokenPos();
                        const openParenParsed = parseExpected(20 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpectedMatchingBrackets(20 /* OpenParenToken */, 21 /* CloseParenToken */, openParenParsed, openParenPosition);
                        const thenStatement = parseStatement();
                        const elseStatement = parseOptional(91 /* ElseKeyword */) ? parseStatement() : void 0;
                        return withJSDoc(finishNode(factoryCreateIfStatement(expression, thenStatement, elseStatement), pos), hasJSDoc);
                    }
                    function parseDoStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(90 /* DoKeyword */);
                        const statement = parseStatement();
                        parseExpected(115 /* WhileKeyword */);
                        const openParenPosition = scanner2.getTokenPos();
                        const openParenParsed = parseExpected(20 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpectedMatchingBrackets(20 /* OpenParenToken */, 21 /* CloseParenToken */, openParenParsed, openParenPosition);
                        parseOptional(26 /* SemicolonToken */);
                        return withJSDoc(finishNode(factory2.createDoStatement(statement, expression), pos), hasJSDoc);
                    }
                    function parseWhileStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(115 /* WhileKeyword */);
                        const openParenPosition = scanner2.getTokenPos();
                        const openParenParsed = parseExpected(20 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpectedMatchingBrackets(20 /* OpenParenToken */, 21 /* CloseParenToken */, openParenParsed, openParenPosition);
                        const statement = parseStatement();
                        return withJSDoc(finishNode(factoryCreateWhileStatement(expression, statement), pos), hasJSDoc);
                    }
                    function parseForOrForInOrForOfStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(97 /* ForKeyword */);
                        const awaitToken = parseOptionalToken(133 /* AwaitKeyword */);
                        parseExpected(20 /* OpenParenToken */);
                        let initializer;
                        if (token() !== 26 /* SemicolonToken */) {
                            if (token() === 113 /* VarKeyword */ || token() === 119 /* LetKeyword */ || token() === 85 /* ConstKeyword */) {
                                initializer = parseVariableDeclarationList(
                                /*inForStatementInitializer*/
                                true);
                            }
                            else {
                                initializer = disallowInAnd(parseExpression);
                            }
                        }
                        let node;
                        if (awaitToken ? parseExpected(162 /* OfKeyword */) : parseOptional(162 /* OfKeyword */)) {
                            const expression = allowInAnd(() => parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true));
                            parseExpected(21 /* CloseParenToken */);
                            node = factoryCreateForOfStatement(awaitToken, initializer, expression, parseStatement());
                        }
                        else if (parseOptional(101 /* InKeyword */)) {
                            const expression = allowInAnd(parseExpression);
                            parseExpected(21 /* CloseParenToken */);
                            node = factory2.createForInStatement(initializer, expression, parseStatement());
                        }
                        else {
                            parseExpected(26 /* SemicolonToken */);
                            const condition = token() !== 26 /* SemicolonToken */ && token() !== 21 /* CloseParenToken */ ? allowInAnd(parseExpression) : void 0;
                            parseExpected(26 /* SemicolonToken */);
                            const incrementor = token() !== 21 /* CloseParenToken */ ? allowInAnd(parseExpression) : void 0;
                            parseExpected(21 /* CloseParenToken */);
                            node = factoryCreateForStatement(initializer, condition, incrementor, parseStatement());
                        }
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseBreakOrContinueStatement(kind) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(kind === 249 /* BreakStatement */ ? 81 /* BreakKeyword */ : 86 /* ContinueKeyword */);
                        const label = canParseSemicolon() ? void 0 : parseIdentifier();
                        parseSemicolon();
                        const node = kind === 249 /* BreakStatement */ ? factory2.createBreakStatement(label) : factory2.createContinueStatement(label);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseReturnStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(105 /* ReturnKeyword */);
                        const expression = canParseSemicolon() ? void 0 : allowInAnd(parseExpression);
                        parseSemicolon();
                        return withJSDoc(finishNode(factory2.createReturnStatement(expression), pos), hasJSDoc);
                    }
                    function parseWithStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(116 /* WithKeyword */);
                        const openParenPosition = scanner2.getTokenPos();
                        const openParenParsed = parseExpected(20 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpectedMatchingBrackets(20 /* OpenParenToken */, 21 /* CloseParenToken */, openParenParsed, openParenPosition);
                        const statement = doInsideOfContext(33554432 /* InWithStatement */, parseStatement);
                        return withJSDoc(finishNode(factory2.createWithStatement(expression, statement), pos), hasJSDoc);
                    }
                    function parseCaseClause() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(82 /* CaseKeyword */);
                        const expression = allowInAnd(parseExpression);
                        parseExpected(58 /* ColonToken */);
                        const statements = parseList(3 /* SwitchClauseStatements */, parseStatement);
                        return withJSDoc(finishNode(factory2.createCaseClause(expression, statements), pos), hasJSDoc);
                    }
                    function parseDefaultClause() {
                        const pos = getNodePos();
                        parseExpected(88 /* DefaultKeyword */);
                        parseExpected(58 /* ColonToken */);
                        const statements = parseList(3 /* SwitchClauseStatements */, parseStatement);
                        return finishNode(factory2.createDefaultClause(statements), pos);
                    }
                    function parseCaseOrDefaultClause() {
                        return token() === 82 /* CaseKeyword */ ? parseCaseClause() : parseDefaultClause();
                    }
                    function parseCaseBlock() {
                        const pos = getNodePos();
                        parseExpected(18 /* OpenBraceToken */);
                        const clauses = parseList(2 /* SwitchClauses */, parseCaseOrDefaultClause);
                        parseExpected(19 /* CloseBraceToken */);
                        return finishNode(factory2.createCaseBlock(clauses), pos);
                    }
                    function parseSwitchStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(107 /* SwitchKeyword */);
                        parseExpected(20 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpected(21 /* CloseParenToken */);
                        const caseBlock = parseCaseBlock();
                        return withJSDoc(finishNode(factory2.createSwitchStatement(expression, caseBlock), pos), hasJSDoc);
                    }
                    function parseThrowStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(109 /* ThrowKeyword */);
                        let expression = scanner2.hasPrecedingLineBreak() ? void 0 : allowInAnd(parseExpression);
                        if (expression === void 0) {
                            identifierCount++;
                            expression = finishNode(factoryCreateIdentifier(""), getNodePos());
                        }
                        if (!tryParseSemicolon()) {
                            parseErrorForMissingSemicolonAfter(expression);
                        }
                        return withJSDoc(finishNode(factory2.createThrowStatement(expression), pos), hasJSDoc);
                    }
                    function parseTryStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(111 /* TryKeyword */);
                        const tryBlock = parseBlock(
                        /*ignoreMissingOpenBrace*/
                        false);
                        const catchClause = token() === 83 /* CatchKeyword */ ? parseCatchClause() : void 0;
                        let finallyBlock;
                        if (!catchClause || token() === 96 /* FinallyKeyword */) {
                            parseExpected(96 /* FinallyKeyword */, Diagnostics.catch_or_finally_expected);
                            finallyBlock = parseBlock(
                            /*ignoreMissingOpenBrace*/
                            false);
                        }
                        return withJSDoc(finishNode(factory2.createTryStatement(tryBlock, catchClause, finallyBlock), pos), hasJSDoc);
                    }
                    function parseCatchClause() {
                        const pos = getNodePos();
                        parseExpected(83 /* CatchKeyword */);
                        let variableDeclaration;
                        if (parseOptional(20 /* OpenParenToken */)) {
                            variableDeclaration = parseVariableDeclaration();
                            parseExpected(21 /* CloseParenToken */);
                        }
                        else {
                            variableDeclaration = void 0;
                        }
                        const block = parseBlock(
                        /*ignoreMissingOpenBrace*/
                        false);
                        return finishNode(factory2.createCatchClause(variableDeclaration, block), pos);
                    }
                    function parseDebuggerStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(87 /* DebuggerKeyword */);
                        parseSemicolon();
                        return withJSDoc(finishNode(factory2.createDebuggerStatement(), pos), hasJSDoc);
                    }
                    function parseExpressionOrLabeledStatement() {
                        const pos = getNodePos();
                        let hasJSDoc = hasPrecedingJSDocComment();
                        let node;
                        const hasParen = token() === 20 /* OpenParenToken */;
                        const expression = allowInAnd(parseExpression);
                        if (isIdentifier(expression) && parseOptional(58 /* ColonToken */)) {
                            node = factory2.createLabeledStatement(expression, parseStatement());
                        }
                        else {
                            if (!tryParseSemicolon()) {
                                parseErrorForMissingSemicolonAfter(expression);
                            }
                            node = factoryCreateExpressionStatement(expression);
                            if (hasParen) {
                                hasJSDoc = false;
                            }
                        }
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function nextTokenIsIdentifierOrKeywordOnSameLine() {
                        nextToken();
                        return tokenIsIdentifierOrKeyword(token()) && !scanner2.hasPrecedingLineBreak();
                    }
                    function nextTokenIsClassKeywordOnSameLine() {
                        nextToken();
                        return token() === 84 /* ClassKeyword */ && !scanner2.hasPrecedingLineBreak();
                    }
                    function nextTokenIsFunctionKeywordOnSameLine() {
                        nextToken();
                        return token() === 98 /* FunctionKeyword */ && !scanner2.hasPrecedingLineBreak();
                    }
                    function nextTokenIsIdentifierOrKeywordOrLiteralOnSameLine() {
                        nextToken();
                        return (tokenIsIdentifierOrKeyword(token()) || token() === 8 /* NumericLiteral */ || token() === 9 /* BigIntLiteral */ || token() === 10 /* StringLiteral */) && !scanner2.hasPrecedingLineBreak();
                    }
                    function isDeclaration2() {
                        while (true) {
                            switch (token()) {
                                case 113 /* VarKeyword */:
                                case 119 /* LetKeyword */:
                                case 85 /* ConstKeyword */:
                                case 98 /* FunctionKeyword */:
                                case 84 /* ClassKeyword */:
                                case 92 /* EnumKeyword */:
                                    return true;
                                case 118 /* InterfaceKeyword */:
                                case 154 /* TypeKeyword */:
                                    return nextTokenIsIdentifierOnSameLine();
                                case 142 /* ModuleKeyword */:
                                case 143 /* NamespaceKeyword */:
                                    return nextTokenIsIdentifierOrStringLiteralOnSameLine();
                                case 126 /* AbstractKeyword */:
                                case 127 /* AccessorKeyword */:
                                case 132 /* AsyncKeyword */:
                                case 136 /* DeclareKeyword */:
                                case 121 /* PrivateKeyword */:
                                case 122 /* ProtectedKeyword */:
                                case 123 /* PublicKeyword */:
                                case 146 /* ReadonlyKeyword */:
                                    nextToken();
                                    if (scanner2.hasPrecedingLineBreak()) {
                                        return false;
                                    }
                                    continue;
                                case 159 /* GlobalKeyword */:
                                    nextToken();
                                    return token() === 18 /* OpenBraceToken */ || token() === 79 /* Identifier */ || token() === 93 /* ExportKeyword */;
                                case 100 /* ImportKeyword */:
                                    nextToken();
                                    return token() === 10 /* StringLiteral */ || token() === 41 /* AsteriskToken */ || token() === 18 /* OpenBraceToken */ || tokenIsIdentifierOrKeyword(token());
                                case 93 /* ExportKeyword */:
                                    let currentToken2 = nextToken();
                                    if (currentToken2 === 154 /* TypeKeyword */) {
                                        currentToken2 = lookAhead(nextToken);
                                    }
                                    if (currentToken2 === 63 /* EqualsToken */ || currentToken2 === 41 /* AsteriskToken */ || currentToken2 === 18 /* OpenBraceToken */ || currentToken2 === 88 /* DefaultKeyword */ || currentToken2 === 128 /* AsKeyword */ || currentToken2 === 59 /* AtToken */) {
                                        return true;
                                    }
                                    continue;
                                case 124 /* StaticKeyword */:
                                    nextToken();
                                    continue;
                                default:
                                    return false;
                            }
                        }
                    }
                    function isStartOfDeclaration() {
                        return lookAhead(isDeclaration2);
                    }
                    function isStartOfStatement() {
                        switch (token()) {
                            case 59 /* AtToken */:
                            case 26 /* SemicolonToken */:
                            case 18 /* OpenBraceToken */:
                            case 113 /* VarKeyword */:
                            case 119 /* LetKeyword */:
                            case 98 /* FunctionKeyword */:
                            case 84 /* ClassKeyword */:
                            case 92 /* EnumKeyword */:
                            case 99 /* IfKeyword */:
                            case 90 /* DoKeyword */:
                            case 115 /* WhileKeyword */:
                            case 97 /* ForKeyword */:
                            case 86 /* ContinueKeyword */:
                            case 81 /* BreakKeyword */:
                            case 105 /* ReturnKeyword */:
                            case 116 /* WithKeyword */:
                            case 107 /* SwitchKeyword */:
                            case 109 /* ThrowKeyword */:
                            case 111 /* TryKeyword */:
                            case 87 /* DebuggerKeyword */:
                            case 83 /* CatchKeyword */:
                            case 96 /* FinallyKeyword */:
                                return true;
                            case 100 /* ImportKeyword */:
                                return isStartOfDeclaration() || lookAhead(nextTokenIsOpenParenOrLessThanOrDot);
                            case 85 /* ConstKeyword */:
                            case 93 /* ExportKeyword */:
                                return isStartOfDeclaration();
                            case 132 /* AsyncKeyword */:
                            case 136 /* DeclareKeyword */:
                            case 118 /* InterfaceKeyword */:
                            case 142 /* ModuleKeyword */:
                            case 143 /* NamespaceKeyword */:
                            case 154 /* TypeKeyword */:
                            case 159 /* GlobalKeyword */:
                                return true;
                            case 127 /* AccessorKeyword */:
                            case 123 /* PublicKeyword */:
                            case 121 /* PrivateKeyword */:
                            case 122 /* ProtectedKeyword */:
                            case 124 /* StaticKeyword */:
                            case 146 /* ReadonlyKeyword */:
                                return isStartOfDeclaration() || !lookAhead(nextTokenIsIdentifierOrKeywordOnSameLine);
                            default:
                                return isStartOfExpression();
                        }
                    }
                    function nextTokenIsBindingIdentifierOrStartOfDestructuring() {
                        nextToken();
                        return isBindingIdentifier() || token() === 18 /* OpenBraceToken */ || token() === 22 /* OpenBracketToken */;
                    }
                    function isLetDeclaration() {
                        return lookAhead(nextTokenIsBindingIdentifierOrStartOfDestructuring);
                    }
                    function parseStatement() {
                        switch (token()) {
                            case 26 /* SemicolonToken */:
                                return parseEmptyStatement();
                            case 18 /* OpenBraceToken */:
                                return parseBlock(
                                /*ignoreMissingOpenBrace*/
                                false);
                            case 113 /* VarKeyword */:
                                return parseVariableStatement(getNodePos(), hasPrecedingJSDocComment(), 
                                /*modifiers*/
                                void 0);
                            case 119 /* LetKeyword */:
                                if (isLetDeclaration()) {
                                    return parseVariableStatement(getNodePos(), hasPrecedingJSDocComment(), 
                                    /*modifiers*/
                                    void 0);
                                }
                                break;
                            case 98 /* FunctionKeyword */:
                                return parseFunctionDeclaration(getNodePos(), hasPrecedingJSDocComment(), 
                                /*modifiers*/
                                void 0);
                            case 84 /* ClassKeyword */:
                                return parseClassDeclaration(getNodePos(), hasPrecedingJSDocComment(), 
                                /*modifiers*/
                                void 0);
                            case 99 /* IfKeyword */:
                                return parseIfStatement();
                            case 90 /* DoKeyword */:
                                return parseDoStatement();
                            case 115 /* WhileKeyword */:
                                return parseWhileStatement();
                            case 97 /* ForKeyword */:
                                return parseForOrForInOrForOfStatement();
                            case 86 /* ContinueKeyword */:
                                return parseBreakOrContinueStatement(248 /* ContinueStatement */);
                            case 81 /* BreakKeyword */:
                                return parseBreakOrContinueStatement(249 /* BreakStatement */);
                            case 105 /* ReturnKeyword */:
                                return parseReturnStatement();
                            case 116 /* WithKeyword */:
                                return parseWithStatement();
                            case 107 /* SwitchKeyword */:
                                return parseSwitchStatement();
                            case 109 /* ThrowKeyword */:
                                return parseThrowStatement();
                            case 111 /* TryKeyword */:
                            case 83 /* CatchKeyword */:
                            case 96 /* FinallyKeyword */:
                                return parseTryStatement();
                            case 87 /* DebuggerKeyword */:
                                return parseDebuggerStatement();
                            case 59 /* AtToken */:
                                return parseDeclaration();
                            case 132 /* AsyncKeyword */:
                            case 118 /* InterfaceKeyword */:
                            case 154 /* TypeKeyword */:
                            case 142 /* ModuleKeyword */:
                            case 143 /* NamespaceKeyword */:
                            case 136 /* DeclareKeyword */:
                            case 85 /* ConstKeyword */:
                            case 92 /* EnumKeyword */:
                            case 93 /* ExportKeyword */:
                            case 100 /* ImportKeyword */:
                            case 121 /* PrivateKeyword */:
                            case 122 /* ProtectedKeyword */:
                            case 123 /* PublicKeyword */:
                            case 126 /* AbstractKeyword */:
                            case 127 /* AccessorKeyword */:
                            case 124 /* StaticKeyword */:
                            case 146 /* ReadonlyKeyword */:
                            case 159 /* GlobalKeyword */:
                                if (isStartOfDeclaration()) {
                                    return parseDeclaration();
                                }
                                break;
                        }
                        return parseExpressionOrLabeledStatement();
                    }
                    function isDeclareModifier(modifier) {
                        return modifier.kind === 136 /* DeclareKeyword */;
                    }
                    function parseDeclaration() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        true);
                        const isAmbient = some(modifiers, isDeclareModifier);
                        if (isAmbient) {
                            const node = tryReuseAmbientDeclaration(pos);
                            if (node) {
                                return node;
                            }
                            for (const m of modifiers) {
                                m.flags |= 16777216 /* Ambient */;
                            }
                            return doInsideOfContext(16777216 /* Ambient */, () => parseDeclarationWorker(pos, hasJSDoc, modifiers));
                        }
                        else {
                            return parseDeclarationWorker(pos, hasJSDoc, modifiers);
                        }
                    }
                    function tryReuseAmbientDeclaration(pos) {
                        return doInsideOfContext(16777216 /* Ambient */, () => {
                            const node = currentNode(parsingContext, pos);
                            if (node) {
                                return consumeNode(node);
                            }
                        });
                    }
                    function parseDeclarationWorker(pos, hasJSDoc, modifiersIn) {
                        switch (token()) {
                            case 113 /* VarKeyword */:
                            case 119 /* LetKeyword */:
                            case 85 /* ConstKeyword */:
                                return parseVariableStatement(pos, hasJSDoc, modifiersIn);
                            case 98 /* FunctionKeyword */:
                                return parseFunctionDeclaration(pos, hasJSDoc, modifiersIn);
                            case 84 /* ClassKeyword */:
                                return parseClassDeclaration(pos, hasJSDoc, modifiersIn);
                            case 118 /* InterfaceKeyword */:
                                return parseInterfaceDeclaration(pos, hasJSDoc, modifiersIn);
                            case 154 /* TypeKeyword */:
                                return parseTypeAliasDeclaration(pos, hasJSDoc, modifiersIn);
                            case 92 /* EnumKeyword */:
                                return parseEnumDeclaration(pos, hasJSDoc, modifiersIn);
                            case 159 /* GlobalKeyword */:
                            case 142 /* ModuleKeyword */:
                            case 143 /* NamespaceKeyword */:
                                return parseModuleDeclaration(pos, hasJSDoc, modifiersIn);
                            case 100 /* ImportKeyword */:
                                return parseImportDeclarationOrImportEqualsDeclaration(pos, hasJSDoc, modifiersIn);
                            case 93 /* ExportKeyword */:
                                nextToken();
                                switch (token()) {
                                    case 88 /* DefaultKeyword */:
                                    case 63 /* EqualsToken */:
                                        return parseExportAssignment(pos, hasJSDoc, modifiersIn);
                                    case 128 /* AsKeyword */:
                                        return parseNamespaceExportDeclaration(pos, hasJSDoc, modifiersIn);
                                    default:
                                        return parseExportDeclaration(pos, hasJSDoc, modifiersIn);
                                }
                            default:
                                if (modifiersIn) {
                                    const missing = createMissingNode(279 /* MissingDeclaration */, 
                                    /*reportAtCurrentPosition*/
                                    true, Diagnostics.Declaration_expected);
                                    setTextRangePos(missing, pos);
                                    missing.modifiers = modifiersIn;
                                    return missing;
                                }
                                return void 0;
                        }
                    }
                    function nextTokenIsIdentifierOrStringLiteralOnSameLine() {
                        nextToken();
                        return !scanner2.hasPrecedingLineBreak() && (isIdentifier2() || token() === 10 /* StringLiteral */);
                    }
                    function parseFunctionBlockOrSemicolon(flags, diagnosticMessage) {
                        if (token() !== 18 /* OpenBraceToken */) {
                            if (flags & 4 /* Type */) {
                                parseTypeMemberSemicolon();
                                return;
                            }
                            if (canParseSemicolon()) {
                                parseSemicolon();
                                return;
                            }
                        }
                        return parseFunctionBlock(flags, diagnosticMessage);
                    }
                    function parseArrayBindingElement() {
                        const pos = getNodePos();
                        if (token() === 27 /* CommaToken */) {
                            return finishNode(factory2.createOmittedExpression(), pos);
                        }
                        const dotDotDotToken = parseOptionalToken(25 /* DotDotDotToken */);
                        const name = parseIdentifierOrPattern();
                        const initializer = parseInitializer();
                        return finishNode(factory2.createBindingElement(dotDotDotToken, 
                        /*propertyName*/
                        void 0, name, initializer), pos);
                    }
                    function parseObjectBindingElement() {
                        const pos = getNodePos();
                        const dotDotDotToken = parseOptionalToken(25 /* DotDotDotToken */);
                        const tokenIsIdentifier = isBindingIdentifier();
                        let propertyName = parsePropertyName();
                        let name;
                        if (tokenIsIdentifier && token() !== 58 /* ColonToken */) {
                            name = propertyName;
                            propertyName = void 0;
                        }
                        else {
                            parseExpected(58 /* ColonToken */);
                            name = parseIdentifierOrPattern();
                        }
                        const initializer = parseInitializer();
                        return finishNode(factory2.createBindingElement(dotDotDotToken, propertyName, name, initializer), pos);
                    }
                    function parseObjectBindingPattern() {
                        const pos = getNodePos();
                        parseExpected(18 /* OpenBraceToken */);
                        const elements = parseDelimitedList(9 /* ObjectBindingElements */, parseObjectBindingElement);
                        parseExpected(19 /* CloseBraceToken */);
                        return finishNode(factory2.createObjectBindingPattern(elements), pos);
                    }
                    function parseArrayBindingPattern() {
                        const pos = getNodePos();
                        parseExpected(22 /* OpenBracketToken */);
                        const elements = parseDelimitedList(10 /* ArrayBindingElements */, parseArrayBindingElement);
                        parseExpected(23 /* CloseBracketToken */);
                        return finishNode(factory2.createArrayBindingPattern(elements), pos);
                    }
                    function isBindingIdentifierOrPrivateIdentifierOrPattern() {
                        return token() === 18 /* OpenBraceToken */ || token() === 22 /* OpenBracketToken */ || token() === 80 /* PrivateIdentifier */ || isBindingIdentifier();
                    }
                    function parseIdentifierOrPattern(privateIdentifierDiagnosticMessage) {
                        if (token() === 22 /* OpenBracketToken */) {
                            return parseArrayBindingPattern();
                        }
                        if (token() === 18 /* OpenBraceToken */) {
                            return parseObjectBindingPattern();
                        }
                        return parseBindingIdentifier(privateIdentifierDiagnosticMessage);
                    }
                    function parseVariableDeclarationAllowExclamation() {
                        return parseVariableDeclaration(
                        /*allowExclamation*/
                        true);
                    }
                    function parseVariableDeclaration(allowExclamation) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const name = parseIdentifierOrPattern(Diagnostics.Private_identifiers_are_not_allowed_in_variable_declarations);
                        let exclamationToken;
                        if (allowExclamation && name.kind === 79 /* Identifier */ && token() === 53 /* ExclamationToken */ && !scanner2.hasPrecedingLineBreak()) {
                            exclamationToken = parseTokenNode();
                        }
                        const type = parseTypeAnnotation();
                        const initializer = isInOrOfKeyword(token()) ? void 0 : parseInitializer();
                        const node = factoryCreateVariableDeclaration(name, exclamationToken, type, initializer);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseVariableDeclarationList(inForStatementInitializer) {
                        const pos = getNodePos();
                        let flags = 0;
                        switch (token()) {
                            case 113 /* VarKeyword */:
                                break;
                            case 119 /* LetKeyword */:
                                flags |= 1 /* Let */;
                                break;
                            case 85 /* ConstKeyword */:
                                flags |= 2 /* Const */;
                                break;
                            default:
                                Debug.fail();
                        }
                        nextToken();
                        let declarations;
                        if (token() === 162 /* OfKeyword */ && lookAhead(canFollowContextualOfKeyword)) {
                            declarations = createMissingList();
                        }
                        else {
                            const savedDisallowIn = inDisallowInContext();
                            setDisallowInContext(inForStatementInitializer);
                            declarations = parseDelimitedList(8 /* VariableDeclarations */, inForStatementInitializer ? parseVariableDeclaration : parseVariableDeclarationAllowExclamation);
                            setDisallowInContext(savedDisallowIn);
                        }
                        return finishNode(factoryCreateVariableDeclarationList(declarations, flags), pos);
                    }
                    function canFollowContextualOfKeyword() {
                        return nextTokenIsIdentifier() && nextToken() === 21 /* CloseParenToken */;
                    }
                    function parseVariableStatement(pos, hasJSDoc, modifiers) {
                        const declarationList = parseVariableDeclarationList(
                        /*inForStatementInitializer*/
                        false);
                        parseSemicolon();
                        const node = factoryCreateVariableStatement(modifiers, declarationList);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseFunctionDeclaration(pos, hasJSDoc, modifiers) {
                        const savedAwaitContext = inAwaitContext();
                        const modifierFlags = modifiersToFlags(modifiers);
                        parseExpected(98 /* FunctionKeyword */);
                        const asteriskToken = parseOptionalToken(41 /* AsteriskToken */);
                        const name = modifierFlags & 1024 /* Default */ ? parseOptionalBindingIdentifier() : parseBindingIdentifier();
                        const isGenerator = asteriskToken ? 1 /* Yield */ : 0 /* None */;
                        const isAsync = modifierFlags & 512 /* Async */ ? 2 /* Await */ : 0 /* None */;
                        const typeParameters = parseTypeParameters();
                        if (modifierFlags & 1 /* Export */)
                            setAwaitContext(
                            /*value*/
                            true);
                        const parameters = parseParameters(isGenerator | isAsync);
                        const type = parseReturnType(58 /* ColonToken */, 
                        /*isType*/
                        false);
                        const body = parseFunctionBlockOrSemicolon(isGenerator | isAsync, Diagnostics.or_expected);
                        setAwaitContext(savedAwaitContext);
                        const node = factory2.createFunctionDeclaration(modifiers, asteriskToken, name, typeParameters, parameters, type, body);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseConstructorName() {
                        if (token() === 135 /* ConstructorKeyword */) {
                            return parseExpected(135 /* ConstructorKeyword */);
                        }
                        if (token() === 10 /* StringLiteral */ && lookAhead(nextToken) === 20 /* OpenParenToken */) {
                            return tryParse(() => {
                                const literalNode = parseLiteralNode();
                                return literalNode.text === "constructor" ? literalNode : void 0;
                            });
                        }
                    }
                    function tryParseConstructorDeclaration(pos, hasJSDoc, modifiers) {
                        return tryParse(() => {
                            if (parseConstructorName()) {
                                const typeParameters = parseTypeParameters();
                                const parameters = parseParameters(0 /* None */);
                                const type = parseReturnType(58 /* ColonToken */, 
                                /*isType*/
                                false);
                                const body = parseFunctionBlockOrSemicolon(0 /* None */, Diagnostics.or_expected);
                                const node = factory2.createConstructorDeclaration(modifiers, parameters, body);
                                node.typeParameters = typeParameters;
                                node.type = type;
                                return withJSDoc(finishNode(node, pos), hasJSDoc);
                            }
                        });
                    }
                    function parseMethodDeclaration(pos, hasJSDoc, modifiers, asteriskToken, name, questionToken, exclamationToken, diagnosticMessage) {
                        const isGenerator = asteriskToken ? 1 /* Yield */ : 0 /* None */;
                        const isAsync = some(modifiers, isAsyncModifier) ? 2 /* Await */ : 0 /* None */;
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(isGenerator | isAsync);
                        const type = parseReturnType(58 /* ColonToken */, 
                        /*isType*/
                        false);
                        const body = parseFunctionBlockOrSemicolon(isGenerator | isAsync, diagnosticMessage);
                        const node = factory2.createMethodDeclaration(modifiers, asteriskToken, name, questionToken, typeParameters, parameters, type, body);
                        node.exclamationToken = exclamationToken;
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parsePropertyDeclaration(pos, hasJSDoc, modifiers, name, questionToken) {
                        const exclamationToken = !questionToken && !scanner2.hasPrecedingLineBreak() ? parseOptionalToken(53 /* ExclamationToken */) : void 0;
                        const type = parseTypeAnnotation();
                        const initializer = doOutsideOfContext(8192 /* YieldContext */ | 32768 /* AwaitContext */ | 4096 /* DisallowInContext */, parseInitializer);
                        parseSemicolonAfterPropertyName(name, type, initializer);
                        const node = factory2.createPropertyDeclaration(modifiers, name, questionToken || exclamationToken, type, initializer);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parsePropertyOrMethodDeclaration(pos, hasJSDoc, modifiers) {
                        const asteriskToken = parseOptionalToken(41 /* AsteriskToken */);
                        const name = parsePropertyName();
                        const questionToken = parseOptionalToken(57 /* QuestionToken */);
                        if (asteriskToken || token() === 20 /* OpenParenToken */ || token() === 29 /* LessThanToken */) {
                            return parseMethodDeclaration(pos, hasJSDoc, modifiers, asteriskToken, name, questionToken, 
                            /*exclamationToken*/
                            void 0, Diagnostics.or_expected);
                        }
                        return parsePropertyDeclaration(pos, hasJSDoc, modifiers, name, questionToken);
                    }
                    function parseAccessorDeclaration(pos, hasJSDoc, modifiers, kind, flags) {
                        const name = parsePropertyName();
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(0 /* None */);
                        const type = parseReturnType(58 /* ColonToken */, 
                        /*isType*/
                        false);
                        const body = parseFunctionBlockOrSemicolon(flags);
                        const node = kind === 174 /* GetAccessor */ ? factory2.createGetAccessorDeclaration(modifiers, name, parameters, type, body) : factory2.createSetAccessorDeclaration(modifiers, name, parameters, body);
                        node.typeParameters = typeParameters;
                        if (isSetAccessorDeclaration(node))
                            node.type = type;
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function isClassMemberStart() {
                        let idToken;
                        if (token() === 59 /* AtToken */) {
                            return true;
                        }
                        while (isModifierKind(token())) {
                            idToken = token();
                            if (isClassMemberModifier(idToken)) {
                                return true;
                            }
                            nextToken();
                        }
                        if (token() === 41 /* AsteriskToken */) {
                            return true;
                        }
                        if (isLiteralPropertyName()) {
                            idToken = token();
                            nextToken();
                        }
                        if (token() === 22 /* OpenBracketToken */) {
                            return true;
                        }
                        if (idToken !== void 0) {
                            if (!isKeyword(idToken) || idToken === 151 /* SetKeyword */ || idToken === 137 /* GetKeyword */) {
                                return true;
                            }
                            switch (token()) {
                                case 20 /* OpenParenToken */:
                                case 29 /* LessThanToken */:
                                case 53 /* ExclamationToken */:
                                case 58 /* ColonToken */:
                                case 63 /* EqualsToken */:
                                case 57 /* QuestionToken */:
                                    return true;
                                default:
                                    return canParseSemicolon();
                            }
                        }
                        return false;
                    }
                    function parseClassStaticBlockDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpectedToken(124 /* StaticKeyword */);
                        const body = parseClassStaticBlockBody();
                        const node = withJSDoc(finishNode(factory2.createClassStaticBlockDeclaration(body), pos), hasJSDoc);
                        node.modifiers = modifiers;
                        return node;
                    }
                    function parseClassStaticBlockBody() {
                        const savedYieldContext = inYieldContext();
                        const savedAwaitContext = inAwaitContext();
                        setYieldContext(false);
                        setAwaitContext(true);
                        const body = parseBlock(
                        /*ignoreMissingOpenBrace*/
                        false);
                        setYieldContext(savedYieldContext);
                        setAwaitContext(savedAwaitContext);
                        return body;
                    }
                    function parseDecoratorExpression() {
                        if (inAwaitContext() && token() === 133 /* AwaitKeyword */) {
                            const pos = getNodePos();
                            const awaitExpression = parseIdentifier(Diagnostics.Expression_expected);
                            nextToken();
                            const memberExpression = parseMemberExpressionRest(pos, awaitExpression, 
                            /*allowOptionalChain*/
                            true);
                            return parseCallExpressionRest(pos, memberExpression);
                        }
                        return parseLeftHandSideExpressionOrHigher();
                    }
                    function tryParseDecorator() {
                        const pos = getNodePos();
                        if (!parseOptional(59 /* AtToken */)) {
                            return void 0;
                        }
                        const expression = doInDecoratorContext(parseDecoratorExpression);
                        return finishNode(factory2.createDecorator(expression), pos);
                    }
                    function tryParseModifier(hasSeenStaticModifier, permitConstAsModifier, stopOnStartOfClassStaticBlock) {
                        const pos = getNodePos();
                        const kind = token();
                        if (token() === 85 /* ConstKeyword */ && permitConstAsModifier) {
                            if (!tryParse(nextTokenIsOnSameLineAndCanFollowModifier)) {
                                return void 0;
                            }
                        }
                        else if (stopOnStartOfClassStaticBlock && token() === 124 /* StaticKeyword */ && lookAhead(nextTokenIsOpenBrace)) {
                            return void 0;
                        }
                        else if (hasSeenStaticModifier && token() === 124 /* StaticKeyword */) {
                            return void 0;
                        }
                        else {
                            if (!parseAnyContextualModifier()) {
                                return void 0;
                            }
                        }
                        return finishNode(factoryCreateToken(kind), pos);
                    }
                    function parseModifiers(allowDecorators, permitConstAsModifier, stopOnStartOfClassStaticBlock) {
                        const pos = getNodePos();
                        let list;
                        let decorator, modifier, hasSeenStaticModifier = false, hasLeadingModifier = false, hasTrailingDecorator = false;
                        if (allowDecorators && token() === 59 /* AtToken */) {
                            while (decorator = tryParseDecorator()) {
                                list = append(list, decorator);
                            }
                        }
                        while (modifier = tryParseModifier(hasSeenStaticModifier, permitConstAsModifier, stopOnStartOfClassStaticBlock)) {
                            if (modifier.kind === 124 /* StaticKeyword */)
                                hasSeenStaticModifier = true;
                            list = append(list, modifier);
                            hasLeadingModifier = true;
                        }
                        if (hasLeadingModifier && allowDecorators && token() === 59 /* AtToken */) {
                            while (decorator = tryParseDecorator()) {
                                list = append(list, decorator);
                                hasTrailingDecorator = true;
                            }
                        }
                        if (hasTrailingDecorator) {
                            while (modifier = tryParseModifier(hasSeenStaticModifier, permitConstAsModifier, stopOnStartOfClassStaticBlock)) {
                                if (modifier.kind === 124 /* StaticKeyword */)
                                    hasSeenStaticModifier = true;
                                list = append(list, modifier);
                            }
                        }
                        return list && createNodeArray(list, pos);
                    }
                    function parseModifiersForArrowFunction() {
                        let modifiers;
                        if (token() === 132 /* AsyncKeyword */) {
                            const pos = getNodePos();
                            nextToken();
                            const modifier = finishNode(factoryCreateToken(132 /* AsyncKeyword */), pos);
                            modifiers = createNodeArray([modifier], pos);
                        }
                        return modifiers;
                    }
                    function parseClassElement() {
                        const pos = getNodePos();
                        if (token() === 26 /* SemicolonToken */) {
                            nextToken();
                            return finishNode(factory2.createSemicolonClassElement(), pos);
                        }
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        true, 
                        /*permitConstAsModifier*/
                        true, 
                        /*stopOnStartOfClassStaticBlock*/
                        true);
                        if (token() === 124 /* StaticKeyword */ && lookAhead(nextTokenIsOpenBrace)) {
                            return parseClassStaticBlockDeclaration(pos, hasJSDoc, modifiers);
                        }
                        if (parseContextualModifier(137 /* GetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 174 /* GetAccessor */, 0 /* None */);
                        }
                        if (parseContextualModifier(151 /* SetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 175 /* SetAccessor */, 0 /* None */);
                        }
                        if (token() === 135 /* ConstructorKeyword */ || token() === 10 /* StringLiteral */) {
                            const constructorDeclaration = tryParseConstructorDeclaration(pos, hasJSDoc, modifiers);
                            if (constructorDeclaration) {
                                return constructorDeclaration;
                            }
                        }
                        if (isIndexSignature()) {
                            return parseIndexSignatureDeclaration(pos, hasJSDoc, modifiers);
                        }
                        if (tokenIsIdentifierOrKeyword(token()) || token() === 10 /* StringLiteral */ || token() === 8 /* NumericLiteral */ || token() === 41 /* AsteriskToken */ || token() === 22 /* OpenBracketToken */) {
                            const isAmbient = some(modifiers, isDeclareModifier);
                            if (isAmbient) {
                                for (const m of modifiers) {
                                    m.flags |= 16777216 /* Ambient */;
                                }
                                return doInsideOfContext(16777216 /* Ambient */, () => parsePropertyOrMethodDeclaration(pos, hasJSDoc, modifiers));
                            }
                            else {
                                return parsePropertyOrMethodDeclaration(pos, hasJSDoc, modifiers);
                            }
                        }
                        if (modifiers) {
                            const name = createMissingNode(79 /* Identifier */, 
                            /*reportAtCurrentPosition*/
                            true, Diagnostics.Declaration_expected);
                            return parsePropertyDeclaration(pos, hasJSDoc, modifiers, name, 
                            /*questionToken*/
                            void 0);
                        }
                        return Debug.fail("Should not have attempted to parse class member declaration.");
                    }
                    function parseDecoratedExpression() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        true);
                        if (token() === 84 /* ClassKeyword */) {
                            return parseClassDeclarationOrExpression(pos, hasJSDoc, modifiers, 228 /* ClassExpression */);
                        }
                        const missing = createMissingNode(279 /* MissingDeclaration */, 
                        /*reportAtCurrentPosition*/
                        true, Diagnostics.Expression_expected);
                        setTextRangePos(missing, pos);
                        missing.modifiers = modifiers;
                        return missing;
                    }
                    function parseClassExpression() {
                        return parseClassDeclarationOrExpression(getNodePos(), hasPrecedingJSDocComment(), 
                        /*modifiers*/
                        void 0, 228 /* ClassExpression */);
                    }
                    function parseClassDeclaration(pos, hasJSDoc, modifiers) {
                        return parseClassDeclarationOrExpression(pos, hasJSDoc, modifiers, 260 /* ClassDeclaration */);
                    }
                    function parseClassDeclarationOrExpression(pos, hasJSDoc, modifiers, kind) {
                        const savedAwaitContext = inAwaitContext();
                        parseExpected(84 /* ClassKeyword */);
                        const name = parseNameOfClassDeclarationOrExpression();
                        const typeParameters = parseTypeParameters();
                        if (some(modifiers, isExportModifier))
                            setAwaitContext(
                            /*value*/
                            true);
                        const heritageClauses = parseHeritageClauses();
                        let members;
                        if (parseExpected(18 /* OpenBraceToken */)) {
                            members = parseClassMembers();
                            parseExpected(19 /* CloseBraceToken */);
                        }
                        else {
                            members = createMissingList();
                        }
                        setAwaitContext(savedAwaitContext);
                        const node = kind === 260 /* ClassDeclaration */ ? factory2.createClassDeclaration(modifiers, name, typeParameters, heritageClauses, members) : factory2.createClassExpression(modifiers, name, typeParameters, heritageClauses, members);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseNameOfClassDeclarationOrExpression() {
                        return isBindingIdentifier() && !isImplementsClause() ? createIdentifier(isBindingIdentifier()) : void 0;
                    }
                    function isImplementsClause() {
                        return token() === 117 /* ImplementsKeyword */ && lookAhead(nextTokenIsIdentifierOrKeyword);
                    }
                    function parseHeritageClauses() {
                        if (isHeritageClause2()) {
                            return parseList(22 /* HeritageClauses */, parseHeritageClause);
                        }
                        return void 0;
                    }
                    function parseHeritageClause() {
                        const pos = getNodePos();
                        const tok = token();
                        Debug.assert(tok === 94 /* ExtendsKeyword */ || tok === 117 /* ImplementsKeyword */);
                        nextToken();
                        const types = parseDelimitedList(7 /* HeritageClauseElement */, parseExpressionWithTypeArguments);
                        return finishNode(factory2.createHeritageClause(tok, types), pos);
                    }
                    function parseExpressionWithTypeArguments() {
                        const pos = getNodePos();
                        const expression = parseLeftHandSideExpressionOrHigher();
                        if (expression.kind === 230 /* ExpressionWithTypeArguments */) {
                            return expression;
                        }
                        const typeArguments = tryParseTypeArguments();
                        return finishNode(factory2.createExpressionWithTypeArguments(expression, typeArguments), pos);
                    }
                    function tryParseTypeArguments() {
                        return token() === 29 /* LessThanToken */ ? parseBracketedList(20 /* TypeArguments */, parseType, 29 /* LessThanToken */, 31 /* GreaterThanToken */) : void 0;
                    }
                    function isHeritageClause2() {
                        return token() === 94 /* ExtendsKeyword */ || token() === 117 /* ImplementsKeyword */;
                    }
                    function parseClassMembers() {
                        return parseList(5 /* ClassMembers */, parseClassElement);
                    }
                    function parseInterfaceDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(118 /* InterfaceKeyword */);
                        const name = parseIdentifier();
                        const typeParameters = parseTypeParameters();
                        const heritageClauses = parseHeritageClauses();
                        const members = parseObjectTypeMembers();
                        const node = factory2.createInterfaceDeclaration(modifiers, name, typeParameters, heritageClauses, members);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseTypeAliasDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(154 /* TypeKeyword */);
                        const name = parseIdentifier();
                        const typeParameters = parseTypeParameters();
                        parseExpected(63 /* EqualsToken */);
                        const type = token() === 139 /* IntrinsicKeyword */ && tryParse(parseKeywordAndNoDot) || parseType();
                        parseSemicolon();
                        const node = factory2.createTypeAliasDeclaration(modifiers, name, typeParameters, type);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseEnumMember() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const name = parsePropertyName();
                        const initializer = allowInAnd(parseInitializer);
                        return withJSDoc(finishNode(factory2.createEnumMember(name, initializer), pos), hasJSDoc);
                    }
                    function parseEnumDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(92 /* EnumKeyword */);
                        const name = parseIdentifier();
                        let members;
                        if (parseExpected(18 /* OpenBraceToken */)) {
                            members = doOutsideOfYieldAndAwaitContext(() => parseDelimitedList(6 /* EnumMembers */, parseEnumMember));
                            parseExpected(19 /* CloseBraceToken */);
                        }
                        else {
                            members = createMissingList();
                        }
                        const node = factory2.createEnumDeclaration(modifiers, name, members);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseModuleBlock() {
                        const pos = getNodePos();
                        let statements;
                        if (parseExpected(18 /* OpenBraceToken */)) {
                            statements = parseList(1 /* BlockStatements */, parseStatement);
                            parseExpected(19 /* CloseBraceToken */);
                        }
                        else {
                            statements = createMissingList();
                        }
                        return finishNode(factory2.createModuleBlock(statements), pos);
                    }
                    function parseModuleOrNamespaceDeclaration(pos, hasJSDoc, modifiers, flags) {
                        const namespaceFlag = flags & 16 /* Namespace */;
                        const name = parseIdentifier();
                        const body = parseOptional(24 /* DotToken */) ? parseModuleOrNamespaceDeclaration(getNodePos(), 
                        /*hasJSDoc*/
                        false, 
                        /*modifiers*/
                        void 0, 4 /* NestedNamespace */ | namespaceFlag) : parseModuleBlock();
                        const node = factory2.createModuleDeclaration(modifiers, name, body, flags);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseAmbientExternalModuleDeclaration(pos, hasJSDoc, modifiersIn) {
                        let flags = 0;
                        let name;
                        if (token() === 159 /* GlobalKeyword */) {
                            name = parseIdentifier();
                            flags |= 1024 /* GlobalAugmentation */;
                        }
                        else {
                            name = parseLiteralNode();
                            name.text = internIdentifier(name.text);
                        }
                        let body;
                        if (token() === 18 /* OpenBraceToken */) {
                            body = parseModuleBlock();
                        }
                        else {
                            parseSemicolon();
                        }
                        const node = factory2.createModuleDeclaration(modifiersIn, name, body, flags);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseModuleDeclaration(pos, hasJSDoc, modifiersIn) {
                        let flags = 0;
                        if (token() === 159 /* GlobalKeyword */) {
                            return parseAmbientExternalModuleDeclaration(pos, hasJSDoc, modifiersIn);
                        }
                        else if (parseOptional(143 /* NamespaceKeyword */)) {
                            flags |= 16 /* Namespace */;
                        }
                        else {
                            parseExpected(142 /* ModuleKeyword */);
                            if (token() === 10 /* StringLiteral */) {
                                return parseAmbientExternalModuleDeclaration(pos, hasJSDoc, modifiersIn);
                            }
                        }
                        return parseModuleOrNamespaceDeclaration(pos, hasJSDoc, modifiersIn, flags);
                    }
                    function isExternalModuleReference2() {
                        return token() === 147 /* RequireKeyword */ && lookAhead(nextTokenIsOpenParen);
                    }
                    function nextTokenIsOpenParen() {
                        return nextToken() === 20 /* OpenParenToken */;
                    }
                    function nextTokenIsOpenBrace() {
                        return nextToken() === 18 /* OpenBraceToken */;
                    }
                    function nextTokenIsSlash() {
                        return nextToken() === 43 /* SlashToken */;
                    }
                    function parseNamespaceExportDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(128 /* AsKeyword */);
                        parseExpected(143 /* NamespaceKeyword */);
                        const name = parseIdentifier();
                        parseSemicolon();
                        const node = factory2.createNamespaceExportDeclaration(name);
                        node.modifiers = modifiers;
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseImportDeclarationOrImportEqualsDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(100 /* ImportKeyword */);
                        const afterImportPos = scanner2.getStartPos();
                        let identifier;
                        if (isIdentifier2()) {
                            identifier = parseIdentifier();
                        }
                        let isTypeOnly = false;
                        if (token() !== 158 /* FromKeyword */ && (identifier == null ? void 0 : identifier.escapedText) === "type" && (isIdentifier2() || tokenAfterImportDefinitelyProducesImportDeclaration())) {
                            isTypeOnly = true;
                            identifier = isIdentifier2() ? parseIdentifier() : void 0;
                        }
                        if (identifier && !tokenAfterImportedIdentifierDefinitelyProducesImportDeclaration()) {
                            return parseImportEqualsDeclaration(pos, hasJSDoc, modifiers, identifier, isTypeOnly);
                        }
                        let importClause;
                        if (identifier || // import id
                            token() === 41 /* AsteriskToken */ || // import *
                            token() === 18 /* OpenBraceToken */) {
                            importClause = parseImportClause(identifier, afterImportPos, isTypeOnly);
                            parseExpected(158 /* FromKeyword */);
                        }
                        const moduleSpecifier = parseModuleSpecifier();
                        let assertClause;
                        if (token() === 130 /* AssertKeyword */ && !scanner2.hasPrecedingLineBreak()) {
                            assertClause = parseAssertClause();
                        }
                        parseSemicolon();
                        const node = factory2.createImportDeclaration(modifiers, importClause, moduleSpecifier, assertClause);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseAssertEntry() {
                        const pos = getNodePos();
                        const name = tokenIsIdentifierOrKeyword(token()) ? parseIdentifierName() : parseLiteralLikeNode(10 /* StringLiteral */);
                        parseExpected(58 /* ColonToken */);
                        const value = parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                        return finishNode(factory2.createAssertEntry(name, value), pos);
                    }
                    function parseAssertClause(skipAssertKeyword) {
                        const pos = getNodePos();
                        if (!skipAssertKeyword) {
                            parseExpected(130 /* AssertKeyword */);
                        }
                        const openBracePosition = scanner2.getTokenPos();
                        if (parseExpected(18 /* OpenBraceToken */)) {
                            const multiLine = scanner2.hasPrecedingLineBreak();
                            const elements = parseDelimitedList(24 /* AssertEntries */, parseAssertEntry, 
                            /*considerSemicolonAsDelimiter*/
                            true);
                            if (!parseExpected(19 /* CloseBraceToken */)) {
                                const lastError = lastOrUndefined(parseDiagnostics);
                                if (lastError && lastError.code === Diagnostics._0_expected.code) {
                                    addRelatedInfo(lastError, createDetachedDiagnostic(fileName, openBracePosition, 1, Diagnostics.The_parser_expected_to_find_a_1_to_match_the_0_token_here, "{", "}"));
                                }
                            }
                            return finishNode(factory2.createAssertClause(elements, multiLine), pos);
                        }
                        else {
                            const elements = createNodeArray([], getNodePos(), 
                            /*end*/
                            void 0, 
                            /*hasTrailingComma*/
                            false);
                            return finishNode(factory2.createAssertClause(elements, 
                            /*multiLine*/
                            false), pos);
                        }
                    }
                    function tokenAfterImportDefinitelyProducesImportDeclaration() {
                        return token() === 41 /* AsteriskToken */ || token() === 18 /* OpenBraceToken */;
                    }
                    function tokenAfterImportedIdentifierDefinitelyProducesImportDeclaration() {
                        return token() === 27 /* CommaToken */ || token() === 158 /* FromKeyword */;
                    }
                    function parseImportEqualsDeclaration(pos, hasJSDoc, modifiers, identifier, isTypeOnly) {
                        parseExpected(63 /* EqualsToken */);
                        const moduleReference = parseModuleReference();
                        parseSemicolon();
                        const node = factory2.createImportEqualsDeclaration(modifiers, isTypeOnly, identifier, moduleReference);
                        const finished = withJSDoc(finishNode(node, pos), hasJSDoc);
                        return finished;
                    }
                    function parseImportClause(identifier, pos, isTypeOnly) {
                        let namedBindings;
                        if (!identifier || parseOptional(27 /* CommaToken */)) {
                            namedBindings = token() === 41 /* AsteriskToken */ ? parseNamespaceImport() : parseNamedImportsOrExports(272 /* NamedImports */);
                        }
                        return finishNode(factory2.createImportClause(isTypeOnly, identifier, namedBindings), pos);
                    }
                    function parseModuleReference() {
                        return isExternalModuleReference2() ? parseExternalModuleReference() : parseEntityName(
                        /*allowReservedWords*/
                        false);
                    }
                    function parseExternalModuleReference() {
                        const pos = getNodePos();
                        parseExpected(147 /* RequireKeyword */);
                        parseExpected(20 /* OpenParenToken */);
                        const expression = parseModuleSpecifier();
                        parseExpected(21 /* CloseParenToken */);
                        return finishNode(factory2.createExternalModuleReference(expression), pos);
                    }
                    function parseModuleSpecifier() {
                        if (token() === 10 /* StringLiteral */) {
                            const result = parseLiteralNode();
                            result.text = internIdentifier(result.text);
                            return result;
                        }
                        else {
                            return parseExpression();
                        }
                    }
                    function parseNamespaceImport() {
                        const pos = getNodePos();
                        parseExpected(41 /* AsteriskToken */);
                        parseExpected(128 /* AsKeyword */);
                        const name = parseIdentifier();
                        return finishNode(factory2.createNamespaceImport(name), pos);
                    }
                    function parseNamedImportsOrExports(kind) {
                        const pos = getNodePos();
                        const node = kind === 272 /* NamedImports */ ? factory2.createNamedImports(parseBracketedList(23 /* ImportOrExportSpecifiers */, parseImportSpecifier, 18 /* OpenBraceToken */, 19 /* CloseBraceToken */)) : factory2.createNamedExports(parseBracketedList(23 /* ImportOrExportSpecifiers */, parseExportSpecifier, 18 /* OpenBraceToken */, 19 /* CloseBraceToken */));
                        return finishNode(node, pos);
                    }
                    function parseExportSpecifier() {
                        const hasJSDoc = hasPrecedingJSDocComment();
                        return withJSDoc(parseImportOrExportSpecifier(278 /* ExportSpecifier */), hasJSDoc);
                    }
                    function parseImportSpecifier() {
                        return parseImportOrExportSpecifier(273 /* ImportSpecifier */);
                    }
                    function parseImportOrExportSpecifier(kind) {
                        const pos = getNodePos();
                        let checkIdentifierIsKeyword = isKeyword(token()) && !isIdentifier2();
                        let checkIdentifierStart = scanner2.getTokenPos();
                        let checkIdentifierEnd = scanner2.getTextPos();
                        let isTypeOnly = false;
                        let propertyName;
                        let canParseAsKeyword = true;
                        let name = parseIdentifierName();
                        if (name.escapedText === "type") {
                            if (token() === 128 /* AsKeyword */) {
                                const firstAs = parseIdentifierName();
                                if (token() === 128 /* AsKeyword */) {
                                    const secondAs = parseIdentifierName();
                                    if (tokenIsIdentifierOrKeyword(token())) {
                                        isTypeOnly = true;
                                        propertyName = firstAs;
                                        name = parseNameWithKeywordCheck();
                                        canParseAsKeyword = false;
                                    }
                                    else {
                                        propertyName = name;
                                        name = secondAs;
                                        canParseAsKeyword = false;
                                    }
                                }
                                else if (tokenIsIdentifierOrKeyword(token())) {
                                    propertyName = name;
                                    canParseAsKeyword = false;
                                    name = parseNameWithKeywordCheck();
                                }
                                else {
                                    isTypeOnly = true;
                                    name = firstAs;
                                }
                            }
                            else if (tokenIsIdentifierOrKeyword(token())) {
                                isTypeOnly = true;
                                name = parseNameWithKeywordCheck();
                            }
                        }
                        if (canParseAsKeyword && token() === 128 /* AsKeyword */) {
                            propertyName = name;
                            parseExpected(128 /* AsKeyword */);
                            name = parseNameWithKeywordCheck();
                        }
                        if (kind === 273 /* ImportSpecifier */ && checkIdentifierIsKeyword) {
                            parseErrorAt(checkIdentifierStart, checkIdentifierEnd, Diagnostics.Identifier_expected);
                        }
                        const node = kind === 273 /* ImportSpecifier */ ? factory2.createImportSpecifier(isTypeOnly, propertyName, name) : factory2.createExportSpecifier(isTypeOnly, propertyName, name);
                        return finishNode(node, pos);
                        function parseNameWithKeywordCheck() {
                            checkIdentifierIsKeyword = isKeyword(token()) && !isIdentifier2();
                            checkIdentifierStart = scanner2.getTokenPos();
                            checkIdentifierEnd = scanner2.getTextPos();
                            return parseIdentifierName();
                        }
                    }
                    function parseNamespaceExport(pos) {
                        return finishNode(factory2.createNamespaceExport(parseIdentifierName()), pos);
                    }
                    function parseExportDeclaration(pos, hasJSDoc, modifiers) {
                        const savedAwaitContext = inAwaitContext();
                        setAwaitContext(
                        /*value*/
                        true);
                        let exportClause;
                        let moduleSpecifier;
                        let assertClause;
                        const isTypeOnly = parseOptional(154 /* TypeKeyword */);
                        const namespaceExportPos = getNodePos();
                        if (parseOptional(41 /* AsteriskToken */)) {
                            if (parseOptional(128 /* AsKeyword */)) {
                                exportClause = parseNamespaceExport(namespaceExportPos);
                            }
                            parseExpected(158 /* FromKeyword */);
                            moduleSpecifier = parseModuleSpecifier();
                        }
                        else {
                            exportClause = parseNamedImportsOrExports(276 /* NamedExports */);
                            if (token() === 158 /* FromKeyword */ || token() === 10 /* StringLiteral */ && !scanner2.hasPrecedingLineBreak()) {
                                parseExpected(158 /* FromKeyword */);
                                moduleSpecifier = parseModuleSpecifier();
                            }
                        }
                        if (moduleSpecifier && token() === 130 /* AssertKeyword */ && !scanner2.hasPrecedingLineBreak()) {
                            assertClause = parseAssertClause();
                        }
                        parseSemicolon();
                        setAwaitContext(savedAwaitContext);
                        const node = factory2.createExportDeclaration(modifiers, isTypeOnly, exportClause, moduleSpecifier, assertClause);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseExportAssignment(pos, hasJSDoc, modifiers) {
                        const savedAwaitContext = inAwaitContext();
                        setAwaitContext(
                        /*value*/
                        true);
                        let isExportEquals;
                        if (parseOptional(63 /* EqualsToken */)) {
                            isExportEquals = true;
                        }
                        else {
                            parseExpected(88 /* DefaultKeyword */);
                        }
                        const expression = parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                        parseSemicolon();
                        setAwaitContext(savedAwaitContext);
                        const node = factory2.createExportAssignment(modifiers, isExportEquals, expression);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    let ParsingContext;
                    ((ParsingContext2) => {
                        ParsingContext2[ParsingContext2["SourceElements"] = 0] = "SourceElements";
                        ParsingContext2[ParsingContext2["BlockStatements"] = 1] = "BlockStatements";
                        ParsingContext2[ParsingContext2["SwitchClauses"] = 2] = "SwitchClauses";
                        ParsingContext2[ParsingContext2["SwitchClauseStatements"] = 3] = "SwitchClauseStatements";
                        ParsingContext2[ParsingContext2["TypeMembers"] = 4] = "TypeMembers";
                        ParsingContext2[ParsingContext2["ClassMembers"] = 5] = "ClassMembers";
                        ParsingContext2[ParsingContext2["EnumMembers"] = 6] = "EnumMembers";
                        ParsingContext2[ParsingContext2["HeritageClauseElement"] = 7] = "HeritageClauseElement";
                        ParsingContext2[ParsingContext2["VariableDeclarations"] = 8] = "VariableDeclarations";
                        ParsingContext2[ParsingContext2["ObjectBindingElements"] = 9] = "ObjectBindingElements";
                        ParsingContext2[ParsingContext2["ArrayBindingElements"] = 10] = "ArrayBindingElements";
                        ParsingContext2[ParsingContext2["ArgumentExpressions"] = 11] = "ArgumentExpressions";
                        ParsingContext2[ParsingContext2["ObjectLiteralMembers"] = 12] = "ObjectLiteralMembers";
                        ParsingContext2[ParsingContext2["JsxAttributes"] = 13] = "JsxAttributes";
                        ParsingContext2[ParsingContext2["JsxChildren"] = 14] = "JsxChildren";
                        ParsingContext2[ParsingContext2["ArrayLiteralMembers"] = 15] = "ArrayLiteralMembers";
                        ParsingContext2[ParsingContext2["Parameters"] = 16] = "Parameters";
                        ParsingContext2[ParsingContext2["JSDocParameters"] = 17] = "JSDocParameters";
                        ParsingContext2[ParsingContext2["RestProperties"] = 18] = "RestProperties";
                        ParsingContext2[ParsingContext2["TypeParameters"] = 19] = "TypeParameters";
                        ParsingContext2[ParsingContext2["TypeArguments"] = 20] = "TypeArguments";
                        ParsingContext2[ParsingContext2["TupleElementTypes"] = 21] = "TupleElementTypes";
                        ParsingContext2[ParsingContext2["HeritageClauses"] = 22] = "HeritageClauses";
                        ParsingContext2[ParsingContext2["ImportOrExportSpecifiers"] = 23] = "ImportOrExportSpecifiers";
                        ParsingContext2[ParsingContext2["AssertEntries"] = 24] = "AssertEntries";
                        ParsingContext2[ParsingContext2["Count"] = 25] = "Count";
                    })(ParsingContext || (ParsingContext = {}));
                    let Tristate;
                    ((Tristate2) => {
                        Tristate2[Tristate2["False"] = 0] = "False";
                        Tristate2[Tristate2["True"] = 1] = "True";
                        Tristate2[Tristate2["Unknown"] = 2] = "Unknown";
                    })(Tristate || (Tristate = {}));
                    let JSDocParser;
                    ((JSDocParser2) => {
                        function parseJSDocTypeExpressionForTests2(content, start, length2) {
                            initializeState("file.js", content, 99 /* Latest */, 
                            /*_syntaxCursor:*/
                            void 0, 1 /* JS */);
                            scanner2.setText(content, start, length2);
                            currentToken = scanner2.scan();
                            const jsDocTypeExpression = parseJSDocTypeExpression();
                            const sourceFile = createSourceFile2("file.js", 99 /* Latest */, 1 /* JS */, 
                            /*isDeclarationFile*/
                            false, [], factoryCreateToken(1 /* EndOfFileToken */), 0 /* None */, noop);
                            const diagnostics = attachFileToDiagnostics(parseDiagnostics, sourceFile);
                            if (jsDocDiagnostics) {
                                sourceFile.jsDocDiagnostics = attachFileToDiagnostics(jsDocDiagnostics, sourceFile);
                            }
                            clearState();
                            return jsDocTypeExpression ? { jsDocTypeExpression, diagnostics } : void 0;
                        }
                        JSDocParser2.parseJSDocTypeExpressionForTests = parseJSDocTypeExpressionForTests2;
                        function parseJSDocTypeExpression(mayOmitBraces) {
                            const pos = getNodePos();
                            const hasBrace = (mayOmitBraces ? parseOptional : parseExpected)(18 /* OpenBraceToken */);
                            const type = doInsideOfContext(8388608 /* JSDoc */, parseJSDocType);
                            if (!mayOmitBraces || hasBrace) {
                                parseExpectedJSDoc(19 /* CloseBraceToken */);
                            }
                            const result = factory2.createJSDocTypeExpression(type);
                            fixupParentReferences(result);
                            return finishNode(result, pos);
                        }
                        JSDocParser2.parseJSDocTypeExpression = parseJSDocTypeExpression;
                        function parseJSDocNameReference() {
                            const pos = getNodePos();
                            const hasBrace = parseOptional(18 /* OpenBraceToken */);
                            const p2 = getNodePos();
                            let entityName = parseEntityName(
                            /* allowReservedWords*/
                            false);
                            while (token() === 80 /* PrivateIdentifier */) {
                                reScanHashToken();
                                nextTokenJSDoc();
                                entityName = finishNode(factory2.createJSDocMemberName(entityName, parseIdentifier()), p2);
                            }
                            if (hasBrace) {
                                parseExpectedJSDoc(19 /* CloseBraceToken */);
                            }
                            const result = factory2.createJSDocNameReference(entityName);
                            fixupParentReferences(result);
                            return finishNode(result, pos);
                        }
                        JSDocParser2.parseJSDocNameReference = parseJSDocNameReference;
                        function parseIsolatedJSDocComment2(content, start, length2) {
                            initializeState("", content, 99 /* Latest */, 
                            /*_syntaxCursor:*/
                            void 0, 1 /* JS */);
                            const jsDoc = doInsideOfContext(8388608 /* JSDoc */, () => parseJSDocCommentWorker(start, length2));
                            const sourceFile = { languageVariant: 0 /* Standard */, text: content };
                            const diagnostics = attachFileToDiagnostics(parseDiagnostics, sourceFile);
                            clearState();
                            return jsDoc ? { jsDoc, diagnostics } : void 0;
                        }
                        JSDocParser2.parseIsolatedJSDocComment = parseIsolatedJSDocComment2;
                        function parseJSDocComment(parent2, start, length2) {
                            const saveToken = currentToken;
                            const saveParseDiagnosticsLength = parseDiagnostics.length;
                            const saveParseErrorBeforeNextFinishedNode = parseErrorBeforeNextFinishedNode;
                            const comment = doInsideOfContext(8388608 /* JSDoc */, () => parseJSDocCommentWorker(start, length2));
                            setParent(comment, parent2);
                            if (contextFlags & 262144 /* JavaScriptFile */) {
                                if (!jsDocDiagnostics) {
                                    jsDocDiagnostics = [];
                                }
                                jsDocDiagnostics.push(...parseDiagnostics);
                            }
                            currentToken = saveToken;
                            parseDiagnostics.length = saveParseDiagnosticsLength;
                            parseErrorBeforeNextFinishedNode = saveParseErrorBeforeNextFinishedNode;
                            return comment;
                        }
                        JSDocParser2.parseJSDocComment = parseJSDocComment;
                        let JSDocState;
                        ((JSDocState2) => {
                            JSDocState2[JSDocState2["BeginningOfLine"] = 0] = "BeginningOfLine";
                            JSDocState2[JSDocState2["SawAsterisk"] = 1] = "SawAsterisk";
                            JSDocState2[JSDocState2["SavingComments"] = 2] = "SavingComments";
                            JSDocState2[JSDocState2["SavingBackticks"] = 3] = "SavingBackticks";
                        })(JSDocState || (JSDocState = {}));
                        let PropertyLikeParse;
                        ((PropertyLikeParse2) => {
                            PropertyLikeParse2[PropertyLikeParse2["Property"] = 1] = "Property";
                            PropertyLikeParse2[PropertyLikeParse2["Parameter"] = 2] = "Parameter";
                            PropertyLikeParse2[PropertyLikeParse2["CallbackParameter"] = 4] = "CallbackParameter";
                        })(PropertyLikeParse || (PropertyLikeParse = {}));
                        function parseJSDocCommentWorker(start = 0, length2) {
                            const content = sourceText;
                            const end = length2 === void 0 ? content.length : start + length2;
                            length2 = end - start;
                            Debug.assert(start >= 0);
                            Debug.assert(start <= end);
                            Debug.assert(end <= content.length);
                            if (!isJSDocLikeText(content, start)) {
                                return void 0;
                            }
                            let tags;
                            let tagsPos;
                            let tagsEnd;
                            let linkEnd;
                            let commentsPos;
                            let comments = [];
                            const parts = [];
                            return scanner2.scanRange(start + 3, length2 - 5, () => {
                                let state = 1 /* SawAsterisk */;
                                let margin;
                                let indent2 = start - (content.lastIndexOf("\n", start) + 1) + 4;
                                function pushComment(text) {
                                    if (!margin) {
                                        margin = indent2;
                                    }
                                    comments.push(text);
                                    indent2 += text.length;
                                }
                                nextTokenJSDoc();
                                while (parseOptionalJsdoc(5 /* WhitespaceTrivia */))
                                    ;
                                if (parseOptionalJsdoc(4 /* NewLineTrivia */)) {
                                    state = 0 /* BeginningOfLine */;
                                    indent2 = 0;
                                }
                                loop: while (true) {
                                    switch (token()) {
                                        case 59 /* AtToken */:
                                            if (state === 0 /* BeginningOfLine */ || state === 1 /* SawAsterisk */) {
                                                removeTrailingWhitespace(comments);
                                                if (!commentsPos)
                                                    commentsPos = getNodePos();
                                                addTag(parseTag(indent2));
                                                state = 0 /* BeginningOfLine */;
                                                margin = void 0;
                                            }
                                            else {
                                                pushComment(scanner2.getTokenText());
                                            }
                                            break;
                                        case 4 /* NewLineTrivia */:
                                            comments.push(scanner2.getTokenText());
                                            state = 0 /* BeginningOfLine */;
                                            indent2 = 0;
                                            break;
                                        case 41 /* AsteriskToken */:
                                            const asterisk = scanner2.getTokenText();
                                            if (state === 1 /* SawAsterisk */ || state === 2 /* SavingComments */) {
                                                state = 2 /* SavingComments */;
                                                pushComment(asterisk);
                                            }
                                            else {
                                                state = 1 /* SawAsterisk */;
                                                indent2 += asterisk.length;
                                            }
                                            break;
                                        case 5 /* WhitespaceTrivia */:
                                            const whitespace = scanner2.getTokenText();
                                            if (state === 2 /* SavingComments */) {
                                                comments.push(whitespace);
                                            }
                                            else if (margin !== void 0 && indent2 + whitespace.length > margin) {
                                                comments.push(whitespace.slice(margin - indent2));
                                            }
                                            indent2 += whitespace.length;
                                            break;
                                        case 1 /* EndOfFileToken */:
                                            break loop;
                                        case 18 /* OpenBraceToken */:
                                            state = 2 /* SavingComments */;
                                            const commentEnd = scanner2.getStartPos();
                                            const linkStart = scanner2.getTextPos() - 1;
                                            const link = parseJSDocLink(linkStart);
                                            if (link) {
                                                if (!linkEnd) {
                                                    removeLeadingNewlines(comments);
                                                }
                                                parts.push(finishNode(factory2.createJSDocText(comments.join("")), linkEnd != null ? linkEnd : start, commentEnd));
                                                parts.push(link);
                                                comments = [];
                                                linkEnd = scanner2.getTextPos();
                                                break;
                                            }
                                        default:
                                            state = 2 /* SavingComments */;
                                            pushComment(scanner2.getTokenText());
                                            break;
                                    }
                                    nextTokenJSDoc();
                                }
                                removeTrailingWhitespace(comments);
                                if (parts.length && comments.length) {
                                    parts.push(finishNode(factory2.createJSDocText(comments.join("")), linkEnd != null ? linkEnd : start, commentsPos));
                                }
                                if (parts.length && tags)
                                    Debug.assertIsDefined(commentsPos, "having parsed tags implies that the end of the comment span should be set");
                                const tagsArray = tags && createNodeArray(tags, tagsPos, tagsEnd);
                                return finishNode(factory2.createJSDocComment(parts.length ? createNodeArray(parts, start, commentsPos) : comments.length ? comments.join("") : void 0, tagsArray), start, end);
                            });
                            function removeLeadingNewlines(comments2) {
                                while (comments2.length && (comments2[0] === "\n" || comments2[0] === "\r")) {
                                    comments2.shift();
                                }
                            }
                            function removeTrailingWhitespace(comments2) {
                                while (comments2.length && comments2[comments2.length - 1].trim() === "") {
                                    comments2.pop();
                                }
                            }
                            function isNextNonwhitespaceTokenEndOfFile() {
                                while (true) {
                                    nextTokenJSDoc();
                                    if (token() === 1 /* EndOfFileToken */) {
                                        return true;
                                    }
                                    if (!(token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */)) {
                                        return false;
                                    }
                                }
                            }
                            function skipWhitespace() {
                                if (token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */) {
                                    if (lookAhead(isNextNonwhitespaceTokenEndOfFile)) {
                                        return;
                                    }
                                }
                                while (token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */) {
                                    nextTokenJSDoc();
                                }
                            }
                            function skipWhitespaceOrAsterisk() {
                                if (token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */) {
                                    if (lookAhead(isNextNonwhitespaceTokenEndOfFile)) {
                                        return "";
                                    }
                                }
                                let precedingLineBreak = scanner2.hasPrecedingLineBreak();
                                let seenLineBreak = false;
                                let indentText = "";
                                while (precedingLineBreak && token() === 41 /* AsteriskToken */ || token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */) {
                                    indentText += scanner2.getTokenText();
                                    if (token() === 4 /* NewLineTrivia */) {
                                        precedingLineBreak = true;
                                        seenLineBreak = true;
                                        indentText = "";
                                    }
                                    else if (token() === 41 /* AsteriskToken */) {
                                        precedingLineBreak = false;
                                    }
                                    nextTokenJSDoc();
                                }
                                return seenLineBreak ? indentText : "";
                            }
                            function parseTag(margin) {
                                Debug.assert(token() === 59 /* AtToken */);
                                const start2 = scanner2.getTokenPos();
                                nextTokenJSDoc();
                                const tagName = parseJSDocIdentifierName(
                                /*message*/
                                void 0);
                                const indentText = skipWhitespaceOrAsterisk();
                                let tag;
                                switch (tagName.escapedText) {
                                    case "author":
                                        tag = parseAuthorTag(start2, tagName, margin, indentText);
                                        break;
                                    case "implements":
                                        tag = parseImplementsTag(start2, tagName, margin, indentText);
                                        break;
                                    case "augments":
                                    case "extends":
                                        tag = parseAugmentsTag(start2, tagName, margin, indentText);
                                        break;
                                    case "class":
                                    case "constructor":
                                        tag = parseSimpleTag(start2, factory2.createJSDocClassTag, tagName, margin, indentText);
                                        break;
                                    case "public":
                                        tag = parseSimpleTag(start2, factory2.createJSDocPublicTag, tagName, margin, indentText);
                                        break;
                                    case "private":
                                        tag = parseSimpleTag(start2, factory2.createJSDocPrivateTag, tagName, margin, indentText);
                                        break;
                                    case "protected":
                                        tag = parseSimpleTag(start2, factory2.createJSDocProtectedTag, tagName, margin, indentText);
                                        break;
                                    case "readonly":
                                        tag = parseSimpleTag(start2, factory2.createJSDocReadonlyTag, tagName, margin, indentText);
                                        break;
                                    case "override":
                                        tag = parseSimpleTag(start2, factory2.createJSDocOverrideTag, tagName, margin, indentText);
                                        break;
                                    case "deprecated":
                                        hasDeprecatedTag = true;
                                        tag = parseSimpleTag(start2, factory2.createJSDocDeprecatedTag, tagName, margin, indentText);
                                        break;
                                    case "this":
                                        tag = parseThisTag(start2, tagName, margin, indentText);
                                        break;
                                    case "enum":
                                        tag = parseEnumTag(start2, tagName, margin, indentText);
                                        break;
                                    case "arg":
                                    case "argument":
                                    case "param":
                                        return parseParameterOrPropertyTag(start2, tagName, 2 /* Parameter */, margin);
                                    case "return":
                                    case "returns":
                                        tag = parseReturnTag(start2, tagName, margin, indentText);
                                        break;
                                    case "template":
                                        tag = parseTemplateTag(start2, tagName, margin, indentText);
                                        break;
                                    case "type":
                                        tag = parseTypeTag(start2, tagName, margin, indentText);
                                        break;
                                    case "typedef":
                                        tag = parseTypedefTag(start2, tagName, margin, indentText);
                                        break;
                                    case "callback":
                                        tag = parseCallbackTag(start2, tagName, margin, indentText);
                                        break;
                                    case "overload":
                                        tag = parseOverloadTag(start2, tagName, margin, indentText);
                                        break;
                                    case "satisfies":
                                        tag = parseSatisfiesTag(start2, tagName, margin, indentText);
                                        break;
                                    case "see":
                                        tag = parseSeeTag(start2, tagName, margin, indentText);
                                        break;
                                    case "exception":
                                    case "throws":
                                        tag = parseThrowsTag(start2, tagName, margin, indentText);
                                        break;
                                    default:
                                        tag = parseUnknownTag(start2, tagName, margin, indentText);
                                        break;
                                }
                                return tag;
                            }
                            function parseTrailingTagComments(pos, end2, margin, indentText) {
                                if (!indentText) {
                                    margin += end2 - pos;
                                }
                                return parseTagComments(margin, indentText.slice(margin));
                            }
                            function parseTagComments(indent2, initialMargin) {
                                const commentsPos2 = getNodePos();
                                let comments2 = [];
                                const parts2 = [];
                                let linkEnd2;
                                let state = 0 /* BeginningOfLine */;
                                let previousWhitespace = true;
                                let margin;
                                function pushComment(text) {
                                    if (!margin) {
                                        margin = indent2;
                                    }
                                    comments2.push(text);
                                    indent2 += text.length;
                                }
                                if (initialMargin !== void 0) {
                                    if (initialMargin !== "") {
                                        pushComment(initialMargin);
                                    }
                                    state = 1 /* SawAsterisk */;
                                }
                                let tok = token();
                                loop: while (true) {
                                    switch (tok) {
                                        case 4 /* NewLineTrivia */:
                                            state = 0 /* BeginningOfLine */;
                                            comments2.push(scanner2.getTokenText());
                                            indent2 = 0;
                                            break;
                                        case 59 /* AtToken */:
                                            if (state === 3 /* SavingBackticks */ || state === 2 /* SavingComments */ && (!previousWhitespace || lookAhead(isNextJSDocTokenWhitespace))) {
                                                comments2.push(scanner2.getTokenText());
                                                break;
                                            }
                                            scanner2.setTextPos(scanner2.getTextPos() - 1);
                                        case 1 /* EndOfFileToken */:
                                            break loop;
                                        case 5 /* WhitespaceTrivia */:
                                            if (state === 2 /* SavingComments */ || state === 3 /* SavingBackticks */) {
                                                pushComment(scanner2.getTokenText());
                                            }
                                            else {
                                                const whitespace = scanner2.getTokenText();
                                                if (margin !== void 0 && indent2 + whitespace.length > margin) {
                                                    comments2.push(whitespace.slice(margin - indent2));
                                                }
                                                indent2 += whitespace.length;
                                            }
                                            break;
                                        case 18 /* OpenBraceToken */:
                                            state = 2 /* SavingComments */;
                                            const commentEnd = scanner2.getStartPos();
                                            const linkStart = scanner2.getTextPos() - 1;
                                            const link = parseJSDocLink(linkStart);
                                            if (link) {
                                                parts2.push(finishNode(factory2.createJSDocText(comments2.join("")), linkEnd2 != null ? linkEnd2 : commentsPos2, commentEnd));
                                                parts2.push(link);
                                                comments2 = [];
                                                linkEnd2 = scanner2.getTextPos();
                                            }
                                            else {
                                                pushComment(scanner2.getTokenText());
                                            }
                                            break;
                                        case 61 /* BacktickToken */:
                                            if (state === 3 /* SavingBackticks */) {
                                                state = 2 /* SavingComments */;
                                            }
                                            else {
                                                state = 3 /* SavingBackticks */;
                                            }
                                            pushComment(scanner2.getTokenText());
                                            break;
                                        case 41 /* AsteriskToken */:
                                            if (state === 0 /* BeginningOfLine */) {
                                                state = 1 /* SawAsterisk */;
                                                indent2 += 1;
                                                break;
                                            }
                                        default:
                                            if (state !== 3 /* SavingBackticks */) {
                                                state = 2 /* SavingComments */;
                                            }
                                            pushComment(scanner2.getTokenText());
                                            break;
                                    }
                                    previousWhitespace = token() === 5 /* WhitespaceTrivia */;
                                    tok = nextTokenJSDoc();
                                }
                                removeLeadingNewlines(comments2);
                                removeTrailingWhitespace(comments2);
                                if (parts2.length) {
                                    if (comments2.length) {
                                        parts2.push(finishNode(factory2.createJSDocText(comments2.join("")), linkEnd2 != null ? linkEnd2 : commentsPos2));
                                    }
                                    return createNodeArray(parts2, commentsPos2, scanner2.getTextPos());
                                }
                                else if (comments2.length) {
                                    return comments2.join("");
                                }
                            }
                            function isNextJSDocTokenWhitespace() {
                                const next = nextTokenJSDoc();
                                return next === 5 /* WhitespaceTrivia */ || next === 4 /* NewLineTrivia */;
                            }
                            function parseJSDocLink(start2) {
                                const linkType = tryParse(parseJSDocLinkPrefix);
                                if (!linkType) {
                                    return void 0;
                                }
                                nextTokenJSDoc();
                                skipWhitespace();
                                const p2 = getNodePos();
                                let name = tokenIsIdentifierOrKeyword(token()) ? parseEntityName(
                                /*allowReservedWords*/
                                true) : void 0;
                                if (name) {
                                    while (token() === 80 /* PrivateIdentifier */) {
                                        reScanHashToken();
                                        nextTokenJSDoc();
                                        name = finishNode(factory2.createJSDocMemberName(name, parseIdentifier()), p2);
                                    }
                                }
                                const text = [];
                                while (token() !== 19 /* CloseBraceToken */ && token() !== 4 /* NewLineTrivia */ && token() !== 1 /* EndOfFileToken */) {
                                    text.push(scanner2.getTokenText());
                                    nextTokenJSDoc();
                                }
                                const create = linkType === "link" ? factory2.createJSDocLink : linkType === "linkcode" ? factory2.createJSDocLinkCode : factory2.createJSDocLinkPlain;
                                return finishNode(create(name, text.join("")), start2, scanner2.getTextPos());
                            }
                            function parseJSDocLinkPrefix() {
                                skipWhitespaceOrAsterisk();
                                if (token() === 18 /* OpenBraceToken */ && nextTokenJSDoc() === 59 /* AtToken */ && tokenIsIdentifierOrKeyword(nextTokenJSDoc())) {
                                    const kind = scanner2.getTokenValue();
                                    if (isJSDocLinkTag(kind))
                                        return kind;
                                }
                            }
                            function isJSDocLinkTag(kind) {
                                return kind === "link" || kind === "linkcode" || kind === "linkplain";
                            }
                            function parseUnknownTag(start2, tagName, indent2, indentText) {
                                return finishNode(factory2.createJSDocUnknownTag(tagName, parseTrailingTagComments(start2, getNodePos(), indent2, indentText)), start2);
                            }
                            function addTag(tag) {
                                if (!tag) {
                                    return;
                                }
                                if (!tags) {
                                    tags = [tag];
                                    tagsPos = tag.pos;
                                }
                                else {
                                    tags.push(tag);
                                }
                                tagsEnd = tag.end;
                            }
                            function tryParseTypeExpression() {
                                skipWhitespaceOrAsterisk();
                                return token() === 18 /* OpenBraceToken */ ? parseJSDocTypeExpression() : void 0;
                            }
                            function parseBracketNameInPropertyAndParamTag() {
                                const isBracketed = parseOptionalJsdoc(22 /* OpenBracketToken */);
                                if (isBracketed) {
                                    skipWhitespace();
                                }
                                const isBackquoted = parseOptionalJsdoc(61 /* BacktickToken */);
                                const name = parseJSDocEntityName();
                                if (isBackquoted) {
                                    parseExpectedTokenJSDoc(61 /* BacktickToken */);
                                }
                                if (isBracketed) {
                                    skipWhitespace();
                                    if (parseOptionalToken(63 /* EqualsToken */)) {
                                        parseExpression();
                                    }
                                    parseExpected(23 /* CloseBracketToken */);
                                }
                                return { name, isBracketed };
                            }
                            function isObjectOrObjectArrayTypeReference(node) {
                                switch (node.kind) {
                                    case 149 /* ObjectKeyword */:
                                        return true;
                                    case 185 /* ArrayType */:
                                        return isObjectOrObjectArrayTypeReference(node.elementType);
                                    default:
                                        return isTypeReferenceNode(node) && isIdentifier(node.typeName) && node.typeName.escapedText === "Object" && !node.typeArguments;
                                }
                            }
                            function parseParameterOrPropertyTag(start2, tagName, target, indent2) {
                                let typeExpression = tryParseTypeExpression();
                                let isNameFirst = !typeExpression;
                                skipWhitespaceOrAsterisk();
                                const { name, isBracketed } = parseBracketNameInPropertyAndParamTag();
                                const indentText = skipWhitespaceOrAsterisk();
                                if (isNameFirst && !lookAhead(parseJSDocLinkPrefix)) {
                                    typeExpression = tryParseTypeExpression();
                                }
                                const comment = parseTrailingTagComments(start2, getNodePos(), indent2, indentText);
                                const nestedTypeLiteral = target !== 4 /* CallbackParameter */ && parseNestedTypeLiteral(typeExpression, name, target, indent2);
                                if (nestedTypeLiteral) {
                                    typeExpression = nestedTypeLiteral;
                                    isNameFirst = true;
                                }
                                const result = target === 1 /* Property */ ? factory2.createJSDocPropertyTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment) : factory2.createJSDocParameterTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment);
                                return finishNode(result, start2);
                            }
                            function parseNestedTypeLiteral(typeExpression, name, target, indent2) {
                                if (typeExpression && isObjectOrObjectArrayTypeReference(typeExpression.type)) {
                                    const pos = getNodePos();
                                    let child;
                                    let children;
                                    while (child = tryParse(() => parseChildParameterOrPropertyTag(target, indent2, name))) {
                                        if (child.kind === 344 /* JSDocParameterTag */ || child.kind === 351 /* JSDocPropertyTag */) {
                                            children = append(children, child);
                                        }
                                    }
                                    if (children) {
                                        const literal = finishNode(factory2.createJSDocTypeLiteral(children, typeExpression.type.kind === 185 /* ArrayType */), pos);
                                        return finishNode(factory2.createJSDocTypeExpression(literal), pos);
                                    }
                                }
                            }
                            function parseReturnTag(start2, tagName, indent2, indentText) {
                                if (some(tags, isJSDocReturnTag)) {
                                    parseErrorAt(tagName.pos, scanner2.getTokenPos(), Diagnostics._0_tag_already_specified, tagName.escapedText);
                                }
                                const typeExpression = tryParseTypeExpression();
                                return finishNode(factory2.createJSDocReturnTag(tagName, typeExpression, parseTrailingTagComments(start2, getNodePos(), indent2, indentText)), start2);
                            }
                            function parseTypeTag(start2, tagName, indent2, indentText) {
                                if (some(tags, isJSDocTypeTag)) {
                                    parseErrorAt(tagName.pos, scanner2.getTokenPos(), Diagnostics._0_tag_already_specified, tagName.escapedText);
                                }
                                const typeExpression = parseJSDocTypeExpression(
                                /*mayOmitBraces*/
                                true);
                                const comments2 = indent2 !== void 0 && indentText !== void 0 ? parseTrailingTagComments(start2, getNodePos(), indent2, indentText) : void 0;
                                return finishNode(factory2.createJSDocTypeTag(tagName, typeExpression, comments2), start2);
                            }
                            function parseSeeTag(start2, tagName, indent2, indentText) {
                                const isMarkdownOrJSDocLink = token() === 22 /* OpenBracketToken */ || lookAhead(() => nextTokenJSDoc() === 59 /* AtToken */ && tokenIsIdentifierOrKeyword(nextTokenJSDoc()) && isJSDocLinkTag(scanner2.getTokenValue()));
                                const nameExpression = isMarkdownOrJSDocLink ? void 0 : parseJSDocNameReference();
                                const comments2 = indent2 !== void 0 && indentText !== void 0 ? parseTrailingTagComments(start2, getNodePos(), indent2, indentText) : void 0;
                                return finishNode(factory2.createJSDocSeeTag(tagName, nameExpression, comments2), start2);
                            }
                            function parseThrowsTag(start2, tagName, indent2, indentText) {
                                const typeExpression = tryParseTypeExpression();
                                const comment = parseTrailingTagComments(start2, getNodePos(), indent2, indentText);
                                return finishNode(factory2.createJSDocThrowsTag(tagName, typeExpression, comment), start2);
                            }
                            function parseAuthorTag(start2, tagName, indent2, indentText) {
                                const commentStart = getNodePos();
                                const textOnly = parseAuthorNameAndEmail();
                                let commentEnd = scanner2.getStartPos();
                                const comments2 = parseTrailingTagComments(start2, commentEnd, indent2, indentText);
                                if (!comments2) {
                                    commentEnd = scanner2.getStartPos();
                                }
                                const allParts = typeof comments2 !== "string" ? createNodeArray(concatenate([finishNode(textOnly, commentStart, commentEnd)], comments2), commentStart) : textOnly.text + comments2;
                                return finishNode(factory2.createJSDocAuthorTag(tagName, allParts), start2);
                            }
                            function parseAuthorNameAndEmail() {
                                const comments2 = [];
                                let inEmail = false;
                                let token2 = scanner2.getToken();
                                while (token2 !== 1 /* EndOfFileToken */ && token2 !== 4 /* NewLineTrivia */) {
                                    if (token2 === 29 /* LessThanToken */) {
                                        inEmail = true;
                                    }
                                    else if (token2 === 59 /* AtToken */ && !inEmail) {
                                        break;
                                    }
                                    else if (token2 === 31 /* GreaterThanToken */ && inEmail) {
                                        comments2.push(scanner2.getTokenText());
                                        scanner2.setTextPos(scanner2.getTokenPos() + 1);
                                        break;
                                    }
                                    comments2.push(scanner2.getTokenText());
                                    token2 = nextTokenJSDoc();
                                }
                                return factory2.createJSDocText(comments2.join(""));
                            }
                            function parseImplementsTag(start2, tagName, margin, indentText) {
                                const className = parseExpressionWithTypeArgumentsForAugments();
                                return finishNode(factory2.createJSDocImplementsTag(tagName, className, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseAugmentsTag(start2, tagName, margin, indentText) {
                                const className = parseExpressionWithTypeArgumentsForAugments();
                                return finishNode(factory2.createJSDocAugmentsTag(tagName, className, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseSatisfiesTag(start2, tagName, margin, indentText) {
                                const typeExpression = parseJSDocTypeExpression(
                                /*mayOmitBraces*/
                                false);
                                const comments2 = margin !== void 0 && indentText !== void 0 ? parseTrailingTagComments(start2, getNodePos(), margin, indentText) : void 0;
                                return finishNode(factory2.createJSDocSatisfiesTag(tagName, typeExpression, comments2), start2);
                            }
                            function parseExpressionWithTypeArgumentsForAugments() {
                                const usedBrace = parseOptional(18 /* OpenBraceToken */);
                                const pos = getNodePos();
                                const expression = parsePropertyAccessEntityNameExpression();
                                const typeArguments = tryParseTypeArguments();
                                const node = factory2.createExpressionWithTypeArguments(expression, typeArguments);
                                const res = finishNode(node, pos);
                                if (usedBrace) {
                                    parseExpected(19 /* CloseBraceToken */);
                                }
                                return res;
                            }
                            function parsePropertyAccessEntityNameExpression() {
                                const pos = getNodePos();
                                let node = parseJSDocIdentifierName();
                                while (parseOptional(24 /* DotToken */)) {
                                    const name = parseJSDocIdentifierName();
                                    node = finishNode(factoryCreatePropertyAccessExpression(node, name), pos);
                                }
                                return node;
                            }
                            function parseSimpleTag(start2, createTag, tagName, margin, indentText) {
                                return finishNode(createTag(tagName, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseThisTag(start2, tagName, margin, indentText) {
                                const typeExpression = parseJSDocTypeExpression(
                                /*mayOmitBraces*/
                                true);
                                skipWhitespace();
                                return finishNode(factory2.createJSDocThisTag(tagName, typeExpression, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseEnumTag(start2, tagName, margin, indentText) {
                                const typeExpression = parseJSDocTypeExpression(
                                /*mayOmitBraces*/
                                true);
                                skipWhitespace();
                                return finishNode(factory2.createJSDocEnumTag(tagName, typeExpression, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseTypedefTag(start2, tagName, indent2, indentText) {
                                var _a2;
                                let typeExpression = tryParseTypeExpression();
                                skipWhitespaceOrAsterisk();
                                const fullName = parseJSDocTypeNameWithNamespace();
                                skipWhitespace();
                                let comment = parseTagComments(indent2);
                                let end2;
                                if (!typeExpression || isObjectOrObjectArrayTypeReference(typeExpression.type)) {
                                    let child;
                                    let childTypeTag;
                                    let jsDocPropertyTags;
                                    let hasChildren = false;
                                    while (child = tryParse(() => parseChildPropertyTag(indent2))) {
                                        hasChildren = true;
                                        if (child.kind === 347 /* JSDocTypeTag */) {
                                            if (childTypeTag) {
                                                const lastError = parseErrorAtCurrentToken(Diagnostics.A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags);
                                                if (lastError) {
                                                    addRelatedInfo(lastError, createDetachedDiagnostic(fileName, 0, 0, Diagnostics.The_tag_was_first_specified_here));
                                                }
                                                break;
                                            }
                                            else {
                                                childTypeTag = child;
                                            }
                                        }
                                        else {
                                            jsDocPropertyTags = append(jsDocPropertyTags, child);
                                        }
                                    }
                                    if (hasChildren) {
                                        const isArrayType = typeExpression && typeExpression.type.kind === 185 /* ArrayType */;
                                        const jsdocTypeLiteral = factory2.createJSDocTypeLiteral(jsDocPropertyTags, isArrayType);
                                        typeExpression = childTypeTag && childTypeTag.typeExpression && !isObjectOrObjectArrayTypeReference(childTypeTag.typeExpression.type) ? childTypeTag.typeExpression : finishNode(jsdocTypeLiteral, start2);
                                        end2 = typeExpression.end;
                                    }
                                }
                                end2 = end2 || comment !== void 0 ? getNodePos() : ((_a2 = fullName != null ? fullName : typeExpression) != null ? _a2 : tagName).end;
                                if (!comment) {
                                    comment = parseTrailingTagComments(start2, end2, indent2, indentText);
                                }
                                const typedefTag = factory2.createJSDocTypedefTag(tagName, typeExpression, fullName, comment);
                                return finishNode(typedefTag, start2, end2);
                            }
                            function parseJSDocTypeNameWithNamespace(nested) {
                                const pos = scanner2.getTokenPos();
                                if (!tokenIsIdentifierOrKeyword(token())) {
                                    return void 0;
                                }
                                const typeNameOrNamespaceName = parseJSDocIdentifierName();
                                if (parseOptional(24 /* DotToken */)) {
                                    const body = parseJSDocTypeNameWithNamespace(
                                    /*nested*/
                                    true);
                                    const jsDocNamespaceNode = factory2.createModuleDeclaration(
                                    /*modifiers*/
                                    void 0, typeNameOrNamespaceName, body, nested ? 4 /* NestedNamespace */ : void 0);
                                    return finishNode(jsDocNamespaceNode, pos);
                                }
                                if (nested) {
                                    typeNameOrNamespaceName.flags |= 2048 /* IdentifierIsInJSDocNamespace */;
                                }
                                return typeNameOrNamespaceName;
                            }
                            function parseCallbackTagParameters(indent2) {
                                const pos = getNodePos();
                                let child;
                                let parameters;
                                while (child = tryParse(() => parseChildParameterOrPropertyTag(4 /* CallbackParameter */, indent2))) {
                                    parameters = append(parameters, child);
                                }
                                return createNodeArray(parameters || [], pos);
                            }
                            function parseJSDocSignature(start2, indent2) {
                                const parameters = parseCallbackTagParameters(indent2);
                                const returnTag = tryParse(() => {
                                    if (parseOptionalJsdoc(59 /* AtToken */)) {
                                        const tag = parseTag(indent2);
                                        if (tag && tag.kind === 345 /* JSDocReturnTag */) {
                                            return tag;
                                        }
                                    }
                                });
                                return finishNode(factory2.createJSDocSignature(
                                /*typeParameters*/
                                void 0, parameters, returnTag), start2);
                            }
                            function parseCallbackTag(start2, tagName, indent2, indentText) {
                                const fullName = parseJSDocTypeNameWithNamespace();
                                skipWhitespace();
                                let comment = parseTagComments(indent2);
                                const typeExpression = parseJSDocSignature(start2, indent2);
                                if (!comment) {
                                    comment = parseTrailingTagComments(start2, getNodePos(), indent2, indentText);
                                }
                                const end2 = comment !== void 0 ? getNodePos() : typeExpression.end;
                                return finishNode(factory2.createJSDocCallbackTag(tagName, typeExpression, fullName, comment), start2, end2);
                            }
                            function parseOverloadTag(start2, tagName, indent2, indentText) {
                                skipWhitespace();
                                let comment = parseTagComments(indent2);
                                const typeExpression = parseJSDocSignature(start2, indent2);
                                if (!comment) {
                                    comment = parseTrailingTagComments(start2, getNodePos(), indent2, indentText);
                                }
                                const end2 = comment !== void 0 ? getNodePos() : typeExpression.end;
                                return finishNode(factory2.createJSDocOverloadTag(tagName, typeExpression, comment), start2, end2);
                            }
                            function escapedTextsEqual(a, b) {
                                while (!isIdentifier(a) || !isIdentifier(b)) {
                                    if (!isIdentifier(a) && !isIdentifier(b) && a.right.escapedText === b.right.escapedText) {
                                        a = a.left;
                                        b = b.left;
                                    }
                                    else {
                                        return false;
                                    }
                                }
                                return a.escapedText === b.escapedText;
                            }
                            function parseChildPropertyTag(indent2) {
                                return parseChildParameterOrPropertyTag(1 /* Property */, indent2);
                            }
                            function parseChildParameterOrPropertyTag(target, indent2, name) {
                                let canParseTag = true;
                                let seenAsterisk = false;
                                while (true) {
                                    switch (nextTokenJSDoc()) {
                                        case 59 /* AtToken */:
                                            if (canParseTag) {
                                                const child = tryParseChildTag(target, indent2);
                                                if (child && (child.kind === 344 /* JSDocParameterTag */ || child.kind === 351 /* JSDocPropertyTag */) && target !== 4 /* CallbackParameter */ && name && (isIdentifier(child.name) || !escapedTextsEqual(name, child.name.left))) {
                                                    return false;
                                                }
                                                return child;
                                            }
                                            seenAsterisk = false;
                                            break;
                                        case 4 /* NewLineTrivia */:
                                            canParseTag = true;
                                            seenAsterisk = false;
                                            break;
                                        case 41 /* AsteriskToken */:
                                            if (seenAsterisk) {
                                                canParseTag = false;
                                            }
                                            seenAsterisk = true;
                                            break;
                                        case 79 /* Identifier */:
                                            canParseTag = false;
                                            break;
                                        case 1 /* EndOfFileToken */:
                                            return false;
                                    }
                                }
                            }
                            function tryParseChildTag(target, indent2) {
                                Debug.assert(token() === 59 /* AtToken */);
                                const start2 = scanner2.getStartPos();
                                nextTokenJSDoc();
                                const tagName = parseJSDocIdentifierName();
                                skipWhitespace();
                                let t;
                                switch (tagName.escapedText) {
                                    case "type":
                                        return target === 1 /* Property */ && parseTypeTag(start2, tagName);
                                    case "prop":
                                    case "property":
                                        t = 1 /* Property */;
                                        break;
                                    case "arg":
                                    case "argument":
                                    case "param":
                                        t = 2 /* Parameter */ | 4 /* CallbackParameter */;
                                        break;
                                    default:
                                        return false;
                                }
                                if (!(target & t)) {
                                    return false;
                                }
                                return parseParameterOrPropertyTag(start2, tagName, target, indent2);
                            }
                            function parseTemplateTagTypeParameter() {
                                const typeParameterPos = getNodePos();
                                const isBracketed = parseOptionalJsdoc(22 /* OpenBracketToken */);
                                if (isBracketed) {
                                    skipWhitespace();
                                }
                                const name = parseJSDocIdentifierName(Diagnostics.Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces);
                                let defaultType;
                                if (isBracketed) {
                                    skipWhitespace();
                                    parseExpected(63 /* EqualsToken */);
                                    defaultType = doInsideOfContext(8388608 /* JSDoc */, parseJSDocType);
                                    parseExpected(23 /* CloseBracketToken */);
                                }
                                if (nodeIsMissing(name)) {
                                    return void 0;
                                }
                                return finishNode(factory2.createTypeParameterDeclaration(
                                /*modifiers*/
                                void 0, name, 
                                /*constraint*/
                                void 0, defaultType), typeParameterPos);
                            }
                            function parseTemplateTagTypeParameters() {
                                const pos = getNodePos();
                                const typeParameters = [];
                                do {
                                    skipWhitespace();
                                    const node = parseTemplateTagTypeParameter();
                                    if (node !== void 0) {
                                        typeParameters.push(node);
                                    }
                                    skipWhitespaceOrAsterisk();
                                } while (parseOptionalJsdoc(27 /* CommaToken */));
                                return createNodeArray(typeParameters, pos);
                            }
                            function parseTemplateTag(start2, tagName, indent2, indentText) {
                                const constraint = token() === 18 /* OpenBraceToken */ ? parseJSDocTypeExpression() : void 0;
                                const typeParameters = parseTemplateTagTypeParameters();
                                return finishNode(factory2.createJSDocTemplateTag(tagName, constraint, typeParameters, parseTrailingTagComments(start2, getNodePos(), indent2, indentText)), start2);
                            }
                            function parseOptionalJsdoc(t) {
                                if (token() === t) {
                                    nextTokenJSDoc();
                                    return true;
                                }
                                return false;
                            }
                            function parseJSDocEntityName() {
                                let entity = parseJSDocIdentifierName();
                                if (parseOptional(22 /* OpenBracketToken */)) {
                                    parseExpected(23 /* CloseBracketToken */);
                                }
                                while (parseOptional(24 /* DotToken */)) {
                                    const name = parseJSDocIdentifierName();
                                    if (parseOptional(22 /* OpenBracketToken */)) {
                                        parseExpected(23 /* CloseBracketToken */);
                                    }
                                    entity = createQualifiedName(entity, name);
                                }
                                return entity;
                            }
                            function parseJSDocIdentifierName(message) {
                                if (!tokenIsIdentifierOrKeyword(token())) {
                                    return createMissingNode(79 /* Identifier */, 
                                    /*reportAtCurrentPosition*/
                                    !message, message || Diagnostics.Identifier_expected);
                                }
                                identifierCount++;
                                const pos = scanner2.getTokenPos();
                                const end2 = scanner2.getTextPos();
                                const originalKeywordKind = token();
                                const text = internIdentifier(scanner2.getTokenValue());
                                const result = finishNode(factoryCreateIdentifier(text, originalKeywordKind), pos, end2);
                                nextTokenJSDoc();
                                return result;
                            }
                        }
                    })(JSDocParser = Parser2.JSDocParser || (Parser2.JSDocParser = {}));
                })(Parser || (Parser = {}));
                ((IncrementalParser2) => {
                    function updateSourceFile2(sourceFile, newText, textChangeRange, aggressiveChecks) {
                        aggressiveChecks = aggressiveChecks || Debug.shouldAssert(2 /* Aggressive */);
                        checkChangeRange(sourceFile, newText, textChangeRange, aggressiveChecks);
                        if (textChangeRangeIsUnchanged(textChangeRange)) {
                            return sourceFile;
                        }
                        if (sourceFile.statements.length === 0) {
                            return Parser.parseSourceFile(sourceFile.fileName, newText, sourceFile.languageVersion, 
                            /*syntaxCursor*/
                            void 0, 
                            /*setParentNodes*/
                            true, sourceFile.scriptKind, sourceFile.setExternalModuleIndicator);
                        }
                        const incrementalSourceFile = sourceFile;
                        Debug.assert(!incrementalSourceFile.hasBeenIncrementallyParsed);
                        incrementalSourceFile.hasBeenIncrementallyParsed = true;
                        Parser.fixupParentReferences(incrementalSourceFile);
                        const oldText = sourceFile.text;
                        const syntaxCursor = createSyntaxCursor(sourceFile);
                        const changeRange = extendToAffectedRange(sourceFile, textChangeRange);
                        checkChangeRange(sourceFile, newText, changeRange, aggressiveChecks);
                        Debug.assert(changeRange.span.start <= textChangeRange.span.start);
                        Debug.assert(textSpanEnd(changeRange.span) === textSpanEnd(textChangeRange.span));
                        Debug.assert(textSpanEnd(textChangeRangeNewSpan(changeRange)) === textSpanEnd(textChangeRangeNewSpan(textChangeRange)));
                        const delta = textChangeRangeNewSpan(changeRange).length - changeRange.span.length;
                        updateTokenPositionsAndMarkElements(incrementalSourceFile, changeRange.span.start, textSpanEnd(changeRange.span), textSpanEnd(textChangeRangeNewSpan(changeRange)), delta, oldText, newText, aggressiveChecks);
                        const result = Parser.parseSourceFile(sourceFile.fileName, newText, sourceFile.languageVersion, syntaxCursor, 
                        /*setParentNodes*/
                        true, sourceFile.scriptKind, sourceFile.setExternalModuleIndicator);
                        result.commentDirectives = getNewCommentDirectives(sourceFile.commentDirectives, result.commentDirectives, changeRange.span.start, textSpanEnd(changeRange.span), delta, oldText, newText, aggressiveChecks);
                        result.impliedNodeFormat = sourceFile.impliedNodeFormat;
                        return result;
                    }
                    IncrementalParser2.updateSourceFile = updateSourceFile2;
                    function getNewCommentDirectives(oldDirectives, newDirectives, changeStart, changeRangeOldEnd, delta, oldText, newText, aggressiveChecks) {
                        if (!oldDirectives)
                            return newDirectives;
                        let commentDirectives;
                        let addedNewlyScannedDirectives = false;
                        for (const directive of oldDirectives) {
                            const { range, type } = directive;
                            if (range.end < changeStart) {
                                commentDirectives = append(commentDirectives, directive);
                            }
                            else if (range.pos > changeRangeOldEnd) {
                                addNewlyScannedDirectives();
                                const updatedDirective = {
                                    range: { pos: range.pos + delta, end: range.end + delta },
                                    type
                                };
                                commentDirectives = append(commentDirectives, updatedDirective);
                                if (aggressiveChecks) {
                                    Debug.assert(oldText.substring(range.pos, range.end) === newText.substring(updatedDirective.range.pos, updatedDirective.range.end));
                                }
                            }
                        }
                        addNewlyScannedDirectives();
                        return commentDirectives;
                        function addNewlyScannedDirectives() {
                            if (addedNewlyScannedDirectives)
                                return;
                            addedNewlyScannedDirectives = true;
                            if (!commentDirectives) {
                                commentDirectives = newDirectives;
                            }
                            else if (newDirectives) {
                                commentDirectives.push(...newDirectives);
                            }
                        }
                    }
                    function moveElementEntirelyPastChangeRange(element, isArray2, delta, oldText, newText, aggressiveChecks) {
                        if (isArray2) {
                            visitArray2(element);
                        }
                        else {
                            visitNode3(element);
                        }
                        return;
                        function visitNode3(node) {
                            let text = "";
                            if (aggressiveChecks && shouldCheckNode(node)) {
                                text = oldText.substring(node.pos, node.end);
                            }
                            if (node._children) {
                                node._children = void 0;
                            }
                            setTextRangePosEnd(node, node.pos + delta, node.end + delta);
                            if (aggressiveChecks && shouldCheckNode(node)) {
                                Debug.assert(text === newText.substring(node.pos, node.end));
                            }
                            forEachChild(node, visitNode3, visitArray2);
                            if (hasJSDocNodes(node)) {
                                for (const jsDocComment of node.jsDoc) {
                                    visitNode3(jsDocComment);
                                }
                            }
                            checkNodePositions(node, aggressiveChecks);
                        }
                        function visitArray2(array) {
                            array._children = void 0;
                            setTextRangePosEnd(array, array.pos + delta, array.end + delta);
                            for (const node of array) {
                                visitNode3(node);
                            }
                        }
                    }
                    function shouldCheckNode(node) {
                        switch (node.kind) {
                            case 10 /* StringLiteral */:
                            case 8 /* NumericLiteral */:
                            case 79 /* Identifier */:
                                return true;
                        }
                        return false;
                    }
                    function adjustIntersectingElement(element, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta) {
                        Debug.assert(element.end >= changeStart, "Adjusting an element that was entirely before the change range");
                        Debug.assert(element.pos <= changeRangeOldEnd, "Adjusting an element that was entirely after the change range");
                        Debug.assert(element.pos <= element.end);
                        const pos = Math.min(element.pos, changeRangeNewEnd);
                        const end = element.end >= changeRangeOldEnd ? (
                        // Element ends after the change range.  Always adjust the end pos.
                        element.end + delta) : (
                        // Element ends in the change range.  The element will keep its position if
                        // possible. Or Move backward to the new-end if it's in the 'Y' range.
                        Math.min(element.end, changeRangeNewEnd));
                        Debug.assert(pos <= end);
                        if (element.parent) {
                            Debug.assertGreaterThanOrEqual(pos, element.parent.pos);
                            Debug.assertLessThanOrEqual(end, element.parent.end);
                        }
                        setTextRangePosEnd(element, pos, end);
                    }
                    function checkNodePositions(node, aggressiveChecks) {
                        if (aggressiveChecks) {
                            let pos = node.pos;
                            const visitNode3 = (child) => {
                                Debug.assert(child.pos >= pos);
                                pos = child.end;
                            };
                            if (hasJSDocNodes(node)) {
                                for (const jsDocComment of node.jsDoc) {
                                    visitNode3(jsDocComment);
                                }
                            }
                            forEachChild(node, visitNode3);
                            Debug.assert(pos <= node.end);
                        }
                    }
                    function updateTokenPositionsAndMarkElements(sourceFile, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta, oldText, newText, aggressiveChecks) {
                        visitNode3(sourceFile);
                        return;
                        function visitNode3(child) {
                            Debug.assert(child.pos <= child.end);
                            if (child.pos > changeRangeOldEnd) {
                                moveElementEntirelyPastChangeRange(child, 
                                /*isArray*/
                                false, delta, oldText, newText, aggressiveChecks);
                                return;
                            }
                            const fullEnd = child.end;
                            if (fullEnd >= changeStart) {
                                child.intersectsChange = true;
                                child._children = void 0;
                                adjustIntersectingElement(child, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta);
                                forEachChild(child, visitNode3, visitArray2);
                                if (hasJSDocNodes(child)) {
                                    for (const jsDocComment of child.jsDoc) {
                                        visitNode3(jsDocComment);
                                    }
                                }
                                checkNodePositions(child, aggressiveChecks);
                                return;
                            }
                            Debug.assert(fullEnd < changeStart);
                        }
                        function visitArray2(array) {
                            Debug.assert(array.pos <= array.end);
                            if (array.pos > changeRangeOldEnd) {
                                moveElementEntirelyPastChangeRange(array, 
                                /*isArray*/
                                true, delta, oldText, newText, aggressiveChecks);
                                return;
                            }
                            const fullEnd = array.end;
                            if (fullEnd >= changeStart) {
                                array.intersectsChange = true;
                                array._children = void 0;
                                adjustIntersectingElement(array, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta);
                                for (const node of array) {
                                    visitNode3(node);
                                }
                                return;
                            }
                            Debug.assert(fullEnd < changeStart);
                        }
                    }
                    function extendToAffectedRange(sourceFile, changeRange) {
                        const maxLookahead = 1;
                        let start = changeRange.span.start;
                        for (let i = 0; start > 0 && i <= maxLookahead; i++) {
                            const nearestNode = findNearestNodeStartingBeforeOrAtPosition(sourceFile, start);
                            Debug.assert(nearestNode.pos <= start);
                            const position = nearestNode.pos;
                            start = Math.max(0, position - 1);
                        }
                        const finalSpan = createTextSpanFromBounds(start, textSpanEnd(changeRange.span));
                        const finalLength = changeRange.newLength + (changeRange.span.start - start);
                        return createTextChangeRange(finalSpan, finalLength);
                    }
                    function findNearestNodeStartingBeforeOrAtPosition(sourceFile, position) {
                        let bestResult = sourceFile;
                        let lastNodeEntirelyBeforePosition;
                        forEachChild(sourceFile, visit);
                        if (lastNodeEntirelyBeforePosition) {
                            const lastChildOfLastEntireNodeBeforePosition = getLastDescendant(lastNodeEntirelyBeforePosition);
                            if (lastChildOfLastEntireNodeBeforePosition.pos > bestResult.pos) {
                                bestResult = lastChildOfLastEntireNodeBeforePosition;
                            }
                        }
                        return bestResult;
                        function getLastDescendant(node) {
                            while (true) {
                                const lastChild = getLastChild(node);
                                if (lastChild) {
                                    node = lastChild;
                                }
                                else {
                                    return node;
                                }
                            }
                        }
                        function visit(child) {
                            if (nodeIsMissing(child)) {
                                return;
                            }
                            if (child.pos <= position) {
                                if (child.pos >= bestResult.pos) {
                                    bestResult = child;
                                }
                                if (position < child.end) {
                                    forEachChild(child, visit);
                                    return true;
                                }
                                else {
                                    Debug.assert(child.end <= position);
                                    lastNodeEntirelyBeforePosition = child;
                                }
                            }
                            else {
                                Debug.assert(child.pos > position);
                                return true;
                            }
                        }
                    }
                    function checkChangeRange(sourceFile, newText, textChangeRange, aggressiveChecks) {
                        const oldText = sourceFile.text;
                        if (textChangeRange) {
                            Debug.assert(oldText.length - textChangeRange.span.length + textChangeRange.newLength === newText.length);
                            if (aggressiveChecks || Debug.shouldAssert(3 /* VeryAggressive */)) {
                                const oldTextPrefix = oldText.substr(0, textChangeRange.span.start);
                                const newTextPrefix = newText.substr(0, textChangeRange.span.start);
                                Debug.assert(oldTextPrefix === newTextPrefix);
                                const oldTextSuffix = oldText.substring(textSpanEnd(textChangeRange.span), oldText.length);
                                const newTextSuffix = newText.substring(textSpanEnd(textChangeRangeNewSpan(textChangeRange)), newText.length);
                                Debug.assert(oldTextSuffix === newTextSuffix);
                            }
                        }
                    }
                    function createSyntaxCursor(sourceFile) {
                        let currentArray = sourceFile.statements;
                        let currentArrayIndex = 0;
                        Debug.assert(currentArrayIndex < currentArray.length);
                        let current = currentArray[currentArrayIndex];
                        let lastQueriedPosition = -1 /* Value */;
                        return {
                            currentNode(position) {
                                if (position !== lastQueriedPosition) {
                                    if (current && current.end === position && currentArrayIndex < currentArray.length - 1) {
                                        currentArrayIndex++;
                                        current = currentArray[currentArrayIndex];
                                    }
                                    if (!current || current.pos !== position) {
                                        findHighestListElementThatStartsAtPosition(position);
                                    }
                                }
                                lastQueriedPosition = position;
                                Debug.assert(!current || current.pos === position);
                                return current;
                            }
                        };
                        function findHighestListElementThatStartsAtPosition(position) {
                            currentArray = void 0;
                            currentArrayIndex = -1 /* Value */;
                            current = void 0;
                            forEachChild(sourceFile, visitNode3, visitArray2);
                            return;
                            function visitNode3(node) {
                                if (position >= node.pos && position < node.end) {
                                    forEachChild(node, visitNode3, visitArray2);
                                    return true;
                                }
                                return false;
                            }
                            function visitArray2(array) {
                                if (position >= array.pos && position < array.end) {
                                    for (let i = 0; i < array.length; i++) {
                                        const child = array[i];
                                        if (child) {
                                            if (child.pos === position) {
                                                currentArray = array;
                                                currentArrayIndex = i;
                                                current = child;
                                                return true;
                                            }
                                            else {
                                                if (child.pos < position && position < child.end) {
                                                    forEachChild(child, visitNode3, visitArray2);
                                                    return true;
                                                }
                                            }
                                        }
                                    }
                                }
                                return false;
                            }
                        }
                    }
                    IncrementalParser2.createSyntaxCursor = createSyntaxCursor;
                    let InvalidPosition;
                    ((InvalidPosition2) => {
                        InvalidPosition2[InvalidPosition2["Value"] = -1] = "Value";
                    })(InvalidPosition || (InvalidPosition = {}));
                })(IncrementalParser || (IncrementalParser = {}));
                namedArgRegExCache = /* @__PURE__ */ new Map();
                tripleSlashXMLCommentStartRegEx = /^\/\/\/\s*<(\S+)\s.*?\/>/im;
                singleLinePragmaRegEx = /^\/\/\/?\s*@(\S+)\s*(.*)\s*$/im;
            }
        });
        // src/compiler/commandLineParser.ts
        function createOptionNameMap(optionDeclarations2) {
            const optionsNameMap = /* @__PURE__ */ new Map();
            const shortOptionNames = /* @__PURE__ */ new Map();
            forEach(optionDeclarations2, (option) => {
                optionsNameMap.set(option.name.toLowerCase(), option);
                if (option.shortName) {
                    shortOptionNames.set(option.shortName, option.name);
                }
            });
            return { optionsNameMap, shortOptionNames };
        }
        function getOptionsNameMap() {
            return optionsNameMapCache || (optionsNameMapCache = createOptionNameMap(optionDeclarations));
        }
        function createCompilerDiagnosticForInvalidCustomType(opt) {
            return createDiagnosticForInvalidCustomType(opt, createCompilerDiagnostic);
        }
        function createDiagnosticForInvalidCustomType(opt, createDiagnostic) {
            const namesOfType = arrayFrom(opt.type.keys());
            const stringNames = (opt.deprecatedKeys ? namesOfType.filter((k) => !opt.deprecatedKeys.has(k)) : namesOfType).map((key) => `'${key}'`).join(", ");
            return createDiagnostic(Diagnostics.Argument_for_0_option_must_be_Colon_1, `--${opt.name}`, stringNames);
        }
        function parseCustomTypeOption(opt, value, errors) {
            return convertJsonOptionOfCustomType(opt, trimString(value || ""), errors);
        }
        function parseListTypeOption(opt, value = "", errors) {
            value = trimString(value);
            if (startsWith(value, "-")) {
                return void 0;
            }
            if (opt.type === "listOrElement" && !stringContains(value, ",")) {
                return validateJsonOptionValue(opt, value, errors);
            }
            if (value === "") {
                return [];
            }
            const values = value.split(",");
            switch (opt.element.type) {
                case "number":
                    return mapDefined(values, (v) => validateJsonOptionValue(opt.element, parseInt(v), errors));
                case "string":
                    return mapDefined(values, (v) => validateJsonOptionValue(opt.element, v || "", errors));
                case "boolean":
                case "object":
                    return Debug.fail(`List of ${opt.element.type} is not yet supported.`);
                default:
                    return mapDefined(values, (v) => parseCustomTypeOption(opt.element, v, errors));
            }
        }
        function getOptionName(option) {
            return option.name;
        }
        function createUnknownOptionError(unknownOption, diagnostics, createDiagnostics, unknownOptionErrorText) {
            var _a2;
            if ((_a2 = diagnostics.alternateMode) == null ? void 0 : _a2.getOptionsNameMap().optionsNameMap.has(unknownOption.toLowerCase())) {
                return createDiagnostics(diagnostics.alternateMode.diagnostic, unknownOption);
            }
            const possibleOption = getSpellingSuggestion(unknownOption, diagnostics.optionDeclarations, getOptionName);
            return possibleOption ? createDiagnostics(diagnostics.unknownDidYouMeanDiagnostic, unknownOptionErrorText || unknownOption, possibleOption.name) : createDiagnostics(diagnostics.unknownOptionDiagnostic, unknownOptionErrorText || unknownOption);
        }
        function parseCommandLineWorker(diagnostics, commandLine, readFile) {
            const options = {};
            let watchOptions;
            const fileNames = [];
            const errors = [];
            parseStrings(commandLine);
            return {
                options,
                watchOptions,
                fileNames,
                errors
            };
            function parseStrings(args) {
                let i = 0;
                while (i < args.length) {
                    const s = args[i];
                    i++;
                    if (s.charCodeAt(0) === 64 /* at */) {
                        parseResponseFile(s.slice(1));
                    }
                    else if (s.charCodeAt(0) === 45 /* minus */) {
                        const inputOptionName = s.slice(s.charCodeAt(1) === 45 /* minus */ ? 2 : 1);
                        const opt = getOptionDeclarationFromName(diagnostics.getOptionsNameMap, inputOptionName, 
                        /*allowShort*/
                        true);
                        if (opt) {
                            i = parseOptionValue(args, i, diagnostics, opt, options, errors);
                        }
                        else {
                            const watchOpt = getOptionDeclarationFromName(watchOptionsDidYouMeanDiagnostics.getOptionsNameMap, inputOptionName, 
                            /*allowShort*/
                            true);
                            if (watchOpt) {
                                i = parseOptionValue(args, i, watchOptionsDidYouMeanDiagnostics, watchOpt, watchOptions || (watchOptions = {}), errors);
                            }
                            else {
                                errors.push(createUnknownOptionError(inputOptionName, diagnostics, createCompilerDiagnostic, s));
                            }
                        }
                    }
                    else {
                        fileNames.push(s);
                    }
                }
            }
            function parseResponseFile(fileName) {
                const text = tryReadFile(fileName, readFile || ((fileName2) => sys.readFile(fileName2)));
                if (!isString(text)) {
                    errors.push(text);
                    return;
                }
                const args = [];
                let pos = 0;
                while (true) {
                    while (pos < text.length && text.charCodeAt(pos) <= 32 /* space */)
                        pos++;
                    if (pos >= text.length)
                        break;
                    const start = pos;
                    if (text.charCodeAt(start) === 34 /* doubleQuote */) {
                        pos++;
                        while (pos < text.length && text.charCodeAt(pos) !== 34 /* doubleQuote */)
                            pos++;
                        if (pos < text.length) {
                            args.push(text.substring(start + 1, pos));
                            pos++;
                        }
                        else {
                            errors.push(createCompilerDiagnostic(Diagnostics.Unterminated_quoted_string_in_response_file_0, fileName));
                        }
                    }
                    else {
                        while (text.charCodeAt(pos) > 32 /* space */)
                            pos++;
                        args.push(text.substring(start, pos));
                    }
                }
                parseStrings(args);
            }
        }
        function parseOptionValue(args, i, diagnostics, opt, options, errors) {
            if (opt.isTSConfigOnly) {
                const optValue = args[i];
                if (optValue === "null") {
                    options[opt.name] = void 0;
                    i++;
                }
                else if (opt.type === "boolean") {
                    if (optValue === "false") {
                        options[opt.name] = validateJsonOptionValue(opt, 
                        /*value*/
                        false, errors);
                        i++;
                    }
                    else {
                        if (optValue === "true")
                            i++;
                        errors.push(createCompilerDiagnostic(Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line, opt.name));
                    }
                }
                else {
                    errors.push(createCompilerDiagnostic(Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line, opt.name));
                    if (optValue && !startsWith(optValue, "-"))
                        i++;
                }
            }
            else {
                if (!args[i] && opt.type !== "boolean") {
                    errors.push(createCompilerDiagnostic(diagnostics.optionTypeMismatchDiagnostic, opt.name, getCompilerOptionValueTypeString(opt)));
                }
                if (args[i] !== "null") {
                    switch (opt.type) {
                        case "number":
                            options[opt.name] = validateJsonOptionValue(opt, parseInt(args[i]), errors);
                            i++;
                            break;
                        case "boolean":
                            const optValue = args[i];
                            options[opt.name] = validateJsonOptionValue(opt, optValue !== "false", errors);
                            if (optValue === "false" || optValue === "true") {
                                i++;
                            }
                            break;
                        case "string":
                            options[opt.name] = validateJsonOptionValue(opt, args[i] || "", errors);
                            i++;
                            break;
                        case "list":
                            const result = parseListTypeOption(opt, args[i], errors);
                            options[opt.name] = result || [];
                            if (result) {
                                i++;
                            }
                            break;
                        case "listOrElement":
                            Debug.fail("listOrElement not supported here");
                            break;
                        default:
                            options[opt.name] = parseCustomTypeOption(opt, args[i], errors);
                            i++;
                            break;
                    }
                }
                else {
                    options[opt.name] = void 0;
                    i++;
                }
            }
            return i;
        }
        function parseCommandLine(commandLine, readFile) {
            return parseCommandLineWorker(compilerOptionsDidYouMeanDiagnostics, commandLine, readFile);
        }
        function getOptionFromName(optionName, allowShort) {
            return getOptionDeclarationFromName(getOptionsNameMap, optionName, allowShort);
        }
        function getOptionDeclarationFromName(getOptionNameMap, optionName, allowShort = false) {
            optionName = optionName.toLowerCase();
            const { optionsNameMap, shortOptionNames } = getOptionNameMap();
            if (allowShort) {
                const short = shortOptionNames.get(optionName);
                if (short !== void 0) {
                    optionName = short;
                }
            }
            return optionsNameMap.get(optionName);
        }
        function getBuildOptionsNameMap() {
            return buildOptionsNameMapCache || (buildOptionsNameMapCache = createOptionNameMap(buildOpts));
        }
        function parseBuildCommand(args) {
            const { options, watchOptions, fileNames: projects, errors } = parseCommandLineWorker(buildOptionsDidYouMeanDiagnostics, args);
            const buildOptions = options;
            if (projects.length === 0) {
                projects.push(".");
            }
            if (buildOptions.clean && buildOptions.force) {
                errors.push(createCompilerDiagnostic(Diagnostics.Options_0_and_1_cannot_be_combined, "clean", "force"));
            }
            if (buildOptions.clean && buildOptions.verbose) {
                errors.push(createCompilerDiagnostic(Diagnostics.Options_0_and_1_cannot_be_combined, "clean", "verbose"));
            }
            if (buildOptions.clean && buildOptions.watch) {
                errors.push(createCompilerDiagnostic(Diagnostics.Options_0_and_1_cannot_be_combined, "clean", "watch"));
            }
            if (buildOptions.watch && buildOptions.dry) {
                errors.push(createCompilerDiagnostic(Diagnostics.Options_0_and_1_cannot_be_combined, "watch", "dry"));
            }
            return { buildOptions, watchOptions, projects, errors };
        }
        function getDiagnosticText(_message, ..._args) {
            const diagnostic = createCompilerDiagnostic.apply(void 0, arguments);
            return diagnostic.messageText;
        }
        function getParsedCommandLineOfConfigFile(configFileName, optionsToExtend, host, extendedConfigCache, watchOptionsToExtend, extraFileExtensions) {
            const configFileText = tryReadFile(configFileName, (fileName) => host.readFile(fileName));
            if (!isString(configFileText)) {
                host.onUnRecoverableConfigFileDiagnostic(configFileText);
                return void 0;
            }
            const result = parseJsonText(configFileName, configFileText);
            const cwd = host.getCurrentDirectory();
            result.path = toPath(configFileName, cwd, createGetCanonicalFileName(host.useCaseSensitiveFileNames));
            result.resolvedPath = result.path;
            result.originalFileName = result.fileName;
            return parseJsonSourceFileConfigFileContent(result, host, getNormalizedAbsolutePath(getDirectoryPath(configFileName), cwd), optionsToExtend, getNormalizedAbsolutePath(configFileName, cwd), 
            /*resolutionStack*/
            void 0, extraFileExtensions, extendedConfigCache, watchOptionsToExtend);
        }
        function readConfigFile(fileName, readFile) {
            const textOrDiagnostic = tryReadFile(fileName, readFile);
            return isString(textOrDiagnostic) ? parseConfigFileTextToJson(fileName, textOrDiagnostic) : { config: {}, error: textOrDiagnostic };
        }
        function parseConfigFileTextToJson(fileName, jsonText) {
            const jsonSourceFile = parseJsonText(fileName, jsonText);
            return {
                config: convertConfigFileToObject(jsonSourceFile, jsonSourceFile.parseDiagnostics, 
                /*reportOptionsErrors*/
                false, 
                /*optionsIterator*/
                void 0),
                error: jsonSourceFile.parseDiagnostics.length ? jsonSourceFile.parseDiagnostics[0] : void 0
            };
        }
        function readJsonConfigFile(fileName, readFile) {
            const textOrDiagnostic = tryReadFile(fileName, readFile);
            return isString(textOrDiagnostic) ? parseJsonText(fileName, textOrDiagnostic) : { fileName, parseDiagnostics: [textOrDiagnostic] };
        }
        function tryReadFile(fileName, readFile) {
            let text;
            try {
                text = readFile(fileName);
            }
            catch (e) {
                return createCompilerDiagnostic(Diagnostics.Cannot_read_file_0_Colon_1, fileName, e.message);
            }
            return text === void 0 ? createCompilerDiagnostic(Diagnostics.Cannot_read_file_0, fileName) : text;
        }
        function commandLineOptionsToMap(options) {
            return arrayToMap(options, getOptionName);
        }
        function getWatchOptionsNameMap() {
            return watchOptionsNameMapCache || (watchOptionsNameMapCache = createOptionNameMap(optionsForWatch));
        }
        function getCommandLineCompilerOptionsMap() {
            return commandLineCompilerOptionsMapCache || (commandLineCompilerOptionsMapCache = commandLineOptionsToMap(optionDeclarations));
        }
        function getCommandLineWatchOptionsMap() {
            return commandLineWatchOptionsMapCache || (commandLineWatchOptionsMapCache = commandLineOptionsToMap(optionsForWatch));
        }
        function getCommandLineTypeAcquisitionMap() {
            return commandLineTypeAcquisitionMapCache || (commandLineTypeAcquisitionMapCache = commandLineOptionsToMap(typeAcquisitionDeclarations));
        }
        function getTsconfigRootOptionsMap() {
            if (_tsconfigRootOptions === void 0) {
                _tsconfigRootOptions = {
                    name: void 0,
                    // should never be needed since this is root
                    type: "object",
                    elementOptions: commandLineOptionsToMap([
                        {
                            name: "compilerOptions",
                            type: "object",
                            elementOptions: getCommandLineCompilerOptionsMap(),
                            extraKeyDiagnostics: compilerOptionsDidYouMeanDiagnostics
                        },
                        {
                            name: "watchOptions",
                            type: "object",
                            elementOptions: getCommandLineWatchOptionsMap(),
                            extraKeyDiagnostics: watchOptionsDidYouMeanDiagnostics
                        },
                        {
                            name: "typeAcquisition",
                            type: "object",
                            elementOptions: getCommandLineTypeAcquisitionMap(),
                            extraKeyDiagnostics: typeAcquisitionDidYouMeanDiagnostics
                        },
                        extendsOptionDeclaration,
                        {
                            name: "references",
                            type: "list",
                            element: {
                                name: "references",
                                type: "object"
                            },
                            category: Diagnostics.Projects
                        },
                        {
                            name: "files",
                            type: "list",
                            element: {
                                name: "files",
                                type: "string"
                            },
                            category: Diagnostics.File_Management
                        },
                        {
                            name: "include",
                            type: "list",
                            element: {
                                name: "include",
                                type: "string"
                            },
                            category: Diagnostics.File_Management,
                            defaultValueDescription: Diagnostics.if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk
                        },
                        {
                            name: "exclude",
                            type: "list",
                            element: {
                                name: "exclude",
                                type: "string"
                            },
                            category: Diagnostics.File_Management,
                            defaultValueDescription: Diagnostics.node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified
                        },
                        compileOnSaveCommandLineOption
                    ])
                };
            }
            return _tsconfigRootOptions;
        }
        function convertConfigFileToObject(sourceFile, errors, reportOptionsErrors, optionsIterator) {
            var _a2;
            const rootExpression = (_a2 = sourceFile.statements[0]) == null ? void 0 : _a2.expression;
            const knownRootOptions = reportOptionsErrors ? getTsconfigRootOptionsMap() : void 0;
            if (rootExpression && rootExpression.kind !== 207 /* ObjectLiteralExpression */) {
                errors.push(createDiagnosticForNodeInSourceFile(sourceFile, rootExpression, Diagnostics.The_root_value_of_a_0_file_must_be_an_object, getBaseFileName(sourceFile.fileName) === "jsconfig.json" ? "jsconfig.json" : "tsconfig.json"));
                if (isArrayLiteralExpression(rootExpression)) {
                    const firstObject = find(rootExpression.elements, isObjectLiteralExpression);
                    if (firstObject) {
                        return convertToObjectWorker(sourceFile, firstObject, errors, 
                        /*returnValue*/
                        true, knownRootOptions, optionsIterator);
                    }
                }
                return {};
            }
            return convertToObjectWorker(sourceFile, rootExpression, errors, 
            /*returnValue*/
            true, knownRootOptions, optionsIterator);
        }
        function convertToObject(sourceFile, errors) {
            var _a2;
            return convertToObjectWorker(sourceFile, (_a2 = sourceFile.statements[0]) == null ? void 0 : _a2.expression, errors, 
            /*returnValue*/
            true, 
            /*knownRootOptions*/
            void 0, 
            /*jsonConversionNotifier*/
            void 0);
        }
        function convertToObjectWorker(sourceFile, rootExpression, errors, returnValue, knownRootOptions, jsonConversionNotifier) {
            if (!rootExpression) {
                return returnValue ? {} : void 0;
            }
            return convertPropertyValueToJson(rootExpression, knownRootOptions);
            function isRootOptionMap(knownOptions) {
                return knownRootOptions && knownRootOptions.elementOptions === knownOptions;
            }
            function convertObjectLiteralExpressionToJson(node, knownOptions, extraKeyDiagnostics, parentOption) {
                const result = returnValue ? {} : void 0;
                for (const element of node.properties) {
                    if (element.kind !== 299 /* PropertyAssignment */) {
                        errors.push(createDiagnosticForNodeInSourceFile(sourceFile, element, Diagnostics.Property_assignment_expected));
                        continue;
                    }
                    if (element.questionToken) {
                        errors.push(createDiagnosticForNodeInSourceFile(sourceFile, element.questionToken, Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files, "?"));
                    }
                    if (!isDoubleQuotedString(element.name)) {
                        errors.push(createDiagnosticForNodeInSourceFile(sourceFile, element.name, Diagnostics.String_literal_with_double_quotes_expected));
                    }
                    const textOfKey = isComputedNonLiteralName(element.name) ? void 0 : getTextOfPropertyName(element.name);
                    const keyText = textOfKey && unescapeLeadingUnderscores(textOfKey);
                    const option = keyText && knownOptions ? knownOptions.get(keyText) : void 0;
                    if (keyText && extraKeyDiagnostics && !option) {
                        if (knownOptions) {
                            errors.push(createUnknownOptionError(keyText, extraKeyDiagnostics, (message, arg0, arg1) => createDiagnosticForNodeInSourceFile(sourceFile, element.name, message, arg0, arg1)));
                        }
                        else {
                            errors.push(createDiagnosticForNodeInSourceFile(sourceFile, element.name, extraKeyDiagnostics.unknownOptionDiagnostic, keyText));
                        }
                    }
                    const value = convertPropertyValueToJson(element.initializer, option);
                    if (typeof keyText !== "undefined") {
                        if (returnValue) {
                            result[keyText] = value;
                        }
                        if (jsonConversionNotifier && // Current callbacks are only on known parent option or if we are setting values in the root
                            (parentOption || isRootOptionMap(knownOptions))) {
                            const isValidOptionValue = isCompilerOptionsValue(option, value);
                            if (parentOption) {
                                if (isValidOptionValue) {
                                    jsonConversionNotifier.onSetValidOptionKeyValueInParent(parentOption, option, value);
                                }
                            }
                            else if (isRootOptionMap(knownOptions)) {
                                if (isValidOptionValue) {
                                    jsonConversionNotifier.onSetValidOptionKeyValueInRoot(keyText, element.name, value, element.initializer);
                                }
                                else if (!option) {
                                    jsonConversionNotifier.onSetUnknownOptionKeyValueInRoot(keyText, element.name, value, element.initializer);
                                }
                            }
                        }
                    }
                }
                return result;
            }
            function convertArrayLiteralExpressionToJson(elements, elementOption) {
                if (!returnValue) {
                    elements.forEach((element) => convertPropertyValueToJson(element, elementOption));
                    return void 0;
                }
                return filter(elements.map((element) => convertPropertyValueToJson(element, elementOption)), (v) => v !== void 0);
            }
            function convertPropertyValueToJson(valueExpression, option) {
                let invalidReported;
                switch (valueExpression.kind) {
                    case 110 /* TrueKeyword */:
                        reportInvalidOptionValue(option && option.type !== "boolean" && (option.type !== "listOrElement" || option.element.type !== "boolean"));
                        return validateValue(
                        /*value*/
                        true);
                    case 95 /* FalseKeyword */:
                        reportInvalidOptionValue(option && option.type !== "boolean" && (option.type !== "listOrElement" || option.element.type !== "boolean"));
                        return validateValue(
                        /*value*/
                        false);
                    case 104 /* NullKeyword */:
                        reportInvalidOptionValue(option && option.name === "extends");
                        return validateValue(
                        /*value*/
                        null);
                    case 10 /* StringLiteral */:
                        if (!isDoubleQuotedString(valueExpression)) {
                            errors.push(createDiagnosticForNodeInSourceFile(sourceFile, valueExpression, Diagnostics.String_literal_with_double_quotes_expected));
                        }
                        reportInvalidOptionValue(option && isString(option.type) && option.type !== "string" && (option.type !== "listOrElement" || isString(option.element.type) && option.element.type !== "string"));
                        const text = valueExpression.text;
                        if (option) {
                            Debug.assert(option.type !== "listOrElement" || option.element.type === "string", "Only string or array of string is handled for now");
                        }
                        if (option && !isString(option.type)) {
                            const customOption = option;
                            if (!customOption.type.has(text.toLowerCase())) {
                                errors.push(createDiagnosticForInvalidCustomType(customOption, (message, arg0, arg1) => createDiagnosticForNodeInSourceFile(sourceFile, valueExpression, message, arg0, arg1)));
                                invalidReported = true;
                            }
                        }
                        return validateValue(text);
                    case 8 /* NumericLiteral */:
                        reportInvalidOptionValue(option && option.type !== "number" && (option.type !== "listOrElement" || option.element.type !== "number"));
                        return validateValue(Number(valueExpression.text));
                    case 221 /* PrefixUnaryExpression */:
                        if (valueExpression.operator !== 40 /* MinusToken */ || valueExpression.operand.kind !== 8 /* NumericLiteral */) {
                            break;
                        }
                        reportInvalidOptionValue(option && option.type !== "number" && (option.type !== "listOrElement" || option.element.type !== "number"));
                        return validateValue(-Number(valueExpression.operand.text));
                    case 207 /* ObjectLiteralExpression */:
                        reportInvalidOptionValue(option && option.type !== "object" && (option.type !== "listOrElement" || option.element.type !== "object"));
                        const objectLiteralExpression = valueExpression;
                        if (option) {
                            const { elementOptions, extraKeyDiagnostics, name: optionName } = option;
                            return validateValue(convertObjectLiteralExpressionToJson(objectLiteralExpression, elementOptions, extraKeyDiagnostics, optionName));
                        }
                        else {
                            return validateValue(convertObjectLiteralExpressionToJson(objectLiteralExpression, 
                            /* knownOptions*/
                            void 0, 
                            /*extraKeyDiagnosticMessage */
                            void 0, 
                            /*parentOption*/
                            void 0));
                        }
                    case 206 /* ArrayLiteralExpression */:
                        reportInvalidOptionValue(option && option.type !== "list" && option.type !== "listOrElement");
                        return validateValue(convertArrayLiteralExpressionToJson(valueExpression.elements, option && option.element));
                }
                if (option) {
                    reportInvalidOptionValue(
                    /*isError*/
                    true);
                }
                else {
                    errors.push(createDiagnosticForNodeInSourceFile(sourceFile, valueExpression, Diagnostics.Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_literal));
                }
                return void 0;
                function validateValue(value) {
                    var _a2;
                    if (!invalidReported) {
                        const diagnostic = (_a2 = option == null ? void 0 : option.extraValidation) == null ? void 0 : _a2.call(option, value);
                        if (diagnostic) {
                            errors.push(createDiagnosticForNodeInSourceFile(sourceFile, valueExpression, ...diagnostic));
                            return void 0;
                        }
                    }
                    return value;
                }
                function reportInvalidOptionValue(isError) {
                    if (isError) {
                        errors.push(createDiagnosticForNodeInSourceFile(sourceFile, valueExpression, Diagnostics.Compiler_option_0_requires_a_value_of_type_1, option.name, getCompilerOptionValueTypeString(option)));
                        invalidReported = true;
                    }
                }
            }
            function isDoubleQuotedString(node) {
                return isStringLiteral(node) && isStringDoubleQuoted(node, sourceFile);
            }
        }
        function getCompilerOptionValueTypeString(option) {
            return option.type === "listOrElement" ? `${getCompilerOptionValueTypeString(option.element)} or Array` : option.type === "list" ? "Array" : isString(option.type) ? option.type : "string";
        }
        function isCompilerOptionsValue(option, value) {
            if (option) {
                if (isNullOrUndefined(value))
                    return true;
                if (option.type === "list") {
                    return isArray(value);
                }
                if (option.type === "listOrElement") {
                    return isArray(value) || isCompilerOptionsValue(option.element, value);
                }
                const expectedType = isString(option.type) ? option.type : "string";
                return typeof value === expectedType;
            }
            return false;
        }
        function convertToTSConfig(configParseResult, configFileName, host) {
            var _a2, _b, _c;
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames);
            const files = map(filter(configParseResult.fileNames, !((_b = (_a2 = configParseResult.options.configFile) == null ? void 0 : _a2.configFileSpecs) == null ? void 0 : _b.validatedIncludeSpecs) ? returnTrue : matchesSpecs(configFileName, configParseResult.options.configFile.configFileSpecs.validatedIncludeSpecs, configParseResult.options.configFile.configFileSpecs.validatedExcludeSpecs, host)), (f) => getRelativePathFromFile(getNormalizedAbsolutePath(configFileName, host.getCurrentDirectory()), getNormalizedAbsolutePath(f, host.getCurrentDirectory()), getCanonicalFileName));
            const optionMap = serializeCompilerOptions(configParseResult.options, { configFilePath: getNormalizedAbsolutePath(configFileName, host.getCurrentDirectory()), useCaseSensitiveFileNames: host.useCaseSensitiveFileNames });
            const watchOptionMap = configParseResult.watchOptions && serializeWatchOptions(configParseResult.watchOptions);
            const config = {
                compilerOptions: {
                    ...optionMapToObject(optionMap),
                    showConfig: void 0,
                    configFile: void 0,
                    configFilePath: void 0,
                    help: void 0,
                    init: void 0,
                    listFiles: void 0,
                    listEmittedFiles: void 0,
                    project: void 0,
                    build: void 0,
                    version: void 0
                },
                watchOptions: watchOptionMap && optionMapToObject(watchOptionMap),
                references: map(configParseResult.projectReferences, (r) => ({ ...r, path: r.originalPath ? r.originalPath : "", originalPath: void 0 })),
                files: length(files) ? files : void 0,
                ...((_c = configParseResult.options.configFile) == null ? void 0 : _c.configFileSpecs) ? {
                    include: filterSameAsDefaultInclude(configParseResult.options.configFile.configFileSpecs.validatedIncludeSpecs),
                    exclude: configParseResult.options.configFile.configFileSpecs.validatedExcludeSpecs
                } : {},
                compileOnSave: !!configParseResult.compileOnSave ? true : void 0
            };
            return config;
        }
        function optionMapToObject(optionMap) {
            return {
                ...arrayFrom(optionMap.entries()).reduce((prev, cur) => ({ ...prev, [cur[0]]: cur[1] }), {})
            };
        }
        function filterSameAsDefaultInclude(specs) {
            if (!length(specs))
                return void 0;
            if (length(specs) !== 1)
                return specs;
            if (specs[0] === defaultIncludeSpec)
                return void 0;
            return specs;
        }
        function matchesSpecs(path, includeSpecs, excludeSpecs, host) {
            if (!includeSpecs)
                return returnTrue;
            const patterns = getFileMatcherPatterns(path, excludeSpecs, includeSpecs, host.useCaseSensitiveFileNames, host.getCurrentDirectory());
            const excludeRe = patterns.excludePattern && getRegexFromPattern(patterns.excludePattern, host.useCaseSensitiveFileNames);
            const includeRe = patterns.includeFilePattern && getRegexFromPattern(patterns.includeFilePattern, host.useCaseSensitiveFileNames);
            if (includeRe) {
                if (excludeRe) {
                    return (path2) => !(includeRe.test(path2) && !excludeRe.test(path2));
                }
                return (path2) => !includeRe.test(path2);
            }
            if (excludeRe) {
                return (path2) => excludeRe.test(path2);
            }
            return returnTrue;
        }
        function getCustomTypeMapOfCommandLineOption(optionDefinition) {
            switch (optionDefinition.type) {
                case "string":
                case "number":
                case "boolean":
                case "object":
                    return void 0;
                case "list":
                case "listOrElement":
                    return getCustomTypeMapOfCommandLineOption(optionDefinition.element);
                default:
                    return optionDefinition.type;
            }
        }
        function getNameOfCompilerOptionValue(value, customTypeMap) {
            return forEachEntry(customTypeMap, (mapValue, key) => {
                if (mapValue === value) {
                    return key;
                }
            });
        }
        function serializeCompilerOptions(options, pathOptions) {
            return serializeOptionBaseObject(options, getOptionsNameMap(), pathOptions);
        }
        function serializeWatchOptions(options) {
            return serializeOptionBaseObject(options, getWatchOptionsNameMap());
        }
        function serializeOptionBaseObject(options, { optionsNameMap }, pathOptions) {
            const result = /* @__PURE__ */ new Map();
            const getCanonicalFileName = pathOptions && createGetCanonicalFileName(pathOptions.useCaseSensitiveFileNames);
            for (const name in options) {
                if (hasProperty(options, name)) {
                    if (optionsNameMap.has(name) && (optionsNameMap.get(name).category === Diagnostics.Command_line_Options || optionsNameMap.get(name).category === Diagnostics.Output_Formatting)) {
                        continue;
                    }
                    const value = options[name];
                    const optionDefinition = optionsNameMap.get(name.toLowerCase());
                    if (optionDefinition) {
                        Debug.assert(optionDefinition.type !== "listOrElement");
                        const customTypeMap = getCustomTypeMapOfCommandLineOption(optionDefinition);
                        if (!customTypeMap) {
                            if (pathOptions && optionDefinition.isFilePath) {
                                result.set(name, getRelativePathFromFile(pathOptions.configFilePath, getNormalizedAbsolutePath(value, getDirectoryPath(pathOptions.configFilePath)), getCanonicalFileName));
                            }
                            else {
                                result.set(name, value);
                            }
                        }
                        else {
                            if (optionDefinition.type === "list") {
                                result.set(name, value.map((element) => getNameOfCompilerOptionValue(element, customTypeMap)));
                            }
                            else {
                                result.set(name, getNameOfCompilerOptionValue(value, customTypeMap));
                            }
                        }
                    }
                }
            }
            return result;
        }
        function getCompilerOptionsDiffValue(options, newLine) {
            const compilerOptionsMap = getSerializedCompilerOption(options);
            return getOverwrittenDefaultOptions();
            function makePadding(paddingLength) {
                return Array(paddingLength + 1).join(" ");
            }
            function getOverwrittenDefaultOptions() {
                const result = [];
                const tab = makePadding(2);
                commandOptionsWithoutBuild.forEach((cmd) => {
                    if (!compilerOptionsMap.has(cmd.name)) {
                        return;
                    }
                    const newValue = compilerOptionsMap.get(cmd.name);
                    const defaultValue = getDefaultValueForOption(cmd);
                    if (newValue !== defaultValue) {
                        result.push(`${tab}${cmd.name}: ${newValue}`);
                    }
                    else if (hasProperty(defaultInitCompilerOptions, cmd.name)) {
                        result.push(`${tab}${cmd.name}: ${defaultValue}`);
                    }
                });
                return result.join(newLine) + newLine;
            }
        }
        function getSerializedCompilerOption(options) {
            const compilerOptions = extend(options, defaultInitCompilerOptions);
            return serializeCompilerOptions(compilerOptions);
        }
        function generateTSConfig(options, fileNames, newLine) {
            const compilerOptionsMap = getSerializedCompilerOption(options);
            return writeConfigurations();
            function makePadding(paddingLength) {
                return Array(paddingLength + 1).join(" ");
            }
            function isAllowedOptionForOutput({ category, name, isCommandLineOnly }) {
                const categoriesToSkip = [Diagnostics.Command_line_Options, Diagnostics.Editor_Support, Diagnostics.Compiler_Diagnostics, Diagnostics.Backwards_Compatibility, Diagnostics.Watch_and_Build_Modes, Diagnostics.Output_Formatting];
                return !isCommandLineOnly && category !== void 0 && (!categoriesToSkip.includes(category) || compilerOptionsMap.has(name));
            }
            function writeConfigurations() {
                const categorizedOptions = /* @__PURE__ */ new Map();
                categorizedOptions.set(Diagnostics.Projects, []);
                categorizedOptions.set(Diagnostics.Language_and_Environment, []);
                categorizedOptions.set(Diagnostics.Modules, []);
                categorizedOptions.set(Diagnostics.JavaScript_Support, []);
                categorizedOptions.set(Diagnostics.Emit, []);
                categorizedOptions.set(Diagnostics.Interop_Constraints, []);
                categorizedOptions.set(Diagnostics.Type_Checking, []);
                categorizedOptions.set(Diagnostics.Completeness, []);
                for (const option of optionDeclarations) {
                    if (isAllowedOptionForOutput(option)) {
                        let listForCategory = categorizedOptions.get(option.category);
                        if (!listForCategory)
                            categorizedOptions.set(option.category, listForCategory = []);
                        listForCategory.push(option);
                    }
                }
                let marginLength = 0;
                let seenKnownKeys = 0;
                const entries = [];
                categorizedOptions.forEach((options2, category) => {
                    if (entries.length !== 0) {
                        entries.push({ value: "" });
                    }
                    entries.push({ value: `/* ${getLocaleSpecificMessage(category)} */` });
                    for (const option of options2) {
                        let optionName;
                        if (compilerOptionsMap.has(option.name)) {
                            optionName = `"${option.name}": ${JSON.stringify(compilerOptionsMap.get(option.name))}${(seenKnownKeys += 1) === compilerOptionsMap.size ? "" : ","}`;
                        }
                        else {
                            optionName = `// "${option.name}": ${JSON.stringify(getDefaultValueForOption(option))},`;
                        }
                        entries.push({
                            value: optionName,
                            description: `/* ${option.description && getLocaleSpecificMessage(option.description) || option.name} */`
                        });
                        marginLength = Math.max(optionName.length, marginLength);
                    }
                });
                const tab = makePadding(2);
                const result = [];
                result.push(`{`);
                result.push(`${tab}"compilerOptions": {`);
                result.push(`${tab}${tab}/* ${getLocaleSpecificMessage(Diagnostics.Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file)} */`);
                result.push("");
                for (const entry of entries) {
                    const { value, description: description2 = "" } = entry;
                    result.push(value && `${tab}${tab}${value}${description2 && makePadding(marginLength - value.length + 2) + description2}`);
                }
                if (fileNames.length) {
                    result.push(`${tab}},`);
                    result.push(`${tab}"files": [`);
                    for (let i = 0; i < fileNames.length; i++) {
                        result.push(`${tab}${tab}${JSON.stringify(fileNames[i])}${i === fileNames.length - 1 ? "" : ","}`);
                    }
                    result.push(`${tab}]`);
                }
                else {
                    result.push(`${tab}}`);
                }
                result.push(`}`);
                return result.join(newLine) + newLine;
            }
        }
        function convertToOptionsWithAbsolutePaths(options, toAbsolutePath) {
            const result = {};
            const optionsNameMap = getOptionsNameMap().optionsNameMap;
            for (const name in options) {
                if (hasProperty(options, name)) {
                    result[name] = convertToOptionValueWithAbsolutePaths(optionsNameMap.get(name.toLowerCase()), options[name], toAbsolutePath);
                }
            }
            if (result.configFilePath) {
                result.configFilePath = toAbsolutePath(result.configFilePath);
            }
            return result;
        }
        function convertToOptionValueWithAbsolutePaths(option, value, toAbsolutePath) {
            if (option && !isNullOrUndefined(value)) {
                if (option.type === "list") {
                    const values = value;
                    if (option.element.isFilePath && values.length) {
                        return values.map(toAbsolutePath);
                    }
                }
                else if (option.isFilePath) {
                    return toAbsolutePath(value);
                }
                Debug.assert(option.type !== "listOrElement");
            }
            return value;
        }
        function parseJsonConfigFileContent(json, host, basePath, existingOptions, configFileName, resolutionStack, extraFileExtensions, extendedConfigCache, existingWatchOptions) {
            return parseJsonConfigFileContentWorker(json, 
            /*sourceFile*/
            void 0, host, basePath, existingOptions, existingWatchOptions, configFileName, resolutionStack, extraFileExtensions, extendedConfigCache);
        }
        function parseJsonSourceFileConfigFileContent(sourceFile, host, basePath, existingOptions, configFileName, resolutionStack, extraFileExtensions, extendedConfigCache, existingWatchOptions) {
            var _a2, _b;
            (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Parse, "parseJsonSourceFileConfigFileContent", { path: sourceFile.fileName });
            const result = parseJsonConfigFileContentWorker(
            /*json*/
            void 0, sourceFile, host, basePath, existingOptions, existingWatchOptions, configFileName, resolutionStack, extraFileExtensions, extendedConfigCache);
            (_b = tracing) == null ? void 0 : _b.pop();
            return result;
        }
        function setConfigFileInOptions(options, configFile) {
            if (configFile) {
                Object.defineProperty(options, "configFile", { enumerable: false, writable: false, value: configFile });
            }
        }
        function isNullOrUndefined(x) {
            return x === void 0 || x === null;
        }
        function directoryOfCombinedPath(fileName, basePath) {
            return getDirectoryPath(getNormalizedAbsolutePath(fileName, basePath));
        }
        function parseJsonConfigFileContentWorker(json, sourceFile, host, basePath, existingOptions = {}, existingWatchOptions, configFileName, resolutionStack = [], extraFileExtensions = [], extendedConfigCache) {
            Debug.assert(json === void 0 && sourceFile !== void 0 || json !== void 0 && sourceFile === void 0);
            const errors = [];
            const parsedConfig = parseConfig(json, sourceFile, host, basePath, configFileName, resolutionStack, errors, extendedConfigCache);
            const { raw } = parsedConfig;
            const options = extend(existingOptions, parsedConfig.options || {});
            const watchOptions = existingWatchOptions && parsedConfig.watchOptions ? extend(existingWatchOptions, parsedConfig.watchOptions) : parsedConfig.watchOptions || existingWatchOptions;
            options.configFilePath = configFileName && normalizeSlashes(configFileName);
            const configFileSpecs = getConfigFileSpecs();
            if (sourceFile)
                sourceFile.configFileSpecs = configFileSpecs;
            setConfigFileInOptions(options, sourceFile);
            const basePathForFileNames = normalizePath(configFileName ? directoryOfCombinedPath(configFileName, basePath) : basePath);
            return {
                options,
                watchOptions,
                fileNames: getFileNames(basePathForFileNames),
                projectReferences: getProjectReferences(basePathForFileNames),
                typeAcquisition: parsedConfig.typeAcquisition || getDefaultTypeAcquisition(),
                raw,
                errors,
                // Wildcard directories (provided as part of a wildcard path) are stored in a
                // file map that marks whether it was a regular wildcard match (with a `*` or `?` token),
                // or a recursive directory. This information is used by filesystem watchers to monitor for
                // new entries in these paths.
                wildcardDirectories: getWildcardDirectories(configFileSpecs, basePathForFileNames, host.useCaseSensitiveFileNames),
                compileOnSave: !!raw.compileOnSave
            };
            function getConfigFileSpecs() {
                const referencesOfRaw = getPropFromRaw("references", (element) => typeof element === "object", "object");
                const filesSpecs = toPropValue(getSpecsFromRaw("files"));
                if (filesSpecs) {
                    const hasZeroOrNoReferences = referencesOfRaw === "no-prop" || isArray(referencesOfRaw) && referencesOfRaw.length === 0;
                    const hasExtends = hasProperty(raw, "extends");
                    if (filesSpecs.length === 0 && hasZeroOrNoReferences && !hasExtends) {
                        if (sourceFile) {
                            const fileName = configFileName || "tsconfig.json";
                            const diagnosticMessage = Diagnostics.The_files_list_in_config_file_0_is_empty;
                            const nodeValue = firstDefined(getTsConfigPropArray(sourceFile, "files"), (property) => property.initializer);
                            const error = nodeValue ? createDiagnosticForNodeInSourceFile(sourceFile, nodeValue, diagnosticMessage, fileName) : createCompilerDiagnostic(diagnosticMessage, fileName);
                            errors.push(error);
                        }
                        else {
                            createCompilerDiagnosticOnlyIfJson(Diagnostics.The_files_list_in_config_file_0_is_empty, configFileName || "tsconfig.json");
                        }
                    }
                }
                let includeSpecs = toPropValue(getSpecsFromRaw("include"));
                const excludeOfRaw = getSpecsFromRaw("exclude");
                let isDefaultIncludeSpec = false;
                let excludeSpecs = toPropValue(excludeOfRaw);
                if (excludeOfRaw === "no-prop" && raw.compilerOptions) {
                    const outDir = raw.compilerOptions.outDir;
                    const declarationDir = raw.compilerOptions.declarationDir;
                    if (outDir || declarationDir) {
                        excludeSpecs = [outDir, declarationDir].filter((d) => !!d);
                    }
                }
                if (filesSpecs === void 0 && includeSpecs === void 0) {
                    includeSpecs = [defaultIncludeSpec];
                    isDefaultIncludeSpec = true;
                }
                let validatedIncludeSpecs, validatedExcludeSpecs;
                if (includeSpecs) {
                    validatedIncludeSpecs = validateSpecs(includeSpecs, errors, 
                    /*disallowTrailingRecursion*/
                    true, sourceFile, "include");
                }
                if (excludeSpecs) {
                    validatedExcludeSpecs = validateSpecs(excludeSpecs, errors, 
                    /*disallowTrailingRecursion*/
                    false, sourceFile, "exclude");
                }
                return {
                    filesSpecs,
                    includeSpecs,
                    excludeSpecs,
                    validatedFilesSpec: filter(filesSpecs, isString),
                    validatedIncludeSpecs,
                    validatedExcludeSpecs,
                    pathPatterns: void 0,
                    // Initialized on first use
                    isDefaultIncludeSpec
                };
            }
            function getFileNames(basePath2) {
                const fileNames = getFileNamesFromConfigSpecs(configFileSpecs, basePath2, options, host, extraFileExtensions);
                if (shouldReportNoInputFiles(fileNames, canJsonReportNoInputFiles(raw), resolutionStack)) {
                    errors.push(getErrorForNoInputFiles(configFileSpecs, configFileName));
                }
                return fileNames;
            }
            function getProjectReferences(basePath2) {
                let projectReferences;
                const referencesOfRaw = getPropFromRaw("references", (element) => typeof element === "object", "object");
                if (isArray(referencesOfRaw)) {
                    for (const ref of referencesOfRaw) {
                        if (typeof ref.path !== "string") {
                            createCompilerDiagnosticOnlyIfJson(Diagnostics.Compiler_option_0_requires_a_value_of_type_1, "reference.path", "string");
                        }
                        else {
                            (projectReferences || (projectReferences = [])).push({
                                path: getNormalizedAbsolutePath(ref.path, basePath2),
                                originalPath: ref.path,
                                prepend: ref.prepend,
                                circular: ref.circular
                            });
                        }
                    }
                }
                return projectReferences;
            }
            function toPropValue(specResult) {
                return isArray(specResult) ? specResult : void 0;
            }
            function getSpecsFromRaw(prop) {
                return getPropFromRaw(prop, isString, "string");
            }
            function getPropFromRaw(prop, validateElement, elementTypeName) {
                if (hasProperty(raw, prop) && !isNullOrUndefined(raw[prop])) {
                    if (isArray(raw[prop])) {
                        const result = raw[prop];
                        if (!sourceFile && !every(result, validateElement)) {
                            errors.push(createCompilerDiagnostic(Diagnostics.Compiler_option_0_requires_a_value_of_type_1, prop, elementTypeName));
                        }
                        return result;
                    }
                    else {
                        createCompilerDiagnosticOnlyIfJson(Diagnostics.Compiler_option_0_requires_a_value_of_type_1, prop, "Array");
                        return "not-array";
                    }
                }
                return "no-prop";
            }
            function createCompilerDiagnosticOnlyIfJson(message, arg0, arg1) {
                if (!sourceFile) {
                    errors.push(createCompilerDiagnostic(message, arg0, arg1));
                }
            }
        }
        function isErrorNoInputFiles(error) {
            return error.code === Diagnostics.No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2.code;
        }
        function getErrorForNoInputFiles({ includeSpecs, excludeSpecs }, configFileName) {
            return createCompilerDiagnostic(Diagnostics.No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2, configFileName || "tsconfig.json", JSON.stringify(includeSpecs || []), JSON.stringify(excludeSpecs || []));
        }
        function shouldReportNoInputFiles(fileNames, canJsonReportNoInutFiles, resolutionStack) {
            return fileNames.length === 0 && canJsonReportNoInutFiles && (!resolutionStack || resolutionStack.length === 0);
        }
        function canJsonReportNoInputFiles(raw) {
            return !hasProperty(raw, "files") && !hasProperty(raw, "references");
        }
        function updateErrorForNoInputFiles(fileNames, configFileName, configFileSpecs, configParseDiagnostics, canJsonReportNoInutFiles) {
            const existingErrors = configParseDiagnostics.length;
            if (shouldReportNoInputFiles(fileNames, canJsonReportNoInutFiles)) {
                configParseDiagnostics.push(getErrorForNoInputFiles(configFileSpecs, configFileName));
            }
            else {
                filterMutate(configParseDiagnostics, (error) => !isErrorNoInputFiles(error));
            }
            return existingErrors !== configParseDiagnostics.length;
        }
        function isSuccessfulParsedTsconfig(value) {
            return !!value.options;
        }
        function parseConfig(json, sourceFile, host, basePath, configFileName, resolutionStack, errors, extendedConfigCache) {
            var _a2;
            basePath = normalizeSlashes(basePath);
            const resolvedPath = getNormalizedAbsolutePath(configFileName || "", basePath);
            if (resolutionStack.indexOf(resolvedPath) >= 0) {
                errors.push(createCompilerDiagnostic(Diagnostics.Circularity_detected_while_resolving_configuration_Colon_0, [...resolutionStack, resolvedPath].join(" -> ")));
                return { raw: json || convertToObject(sourceFile, errors) };
            }
            const ownConfig = json ? parseOwnConfigOfJson(json, host, basePath, configFileName, errors) : parseOwnConfigOfJsonSourceFile(sourceFile, host, basePath, configFileName, errors);
            if ((_a2 = ownConfig.options) == null ? void 0 : _a2.paths) {
                ownConfig.options.pathsBasePath = basePath;
            }
            if (ownConfig.extendedConfigPath) {
                resolutionStack = resolutionStack.concat([resolvedPath]);
                const result = { options: {} };
                if (isString(ownConfig.extendedConfigPath)) {
                    applyExtendedConfig(result, ownConfig.extendedConfigPath);
                }
                else {
                    ownConfig.extendedConfigPath.forEach((extendedConfigPath) => applyExtendedConfig(result, extendedConfigPath));
                }
                if (!ownConfig.raw.include && result.include)
                    ownConfig.raw.include = result.include;
                if (!ownConfig.raw.exclude && result.exclude)
                    ownConfig.raw.exclude = result.exclude;
                if (!ownConfig.raw.files && result.files)
                    ownConfig.raw.files = result.files;
                if (ownConfig.raw.compileOnSave === void 0 && result.compileOnSave)
                    ownConfig.raw.compileOnSave = result.compileOnSave;
                if (sourceFile && result.extendedSourceFiles)
                    sourceFile.extendedSourceFiles = arrayFrom(result.extendedSourceFiles.keys());
                ownConfig.options = assign(result.options, ownConfig.options);
                ownConfig.watchOptions = ownConfig.watchOptions && result.watchOptions ? assign(result.watchOptions, ownConfig.watchOptions) : ownConfig.watchOptions || result.watchOptions;
            }
            return ownConfig;
            function applyExtendedConfig(result, extendedConfigPath) {
                const extendedConfig = getExtendedConfig(sourceFile, extendedConfigPath, host, resolutionStack, errors, extendedConfigCache, result);
                if (extendedConfig && isSuccessfulParsedTsconfig(extendedConfig)) {
                    const extendsRaw = extendedConfig.raw;
                    let relativeDifference;
                    const setPropertyInResultIfNotUndefined = (propertyName) => {
                        if (extendsRaw[propertyName]) {
                            result[propertyName] = map(extendsRaw[propertyName], (path) => isRootedDiskPath(path) ? path : combinePaths(relativeDifference || (relativeDifference = convertToRelativePath(getDirectoryPath(extendedConfigPath), basePath, createGetCanonicalFileName(host.useCaseSensitiveFileNames))), path));
                        }
                    };
                    setPropertyInResultIfNotUndefined("include");
                    setPropertyInResultIfNotUndefined("exclude");
                    setPropertyInResultIfNotUndefined("files");
                    if (extendsRaw.compileOnSave !== void 0) {
                        result.compileOnSave = extendsRaw.compileOnSave;
                    }
                    assign(result.options, extendedConfig.options);
                    result.watchOptions = result.watchOptions && extendedConfig.watchOptions ? assign({}, result.watchOptions, extendedConfig.watchOptions) : result.watchOptions || extendedConfig.watchOptions;
                }
            }
        }
        function parseOwnConfigOfJson(json, host, basePath, configFileName, errors) {
            if (hasProperty(json, "excludes")) {
                errors.push(createCompilerDiagnostic(Diagnostics.Unknown_option_excludes_Did_you_mean_exclude));
            }
            const options = convertCompilerOptionsFromJsonWorker(json.compilerOptions, basePath, errors, configFileName);
            const typeAcquisition = convertTypeAcquisitionFromJsonWorker(json.typeAcquisition, basePath, errors, configFileName);
            const watchOptions = convertWatchOptionsFromJsonWorker(json.watchOptions, basePath, errors);
            json.compileOnSave = convertCompileOnSaveOptionFromJson(json, basePath, errors);
            let extendedConfigPath;
            if (json.extends || json.extends === "") {
                if (!isCompilerOptionsValue(extendsOptionDeclaration, json.extends)) {
                    errors.push(createCompilerDiagnostic(Diagnostics.Compiler_option_0_requires_a_value_of_type_1, "extends", getCompilerOptionValueTypeString(extendsOptionDeclaration)));
                }
                else {
                    const newBase = configFileName ? directoryOfCombinedPath(configFileName, basePath) : basePath;
                    if (isString(json.extends)) {
                        extendedConfigPath = getExtendsConfigPath(json.extends, host, newBase, errors, createCompilerDiagnostic);
                    }
                    else {
                        extendedConfigPath = [];
                        for (const fileName of json.extends) {
                            if (isString(fileName)) {
                                extendedConfigPath = append(extendedConfigPath, getExtendsConfigPath(fileName, host, newBase, errors, createCompilerDiagnostic));
                            }
                            else {
                                errors.push(createCompilerDiagnostic(Diagnostics.Compiler_option_0_requires_a_value_of_type_1, "extends", getCompilerOptionValueTypeString(extendsOptionDeclaration.element)));
                            }
                        }
                    }
                }
            }
            return { raw: json, options, watchOptions, typeAcquisition, extendedConfigPath };
        }
        function parseOwnConfigOfJsonSourceFile(sourceFile, host, basePath, configFileName, errors) {
            const options = getDefaultCompilerOptions(configFileName);
            let typeAcquisition;
            let watchOptions;
            let extendedConfigPath;
            let rootCompilerOptions;
            const optionsIterator = {
                onSetValidOptionKeyValueInParent(parentOption, option, value) {
                    let currentOption;
                    switch (parentOption) {
                        case "compilerOptions":
                            currentOption = options;
                            break;
                        case "watchOptions":
                            currentOption = watchOptions || (watchOptions = {});
                            break;
                        case "typeAcquisition":
                            currentOption = typeAcquisition || (typeAcquisition = getDefaultTypeAcquisition(configFileName));
                            break;
                        default:
                            Debug.fail("Unknown option");
                    }
                    currentOption[option.name] = normalizeOptionValue(option, basePath, value);
                },
                onSetValidOptionKeyValueInRoot(key, _keyNode, value, valueNode) {
                    switch (key) {
                        case "extends":
                            const newBase = configFileName ? directoryOfCombinedPath(configFileName, basePath) : basePath;
                            if (isString(value)) {
                                extendedConfigPath = getExtendsConfigPath(value, host, newBase, errors, (message, arg0) => createDiagnosticForNodeInSourceFile(sourceFile, valueNode, message, arg0));
                            }
                            else {
                                extendedConfigPath = [];
                                for (let index = 0; index < value.length; index++) {
                                    const fileName = value[index];
                                    if (isString(fileName)) {
                                        extendedConfigPath = append(extendedConfigPath, getExtendsConfigPath(fileName, host, newBase, errors, (message, arg0) => createDiagnosticForNodeInSourceFile(sourceFile, valueNode.elements[index], message, arg0)));
                                    }
                                }
                            }
                            return;
                    }
                },
                onSetUnknownOptionKeyValueInRoot(key, keyNode, _value, _valueNode) {
                    if (key === "excludes") {
                        errors.push(createDiagnosticForNodeInSourceFile(sourceFile, keyNode, Diagnostics.Unknown_option_excludes_Did_you_mean_exclude));
                    }
                    if (find(commandOptionsWithoutBuild, (opt) => opt.name === key)) {
                        rootCompilerOptions = append(rootCompilerOptions, keyNode);
                    }
                }
            };
            const json = convertConfigFileToObject(sourceFile, errors, 
            /*reportOptionsErrors*/
            true, optionsIterator);
            if (!typeAcquisition) {
                typeAcquisition = getDefaultTypeAcquisition(configFileName);
            }
            if (rootCompilerOptions && json && json.compilerOptions === void 0) {
                errors.push(createDiagnosticForNodeInSourceFile(sourceFile, rootCompilerOptions[0], Diagnostics._0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file, getTextOfPropertyName(rootCompilerOptions[0])));
            }
            return { raw: json, options, watchOptions, typeAcquisition, extendedConfigPath };
        }
        function getExtendsConfigPath(extendedConfig, host, basePath, errors, createDiagnostic) {
            extendedConfig = normalizeSlashes(extendedConfig);
            if (isRootedDiskPath(extendedConfig) || startsWith(extendedConfig, "./") || startsWith(extendedConfig, "../")) {
                let extendedConfigPath = getNormalizedAbsolutePath(extendedConfig, basePath);
                if (!host.fileExists(extendedConfigPath) && !endsWith(extendedConfigPath, ".json" /* Json */)) {
                    extendedConfigPath = `${extendedConfigPath}.json`;
                    if (!host.fileExists(extendedConfigPath)) {
                        errors.push(createDiagnostic(Diagnostics.File_0_not_found, extendedConfig));
                        return void 0;
                    }
                }
                return extendedConfigPath;
            }
            const resolved = nodeNextJsonConfigResolver(extendedConfig, combinePaths(basePath, "tsconfig.json"), host);
            if (resolved.resolvedModule) {
                return resolved.resolvedModule.resolvedFileName;
            }
            if (extendedConfig === "") {
                errors.push(createDiagnostic(Diagnostics.Compiler_option_0_cannot_be_given_an_empty_string, "extends"));
            }
            else {
                errors.push(createDiagnostic(Diagnostics.File_0_not_found, extendedConfig));
            }
            return void 0;
        }
        function getExtendedConfig(sourceFile, extendedConfigPath, host, resolutionStack, errors, extendedConfigCache, result) {
            var _a2;
            const path = host.useCaseSensitiveFileNames ? extendedConfigPath : toFileNameLowerCase(extendedConfigPath);
            let value;
            let extendedResult;
            let extendedConfig;
            if (extendedConfigCache && (value = extendedConfigCache.get(path))) {
                ({ extendedResult, extendedConfig } = value);
            }
            else {
                extendedResult = readJsonConfigFile(extendedConfigPath, (path2) => host.readFile(path2));
                if (!extendedResult.parseDiagnostics.length) {
                    extendedConfig = parseConfig(
                    /*json*/
                    void 0, extendedResult, host, getDirectoryPath(extendedConfigPath), getBaseFileName(extendedConfigPath), resolutionStack, errors, extendedConfigCache);
                }
                if (extendedConfigCache) {
                    extendedConfigCache.set(path, { extendedResult, extendedConfig });
                }
            }
            if (sourceFile) {
                ((_a2 = result.extendedSourceFiles) != null ? _a2 : result.extendedSourceFiles = /* @__PURE__ */ new Set()).add(extendedResult.fileName);
                if (extendedResult.extendedSourceFiles) {
                    for (const extenedSourceFile of extendedResult.extendedSourceFiles) {
                        result.extendedSourceFiles.add(extenedSourceFile);
                    }
                }
            }
            if (extendedResult.parseDiagnostics.length) {
                errors.push(...extendedResult.parseDiagnostics);
                return void 0;
            }
            return extendedConfig;
        }
        function convertCompileOnSaveOptionFromJson(jsonOption, basePath, errors) {
            if (!hasProperty(jsonOption, compileOnSaveCommandLineOption.name)) {
                return false;
            }
            const result = convertJsonOption(compileOnSaveCommandLineOption, jsonOption.compileOnSave, basePath, errors);
            return typeof result === "boolean" && result;
        }
        function convertCompilerOptionsFromJson(jsonOptions, basePath, configFileName) {
            const errors = [];
            const options = convertCompilerOptionsFromJsonWorker(jsonOptions, basePath, errors, configFileName);
            return { options, errors };
        }
        function convertTypeAcquisitionFromJson(jsonOptions, basePath, configFileName) {
            const errors = [];
            const options = convertTypeAcquisitionFromJsonWorker(jsonOptions, basePath, errors, configFileName);
            return { options, errors };
        }
        function getDefaultCompilerOptions(configFileName) {
            const options = configFileName && getBaseFileName(configFileName) === "jsconfig.json" ? { allowJs: true, maxNodeModuleJsDepth: 2, allowSyntheticDefaultImports: true, skipLibCheck: true, noEmit: true } : {};
            return options;
        }
        function convertCompilerOptionsFromJsonWorker(jsonOptions, basePath, errors, configFileName) {
            const options = getDefaultCompilerOptions(configFileName);
            convertOptionsFromJson(getCommandLineCompilerOptionsMap(), jsonOptions, basePath, options, compilerOptionsDidYouMeanDiagnostics, errors);
            if (configFileName) {
                options.configFilePath = normalizeSlashes(configFileName);
            }
            return options;
        }
        function getDefaultTypeAcquisition(configFileName) {
            return { enable: !!configFileName && getBaseFileName(configFileName) === "jsconfig.json", include: [], exclude: [] };
        }
        function convertTypeAcquisitionFromJsonWorker(jsonOptions, basePath, errors, configFileName) {
            const options = getDefaultTypeAcquisition(configFileName);
            convertOptionsFromJson(getCommandLineTypeAcquisitionMap(), jsonOptions, basePath, options, typeAcquisitionDidYouMeanDiagnostics, errors);
            return options;
        }
        function convertWatchOptionsFromJsonWorker(jsonOptions, basePath, errors) {
            return convertOptionsFromJson(getCommandLineWatchOptionsMap(), jsonOptions, basePath, 
            /*defaultOptions*/
            void 0, watchOptionsDidYouMeanDiagnostics, errors);
        }
        function convertOptionsFromJson(optionsNameMap, jsonOptions, basePath, defaultOptions, diagnostics, errors) {
            if (!jsonOptions) {
                return;
            }
            for (const id in jsonOptions) {
                const opt = optionsNameMap.get(id);
                if (opt) {
                    (defaultOptions || (defaultOptions = {}))[opt.name] = convertJsonOption(opt, jsonOptions[id], basePath, errors);
                }
                else {
                    errors.push(createUnknownOptionError(id, diagnostics, createCompilerDiagnostic));
                }
            }
            return defaultOptions;
        }
        function convertJsonOption(opt, value, basePath, errors) {
            if (isCompilerOptionsValue(opt, value)) {
                const optType = opt.type;
                if (optType === "list" && isArray(value)) {
                    return convertJsonOptionOfListType(opt, value, basePath, errors);
                }
                else if (optType === "listOrElement") {
                    return isArray(value) ? convertJsonOptionOfListType(opt, value, basePath, errors) : convertJsonOption(opt.element, value, basePath, errors);
                }
                else if (!isString(opt.type)) {
                    return convertJsonOptionOfCustomType(opt, value, errors);
                }
                const validatedValue = validateJsonOptionValue(opt, value, errors);
                return isNullOrUndefined(validatedValue) ? validatedValue : normalizeNonListOptionValue(opt, basePath, validatedValue);
            }
            else {
                errors.push(createCompilerDiagnostic(Diagnostics.Compiler_option_0_requires_a_value_of_type_1, opt.name, getCompilerOptionValueTypeString(opt)));
            }
        }
        function normalizeOptionValue(option, basePath, value) {
            if (isNullOrUndefined(value))
                return void 0;
            if (option.type === "listOrElement" && !isArray(value))
                return normalizeOptionValue(option.element, basePath, value);
            else if (option.type === "list" || option.type === "listOrElement") {
                const listOption = option;
                if (listOption.element.isFilePath || !isString(listOption.element.type)) {
                    return filter(map(value, (v) => normalizeOptionValue(listOption.element, basePath, v)), (v) => listOption.listPreserveFalsyValues ? true : !!v);
                }
                return value;
            }
            else if (!isString(option.type)) {
                return option.type.get(isString(value) ? value.toLowerCase() : value);
            }
            return normalizeNonListOptionValue(option, basePath, value);
        }
        function normalizeNonListOptionValue(option, basePath, value) {
            if (option.isFilePath) {
                value = getNormalizedAbsolutePath(value, basePath);
                if (value === "") {
                    value = ".";
                }
            }
            return value;
        }
        function validateJsonOptionValue(opt, value, errors) {
            var _a2;
            if (isNullOrUndefined(value))
                return void 0;
            const d = (_a2 = opt.extraValidation) == null ? void 0 : _a2.call(opt, value);
            if (!d)
                return value;
            errors.push(createCompilerDiagnostic(...d));
            return void 0;
        }
        function convertJsonOptionOfCustomType(opt, value, errors) {
            if (isNullOrUndefined(value))
                return void 0;
            const key = value.toLowerCase();
            const val = opt.type.get(key);
            if (val !== void 0) {
                return validateJsonOptionValue(opt, val, errors);
            }
            else {
                errors.push(createCompilerDiagnosticForInvalidCustomType(opt));
            }
        }
        function convertJsonOptionOfListType(option, values, basePath, errors) {
            return filter(map(values, (v) => convertJsonOption(option.element, v, basePath, errors)), (v) => option.listPreserveFalsyValues ? true : !!v);
        }
        function getFileNamesFromConfigSpecs(configFileSpecs, basePath, options, host, extraFileExtensions = emptyArray) {
            basePath = normalizePath(basePath);
            const keyMapper = createGetCanonicalFileName(host.useCaseSensitiveFileNames);
            const literalFileMap = /* @__PURE__ */ new Map();
            const wildcardFileMap = /* @__PURE__ */ new Map();
            const wildCardJsonFileMap = /* @__PURE__ */ new Map();
            const { validatedFilesSpec, validatedIncludeSpecs, validatedExcludeSpecs } = configFileSpecs;
            const supportedExtensions = getSupportedExtensions(options, extraFileExtensions);
            const supportedExtensionsWithJsonIfResolveJsonModule = getSupportedExtensionsWithJsonIfResolveJsonModule(options, supportedExtensions);
            if (validatedFilesSpec) {
                for (const fileName of validatedFilesSpec) {
                    const file = getNormalizedAbsolutePath(fileName, basePath);
                    literalFileMap.set(keyMapper(file), file);
                }
            }
            let jsonOnlyIncludeRegexes;
            if (validatedIncludeSpecs && validatedIncludeSpecs.length > 0) {
                for (const file of host.readDirectory(basePath, flatten(supportedExtensionsWithJsonIfResolveJsonModule), validatedExcludeSpecs, validatedIncludeSpecs, 
                /*depth*/
                void 0)) {
                    if (fileExtensionIs(file, ".json" /* Json */)) {
                        if (!jsonOnlyIncludeRegexes) {
                            const includes = validatedIncludeSpecs.filter((s) => endsWith(s, ".json" /* Json */));
                            const includeFilePatterns = map(getRegularExpressionsForWildcards(includes, basePath, "files"), (pattern) => `^${pattern}$`);
                            jsonOnlyIncludeRegexes = includeFilePatterns ? includeFilePatterns.map((pattern) => getRegexFromPattern(pattern, host.useCaseSensitiveFileNames)) : emptyArray;
                        }
                        const includeIndex = findIndex(jsonOnlyIncludeRegexes, (re) => re.test(file));
                        if (includeIndex !== -1) {
                            const key2 = keyMapper(file);
                            if (!literalFileMap.has(key2) && !wildCardJsonFileMap.has(key2)) {
                                wildCardJsonFileMap.set(key2, file);
                            }
                        }
                        continue;
                    }
                    if (hasFileWithHigherPriorityExtension(file, literalFileMap, wildcardFileMap, supportedExtensions, keyMapper)) {
                        continue;
                    }
                    removeWildcardFilesWithLowerPriorityExtension(file, wildcardFileMap, supportedExtensions, keyMapper);
                    const key = keyMapper(file);
                    if (!literalFileMap.has(key) && !wildcardFileMap.has(key)) {
                        wildcardFileMap.set(key, file);
                    }
                }
            }
            const literalFiles = arrayFrom(literalFileMap.values());
            const wildcardFiles = arrayFrom(wildcardFileMap.values());
            return literalFiles.concat(wildcardFiles, arrayFrom(wildCardJsonFileMap.values()));
        }
        function isExcludedFile(pathToCheck, spec, basePath, useCaseSensitiveFileNames, currentDirectory) {
            const { validatedFilesSpec, validatedIncludeSpecs, validatedExcludeSpecs } = spec;
            if (!length(validatedIncludeSpecs) || !length(validatedExcludeSpecs))
                return false;
            basePath = normalizePath(basePath);
            const keyMapper = createGetCanonicalFileName(useCaseSensitiveFileNames);
            if (validatedFilesSpec) {
                for (const fileName of validatedFilesSpec) {
                    if (keyMapper(getNormalizedAbsolutePath(fileName, basePath)) === pathToCheck)
                        return false;
                }
            }
            return matchesExcludeWorker(pathToCheck, validatedExcludeSpecs, useCaseSensitiveFileNames, currentDirectory, basePath);
        }
        function invalidDotDotAfterRecursiveWildcard(s) {
            const wildcardIndex = startsWith(s, "**/") ? 0 : s.indexOf("/**/");
            if (wildcardIndex === -1) {
                return false;
            }
            const lastDotIndex = endsWith(s, "/..") ? s.length : s.lastIndexOf("/../");
            return lastDotIndex > wildcardIndex;
        }
        function matchesExclude(pathToCheck, excludeSpecs, useCaseSensitiveFileNames, currentDirectory) {
            return matchesExcludeWorker(pathToCheck, filter(excludeSpecs, (spec) => !invalidDotDotAfterRecursiveWildcard(spec)), useCaseSensitiveFileNames, currentDirectory);
        }
        function matchesExcludeWorker(pathToCheck, excludeSpecs, useCaseSensitiveFileNames, currentDirectory, basePath) {
            const excludePattern = getRegularExpressionForWildcard(excludeSpecs, combinePaths(normalizePath(currentDirectory), basePath), "exclude");
            const excludeRegex = excludePattern && getRegexFromPattern(excludePattern, useCaseSensitiveFileNames);
            if (!excludeRegex)
                return false;
            if (excludeRegex.test(pathToCheck))
                return true;
            return !hasExtension(pathToCheck) && excludeRegex.test(ensureTrailingDirectorySeparator(pathToCheck));
        }
        function validateSpecs(specs, errors, disallowTrailingRecursion, jsonSourceFile, specKey) {
            return specs.filter((spec) => {
                if (!isString(spec))
                    return false;
                const diag2 = specToDiagnostic(spec, disallowTrailingRecursion);
                if (diag2 !== void 0) {
                    errors.push(createDiagnostic(...diag2));
                }
                return diag2 === void 0;
            });
            function createDiagnostic(message, spec) {
                const element = getTsConfigPropArrayElementValue(jsonSourceFile, specKey, spec);
                return element ? createDiagnosticForNodeInSourceFile(jsonSourceFile, element, message, spec) : createCompilerDiagnostic(message, spec);
            }
        }
        function specToDiagnostic(spec, disallowTrailingRecursion) {
            Debug.assert(typeof spec === "string");
            if (disallowTrailingRecursion && invalidTrailingRecursionPattern.test(spec)) {
                return [Diagnostics.File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0, spec];
            }
            else if (invalidDotDotAfterRecursiveWildcard(spec)) {
                return [Diagnostics.File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0, spec];
            }
        }
        function getWildcardDirectories({ validatedIncludeSpecs: include, validatedExcludeSpecs: exclude }, path, useCaseSensitiveFileNames) {
            const rawExcludeRegex = getRegularExpressionForWildcard(exclude, path, "exclude");
            const excludeRegex = rawExcludeRegex && new RegExp(rawExcludeRegex, useCaseSensitiveFileNames ? "" : "i");
            const wildcardDirectories = {};
            if (include !== void 0) {
                const recursiveKeys = [];
                for (const file of include) {
                    const spec = normalizePath(combinePaths(path, file));
                    if (excludeRegex && excludeRegex.test(spec)) {
                        continue;
                    }
                    const match = getWildcardDirectoryFromSpec(spec, useCaseSensitiveFileNames);
                    if (match) {
                        const { key, flags } = match;
                        const existingFlags = wildcardDirectories[key];
                        if (existingFlags === void 0 || existingFlags < flags) {
                            wildcardDirectories[key] = flags;
                            if (flags === 1 /* Recursive */) {
                                recursiveKeys.push(key);
                            }
                        }
                    }
                }
                for (const key in wildcardDirectories) {
                    if (hasProperty(wildcardDirectories, key)) {
                        for (const recursiveKey of recursiveKeys) {
                            if (key !== recursiveKey && containsPath(recursiveKey, key, path, !useCaseSensitiveFileNames)) {
                                delete wildcardDirectories[key];
                            }
                        }
                    }
                }
            }
            return wildcardDirectories;
        }
        function getWildcardDirectoryFromSpec(spec, useCaseSensitiveFileNames) {
            const match = wildcardDirectoryPattern.exec(spec);
            if (match) {
                const questionWildcardIndex = spec.indexOf("?");
                const starWildcardIndex = spec.indexOf("*");
                const lastDirectorySeperatorIndex = spec.lastIndexOf(directorySeparator);
                return {
                    key: useCaseSensitiveFileNames ? match[0] : toFileNameLowerCase(match[0]),
                    flags: questionWildcardIndex !== -1 && questionWildcardIndex < lastDirectorySeperatorIndex || starWildcardIndex !== -1 && starWildcardIndex < lastDirectorySeperatorIndex ? 1 /* Recursive */ : 0 /* None */
                };
            }
            if (isImplicitGlob(spec.substring(spec.lastIndexOf(directorySeparator) + 1))) {
                return {
                    key: removeTrailingDirectorySeparator(useCaseSensitiveFileNames ? spec : toFileNameLowerCase(spec)),
                    flags: 1 /* Recursive */
                };
            }
            return void 0;
        }
        function hasFileWithHigherPriorityExtension(file, literalFiles, wildcardFiles, extensions, keyMapper) {
            const extensionGroup = forEach(extensions, (group2) => fileExtensionIsOneOf(file, group2) ? group2 : void 0);
            if (!extensionGroup) {
                return false;
            }
            for (const ext of extensionGroup) {
                if (fileExtensionIs(file, ext)) {
                    return false;
                }
                const higherPriorityPath = keyMapper(changeExtension(file, ext));
                if (literalFiles.has(higherPriorityPath) || wildcardFiles.has(higherPriorityPath)) {
                    if (ext === ".d.ts" /* Dts */ && (fileExtensionIs(file, ".js" /* Js */) || fileExtensionIs(file, ".jsx" /* Jsx */))) {
                        continue;
                    }
                    return true;
                }
            }
            return false;
        }
        function removeWildcardFilesWithLowerPriorityExtension(file, wildcardFiles, extensions, keyMapper) {
            const extensionGroup = forEach(extensions, (group2) => fileExtensionIsOneOf(file, group2) ? group2 : void 0);
            if (!extensionGroup) {
                return;
            }
            for (let i = extensionGroup.length - 1; i >= 0; i--) {
                const ext = extensionGroup[i];
                if (fileExtensionIs(file, ext)) {
                    return;
                }
                const lowerPriorityPath = keyMapper(changeExtension(file, ext));
                wildcardFiles.delete(lowerPriorityPath);
            }
        }
        function convertCompilerOptionsForTelemetry(opts) {
            const out = {};
            for (const key in opts) {
                if (hasProperty(opts, key)) {
                    const type = getOptionFromName(key);
                    if (type !== void 0) {
                        out[key] = getOptionValueWithEmptyStrings(opts[key], type);
                    }
                }
            }
            return out;
        }
        function getOptionValueWithEmptyStrings(value, option) {
            switch (option.type) {
                case "object":
                    return "";
                case "string":
                    return "";
                case "number":
                    return typeof value === "number" ? value : "";
                case "boolean":
                    return typeof value === "boolean" ? value : "";
                case "listOrElement":
                    if (!isArray(value))
                        return getOptionValueWithEmptyStrings(value, option.element);
                case "list":
                    const elementType = option.element;
                    return isArray(value) ? value.map((v) => getOptionValueWithEmptyStrings(v, elementType)) : "";
                default:
                    return forEachEntry(option.type, (optionEnumValue, optionStringValue) => {
                        if (optionEnumValue === value) {
                            return optionStringValue;
                        }
                    });
            }
        }
        function getDefaultValueForOption(option) {
            switch (option.type) {
                case "number":
                    return 1;
                case "boolean":
                    return true;
                case "string":
                    const defaultValue = option.defaultValueDescription;
                    return option.isFilePath ? `./${defaultValue && typeof defaultValue === "string" ? defaultValue : ""}` : "";
                case "list":
                    return [];
                case "listOrElement":
                    return getDefaultValueForOption(option.element);
                case "object":
                    return {};
                default:
                    const value = firstOrUndefinedIterator(option.type.keys());
                    if (value !== void 0)
                        return value;
                    return Debug.fail("Expected 'option.type' to have entries.");
            }
        }
        var compileOnSaveCommandLineOption, jsxOptionMap, inverseJsxOptionMap, libEntries, libs, libMap, optionsForWatch, commonOptionsWithBuild, targetOptionDeclaration, moduleOptionDeclaration, commandOptionsWithoutBuild, optionDeclarations, semanticDiagnosticsOptionDeclarations, affectsEmitOptionDeclarations, affectsDeclarationPathOptionDeclarations, moduleResolutionOptionDeclarations, sourceFileAffectingCompilerOptions, optionsAffectingProgramStructure, transpileOptionValueCompilerOptions, optionsForBuild, buildOpts, typeAcquisitionDeclarations, optionsNameMapCache, compilerOptionsAlternateMode, defaultInitCompilerOptions, compilerOptionsDidYouMeanDiagnostics, buildOptionsNameMapCache, buildOptionsAlternateMode, buildOptionsDidYouMeanDiagnostics, typeAcquisitionDidYouMeanDiagnostics, watchOptionsNameMapCache, watchOptionsDidYouMeanDiagnostics, commandLineCompilerOptionsMapCache, commandLineWatchOptionsMapCache, commandLineTypeAcquisitionMapCache, extendsOptionDeclaration, _tsconfigRootOptions, defaultIncludeSpec, invalidTrailingRecursionPattern, wildcardDirectoryPattern;
        var init_commandLineParser = __esm({
            "src/compiler/commandLineParser.ts"() {
                "use strict";
                init_ts2();
                compileOnSaveCommandLineOption = {
                    name: "compileOnSave",
                    type: "boolean",
                    defaultValueDescription: false
                };
                jsxOptionMap = new Map(Object.entries({
                    "preserve": 1 /* Preserve */,
                    "react-native": 3 /* ReactNative */,
                    "react": 2 /* React */,
                    "react-jsx": 4 /* ReactJSX */,
                    "react-jsxdev": 5 /* ReactJSXDev */
                }));
                inverseJsxOptionMap = new Map(mapIterator(jsxOptionMap.entries(), ([key, value]) => ["" + value, key]));
                libEntries = [
                    // JavaScript only
                    ["es5", "lib.es5.d.ts"],
                    ["es6", "lib.es2015.d.ts"],
                    ["es2015", "lib.es2015.d.ts"],
                    ["es7", "lib.es2016.d.ts"],
                    ["es2016", "lib.es2016.d.ts"],
                    ["es2017", "lib.es2017.d.ts"],
                    ["es2018", "lib.es2018.d.ts"],
                    ["es2019", "lib.es2019.d.ts"],
                    ["es2020", "lib.es2020.d.ts"],
                    ["es2021", "lib.es2021.d.ts"],
                    ["es2022", "lib.es2022.d.ts"],
                    ["es2023", "lib.es2023.d.ts"],
                    ["esnext", "lib.esnext.d.ts"],
                    // Host only
                    ["dom", "lib.dom.d.ts"],
                    ["dom.iterable", "lib.dom.iterable.d.ts"],
                    ["webworker", "lib.webworker.d.ts"],
                    ["webworker.importscripts", "lib.webworker.importscripts.d.ts"],
                    ["webworker.iterable", "lib.webworker.iterable.d.ts"],
                    ["scripthost", "lib.scripthost.d.ts"],
                    // ES2015 Or ESNext By-feature options
                    ["es2015.core", "lib.es2015.core.d.ts"],
                    ["es2015.collection", "lib.es2015.collection.d.ts"],
                    ["es2015.generator", "lib.es2015.generator.d.ts"],
                    ["es2015.iterable", "lib.es2015.iterable.d.ts"],
                    ["es2015.promise", "lib.es2015.promise.d.ts"],
                    ["es2015.proxy", "lib.es2015.proxy.d.ts"],
                    ["es2015.reflect", "lib.es2015.reflect.d.ts"],
                    ["es2015.symbol", "lib.es2015.symbol.d.ts"],
                    ["es2015.symbol.wellknown", "lib.es2015.symbol.wellknown.d.ts"],
                    ["es2016.array.include", "lib.es2016.array.include.d.ts"],
                    ["es2017.object", "lib.es2017.object.d.ts"],
                    ["es2017.sharedmemory", "lib.es2017.sharedmemory.d.ts"],
                    ["es2017.string", "lib.es2017.string.d.ts"],
                    ["es2017.intl", "lib.es2017.intl.d.ts"],
                    ["es2017.typedarrays", "lib.es2017.typedarrays.d.ts"],
                    ["es2018.asyncgenerator", "lib.es2018.asyncgenerator.d.ts"],
                    ["es2018.asynciterable", "lib.es2018.asynciterable.d.ts"],
                    ["es2018.intl", "lib.es2018.intl.d.ts"],
                    ["es2018.promise", "lib.es2018.promise.d.ts"],
                    ["es2018.regexp", "lib.es2018.regexp.d.ts"],
                    ["es2019.array", "lib.es2019.array.d.ts"],
                    ["es2019.object", "lib.es2019.object.d.ts"],
                    ["es2019.string", "lib.es2019.string.d.ts"],
                    ["es2019.symbol", "lib.es2019.symbol.d.ts"],
                    ["es2019.intl", "lib.es2019.intl.d.ts"],
                    ["es2020.bigint", "lib.es2020.bigint.d.ts"],
                    ["es2020.date", "lib.es2020.date.d.ts"],
                    ["es2020.promise", "lib.es2020.promise.d.ts"],
                    ["es2020.sharedmemory", "lib.es2020.sharedmemory.d.ts"],
                    ["es2020.string", "lib.es2020.string.d.ts"],
                    ["es2020.symbol.wellknown", "lib.es2020.symbol.wellknown.d.ts"],
                    ["es2020.intl", "lib.es2020.intl.d.ts"],
                    ["es2020.number", "lib.es2020.number.d.ts"],
                    ["es2021.promise", "lib.es2021.promise.d.ts"],
                    ["es2021.string", "lib.es2021.string.d.ts"],
                    ["es2021.weakref", "lib.es2021.weakref.d.ts"],
                    ["es2021.intl", "lib.es2021.intl.d.ts"],
                    ["es2022.array", "lib.es2022.array.d.ts"],
                    ["es2022.error", "lib.es2022.error.d.ts"],
                    ["es2022.intl", "lib.es2022.intl.d.ts"],
                    ["es2022.object", "lib.es2022.object.d.ts"],
                    ["es2022.sharedmemory", "lib.es2022.sharedmemory.d.ts"],
                    ["es2022.string", "lib.es2022.string.d.ts"],
                    ["es2022.regexp", "lib.es2022.regexp.d.ts"],
                    ["es2023.array", "lib.es2023.array.d.ts"],
                    ["esnext.array", "lib.es2023.array.d.ts"],
                    ["esnext.symbol", "lib.es2019.symbol.d.ts"],
                    ["esnext.asynciterable", "lib.es2018.asynciterable.d.ts"],
                    ["esnext.intl", "lib.esnext.intl.d.ts"],
                    ["esnext.bigint", "lib.es2020.bigint.d.ts"],
                    ["esnext.string", "lib.es2022.string.d.ts"],
                    ["esnext.promise", "lib.es2021.promise.d.ts"],
                    ["esnext.weakref", "lib.es2021.weakref.d.ts"],
                    ["decorators", "lib.decorators.d.ts"],
                    ["decorators.legacy", "lib.decorators.legacy.d.ts"]
                ];
                libs = libEntries.map((entry) => entry[0]);
                libMap = new Map(libEntries);
                optionsForWatch = [
                    {
                        name: "watchFile",
                        type: new Map(Object.entries({
                            fixedpollinginterval: 0 /* FixedPollingInterval */,
                            prioritypollinginterval: 1 /* PriorityPollingInterval */,
                            dynamicprioritypolling: 2 /* DynamicPriorityPolling */,
                            fixedchunksizepolling: 3 /* FixedChunkSizePolling */,
                            usefsevents: 4 /* UseFsEvents */,
                            usefseventsonparentdirectory: 5 /* UseFsEventsOnParentDirectory */
                        })),
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Specify_how_the_TypeScript_watch_mode_works,
                        defaultValueDescription: 4 /* UseFsEvents */
                    },
                    {
                        name: "watchDirectory",
                        type: new Map(Object.entries({
                            usefsevents: 0 /* UseFsEvents */,
                            fixedpollinginterval: 1 /* FixedPollingInterval */,
                            dynamicprioritypolling: 2 /* DynamicPriorityPolling */,
                            fixedchunksizepolling: 3 /* FixedChunkSizePolling */
                        })),
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality,
                        defaultValueDescription: 0 /* UseFsEvents */
                    },
                    {
                        name: "fallbackPolling",
                        type: new Map(Object.entries({
                            fixedinterval: 0 /* FixedInterval */,
                            priorityinterval: 1 /* PriorityInterval */,
                            dynamicpriority: 2 /* DynamicPriority */,
                            fixedchunksize: 3 /* FixedChunkSize */
                        })),
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers,
                        defaultValueDescription: 1 /* PriorityInterval */
                    },
                    {
                        name: "synchronousWatchDirectory",
                        type: "boolean",
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively,
                        defaultValueDescription: false
                    },
                    {
                        name: "excludeDirectories",
                        type: "list",
                        element: {
                            name: "excludeDirectory",
                            type: "string",
                            isFilePath: true,
                            extraValidation: specToDiagnostic
                        },
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Remove_a_list_of_directories_from_the_watch_process
                    },
                    {
                        name: "excludeFiles",
                        type: "list",
                        element: {
                            name: "excludeFile",
                            type: "string",
                            isFilePath: true,
                            extraValidation: specToDiagnostic
                        },
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Remove_a_list_of_files_from_the_watch_mode_s_processing
                    }
                ];
                commonOptionsWithBuild = [
                    {
                        name: "help",
                        shortName: "h",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        isCommandLineOnly: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Print_this_message,
                        defaultValueDescription: false
                    },
                    {
                        name: "help",
                        shortName: "?",
                        type: "boolean",
                        isCommandLineOnly: true,
                        category: Diagnostics.Command_line_Options,
                        defaultValueDescription: false
                    },
                    {
                        name: "watch",
                        shortName: "w",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        isCommandLineOnly: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Watch_input_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "preserveWatchOutput",
                        type: "boolean",
                        showInSimplifiedHelpView: false,
                        category: Diagnostics.Output_Formatting,
                        description: Diagnostics.Disable_wiping_the_console_in_watch_mode,
                        defaultValueDescription: false
                    },
                    {
                        name: "listFiles",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Print_all_of_the_files_read_during_the_compilation,
                        defaultValueDescription: false
                    },
                    {
                        name: "explainFiles",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Print_files_read_during_the_compilation_including_why_it_was_included,
                        defaultValueDescription: false
                    },
                    {
                        name: "listEmittedFiles",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Print_the_names_of_emitted_files_after_a_compilation,
                        defaultValueDescription: false
                    },
                    {
                        name: "pretty",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Output_Formatting,
                        description: Diagnostics.Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read,
                        defaultValueDescription: true
                    },
                    {
                        name: "traceResolution",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Log_paths_used_during_the_moduleResolution_process,
                        defaultValueDescription: false
                    },
                    {
                        name: "diagnostics",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Output_compiler_performance_information_after_building,
                        defaultValueDescription: false
                    },
                    {
                        name: "extendedDiagnostics",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Output_more_detailed_compiler_performance_information_after_building,
                        defaultValueDescription: false
                    },
                    {
                        name: "generateCpuProfile",
                        type: "string",
                        isFilePath: true,
                        paramType: Diagnostics.FILE_OR_DIRECTORY,
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging,
                        defaultValueDescription: "profile.cpuprofile"
                    },
                    {
                        name: "generateTrace",
                        type: "string",
                        isFilePath: true,
                        isCommandLineOnly: true,
                        paramType: Diagnostics.DIRECTORY,
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Generates_an_event_trace_and_a_list_of_types
                    },
                    {
                        name: "incremental",
                        shortName: "i",
                        type: "boolean",
                        category: Diagnostics.Projects,
                        description: Diagnostics.Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects,
                        transpileOptionValue: void 0,
                        defaultValueDescription: Diagnostics.false_unless_composite_is_set
                    },
                    {
                        name: "declaration",
                        shortName: "d",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        transpileOptionValue: void 0,
                        description: Diagnostics.Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project,
                        defaultValueDescription: Diagnostics.false_unless_composite_is_set
                    },
                    {
                        name: "declarationMap",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        transpileOptionValue: void 0,
                        defaultValueDescription: false,
                        description: Diagnostics.Create_sourcemaps_for_d_ts_files
                    },
                    {
                        name: "emitDeclarationOnly",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Only_output_d_ts_files_and_not_JavaScript_files,
                        transpileOptionValue: void 0,
                        defaultValueDescription: false
                    },
                    {
                        name: "sourceMap",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        defaultValueDescription: false,
                        description: Diagnostics.Create_source_map_files_for_emitted_JavaScript_files
                    },
                    {
                        name: "inlineSourceMap",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Include_sourcemap_files_inside_the_emitted_JavaScript,
                        defaultValueDescription: false
                    },
                    {
                        name: "assumeChangesOnlyAffectDirectDependencies",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it,
                        defaultValueDescription: false
                    },
                    {
                        name: "locale",
                        type: "string",
                        category: Diagnostics.Command_line_Options,
                        isCommandLineOnly: true,
                        description: Diagnostics.Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit,
                        defaultValueDescription: Diagnostics.Platform_specific
                    }
                ];
                targetOptionDeclaration = {
                    name: "target",
                    shortName: "t",
                    type: new Map(Object.entries({
                        es3: 0 /* ES3 */,
                        es5: 1 /* ES5 */,
                        es6: 2 /* ES2015 */,
                        es2015: 2 /* ES2015 */,
                        es2016: 3 /* ES2016 */,
                        es2017: 4 /* ES2017 */,
                        es2018: 5 /* ES2018 */,
                        es2019: 6 /* ES2019 */,
                        es2020: 7 /* ES2020 */,
                        es2021: 8 /* ES2021 */,
                        es2022: 9 /* ES2022 */,
                        esnext: 99 /* ESNext */
                    })),
                    affectsSourceFile: true,
                    affectsModuleResolution: true,
                    affectsEmit: true,
                    affectsBuildInfo: true,
                    paramType: Diagnostics.VERSION,
                    showInSimplifiedHelpView: true,
                    category: Diagnostics.Language_and_Environment,
                    description: Diagnostics.Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declarations,
                    defaultValueDescription: 1 /* ES5 */
                };
                moduleOptionDeclaration = {
                    name: "module",
                    shortName: "m",
                    type: new Map(Object.entries({
                        none: 0 /* None */,
                        commonjs: 1 /* CommonJS */,
                        amd: 2 /* AMD */,
                        system: 4 /* System */,
                        umd: 3 /* UMD */,
                        es6: 5 /* ES2015 */,
                        es2015: 5 /* ES2015 */,
                        es2020: 6 /* ES2020 */,
                        es2022: 7 /* ES2022 */,
                        esnext: 99 /* ESNext */,
                        node16: 100 /* Node16 */,
                        nodenext: 199 /* NodeNext */
                    })),
                    affectsModuleResolution: true,
                    affectsEmit: true,
                    affectsBuildInfo: true,
                    paramType: Diagnostics.KIND,
                    showInSimplifiedHelpView: true,
                    category: Diagnostics.Modules,
                    description: Diagnostics.Specify_what_module_code_is_generated,
                    defaultValueDescription: void 0
                };
                commandOptionsWithoutBuild = [
                    // CommandLine only options
                    {
                        name: "all",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Show_all_compiler_options,
                        defaultValueDescription: false
                    },
                    {
                        name: "version",
                        shortName: "v",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Print_the_compiler_s_version,
                        defaultValueDescription: false
                    },
                    {
                        name: "init",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file,
                        defaultValueDescription: false
                    },
                    {
                        name: "project",
                        shortName: "p",
                        type: "string",
                        isFilePath: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        paramType: Diagnostics.FILE_OR_DIRECTORY,
                        description: Diagnostics.Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json
                    },
                    {
                        name: "build",
                        type: "boolean",
                        shortName: "b",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Build_one_or_more_projects_and_their_dependencies_if_out_of_date,
                        defaultValueDescription: false
                    },
                    {
                        name: "showConfig",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        isCommandLineOnly: true,
                        description: Diagnostics.Print_the_final_configuration_instead_of_building,
                        defaultValueDescription: false
                    },
                    {
                        name: "listFilesOnly",
                        type: "boolean",
                        category: Diagnostics.Command_line_Options,
                        isCommandLineOnly: true,
                        description: Diagnostics.Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing,
                        defaultValueDescription: false
                    },
                    // Basic
                    targetOptionDeclaration,
                    moduleOptionDeclaration,
                    {
                        name: "lib",
                        type: "list",
                        element: {
                            name: "lib",
                            type: libMap,
                            defaultValueDescription: void 0
                        },
                        affectsProgramStructure: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment,
                        transpileOptionValue: void 0
                    },
                    {
                        name: "allowJs",
                        type: "boolean",
                        affectsModuleResolution: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.JavaScript_Support,
                        description: Diagnostics.Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJS_option_to_get_errors_from_these_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "checkJs",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.JavaScript_Support,
                        description: Diagnostics.Enable_error_reporting_in_type_checked_JavaScript_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "jsx",
                        type: jsxOptionMap,
                        affectsSourceFile: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsModuleResolution: true,
                        paramType: Diagnostics.KIND,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_what_JSX_code_is_generated,
                        defaultValueDescription: void 0
                    },
                    {
                        name: "outFile",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: true,
                        paramType: Diagnostics.FILE,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designates_a_file_that_bundles_all_d_ts_output,
                        transpileOptionValue: void 0
                    },
                    {
                        name: "outDir",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: true,
                        paramType: Diagnostics.DIRECTORY,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_an_output_folder_for_all_emitted_files
                    },
                    {
                        name: "rootDir",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: true,
                        paramType: Diagnostics.LOCATION,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_the_root_folder_within_your_source_files,
                        defaultValueDescription: Diagnostics.Computed_from_the_list_of_input_files
                    },
                    {
                        name: "composite",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        isTSConfigOnly: true,
                        category: Diagnostics.Projects,
                        transpileOptionValue: void 0,
                        defaultValueDescription: false,
                        description: Diagnostics.Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references
                    },
                    {
                        name: "tsBuildInfoFile",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        isFilePath: true,
                        paramType: Diagnostics.FILE,
                        category: Diagnostics.Projects,
                        transpileOptionValue: void 0,
                        defaultValueDescription: ".tsbuildinfo",
                        description: Diagnostics.Specify_the_path_to_tsbuildinfo_incremental_compilation_file
                    },
                    {
                        name: "removeComments",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        defaultValueDescription: false,
                        description: Diagnostics.Disable_emitting_comments
                    },
                    {
                        name: "noEmit",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Disable_emitting_files_from_a_compilation,
                        transpileOptionValue: void 0,
                        defaultValueDescription: false
                    },
                    {
                        name: "importHelpers",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file,
                        defaultValueDescription: false
                    },
                    {
                        name: "importsNotUsedAsValues",
                        type: new Map(Object.entries({
                            remove: 0 /* Remove */,
                            preserve: 1 /* Preserve */,
                            error: 2 /* Error */
                        })),
                        affectsEmit: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types,
                        defaultValueDescription: 0 /* Remove */
                    },
                    {
                        name: "downlevelIteration",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration,
                        defaultValueDescription: false
                    },
                    {
                        name: "isolatedModules",
                        type: "boolean",
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports,
                        transpileOptionValue: true,
                        defaultValueDescription: false
                    },
                    {
                        name: "verbatimModuleSyntax",
                        type: "boolean",
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Do_not_transform_or_elide_any_imports_or_exports_not_marked_as_type_only_ensuring_they_are_written_in_the_output_file_s_format_based_on_the_module_setting,
                        defaultValueDescription: false
                    },
                    // Strict Type Checks
                    {
                        name: "strict",
                        type: "boolean",
                        // Though this affects semantic diagnostics, affectsSemanticDiagnostics is not set here
                        // The value of each strictFlag depends on own strictFlag value or this and never accessed directly.
                        // But we need to store `strict` in builf info, even though it won't be examined directly, so that the
                        // flags it controls (e.g. `strictNullChecks`) will be retrieved correctly
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_all_strict_type_checking_options,
                        defaultValueDescription: false
                    },
                    {
                        name: "noImplicitAny",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "strictNullChecks",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.When_type_checking_take_into_account_null_and_undefined,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "strictFunctionTypes",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "strictBindCallApply",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "strictPropertyInitialization",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "noImplicitThis",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_when_this_is_given_the_type_any,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "useUnknownInCatchVariables",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Default_catch_clause_variables_as_unknown_instead_of_any,
                        defaultValueDescription: false
                    },
                    {
                        name: "alwaysStrict",
                        type: "boolean",
                        affectsSourceFile: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Ensure_use_strict_is_always_emitted,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    // Additional Checks
                    {
                        name: "noUnusedLocals",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_when_local_variables_aren_t_read,
                        defaultValueDescription: false
                    },
                    {
                        name: "noUnusedParameters",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Raise_an_error_when_a_function_parameter_isn_t_read,
                        defaultValueDescription: false
                    },
                    {
                        name: "exactOptionalPropertyTypes",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Interpret_optional_property_types_as_written_rather_than_adding_undefined,
                        defaultValueDescription: false
                    },
                    {
                        name: "noImplicitReturns",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function,
                        defaultValueDescription: false
                    },
                    {
                        name: "noFallthroughCasesInSwitch",
                        type: "boolean",
                        affectsBindDiagnostics: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_for_fallthrough_cases_in_switch_statements,
                        defaultValueDescription: false
                    },
                    {
                        name: "noUncheckedIndexedAccess",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Add_undefined_to_a_type_when_accessed_using_an_index,
                        defaultValueDescription: false
                    },
                    {
                        name: "noImplicitOverride",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier,
                        defaultValueDescription: false
                    },
                    {
                        name: "noPropertyAccessFromIndexSignature",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: false,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type,
                        defaultValueDescription: false
                    },
                    // Module Resolution
                    {
                        name: "moduleResolution",
                        type: new Map(Object.entries({
                            // N.B. The first entry specifies the value shown in `tsc --init`
                            node10: 2 /* Node10 */,
                            node: 2 /* Node10 */,
                            classic: 1 /* Classic */,
                            node16: 3 /* Node16 */,
                            nodenext: 99 /* NodeNext */,
                            bundler: 100 /* Bundler */
                        })),
                        deprecatedKeys: /* @__PURE__ */ new Set(["node"]),
                        affectsModuleResolution: true,
                        paramType: Diagnostics.STRATEGY,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier,
                        defaultValueDescription: Diagnostics.module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node
                    },
                    {
                        name: "baseUrl",
                        type: "string",
                        affectsModuleResolution: true,
                        isFilePath: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_the_base_directory_to_resolve_non_relative_module_names
                    },
                    {
                        // this option can only be specified in tsconfig.json
                        // use type = object to copy the value as-is
                        name: "paths",
                        type: "object",
                        affectsModuleResolution: true,
                        isTSConfigOnly: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations,
                        transpileOptionValue: void 0
                    },
                    {
                        // this option can only be specified in tsconfig.json
                        // use type = object to copy the value as-is
                        name: "rootDirs",
                        type: "list",
                        isTSConfigOnly: true,
                        element: {
                            name: "rootDirs",
                            type: "string",
                            isFilePath: true
                        },
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules,
                        transpileOptionValue: void 0,
                        defaultValueDescription: Diagnostics.Computed_from_the_list_of_input_files
                    },
                    {
                        name: "typeRoots",
                        type: "list",
                        element: {
                            name: "typeRoots",
                            type: "string",
                            isFilePath: true
                        },
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types
                    },
                    {
                        name: "types",
                        type: "list",
                        element: {
                            name: "types",
                            type: "string"
                        },
                        affectsProgramStructure: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file,
                        transpileOptionValue: void 0
                    },
                    {
                        name: "allowSyntheticDefaultImports",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export,
                        defaultValueDescription: Diagnostics.module_system_or_esModuleInterop
                    },
                    {
                        name: "esModuleInterop",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheticDefaultImports_for_type_compatibility,
                        defaultValueDescription: false
                    },
                    {
                        name: "preserveSymlinks",
                        type: "boolean",
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node,
                        defaultValueDescription: false
                    },
                    {
                        name: "allowUmdGlobalAccess",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Allow_accessing_UMD_globals_from_modules,
                        defaultValueDescription: false
                    },
                    {
                        name: "moduleSuffixes",
                        type: "list",
                        element: {
                            name: "suffix",
                            type: "string"
                        },
                        listPreserveFalsyValues: true,
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.List_of_file_name_suffixes_to_search_when_resolving_a_module
                    },
                    {
                        name: "allowImportingTsExtensions",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Allow_imports_to_include_TypeScript_file_extensions_Requires_moduleResolution_bundler_and_either_noEmit_or_emitDeclarationOnly_to_be_set,
                        defaultValueDescription: false,
                        transpileOptionValue: void 0
                    },
                    {
                        name: "resolvePackageJsonExports",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Use_the_package_json_exports_field_when_resolving_package_imports,
                        defaultValueDescription: Diagnostics.true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false
                    },
                    {
                        name: "resolvePackageJsonImports",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Use_the_package_json_imports_field_when_resolving_imports,
                        defaultValueDescription: Diagnostics.true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false
                    },
                    {
                        name: "customConditions",
                        type: "list",
                        element: {
                            name: "condition",
                            type: "string"
                        },
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Conditions_to_set_in_addition_to_the_resolver_specific_defaults_when_resolving_imports
                    },
                    // Source Maps
                    {
                        name: "sourceRoot",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        paramType: Diagnostics.LOCATION,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_the_root_path_for_debuggers_to_find_the_reference_source_code
                    },
                    {
                        name: "mapRoot",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        paramType: Diagnostics.LOCATION,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations
                    },
                    {
                        name: "inlineSources",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript,
                        defaultValueDescription: false
                    },
                    // Experimental
                    {
                        name: "experimentalDecorators",
                        type: "boolean",
                        affectsEmit: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Enable_experimental_support_for_legacy_experimental_decorators,
                        defaultValueDescription: false
                    },
                    {
                        name: "emitDecoratorMetadata",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Emit_design_type_metadata_for_decorated_declarations_in_source_files,
                        defaultValueDescription: false
                    },
                    // Advanced
                    {
                        name: "jsxFactory",
                        type: "string",
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h,
                        defaultValueDescription: "`React.createElement`"
                    },
                    {
                        name: "jsxFragmentFactory",
                        type: "string",
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragment_or_Fragment,
                        defaultValueDescription: "React.Fragment"
                    },
                    {
                        name: "jsxImportSource",
                        type: "string",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsModuleResolution: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Asterisk,
                        defaultValueDescription: "react"
                    },
                    {
                        name: "resolveJsonModule",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Enable_importing_json_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "allowArbitraryExtensions",
                        type: "boolean",
                        affectsProgramStructure: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Enable_importing_files_with_any_extension_provided_a_declaration_file_is_present,
                        defaultValueDescription: false
                    },
                    {
                        name: "out",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: false,
                        // This is intentionally broken to support compatability with existing tsconfig files
                        // for correct behaviour, please use outFile
                        category: Diagnostics.Backwards_Compatibility,
                        paramType: Diagnostics.FILE,
                        transpileOptionValue: void 0,
                        description: Diagnostics.Deprecated_setting_Use_outFile_instead
                    },
                    {
                        name: "reactNamespace",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit,
                        defaultValueDescription: "`React`"
                    },
                    {
                        name: "skipDefaultLibCheck",
                        type: "boolean",
                        // We need to store these to determine whether `lib` files need to be rechecked
                        affectsBuildInfo: true,
                        category: Diagnostics.Completeness,
                        description: Diagnostics.Skip_type_checking_d_ts_files_that_are_included_with_TypeScript,
                        defaultValueDescription: false
                    },
                    {
                        name: "charset",
                        type: "string",
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files,
                        defaultValueDescription: "utf8"
                    },
                    {
                        name: "emitBOM",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "newLine",
                        type: new Map(Object.entries({
                            crlf: 0 /* CarriageReturnLineFeed */,
                            lf: 1 /* LineFeed */
                        })),
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        paramType: Diagnostics.NEWLINE,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Set_the_newline_character_for_emitting_files,
                        defaultValueDescription: "lf"
                    },
                    {
                        name: "noErrorTruncation",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Output_Formatting,
                        description: Diagnostics.Disable_truncating_types_in_error_messages,
                        defaultValueDescription: false
                    },
                    {
                        name: "noLib",
                        type: "boolean",
                        category: Diagnostics.Language_and_Environment,
                        affectsProgramStructure: true,
                        description: Diagnostics.Disable_including_any_library_files_including_the_default_lib_d_ts,
                        // We are not returning a sourceFile for lib file when asked by the program,
                        // so pass --noLib to avoid reporting a file not found error.
                        transpileOptionValue: true,
                        defaultValueDescription: false
                    },
                    {
                        name: "noResolve",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add_to_a_project,
                        // We are not doing a full typecheck, we are not resolving the whole context,
                        // so pass --noResolve to avoid reporting missing file errors.
                        transpileOptionValue: true,
                        defaultValueDescription: false
                    },
                    {
                        name: "stripInternal",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments,
                        defaultValueDescription: false
                    },
                    {
                        name: "disableSizeLimit",
                        type: "boolean",
                        affectsProgramStructure: true,
                        category: Diagnostics.Editor_Support,
                        description: Diagnostics.Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server,
                        defaultValueDescription: false
                    },
                    {
                        name: "disableSourceOfProjectReferenceRedirect",
                        type: "boolean",
                        isTSConfigOnly: true,
                        category: Diagnostics.Projects,
                        description: Diagnostics.Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects,
                        defaultValueDescription: false
                    },
                    {
                        name: "disableSolutionSearching",
                        type: "boolean",
                        isTSConfigOnly: true,
                        category: Diagnostics.Projects,
                        description: Diagnostics.Opt_a_project_out_of_multi_project_reference_checking_when_editing,
                        defaultValueDescription: false
                    },
                    {
                        name: "disableReferencedProjectLoad",
                        type: "boolean",
                        isTSConfigOnly: true,
                        category: Diagnostics.Projects,
                        description: Diagnostics.Reduce_the_number_of_projects_loaded_automatically_by_TypeScript,
                        defaultValueDescription: false
                    },
                    {
                        name: "noImplicitUseStrict",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Disable_adding_use_strict_directives_in_emitted_JavaScript_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "noEmitHelpers",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Disable_generating_custom_helper_functions_like_extends_in_compiled_output,
                        defaultValueDescription: false
                    },
                    {
                        name: "noEmitOnError",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        transpileOptionValue: void 0,
                        description: Diagnostics.Disable_emitting_files_if_any_type_checking_errors_are_reported,
                        defaultValueDescription: false
                    },
                    {
                        name: "preserveConstEnums",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Disable_erasing_const_enum_declarations_in_generated_code,
                        defaultValueDescription: false
                    },
                    {
                        name: "declarationDir",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: true,
                        paramType: Diagnostics.DIRECTORY,
                        category: Diagnostics.Emit,
                        transpileOptionValue: void 0,
                        description: Diagnostics.Specify_the_output_directory_for_generated_declaration_files
                    },
                    {
                        name: "skipLibCheck",
                        type: "boolean",
                        // We need to store these to determine whether `lib` files need to be rechecked
                        affectsBuildInfo: true,
                        category: Diagnostics.Completeness,
                        description: Diagnostics.Skip_type_checking_all_d_ts_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "allowUnusedLabels",
                        type: "boolean",
                        affectsBindDiagnostics: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Disable_error_reporting_for_unused_labels,
                        defaultValueDescription: void 0
                    },
                    {
                        name: "allowUnreachableCode",
                        type: "boolean",
                        affectsBindDiagnostics: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Disable_error_reporting_for_unreachable_code,
                        defaultValueDescription: void 0
                    },
                    {
                        name: "suppressExcessPropertyErrors",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals,
                        defaultValueDescription: false
                    },
                    {
                        name: "suppressImplicitAnyIndexErrors",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures,
                        defaultValueDescription: false
                    },
                    {
                        name: "forceConsistentCasingInFileNames",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Ensure_that_casing_is_correct_in_imports,
                        defaultValueDescription: true
                    },
                    {
                        name: "maxNodeModuleJsDepth",
                        type: "number",
                        affectsModuleResolution: true,
                        category: Diagnostics.JavaScript_Support,
                        description: Diagnostics.Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicable_with_allowJs,
                        defaultValueDescription: 0
                    },
                    {
                        name: "noStrictGenericChecks",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Disable_strict_checking_of_generic_signatures_in_function_types,
                        defaultValueDescription: false
                    },
                    {
                        name: "useDefineForClassFields",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Emit_ECMAScript_standard_compliant_class_fields,
                        defaultValueDescription: Diagnostics.true_for_ES2022_and_above_including_ESNext
                    },
                    {
                        name: "preserveValueImports",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed,
                        defaultValueDescription: false
                    },
                    {
                        name: "keyofStringsOnly",
                        type: "boolean",
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option,
                        defaultValueDescription: false
                    },
                    {
                        // A list of plugins to load in the language service
                        name: "plugins",
                        type: "list",
                        isTSConfigOnly: true,
                        element: {
                            name: "plugin",
                            type: "object"
                        },
                        description: Diagnostics.Specify_a_list_of_language_service_plugins_to_include,
                        category: Diagnostics.Editor_Support
                    },
                    {
                        name: "moduleDetection",
                        type: new Map(Object.entries({
                            auto: 2 /* Auto */,
                            legacy: 1 /* Legacy */,
                            force: 3 /* Force */
                        })),
                        affectsModuleResolution: true,
                        description: Diagnostics.Control_what_method_is_used_to_detect_module_format_JS_files,
                        category: Diagnostics.Language_and_Environment,
                        defaultValueDescription: Diagnostics.auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_with_module_Colon_node16_as_modules
                    },
                    {
                        name: "ignoreDeprecations",
                        type: "string",
                        defaultValueDescription: void 0
                    }
                ];
                optionDeclarations = [
                    ...commonOptionsWithBuild,
                    ...commandOptionsWithoutBuild
                ];
                semanticDiagnosticsOptionDeclarations = optionDeclarations.filter((option) => !!option.affectsSemanticDiagnostics);
                affectsEmitOptionDeclarations = optionDeclarations.filter((option) => !!option.affectsEmit);
                affectsDeclarationPathOptionDeclarations = optionDeclarations.filter((option) => !!option.affectsDeclarationPath);
                moduleResolutionOptionDeclarations = optionDeclarations.filter((option) => !!option.affectsModuleResolution);
                sourceFileAffectingCompilerOptions = optionDeclarations.filter((option) => !!option.affectsSourceFile || !!option.affectsModuleResolution || !!option.affectsBindDiagnostics);
                optionsAffectingProgramStructure = optionDeclarations.filter((option) => !!option.affectsProgramStructure);
                transpileOptionValueCompilerOptions = optionDeclarations.filter((option) => hasProperty(option, "transpileOptionValue"));
                optionsForBuild = [
                    {
                        name: "verbose",
                        shortName: "v",
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Enable_verbose_logging,
                        type: "boolean",
                        defaultValueDescription: false
                    },
                    {
                        name: "dry",
                        shortName: "d",
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Show_what_would_be_built_or_deleted_if_specified_with_clean,
                        type: "boolean",
                        defaultValueDescription: false
                    },
                    {
                        name: "force",
                        shortName: "f",
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Build_all_projects_including_those_that_appear_to_be_up_to_date,
                        type: "boolean",
                        defaultValueDescription: false
                    },
                    {
                        name: "clean",
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Delete_the_outputs_of_all_projects,
                        type: "boolean",
                        defaultValueDescription: false
                    }
                ];
                buildOpts = [
                    ...commonOptionsWithBuild,
                    ...optionsForBuild
                ];
                typeAcquisitionDeclarations = [
                    {
                        name: "enable",
                        type: "boolean",
                        defaultValueDescription: false
                    },
                    {
                        name: "include",
                        type: "list",
                        element: {
                            name: "include",
                            type: "string"
                        }
                    },
                    {
                        name: "exclude",
                        type: "list",
                        element: {
                            name: "exclude",
                            type: "string"
                        }
                    },
                    {
                        name: "disableFilenameBasedTypeAcquisition",
                        type: "boolean",
                        defaultValueDescription: false
                    }
                ];
                compilerOptionsAlternateMode = {
                    diagnostic: Diagnostics.Compiler_option_0_may_only_be_used_with_build,
                    getOptionsNameMap: getBuildOptionsNameMap
                };
                defaultInitCompilerOptions = {
                    module: 1 /* CommonJS */,
                    target: 3 /* ES2016 */,
                    strict: true,
                    esModuleInterop: true,
                    forceConsistentCasingInFileNames: true,
                    skipLibCheck: true
                };
                compilerOptionsDidYouMeanDiagnostics = {
                    alternateMode: compilerOptionsAlternateMode,
                    getOptionsNameMap,
                    optionDeclarations,
                    unknownOptionDiagnostic: Diagnostics.Unknown_compiler_option_0,
                    unknownDidYouMeanDiagnostic: Diagnostics.Unknown_compiler_option_0_Did_you_mean_1,
                    optionTypeMismatchDiagnostic: Diagnostics.Compiler_option_0_expects_an_argument
                };
                buildOptionsAlternateMode = {
                    diagnostic: Diagnostics.Compiler_option_0_may_not_be_used_with_build,
                    getOptionsNameMap
                };
                buildOptionsDidYouMeanDiagnostics = {
                    alternateMode: buildOptionsAlternateMode,
                    getOptionsNameMap: getBuildOptionsNameMap,
                    optionDeclarations: buildOpts,
                    unknownOptionDiagnostic: Diagnostics.Unknown_build_option_0,
                    unknownDidYouMeanDiagnostic: Diagnostics.Unknown_build_option_0_Did_you_mean_1,
                    optionTypeMismatchDiagnostic: Diagnostics.Build_option_0_requires_a_value_of_type_1
                };
                typeAcquisitionDidYouMeanDiagnostics = {
                    optionDeclarations: typeAcquisitionDeclarations,
                    unknownOptionDiagnostic: Diagnostics.Unknown_type_acquisition_option_0,
                    unknownDidYouMeanDiagnostic: Diagnostics.Unknown_type_acquisition_option_0_Did_you_mean_1
                };
                watchOptionsDidYouMeanDiagnostics = {
                    getOptionsNameMap: getWatchOptionsNameMap,
                    optionDeclarations: optionsForWatch,
                    unknownOptionDiagnostic: Diagnostics.Unknown_watch_option_0,
                    unknownDidYouMeanDiagnostic: Diagnostics.Unknown_watch_option_0_Did_you_mean_1,
                    optionTypeMismatchDiagnostic: Diagnostics.Watch_option_0_requires_a_value_of_type_1
                };
                extendsOptionDeclaration = {
                    name: "extends",
                    type: "listOrElement",
                    element: {
                        name: "extends",
                        type: "string"
                    },
                    category: Diagnostics.File_Management
                };
                defaultIncludeSpec = "**/*";
                invalidTrailingRecursionPattern = /(^|\/)\*\*\/?$/;
                wildcardDirectoryPattern = /^[^*?]*(?=\/[^/]*[*?])/;
            }
        });
        // src/compiler/moduleNameResolver.ts
        function trace(host) {
            host.trace(formatMessage.apply(void 0, arguments));
        }
        function isTraceEnabled(compilerOptions, host) {
            return !!compilerOptions.traceResolution && host.trace !== void 0;
        }
        function withPackageId(packageInfo, r) {
            let packageId;
            if (r && packageInfo) {
                const packageJsonContent = packageInfo.contents.packageJsonContent;
                if (typeof packageJsonContent.name === "string" && typeof packageJsonContent.version === "string") {
                    packageId = {
                        name: packageJsonContent.name,
                        subModuleName: r.path.slice(packageInfo.packageDirectory.length + directorySeparator.length),
                        version: packageJsonContent.version
                    };
                }
            }
            return r && { path: r.path, extension: r.ext, packageId, resolvedUsingTsExtension: r.resolvedUsingTsExtension };
        }
        function noPackageId(r) {
            return withPackageId(
            /*packageInfo*/
            void 0, r);
        }
        function removeIgnoredPackageId(r) {
            if (r) {
                Debug.assert(r.packageId === void 0);
                return { path: r.path, ext: r.extension, resolvedUsingTsExtension: r.resolvedUsingTsExtension };
            }
        }
        function formatExtensions(extensions) {
            const result = [];
            if (extensions & 1 /* TypeScript */)
                result.push("TypeScript");
            if (extensions & 2 /* JavaScript */)
                result.push("JavaScript");
            if (extensions & 4 /* Declaration */)
                result.push("Declaration");
            if (extensions & 8 /* Json */)
                result.push("JSON");
            return result.join(", ");
        }
        function resolvedTypeScriptOnly(resolved) {
            if (!resolved) {
                return void 0;
            }
            Debug.assert(extensionIsTS(resolved.extension));
            return { fileName: resolved.path, packageId: resolved.packageId };
        }
        function createResolvedModuleWithFailedLookupLocationsHandlingSymlink(moduleName, resolved, isExternalLibraryImport, failedLookupLocations, affectingLocations, diagnostics, state, legacyResult) {
            if (!state.resultFromCache && !state.compilerOptions.preserveSymlinks && resolved && isExternalLibraryImport && !resolved.originalPath && !isExternalModuleNameRelative(moduleName)) {
                const { resolvedFileName, originalPath } = getOriginalAndResolvedFileName(resolved.path, state.host, state.traceEnabled);
                if (originalPath)
                    resolved = { ...resolved, path: resolvedFileName, originalPath };
            }
            return createResolvedModuleWithFailedLookupLocations(resolved, isExternalLibraryImport, failedLookupLocations, affectingLocations, diagnostics, state.resultFromCache, legacyResult);
        }
        function createResolvedModuleWithFailedLookupLocations(resolved, isExternalLibraryImport, failedLookupLocations, affectingLocations, diagnostics, resultFromCache, legacyResult) {
            if (resultFromCache) {
                resultFromCache.failedLookupLocations = updateResolutionField(resultFromCache.failedLookupLocations, failedLookupLocations);
                resultFromCache.affectingLocations = updateResolutionField(resultFromCache.affectingLocations, affectingLocations);
                resultFromCache.resolutionDiagnostics = updateResolutionField(resultFromCache.resolutionDiagnostics, diagnostics);
                return resultFromCache;
            }
            return {
                resolvedModule: resolved && {
                    resolvedFileName: resolved.path,
                    originalPath: resolved.originalPath === true ? void 0 : resolved.originalPath,
                    extension: resolved.extension,
                    isExternalLibraryImport,
                    packageId: resolved.packageId,
                    resolvedUsingTsExtension: !!resolved.resolvedUsingTsExtension
                },
                failedLookupLocations: initializeResolutionField(failedLookupLocations),
                affectingLocations: initializeResolutionField(affectingLocations),
                resolutionDiagnostics: initializeResolutionField(diagnostics),
                node10Result: legacyResult
            };
        }
        function initializeResolutionField(value) {
            return value.length ? value : void 0;
        }
        function updateResolutionField(to, value) {
            if (!(value == null ? void 0 : value.length))
                return to;
            if (!(to == null ? void 0 : to.length))
                return value;
            to.push(...value);
            return to;
        }
        function readPackageJsonField(jsonContent, fieldName, typeOfTag, state) {
            if (!hasProperty(jsonContent, fieldName)) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_does_not_have_a_0_field, fieldName);
                }
                return;
            }
            const value = jsonContent[fieldName];
            if (typeof value !== typeOfTag || value === null) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Expected_type_of_0_field_in_package_json_to_be_1_got_2, fieldName, typeOfTag, value === null ? "null" : typeof value);
                }
                return;
            }
            return value;
        }
        function readPackageJsonPathField(jsonContent, fieldName, baseDirectory, state) {
            const fileName = readPackageJsonField(jsonContent, fieldName, "string", state);
            if (fileName === void 0) {
                return;
            }
            if (!fileName) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_had_a_falsy_0_field, fieldName);
                }
                return;
            }
            const path = normalizePath(combinePaths(baseDirectory, fileName));
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.package_json_has_0_field_1_that_references_2, fieldName, fileName, path);
            }
            return path;
        }
        function readPackageJsonTypesFields(jsonContent, baseDirectory, state) {
            return readPackageJsonPathField(jsonContent, "typings", baseDirectory, state) || readPackageJsonPathField(jsonContent, "types", baseDirectory, state);
        }
        function readPackageJsonTSConfigField(jsonContent, baseDirectory, state) {
            return readPackageJsonPathField(jsonContent, "tsconfig", baseDirectory, state);
        }
        function readPackageJsonMainField(jsonContent, baseDirectory, state) {
            return readPackageJsonPathField(jsonContent, "main", baseDirectory, state);
        }
        function readPackageJsonTypesVersionsField(jsonContent, state) {
            const typesVersions = readPackageJsonField(jsonContent, "typesVersions", "object", state);
            if (typesVersions === void 0)
                return;
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.package_json_has_a_typesVersions_field_with_version_specific_path_mappings);
            }
            return typesVersions;
        }
        function readPackageJsonTypesVersionPaths(jsonContent, state) {
            const typesVersions = readPackageJsonTypesVersionsField(jsonContent, state);
            if (typesVersions === void 0)
                return;
            if (state.traceEnabled) {
                for (const key in typesVersions) {
                    if (hasProperty(typesVersions, key) && !VersionRange.tryParse(key)) {
                        trace(state.host, Diagnostics.package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range, key);
                    }
                }
            }
            const result = getPackageJsonTypesVersionsPaths(typesVersions);
            if (!result) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_does_not_have_a_typesVersions_entry_that_matches_version_0, versionMajorMinor);
                }
                return;
            }
            const { version: bestVersionKey, paths: bestVersionPaths } = result;
            if (typeof bestVersionPaths !== "object") {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Expected_type_of_0_field_in_package_json_to_be_1_got_2, `typesVersions['${bestVersionKey}']`, "object", typeof bestVersionPaths);
                }
                return;
            }
            return result;
        }
        function getPackageJsonTypesVersionsPaths(typesVersions) {
            if (!typeScriptVersion)
                typeScriptVersion = new Version(version);
            for (const key in typesVersions) {
                if (!hasProperty(typesVersions, key))
                    continue;
                const keyRange = VersionRange.tryParse(key);
                if (keyRange === void 0) {
                    continue;
                }
                if (keyRange.test(typeScriptVersion)) {
                    return { version: key, paths: typesVersions[key] };
                }
            }
        }
        function getEffectiveTypeRoots(options, host) {
            if (options.typeRoots) {
                return options.typeRoots;
            }
            let currentDirectory;
            if (options.configFilePath) {
                currentDirectory = getDirectoryPath(options.configFilePath);
            }
            else if (host.getCurrentDirectory) {
                currentDirectory = host.getCurrentDirectory();
            }
            if (currentDirectory !== void 0) {
                return getDefaultTypeRoots(currentDirectory, host);
            }
        }
        function getDefaultTypeRoots(currentDirectory, host) {
            if (!host.directoryExists) {
                return [combinePaths(currentDirectory, nodeModulesAtTypes)];
            }
            let typeRoots;
            forEachAncestorDirectory(normalizePath(currentDirectory), (directory) => {
                const atTypes = combinePaths(directory, nodeModulesAtTypes);
                if (host.directoryExists(atTypes)) {
                    (typeRoots || (typeRoots = [])).push(atTypes);
                }
                return void 0;
            });
            return typeRoots;
        }
        function arePathsEqual(path1, path2, host) {
            const useCaseSensitiveFileNames = typeof host.useCaseSensitiveFileNames === "function" ? host.useCaseSensitiveFileNames() : host.useCaseSensitiveFileNames;
            return comparePaths(path1, path2, !useCaseSensitiveFileNames) === 0 /* EqualTo */;
        }
        function getOriginalAndResolvedFileName(fileName, host, traceEnabled) {
            const resolvedFileName = realPath(fileName, host, traceEnabled);
            const pathsAreEqual = arePathsEqual(fileName, resolvedFileName, host);
            return {
                // If the fileName and realpath are differing only in casing prefer fileName so that we can issue correct errors for casing under forceConsistentCasingInFileNames
                resolvedFileName: pathsAreEqual ? fileName : resolvedFileName,
                originalPath: pathsAreEqual ? void 0 : fileName
            };
        }
        function resolveTypeReferenceDirective(typeReferenceDirectiveName, containingFile, options, host, redirectedReference, cache, resolutionMode) {
            Debug.assert(typeof typeReferenceDirectiveName === "string", "Non-string value passed to `ts.resolveTypeReferenceDirective`, likely by a wrapping package working with an outdated `resolveTypeReferenceDirectives` signature. This is probably not a problem in TS itself.");
            const traceEnabled = isTraceEnabled(options, host);
            if (redirectedReference) {
                options = redirectedReference.commandLine.options;
            }
            const containingDirectory = containingFile ? getDirectoryPath(containingFile) : void 0;
            let result = containingDirectory ? cache == null ? void 0 : cache.getFromDirectoryCache(typeReferenceDirectiveName, resolutionMode, containingDirectory, redirectedReference) : void 0;
            if (!result && containingDirectory && !isExternalModuleNameRelative(typeReferenceDirectiveName)) {
                result = cache == null ? void 0 : cache.getFromNonRelativeNameCache(typeReferenceDirectiveName, resolutionMode, containingDirectory, redirectedReference);
            }
            if (result) {
                if (traceEnabled) {
                    trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_1, typeReferenceDirectiveName, containingFile);
                    if (redirectedReference)
                        trace(host, Diagnostics.Using_compiler_options_of_project_reference_redirect_0, redirectedReference.sourceFile.fileName);
                    trace(host, Diagnostics.Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1, typeReferenceDirectiveName, containingDirectory);
                    traceResult(result);
                }
                return result;
            }
            const typeRoots = getEffectiveTypeRoots(options, host);
            if (traceEnabled) {
                if (containingFile === void 0) {
                    if (typeRoots === void 0) {
                        trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set, typeReferenceDirectiveName);
                    }
                    else {
                        trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1, typeReferenceDirectiveName, typeRoots);
                    }
                }
                else {
                    if (typeRoots === void 0) {
                        trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set, typeReferenceDirectiveName, containingFile);
                    }
                    else {
                        trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_1_root_directory_2, typeReferenceDirectiveName, containingFile, typeRoots);
                    }
                }
                if (redirectedReference) {
                    trace(host, Diagnostics.Using_compiler_options_of_project_reference_redirect_0, redirectedReference.sourceFile.fileName);
                }
            }
            const failedLookupLocations = [];
            const affectingLocations = [];
            let features = getNodeResolutionFeatures(options);
            if (resolutionMode === 99 /* ESNext */ && (getEmitModuleResolutionKind(options) === 3 /* Node16 */ || getEmitModuleResolutionKind(options) === 99 /* NodeNext */)) {
                features |= 32 /* EsmMode */;
            }
            const conditions = features & 8 /* Exports */ ? getConditions(options, !!(features & 32 /* EsmMode */)) : [];
            const diagnostics = [];
            const moduleResolutionState = {
                compilerOptions: options,
                host,
                traceEnabled,
                failedLookupLocations,
                affectingLocations,
                packageJsonInfoCache: cache,
                features,
                conditions,
                requestContainingDirectory: containingDirectory,
                reportDiagnostic: (diag2) => void diagnostics.push(diag2),
                isConfigLookup: false,
                candidateIsFromPackageJsonField: false
            };
            let resolved = primaryLookup();
            let primary = true;
            if (!resolved) {
                resolved = secondaryLookup();
                primary = false;
            }
            let resolvedTypeReferenceDirective;
            if (resolved) {
                const { fileName, packageId } = resolved;
                let resolvedFileName = fileName, originalPath;
                if (!options.preserveSymlinks)
                    ({ resolvedFileName, originalPath } = getOriginalAndResolvedFileName(fileName, host, traceEnabled));
                resolvedTypeReferenceDirective = {
                    primary,
                    resolvedFileName,
                    originalPath,
                    packageId,
                    isExternalLibraryImport: pathContainsNodeModules(fileName)
                };
            }
            result = {
                resolvedTypeReferenceDirective,
                failedLookupLocations: initializeResolutionField(failedLookupLocations),
                affectingLocations: initializeResolutionField(affectingLocations),
                resolutionDiagnostics: initializeResolutionField(diagnostics)
            };
            if (containingDirectory) {
                cache == null ? void 0 : cache.getOrCreateCacheForDirectory(containingDirectory, redirectedReference).set(typeReferenceDirectiveName, 
                /*mode*/
                resolutionMode, result);
                if (!isExternalModuleNameRelative(typeReferenceDirectiveName)) {
                    cache == null ? void 0 : cache.getOrCreateCacheForNonRelativeName(typeReferenceDirectiveName, resolutionMode, redirectedReference).set(containingDirectory, result);
                }
            }
            if (traceEnabled)
                traceResult(result);
            return result;
            function traceResult(result2) {
                var _a2;
                if (!((_a2 = result2.resolvedTypeReferenceDirective) == null ? void 0 : _a2.resolvedFileName)) {
                    trace(host, Diagnostics.Type_reference_directive_0_was_not_resolved, typeReferenceDirectiveName);
                }
                else if (result2.resolvedTypeReferenceDirective.packageId) {
                    trace(host, Diagnostics.Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3, typeReferenceDirectiveName, result2.resolvedTypeReferenceDirective.resolvedFileName, packageIdToString(result2.resolvedTypeReferenceDirective.packageId), result2.resolvedTypeReferenceDirective.primary);
                }
                else {
                    trace(host, Diagnostics.Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2, typeReferenceDirectiveName, result2.resolvedTypeReferenceDirective.resolvedFileName, result2.resolvedTypeReferenceDirective.primary);
                }
            }
            function primaryLookup() {
                if (typeRoots && typeRoots.length) {
                    if (traceEnabled) {
                        trace(host, Diagnostics.Resolving_with_primary_search_path_0, typeRoots.join(", "));
                    }
                    return firstDefined(typeRoots, (typeRoot) => {
                        const candidate = combinePaths(typeRoot, typeReferenceDirectiveName);
                        const candidateDirectory = getDirectoryPath(candidate);
                        const directoryExists = directoryProbablyExists(candidateDirectory, host);
                        if (!directoryExists && traceEnabled) {
                            trace(host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, candidateDirectory);
                        }
                        return resolvedTypeScriptOnly(loadNodeModuleFromDirectory(4 /* Declaration */, candidate, !directoryExists, moduleResolutionState));
                    });
                }
                else {
                    if (traceEnabled) {
                        trace(host, Diagnostics.Root_directory_cannot_be_determined_skipping_primary_search_paths);
                    }
                }
            }
            function secondaryLookup() {
                const initialLocationForSecondaryLookup = containingFile && getDirectoryPath(containingFile);
                if (initialLocationForSecondaryLookup !== void 0) {
                    if (traceEnabled) {
                        trace(host, Diagnostics.Looking_up_in_node_modules_folder_initial_location_0, initialLocationForSecondaryLookup);
                    }
                    let result2;
                    if (!isExternalModuleNameRelative(typeReferenceDirectiveName)) {
                        const searchResult = loadModuleFromNearestNodeModulesDirectory(4 /* Declaration */, typeReferenceDirectiveName, initialLocationForSecondaryLookup, moduleResolutionState, 
                        /*cache*/
                        void 0, 
                        /*redirectedReference*/
                        void 0);
                        result2 = searchResult && searchResult.value;
                    }
                    else {
                        const { path: candidate } = normalizePathForCJSResolution(initialLocationForSecondaryLookup, typeReferenceDirectiveName);
                        result2 = nodeLoadModuleByRelativeName(4 /* Declaration */, candidate, 
                        /*onlyRecordFailures*/
                        false, moduleResolutionState, 
                        /*considerPackageJson*/
                        true);
                    }
                    return resolvedTypeScriptOnly(result2);
                }
                else {
                    if (traceEnabled) {
                        trace(host, Diagnostics.Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_modules_folder);
                    }
                }
            }
        }
        function getNodeResolutionFeatures(options) {
            let features = 0 /* None */;
            switch (getEmitModuleResolutionKind(options)) {
                case 3 /* Node16 */:
                    features = 30 /* Node16Default */;
                    break;
                case 99 /* NodeNext */:
                    features = 30 /* NodeNextDefault */;
                    break;
                case 100 /* Bundler */:
                    features = 30 /* BundlerDefault */;
                    break;
            }
            if (options.resolvePackageJsonExports) {
                features |= 8 /* Exports */;
            }
            else if (options.resolvePackageJsonExports === false) {
                features &= ~8 /* Exports */;
            }
            if (options.resolvePackageJsonImports) {
                features |= 2 /* Imports */;
            }
            else if (options.resolvePackageJsonImports === false) {
                features &= ~2 /* Imports */;
            }
            return features;
        }
        function getConditions(options, esmMode) {
            const conditions = esmMode || getEmitModuleResolutionKind(options) === 100 /* Bundler */ ? ["import"] : ["require"];
            if (!options.noDtsResolution) {
                conditions.push("types");
            }
            if (getEmitModuleResolutionKind(options) !== 100 /* Bundler */) {
                conditions.push("node");
            }
            return concatenate(conditions, options.customConditions);
        }
        function resolvePackageNameToPackageJson(packageName, containingDirectory, options, host, cache) {
            const moduleResolutionState = getTemporaryModuleResolutionState(cache == null ? void 0 : cache.getPackageJsonInfoCache(), host, options);
            return forEachAncestorDirectory(containingDirectory, (ancestorDirectory) => {
                if (getBaseFileName(ancestorDirectory) !== "node_modules") {
                    const nodeModulesFolder = combinePaths(ancestorDirectory, "node_modules");
                    const candidate = combinePaths(nodeModulesFolder, packageName);
                    return getPackageJsonInfo(candidate, 
                    /*onlyRecordFailures*/
                    false, moduleResolutionState);
                }
            });
        }
        function getAutomaticTypeDirectiveNames(options, host) {
            if (options.types) {
                return options.types;
            }
            const result = [];
            if (host.directoryExists && host.getDirectories) {
                const typeRoots = getEffectiveTypeRoots(options, host);
                if (typeRoots) {
                    for (const root of typeRoots) {
                        if (host.directoryExists(root)) {
                            for (const typeDirectivePath of host.getDirectories(root)) {
                                const normalized = normalizePath(typeDirectivePath);
                                const packageJsonPath = combinePaths(root, normalized, "package.json");
                                const isNotNeededPackage = host.fileExists(packageJsonPath) && readJson(packageJsonPath, host).typings === null;
                                if (!isNotNeededPackage) {
                                    const baseFileName = getBaseFileName(normalized);
                                    if (baseFileName.charCodeAt(0) !== 46 /* dot */) {
                                        result.push(baseFileName);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            return result;
        }
        function compilerOptionValueToString(value) {
            var _a2;
            if (value === null || typeof value !== "object") {
                return "" + value;
            }
            if (isArray(value)) {
                return `[${(_a2 = value.map((e) => compilerOptionValueToString(e))) == null ? void 0 : _a2.join(",")}]`;
            }
            let str = "{";
            for (const key in value) {
                if (hasProperty(value, key)) {
                    str += `${key}: ${compilerOptionValueToString(value[key])}`;
                }
            }
            return str + "}";
        }
        function getKeyForCompilerOptions(options, affectingOptionDeclarations) {
            return affectingOptionDeclarations.map((option) => compilerOptionValueToString(getCompilerOptionValue(options, option))).join("|") + (options.pathsBasePath ? `|${options.pathsBasePath}` : void 0);
        }
        function createCacheWithRedirects(ownOptions) {
            const redirectsMap = /* @__PURE__ */ new Map();
            const optionsToRedirectsKey = /* @__PURE__ */ new Map();
            const redirectsKeyToMap = /* @__PURE__ */ new Map();
            let ownMap = /* @__PURE__ */ new Map();
            if (ownOptions)
                redirectsMap.set(ownOptions, ownMap);
            return {
                getMapOfCacheRedirects,
                getOrCreateMapOfCacheRedirects,
                update,
                clear: clear2
            };
            function getMapOfCacheRedirects(redirectedReference) {
                return redirectedReference ? getOrCreateMap(redirectedReference.commandLine.options, 
                /*create*/
                false) : ownMap;
            }
            function getOrCreateMapOfCacheRedirects(redirectedReference) {
                return redirectedReference ? getOrCreateMap(redirectedReference.commandLine.options, 
                /*create*/
                true) : ownMap;
            }
            function update(newOptions) {
                if (ownOptions !== newOptions) {
                    if (ownOptions)
                        ownMap = getOrCreateMap(newOptions, 
                        /*create*/
                        true);
                    else
                        redirectsMap.set(newOptions, ownMap);
                    ownOptions = newOptions;
                }
            }
            function getOrCreateMap(redirectOptions, create) {
                let result = redirectsMap.get(redirectOptions);
                if (result)
                    return result;
                const key = getRedirectsCacheKey(redirectOptions);
                result = redirectsKeyToMap.get(key);
                if (!result) {
                    if (ownOptions) {
                        const ownKey = getRedirectsCacheKey(ownOptions);
                        if (ownKey === key)
                            result = ownMap;
                        else if (!redirectsKeyToMap.has(ownKey))
                            redirectsKeyToMap.set(ownKey, ownMap);
                    }
                    if (create)
                        result != null ? result : result = /* @__PURE__ */ new Map();
                    if (result)
                        redirectsKeyToMap.set(key, result);
                }
                if (result)
                    redirectsMap.set(redirectOptions, result);
                return result;
            }
            function clear2() {
                const ownKey = ownOptions && optionsToRedirectsKey.get(ownOptions);
                ownMap.clear();
                redirectsMap.clear();
                optionsToRedirectsKey.clear();
                redirectsKeyToMap.clear();
                if (ownOptions) {
                    if (ownKey)
                        optionsToRedirectsKey.set(ownOptions, ownKey);
                    redirectsMap.set(ownOptions, ownMap);
                }
            }
            function getRedirectsCacheKey(options) {
                let result = optionsToRedirectsKey.get(options);
                if (!result) {
                    optionsToRedirectsKey.set(options, result = getKeyForCompilerOptions(options, moduleResolutionOptionDeclarations));
                }
                return result;
            }
        }
        function createPackageJsonInfoCache(currentDirectory, getCanonicalFileName) {
            let cache;
            return { getPackageJsonInfo: getPackageJsonInfo2, setPackageJsonInfo, clear: clear2, entries, getInternalMap };
            function getPackageJsonInfo2(packageJsonPath) {
                return cache == null ? void 0 : cache.get(toPath(packageJsonPath, currentDirectory, getCanonicalFileName));
            }
            function setPackageJsonInfo(packageJsonPath, info) {
                (cache || (cache = /* @__PURE__ */ new Map())).set(toPath(packageJsonPath, currentDirectory, getCanonicalFileName), info);
            }
            function clear2() {
                cache = void 0;
            }
            function entries() {
                const iter = cache == null ? void 0 : cache.entries();
                return iter ? arrayFrom(iter) : [];
            }
            function getInternalMap() {
                return cache;
            }
        }
        function getOrCreateCache(cacheWithRedirects, redirectedReference, key, create) {
            const cache = cacheWithRedirects.getOrCreateMapOfCacheRedirects(redirectedReference);
            let result = cache.get(key);
            if (!result) {
                result = create();
                cache.set(key, result);
            }
            return result;
        }
        function createPerDirectoryResolutionCache(currentDirectory, getCanonicalFileName, options) {
            const directoryToModuleNameMap = createCacheWithRedirects(options);
            return {
                getFromDirectoryCache,
                getOrCreateCacheForDirectory,
                clear: clear2,
                update
            };
            function clear2() {
                directoryToModuleNameMap.clear();
            }
            function update(options2) {
                directoryToModuleNameMap.update(options2);
            }
            function getOrCreateCacheForDirectory(directoryName, redirectedReference) {
                const path = toPath(directoryName, currentDirectory, getCanonicalFileName);
                return getOrCreateCache(directoryToModuleNameMap, redirectedReference, path, () => createModeAwareCache());
            }
            function getFromDirectoryCache(name, mode, directoryName, redirectedReference) {
                var _a2, _b;
                const path = toPath(directoryName, currentDirectory, getCanonicalFileName);
                return (_b = (_a2 = directoryToModuleNameMap.getMapOfCacheRedirects(redirectedReference)) == null ? void 0 : _a2.get(path)) == null ? void 0 : _b.get(name, mode);
            }
        }
        function createModeAwareCacheKey(specifier, mode) {
            return mode === void 0 ? specifier : `${mode}|${specifier}`;
        }
        function createModeAwareCache() {
            const underlying = /* @__PURE__ */ new Map();
            const memoizedReverseKeys = /* @__PURE__ */ new Map();
            const cache = {
                get(specifier, mode) {
                    return underlying.get(getUnderlyingCacheKey(specifier, mode));
                },
                set(specifier, mode, value) {
                    underlying.set(getUnderlyingCacheKey(specifier, mode), value);
                    return cache;
                },
                delete(specifier, mode) {
                    underlying.delete(getUnderlyingCacheKey(specifier, mode));
                    return cache;
                },
                has(specifier, mode) {
                    return underlying.has(getUnderlyingCacheKey(specifier, mode));
                },
                forEach(cb) {
                    return underlying.forEach((elem, key) => {
                        const [specifier, mode] = memoizedReverseKeys.get(key);
                        return cb(elem, specifier, mode);
                    });
                },
                size() {
                    return underlying.size;
                }
            };
            return cache;
            function getUnderlyingCacheKey(specifier, mode) {
                const result = createModeAwareCacheKey(specifier, mode);
                memoizedReverseKeys.set(result, [specifier, mode]);
                return result;
            }
        }
        function zipToModeAwareCache(file, keys, values, nameAndModeGetter) {
            Debug.assert(keys.length === values.length);
            const map2 = createModeAwareCache();
            for (let i = 0; i < keys.length; ++i) {
                const entry = keys[i];
                map2.set(nameAndModeGetter.getName(entry), nameAndModeGetter.getMode(entry, file), values[i]);
            }
            return map2;
        }
        function getOriginalOrResolvedModuleFileName(result) {
            return result.resolvedModule && (result.resolvedModule.originalPath || result.resolvedModule.resolvedFileName);
        }
        function getOriginalOrResolvedTypeReferenceFileName(result) {
            return result.resolvedTypeReferenceDirective && (result.resolvedTypeReferenceDirective.originalPath || result.resolvedTypeReferenceDirective.resolvedFileName);
        }
        function createNonRelativeNameResolutionCache(currentDirectory, getCanonicalFileName, options, getResolvedFileName) {
            const moduleNameToDirectoryMap = createCacheWithRedirects(options);
            return {
                getFromNonRelativeNameCache,
                getOrCreateCacheForNonRelativeName,
                clear: clear2,
                update
            };
            function clear2() {
                moduleNameToDirectoryMap.clear();
            }
            function update(options2) {
                moduleNameToDirectoryMap.update(options2);
            }
            function getFromNonRelativeNameCache(nonRelativeModuleName, mode, directoryName, redirectedReference) {
                var _a2, _b;
                Debug.assert(!isExternalModuleNameRelative(nonRelativeModuleName));
                return (_b = (_a2 = moduleNameToDirectoryMap.getMapOfCacheRedirects(redirectedReference)) == null ? void 0 : _a2.get(createModeAwareCacheKey(nonRelativeModuleName, mode))) == null ? void 0 : _b.get(directoryName);
            }
            function getOrCreateCacheForNonRelativeName(nonRelativeModuleName, mode, redirectedReference) {
                Debug.assert(!isExternalModuleNameRelative(nonRelativeModuleName));
                return getOrCreateCache(moduleNameToDirectoryMap, redirectedReference, createModeAwareCacheKey(nonRelativeModuleName, mode), createPerModuleNameCache);
            }
            function createPerModuleNameCache() {
                const directoryPathMap = /* @__PURE__ */ new Map();
                return { get, set };
                function get(directory) {
                    return directoryPathMap.get(toPath(directory, currentDirectory, getCanonicalFileName));
                }
                function set(directory, result) {
                    const path = toPath(directory, currentDirectory, getCanonicalFileName);
                    if (directoryPathMap.has(path)) {
                        return;
                    }
                    directoryPathMap.set(path, result);
                    const resolvedFileName = getResolvedFileName(result);
                    const commonPrefix = resolvedFileName && getCommonPrefix(path, resolvedFileName);
                    let current = path;
                    while (current !== commonPrefix) {
                        const parent2 = getDirectoryPath(current);
                        if (parent2 === current || directoryPathMap.has(parent2)) {
                            break;
                        }
                        directoryPathMap.set(parent2, result);
                        current = parent2;
                    }
                }
                function getCommonPrefix(directory, resolution) {
                    const resolutionDirectory = toPath(getDirectoryPath(resolution), currentDirectory, getCanonicalFileName);
                    let i = 0;
                    const limit = Math.min(directory.length, resolutionDirectory.length);
                    while (i < limit && directory.charCodeAt(i) === resolutionDirectory.charCodeAt(i)) {
                        i++;
                    }
                    if (i === directory.length && (resolutionDirectory.length === i || resolutionDirectory[i] === directorySeparator)) {
                        return directory;
                    }
                    const rootLength = getRootLength(directory);
                    if (i < rootLength) {
                        return void 0;
                    }
                    const sep = directory.lastIndexOf(directorySeparator, i - 1);
                    if (sep === -1) {
                        return void 0;
                    }
                    return directory.substr(0, Math.max(sep, rootLength));
                }
            }
        }
        function createModuleOrTypeReferenceResolutionCache(currentDirectory, getCanonicalFileName, options, packageJsonInfoCache, getResolvedFileName) {
            const perDirectoryResolutionCache = createPerDirectoryResolutionCache(currentDirectory, getCanonicalFileName, options);
            const nonRelativeNameResolutionCache = createNonRelativeNameResolutionCache(currentDirectory, getCanonicalFileName, options, getResolvedFileName);
            packageJsonInfoCache != null ? packageJsonInfoCache : packageJsonInfoCache = createPackageJsonInfoCache(currentDirectory, getCanonicalFileName);
            return {
                ...packageJsonInfoCache,
                ...perDirectoryResolutionCache,
                ...nonRelativeNameResolutionCache,
                clear: clear2,
                update,
                getPackageJsonInfoCache: () => packageJsonInfoCache,
                clearAllExceptPackageJsonInfoCache
            };
            function clear2() {
                clearAllExceptPackageJsonInfoCache();
                packageJsonInfoCache.clear();
            }
            function clearAllExceptPackageJsonInfoCache() {
                perDirectoryResolutionCache.clear();
                nonRelativeNameResolutionCache.clear();
            }
            function update(options2) {
                perDirectoryResolutionCache.update(options2);
                nonRelativeNameResolutionCache.update(options2);
            }
        }
        function createModuleResolutionCache(currentDirectory, getCanonicalFileName, options) {
            const result = createModuleOrTypeReferenceResolutionCache(currentDirectory, getCanonicalFileName, options, 
            /*packageJsonInfoCache*/
            void 0, getOriginalOrResolvedModuleFileName);
            result.getOrCreateCacheForModuleName = (nonRelativeName, mode, redirectedReference) => result.getOrCreateCacheForNonRelativeName(nonRelativeName, mode, redirectedReference);
            return result;
        }
        function createTypeReferenceDirectiveResolutionCache(currentDirectory, getCanonicalFileName, options, packageJsonInfoCache) {
            return createModuleOrTypeReferenceResolutionCache(currentDirectory, getCanonicalFileName, options, packageJsonInfoCache, getOriginalOrResolvedTypeReferenceFileName);
        }
        function resolveModuleNameFromCache(moduleName, containingFile, cache, mode) {
            const containingDirectory = getDirectoryPath(containingFile);
            return cache.getFromDirectoryCache(moduleName, mode, containingDirectory, 
            /*redirectedReference*/
            void 0);
        }
        function resolveModuleName(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode) {
            const traceEnabled = isTraceEnabled(compilerOptions, host);
            if (redirectedReference) {
                compilerOptions = redirectedReference.commandLine.options;
            }
            if (traceEnabled) {
                trace(host, Diagnostics.Resolving_module_0_from_1, moduleName, containingFile);
                if (redirectedReference) {
                    trace(host, Diagnostics.Using_compiler_options_of_project_reference_redirect_0, redirectedReference.sourceFile.fileName);
                }
            }
            const containingDirectory = getDirectoryPath(containingFile);
            let result = cache == null ? void 0 : cache.getFromDirectoryCache(moduleName, resolutionMode, containingDirectory, redirectedReference);
            if (result) {
                if (traceEnabled) {
                    trace(host, Diagnostics.Resolution_for_module_0_was_found_in_cache_from_location_1, moduleName, containingDirectory);
                }
            }
            else {
                let moduleResolution = compilerOptions.moduleResolution;
                if (moduleResolution === void 0) {
                    switch (getEmitModuleKind(compilerOptions)) {
                        case 1 /* CommonJS */:
                            moduleResolution = 2 /* Node10 */;
                            break;
                        case 100 /* Node16 */:
                            moduleResolution = 3 /* Node16 */;
                            break;
                        case 199 /* NodeNext */:
                            moduleResolution = 99 /* NodeNext */;
                            break;
                        default:
                            moduleResolution = 1 /* Classic */;
                            break;
                    }
                    if (traceEnabled) {
                        trace(host, Diagnostics.Module_resolution_kind_is_not_specified_using_0, ModuleResolutionKind[moduleResolution]);
                    }
                }
                else {
                    if (traceEnabled) {
                        trace(host, Diagnostics.Explicitly_specified_module_resolution_kind_Colon_0, ModuleResolutionKind[moduleResolution]);
                    }
                }
                perfLogger.logStartResolveModule(moduleName
                /* , containingFile, ModuleResolutionKind[moduleResolution]*/
                );
                switch (moduleResolution) {
                    case 3 /* Node16 */:
                        result = node16ModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode);
                        break;
                    case 99 /* NodeNext */:
                        result = nodeNextModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode);
                        break;
                    case 2 /* Node10 */:
                        result = nodeModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference);
                        break;
                    case 1 /* Classic */:
                        result = classicNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference);
                        break;
                    case 100 /* Bundler */:
                        result = bundlerModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference);
                        break;
                    default:
                        return Debug.fail(`Unexpected moduleResolution: ${moduleResolution}`);
                }
                if (result && result.resolvedModule)
                    perfLogger.logInfoEvent(`Module "${moduleName}" resolved to "${result.resolvedModule.resolvedFileName}"`);
                perfLogger.logStopResolveModule(result && result.resolvedModule ? "" + result.resolvedModule.resolvedFileName : "null");
                cache == null ? void 0 : cache.getOrCreateCacheForDirectory(containingDirectory, redirectedReference).set(moduleName, resolutionMode, result);
                if (!isExternalModuleNameRelative(moduleName)) {
                    cache == null ? void 0 : cache.getOrCreateCacheForNonRelativeName(moduleName, resolutionMode, redirectedReference).set(containingDirectory, result);
                }
            }
            if (traceEnabled) {
                if (result.resolvedModule) {
                    if (result.resolvedModule.packageId) {
                        trace(host, Diagnostics.Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2, moduleName, result.resolvedModule.resolvedFileName, packageIdToString(result.resolvedModule.packageId));
                    }
                    else {
                        trace(host, Diagnostics.Module_name_0_was_successfully_resolved_to_1, moduleName, result.resolvedModule.resolvedFileName);
                    }
                }
                else {
                    trace(host, Diagnostics.Module_name_0_was_not_resolved, moduleName);
                }
            }
            return result;
        }
        function tryLoadModuleUsingOptionalResolutionSettings(extensions, moduleName, containingDirectory, loader, state) {
            const resolved = tryLoadModuleUsingPathsIfEligible(extensions, moduleName, loader, state);
            if (resolved)
                return resolved.value;
            if (!isExternalModuleNameRelative(moduleName)) {
                return tryLoadModuleUsingBaseUrl(extensions, moduleName, loader, state);
            }
            else {
                return tryLoadModuleUsingRootDirs(extensions, moduleName, containingDirectory, loader, state);
            }
        }
        function tryLoadModuleUsingPathsIfEligible(extensions, moduleName, loader, state) {
            var _a2;
            const { baseUrl, paths, configFile } = state.compilerOptions;
            if (paths && !pathIsRelative(moduleName)) {
                if (state.traceEnabled) {
                    if (baseUrl) {
                        trace(state.host, Diagnostics.baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1, baseUrl, moduleName);
                    }
                    trace(state.host, Diagnostics.paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0, moduleName);
                }
                const baseDirectory = getPathsBasePath(state.compilerOptions, state.host);
                const pathPatterns = (configFile == null ? void 0 : configFile.configFileSpecs) ? (_a2 = configFile.configFileSpecs).pathPatterns || (_a2.pathPatterns = tryParsePatterns(paths)) : void 0;
                return tryLoadModuleUsingPaths(extensions, moduleName, baseDirectory, paths, pathPatterns, loader, 
                /*onlyRecordFailures*/
                false, state);
            }
        }
        function tryLoadModuleUsingRootDirs(extensions, moduleName, containingDirectory, loader, state) {
            if (!state.compilerOptions.rootDirs) {
                return void 0;
            }
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0, moduleName);
            }
            const candidate = normalizePath(combinePaths(containingDirectory, moduleName));
            let matchedRootDir;
            let matchedNormalizedPrefix;
            for (const rootDir of state.compilerOptions.rootDirs) {
                let normalizedRoot = normalizePath(rootDir);
                if (!endsWith(normalizedRoot, directorySeparator)) {
                    normalizedRoot += directorySeparator;
                }
                const isLongestMatchingPrefix = startsWith(candidate, normalizedRoot) && (matchedNormalizedPrefix === void 0 || matchedNormalizedPrefix.length < normalizedRoot.length);
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Checking_if_0_is_the_longest_matching_prefix_for_1_2, normalizedRoot, candidate, isLongestMatchingPrefix);
                }
                if (isLongestMatchingPrefix) {
                    matchedNormalizedPrefix = normalizedRoot;
                    matchedRootDir = rootDir;
                }
            }
            if (matchedNormalizedPrefix) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Longest_matching_prefix_for_0_is_1, candidate, matchedNormalizedPrefix);
                }
                const suffix = candidate.substr(matchedNormalizedPrefix.length);
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Loading_0_from_the_root_dir_1_candidate_location_2, suffix, matchedNormalizedPrefix, candidate);
                }
                const resolvedFileName = loader(extensions, candidate, !directoryProbablyExists(containingDirectory, state.host), state);
                if (resolvedFileName) {
                    return resolvedFileName;
                }
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Trying_other_entries_in_rootDirs);
                }
                for (const rootDir of state.compilerOptions.rootDirs) {
                    if (rootDir === matchedRootDir) {
                        continue;
                    }
                    const candidate2 = combinePaths(normalizePath(rootDir), suffix);
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Loading_0_from_the_root_dir_1_candidate_location_2, suffix, rootDir, candidate2);
                    }
                    const baseDirectory = getDirectoryPath(candidate2);
                    const resolvedFileName2 = loader(extensions, candidate2, !directoryProbablyExists(baseDirectory, state.host), state);
                    if (resolvedFileName2) {
                        return resolvedFileName2;
                    }
                }
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Module_resolution_using_rootDirs_has_failed);
                }
            }
            return void 0;
        }
        function tryLoadModuleUsingBaseUrl(extensions, moduleName, loader, state) {
            const { baseUrl } = state.compilerOptions;
            if (!baseUrl) {
                return void 0;
            }
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1, baseUrl, moduleName);
            }
            const candidate = normalizePath(combinePaths(baseUrl, moduleName));
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.Resolving_module_name_0_relative_to_base_url_1_2, moduleName, baseUrl, candidate);
            }
            return loader(extensions, candidate, !directoryProbablyExists(getDirectoryPath(candidate), state.host), state);
        }
        function resolveJSModule(moduleName, initialDir, host) {
            const { resolvedModule, failedLookupLocations } = tryResolveJSModuleWorker(moduleName, initialDir, host);
            if (!resolvedModule) {
                throw new Error(`Could not resolve JS module '${moduleName}' starting at '${initialDir}'. Looked in: ${failedLookupLocations == null ? void 0 : failedLookupLocations.join(", ")}`);
            }
            return resolvedModule.resolvedFileName;
        }
        function node16ModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode) {
            return nodeNextModuleNameResolverWorker(30 /* Node16Default */, moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode);
        }
        function nodeNextModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode) {
            return nodeNextModuleNameResolverWorker(30 /* NodeNextDefault */, moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode);
        }
        function nodeNextModuleNameResolverWorker(features, moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode) {
            const containingDirectory = getDirectoryPath(containingFile);
            const esmMode = resolutionMode === 99 /* ESNext */ ? 32 /* EsmMode */ : 0;
            let extensions = compilerOptions.noDtsResolution ? 3 /* ImplementationFiles */ : 1 /* TypeScript */ | 2 /* JavaScript */ | 4 /* Declaration */;
            if (getResolveJsonModule(compilerOptions)) {
                extensions |= 8 /* Json */;
            }
            return nodeModuleNameResolverWorker(features | esmMode, moduleName, containingDirectory, compilerOptions, host, cache, extensions, 
            /*isConfigLookup*/
            false, redirectedReference);
        }
        function tryResolveJSModuleWorker(moduleName, initialDir, host) {
            return nodeModuleNameResolverWorker(0 /* None */, moduleName, initialDir, { moduleResolution: 2 /* Node10 */, allowJs: true }, host, 
            /*cache*/
            void 0, 2 /* JavaScript */, 
            /*isConfigLookup*/
            false, 
            /*redirectedReferences*/
            void 0);
        }
        function bundlerModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference) {
            const containingDirectory = getDirectoryPath(containingFile);
            let extensions = compilerOptions.noDtsResolution ? 3 /* ImplementationFiles */ : 1 /* TypeScript */ | 2 /* JavaScript */ | 4 /* Declaration */;
            if (getResolveJsonModule(compilerOptions)) {
                extensions |= 8 /* Json */;
            }
            return nodeModuleNameResolverWorker(getNodeResolutionFeatures(compilerOptions), moduleName, containingDirectory, compilerOptions, host, cache, extensions, 
            /*isConfigLookup*/
            false, redirectedReference);
        }
        function nodeModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, isConfigLookup) {
            let extensions;
            if (isConfigLookup) {
                extensions = 8 /* Json */;
            }
            else if (compilerOptions.noDtsResolution) {
                extensions = 3 /* ImplementationFiles */;
                if (getResolveJsonModule(compilerOptions))
                    extensions |= 8 /* Json */;
            }
            else {
                extensions = getResolveJsonModule(compilerOptions) ? 1 /* TypeScript */ | 2 /* JavaScript */ | 4 /* Declaration */ | 8 /* Json */ : 1 /* TypeScript */ | 2 /* JavaScript */ | 4 /* Declaration */;
            }
            return nodeModuleNameResolverWorker(0 /* None */, moduleName, getDirectoryPath(containingFile), compilerOptions, host, cache, extensions, !!isConfigLookup, redirectedReference);
        }
        function nodeNextJsonConfigResolver(moduleName, containingFile, host) {
            return nodeModuleNameResolverWorker(30 /* NodeNextDefault */, moduleName, getDirectoryPath(containingFile), { moduleResolution: 99 /* NodeNext */ }, host, 
            /*cache*/
            void 0, 8 /* Json */, 
            /*isConfigLookup*/
            true, 
            /*redirectedReference*/
            void 0);
        }
        function nodeModuleNameResolverWorker(features, moduleName, containingDirectory, compilerOptions, host, cache, extensions, isConfigLookup, redirectedReference) {
            var _a2, _b, _c, _d;
            const traceEnabled = isTraceEnabled(compilerOptions, host);
            const failedLookupLocations = [];
            const affectingLocations = [];
            const conditions = getConditions(compilerOptions, !!(features & 32 /* EsmMode */));
            const diagnostics = [];
            const state = {
                compilerOptions,
                host,
                traceEnabled,
                failedLookupLocations,
                affectingLocations,
                packageJsonInfoCache: cache,
                features,
                conditions,
                requestContainingDirectory: containingDirectory,
                reportDiagnostic: (diag2) => void diagnostics.push(diag2),
                isConfigLookup,
                candidateIsFromPackageJsonField: false
            };
            if (traceEnabled && moduleResolutionSupportsPackageJsonExportsAndImports(getEmitModuleResolutionKind(compilerOptions))) {
                trace(host, Diagnostics.Resolving_in_0_mode_with_conditions_1, features & 32 /* EsmMode */ ? "ESM" : "CJS", conditions.map((c) => `'${c}'`).join(", "));
            }
            let result;
            if (getEmitModuleResolutionKind(compilerOptions) === 2 /* Node10 */) {
                const priorityExtensions = extensions & (1 /* TypeScript */ | 4 /* Declaration */);
                const secondaryExtensions = extensions & ~(1 /* TypeScript */ | 4 /* Declaration */);
                result = priorityExtensions && tryResolve(priorityExtensions, state) || secondaryExtensions && tryResolve(secondaryExtensions, state) || void 0;
            }
            else {
                result = tryResolve(extensions, state);
            }
            let legacyResult;
            if (((_a2 = result == null ? void 0 : result.value) == null ? void 0 : _a2.isExternalLibraryImport) && !isConfigLookup && extensions & (1 /* TypeScript */ | 4 /* Declaration */) && features & 8 /* Exports */ && !isExternalModuleNameRelative(moduleName) && !extensionIsOk(1 /* TypeScript */ | 4 /* Declaration */, result.value.resolved.extension) && conditions.indexOf("import") > -1) {
                traceIfEnabled(state, Diagnostics.Resolution_of_non_relative_name_failed_trying_with_modern_Node_resolution_features_disabled_to_see_if_npm_library_needs_configuration_update);
                const diagnosticState = {
                    ...state,
                    features: state.features & ~8 /* Exports */,
                    failedLookupLocations: [],
                    affectingLocations: [],
                    reportDiagnostic: noop
                };
                const diagnosticResult = tryResolve(extensions & (1 /* TypeScript */ | 4 /* Declaration */), diagnosticState);
                if ((_b = diagnosticResult == null ? void 0 : diagnosticResult.value) == null ? void 0 : _b.isExternalLibraryImport) {
                    legacyResult = diagnosticResult.value.resolved.path;
                }
            }
            return createResolvedModuleWithFailedLookupLocationsHandlingSymlink(moduleName, (_c = result == null ? void 0 : result.value) == null ? void 0 : _c.resolved, (_d = result == null ? void 0 : result.value) == null ? void 0 : _d.isExternalLibraryImport, failedLookupLocations, affectingLocations, diagnostics, state, legacyResult);
            function tryResolve(extensions2, state2) {
                const loader = (extensions3, candidate, onlyRecordFailures, state3) => nodeLoadModuleByRelativeName(extensions3, candidate, onlyRecordFailures, state3, 
                /*considerPackageJson*/
                true);
                const resolved = tryLoadModuleUsingOptionalResolutionSettings(extensions2, moduleName, containingDirectory, loader, state2);
                if (resolved) {
                    return toSearchResult({ resolved, isExternalLibraryImport: pathContainsNodeModules(resolved.path) });
                }
                if (!isExternalModuleNameRelative(moduleName)) {
                    let resolved2;
                    if (features & 2 /* Imports */ && startsWith(moduleName, "#")) {
                        resolved2 = loadModuleFromImports(extensions2, moduleName, containingDirectory, state2, cache, redirectedReference);
                    }
                    if (!resolved2 && features & 4 /* SelfName */) {
                        resolved2 = loadModuleFromSelfNameReference(extensions2, moduleName, containingDirectory, state2, cache, redirectedReference);
                    }
                    if (!resolved2) {
                        if (traceEnabled) {
                            trace(host, Diagnostics.Loading_module_0_from_node_modules_folder_target_file_types_Colon_1, moduleName, formatExtensions(extensions2));
                        }
                        resolved2 = loadModuleFromNearestNodeModulesDirectory(extensions2, moduleName, containingDirectory, state2, cache, redirectedReference);
                    }
                    return resolved2 && { value: resolved2.value && { resolved: resolved2.value, isExternalLibraryImport: true } };
                }
                else {
                    const { path: candidate, parts } = normalizePathForCJSResolution(containingDirectory, moduleName);
                    const resolved2 = nodeLoadModuleByRelativeName(extensions2, candidate, 
                    /*onlyRecordFailures*/
                    false, state2, 
                    /*considerPackageJson*/
                    true);
                    return resolved2 && toSearchResult({ resolved: resolved2, isExternalLibraryImport: contains(parts, "node_modules") });
                }
            }
        }
        function normalizePathForCJSResolution(containingDirectory, moduleName) {
            const combined = combinePaths(containingDirectory, moduleName);
            const parts = getPathComponents(combined);
            const lastPart = lastOrUndefined(parts);
            const path = lastPart === "." || lastPart === ".." ? ensureTrailingDirectorySeparator(normalizePath(combined)) : normalizePath(combined);
            return { path, parts };
        }
        function realPath(path, host, traceEnabled) {
            if (!host.realpath) {
                return path;
            }
            const real = normalizePath(host.realpath(path));
            if (traceEnabled) {
                trace(host, Diagnostics.Resolving_real_path_for_0_result_1, path, real);
            }
            Debug.assert(host.fileExists(real), `${path} linked to nonexistent file ${real}`);
            return real;
        }
        function nodeLoadModuleByRelativeName(extensions, candidate, onlyRecordFailures, state, considerPackageJson) {
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_types_Colon_1, candidate, formatExtensions(extensions));
            }
            if (!hasTrailingDirectorySeparator(candidate)) {
                if (!onlyRecordFailures) {
                    const parentOfCandidate = getDirectoryPath(candidate);
                    if (!directoryProbablyExists(parentOfCandidate, state.host)) {
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, parentOfCandidate);
                        }
                        onlyRecordFailures = true;
                    }
                }
                const resolvedFromFile = loadModuleFromFile(extensions, candidate, onlyRecordFailures, state);
                if (resolvedFromFile) {
                    const packageDirectory = considerPackageJson ? parseNodeModuleFromPath(resolvedFromFile.path) : void 0;
                    const packageInfo = packageDirectory ? getPackageJsonInfo(packageDirectory, 
                    /*onlyRecordFailures*/
                    false, state) : void 0;
                    return withPackageId(packageInfo, resolvedFromFile);
                }
            }
            if (!onlyRecordFailures) {
                const candidateExists = directoryProbablyExists(candidate, state.host);
                if (!candidateExists) {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, candidate);
                    }
                    onlyRecordFailures = true;
                }
            }
            if (!(state.features & 32 /* EsmMode */)) {
                return loadNodeModuleFromDirectory(extensions, candidate, onlyRecordFailures, state, considerPackageJson);
            }
            return void 0;
        }
        function pathContainsNodeModules(path) {
            return stringContains(path, nodeModulesPathPart);
        }
        function parseNodeModuleFromPath(resolved) {
            const path = normalizePath(resolved);
            const idx = path.lastIndexOf(nodeModulesPathPart);
            if (idx === -1) {
                return void 0;
            }
            const indexAfterNodeModules = idx + nodeModulesPathPart.length;
            let indexAfterPackageName = moveToNextDirectorySeparatorIfAvailable(path, indexAfterNodeModules);
            if (path.charCodeAt(indexAfterNodeModules) === 64 /* at */) {
                indexAfterPackageName = moveToNextDirectorySeparatorIfAvailable(path, indexAfterPackageName);
            }
            return path.slice(0, indexAfterPackageName);
        }
        function moveToNextDirectorySeparatorIfAvailable(path, prevSeparatorIndex) {
            const nextSeparatorIndex = path.indexOf(directorySeparator, prevSeparatorIndex + 1);
            return nextSeparatorIndex === -1 ? prevSeparatorIndex : nextSeparatorIndex;
        }
        function loadModuleFromFileNoPackageId(extensions, candidate, onlyRecordFailures, state) {
            return noPackageId(loadModuleFromFile(extensions, candidate, onlyRecordFailures, state));
        }
        function loadModuleFromFile(extensions, candidate, onlyRecordFailures, state) {
            const resolvedByReplacingExtension = loadModuleFromFileNoImplicitExtensions(extensions, candidate, onlyRecordFailures, state);
            if (resolvedByReplacingExtension) {
                return resolvedByReplacingExtension;
            }
            if (!(state.features & 32 /* EsmMode */)) {
                const resolvedByAddingExtension = tryAddingExtensions(candidate, extensions, "", onlyRecordFailures, state);
                if (resolvedByAddingExtension) {
                    return resolvedByAddingExtension;
                }
            }
        }
        function loadModuleFromFileNoImplicitExtensions(extensions, candidate, onlyRecordFailures, state) {
            const filename = getBaseFileName(candidate);
            if (filename.indexOf(".") === -1) {
                return void 0;
            }
            let extensionless = removeFileExtension(candidate);
            if (extensionless === candidate) {
                extensionless = candidate.substring(0, candidate.lastIndexOf("."));
            }
            const extension = candidate.substring(extensionless.length);
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.File_name_0_has_a_1_extension_stripping_it, candidate, extension);
            }
            return tryAddingExtensions(extensionless, extensions, extension, onlyRecordFailures, state);
        }
        function loadFileNameFromPackageJsonField(extensions, candidate, onlyRecordFailures, state) {
            if (extensions & 1 /* TypeScript */ && fileExtensionIsOneOf(candidate, supportedTSImplementationExtensions) || extensions & 4 /* Declaration */ && fileExtensionIsOneOf(candidate, supportedDeclarationExtensions)) {
                const result = tryFile(candidate, onlyRecordFailures, state);
                return result !== void 0 ? { path: candidate, ext: tryExtractTSExtension(candidate), resolvedUsingTsExtension: void 0 } : void 0;
            }
            if (state.isConfigLookup && extensions === 8 /* Json */ && fileExtensionIs(candidate, ".json" /* Json */)) {
                const result = tryFile(candidate, onlyRecordFailures, state);
                return result !== void 0 ? { path: candidate, ext: ".json" /* Json */, resolvedUsingTsExtension: void 0 } : void 0;
            }
            return loadModuleFromFileNoImplicitExtensions(extensions, candidate, onlyRecordFailures, state);
        }
        function tryAddingExtensions(candidate, extensions, originalExtension, onlyRecordFailures, state) {
            if (!onlyRecordFailures) {
                const directory = getDirectoryPath(candidate);
                if (directory) {
                    onlyRecordFailures = !directoryProbablyExists(directory, state.host);
                }
            }
            switch (originalExtension) {
                case ".mjs" /* Mjs */:
                case ".mts" /* Mts */:
                case ".d.mts" /* Dmts */:
                    return extensions & 1 /* TypeScript */ && tryExtension(".mts" /* Mts */, originalExtension === ".mts" /* Mts */ || originalExtension === ".d.mts" /* Dmts */) || extensions & 4 /* Declaration */ && tryExtension(".d.mts" /* Dmts */, originalExtension === ".mts" /* Mts */ || originalExtension === ".d.mts" /* Dmts */) || extensions & 2 /* JavaScript */ && tryExtension(".mjs" /* Mjs */) || void 0;
                case ".cjs" /* Cjs */:
                case ".cts" /* Cts */:
                case ".d.cts" /* Dcts */:
                    return extensions & 1 /* TypeScript */ && tryExtension(".cts" /* Cts */, originalExtension === ".cts" /* Cts */ || originalExtension === ".d.cts" /* Dcts */) || extensions & 4 /* Declaration */ && tryExtension(".d.cts" /* Dcts */, originalExtension === ".cts" /* Cts */ || originalExtension === ".d.cts" /* Dcts */) || extensions & 2 /* JavaScript */ && tryExtension(".cjs" /* Cjs */) || void 0;
                case ".json" /* Json */:
                    return extensions & 4 /* Declaration */ && tryExtension(".d.json.ts") || extensions & 8 /* Json */ && tryExtension(".json" /* Json */) || void 0;
                case ".tsx" /* Tsx */:
                case ".jsx" /* Jsx */:
                    return extensions & 1 /* TypeScript */ && (tryExtension(".tsx" /* Tsx */, originalExtension === ".tsx" /* Tsx */) || tryExtension(".ts" /* Ts */, originalExtension === ".tsx" /* Tsx */)) || extensions & 4 /* Declaration */ && tryExtension(".d.ts" /* Dts */, originalExtension === ".tsx" /* Tsx */) || extensions & 2 /* JavaScript */ && (tryExtension(".jsx" /* Jsx */) || tryExtension(".js" /* Js */)) || void 0;
                case ".ts" /* Ts */:
                case ".d.ts" /* Dts */:
                case ".js" /* Js */:
                case "":
                    return extensions & 1 /* TypeScript */ && (tryExtension(".ts" /* Ts */, originalExtension === ".ts" /* Ts */ || originalExtension === ".d.ts" /* Dts */) || tryExtension(".tsx" /* Tsx */, originalExtension === ".ts" /* Ts */ || originalExtension === ".d.ts" /* Dts */)) || extensions & 4 /* Declaration */ && tryExtension(".d.ts" /* Dts */, originalExtension === ".ts" /* Ts */ || originalExtension === ".d.ts" /* Dts */) || extensions & 2 /* JavaScript */ && (tryExtension(".js" /* Js */) || tryExtension(".jsx" /* Jsx */)) || state.isConfigLookup && tryExtension(".json" /* Json */) || void 0;
                default:
                    return extensions & 4 /* Declaration */ && !isDeclarationFileName(candidate + originalExtension) && tryExtension(`.d${originalExtension}.ts`) || void 0;
            }
            function tryExtension(ext, resolvedUsingTsExtension) {
                const path = tryFile(candidate + ext, onlyRecordFailures, state);
                return path === void 0 ? void 0 : { path, ext, resolvedUsingTsExtension: !state.candidateIsFromPackageJsonField && resolvedUsingTsExtension };
            }
        }
        function tryFile(fileName, onlyRecordFailures, state) {
            var _a2, _b;
            if (!((_a2 = state.compilerOptions.moduleSuffixes) == null ? void 0 : _a2.length)) {
                return tryFileLookup(fileName, onlyRecordFailures, state);
            }
            const ext = (_b = tryGetExtensionFromPath2(fileName)) != null ? _b : "";
            const fileNameNoExtension = ext ? removeExtension(fileName, ext) : fileName;
            return forEach(state.compilerOptions.moduleSuffixes, (suffix) => tryFileLookup(fileNameNoExtension + suffix + ext, onlyRecordFailures, state));
        }
        function tryFileLookup(fileName, onlyRecordFailures, state) {
            if (!onlyRecordFailures) {
                if (state.host.fileExists(fileName)) {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.File_0_exists_use_it_as_a_name_resolution_result, fileName);
                    }
                    return fileName;
                }
                else {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.File_0_does_not_exist, fileName);
                    }
                }
            }
            state.failedLookupLocations.push(fileName);
            return void 0;
        }
        function loadNodeModuleFromDirectory(extensions, candidate, onlyRecordFailures, state, considerPackageJson = true) {
            const packageInfo = considerPackageJson ? getPackageJsonInfo(candidate, onlyRecordFailures, state) : void 0;
            const packageJsonContent = packageInfo && packageInfo.contents.packageJsonContent;
            const versionPaths = packageInfo && getVersionPathsOfPackageJsonInfo(packageInfo, state);
            return withPackageId(packageInfo, loadNodeModuleFromDirectoryWorker(extensions, candidate, onlyRecordFailures, state, packageJsonContent, versionPaths));
        }
        function getEntrypointsFromPackageJsonInfo(packageJsonInfo, options, host, cache, resolveJs) {
            if (!resolveJs && packageJsonInfo.contents.resolvedEntrypoints !== void 0) {
                return packageJsonInfo.contents.resolvedEntrypoints;
            }
            let entrypoints;
            const extensions = 1 /* TypeScript */ | 4 /* Declaration */ | (resolveJs ? 2 /* JavaScript */ : 0);
            const features = getNodeResolutionFeatures(options);
            const loadPackageJsonMainState = getTemporaryModuleResolutionState(cache == null ? void 0 : cache.getPackageJsonInfoCache(), host, options);
            loadPackageJsonMainState.conditions = getConditions(options);
            loadPackageJsonMainState.requestContainingDirectory = packageJsonInfo.packageDirectory;
            const mainResolution = loadNodeModuleFromDirectoryWorker(extensions, packageJsonInfo.packageDirectory, 
            /*onlyRecordFailures*/
            false, loadPackageJsonMainState, packageJsonInfo.contents.packageJsonContent, getVersionPathsOfPackageJsonInfo(packageJsonInfo, loadPackageJsonMainState));
            entrypoints = append(entrypoints, mainResolution == null ? void 0 : mainResolution.path);
            if (features & 8 /* Exports */ && packageJsonInfo.contents.packageJsonContent.exports) {
                const conditionSets = deduplicate([getConditions(options, 
                    /*esmMode*/
                    true), getConditions(options, 
                    /*esmMode*/
                    false)], arrayIsEqualTo);
                for (const conditions of conditionSets) {
                    const loadPackageJsonExportsState = { ...loadPackageJsonMainState, failedLookupLocations: [], conditions };
                    const exportResolutions = loadEntrypointsFromExportMap(packageJsonInfo, packageJsonInfo.contents.packageJsonContent.exports, loadPackageJsonExportsState, extensions);
                    if (exportResolutions) {
                        for (const resolution of exportResolutions) {
                            entrypoints = appendIfUnique(entrypoints, resolution.path);
                        }
                    }
                }
            }
            return packageJsonInfo.contents.resolvedEntrypoints = entrypoints || false;
        }
        function loadEntrypointsFromExportMap(scope, exports, state, extensions) {
            let entrypoints;
            if (isArray(exports)) {
                for (const target of exports) {
                    loadEntrypointsFromTargetExports(target);
                }
            }
            else if (typeof exports === "object" && exports !== null && allKeysStartWithDot(exports)) {
                for (const key in exports) {
                    loadEntrypointsFromTargetExports(exports[key]);
                }
            }
            else {
                loadEntrypointsFromTargetExports(exports);
            }
            return entrypoints;
            function loadEntrypointsFromTargetExports(target) {
                var _a2, _b;
                if (typeof target === "string" && startsWith(target, "./") && target.indexOf("*") === -1) {
                    const partsAfterFirst = getPathComponents(target).slice(2);
                    if (partsAfterFirst.indexOf("..") >= 0 || partsAfterFirst.indexOf(".") >= 0 || partsAfterFirst.indexOf("node_modules") >= 0) {
                        return false;
                    }
                    const resolvedTarget = combinePaths(scope.packageDirectory, target);
                    const finalPath = getNormalizedAbsolutePath(resolvedTarget, (_b = (_a2 = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a2));
                    const result = loadFileNameFromPackageJsonField(extensions, finalPath, 
                    /*recordOnlyFailures*/
                    false, state);
                    if (result) {
                        entrypoints = appendIfUnique(entrypoints, result, (a, b) => a.path === b.path);
                        return true;
                    }
                }
                else if (Array.isArray(target)) {
                    for (const t of target) {
                        const success = loadEntrypointsFromTargetExports(t);
                        if (success) {
                            return true;
                        }
                    }
                }
                else if (typeof target === "object" && target !== null) {
                    return forEach(getOwnKeys(target), (key) => {
                        if (key === "default" || contains(state.conditions, key) || isApplicableVersionedTypesKey(state.conditions, key)) {
                            loadEntrypointsFromTargetExports(target[key]);
                            return true;
                        }
                    });
                }
            }
        }
        function getTemporaryModuleResolutionState(packageJsonInfoCache, host, options) {
            return {
                host,
                compilerOptions: options,
                traceEnabled: isTraceEnabled(options, host),
                failedLookupLocations: noopPush,
                affectingLocations: noopPush,
                packageJsonInfoCache,
                features: 0 /* None */,
                conditions: emptyArray,
                requestContainingDirectory: void 0,
                reportDiagnostic: noop,
                isConfigLookup: false,
                candidateIsFromPackageJsonField: false
            };
        }
        function getPackageScopeForPath(fileName, state) {
            const parts = getPathComponents(fileName);
            parts.pop();
            while (parts.length > 0) {
                const pkg = getPackageJsonInfo(getPathFromPathComponents(parts), 
                /*onlyRecordFailures*/
                false, state);
                if (pkg) {
                    return pkg;
                }
                parts.pop();
            }
            return void 0;
        }
        function getVersionPathsOfPackageJsonInfo(packageJsonInfo, state) {
            if (packageJsonInfo.contents.versionPaths === void 0) {
                packageJsonInfo.contents.versionPaths = readPackageJsonTypesVersionPaths(packageJsonInfo.contents.packageJsonContent, state) || false;
            }
            return packageJsonInfo.contents.versionPaths || void 0;
        }
        function getPackageJsonInfo(packageDirectory, onlyRecordFailures, state) {
            var _a2, _b, _c;
            const { host, traceEnabled } = state;
            const packageJsonPath = combinePaths(packageDirectory, "package.json");
            if (onlyRecordFailures) {
                state.failedLookupLocations.push(packageJsonPath);
                return void 0;
            }
            const existing = (_a2 = state.packageJsonInfoCache) == null ? void 0 : _a2.getPackageJsonInfo(packageJsonPath);
            if (existing !== void 0) {
                if (typeof existing !== "boolean") {
                    if (traceEnabled)
                        trace(host, Diagnostics.File_0_exists_according_to_earlier_cached_lookups, packageJsonPath);
                    state.affectingLocations.push(packageJsonPath);
                    return existing.packageDirectory === packageDirectory ? existing : { packageDirectory, contents: existing.contents };
                }
                else {
                    if (existing && traceEnabled)
                        trace(host, Diagnostics.File_0_does_not_exist_according_to_earlier_cached_lookups, packageJsonPath);
                    state.failedLookupLocations.push(packageJsonPath);
                    return void 0;
                }
            }
            const directoryExists = directoryProbablyExists(packageDirectory, host);
            if (directoryExists && host.fileExists(packageJsonPath)) {
                const packageJsonContent = readJson(packageJsonPath, host);
                if (traceEnabled) {
                    trace(host, Diagnostics.Found_package_json_at_0, packageJsonPath);
                }
                const result = { packageDirectory, contents: { packageJsonContent, versionPaths: void 0, resolvedEntrypoints: void 0 } };
                (_b = state.packageJsonInfoCache) == null ? void 0 : _b.setPackageJsonInfo(packageJsonPath, result);
                state.affectingLocations.push(packageJsonPath);
                return result;
            }
            else {
                if (directoryExists && traceEnabled) {
                    trace(host, Diagnostics.File_0_does_not_exist, packageJsonPath);
                }
                (_c = state.packageJsonInfoCache) == null ? void 0 : _c.setPackageJsonInfo(packageJsonPath, directoryExists);
                state.failedLookupLocations.push(packageJsonPath);
            }
        }
        function loadNodeModuleFromDirectoryWorker(extensions, candidate, onlyRecordFailures, state, jsonContent, versionPaths) {
            let packageFile;
            if (jsonContent) {
                if (state.isConfigLookup) {
                    packageFile = readPackageJsonTSConfigField(jsonContent, candidate, state);
                }
                else {
                    packageFile = extensions & 4 /* Declaration */ && readPackageJsonTypesFields(jsonContent, candidate, state) || extensions & (3 /* ImplementationFiles */ | 4 /* Declaration */) && readPackageJsonMainField(jsonContent, candidate, state) || void 0;
                }
            }
            const loader = (extensions2, candidate2, onlyRecordFailures2, state2) => {
                const fromFile = tryFile(candidate2, onlyRecordFailures2, state2);
                if (fromFile) {
                    const resolved = resolvedIfExtensionMatches(extensions2, fromFile);
                    if (resolved) {
                        return noPackageId(resolved);
                    }
                    if (state2.traceEnabled) {
                        trace(state2.host, Diagnostics.File_0_has_an_unsupported_extension_so_skipping_it, fromFile);
                    }
                }
                const expandedExtensions = extensions2 === 4 /* Declaration */ ? 1 /* TypeScript */ | 4 /* Declaration */ : extensions2;
                const features = state2.features;
                const candidateIsFromPackageJsonField = state2.candidateIsFromPackageJsonField;
                state2.candidateIsFromPackageJsonField = true;
                if ((jsonContent == null ? void 0 : jsonContent.type) !== "module") {
                    state2.features &= ~32 /* EsmMode */;
                }
                const result = nodeLoadModuleByRelativeName(expandedExtensions, candidate2, onlyRecordFailures2, state2, 
                /*considerPackageJson*/
                false);
                state2.features = features;
                state2.candidateIsFromPackageJsonField = candidateIsFromPackageJsonField;
                return result;
            };
            const onlyRecordFailuresForPackageFile = packageFile ? !directoryProbablyExists(getDirectoryPath(packageFile), state.host) : void 0;
            const onlyRecordFailuresForIndex = onlyRecordFailures || !directoryProbablyExists(candidate, state.host);
            const indexPath = combinePaths(candidate, state.isConfigLookup ? "tsconfig" : "index");
            if (versionPaths && (!packageFile || containsPath(candidate, packageFile))) {
                const moduleName = getRelativePathFromDirectory(candidate, packageFile || indexPath, 
                /*ignoreCase*/
                false);
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2, versionPaths.version, version, moduleName);
                }
                const result = tryLoadModuleUsingPaths(extensions, moduleName, candidate, versionPaths.paths, 
                /*pathPatterns*/
                void 0, loader, onlyRecordFailuresForPackageFile || onlyRecordFailuresForIndex, state);
                if (result) {
                    return removeIgnoredPackageId(result.value);
                }
            }
            const packageFileResult = packageFile && removeIgnoredPackageId(loader(extensions, packageFile, onlyRecordFailuresForPackageFile, state));
            if (packageFileResult)
                return packageFileResult;
            if (!(state.features & 32 /* EsmMode */)) {
                return loadModuleFromFile(extensions, indexPath, onlyRecordFailuresForIndex, state);
            }
        }
        function resolvedIfExtensionMatches(extensions, path, resolvedUsingTsExtension) {
            const ext = tryGetExtensionFromPath2(path);
            return ext !== void 0 && extensionIsOk(extensions, ext) ? { path, ext, resolvedUsingTsExtension } : void 0;
        }
        function extensionIsOk(extensions, extension) {
            return extensions & 2 /* JavaScript */ && (extension === ".js" /* Js */ || extension === ".jsx" /* Jsx */ || extension === ".mjs" /* Mjs */ || extension === ".cjs" /* Cjs */) || extensions & 1 /* TypeScript */ && (extension === ".ts" /* Ts */ || extension === ".tsx" /* Tsx */ || extension === ".mts" /* Mts */ || extension === ".cts" /* Cts */) || extensions & 4 /* Declaration */ && (extension === ".d.ts" /* Dts */ || extension === ".d.mts" /* Dmts */ || extension === ".d.cts" /* Dcts */) || extensions & 8 /* Json */ && extension === ".json" /* Json */ || false;
        }
        function parsePackageName(moduleName) {
            let idx = moduleName.indexOf(directorySeparator);
            if (moduleName[0] === "@") {
                idx = moduleName.indexOf(directorySeparator, idx + 1);
            }
            return idx === -1 ? { packageName: moduleName, rest: "" } : { packageName: moduleName.slice(0, idx), rest: moduleName.slice(idx + 1) };
        }
        function allKeysStartWithDot(obj) {
            return every(getOwnKeys(obj), (k) => startsWith(k, "."));
        }
        function noKeyStartsWithDot(obj) {
            return !some(getOwnKeys(obj), (k) => startsWith(k, "."));
        }
        function loadModuleFromSelfNameReference(extensions, moduleName, directory, state, cache, redirectedReference) {
            var _a2, _b;
            const directoryPath = getNormalizedAbsolutePath(combinePaths(directory, "dummy"), (_b = (_a2 = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a2));
            const scope = getPackageScopeForPath(directoryPath, state);
            if (!scope || !scope.contents.packageJsonContent.exports) {
                return void 0;
            }
            if (typeof scope.contents.packageJsonContent.name !== "string") {
                return void 0;
            }
            const parts = getPathComponents(moduleName);
            const nameParts = getPathComponents(scope.contents.packageJsonContent.name);
            if (!every(nameParts, (p, i) => parts[i] === p)) {
                return void 0;
            }
            const trailingParts = parts.slice(nameParts.length);
            const subpath = !length(trailingParts) ? "." : `.${directorySeparator}${trailingParts.join(directorySeparator)}`;
            const priorityExtensions = extensions & (1 /* TypeScript */ | 4 /* Declaration */);
            const secondaryExtensions = extensions & ~(1 /* TypeScript */ | 4 /* Declaration */);
            return loadModuleFromExports(scope, priorityExtensions, subpath, state, cache, redirectedReference) || loadModuleFromExports(scope, secondaryExtensions, subpath, state, cache, redirectedReference);
        }
        function loadModuleFromExports(scope, extensions, subpath, state, cache, redirectedReference) {
            if (!scope.contents.packageJsonContent.exports) {
                return void 0;
            }
            if (subpath === ".") {
                let mainExport;
                if (typeof scope.contents.packageJsonContent.exports === "string" || Array.isArray(scope.contents.packageJsonContent.exports) || typeof scope.contents.packageJsonContent.exports === "object" && noKeyStartsWithDot(scope.contents.packageJsonContent.exports)) {
                    mainExport = scope.contents.packageJsonContent.exports;
                }
                else if (hasProperty(scope.contents.packageJsonContent.exports, ".")) {
                    mainExport = scope.contents.packageJsonContent.exports["."];
                }
                if (mainExport) {
                    const loadModuleFromTargetImportOrExport = getLoadModuleFromTargetImportOrExport(extensions, state, cache, redirectedReference, subpath, scope, 
                    /*isImports*/
                    false);
                    return loadModuleFromTargetImportOrExport(mainExport, "", 
                    /*pattern*/
                    false, ".");
                }
            }
            else if (allKeysStartWithDot(scope.contents.packageJsonContent.exports)) {
                if (typeof scope.contents.packageJsonContent.exports !== "object") {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1, subpath, scope.packageDirectory);
                    }
                    return toSearchResult(
                    /*value*/
                    void 0);
                }
                const result = loadModuleFromImportsOrExports(extensions, state, cache, redirectedReference, subpath, scope.contents.packageJsonContent.exports, scope, 
                /*isImports*/
                false);
                if (result) {
                    return result;
                }
            }
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1, subpath, scope.packageDirectory);
            }
            return toSearchResult(
            /*value*/
            void 0);
        }
        function loadModuleFromImports(extensions, moduleName, directory, state, cache, redirectedReference) {
            var _a2, _b;
            if (moduleName === "#" || startsWith(moduleName, "#/")) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Invalid_import_specifier_0_has_no_possible_resolutions, moduleName);
                }
                return toSearchResult(
                /*value*/
                void 0);
            }
            const directoryPath = getNormalizedAbsolutePath(combinePaths(directory, "dummy"), (_b = (_a2 = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a2));
            const scope = getPackageScopeForPath(directoryPath, state);
            if (!scope) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve, directoryPath);
                }
                return toSearchResult(
                /*value*/
                void 0);
            }
            if (!scope.contents.packageJsonContent.imports) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_scope_0_has_no_imports_defined, scope.packageDirectory);
                }
                return toSearchResult(
                /*value*/
                void 0);
            }
            const result = loadModuleFromImportsOrExports(extensions, state, cache, redirectedReference, moduleName, scope.contents.packageJsonContent.imports, scope, 
            /*isImports*/
            true);
            if (result) {
                return result;
            }
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1, moduleName, scope.packageDirectory);
            }
            return toSearchResult(
            /*value*/
            void 0);
        }
        function comparePatternKeys(a, b) {
            const aPatternIndex = a.indexOf("*");
            const bPatternIndex = b.indexOf("*");
            const baseLenA = aPatternIndex === -1 ? a.length : aPatternIndex + 1;
            const baseLenB = bPatternIndex === -1 ? b.length : bPatternIndex + 1;
            if (baseLenA > baseLenB)
                return -1;
            if (baseLenB > baseLenA)
                return 1;
            if (aPatternIndex === -1)
                return 1;
            if (bPatternIndex === -1)
                return -1;
            if (a.length > b.length)
                return -1;
            if (b.length > a.length)
                return 1;
            return 0;
        }
        function loadModuleFromImportsOrExports(extensions, state, cache, redirectedReference, moduleName, lookupTable, scope, isImports) {
            const loadModuleFromTargetImportOrExport = getLoadModuleFromTargetImportOrExport(extensions, state, cache, redirectedReference, moduleName, scope, isImports);
            if (!endsWith(moduleName, directorySeparator) && moduleName.indexOf("*") === -1 && hasProperty(lookupTable, moduleName)) {
                const target = lookupTable[moduleName];
                return loadModuleFromTargetImportOrExport(target, 
                /*subpath*/
                "", 
                /*pattern*/
                false, moduleName);
            }
            const expandingKeys = sort(filter(getOwnKeys(lookupTable), (k) => k.indexOf("*") !== -1 || endsWith(k, "/")), comparePatternKeys);
            for (const potentialTarget of expandingKeys) {
                if (state.features & 16 /* ExportsPatternTrailers */ && matchesPatternWithTrailer(potentialTarget, moduleName)) {
                    const target = lookupTable[potentialTarget];
                    const starPos = potentialTarget.indexOf("*");
                    const subpath = moduleName.substring(potentialTarget.substring(0, starPos).length, moduleName.length - (potentialTarget.length - 1 - starPos));
                    return loadModuleFromTargetImportOrExport(target, subpath, 
                    /*pattern*/
                    true, potentialTarget);
                }
                else if (endsWith(potentialTarget, "*") && startsWith(moduleName, potentialTarget.substring(0, potentialTarget.length - 1))) {
                    const target = lookupTable[potentialTarget];
                    const subpath = moduleName.substring(potentialTarget.length - 1);
                    return loadModuleFromTargetImportOrExport(target, subpath, 
                    /*pattern*/
                    true, potentialTarget);
                }
                else if (startsWith(moduleName, potentialTarget)) {
                    const target = lookupTable[potentialTarget];
                    const subpath = moduleName.substring(potentialTarget.length);
                    return loadModuleFromTargetImportOrExport(target, subpath, 
                    /*pattern*/
                    false, potentialTarget);
                }
            }
            function matchesPatternWithTrailer(target, name) {
                if (endsWith(target, "*"))
                    return false;
                const starPos = target.indexOf("*");
                if (starPos === -1)
                    return false;
                return startsWith(name, target.substring(0, starPos)) && endsWith(name, target.substring(starPos + 1));
            }
        }
        function getLoadModuleFromTargetImportOrExport(extensions, state, cache, redirectedReference, moduleName, scope, isImports) {
            return loadModuleFromTargetImportOrExport;
            function loadModuleFromTargetImportOrExport(target, subpath, pattern, key) {
                if (typeof target === "string") {
                    if (!pattern && subpath.length > 0 && !endsWith(target, "/")) {
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                        }
                        return toSearchResult(
                        /*value*/
                        void 0);
                    }
                    if (!startsWith(target, "./")) {
                        if (isImports && !startsWith(target, "../") && !startsWith(target, "/") && !isRootedDiskPath(target)) {
                            const combinedLookup = pattern ? target.replace(/\*/g, subpath) : target + subpath;
                            traceIfEnabled(state, Diagnostics.Using_0_subpath_1_with_target_2, "imports", key, combinedLookup);
                            traceIfEnabled(state, Diagnostics.Resolving_module_0_from_1, combinedLookup, scope.packageDirectory + "/");
                            const result = nodeModuleNameResolverWorker(state.features, combinedLookup, scope.packageDirectory + "/", state.compilerOptions, state.host, cache, extensions, 
                            /*isConfigLookup*/
                            false, redirectedReference);
                            return toSearchResult(result.resolvedModule ? {
                                path: result.resolvedModule.resolvedFileName,
                                extension: result.resolvedModule.extension,
                                packageId: result.resolvedModule.packageId,
                                originalPath: result.resolvedModule.originalPath,
                                resolvedUsingTsExtension: result.resolvedModule.resolvedUsingTsExtension
                            } : void 0);
                        }
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                        }
                        return toSearchResult(
                        /*value*/
                        void 0);
                    }
                    const parts = pathIsRelative(target) ? getPathComponents(target).slice(1) : getPathComponents(target);
                    const partsAfterFirst = parts.slice(1);
                    if (partsAfterFirst.indexOf("..") >= 0 || partsAfterFirst.indexOf(".") >= 0 || partsAfterFirst.indexOf("node_modules") >= 0) {
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                        }
                        return toSearchResult(
                        /*value*/
                        void 0);
                    }
                    const resolvedTarget = combinePaths(scope.packageDirectory, target);
                    const subpathParts = getPathComponents(subpath);
                    if (subpathParts.indexOf("..") >= 0 || subpathParts.indexOf(".") >= 0 || subpathParts.indexOf("node_modules") >= 0) {
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                        }
                        return toSearchResult(
                        /*value*/
                        void 0);
                    }
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Using_0_subpath_1_with_target_2, isImports ? "imports" : "exports", key, pattern ? target.replace(/\*/g, subpath) : target + subpath);
                    }
                    const finalPath = toAbsolutePath(pattern ? resolvedTarget.replace(/\*/g, subpath) : resolvedTarget + subpath);
                    const inputLink = tryLoadInputFileForPath(finalPath, subpath, combinePaths(scope.packageDirectory, "package.json"), isImports);
                    if (inputLink)
                        return inputLink;
                    return toSearchResult(withPackageId(scope, loadFileNameFromPackageJsonField(extensions, finalPath, 
                    /*onlyRecordFailures*/
                    false, state)));
                }
                else if (typeof target === "object" && target !== null) {
                    if (!Array.isArray(target)) {
                        traceIfEnabled(state, Diagnostics.Entering_conditional_exports);
                        for (const condition of getOwnKeys(target)) {
                            if (condition === "default" || state.conditions.indexOf(condition) >= 0 || isApplicableVersionedTypesKey(state.conditions, condition)) {
                                traceIfEnabled(state, Diagnostics.Matched_0_condition_1, isImports ? "imports" : "exports", condition);
                                const subTarget = target[condition];
                                const result = loadModuleFromTargetImportOrExport(subTarget, subpath, pattern, key);
                                if (result) {
                                    traceIfEnabled(state, Diagnostics.Resolved_under_condition_0, condition);
                                    traceIfEnabled(state, Diagnostics.Exiting_conditional_exports);
                                    return result;
                                }
                                else {
                                    traceIfEnabled(state, Diagnostics.Failed_to_resolve_under_condition_0, condition);
                                }
                            }
                            else {
                                traceIfEnabled(state, Diagnostics.Saw_non_matching_condition_0, condition);
                            }
                        }
                        traceIfEnabled(state, Diagnostics.Exiting_conditional_exports);
                        return void 0;
                    }
                    else {
                        if (!length(target)) {
                            if (state.traceEnabled) {
                                trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                            }
                            return toSearchResult(
                            /*value*/
                            void 0);
                        }
                        for (const elem of target) {
                            const result = loadModuleFromTargetImportOrExport(elem, subpath, pattern, key);
                            if (result) {
                                return result;
                            }
                        }
                    }
                }
                else if (target === null) {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.package_json_scope_0_explicitly_maps_specifier_1_to_null, scope.packageDirectory, moduleName);
                    }
                    return toSearchResult(
                    /*value*/
                    void 0);
                }
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                }
                return toSearchResult(
                /*value*/
                void 0);
                function toAbsolutePath(path) {
                    var _a2, _b;
                    if (path === void 0)
                        return path;
                    return getNormalizedAbsolutePath(path, (_b = (_a2 = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a2));
                }
                function combineDirectoryPath(root, dir) {
                    return ensureTrailingDirectorySeparator(combinePaths(root, dir));
                }
                function useCaseSensitiveFileNames() {
                    return !state.host.useCaseSensitiveFileNames ? true : typeof state.host.useCaseSensitiveFileNames === "boolean" ? state.host.useCaseSensitiveFileNames : state.host.useCaseSensitiveFileNames();
                }
                function tryLoadInputFileForPath(finalPath, entry, packagePath, isImports2) {
                    var _a2, _b, _c, _d;
                    if (!state.isConfigLookup && (state.compilerOptions.declarationDir || state.compilerOptions.outDir) && finalPath.indexOf("/node_modules/") === -1 && (state.compilerOptions.configFile ? containsPath(scope.packageDirectory, toAbsolutePath(state.compilerOptions.configFile.fileName), !useCaseSensitiveFileNames()) : true)) {
                        const getCanonicalFileName = hostGetCanonicalFileName({ useCaseSensitiveFileNames });
                        const commonSourceDirGuesses = [];
                        if (state.compilerOptions.rootDir || state.compilerOptions.composite && state.compilerOptions.configFilePath) {
                            const commonDir = toAbsolutePath(getCommonSourceDirectory(state.compilerOptions, () => [], ((_b = (_a2 = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a2)) || "", getCanonicalFileName));
                            commonSourceDirGuesses.push(commonDir);
                        }
                        else if (state.requestContainingDirectory) {
                            const requestingFile = toAbsolutePath(combinePaths(state.requestContainingDirectory, "index.ts"));
                            const commonDir = toAbsolutePath(getCommonSourceDirectory(state.compilerOptions, () => [requestingFile, toAbsolutePath(packagePath)], ((_d = (_c = state.host).getCurrentDirectory) == null ? void 0 : _d.call(_c)) || "", getCanonicalFileName));
                            commonSourceDirGuesses.push(commonDir);
                            let fragment = ensureTrailingDirectorySeparator(commonDir);
                            while (fragment && fragment.length > 1) {
                                const parts = getPathComponents(fragment);
                                parts.pop();
                                const commonDir2 = getPathFromPathComponents(parts);
                                commonSourceDirGuesses.unshift(commonDir2);
                                fragment = ensureTrailingDirectorySeparator(commonDir2);
                            }
                        }
                        if (commonSourceDirGuesses.length > 1) {
                            state.reportDiagnostic(createCompilerDiagnostic(isImports2 ? Diagnostics.The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate : Diagnostics.The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate, entry === "" ? "." : entry, 
                            // replace empty string with `.` - the reverse of the operation done when entries are built - so main entrypoint errors don't look weird
                            packagePath));
                        }
                        for (const commonSourceDirGuess of commonSourceDirGuesses) {
                            const candidateDirectories = getOutputDirectoriesForBaseDirectory(commonSourceDirGuess);
                            for (const candidateDir of candidateDirectories) {
                                if (containsPath(candidateDir, finalPath, !useCaseSensitiveFileNames())) {
                                    const pathFragment = finalPath.slice(candidateDir.length + 1);
                                    const possibleInputBase = combinePaths(commonSourceDirGuess, pathFragment);
                                    const jsAndDtsExtensions = [".mjs" /* Mjs */, ".cjs" /* Cjs */, ".js" /* Js */, ".json" /* Json */, ".d.mts" /* Dmts */, ".d.cts" /* Dcts */, ".d.ts" /* Dts */];
                                    for (const ext of jsAndDtsExtensions) {
                                        if (fileExtensionIs(possibleInputBase, ext)) {
                                            const inputExts = getPossibleOriginalInputExtensionForExtension(possibleInputBase);
                                            for (const possibleExt of inputExts) {
                                                if (!extensionIsOk(extensions, possibleExt))
                                                    continue;
                                                const possibleInputWithInputExtension = changeAnyExtension(possibleInputBase, possibleExt, ext, !useCaseSensitiveFileNames());
                                                if (state.host.fileExists(possibleInputWithInputExtension)) {
                                                    return toSearchResult(withPackageId(scope, loadFileNameFromPackageJsonField(extensions, possibleInputWithInputExtension, 
                                                    /*onlyRecordFailures*/
                                                    false, state)));
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                    return void 0;
                    function getOutputDirectoriesForBaseDirectory(commonSourceDirGuess) {
                        var _a3, _b2;
                        const currentDir = state.compilerOptions.configFile ? ((_b2 = (_a3 = state.host).getCurrentDirectory) == null ? void 0 : _b2.call(_a3)) || "" : commonSourceDirGuess;
                        const candidateDirectories = [];
                        if (state.compilerOptions.declarationDir) {
                            candidateDirectories.push(toAbsolutePath(combineDirectoryPath(currentDir, state.compilerOptions.declarationDir)));
                        }
                        if (state.compilerOptions.outDir && state.compilerOptions.outDir !== state.compilerOptions.declarationDir) {
                            candidateDirectories.push(toAbsolutePath(combineDirectoryPath(currentDir, state.compilerOptions.outDir)));
                        }
                        return candidateDirectories;
                    }
                }
            }
        }
        function isApplicableVersionedTypesKey(conditions, key) {
            if (conditions.indexOf("types") === -1)
                return false;
            if (!startsWith(key, "types@"))
                return false;
            const range = VersionRange.tryParse(key.substring("types@".length));
            if (!range)
                return false;
            return range.test(version);
        }
        function loadModuleFromNearestNodeModulesDirectory(extensions, moduleName, directory, state, cache, redirectedReference) {
            return loadModuleFromNearestNodeModulesDirectoryWorker(extensions, moduleName, directory, state, 
            /*typesScopeOnly*/
            false, cache, redirectedReference);
        }
        function loadModuleFromNearestNodeModulesDirectoryTypesScope(moduleName, directory, state) {
            return loadModuleFromNearestNodeModulesDirectoryWorker(4 /* Declaration */, moduleName, directory, state, 
            /*typesScopeOnly*/
            true, 
            /*cache*/
            void 0, 
            /*redirectedReference*/
            void 0);
        }
        function loadModuleFromNearestNodeModulesDirectoryWorker(extensions, moduleName, directory, state, typesScopeOnly, cache, redirectedReference) {
            const mode = state.features === 0 ? void 0 : state.features & 32 /* EsmMode */ ? 99 /* ESNext */ : 1 /* CommonJS */;
            const priorityExtensions = extensions & (1 /* TypeScript */ | 4 /* Declaration */);
            const secondaryExtensions = extensions & ~(1 /* TypeScript */ | 4 /* Declaration */);
            if (priorityExtensions) {
                const result = lookup(priorityExtensions);
                if (result)
                    return result;
            }
            if (secondaryExtensions && !typesScopeOnly) {
                return lookup(secondaryExtensions);
            }
            function lookup(extensions2) {
                return forEachAncestorDirectory(normalizeSlashes(directory), (ancestorDirectory) => {
                    if (getBaseFileName(ancestorDirectory) !== "node_modules") {
                        const resolutionFromCache = tryFindNonRelativeModuleNameInCache(cache, moduleName, mode, ancestorDirectory, redirectedReference, state);
                        if (resolutionFromCache) {
                            return resolutionFromCache;
                        }
                        return toSearchResult(loadModuleFromImmediateNodeModulesDirectory(extensions2, moduleName, ancestorDirectory, state, typesScopeOnly, cache, redirectedReference));
                    }
                });
            }
        }
        function loadModuleFromImmediateNodeModulesDirectory(extensions, moduleName, directory, state, typesScopeOnly, cache, redirectedReference) {
            const nodeModulesFolder = combinePaths(directory, "node_modules");
            const nodeModulesFolderExists = directoryProbablyExists(nodeModulesFolder, state.host);
            if (!nodeModulesFolderExists && state.traceEnabled) {
                trace(state.host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, nodeModulesFolder);
            }
            if (!typesScopeOnly) {
                const packageResult = loadModuleFromSpecificNodeModulesDirectory(extensions, moduleName, nodeModulesFolder, nodeModulesFolderExists, state, cache, redirectedReference);
                if (packageResult) {
                    return packageResult;
                }
            }
            if (extensions & 4 /* Declaration */) {
                const nodeModulesAtTypes2 = combinePaths(nodeModulesFolder, "@types");
                let nodeModulesAtTypesExists = nodeModulesFolderExists;
                if (nodeModulesFolderExists && !directoryProbablyExists(nodeModulesAtTypes2, state.host)) {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, nodeModulesAtTypes2);
                    }
                    nodeModulesAtTypesExists = false;
                }
                return loadModuleFromSpecificNodeModulesDirectory(4 /* Declaration */, mangleScopedPackageNameWithTrace(moduleName, state), nodeModulesAtTypes2, nodeModulesAtTypesExists, state, cache, redirectedReference);
            }
        }
        function loadModuleFromSpecificNodeModulesDirectory(extensions, moduleName, nodeModulesDirectory, nodeModulesDirectoryExists, state, cache, redirectedReference) {
            var _a2, _b, _c;
            const candidate = normalizePath(combinePaths(nodeModulesDirectory, moduleName));
            const { packageName, rest } = parsePackageName(moduleName);
            const packageDirectory = combinePaths(nodeModulesDirectory, packageName);
            let rootPackageInfo;
            let packageInfo = getPackageJsonInfo(candidate, !nodeModulesDirectoryExists, state);
            if (rest !== "" && packageInfo && (!(state.features & 8 /* Exports */) || !hasProperty((_b = (_a2 = rootPackageInfo = getPackageJsonInfo(packageDirectory, !nodeModulesDirectoryExists, state)) == null ? void 0 : _a2.contents.packageJsonContent) != null ? _b : emptyArray, "exports"))) {
                const fromFile = loadModuleFromFile(extensions, candidate, !nodeModulesDirectoryExists, state);
                if (fromFile) {
                    return noPackageId(fromFile);
                }
                const fromDirectory = loadNodeModuleFromDirectoryWorker(extensions, candidate, !nodeModulesDirectoryExists, state, packageInfo.contents.packageJsonContent, getVersionPathsOfPackageJsonInfo(packageInfo, state));
                return withPackageId(packageInfo, fromDirectory);
            }
            const loader = (extensions2, candidate2, onlyRecordFailures, state2) => {
                let pathAndExtension = loadModuleFromFile(extensions2, candidate2, onlyRecordFailures, state2) || loadNodeModuleFromDirectoryWorker(extensions2, candidate2, onlyRecordFailures, state2, packageInfo && packageInfo.contents.packageJsonContent, packageInfo && getVersionPathsOfPackageJsonInfo(packageInfo, state2));
                if (!pathAndExtension && packageInfo && (packageInfo.contents.packageJsonContent.exports === void 0 || packageInfo.contents.packageJsonContent.exports === null) && state2.features & 32 /* EsmMode */) {
                    pathAndExtension = loadModuleFromFile(extensions2, combinePaths(candidate2, "index.js"), onlyRecordFailures, state2);
                }
                return withPackageId(packageInfo, pathAndExtension);
            };
            if (rest !== "") {
                packageInfo = rootPackageInfo != null ? rootPackageInfo : getPackageJsonInfo(packageDirectory, !nodeModulesDirectoryExists, state);
            }
            if (packageInfo && packageInfo.contents.packageJsonContent.exports && state.features & 8 /* Exports */) {
                return (_c = loadModuleFromExports(packageInfo, extensions, combinePaths(".", rest), state, cache, redirectedReference)) == null ? void 0 : _c.value;
            }
            const versionPaths = rest !== "" && packageInfo ? getVersionPathsOfPackageJsonInfo(packageInfo, state) : void 0;
            if (versionPaths) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2, versionPaths.version, version, rest);
                }
                const packageDirectoryExists = nodeModulesDirectoryExists && directoryProbablyExists(packageDirectory, state.host);
                const fromPaths = tryLoadModuleUsingPaths(extensions, rest, packageDirectory, versionPaths.paths, 
                /*pathPatterns*/
                void 0, loader, !packageDirectoryExists, state);
                if (fromPaths) {
                    return fromPaths.value;
                }
            }
            return loader(extensions, candidate, !nodeModulesDirectoryExists, state);
        }
        function tryLoadModuleUsingPaths(extensions, moduleName, baseDirectory, paths, pathPatterns, loader, onlyRecordFailures, state) {
            pathPatterns || (pathPatterns = tryParsePatterns(paths));
            const matchedPattern = matchPatternOrExact(pathPatterns, moduleName);
            if (matchedPattern) {
                const matchedStar = isString(matchedPattern) ? void 0 : matchedText(matchedPattern, moduleName);
                const matchedPatternText = isString(matchedPattern) ? matchedPattern : patternText(matchedPattern);
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Module_name_0_matched_pattern_1, moduleName, matchedPatternText);
                }
                const resolved = forEach(paths[matchedPatternText], (subst) => {
                    const path = matchedStar ? subst.replace("*", matchedStar) : subst;
                    const candidate = normalizePath(combinePaths(baseDirectory, path));
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Trying_substitution_0_candidate_module_location_Colon_1, subst, path);
                    }
                    const extension = tryGetExtensionFromPath2(subst);
                    if (extension !== void 0) {
                        const path2 = tryFile(candidate, onlyRecordFailures, state);
                        if (path2 !== void 0) {
                            return noPackageId({ path: path2, ext: extension, resolvedUsingTsExtension: void 0 });
                        }
                    }
                    return loader(extensions, candidate, onlyRecordFailures || !directoryProbablyExists(getDirectoryPath(candidate), state.host), state);
                });
                return { value: resolved };
            }
        }
        function mangleScopedPackageNameWithTrace(packageName, state) {
            const mangled = mangleScopedPackageName(packageName);
            if (state.traceEnabled && mangled !== packageName) {
                trace(state.host, Diagnostics.Scoped_package_detected_looking_in_0, mangled);
            }
            return mangled;
        }
        function getTypesPackageName(packageName) {
            return `@types/${mangleScopedPackageName(packageName)}`;
        }
        function mangleScopedPackageName(packageName) {
            if (startsWith(packageName, "@")) {
                const replaceSlash = packageName.replace(directorySeparator, mangledScopedPackageSeparator);
                if (replaceSlash !== packageName) {
                    return replaceSlash.slice(1);
                }
            }
            return packageName;
        }
        function getPackageNameFromTypesPackageName(mangledName) {
            const withoutAtTypePrefix = removePrefix(mangledName, "@types/");
            if (withoutAtTypePrefix !== mangledName) {
                return unmangleScopedPackageName(withoutAtTypePrefix);
            }
            return mangledName;
        }
        function unmangleScopedPackageName(typesPackageName) {
            return stringContains(typesPackageName, mangledScopedPackageSeparator) ? "@" + typesPackageName.replace(mangledScopedPackageSeparator, directorySeparator) : typesPackageName;
        }
        function tryFindNonRelativeModuleNameInCache(cache, moduleName, mode, containingDirectory, redirectedReference, state) {
            const result = cache && cache.getFromNonRelativeNameCache(moduleName, mode, containingDirectory, redirectedReference);
            if (result) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Resolution_for_module_0_was_found_in_cache_from_location_1, moduleName, containingDirectory);
                }
                state.resultFromCache = result;
                return {
                    value: result.resolvedModule && {
                        path: result.resolvedModule.resolvedFileName,
                        originalPath: result.resolvedModule.originalPath || true,
                        extension: result.resolvedModule.extension,
                        packageId: result.resolvedModule.packageId,
                        resolvedUsingTsExtension: result.resolvedModule.resolvedUsingTsExtension
                    }
                };
            }
        }
        function classicNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference) {
            const traceEnabled = isTraceEnabled(compilerOptions, host);
            const failedLookupLocations = [];
            const affectingLocations = [];
            const containingDirectory = getDirectoryPath(containingFile);
            const diagnostics = [];
            const state = {
                compilerOptions,
                host,
                traceEnabled,
                failedLookupLocations,
                affectingLocations,
                packageJsonInfoCache: cache,
                features: 0 /* None */,
                conditions: [],
                requestContainingDirectory: containingDirectory,
                reportDiagnostic: (diag2) => void diagnostics.push(diag2),
                isConfigLookup: false,
                candidateIsFromPackageJsonField: false
            };
            const resolved = tryResolve(1 /* TypeScript */ | 4 /* Declaration */) || tryResolve(2 /* JavaScript */ | (compilerOptions.resolveJsonModule ? 8 /* Json */ : 0));
            return createResolvedModuleWithFailedLookupLocationsHandlingSymlink(moduleName, resolved && resolved.value, (resolved == null ? void 0 : resolved.value) && pathContainsNodeModules(resolved.value.path), failedLookupLocations, affectingLocations, diagnostics, state);
            function tryResolve(extensions) {
                const resolvedUsingSettings = tryLoadModuleUsingOptionalResolutionSettings(extensions, moduleName, containingDirectory, loadModuleFromFileNoPackageId, state);
                if (resolvedUsingSettings) {
                    return { value: resolvedUsingSettings };
                }
                if (!isExternalModuleNameRelative(moduleName)) {
                    const resolved2 = forEachAncestorDirectory(containingDirectory, (directory) => {
                        const resolutionFromCache = tryFindNonRelativeModuleNameInCache(cache, moduleName, 
                        /*mode*/
                        void 0, directory, redirectedReference, state);
                        if (resolutionFromCache) {
                            return resolutionFromCache;
                        }
                        const searchName = normalizePath(combinePaths(directory, moduleName));
                        return toSearchResult(loadModuleFromFileNoPackageId(extensions, searchName, 
                        /*onlyRecordFailures*/
                        false, state));
                    });
                    if (resolved2) {
                        return resolved2;
                    }
                    if (extensions & (1 /* TypeScript */ | 4 /* Declaration */)) {
                        return loadModuleFromNearestNodeModulesDirectoryTypesScope(moduleName, containingDirectory, state);
                    }
                }
                else {
                    const candidate = normalizePath(combinePaths(containingDirectory, moduleName));
                    return toSearchResult(loadModuleFromFileNoPackageId(extensions, candidate, 
                    /*onlyRecordFailures*/
                    false, state));
                }
            }
        }
        function shouldAllowImportingTsExtension(compilerOptions, fromFileName) {
            return !!compilerOptions.allowImportingTsExtensions || fromFileName && isDeclarationFileName(fromFileName);
        }
        function loadModuleFromGlobalCache(moduleName, projectName, compilerOptions, host, globalCache, packageJsonInfoCache) {
            const traceEnabled = isTraceEnabled(compilerOptions, host);
            if (traceEnabled) {
                trace(host, Diagnostics.Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using_cache_location_2, projectName, moduleName, globalCache);
            }
            const failedLookupLocations = [];
            const affectingLocations = [];
            const diagnostics = [];
            const state = {
                compilerOptions,
                host,
                traceEnabled,
                failedLookupLocations,
                affectingLocations,
                packageJsonInfoCache,
                features: 0 /* None */,
                conditions: [],
                requestContainingDirectory: void 0,
                reportDiagnostic: (diag2) => void diagnostics.push(diag2),
                isConfigLookup: false,
                candidateIsFromPackageJsonField: false
            };
            const resolved = loadModuleFromImmediateNodeModulesDirectory(4 /* Declaration */, moduleName, globalCache, state, 
            /*typesScopeOnly*/
            false, 
            /*cache*/
            void 0, 
            /*redirectedReference*/
            void 0);
            return createResolvedModuleWithFailedLookupLocations(resolved, 
            /*isExternalLibraryImport*/
            true, failedLookupLocations, affectingLocations, diagnostics, state.resultFromCache);
        }
        function toSearchResult(value) {
            return value !== void 0 ? { value } : void 0;
        }
        function traceIfEnabled(state, diagnostic, ...args) {
            if (state.traceEnabled) {
                trace(state.host, diagnostic, ...args);
            }
        }
        var typeScriptVersion, nodeModulesAtTypes, NodeResolutionFeatures, nodeModulesPathPart, mangledScopedPackageSeparator;
        var init_moduleNameResolver = __esm({
            "src/compiler/moduleNameResolver.ts"() {
                "use strict";
                init_ts2();
                nodeModulesAtTypes = combinePaths("node_modules", "@types");
                NodeResolutionFeatures = /* @__PURE__ */ ((NodeResolutionFeatures2) => {
                    NodeResolutionFeatures2[NodeResolutionFeatures2["None"] = 0] = "None";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["Imports"] = 2] = "Imports";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["SelfName"] = 4] = "SelfName";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["Exports"] = 8] = "Exports";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["ExportsPatternTrailers"] = 16] = "ExportsPatternTrailers";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["AllFeatures"] = 30] = "AllFeatures";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["Node16Default"] = 30] = "Node16Default";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["NodeNextDefault"] = 30 /* AllFeatures */] = "NodeNextDefault";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["BundlerDefault"] = 30] = "BundlerDefault";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["EsmMode"] = 32] = "EsmMode";
                    return NodeResolutionFeatures2;
                })(NodeResolutionFeatures || {});
                nodeModulesPathPart = "/node_modules/";
                mangledScopedPackageSeparator = "__";
            }
        });
        // src/compiler/binder.ts
        function getModuleInstanceState(node, visited) {
            if (node.body && !node.body.parent) {
                setParent(node.body, node);
                setParentRecursive(node.body, 
                /*incremental*/
                false);
            }
            return node.body ? getModuleInstanceStateCached(node.body, visited) : 1 /* Instantiated */;
        }
        function getModuleInstanceStateCached(node, visited = /* @__PURE__ */ new Map()) {
            const nodeId = getNodeId(node);
            if (visited.has(nodeId)) {
                return visited.get(nodeId) || 0 /* NonInstantiated */;
            }
            visited.set(nodeId, void 0);
            const result = getModuleInstanceStateWorker(node, visited);
            visited.set(nodeId, result);
            return result;
        }
        function getModuleInstanceStateWorker(node, visited) {
            switch (node.kind) {
                case 261 /* InterfaceDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                    return 0 /* NonInstantiated */;
                case 263 /* EnumDeclaration */:
                    if (isEnumConst(node)) {
                        return 2 /* ConstEnumOnly */;
                    }
                    break;
                case 269 /* ImportDeclaration */:
                case 268 /* ImportEqualsDeclaration */:
                    if (!hasSyntacticModifier(node, 1 /* Export */)) {
                        return 0 /* NonInstantiated */;
                    }
                    break;
                case 275 /* ExportDeclaration */:
                    const exportDeclaration = node;
                    if (!exportDeclaration.moduleSpecifier && exportDeclaration.exportClause && exportDeclaration.exportClause.kind === 276 /* NamedExports */) {
                        let state = 0 /* NonInstantiated */;
                        for (const specifier of exportDeclaration.exportClause.elements) {
                            const specifierState = getModuleInstanceStateForAliasTarget(specifier, visited);
                            if (specifierState > state) {
                                state = specifierState;
                            }
                            if (state === 1 /* Instantiated */) {
                                return state;
                            }
                        }
                        return state;
                    }
                    break;
                case 265 /* ModuleBlock */: {
                    let state = 0 /* NonInstantiated */;
                    forEachChild(node, (n) => {
                        const childState = getModuleInstanceStateCached(n, visited);
                        switch (childState) {
                            case 0 /* NonInstantiated */:
                                return;
                            case 2 /* ConstEnumOnly */:
                                state = 2 /* ConstEnumOnly */;
                                return;
                            case 1 /* Instantiated */:
                                state = 1 /* Instantiated */;
                                return true;
                            default:
                                Debug.assertNever(childState);
                        }
                    });
                    return state;
                }
                case 264 /* ModuleDeclaration */:
                    return getModuleInstanceState(node, visited);
                case 79 /* Identifier */:
                    if (node.flags & 2048 /* IdentifierIsInJSDocNamespace */) {
                        return 0 /* NonInstantiated */;
                    }
            }
            return 1 /* Instantiated */;
        }
        function getModuleInstanceStateForAliasTarget(specifier, visited) {
            const name = specifier.propertyName || specifier.name;
            let p = specifier.parent;
            while (p) {
                if (isBlock(p) || isModuleBlock(p) || isSourceFile(p)) {
                    const statements = p.statements;
                    let found;
                    for (const statement of statements) {
                        if (nodeHasName(statement, name)) {
                            if (!statement.parent) {
                                setParent(statement, p);
                                setParentRecursive(statement, 
                                /*incremental*/
                                false);
                            }
                            const state = getModuleInstanceStateCached(statement, visited);
                            if (found === void 0 || state > found) {
                                found = state;
                            }
                            if (found === 1 /* Instantiated */) {
                                return found;
                            }
                        }
                    }
                    if (found !== void 0) {
                        return found;
                    }
                }
                p = p.parent;
            }
            return 1 /* Instantiated */;
        }
        function initFlowNode(node) {
            Debug.attachFlowNodeDebugInfo(node);
            return node;
        }
        function bindSourceFile(file, options) {
            mark("beforeBind");
            perfLogger.logStartBindFile("" + file.fileName);
            binder(file, options);
            perfLogger.logStopBindFile();
            mark("afterBind");
            measure("Bind", "beforeBind", "afterBind");
        }
        function createBinder() {
            var file;
            var options;
            var languageVersion;
            var parent2;
            var container;
            var thisParentContainer;
            var blockScopeContainer;
            var lastContainer;
            var delayedTypeAliases;
            var seenThisKeyword;
            var currentFlow;
            var currentBreakTarget;
            var currentContinueTarget;
            var currentReturnTarget;
            var currentTrueTarget;
            var currentFalseTarget;
            var currentExceptionTarget;
            var preSwitchCaseFlow;
            var activeLabelList;
            var hasExplicitReturn;
            var emitFlags;
            var inStrictMode;
            var inAssignmentPattern = false;
            var symbolCount = 0;
            var Symbol46;
            var classifiableNames;
            var unreachableFlow = { flags: 1 /* Unreachable */ };
            var reportedUnreachableFlow = { flags: 1 /* Unreachable */ };
            var bindBinaryExpressionFlow = createBindBinaryExpressionFlow();
            return bindSourceFile2;
            function createDiagnosticForNode2(node, message, arg0, arg1, arg2) {
                return createDiagnosticForNodeInSourceFile(getSourceFileOfNode(node) || file, node, message, arg0, arg1, arg2);
            }
            function bindSourceFile2(f, opts) {
                var _a2, _b;
                file = f;
                options = opts;
                languageVersion = getEmitScriptTarget(options);
                inStrictMode = bindInStrictMode(file, opts);
                classifiableNames = /* @__PURE__ */ new Set();
                symbolCount = 0;
                Symbol46 = objectAllocator.getSymbolConstructor();
                Debug.attachFlowNodeDebugInfo(unreachableFlow);
                Debug.attachFlowNodeDebugInfo(reportedUnreachableFlow);
                if (!file.locals) {
                    (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Bind, "bindSourceFile", { path: file.path }, 
                    /*separateBeginAndEnd*/
                    true);
                    bind(file);
                    (_b = tracing) == null ? void 0 : _b.pop();
                    file.symbolCount = symbolCount;
                    file.classifiableNames = classifiableNames;
                    delayedBindJSDocTypedefTag();
                }
                file = void 0;
                options = void 0;
                languageVersion = void 0;
                parent2 = void 0;
                container = void 0;
                thisParentContainer = void 0;
                blockScopeContainer = void 0;
                lastContainer = void 0;
                delayedTypeAliases = void 0;
                seenThisKeyword = false;
                currentFlow = void 0;
                currentBreakTarget = void 0;
                currentContinueTarget = void 0;
                currentReturnTarget = void 0;
                currentTrueTarget = void 0;
                currentFalseTarget = void 0;
                currentExceptionTarget = void 0;
                activeLabelList = void 0;
                hasExplicitReturn = false;
                inAssignmentPattern = false;
                emitFlags = 0 /* None */;
            }
            function bindInStrictMode(file2, opts) {
                if (getStrictOptionValue(opts, "alwaysStrict") && !file2.isDeclarationFile) {
                    return true;
                }
                else {
                    return !!file2.externalModuleIndicator;
                }
            }
            function createSymbol(flags, name) {
                symbolCount++;
                return new Symbol46(flags, name);
            }
            function addDeclarationToSymbol(symbol, node, symbolFlags) {
                symbol.flags |= symbolFlags;
                node.symbol = symbol;
                symbol.declarations = appendIfUnique(symbol.declarations, node);
                if (symbolFlags & (32 /* Class */ | 384 /* Enum */ | 1536 /* Module */ | 3 /* Variable */) && !symbol.exports) {
                    symbol.exports = createSymbolTable();
                }
                if (symbolFlags & (32 /* Class */ | 64 /* Interface */ | 2048 /* TypeLiteral */ | 4096 /* ObjectLiteral */) && !symbol.members) {
                    symbol.members = createSymbolTable();
                }
                if (symbol.constEnumOnlyModule && symbol.flags & (16 /* Function */ | 32 /* Class */ | 256 /* RegularEnum */)) {
                    symbol.constEnumOnlyModule = false;
                }
                if (symbolFlags & 111551 /* Value */) {
                    setValueDeclaration(symbol, node);
                }
            }
            function getDeclarationName(node) {
                if (node.kind === 274 /* ExportAssignment */) {
                    return node.isExportEquals ? "export=" /* ExportEquals */ : "default" /* Default */;
                }
                const name = getNameOfDeclaration(node);
                if (name) {
                    if (isAmbientModule(node)) {
                        const moduleName = getTextOfIdentifierOrLiteral(name);
                        return isGlobalScopeAugmentation(node) ? "__global" : `"${moduleName}"`;
                    }
                    if (name.kind === 164 /* ComputedPropertyName */) {
                        const nameExpression = name.expression;
                        if (isStringOrNumericLiteralLike(nameExpression)) {
                            return escapeLeadingUnderscores(nameExpression.text);
                        }
                        if (isSignedNumericLiteral(nameExpression)) {
                            return tokenToString(nameExpression.operator) + nameExpression.operand.text;
                        }
                        else {
                            Debug.fail("Only computed properties with literal names have declaration names");
                        }
                    }
                    if (isPrivateIdentifier(name)) {
                        const containingClass = getContainingClass(node);
                        if (!containingClass) {
                            return void 0;
                        }
                        const containingClassSymbol = containingClass.symbol;
                        return getSymbolNameForPrivateIdentifier(containingClassSymbol, name.escapedText);
                    }
                    return isPropertyNameLiteral(name) ? getEscapedTextOfIdentifierOrLiteral(name) : void 0;
                }
                switch (node.kind) {
                    case 173 /* Constructor */:
                        return "__constructor" /* Constructor */;
                    case 181 /* FunctionType */:
                    case 176 /* CallSignature */:
                    case 326 /* JSDocSignature */:
                        return "__call" /* Call */;
                    case 182 /* ConstructorType */:
                    case 177 /* ConstructSignature */:
                        return "__new" /* New */;
                    case 178 /* IndexSignature */:
                        return "__index" /* Index */;
                    case 275 /* ExportDeclaration */:
                        return "__export" /* ExportStar */;
                    case 308 /* SourceFile */:
                        return "export=" /* ExportEquals */;
                    case 223 /* BinaryExpression */:
                        if (getAssignmentDeclarationKind(node) === 2 /* ModuleExports */) {
                            return "export=" /* ExportEquals */;
                        }
                        Debug.fail("Unknown binary declaration kind");
                        break;
                    case 320 /* JSDocFunctionType */:
                        return isJSDocConstructSignature(node) ? "__new" /* New */ : "__call" /* Call */;
                    case 166 /* Parameter */:
                        Debug.assert(node.parent.kind === 320 /* JSDocFunctionType */, "Impossible parameter parent kind", () => `parent is: ${Debug.formatSyntaxKind(node.parent.kind)}, expected JSDocFunctionType`);
                        const functionType = node.parent;
                        const index = functionType.parameters.indexOf(node);
                        return "arg" + index;
                }
            }
            function getDisplayName(node) {
                return isNamedDeclaration(node) ? declarationNameToString(node.name) : unescapeLeadingUnderscores(Debug.checkDefined(getDeclarationName(node)));
            }
            function declareSymbol(symbolTable, parent3, node, includes, excludes, isReplaceableByMethod, isComputedName) {
                Debug.assert(isComputedName || !hasDynamicName(node));
                const isDefaultExport = hasSyntacticModifier(node, 1024 /* Default */) || isExportSpecifier(node) && node.name.escapedText === "default";
                const name = isComputedName ? "__computed" /* Computed */ : isDefaultExport && parent3 ? "default" /* Default */ : getDeclarationName(node);
                let symbol;
                if (name === void 0) {
                    symbol = createSymbol(0 /* None */, "__missing" /* Missing */);
                }
                else {
                    symbol = symbolTable.get(name);
                    if (includes & 2885600 /* Classifiable */) {
                        classifiableNames.add(name);
                    }
                    if (!symbol) {
                        symbolTable.set(name, symbol = createSymbol(0 /* None */, name));
                        if (isReplaceableByMethod)
                            symbol.isReplaceableByMethod = true;
                    }
                    else if (isReplaceableByMethod && !symbol.isReplaceableByMethod) {
                        return symbol;
                    }
                    else if (symbol.flags & excludes) {
                        if (symbol.isReplaceableByMethod) {
                            symbolTable.set(name, symbol = createSymbol(0 /* None */, name));
                        }
                        else if (!(includes & 3 /* Variable */ && symbol.flags & 67108864 /* Assignment */)) {
                            if (isNamedDeclaration(node)) {
                                setParent(node.name, node);
                            }
                            let message = symbol.flags & 2 /* BlockScopedVariable */ ? Diagnostics.Cannot_redeclare_block_scoped_variable_0 : Diagnostics.Duplicate_identifier_0;
                            let messageNeedsName = true;
                            if (symbol.flags & 384 /* Enum */ || includes & 384 /* Enum */) {
                                message = Diagnostics.Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations;
                                messageNeedsName = false;
                            }
                            let multipleDefaultExports = false;
                            if (length(symbol.declarations)) {
                                if (isDefaultExport) {
                                    message = Diagnostics.A_module_cannot_have_multiple_default_exports;
                                    messageNeedsName = false;
                                    multipleDefaultExports = true;
                                }
                                else {
                                    if (symbol.declarations && symbol.declarations.length && (node.kind === 274 /* ExportAssignment */ && !node.isExportEquals)) {
                                        message = Diagnostics.A_module_cannot_have_multiple_default_exports;
                                        messageNeedsName = false;
                                        multipleDefaultExports = true;
                                    }
                                }
                            }
                            const relatedInformation = [];
                            if (isTypeAliasDeclaration(node) && nodeIsMissing(node.type) && hasSyntacticModifier(node, 1 /* Export */) && symbol.flags & (2097152 /* Alias */ | 788968 /* Type */ | 1920 /* Namespace */)) {
                                relatedInformation.push(createDiagnosticForNode2(node, Diagnostics.Did_you_mean_0, `export type { ${unescapeLeadingUnderscores(node.name.escapedText)} }`));
                            }
                            const declarationName = getNameOfDeclaration(node) || node;
                            forEach(symbol.declarations, (declaration, index) => {
                                const decl = getNameOfDeclaration(declaration) || declaration;
                                const diag3 = createDiagnosticForNode2(decl, message, messageNeedsName ? getDisplayName(declaration) : void 0);
                                file.bindDiagnostics.push(multipleDefaultExports ? addRelatedInfo(diag3, createDiagnosticForNode2(declarationName, index === 0 ? Diagnostics.Another_export_default_is_here : Diagnostics.and_here)) : diag3);
                                if (multipleDefaultExports) {
                                    relatedInformation.push(createDiagnosticForNode2(decl, Diagnostics.The_first_export_default_is_here));
                                }
                            });
                            const diag2 = createDiagnosticForNode2(declarationName, message, messageNeedsName ? getDisplayName(node) : void 0);
                            file.bindDiagnostics.push(addRelatedInfo(diag2, ...relatedInformation));
                            symbol = createSymbol(0 /* None */, name);
                        }
                    }
                }
                addDeclarationToSymbol(symbol, node, includes);
                if (symbol.parent) {
                    Debug.assert(symbol.parent === parent3, "Existing symbol parent should match new one");
                }
                else {
                    symbol.parent = parent3;
                }
                return symbol;
            }
            function declareModuleMember(node, symbolFlags, symbolExcludes) {
                const hasExportModifier = !!(getCombinedModifierFlags(node) & 1 /* Export */) || jsdocTreatAsExported(node);
                if (symbolFlags & 2097152 /* Alias */) {
                    if (node.kind === 278 /* ExportSpecifier */ || node.kind === 268 /* ImportEqualsDeclaration */ && hasExportModifier) {
                        return declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
                    }
                    else {
                        Debug.assertNode(container, canHaveLocals);
                        return declareSymbol(container.locals, 
                        /*parent*/
                        void 0, node, symbolFlags, symbolExcludes);
                    }
                }
                else {
                    if (isJSDocTypeAlias(node))
                        Debug.assert(isInJSFile(node));
                    if (!isAmbientModule(node) && (hasExportModifier || container.flags & 64 /* ExportContext */)) {
                        if (!canHaveLocals(container) || !container.locals || hasSyntacticModifier(node, 1024 /* Default */) && !getDeclarationName(node)) {
                            return declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
                        }
                        const exportKind = symbolFlags & 111551 /* Value */ ? 1048576 /* ExportValue */ : 0;
                        const local = declareSymbol(container.locals, 
                        /*parent*/
                        void 0, node, exportKind, symbolExcludes);
                        local.exportSymbol = declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
                        node.localSymbol = local;
                        return local;
                    }
                    else {
                        Debug.assertNode(container, canHaveLocals);
                        return declareSymbol(container.locals, 
                        /*parent*/
                        void 0, node, symbolFlags, symbolExcludes);
                    }
                }
            }
            function jsdocTreatAsExported(node) {
                if (node.parent && isModuleDeclaration(node)) {
                    node = node.parent;
                }
                if (!isJSDocTypeAlias(node))
                    return false;
                if (!isJSDocEnumTag(node) && !!node.fullName)
                    return true;
                const declName = getNameOfDeclaration(node);
                if (!declName)
                    return false;
                if (isPropertyAccessEntityNameExpression(declName.parent) && isTopLevelNamespaceAssignment(declName.parent))
                    return true;
                if (isDeclaration(declName.parent) && getCombinedModifierFlags(declName.parent) & 1 /* Export */)
                    return true;
                return false;
            }
            function bindContainer(node, containerFlags) {
                const saveContainer = container;
                const saveThisParentContainer = thisParentContainer;
                const savedBlockScopeContainer = blockScopeContainer;
                if (containerFlags & 1 /* IsContainer */) {
                    if (node.kind !== 216 /* ArrowFunction */) {
                        thisParentContainer = container;
                    }
                    container = blockScopeContainer = node;
                    if (containerFlags & 32 /* HasLocals */) {
                        container.locals = createSymbolTable();
                        addToContainerChain(container);
                    }
                }
                else if (containerFlags & 2 /* IsBlockScopedContainer */) {
                    blockScopeContainer = node;
                    if (containerFlags & 32 /* HasLocals */) {
                        blockScopeContainer.locals = void 0;
                    }
                }
                if (containerFlags & 4 /* IsControlFlowContainer */) {
                    const saveCurrentFlow = currentFlow;
                    const saveBreakTarget = currentBreakTarget;
                    const saveContinueTarget = currentContinueTarget;
                    const saveReturnTarget = currentReturnTarget;
                    const saveExceptionTarget = currentExceptionTarget;
                    const saveActiveLabelList = activeLabelList;
                    const saveHasExplicitReturn = hasExplicitReturn;
                    const isImmediatelyInvoked = containerFlags & 16 /* IsFunctionExpression */ && !hasSyntacticModifier(node, 512 /* Async */) && !node.asteriskToken && !!getImmediatelyInvokedFunctionExpression(node) || node.kind === 172 /* ClassStaticBlockDeclaration */;
                    if (!isImmediatelyInvoked) {
                        currentFlow = initFlowNode({ flags: 2 /* Start */ });
                        if (containerFlags & (16 /* IsFunctionExpression */ | 128 /* IsObjectLiteralOrClassExpressionMethodOrAccessor */)) {
                            currentFlow.node = node;
                        }
                    }
                    currentReturnTarget = isImmediatelyInvoked || node.kind === 173 /* Constructor */ || isInJSFile(node) && (node.kind === 259 /* FunctionDeclaration */ || node.kind === 215 /* FunctionExpression */) ? createBranchLabel() : void 0;
                    currentExceptionTarget = void 0;
                    currentBreakTarget = void 0;
                    currentContinueTarget = void 0;
                    activeLabelList = void 0;
                    hasExplicitReturn = false;
                    bindChildren(node);
                    node.flags &= ~2816 /* ReachabilityAndEmitFlags */;
                    if (!(currentFlow.flags & 1 /* Unreachable */) && containerFlags & 8 /* IsFunctionLike */ && nodeIsPresent(node.body)) {
                        node.flags |= 256 /* HasImplicitReturn */;
                        if (hasExplicitReturn)
                            node.flags |= 512 /* HasExplicitReturn */;
                        node.endFlowNode = currentFlow;
                    }
                    if (node.kind === 308 /* SourceFile */) {
                        node.flags |= emitFlags;
                        node.endFlowNode = currentFlow;
                    }
                    if (currentReturnTarget) {
                        addAntecedent(currentReturnTarget, currentFlow);
                        currentFlow = finishFlowLabel(currentReturnTarget);
                        if (node.kind === 173 /* Constructor */ || node.kind === 172 /* ClassStaticBlockDeclaration */ || isInJSFile(node) && (node.kind === 259 /* FunctionDeclaration */ || node.kind === 215 /* FunctionExpression */)) {
                            node.returnFlowNode = currentFlow;
                        }
                    }
                    if (!isImmediatelyInvoked) {
                        currentFlow = saveCurrentFlow;
                    }
                    currentBreakTarget = saveBreakTarget;
                    currentContinueTarget = saveContinueTarget;
                    currentReturnTarget = saveReturnTarget;
                    currentExceptionTarget = saveExceptionTarget;
                    activeLabelList = saveActiveLabelList;
                    hasExplicitReturn = saveHasExplicitReturn;
                }
                else if (containerFlags & 64 /* IsInterface */) {
                    seenThisKeyword = false;
                    bindChildren(node);
                    Debug.assertNotNode(node, isIdentifier);
                    node.flags = seenThisKeyword ? node.flags | 128 /* ContainsThis */ : node.flags & ~128 /* ContainsThis */;
                }
                else {
                    bindChildren(node);
                }
                container = saveContainer;
                thisParentContainer = saveThisParentContainer;
                blockScopeContainer = savedBlockScopeContainer;
            }
            function bindEachFunctionsFirst(nodes) {
                bindEach(nodes, (n) => n.kind === 259 /* FunctionDeclaration */ ? bind(n) : void 0);
                bindEach(nodes, (n) => n.kind !== 259 /* FunctionDeclaration */ ? bind(n) : void 0);
            }
            function bindEach(nodes, bindFunction = bind) {
                if (nodes === void 0) {
                    return;
                }
                forEach(nodes, bindFunction);
            }
            function bindEachChild(node) {
                forEachChild(node, bind, bindEach);
            }
            function bindChildren(node) {
                const saveInAssignmentPattern = inAssignmentPattern;
                inAssignmentPattern = false;
                if (checkUnreachable(node)) {
                    bindEachChild(node);
                    bindJSDoc(node);
                    inAssignmentPattern = saveInAssignmentPattern;
                    return;
                }
                if (node.kind >= 240 /* FirstStatement */ && node.kind <= 256 /* LastStatement */ && !options.allowUnreachableCode) {
                    node.flowNode = currentFlow;
                }
                switch (node.kind) {
                    case 244 /* WhileStatement */:
                        bindWhileStatement(node);
                        break;
                    case 243 /* DoStatement */:
                        bindDoStatement(node);
                        break;
                    case 245 /* ForStatement */:
                        bindForStatement(node);
                        break;
                    case 246 /* ForInStatement */:
                    case 247 /* ForOfStatement */:
                        bindForInOrForOfStatement(node);
                        break;
                    case 242 /* IfStatement */:
                        bindIfStatement(node);
                        break;
                    case 250 /* ReturnStatement */:
                    case 254 /* ThrowStatement */:
                        bindReturnOrThrow(node);
                        break;
                    case 249 /* BreakStatement */:
                    case 248 /* ContinueStatement */:
                        bindBreakOrContinueStatement(node);
                        break;
                    case 255 /* TryStatement */:
                        bindTryStatement(node);
                        break;
                    case 252 /* SwitchStatement */:
                        bindSwitchStatement(node);
                        break;
                    case 266 /* CaseBlock */:
                        bindCaseBlock(node);
                        break;
                    case 292 /* CaseClause */:
                        bindCaseClause(node);
                        break;
                    case 241 /* ExpressionStatement */:
                        bindExpressionStatement(node);
                        break;
                    case 253 /* LabeledStatement */:
                        bindLabeledStatement(node);
                        break;
                    case 221 /* PrefixUnaryExpression */:
                        bindPrefixUnaryExpressionFlow(node);
                        break;
                    case 222 /* PostfixUnaryExpression */:
                        bindPostfixUnaryExpressionFlow(node);
                        break;
                    case 223 /* BinaryExpression */:
                        if (isDestructuringAssignment(node)) {
                            inAssignmentPattern = saveInAssignmentPattern;
                            bindDestructuringAssignmentFlow(node);
                            return;
                        }
                        bindBinaryExpressionFlow(node);
                        break;
                    case 217 /* DeleteExpression */:
                        bindDeleteExpressionFlow(node);
                        break;
                    case 224 /* ConditionalExpression */:
                        bindConditionalExpressionFlow(node);
                        break;
                    case 257 /* VariableDeclaration */:
                        bindVariableDeclarationFlow(node);
                        break;
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        bindAccessExpressionFlow(node);
                        break;
                    case 210 /* CallExpression */:
                        bindCallExpressionFlow(node);
                        break;
                    case 232 /* NonNullExpression */:
                        bindNonNullExpressionFlow(node);
                        break;
                    case 349 /* JSDocTypedefTag */:
                    case 341 /* JSDocCallbackTag */:
                    case 343 /* JSDocEnumTag */:
                        bindJSDocTypeAlias(node);
                        break;
                    case 308 /* SourceFile */: {
                        bindEachFunctionsFirst(node.statements);
                        bind(node.endOfFileToken);
                        break;
                    }
                    case 238 /* Block */:
                    case 265 /* ModuleBlock */:
                        bindEachFunctionsFirst(node.statements);
                        break;
                    case 205 /* BindingElement */:
                        bindBindingElementFlow(node);
                        break;
                    case 166 /* Parameter */:
                        bindParameterFlow(node);
                        break;
                    case 207 /* ObjectLiteralExpression */:
                    case 206 /* ArrayLiteralExpression */:
                    case 299 /* PropertyAssignment */:
                    case 227 /* SpreadElement */:
                        inAssignmentPattern = saveInAssignmentPattern;
                    default:
                        bindEachChild(node);
                        break;
                }
                bindJSDoc(node);
                inAssignmentPattern = saveInAssignmentPattern;
            }
            function isNarrowingExpression(expr) {
                switch (expr.kind) {
                    case 79 /* Identifier */:
                    case 80 /* PrivateIdentifier */:
                    case 108 /* ThisKeyword */:
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        return containsNarrowableReference(expr);
                    case 210 /* CallExpression */:
                        return hasNarrowableArgument(expr);
                    case 214 /* ParenthesizedExpression */:
                    case 232 /* NonNullExpression */:
                        return isNarrowingExpression(expr.expression);
                    case 223 /* BinaryExpression */:
                        return isNarrowingBinaryExpression(expr);
                    case 221 /* PrefixUnaryExpression */:
                        return expr.operator === 53 /* ExclamationToken */ && isNarrowingExpression(expr.operand);
                    case 218 /* TypeOfExpression */:
                        return isNarrowingExpression(expr.expression);
                }
                return false;
            }
            function isNarrowableReference(expr) {
                return isDottedName(expr) || (isPropertyAccessExpression(expr) || isNonNullExpression(expr) || isParenthesizedExpression(expr)) && isNarrowableReference(expr.expression) || isBinaryExpression(expr) && expr.operatorToken.kind === 27 /* CommaToken */ && isNarrowableReference(expr.right) || isElementAccessExpression(expr) && (isStringOrNumericLiteralLike(expr.argumentExpression) || isEntityNameExpression(expr.argumentExpression)) && isNarrowableReference(expr.expression) || isAssignmentExpression(expr) && isNarrowableReference(expr.left);
            }
            function containsNarrowableReference(expr) {
                return isNarrowableReference(expr) || isOptionalChain(expr) && containsNarrowableReference(expr.expression);
            }
            function hasNarrowableArgument(expr) {
                if (expr.arguments) {
                    for (const argument of expr.arguments) {
                        if (containsNarrowableReference(argument)) {
                            return true;
                        }
                    }
                }
                if (expr.expression.kind === 208 /* PropertyAccessExpression */ && containsNarrowableReference(expr.expression.expression)) {
                    return true;
                }
                return false;
            }
            function isNarrowingTypeofOperands(expr1, expr2) {
                return isTypeOfExpression(expr1) && isNarrowableOperand(expr1.expression) && isStringLiteralLike(expr2);
            }
            function isNarrowingBinaryExpression(expr) {
                switch (expr.operatorToken.kind) {
                    case 63 /* EqualsToken */:
                    case 75 /* BarBarEqualsToken */:
                    case 76 /* AmpersandAmpersandEqualsToken */:
                    case 77 /* QuestionQuestionEqualsToken */:
                        return containsNarrowableReference(expr.left);
                    case 34 /* EqualsEqualsToken */:
                    case 35 /* ExclamationEqualsToken */:
                    case 36 /* EqualsEqualsEqualsToken */:
                    case 37 /* ExclamationEqualsEqualsToken */:
                        return isNarrowableOperand(expr.left) || isNarrowableOperand(expr.right) || isNarrowingTypeofOperands(expr.right, expr.left) || isNarrowingTypeofOperands(expr.left, expr.right);
                    case 102 /* InstanceOfKeyword */:
                        return isNarrowableOperand(expr.left);
                    case 101 /* InKeyword */:
                        return isNarrowingExpression(expr.right);
                    case 27 /* CommaToken */:
                        return isNarrowingExpression(expr.right);
                }
                return false;
            }
            function isNarrowableOperand(expr) {
                switch (expr.kind) {
                    case 214 /* ParenthesizedExpression */:
                        return isNarrowableOperand(expr.expression);
                    case 223 /* BinaryExpression */:
                        switch (expr.operatorToken.kind) {
                            case 63 /* EqualsToken */:
                                return isNarrowableOperand(expr.left);
                            case 27 /* CommaToken */:
                                return isNarrowableOperand(expr.right);
                        }
                }
                return containsNarrowableReference(expr);
            }
            function createBranchLabel() {
                return initFlowNode({ flags: 4 /* BranchLabel */, antecedents: void 0 });
            }
            function createLoopLabel() {
                return initFlowNode({ flags: 8 /* LoopLabel */, antecedents: void 0 });
            }
            function createReduceLabel(target, antecedents, antecedent) {
                return initFlowNode({ flags: 1024 /* ReduceLabel */, target, antecedents, antecedent });
            }
            function setFlowNodeReferenced(flow) {
                flow.flags |= flow.flags & 2048 /* Referenced */ ? 4096 /* Shared */ : 2048 /* Referenced */;
            }
            function addAntecedent(label, antecedent) {
                if (!(antecedent.flags & 1 /* Unreachable */) && !contains(label.antecedents, antecedent)) {
                    (label.antecedents || (label.antecedents = [])).push(antecedent);
                    setFlowNodeReferenced(antecedent);
                }
            }
            function createFlowCondition(flags, antecedent, expression) {
                if (antecedent.flags & 1 /* Unreachable */) {
                    return antecedent;
                }
                if (!expression) {
                    return flags & 32 /* TrueCondition */ ? antecedent : unreachableFlow;
                }
                if ((expression.kind === 110 /* TrueKeyword */ && flags & 64 /* FalseCondition */ || expression.kind === 95 /* FalseKeyword */ && flags & 32 /* TrueCondition */) && !isExpressionOfOptionalChainRoot(expression) && !isNullishCoalesce(expression.parent)) {
                    return unreachableFlow;
                }
                if (!isNarrowingExpression(expression)) {
                    return antecedent;
                }
                setFlowNodeReferenced(antecedent);
                return initFlowNode({ flags, antecedent, node: expression });
            }
            function createFlowSwitchClause(antecedent, switchStatement, clauseStart, clauseEnd) {
                setFlowNodeReferenced(antecedent);
                return initFlowNode({ flags: 128 /* SwitchClause */, antecedent, switchStatement, clauseStart, clauseEnd });
            }
            function createFlowMutation(flags, antecedent, node) {
                setFlowNodeReferenced(antecedent);
                const result = initFlowNode({ flags, antecedent, node });
                if (currentExceptionTarget) {
                    addAntecedent(currentExceptionTarget, result);
                }
                return result;
            }
            function createFlowCall(antecedent, node) {
                setFlowNodeReferenced(antecedent);
                return initFlowNode({ flags: 512 /* Call */, antecedent, node });
            }
            function finishFlowLabel(flow) {
                const antecedents = flow.antecedents;
                if (!antecedents) {
                    return unreachableFlow;
                }
                if (antecedents.length === 1) {
                    return antecedents[0];
                }
                return flow;
            }
            function isStatementCondition(node) {
                const parent3 = node.parent;
                switch (parent3.kind) {
                    case 242 /* IfStatement */:
                    case 244 /* WhileStatement */:
                    case 243 /* DoStatement */:
                        return parent3.expression === node;
                    case 245 /* ForStatement */:
                    case 224 /* ConditionalExpression */:
                        return parent3.condition === node;
                }
                return false;
            }
            function isLogicalExpression(node) {
                while (true) {
                    if (node.kind === 214 /* ParenthesizedExpression */) {
                        node = node.expression;
                    }
                    else if (node.kind === 221 /* PrefixUnaryExpression */ && node.operator === 53 /* ExclamationToken */) {
                        node = node.operand;
                    }
                    else {
                        return isLogicalOrCoalescingBinaryExpression(node);
                    }
                }
            }
            function isLogicalAssignmentExpression(node) {
                return isLogicalOrCoalescingAssignmentExpression(skipParentheses(node));
            }
            function isTopLevelLogicalExpression(node) {
                while (isParenthesizedExpression(node.parent) || isPrefixUnaryExpression(node.parent) && node.parent.operator === 53 /* ExclamationToken */) {
                    node = node.parent;
                }
                return !isStatementCondition(node) && !isLogicalExpression(node.parent) && !(isOptionalChain(node.parent) && node.parent.expression === node);
            }
            function doWithConditionalBranches(action, value, trueTarget, falseTarget) {
                const savedTrueTarget = currentTrueTarget;
                const savedFalseTarget = currentFalseTarget;
                currentTrueTarget = trueTarget;
                currentFalseTarget = falseTarget;
                action(value);
                currentTrueTarget = savedTrueTarget;
                currentFalseTarget = savedFalseTarget;
            }
            function bindCondition(node, trueTarget, falseTarget) {
                doWithConditionalBranches(bind, node, trueTarget, falseTarget);
                if (!node || !isLogicalAssignmentExpression(node) && !isLogicalExpression(node) && !(isOptionalChain(node) && isOutermostOptionalChain(node))) {
                    addAntecedent(trueTarget, createFlowCondition(32 /* TrueCondition */, currentFlow, node));
                    addAntecedent(falseTarget, createFlowCondition(64 /* FalseCondition */, currentFlow, node));
                }
            }
            function bindIterativeStatement(node, breakTarget, continueTarget) {
                const saveBreakTarget = currentBreakTarget;
                const saveContinueTarget = currentContinueTarget;
                currentBreakTarget = breakTarget;
                currentContinueTarget = continueTarget;
                bind(node);
                currentBreakTarget = saveBreakTarget;
                currentContinueTarget = saveContinueTarget;
            }
            function setContinueTarget(node, target) {
                let label = activeLabelList;
                while (label && node.parent.kind === 253 /* LabeledStatement */) {
                    label.continueTarget = target;
                    label = label.next;
                    node = node.parent;
                }
                return target;
            }
            function bindWhileStatement(node) {
                const preWhileLabel = setContinueTarget(node, createLoopLabel());
                const preBodyLabel = createBranchLabel();
                const postWhileLabel = createBranchLabel();
                addAntecedent(preWhileLabel, currentFlow);
                currentFlow = preWhileLabel;
                bindCondition(node.expression, preBodyLabel, postWhileLabel);
                currentFlow = finishFlowLabel(preBodyLabel);
                bindIterativeStatement(node.statement, postWhileLabel, preWhileLabel);
                addAntecedent(preWhileLabel, currentFlow);
                currentFlow = finishFlowLabel(postWhileLabel);
            }
            function bindDoStatement(node) {
                const preDoLabel = createLoopLabel();
                const preConditionLabel = setContinueTarget(node, createBranchLabel());
                const postDoLabel = createBranchLabel();
                addAntecedent(preDoLabel, currentFlow);
                currentFlow = preDoLabel;
                bindIterativeStatement(node.statement, postDoLabel, preConditionLabel);
                addAntecedent(preConditionLabel, currentFlow);
                currentFlow = finishFlowLabel(preConditionLabel);
                bindCondition(node.expression, preDoLabel, postDoLabel);
                currentFlow = finishFlowLabel(postDoLabel);
            }
            function bindForStatement(node) {
                const preLoopLabel = setContinueTarget(node, createLoopLabel());
                const preBodyLabel = createBranchLabel();
                const postLoopLabel = createBranchLabel();
                bind(node.initializer);
                addAntecedent(preLoopLabel, currentFlow);
                currentFlow = preLoopLabel;
                bindCondition(node.condition, preBodyLabel, postLoopLabel);
                currentFlow = finishFlowLabel(preBodyLabel);
                bindIterativeStatement(node.statement, postLoopLabel, preLoopLabel);
                bind(node.incrementor);
                addAntecedent(preLoopLabel, currentFlow);
                currentFlow = finishFlowLabel(postLoopLabel);
            }
            function bindForInOrForOfStatement(node) {
                const preLoopLabel = setContinueTarget(node, createLoopLabel());
                const postLoopLabel = createBranchLabel();
                bind(node.expression);
                addAntecedent(preLoopLabel, currentFlow);
                currentFlow = preLoopLabel;
                if (node.kind === 247 /* ForOfStatement */) {
                    bind(node.awaitModifier);
                }
                addAntecedent(postLoopLabel, currentFlow);
                bind(node.initializer);
                if (node.initializer.kind !== 258 /* VariableDeclarationList */) {
                    bindAssignmentTargetFlow(node.initializer);
                }
                bindIterativeStatement(node.statement, postLoopLabel, preLoopLabel);
                addAntecedent(preLoopLabel, currentFlow);
                currentFlow = finishFlowLabel(postLoopLabel);
            }
            function bindIfStatement(node) {
                const thenLabel = createBranchLabel();
                const elseLabel = createBranchLabel();
                const postIfLabel = createBranchLabel();
                bindCondition(node.expression, thenLabel, elseLabel);
                currentFlow = finishFlowLabel(thenLabel);
                bind(node.thenStatement);
                addAntecedent(postIfLabel, currentFlow);
                currentFlow = finishFlowLabel(elseLabel);
                bind(node.elseStatement);
                addAntecedent(postIfLabel, currentFlow);
                currentFlow = finishFlowLabel(postIfLabel);
            }
            function bindReturnOrThrow(node) {
                bind(node.expression);
                if (node.kind === 250 /* ReturnStatement */) {
                    hasExplicitReturn = true;
                    if (currentReturnTarget) {
                        addAntecedent(currentReturnTarget, currentFlow);
                    }
                }
                currentFlow = unreachableFlow;
            }
            function findActiveLabel(name) {
                for (let label = activeLabelList; label; label = label.next) {
                    if (label.name === name) {
                        return label;
                    }
                }
                return void 0;
            }
            function bindBreakOrContinueFlow(node, breakTarget, continueTarget) {
                const flowLabel = node.kind === 249 /* BreakStatement */ ? breakTarget : continueTarget;
                if (flowLabel) {
                    addAntecedent(flowLabel, currentFlow);
                    currentFlow = unreachableFlow;
                }
            }
            function bindBreakOrContinueStatement(node) {
                bind(node.label);
                if (node.label) {
                    const activeLabel = findActiveLabel(node.label.escapedText);
                    if (activeLabel) {
                        activeLabel.referenced = true;
                        bindBreakOrContinueFlow(node, activeLabel.breakTarget, activeLabel.continueTarget);
                    }
                }
                else {
                    bindBreakOrContinueFlow(node, currentBreakTarget, currentContinueTarget);
                }
            }
            function bindTryStatement(node) {
                const saveReturnTarget = currentReturnTarget;
                const saveExceptionTarget = currentExceptionTarget;
                const normalExitLabel = createBranchLabel();
                const returnLabel = createBranchLabel();
                let exceptionLabel = createBranchLabel();
                if (node.finallyBlock) {
                    currentReturnTarget = returnLabel;
                }
                addAntecedent(exceptionLabel, currentFlow);
                currentExceptionTarget = exceptionLabel;
                bind(node.tryBlock);
                addAntecedent(normalExitLabel, currentFlow);
                if (node.catchClause) {
                    currentFlow = finishFlowLabel(exceptionLabel);
                    exceptionLabel = createBranchLabel();
                    addAntecedent(exceptionLabel, currentFlow);
                    currentExceptionTarget = exceptionLabel;
                    bind(node.catchClause);
                    addAntecedent(normalExitLabel, currentFlow);
                }
                currentReturnTarget = saveReturnTarget;
                currentExceptionTarget = saveExceptionTarget;
                if (node.finallyBlock) {
                    const finallyLabel = createBranchLabel();
                    finallyLabel.antecedents = concatenate(concatenate(normalExitLabel.antecedents, exceptionLabel.antecedents), returnLabel.antecedents);
                    currentFlow = finallyLabel;
                    bind(node.finallyBlock);
                    if (currentFlow.flags & 1 /* Unreachable */) {
                        currentFlow = unreachableFlow;
                    }
                    else {
                        if (currentReturnTarget && returnLabel.antecedents) {
                            addAntecedent(currentReturnTarget, createReduceLabel(finallyLabel, returnLabel.antecedents, currentFlow));
                        }
                        if (currentExceptionTarget && exceptionLabel.antecedents) {
                            addAntecedent(currentExceptionTarget, createReduceLabel(finallyLabel, exceptionLabel.antecedents, currentFlow));
                        }
                        currentFlow = normalExitLabel.antecedents ? createReduceLabel(finallyLabel, normalExitLabel.antecedents, currentFlow) : unreachableFlow;
                    }
                }
                else {
                    currentFlow = finishFlowLabel(normalExitLabel);
                }
            }
            function bindSwitchStatement(node) {
                const postSwitchLabel = createBranchLabel();
                bind(node.expression);
                const saveBreakTarget = currentBreakTarget;
                const savePreSwitchCaseFlow = preSwitchCaseFlow;
                currentBreakTarget = postSwitchLabel;
                preSwitchCaseFlow = currentFlow;
                bind(node.caseBlock);
                addAntecedent(postSwitchLabel, currentFlow);
                const hasDefault = forEach(node.caseBlock.clauses, (c) => c.kind === 293 /* DefaultClause */);
                node.possiblyExhaustive = !hasDefault && !postSwitchLabel.antecedents;
                if (!hasDefault) {
                    addAntecedent(postSwitchLabel, createFlowSwitchClause(preSwitchCaseFlow, node, 0, 0));
                }
                currentBreakTarget = saveBreakTarget;
                preSwitchCaseFlow = savePreSwitchCaseFlow;
                currentFlow = finishFlowLabel(postSwitchLabel);
            }
            function bindCaseBlock(node) {
                const clauses = node.clauses;
                const isNarrowingSwitch = isNarrowingExpression(node.parent.expression);
                let fallthroughFlow = unreachableFlow;
                for (let i = 0; i < clauses.length; i++) {
                    const clauseStart = i;
                    while (!clauses[i].statements.length && i + 1 < clauses.length) {
                        bind(clauses[i]);
                        i++;
                    }
                    const preCaseLabel = createBranchLabel();
                    addAntecedent(preCaseLabel, isNarrowingSwitch ? createFlowSwitchClause(preSwitchCaseFlow, node.parent, clauseStart, i + 1) : preSwitchCaseFlow);
                    addAntecedent(preCaseLabel, fallthroughFlow);
                    currentFlow = finishFlowLabel(preCaseLabel);
                    const clause = clauses[i];
                    bind(clause);
                    fallthroughFlow = currentFlow;
                    if (!(currentFlow.flags & 1 /* Unreachable */) && i !== clauses.length - 1 && options.noFallthroughCasesInSwitch) {
                        clause.fallthroughFlowNode = currentFlow;
                    }
                }
            }
            function bindCaseClause(node) {
                const saveCurrentFlow = currentFlow;
                currentFlow = preSwitchCaseFlow;
                bind(node.expression);
                currentFlow = saveCurrentFlow;
                bindEach(node.statements);
            }
            function bindExpressionStatement(node) {
                bind(node.expression);
                maybeBindExpressionFlowIfCall(node.expression);
            }
            function maybeBindExpressionFlowIfCall(node) {
                if (node.kind === 210 /* CallExpression */) {
                    const call = node;
                    if (call.expression.kind !== 106 /* SuperKeyword */ && isDottedName(call.expression)) {
                        currentFlow = createFlowCall(currentFlow, call);
                    }
                }
            }
            function bindLabeledStatement(node) {
                const postStatementLabel = createBranchLabel();
                activeLabelList = {
                    next: activeLabelList,
                    name: node.label.escapedText,
                    breakTarget: postStatementLabel,
                    continueTarget: void 0,
                    referenced: false
                };
                bind(node.label);
                bind(node.statement);
                if (!activeLabelList.referenced && !options.allowUnusedLabels) {
                    errorOrSuggestionOnNode(unusedLabelIsError(options), node.label, Diagnostics.Unused_label);
                }
                activeLabelList = activeLabelList.next;
                addAntecedent(postStatementLabel, currentFlow);
                currentFlow = finishFlowLabel(postStatementLabel);
            }
            function bindDestructuringTargetFlow(node) {
                if (node.kind === 223 /* BinaryExpression */ && node.operatorToken.kind === 63 /* EqualsToken */) {
                    bindAssignmentTargetFlow(node.left);
                }
                else {
                    bindAssignmentTargetFlow(node);
                }
            }
            function bindAssignmentTargetFlow(node) {
                if (isNarrowableReference(node)) {
                    currentFlow = createFlowMutation(16 /* Assignment */, currentFlow, node);
                }
                else if (node.kind === 206 /* ArrayLiteralExpression */) {
                    for (const e of node.elements) {
                        if (e.kind === 227 /* SpreadElement */) {
                            bindAssignmentTargetFlow(e.expression);
                        }
                        else {
                            bindDestructuringTargetFlow(e);
                        }
                    }
                }
                else if (node.kind === 207 /* ObjectLiteralExpression */) {
                    for (const p of node.properties) {
                        if (p.kind === 299 /* PropertyAssignment */) {
                            bindDestructuringTargetFlow(p.initializer);
                        }
                        else if (p.kind === 300 /* ShorthandPropertyAssignment */) {
                            bindAssignmentTargetFlow(p.name);
                        }
                        else if (p.kind === 301 /* SpreadAssignment */) {
                            bindAssignmentTargetFlow(p.expression);
                        }
                    }
                }
            }
            function bindLogicalLikeExpression(node, trueTarget, falseTarget) {
                const preRightLabel = createBranchLabel();
                if (node.operatorToken.kind === 55 /* AmpersandAmpersandToken */ || node.operatorToken.kind === 76 /* AmpersandAmpersandEqualsToken */) {
                    bindCondition(node.left, preRightLabel, falseTarget);
                }
                else {
                    bindCondition(node.left, trueTarget, preRightLabel);
                }
                currentFlow = finishFlowLabel(preRightLabel);
                bind(node.operatorToken);
                if (isLogicalOrCoalescingAssignmentOperator(node.operatorToken.kind)) {
                    doWithConditionalBranches(bind, node.right, trueTarget, falseTarget);
                    bindAssignmentTargetFlow(node.left);
                    addAntecedent(trueTarget, createFlowCondition(32 /* TrueCondition */, currentFlow, node));
                    addAntecedent(falseTarget, createFlowCondition(64 /* FalseCondition */, currentFlow, node));
                }
                else {
                    bindCondition(node.right, trueTarget, falseTarget);
                }
            }
            function bindPrefixUnaryExpressionFlow(node) {
                if (node.operator === 53 /* ExclamationToken */) {
                    const saveTrueTarget = currentTrueTarget;
                    currentTrueTarget = currentFalseTarget;
                    currentFalseTarget = saveTrueTarget;
                    bindEachChild(node);
                    currentFalseTarget = currentTrueTarget;
                    currentTrueTarget = saveTrueTarget;
                }
                else {
                    bindEachChild(node);
                    if (node.operator === 45 /* PlusPlusToken */ || node.operator === 46 /* MinusMinusToken */) {
                        bindAssignmentTargetFlow(node.operand);
                    }
                }
            }
            function bindPostfixUnaryExpressionFlow(node) {
                bindEachChild(node);
                if (node.operator === 45 /* PlusPlusToken */ || node.operator === 46 /* MinusMinusToken */) {
                    bindAssignmentTargetFlow(node.operand);
                }
            }
            function bindDestructuringAssignmentFlow(node) {
                if (inAssignmentPattern) {
                    inAssignmentPattern = false;
                    bind(node.operatorToken);
                    bind(node.right);
                    inAssignmentPattern = true;
                    bind(node.left);
                }
                else {
                    inAssignmentPattern = true;
                    bind(node.left);
                    inAssignmentPattern = false;
                    bind(node.operatorToken);
                    bind(node.right);
                }
                bindAssignmentTargetFlow(node.left);
            }
            function createBindBinaryExpressionFlow() {
                return createBinaryExpressionTrampoline(onEnter, onLeft, onOperator, onRight, onExit, 
                /*foldState*/
                void 0);
                function onEnter(node, state) {
                    if (state) {
                        state.stackIndex++;
                        setParent(node, parent2);
                        const saveInStrictMode = inStrictMode;
                        bindWorker(node);
                        const saveParent = parent2;
                        parent2 = node;
                        state.skip = false;
                        state.inStrictModeStack[state.stackIndex] = saveInStrictMode;
                        state.parentStack[state.stackIndex] = saveParent;
                    }
                    else {
                        state = {
                            stackIndex: 0,
                            skip: false,
                            inStrictModeStack: [void 0],
                            parentStack: [void 0]
                        };
                    }
                    const operator = node.operatorToken.kind;
                    if (isLogicalOrCoalescingBinaryOperator(operator) || isLogicalOrCoalescingAssignmentOperator(operator)) {
                        if (isTopLevelLogicalExpression(node)) {
                            const postExpressionLabel = createBranchLabel();
                            bindLogicalLikeExpression(node, postExpressionLabel, postExpressionLabel);
                            currentFlow = finishFlowLabel(postExpressionLabel);
                        }
                        else {
                            bindLogicalLikeExpression(node, currentTrueTarget, currentFalseTarget);
                        }
                        state.skip = true;
                    }
                    return state;
                }
                function onLeft(left, state, node) {
                    if (!state.skip) {
                        const maybeBound = maybeBind2(left);
                        if (node.operatorToken.kind === 27 /* CommaToken */) {
                            maybeBindExpressionFlowIfCall(left);
                        }
                        return maybeBound;
                    }
                }
                function onOperator(operatorToken, state, _node) {
                    if (!state.skip) {
                        bind(operatorToken);
                    }
                }
                function onRight(right, state, node) {
                    if (!state.skip) {
                        const maybeBound = maybeBind2(right);
                        if (node.operatorToken.kind === 27 /* CommaToken */) {
                            maybeBindExpressionFlowIfCall(right);
                        }
                        return maybeBound;
                    }
                }
                function onExit(node, state) {
                    if (!state.skip) {
                        const operator = node.operatorToken.kind;
                        if (isAssignmentOperator(operator) && !isAssignmentTarget(node)) {
                            bindAssignmentTargetFlow(node.left);
                            if (operator === 63 /* EqualsToken */ && node.left.kind === 209 /* ElementAccessExpression */) {
                                const elementAccess = node.left;
                                if (isNarrowableOperand(elementAccess.expression)) {
                                    currentFlow = createFlowMutation(256 /* ArrayMutation */, currentFlow, node);
                                }
                            }
                        }
                    }
                    const savedInStrictMode = state.inStrictModeStack[state.stackIndex];
                    const savedParent = state.parentStack[state.stackIndex];
                    if (savedInStrictMode !== void 0) {
                        inStrictMode = savedInStrictMode;
                    }
                    if (savedParent !== void 0) {
                        parent2 = savedParent;
                    }
                    state.skip = false;
                    state.stackIndex--;
                }
                function maybeBind2(node) {
                    if (node && isBinaryExpression(node) && !isDestructuringAssignment(node)) {
                        return node;
                    }
                    bind(node);
                }
            }
            function bindDeleteExpressionFlow(node) {
                bindEachChild(node);
                if (node.expression.kind === 208 /* PropertyAccessExpression */) {
                    bindAssignmentTargetFlow(node.expression);
                }
            }
            function bindConditionalExpressionFlow(node) {
                const trueLabel = createBranchLabel();
                const falseLabel = createBranchLabel();
                const postExpressionLabel = createBranchLabel();
                bindCondition(node.condition, trueLabel, falseLabel);
                currentFlow = finishFlowLabel(trueLabel);
                bind(node.questionToken);
                bind(node.whenTrue);
                addAntecedent(postExpressionLabel, currentFlow);
                currentFlow = finishFlowLabel(falseLabel);
                bind(node.colonToken);
                bind(node.whenFalse);
                addAntecedent(postExpressionLabel, currentFlow);
                currentFlow = finishFlowLabel(postExpressionLabel);
            }
            function bindInitializedVariableFlow(node) {
                const name = !isOmittedExpression(node) ? node.name : void 0;
                if (isBindingPattern(name)) {
                    for (const child of name.elements) {
                        bindInitializedVariableFlow(child);
                    }
                }
                else {
                    currentFlow = createFlowMutation(16 /* Assignment */, currentFlow, node);
                }
            }
            function bindVariableDeclarationFlow(node) {
                bindEachChild(node);
                if (node.initializer || isForInOrOfStatement(node.parent.parent)) {
                    bindInitializedVariableFlow(node);
                }
            }
            function bindBindingElementFlow(node) {
                bind(node.dotDotDotToken);
                bind(node.propertyName);
                bindInitializer(node.initializer);
                bind(node.name);
            }
            function bindParameterFlow(node) {
                bindEach(node.modifiers);
                bind(node.dotDotDotToken);
                bind(node.questionToken);
                bind(node.type);
                bindInitializer(node.initializer);
                bind(node.name);
            }
            function bindInitializer(node) {
                if (!node) {
                    return;
                }
                const entryFlow = currentFlow;
                bind(node);
                if (entryFlow === unreachableFlow || entryFlow === currentFlow) {
                    return;
                }
                const exitFlow = createBranchLabel();
                addAntecedent(exitFlow, entryFlow);
                addAntecedent(exitFlow, currentFlow);
                currentFlow = finishFlowLabel(exitFlow);
            }
            function bindJSDocTypeAlias(node) {
                bind(node.tagName);
                if (node.kind !== 343 /* JSDocEnumTag */ && node.fullName) {
                    setParent(node.fullName, node);
                    setParentRecursive(node.fullName, 
                    /*incremental*/
                    false);
                }
                if (typeof node.comment !== "string") {
                    bindEach(node.comment);
                }
            }
            function bindJSDocClassTag(node) {
                bindEachChild(node);
                const host = getHostSignatureFromJSDoc(node);
                if (host && host.kind !== 171 /* MethodDeclaration */) {
                    addDeclarationToSymbol(host.symbol, host, 32 /* Class */);
                }
            }
            function bindOptionalExpression(node, trueTarget, falseTarget) {
                doWithConditionalBranches(bind, node, trueTarget, falseTarget);
                if (!isOptionalChain(node) || isOutermostOptionalChain(node)) {
                    addAntecedent(trueTarget, createFlowCondition(32 /* TrueCondition */, currentFlow, node));
                    addAntecedent(falseTarget, createFlowCondition(64 /* FalseCondition */, currentFlow, node));
                }
            }
            function bindOptionalChainRest(node) {
                switch (node.kind) {
                    case 208 /* PropertyAccessExpression */:
                        bind(node.questionDotToken);
                        bind(node.name);
                        break;
                    case 209 /* ElementAccessExpression */:
                        bind(node.questionDotToken);
                        bind(node.argumentExpression);
                        break;
                    case 210 /* CallExpression */:
                        bind(node.questionDotToken);
                        bindEach(node.typeArguments);
                        bindEach(node.arguments);
                        break;
                }
            }
            function bindOptionalChain(node, trueTarget, falseTarget) {
                const preChainLabel = isOptionalChainRoot(node) ? createBranchLabel() : void 0;
                bindOptionalExpression(node.expression, preChainLabel || trueTarget, falseTarget);
                if (preChainLabel) {
                    currentFlow = finishFlowLabel(preChainLabel);
                }
                doWithConditionalBranches(bindOptionalChainRest, node, trueTarget, falseTarget);
                if (isOutermostOptionalChain(node)) {
                    addAntecedent(trueTarget, createFlowCondition(32 /* TrueCondition */, currentFlow, node));
                    addAntecedent(falseTarget, createFlowCondition(64 /* FalseCondition */, currentFlow, node));
                }
            }
            function bindOptionalChainFlow(node) {
                if (isTopLevelLogicalExpression(node)) {
                    const postExpressionLabel = createBranchLabel();
                    bindOptionalChain(node, postExpressionLabel, postExpressionLabel);
                    currentFlow = finishFlowLabel(postExpressionLabel);
                }
                else {
                    bindOptionalChain(node, currentTrueTarget, currentFalseTarget);
                }
            }
            function bindNonNullExpressionFlow(node) {
                if (isOptionalChain(node)) {
                    bindOptionalChainFlow(node);
                }
                else {
                    bindEachChild(node);
                }
            }
            function bindAccessExpressionFlow(node) {
                if (isOptionalChain(node)) {
                    bindOptionalChainFlow(node);
                }
                else {
                    bindEachChild(node);
                }
            }
            function bindCallExpressionFlow(node) {
                if (isOptionalChain(node)) {
                    bindOptionalChainFlow(node);
                }
                else {
                    const expr = skipParentheses(node.expression);
                    if (expr.kind === 215 /* FunctionExpression */ || expr.kind === 216 /* ArrowFunction */) {
                        bindEach(node.typeArguments);
                        bindEach(node.arguments);
                        bind(node.expression);
                    }
                    else {
                        bindEachChild(node);
                        if (node.expression.kind === 106 /* SuperKeyword */) {
                            currentFlow = createFlowCall(currentFlow, node);
                        }
                    }
                }
                if (node.expression.kind === 208 /* PropertyAccessExpression */) {
                    const propertyAccess = node.expression;
                    if (isIdentifier(propertyAccess.name) && isNarrowableOperand(propertyAccess.expression) && isPushOrUnshiftIdentifier(propertyAccess.name)) {
                        currentFlow = createFlowMutation(256 /* ArrayMutation */, currentFlow, node);
                    }
                }
            }
            function addToContainerChain(next) {
                if (lastContainer) {
                    lastContainer.nextContainer = next;
                }
                lastContainer = next;
            }
            function declareSymbolAndAddToSymbolTable(node, symbolFlags, symbolExcludes) {
                switch (container.kind) {
                    case 264 /* ModuleDeclaration */:
                        return declareModuleMember(node, symbolFlags, symbolExcludes);
                    case 308 /* SourceFile */:
                        return declareSourceFileMember(node, symbolFlags, symbolExcludes);
                    case 228 /* ClassExpression */:
                    case 260 /* ClassDeclaration */:
                        return declareClassMember(node, symbolFlags, symbolExcludes);
                    case 263 /* EnumDeclaration */:
                        return declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
                    case 184 /* TypeLiteral */:
                    case 325 /* JSDocTypeLiteral */:
                    case 207 /* ObjectLiteralExpression */:
                    case 261 /* InterfaceDeclaration */:
                    case 289 /* JsxAttributes */:
                        return declareSymbol(container.symbol.members, container.symbol, node, symbolFlags, symbolExcludes);
                    case 181 /* FunctionType */:
                    case 182 /* ConstructorType */:
                    case 176 /* CallSignature */:
                    case 177 /* ConstructSignature */:
                    case 326 /* JSDocSignature */:
                    case 178 /* IndexSignature */:
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                    case 173 /* Constructor */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                    case 320 /* JSDocFunctionType */:
                    case 172 /* ClassStaticBlockDeclaration */:
                    case 262 /* TypeAliasDeclaration */:
                    case 197 /* MappedType */:
                        if (container.locals)
                            Debug.assertNode(container, canHaveLocals);
                        return declareSymbol(container.locals, 
                        /*parent*/
                        void 0, node, symbolFlags, symbolExcludes);
                }
            }
            function declareClassMember(node, symbolFlags, symbolExcludes) {
                return isStatic(node) ? declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes) : declareSymbol(container.symbol.members, container.symbol, node, symbolFlags, symbolExcludes);
            }
            function declareSourceFileMember(node, symbolFlags, symbolExcludes) {
                return isExternalModule(file) ? declareModuleMember(node, symbolFlags, symbolExcludes) : declareSymbol(file.locals, 
                /*parent*/
                void 0, node, symbolFlags, symbolExcludes);
            }
            function hasExportDeclarations(node) {
                const body = isSourceFile(node) ? node : tryCast(node.body, isModuleBlock);
                return !!body && body.statements.some((s) => isExportDeclaration(s) || isExportAssignment(s));
            }
            function setExportContextFlag(node) {
                if (node.flags & 16777216 /* Ambient */ && !hasExportDeclarations(node)) {
                    node.flags |= 64 /* ExportContext */;
                }
                else {
                    node.flags &= ~64 /* ExportContext */;
                }
            }
            function bindModuleDeclaration(node) {
                setExportContextFlag(node);
                if (isAmbientModule(node)) {
                    if (hasSyntacticModifier(node, 1 /* Export */)) {
                        errorOnFirstToken(node, Diagnostics.export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible);
                    }
                    if (isModuleAugmentationExternal(node)) {
                        declareModuleSymbol(node);
                    }
                    else {
                        let pattern;
                        if (node.name.kind === 10 /* StringLiteral */) {
                            const { text } = node.name;
                            pattern = tryParsePattern(text);
                            if (pattern === void 0) {
                                errorOnFirstToken(node.name, Diagnostics.Pattern_0_can_have_at_most_one_Asterisk_character, text);
                            }
                        }
                        const symbol = declareSymbolAndAddToSymbolTable(node, 512 /* ValueModule */, 110735 /* ValueModuleExcludes */);
                        file.patternAmbientModules = append(file.patternAmbientModules, pattern && !isString(pattern) ? { pattern, symbol } : void 0);
                    }
                }
                else {
                    const state = declareModuleSymbol(node);
                    if (state !== 0 /* NonInstantiated */) {
                        const { symbol } = node;
                        symbol.constEnumOnlyModule = !(symbol.flags & (16 /* Function */ | 32 /* Class */ | 256 /* RegularEnum */)) && state === 2 /* ConstEnumOnly */ && symbol.constEnumOnlyModule !== false;
                    }
                }
            }
            function declareModuleSymbol(node) {
                const state = getModuleInstanceState(node);
                const instantiated = state !== 0 /* NonInstantiated */;
                declareSymbolAndAddToSymbolTable(node, instantiated ? 512 /* ValueModule */ : 1024 /* NamespaceModule */, instantiated ? 110735 /* ValueModuleExcludes */ : 0 /* NamespaceModuleExcludes */);
                return state;
            }
            function bindFunctionOrConstructorType(node) {
                const symbol = createSymbol(131072 /* Signature */, getDeclarationName(node));
                addDeclarationToSymbol(symbol, node, 131072 /* Signature */);
                const typeLiteralSymbol = createSymbol(2048 /* TypeLiteral */, "__type" /* Type */);
                addDeclarationToSymbol(typeLiteralSymbol, node, 2048 /* TypeLiteral */);
                typeLiteralSymbol.members = createSymbolTable();
                typeLiteralSymbol.members.set(symbol.escapedName, symbol);
            }
            function bindObjectLiteralExpression(node) {
                return bindAnonymousDeclaration(node, 4096 /* ObjectLiteral */, "__object" /* Object */);
            }
            function bindJsxAttributes(node) {
                return bindAnonymousDeclaration(node, 4096 /* ObjectLiteral */, "__jsxAttributes" /* JSXAttributes */);
            }
            function bindJsxAttribute(node, symbolFlags, symbolExcludes) {
                return declareSymbolAndAddToSymbolTable(node, symbolFlags, symbolExcludes);
            }
            function bindAnonymousDeclaration(node, symbolFlags, name) {
                const symbol = createSymbol(symbolFlags, name);
                if (symbolFlags & (8 /* EnumMember */ | 106500 /* ClassMember */)) {
                    symbol.parent = container.symbol;
                }
                addDeclarationToSymbol(symbol, node, symbolFlags);
                return symbol;
            }
            function bindBlockScopedDeclaration(node, symbolFlags, symbolExcludes) {
                switch (blockScopeContainer.kind) {
                    case 264 /* ModuleDeclaration */:
                        declareModuleMember(node, symbolFlags, symbolExcludes);
                        break;
                    case 308 /* SourceFile */:
                        if (isExternalOrCommonJsModule(container)) {
                            declareModuleMember(node, symbolFlags, symbolExcludes);
                            break;
                        }
                    default:
                        Debug.assertNode(blockScopeContainer, canHaveLocals);
                        if (!blockScopeContainer.locals) {
                            blockScopeContainer.locals = createSymbolTable();
                            addToContainerChain(blockScopeContainer);
                        }
                        declareSymbol(blockScopeContainer.locals, 
                        /*parent*/
                        void 0, node, symbolFlags, symbolExcludes);
                }
            }
            function delayedBindJSDocTypedefTag() {
                if (!delayedTypeAliases) {
                    return;
                }
                const saveContainer = container;
                const saveLastContainer = lastContainer;
                const saveBlockScopeContainer = blockScopeContainer;
                const saveParent = parent2;
                const saveCurrentFlow = currentFlow;
                for (const typeAlias of delayedTypeAliases) {
                    const host = typeAlias.parent.parent;
                    container = findAncestor(host.parent, (n) => !!(getContainerFlags(n) & 1 /* IsContainer */)) || file;
                    blockScopeContainer = getEnclosingBlockScopeContainer(host) || file;
                    currentFlow = initFlowNode({ flags: 2 /* Start */ });
                    parent2 = typeAlias;
                    bind(typeAlias.typeExpression);
                    const declName = getNameOfDeclaration(typeAlias);
                    if ((isJSDocEnumTag(typeAlias) || !typeAlias.fullName) && declName && isPropertyAccessEntityNameExpression(declName.parent)) {
                        const isTopLevel = isTopLevelNamespaceAssignment(declName.parent);
                        if (isTopLevel) {
                            bindPotentiallyMissingNamespaces(file.symbol, declName.parent, isTopLevel, !!findAncestor(declName, (d) => isPropertyAccessExpression(d) && d.name.escapedText === "prototype"), 
                            /*containerIsClass*/
                            false);
                            const oldContainer = container;
                            switch (getAssignmentDeclarationPropertyAccessKind(declName.parent)) {
                                case 1 /* ExportsProperty */:
                                case 2 /* ModuleExports */:
                                    if (!isExternalOrCommonJsModule(file)) {
                                        container = void 0;
                                    }
                                    else {
                                        container = file;
                                    }
                                    break;
                                case 4 /* ThisProperty */:
                                    container = declName.parent.expression;
                                    break;
                                case 3 /* PrototypeProperty */:
                                    container = declName.parent.expression.name;
                                    break;
                                case 5 /* Property */:
                                    container = isExportsOrModuleExportsOrAlias(file, declName.parent.expression) ? file : isPropertyAccessExpression(declName.parent.expression) ? declName.parent.expression.name : declName.parent.expression;
                                    break;
                                case 0 /* None */:
                                    return Debug.fail("Shouldn't have detected typedef or enum on non-assignment declaration");
                            }
                            if (container) {
                                declareModuleMember(typeAlias, 524288 /* TypeAlias */, 788968 /* TypeAliasExcludes */);
                            }
                            container = oldContainer;
                        }
                    }
                    else if (isJSDocEnumTag(typeAlias) || !typeAlias.fullName || typeAlias.fullName.kind === 79 /* Identifier */) {
                        parent2 = typeAlias.parent;
                        bindBlockScopedDeclaration(typeAlias, 524288 /* TypeAlias */, 788968 /* TypeAliasExcludes */);
                    }
                    else {
                        bind(typeAlias.fullName);
                    }
                }
                container = saveContainer;
                lastContainer = saveLastContainer;
                blockScopeContainer = saveBlockScopeContainer;
                parent2 = saveParent;
                currentFlow = saveCurrentFlow;
            }
            function checkContextualIdentifier(node) {
                if (!file.parseDiagnostics.length && !(node.flags & 16777216 /* Ambient */) && !(node.flags & 8388608 /* JSDoc */) && !isIdentifierName(node)) {
                    const originalKeywordKind = identifierToKeywordKind(node);
                    if (originalKeywordKind === void 0) {
                        return;
                    }
                    if (inStrictMode && originalKeywordKind >= 117 /* FirstFutureReservedWord */ && originalKeywordKind <= 125 /* LastFutureReservedWord */) {
                        file.bindDiagnostics.push(createDiagnosticForNode2(node, getStrictModeIdentifierMessage(node), declarationNameToString(node)));
                    }
                    else if (originalKeywordKind === 133 /* AwaitKeyword */) {
                        if (isExternalModule(file) && isInTopLevelContext(node)) {
                            file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module, declarationNameToString(node)));
                        }
                        else if (node.flags & 32768 /* AwaitContext */) {
                            file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here, declarationNameToString(node)));
                        }
                    }
                    else if (originalKeywordKind === 125 /* YieldKeyword */ && node.flags & 8192 /* YieldContext */) {
                        file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here, declarationNameToString(node)));
                    }
                }
            }
            function getStrictModeIdentifierMessage(node) {
                if (getContainingClass(node)) {
                    return Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode;
                }
                if (file.externalModuleIndicator) {
                    return Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode;
                }
                return Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode;
            }
            function checkPrivateIdentifier(node) {
                if (node.escapedText === "#constructor") {
                    if (!file.parseDiagnostics.length) {
                        file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.constructor_is_a_reserved_word, declarationNameToString(node)));
                    }
                }
            }
            function checkStrictModeBinaryExpression(node) {
                if (inStrictMode && isLeftHandSideExpression(node.left) && isAssignmentOperator(node.operatorToken.kind)) {
                    checkStrictModeEvalOrArguments(node, node.left);
                }
            }
            function checkStrictModeCatchClause(node) {
                if (inStrictMode && node.variableDeclaration) {
                    checkStrictModeEvalOrArguments(node, node.variableDeclaration.name);
                }
            }
            function checkStrictModeDeleteExpression(node) {
                if (inStrictMode && node.expression.kind === 79 /* Identifier */) {
                    const span = getErrorSpanForNode(file, node.expression);
                    file.bindDiagnostics.push(createFileDiagnostic(file, span.start, span.length, Diagnostics.delete_cannot_be_called_on_an_identifier_in_strict_mode));
                }
            }
            function isEvalOrArgumentsIdentifier(node) {
                return isIdentifier(node) && (node.escapedText === "eval" || node.escapedText === "arguments");
            }
            function checkStrictModeEvalOrArguments(contextNode, name) {
                if (name && name.kind === 79 /* Identifier */) {
                    const identifier = name;
                    if (isEvalOrArgumentsIdentifier(identifier)) {
                        const span = getErrorSpanForNode(file, name);
                        file.bindDiagnostics.push(createFileDiagnostic(file, span.start, span.length, getStrictModeEvalOrArgumentsMessage(contextNode), idText(identifier)));
                    }
                }
            }
            function getStrictModeEvalOrArgumentsMessage(node) {
                if (getContainingClass(node)) {
                    return Diagnostics.Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of_0_For_more_information_see_https_Colon_Slash_Slashdeveloper_mozilla_org_Slashen_US_Slashdocs_SlashWeb_SlashJavaScript_SlashReference_SlashStrict_mode;
                }
                if (file.externalModuleIndicator) {
                    return Diagnostics.Invalid_use_of_0_Modules_are_automatically_in_strict_mode;
                }
                return Diagnostics.Invalid_use_of_0_in_strict_mode;
            }
            function checkStrictModeFunctionName(node) {
                if (inStrictMode) {
                    checkStrictModeEvalOrArguments(node, node.name);
                }
            }
            function getStrictModeBlockScopeFunctionDeclarationMessage(node) {
                if (getContainingClass(node)) {
                    return Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_definitions_are_automatically_in_strict_mode;
                }
                if (file.externalModuleIndicator) {
                    return Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_are_automatically_in_strict_mode;
                }
                return Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5;
            }
            function checkStrictModeFunctionDeclaration(node) {
                if (languageVersion < 2 /* ES2015 */) {
                    if (blockScopeContainer.kind !== 308 /* SourceFile */ && blockScopeContainer.kind !== 264 /* ModuleDeclaration */ && !isFunctionLikeOrClassStaticBlockDeclaration(blockScopeContainer)) {
                        const errorSpan = getErrorSpanForNode(file, node);
                        file.bindDiagnostics.push(createFileDiagnostic(file, errorSpan.start, errorSpan.length, getStrictModeBlockScopeFunctionDeclarationMessage(node)));
                    }
                }
            }
            function checkStrictModeNumericLiteral(node) {
                if (languageVersion < 1 /* ES5 */ && inStrictMode && node.numericLiteralFlags & 32 /* Octal */) {
                    file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.Octal_literals_are_not_allowed_in_strict_mode));
                }
            }
            function checkStrictModePostfixUnaryExpression(node) {
                if (inStrictMode) {
                    checkStrictModeEvalOrArguments(node, node.operand);
                }
            }
            function checkStrictModePrefixUnaryExpression(node) {
                if (inStrictMode) {
                    if (node.operator === 45 /* PlusPlusToken */ || node.operator === 46 /* MinusMinusToken */) {
                        checkStrictModeEvalOrArguments(node, node.operand);
                    }
                }
            }
            function checkStrictModeWithStatement(node) {
                if (inStrictMode) {
                    errorOnFirstToken(node, Diagnostics.with_statements_are_not_allowed_in_strict_mode);
                }
            }
            function checkStrictModeLabeledStatement(node) {
                if (inStrictMode && getEmitScriptTarget(options) >= 2 /* ES2015 */) {
                    if (isDeclarationStatement(node.statement) || isVariableStatement(node.statement)) {
                        errorOnFirstToken(node.label, Diagnostics.A_label_is_not_allowed_here);
                    }
                }
            }
            function errorOnFirstToken(node, message, arg0, arg1, arg2) {
                const span = getSpanOfTokenAtPosition(file, node.pos);
                file.bindDiagnostics.push(createFileDiagnostic(file, span.start, span.length, message, arg0, arg1, arg2));
            }
            function errorOrSuggestionOnNode(isError, node, message) {
                errorOrSuggestionOnRange(isError, node, node, message);
            }
            function errorOrSuggestionOnRange(isError, startNode2, endNode2, message) {
                addErrorOrSuggestionDiagnostic(isError, { pos: getTokenPosOfNode(startNode2, file), end: endNode2.end }, message);
            }
            function addErrorOrSuggestionDiagnostic(isError, range, message) {
                const diag2 = createFileDiagnostic(file, range.pos, range.end - range.pos, message);
                if (isError) {
                    file.bindDiagnostics.push(diag2);
                }
                else {
                    file.bindSuggestionDiagnostics = append(file.bindSuggestionDiagnostics, { ...diag2, category: 2 /* Suggestion */ });
                }
            }
            function bind(node) {
                if (!node) {
                    return;
                }
                setParent(node, parent2);
                if (tracing)
                    node.tracingPath = file.path;
                const saveInStrictMode = inStrictMode;
                bindWorker(node);
                if (node.kind > 162 /* LastToken */) {
                    const saveParent = parent2;
                    parent2 = node;
                    const containerFlags = getContainerFlags(node);
                    if (containerFlags === 0 /* None */) {
                        bindChildren(node);
                    }
                    else {
                        bindContainer(node, containerFlags);
                    }
                    parent2 = saveParent;
                }
                else {
                    const saveParent = parent2;
                    if (node.kind === 1 /* EndOfFileToken */)
                        parent2 = node;
                    bindJSDoc(node);
                    parent2 = saveParent;
                }
                inStrictMode = saveInStrictMode;
            }
            function bindJSDoc(node) {
                if (hasJSDocNodes(node)) {
                    if (isInJSFile(node)) {
                        for (const j of node.jsDoc) {
                            bind(j);
                        }
                    }
                    else {
                        for (const j of node.jsDoc) {
                            setParent(j, node);
                            setParentRecursive(j, 
                            /*incremental*/
                            false);
                        }
                    }
                }
            }
            function updateStrictModeStatementList(statements) {
                if (!inStrictMode) {
                    for (const statement of statements) {
                        if (!isPrologueDirective(statement)) {
                            return;
                        }
                        if (isUseStrictPrologueDirective(statement)) {
                            inStrictMode = true;
                            return;
                        }
                    }
                }
            }
            function isUseStrictPrologueDirective(node) {
                const nodeText2 = getSourceTextOfNodeFromSourceFile(file, node.expression);
                return nodeText2 === '"use strict"' || nodeText2 === "'use strict'";
            }
            function bindWorker(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        if (node.flags & 2048 /* IdentifierIsInJSDocNamespace */) {
                            let parentNode = node.parent;
                            while (parentNode && !isJSDocTypeAlias(parentNode)) {
                                parentNode = parentNode.parent;
                            }
                            bindBlockScopedDeclaration(parentNode, 524288 /* TypeAlias */, 788968 /* TypeAliasExcludes */);
                            break;
                        }
                    case 108 /* ThisKeyword */:
                        if (currentFlow && (isExpression(node) || parent2.kind === 300 /* ShorthandPropertyAssignment */)) {
                            node.flowNode = currentFlow;
                        }
                        return checkContextualIdentifier(node);
                    case 163 /* QualifiedName */:
                        if (currentFlow && isPartOfTypeQuery(node)) {
                            node.flowNode = currentFlow;
                        }
                        break;
                    case 233 /* MetaProperty */:
                    case 106 /* SuperKeyword */:
                        node.flowNode = currentFlow;
                        break;
                    case 80 /* PrivateIdentifier */:
                        return checkPrivateIdentifier(node);
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        const expr = node;
                        if (currentFlow && isNarrowableReference(expr)) {
                            expr.flowNode = currentFlow;
                        }
                        if (isSpecialPropertyDeclaration(expr)) {
                            bindSpecialPropertyDeclaration(expr);
                        }
                        if (isInJSFile(expr) && file.commonJsModuleIndicator && isModuleExportsAccessExpression(expr) && !lookupSymbolForName(blockScopeContainer, "module")) {
                            declareSymbol(file.locals, 
                            /*parent*/
                            void 0, expr.expression, 1 /* FunctionScopedVariable */ | 134217728 /* ModuleExports */, 111550 /* FunctionScopedVariableExcludes */);
                        }
                        break;
                    case 223 /* BinaryExpression */:
                        const specialKind = getAssignmentDeclarationKind(node);
                        switch (specialKind) {
                            case 1 /* ExportsProperty */:
                                bindExportsPropertyAssignment(node);
                                break;
                            case 2 /* ModuleExports */:
                                bindModuleExportsAssignment(node);
                                break;
                            case 3 /* PrototypeProperty */:
                                bindPrototypePropertyAssignment(node.left, node);
                                break;
                            case 6 /* Prototype */:
                                bindPrototypeAssignment(node);
                                break;
                            case 4 /* ThisProperty */:
                                bindThisPropertyAssignment(node);
                                break;
                            case 5 /* Property */:
                                const expression = node.left.expression;
                                if (isInJSFile(node) && isIdentifier(expression)) {
                                    const symbol = lookupSymbolForName(blockScopeContainer, expression.escapedText);
                                    if (isThisInitializedDeclaration(symbol == null ? void 0 : symbol.valueDeclaration)) {
                                        bindThisPropertyAssignment(node);
                                        break;
                                    }
                                }
                                bindSpecialPropertyAssignment(node);
                                break;
                            case 0 /* None */:
                                break;
                            default:
                                Debug.fail("Unknown binary expression special property assignment kind");
                        }
                        return checkStrictModeBinaryExpression(node);
                    case 295 /* CatchClause */:
                        return checkStrictModeCatchClause(node);
                    case 217 /* DeleteExpression */:
                        return checkStrictModeDeleteExpression(node);
                    case 8 /* NumericLiteral */:
                        return checkStrictModeNumericLiteral(node);
                    case 222 /* PostfixUnaryExpression */:
                        return checkStrictModePostfixUnaryExpression(node);
                    case 221 /* PrefixUnaryExpression */:
                        return checkStrictModePrefixUnaryExpression(node);
                    case 251 /* WithStatement */:
                        return checkStrictModeWithStatement(node);
                    case 253 /* LabeledStatement */:
                        return checkStrictModeLabeledStatement(node);
                    case 194 /* ThisType */:
                        seenThisKeyword = true;
                        return;
                    case 179 /* TypePredicate */:
                        break;
                    case 165 /* TypeParameter */:
                        return bindTypeParameter(node);
                    case 166 /* Parameter */:
                        return bindParameter(node);
                    case 257 /* VariableDeclaration */:
                        return bindVariableDeclarationOrBindingElement(node);
                    case 205 /* BindingElement */:
                        node.flowNode = currentFlow;
                        return bindVariableDeclarationOrBindingElement(node);
                    case 169 /* PropertyDeclaration */:
                    case 168 /* PropertySignature */:
                        return bindPropertyWorker(node);
                    case 299 /* PropertyAssignment */:
                    case 300 /* ShorthandPropertyAssignment */:
                        return bindPropertyOrMethodOrAccessor(node, 4 /* Property */, 0 /* PropertyExcludes */);
                    case 302 /* EnumMember */:
                        return bindPropertyOrMethodOrAccessor(node, 8 /* EnumMember */, 900095 /* EnumMemberExcludes */);
                    case 176 /* CallSignature */:
                    case 177 /* ConstructSignature */:
                    case 178 /* IndexSignature */:
                        return declareSymbolAndAddToSymbolTable(node, 131072 /* Signature */, 0 /* None */);
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                        return bindPropertyOrMethodOrAccessor(node, 8192 /* Method */ | (node.questionToken ? 16777216 /* Optional */ : 0 /* None */), isObjectLiteralMethod(node) ? 0 /* PropertyExcludes */ : 103359 /* MethodExcludes */);
                    case 259 /* FunctionDeclaration */:
                        return bindFunctionDeclaration(node);
                    case 173 /* Constructor */:
                        return declareSymbolAndAddToSymbolTable(node, 16384 /* Constructor */, 
                        /*symbolExcludes:*/
                        0 /* None */);
                    case 174 /* GetAccessor */:
                        return bindPropertyOrMethodOrAccessor(node, 32768 /* GetAccessor */, 46015 /* GetAccessorExcludes */);
                    case 175 /* SetAccessor */:
                        return bindPropertyOrMethodOrAccessor(node, 65536 /* SetAccessor */, 78783 /* SetAccessorExcludes */);
                    case 181 /* FunctionType */:
                    case 320 /* JSDocFunctionType */:
                    case 326 /* JSDocSignature */:
                    case 182 /* ConstructorType */:
                        return bindFunctionOrConstructorType(node);
                    case 184 /* TypeLiteral */:
                    case 325 /* JSDocTypeLiteral */:
                    case 197 /* MappedType */:
                        return bindAnonymousTypeWorker(node);
                    case 335 /* JSDocClassTag */:
                        return bindJSDocClassTag(node);
                    case 207 /* ObjectLiteralExpression */:
                        return bindObjectLiteralExpression(node);
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                        return bindFunctionExpression(node);
                    case 210 /* CallExpression */:
                        const assignmentKind = getAssignmentDeclarationKind(node);
                        switch (assignmentKind) {
                            case 7 /* ObjectDefinePropertyValue */:
                                return bindObjectDefinePropertyAssignment(node);
                            case 8 /* ObjectDefinePropertyExports */:
                                return bindObjectDefinePropertyExport(node);
                            case 9 /* ObjectDefinePrototypeProperty */:
                                return bindObjectDefinePrototypeProperty(node);
                            case 0 /* None */:
                                break;
                            default:
                                return Debug.fail("Unknown call expression assignment declaration kind");
                        }
                        if (isInJSFile(node)) {
                            bindCallExpression(node);
                        }
                        break;
                    case 228 /* ClassExpression */:
                    case 260 /* ClassDeclaration */:
                        inStrictMode = true;
                        return bindClassLikeDeclaration(node);
                    case 261 /* InterfaceDeclaration */:
                        return bindBlockScopedDeclaration(node, 64 /* Interface */, 788872 /* InterfaceExcludes */);
                    case 262 /* TypeAliasDeclaration */:
                        return bindBlockScopedDeclaration(node, 524288 /* TypeAlias */, 788968 /* TypeAliasExcludes */);
                    case 263 /* EnumDeclaration */:
                        return bindEnumDeclaration(node);
                    case 264 /* ModuleDeclaration */:
                        return bindModuleDeclaration(node);
                    case 289 /* JsxAttributes */:
                        return bindJsxAttributes(node);
                    case 288 /* JsxAttribute */:
                        return bindJsxAttribute(node, 4 /* Property */, 0 /* PropertyExcludes */);
                    case 268 /* ImportEqualsDeclaration */:
                    case 271 /* NamespaceImport */:
                    case 273 /* ImportSpecifier */:
                    case 278 /* ExportSpecifier */:
                        return declareSymbolAndAddToSymbolTable(node, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                    case 267 /* NamespaceExportDeclaration */:
                        return bindNamespaceExportDeclaration(node);
                    case 270 /* ImportClause */:
                        return bindImportClause(node);
                    case 275 /* ExportDeclaration */:
                        return bindExportDeclaration(node);
                    case 274 /* ExportAssignment */:
                        return bindExportAssignment(node);
                    case 308 /* SourceFile */:
                        updateStrictModeStatementList(node.statements);
                        return bindSourceFileIfExternalModule();
                    case 238 /* Block */:
                        if (!isFunctionLikeOrClassStaticBlockDeclaration(node.parent)) {
                            return;
                        }
                    case 265 /* ModuleBlock */:
                        return updateStrictModeStatementList(node.statements);
                    case 344 /* JSDocParameterTag */:
                        if (node.parent.kind === 326 /* JSDocSignature */) {
                            return bindParameter(node);
                        }
                        if (node.parent.kind !== 325 /* JSDocTypeLiteral */) {
                            break;
                        }
                    case 351 /* JSDocPropertyTag */:
                        const propTag = node;
                        const flags = propTag.isBracketed || propTag.typeExpression && propTag.typeExpression.type.kind === 319 /* JSDocOptionalType */ ? 4 /* Property */ | 16777216 /* Optional */ : 4 /* Property */;
                        return declareSymbolAndAddToSymbolTable(propTag, flags, 0 /* PropertyExcludes */);
                    case 349 /* JSDocTypedefTag */:
                    case 341 /* JSDocCallbackTag */:
                    case 343 /* JSDocEnumTag */:
                        return (delayedTypeAliases || (delayedTypeAliases = [])).push(node);
                    case 342 /* JSDocOverloadTag */:
                        return bind(node.typeExpression);
                }
            }
            function bindPropertyWorker(node) {
                const isAutoAccessor = isAutoAccessorPropertyDeclaration(node);
                const includes = isAutoAccessor ? 98304 /* Accessor */ : 4 /* Property */;
                const excludes = isAutoAccessor ? 13247 /* AccessorExcludes */ : 0 /* PropertyExcludes */;
                return bindPropertyOrMethodOrAccessor(node, includes | (node.questionToken ? 16777216 /* Optional */ : 0 /* None */), excludes);
            }
            function bindAnonymousTypeWorker(node) {
                return bindAnonymousDeclaration(node, 2048 /* TypeLiteral */, "__type" /* Type */);
            }
            function bindSourceFileIfExternalModule() {
                setExportContextFlag(file);
                if (isExternalModule(file)) {
                    bindSourceFileAsExternalModule();
                }
                else if (isJsonSourceFile(file)) {
                    bindSourceFileAsExternalModule();
                    const originalSymbol = file.symbol;
                    declareSymbol(file.symbol.exports, file.symbol, file, 4 /* Property */, 67108863 /* All */);
                    file.symbol = originalSymbol;
                }
            }
            function bindSourceFileAsExternalModule() {
                bindAnonymousDeclaration(file, 512 /* ValueModule */, `"${removeFileExtension(file.fileName)}"`);
            }
            function bindExportAssignment(node) {
                if (!container.symbol || !container.symbol.exports) {
                    bindAnonymousDeclaration(node, 111551 /* Value */, getDeclarationName(node));
                }
                else {
                    const flags = exportAssignmentIsAlias(node) ? 2097152 /* Alias */ : 4 /* Property */;
                    const symbol = declareSymbol(container.symbol.exports, container.symbol, node, flags, 67108863 /* All */);
                    if (node.isExportEquals) {
                        setValueDeclaration(symbol, node);
                    }
                }
            }
            function bindNamespaceExportDeclaration(node) {
                if (some(node.modifiers)) {
                    file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.Modifiers_cannot_appear_here));
                }
                const diag2 = !isSourceFile(node.parent) ? Diagnostics.Global_module_exports_may_only_appear_at_top_level : !isExternalModule(node.parent) ? Diagnostics.Global_module_exports_may_only_appear_in_module_files : !node.parent.isDeclarationFile ? Diagnostics.Global_module_exports_may_only_appear_in_declaration_files : void 0;
                if (diag2) {
                    file.bindDiagnostics.push(createDiagnosticForNode2(node, diag2));
                }
                else {
                    file.symbol.globalExports = file.symbol.globalExports || createSymbolTable();
                    declareSymbol(file.symbol.globalExports, file.symbol, node, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                }
            }
            function bindExportDeclaration(node) {
                if (!container.symbol || !container.symbol.exports) {
                    bindAnonymousDeclaration(node, 8388608 /* ExportStar */, getDeclarationName(node));
                }
                else if (!node.exportClause) {
                    declareSymbol(container.symbol.exports, container.symbol, node, 8388608 /* ExportStar */, 0 /* None */);
                }
                else if (isNamespaceExport(node.exportClause)) {
                    setParent(node.exportClause, node);
                    declareSymbol(container.symbol.exports, container.symbol, node.exportClause, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                }
            }
            function bindImportClause(node) {
                if (node.name) {
                    declareSymbolAndAddToSymbolTable(node, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                }
            }
            function setCommonJsModuleIndicator(node) {
                if (file.externalModuleIndicator && file.externalModuleIndicator !== true) {
                    return false;
                }
                if (!file.commonJsModuleIndicator) {
                    file.commonJsModuleIndicator = node;
                    if (!file.externalModuleIndicator) {
                        bindSourceFileAsExternalModule();
                    }
                }
                return true;
            }
            function bindObjectDefinePropertyExport(node) {
                if (!setCommonJsModuleIndicator(node)) {
                    return;
                }
                const symbol = forEachIdentifierInEntityName(node.arguments[0], 
                /*parent*/
                void 0, (id, symbol2) => {
                    if (symbol2) {
                        addDeclarationToSymbol(symbol2, id, 1536 /* Module */ | 67108864 /* Assignment */);
                    }
                    return symbol2;
                });
                if (symbol) {
                    const flags = 4 /* Property */ | 1048576 /* ExportValue */;
                    declareSymbol(symbol.exports, symbol, node, flags, 0 /* None */);
                }
            }
            function bindExportsPropertyAssignment(node) {
                if (!setCommonJsModuleIndicator(node)) {
                    return;
                }
                const symbol = forEachIdentifierInEntityName(node.left.expression, 
                /*parent*/
                void 0, (id, symbol2) => {
                    if (symbol2) {
                        addDeclarationToSymbol(symbol2, id, 1536 /* Module */ | 67108864 /* Assignment */);
                    }
                    return symbol2;
                });
                if (symbol) {
                    const isAlias = isAliasableExpression(node.right) && (isExportsIdentifier(node.left.expression) || isModuleExportsAccessExpression(node.left.expression));
                    const flags = isAlias ? 2097152 /* Alias */ : 4 /* Property */ | 1048576 /* ExportValue */;
                    setParent(node.left, node);
                    declareSymbol(symbol.exports, symbol, node.left, flags, 0 /* None */);
                }
            }
            function bindModuleExportsAssignment(node) {
                if (!setCommonJsModuleIndicator(node)) {
                    return;
                }
                const assignedExpression = getRightMostAssignedExpression(node.right);
                if (isEmptyObjectLiteral(assignedExpression) || container === file && isExportsOrModuleExportsOrAlias(file, assignedExpression)) {
                    return;
                }
                if (isObjectLiteralExpression(assignedExpression) && every(assignedExpression.properties, isShorthandPropertyAssignment)) {
                    forEach(assignedExpression.properties, bindExportAssignedObjectMemberAlias);
                    return;
                }
                const flags = exportAssignmentIsAlias(node) ? 2097152 /* Alias */ : 4 /* Property */ | 1048576 /* ExportValue */ | 512 /* ValueModule */;
                const symbol = declareSymbol(file.symbol.exports, file.symbol, node, flags | 67108864 /* Assignment */, 0 /* None */);
                setValueDeclaration(symbol, node);
            }
            function bindExportAssignedObjectMemberAlias(node) {
                declareSymbol(file.symbol.exports, file.symbol, node, 2097152 /* Alias */ | 67108864 /* Assignment */, 0 /* None */);
            }
            function bindThisPropertyAssignment(node) {
                Debug.assert(isInJSFile(node));
                const hasPrivateIdentifier = isBinaryExpression(node) && isPropertyAccessExpression(node.left) && isPrivateIdentifier(node.left.name) || isPropertyAccessExpression(node) && isPrivateIdentifier(node.name);
                if (hasPrivateIdentifier) {
                    return;
                }
                const thisContainer = getThisContainer(node, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                switch (thisContainer.kind) {
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                        let constructorSymbol = thisContainer.symbol;
                        if (isBinaryExpression(thisContainer.parent) && thisContainer.parent.operatorToken.kind === 63 /* EqualsToken */) {
                            const l = thisContainer.parent.left;
                            if (isBindableStaticAccessExpression(l) && isPrototypeAccess(l.expression)) {
                                constructorSymbol = lookupSymbolForPropertyAccess(l.expression.expression, thisParentContainer);
                            }
                        }
                        if (constructorSymbol && constructorSymbol.valueDeclaration) {
                            constructorSymbol.members = constructorSymbol.members || createSymbolTable();
                            if (hasDynamicName(node)) {
                                bindDynamicallyNamedThisPropertyAssignment(node, constructorSymbol, constructorSymbol.members);
                            }
                            else {
                                declareSymbol(constructorSymbol.members, constructorSymbol, node, 4 /* Property */ | 67108864 /* Assignment */, 0 /* PropertyExcludes */ & ~4 /* Property */);
                            }
                            addDeclarationToSymbol(constructorSymbol, constructorSymbol.valueDeclaration, 32 /* Class */);
                        }
                        break;
                    case 173 /* Constructor */:
                    case 169 /* PropertyDeclaration */:
                    case 171 /* MethodDeclaration */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 172 /* ClassStaticBlockDeclaration */:
                        const containingClass = thisContainer.parent;
                        const symbolTable = isStatic(thisContainer) ? containingClass.symbol.exports : containingClass.symbol.members;
                        if (hasDynamicName(node)) {
                            bindDynamicallyNamedThisPropertyAssignment(node, containingClass.symbol, symbolTable);
                        }
                        else {
                            declareSymbol(symbolTable, containingClass.symbol, node, 4 /* Property */ | 67108864 /* Assignment */, 0 /* None */, 
                            /*isReplaceableByMethod*/
                            true);
                        }
                        break;
                    case 308 /* SourceFile */:
                        if (hasDynamicName(node)) {
                            break;
                        }
                        else if (thisContainer.commonJsModuleIndicator) {
                            declareSymbol(thisContainer.symbol.exports, thisContainer.symbol, node, 4 /* Property */ | 1048576 /* ExportValue */, 0 /* None */);
                        }
                        else {
                            declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 111550 /* FunctionScopedVariableExcludes */);
                        }
                        break;
                    default:
                        Debug.failBadSyntaxKind(thisContainer);
                }
            }
            function bindDynamicallyNamedThisPropertyAssignment(node, symbol, symbolTable) {
                declareSymbol(symbolTable, symbol, node, 4 /* Property */, 0 /* None */, 
                /*isReplaceableByMethod*/
                true, 
                /*isComputedName*/
                true);
                addLateBoundAssignmentDeclarationToSymbol(node, symbol);
            }
            function addLateBoundAssignmentDeclarationToSymbol(node, symbol) {
                if (symbol) {
                    (symbol.assignmentDeclarationMembers || (symbol.assignmentDeclarationMembers = /* @__PURE__ */ new Map())).set(getNodeId(node), node);
                }
            }
            function bindSpecialPropertyDeclaration(node) {
                if (node.expression.kind === 108 /* ThisKeyword */) {
                    bindThisPropertyAssignment(node);
                }
                else if (isBindableStaticAccessExpression(node) && node.parent.parent.kind === 308 /* SourceFile */) {
                    if (isPrototypeAccess(node.expression)) {
                        bindPrototypePropertyAssignment(node, node.parent);
                    }
                    else {
                        bindStaticPropertyAssignment(node);
                    }
                }
            }
            function bindPrototypeAssignment(node) {
                setParent(node.left, node);
                setParent(node.right, node);
                bindPropertyAssignment(node.left.expression, node.left, 
                /*isPrototypeProperty*/
                false, 
                /*containerIsClass*/
                true);
            }
            function bindObjectDefinePrototypeProperty(node) {
                const namespaceSymbol = lookupSymbolForPropertyAccess(node.arguments[0].expression);
                if (namespaceSymbol && namespaceSymbol.valueDeclaration) {
                    addDeclarationToSymbol(namespaceSymbol, namespaceSymbol.valueDeclaration, 32 /* Class */);
                }
                bindPotentiallyNewExpandoMemberToNamespace(node, namespaceSymbol, 
                /*isPrototypeProperty*/
                true);
            }
            function bindPrototypePropertyAssignment(lhs, parent3) {
                const classPrototype = lhs.expression;
                const constructorFunction = classPrototype.expression;
                setParent(constructorFunction, classPrototype);
                setParent(classPrototype, lhs);
                setParent(lhs, parent3);
                bindPropertyAssignment(constructorFunction, lhs, 
                /*isPrototypeProperty*/
                true, 
                /*containerIsClass*/
                true);
            }
            function bindObjectDefinePropertyAssignment(node) {
                let namespaceSymbol = lookupSymbolForPropertyAccess(node.arguments[0]);
                const isToplevel = node.parent.parent.kind === 308 /* SourceFile */;
                namespaceSymbol = bindPotentiallyMissingNamespaces(namespaceSymbol, node.arguments[0], isToplevel, 
                /*isPrototypeProperty*/
                false, 
                /*containerIsClass*/
                false);
                bindPotentiallyNewExpandoMemberToNamespace(node, namespaceSymbol, 
                /*isPrototypeProperty*/
                false);
            }
            function bindSpecialPropertyAssignment(node) {
                var _a2;
                const parentSymbol = lookupSymbolForPropertyAccess(node.left.expression, container) || lookupSymbolForPropertyAccess(node.left.expression, blockScopeContainer);
                if (!isInJSFile(node) && !isFunctionSymbol(parentSymbol)) {
                    return;
                }
                const rootExpr = getLeftmostAccessExpression(node.left);
                if (isIdentifier(rootExpr) && ((_a2 = lookupSymbolForName(container, rootExpr.escapedText)) == null ? void 0 : _a2.flags) & 2097152 /* Alias */) {
                    return;
                }
                setParent(node.left, node);
                setParent(node.right, node);
                if (isIdentifier(node.left.expression) && container === file && isExportsOrModuleExportsOrAlias(file, node.left.expression)) {
                    bindExportsPropertyAssignment(node);
                }
                else if (hasDynamicName(node)) {
                    bindAnonymousDeclaration(node, 4 /* Property */ | 67108864 /* Assignment */, "__computed" /* Computed */);
                    const sym = bindPotentiallyMissingNamespaces(parentSymbol, node.left.expression, isTopLevelNamespaceAssignment(node.left), 
                    /*isPrototype*/
                    false, 
                    /*containerIsClass*/
                    false);
                    addLateBoundAssignmentDeclarationToSymbol(node, sym);
                }
                else {
                    bindStaticPropertyAssignment(cast(node.left, isBindableStaticNameExpression));
                }
            }
            function bindStaticPropertyAssignment(node) {
                Debug.assert(!isIdentifier(node));
                setParent(node.expression, node);
                bindPropertyAssignment(node.expression, node, 
                /*isPrototypeProperty*/
                false, 
                /*containerIsClass*/
                false);
            }
            function bindPotentiallyMissingNamespaces(namespaceSymbol, entityName, isToplevel, isPrototypeProperty, containerIsClass) {
                if ((namespaceSymbol == null ? void 0 : namespaceSymbol.flags) & 2097152 /* Alias */) {
                    return namespaceSymbol;
                }
                if (isToplevel && !isPrototypeProperty) {
                    const flags = 1536 /* Module */ | 67108864 /* Assignment */;
                    const excludeFlags = 110735 /* ValueModuleExcludes */ & ~67108864 /* Assignment */;
                    namespaceSymbol = forEachIdentifierInEntityName(entityName, namespaceSymbol, (id, symbol, parent3) => {
                        if (symbol) {
                            addDeclarationToSymbol(symbol, id, flags);
                            return symbol;
                        }
                        else {
                            const table = parent3 ? parent3.exports : file.jsGlobalAugmentations || (file.jsGlobalAugmentations = createSymbolTable());
                            return declareSymbol(table, parent3, id, flags, excludeFlags);
                        }
                    });
                }
                if (containerIsClass && namespaceSymbol && namespaceSymbol.valueDeclaration) {
                    addDeclarationToSymbol(namespaceSymbol, namespaceSymbol.valueDeclaration, 32 /* Class */);
                }
                return namespaceSymbol;
            }
            function bindPotentiallyNewExpandoMemberToNamespace(declaration, namespaceSymbol, isPrototypeProperty) {
                if (!namespaceSymbol || !isExpandoSymbol(namespaceSymbol)) {
                    return;
                }
                const symbolTable = isPrototypeProperty ? namespaceSymbol.members || (namespaceSymbol.members = createSymbolTable()) : namespaceSymbol.exports || (namespaceSymbol.exports = createSymbolTable());
                let includes = 0 /* None */;
                let excludes = 0 /* None */;
                if (isFunctionLikeDeclaration(getAssignedExpandoInitializer(declaration))) {
                    includes = 8192 /* Method */;
                    excludes = 103359 /* MethodExcludes */;
                }
                else if (isCallExpression(declaration) && isBindableObjectDefinePropertyCall(declaration)) {
                    if (some(declaration.arguments[2].properties, (p) => {
                        const id = getNameOfDeclaration(p);
                        return !!id && isIdentifier(id) && idText(id) === "set";
                    })) {
                        includes |= 65536 /* SetAccessor */ | 4 /* Property */;
                        excludes |= 78783 /* SetAccessorExcludes */;
                    }
                    if (some(declaration.arguments[2].properties, (p) => {
                        const id = getNameOfDeclaration(p);
                        return !!id && isIdentifier(id) && idText(id) === "get";
                    })) {
                        includes |= 32768 /* GetAccessor */ | 4 /* Property */;
                        excludes |= 46015 /* GetAccessorExcludes */;
                    }
                }
                if (includes === 0 /* None */) {
                    includes = 4 /* Property */;
                    excludes = 0 /* PropertyExcludes */;
                }
                declareSymbol(symbolTable, namespaceSymbol, declaration, includes | 67108864 /* Assignment */, excludes & ~67108864 /* Assignment */);
            }
            function isTopLevelNamespaceAssignment(propertyAccess) {
                return isBinaryExpression(propertyAccess.parent) ? getParentOfBinaryExpression(propertyAccess.parent).parent.kind === 308 /* SourceFile */ : propertyAccess.parent.parent.kind === 308 /* SourceFile */;
            }
            function bindPropertyAssignment(name, propertyAccess, isPrototypeProperty, containerIsClass) {
                let namespaceSymbol = lookupSymbolForPropertyAccess(name, container) || lookupSymbolForPropertyAccess(name, blockScopeContainer);
                const isToplevel = isTopLevelNamespaceAssignment(propertyAccess);
                namespaceSymbol = bindPotentiallyMissingNamespaces(namespaceSymbol, propertyAccess.expression, isToplevel, isPrototypeProperty, containerIsClass);
                bindPotentiallyNewExpandoMemberToNamespace(propertyAccess, namespaceSymbol, isPrototypeProperty);
            }
            function isExpandoSymbol(symbol) {
                if (symbol.flags & (16 /* Function */ | 32 /* Class */ | 1024 /* NamespaceModule */)) {
                    return true;
                }
                const node = symbol.valueDeclaration;
                if (node && isCallExpression(node)) {
                    return !!getAssignedExpandoInitializer(node);
                }
                let init = !node ? void 0 : isVariableDeclaration(node) ? node.initializer : isBinaryExpression(node) ? node.right : isPropertyAccessExpression(node) && isBinaryExpression(node.parent) ? node.parent.right : void 0;
                init = init && getRightMostAssignedExpression(init);
                if (init) {
                    const isPrototypeAssignment = isPrototypeAccess(isVariableDeclaration(node) ? node.name : isBinaryExpression(node) ? node.left : node);
                    return !!getExpandoInitializer(isBinaryExpression(init) && (init.operatorToken.kind === 56 /* BarBarToken */ || init.operatorToken.kind === 60 /* QuestionQuestionToken */) ? init.right : init, isPrototypeAssignment);
                }
                return false;
            }
            function getParentOfBinaryExpression(expr) {
                while (isBinaryExpression(expr.parent)) {
                    expr = expr.parent;
                }
                return expr.parent;
            }
            function lookupSymbolForPropertyAccess(node, lookupContainer = container) {
                if (isIdentifier(node)) {
                    return lookupSymbolForName(lookupContainer, node.escapedText);
                }
                else {
                    const symbol = lookupSymbolForPropertyAccess(node.expression);
                    return symbol && symbol.exports && symbol.exports.get(getElementOrPropertyAccessName(node));
                }
            }
            function forEachIdentifierInEntityName(e, parent3, action) {
                if (isExportsOrModuleExportsOrAlias(file, e)) {
                    return file.symbol;
                }
                else if (isIdentifier(e)) {
                    return action(e, lookupSymbolForPropertyAccess(e), parent3);
                }
                else {
                    const s = forEachIdentifierInEntityName(e.expression, parent3, action);
                    const name = getNameOrArgument(e);
                    if (isPrivateIdentifier(name)) {
                        Debug.fail("unexpected PrivateIdentifier");
                    }
                    return action(name, s && s.exports && s.exports.get(getElementOrPropertyAccessName(e)), s);
                }
            }
            function bindCallExpression(node) {
                if (!file.commonJsModuleIndicator && isRequireCall(node, 
                /*checkArgumentIsStringLiteralLike*/
                false)) {
                    setCommonJsModuleIndicator(node);
                }
            }
            function bindClassLikeDeclaration(node) {
                if (node.kind === 260 /* ClassDeclaration */) {
                    bindBlockScopedDeclaration(node, 32 /* Class */, 899503 /* ClassExcludes */);
                }
                else {
                    const bindingName = node.name ? node.name.escapedText : "__class" /* Class */;
                    bindAnonymousDeclaration(node, 32 /* Class */, bindingName);
                    if (node.name) {
                        classifiableNames.add(node.name.escapedText);
                    }
                }
                const { symbol } = node;
                const prototypeSymbol = createSymbol(4 /* Property */ | 4194304 /* Prototype */, "prototype");
                const symbolExport = symbol.exports.get(prototypeSymbol.escapedName);
                if (symbolExport) {
                    if (node.name) {
                        setParent(node.name, node);
                    }
                    file.bindDiagnostics.push(createDiagnosticForNode2(symbolExport.declarations[0], Diagnostics.Duplicate_identifier_0, symbolName(prototypeSymbol)));
                }
                symbol.exports.set(prototypeSymbol.escapedName, prototypeSymbol);
                prototypeSymbol.parent = symbol;
            }
            function bindEnumDeclaration(node) {
                return isEnumConst(node) ? bindBlockScopedDeclaration(node, 128 /* ConstEnum */, 899967 /* ConstEnumExcludes */) : bindBlockScopedDeclaration(node, 256 /* RegularEnum */, 899327 /* RegularEnumExcludes */);
            }
            function bindVariableDeclarationOrBindingElement(node) {
                if (inStrictMode) {
                    checkStrictModeEvalOrArguments(node, node.name);
                }
                if (!isBindingPattern(node.name)) {
                    const possibleVariableDecl = node.kind === 257 /* VariableDeclaration */ ? node : node.parent.parent;
                    if (isInJSFile(node) && shouldResolveJsRequire(options) && isVariableDeclarationInitializedToBareOrAccessedRequire(possibleVariableDecl) && !getJSDocTypeTag(node) && !(getCombinedModifierFlags(node) & 1 /* Export */)) {
                        declareSymbolAndAddToSymbolTable(node, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                    }
                    else if (isBlockOrCatchScoped(node)) {
                        bindBlockScopedDeclaration(node, 2 /* BlockScopedVariable */, 111551 /* BlockScopedVariableExcludes */);
                    }
                    else if (isParameterDeclaration(node)) {
                        declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 111551 /* ParameterExcludes */);
                    }
                    else {
                        declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 111550 /* FunctionScopedVariableExcludes */);
                    }
                }
            }
            function bindParameter(node) {
                if (node.kind === 344 /* JSDocParameterTag */ && container.kind !== 326 /* JSDocSignature */) {
                    return;
                }
                if (inStrictMode && !(node.flags & 16777216 /* Ambient */)) {
                    checkStrictModeEvalOrArguments(node, node.name);
                }
                if (isBindingPattern(node.name)) {
                    bindAnonymousDeclaration(node, 1 /* FunctionScopedVariable */, "__" + node.parent.parameters.indexOf(node));
                }
                else {
                    declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 111551 /* ParameterExcludes */);
                }
                if (isParameterPropertyDeclaration(node, node.parent)) {
                    const classDeclaration = node.parent.parent;
                    declareSymbol(classDeclaration.symbol.members, classDeclaration.symbol, node, 4 /* Property */ | (node.questionToken ? 16777216 /* Optional */ : 0 /* None */), 0 /* PropertyExcludes */);
                }
            }
            function bindFunctionDeclaration(node) {
                if (!file.isDeclarationFile && !(node.flags & 16777216 /* Ambient */)) {
                    if (isAsyncFunction(node)) {
                        emitFlags |= 2048 /* HasAsyncFunctions */;
                    }
                }
                checkStrictModeFunctionName(node);
                if (inStrictMode) {
                    checkStrictModeFunctionDeclaration(node);
                    bindBlockScopedDeclaration(node, 16 /* Function */, 110991 /* FunctionExcludes */);
                }
                else {
                    declareSymbolAndAddToSymbolTable(node, 16 /* Function */, 110991 /* FunctionExcludes */);
                }
            }
            function bindFunctionExpression(node) {
                if (!file.isDeclarationFile && !(node.flags & 16777216 /* Ambient */)) {
                    if (isAsyncFunction(node)) {
                        emitFlags |= 2048 /* HasAsyncFunctions */;
                    }
                }
                if (currentFlow) {
                    node.flowNode = currentFlow;
                }
                checkStrictModeFunctionName(node);
                const bindingName = node.name ? node.name.escapedText : "__function" /* Function */;
                return bindAnonymousDeclaration(node, 16 /* Function */, bindingName);
            }
            function bindPropertyOrMethodOrAccessor(node, symbolFlags, symbolExcludes) {
                if (!file.isDeclarationFile && !(node.flags & 16777216 /* Ambient */) && isAsyncFunction(node)) {
                    emitFlags |= 2048 /* HasAsyncFunctions */;
                }
                if (currentFlow && isObjectLiteralOrClassExpressionMethodOrAccessor(node)) {
                    node.flowNode = currentFlow;
                }
                return hasDynamicName(node) ? bindAnonymousDeclaration(node, symbolFlags, "__computed" /* Computed */) : declareSymbolAndAddToSymbolTable(node, symbolFlags, symbolExcludes);
            }
            function getInferTypeContainer(node) {
                const extendsType = findAncestor(node, (n) => n.parent && isConditionalTypeNode(n.parent) && n.parent.extendsType === n);
                return extendsType && extendsType.parent;
            }
            function bindTypeParameter(node) {
                var _a2, _b;
                if (isJSDocTemplateTag(node.parent)) {
                    const container2 = getEffectiveContainerForJSDocTemplateTag(node.parent);
                    if (container2) {
                        Debug.assertNode(container2, canHaveLocals);
                        (_a2 = container2.locals) != null ? _a2 : container2.locals = createSymbolTable();
                        declareSymbol(container2.locals, 
                        /*parent*/
                        void 0, node, 262144 /* TypeParameter */, 526824 /* TypeParameterExcludes */);
                    }
                    else {
                        declareSymbolAndAddToSymbolTable(node, 262144 /* TypeParameter */, 526824 /* TypeParameterExcludes */);
                    }
                }
                else if (node.parent.kind === 192 /* InferType */) {
                    const container2 = getInferTypeContainer(node.parent);
                    if (container2) {
                        Debug.assertNode(container2, canHaveLocals);
                        (_b = container2.locals) != null ? _b : container2.locals = createSymbolTable();
                        declareSymbol(container2.locals, 
                        /*parent*/
                        void 0, node, 262144 /* TypeParameter */, 526824 /* TypeParameterExcludes */);
                    }
                    else {
                        bindAnonymousDeclaration(node, 262144 /* TypeParameter */, getDeclarationName(node));
                    }
                }
                else {
                    declareSymbolAndAddToSymbolTable(node, 262144 /* TypeParameter */, 526824 /* TypeParameterExcludes */);
                }
            }
            function shouldReportErrorOnModuleDeclaration(node) {
                const instanceState = getModuleInstanceState(node);
                return instanceState === 1 /* Instantiated */ || instanceState === 2 /* ConstEnumOnly */ && shouldPreserveConstEnums(options);
            }
            function checkUnreachable(node) {
                if (!(currentFlow.flags & 1 /* Unreachable */)) {
                    return false;
                }
                if (currentFlow === unreachableFlow) {
                    const reportError = (
                    // report error on all statements except empty ones
                    isStatementButNotDeclaration(node) && node.kind !== 239 /* EmptyStatement */ || // report error on class declarations
                        node.kind === 260 /* ClassDeclaration */ || // report error on instantiated modules or const-enums only modules if preserveConstEnums is set
                        node.kind === 264 /* ModuleDeclaration */ && shouldReportErrorOnModuleDeclaration(node));
                    if (reportError) {
                        currentFlow = reportedUnreachableFlow;
                        if (!options.allowUnreachableCode) {
                            const isError = unreachableCodeIsError(options) && !(node.flags & 16777216 /* Ambient */) && (!isVariableStatement(node) || !!(getCombinedNodeFlags(node.declarationList) & 3 /* BlockScoped */) || node.declarationList.declarations.some((d) => !!d.initializer));
                            eachUnreachableRange(node, (start, end) => errorOrSuggestionOnRange(isError, start, end, Diagnostics.Unreachable_code_detected));
                        }
                    }
                }
                return true;
            }
        }
        function eachUnreachableRange(node, cb) {
            if (isStatement(node) && isExecutableStatement(node) && isBlock(node.parent)) {
                const { statements } = node.parent;
                const slice = sliceAfter(statements, node);
                getRangesWhere(slice, isExecutableStatement, (start, afterEnd) => cb(slice[start], slice[afterEnd - 1]));
            }
            else {
                cb(node, node);
            }
        }
        function isExecutableStatement(s) {
            return !isFunctionDeclaration(s) && !isPurelyTypeDeclaration(s) && !isEnumDeclaration(s) && // `var x;` may declare a variable used above
                !(isVariableStatement(s) && !(getCombinedNodeFlags(s) & (1 /* Let */ | 2 /* Const */)) && s.declarationList.declarations.some((d) => !d.initializer));
        }
        function isPurelyTypeDeclaration(s) {
            switch (s.kind) {
                case 261 /* InterfaceDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                    return true;
                case 264 /* ModuleDeclaration */:
                    return getModuleInstanceState(s) !== 1 /* Instantiated */;
                case 263 /* EnumDeclaration */:
                    return hasSyntacticModifier(s, 2048 /* Const */);
                default:
                    return false;
            }
        }
        function isExportsOrModuleExportsOrAlias(sourceFile, node) {
            let i = 0;
            const q = createQueue();
            q.enqueue(node);
            while (!q.isEmpty() && i < 100) {
                i++;
                node = q.dequeue();
                if (isExportsIdentifier(node) || isModuleExportsAccessExpression(node)) {
                    return true;
                }
                else if (isIdentifier(node)) {
                    const symbol = lookupSymbolForName(sourceFile, node.escapedText);
                    if (!!symbol && !!symbol.valueDeclaration && isVariableDeclaration(symbol.valueDeclaration) && !!symbol.valueDeclaration.initializer) {
                        const init = symbol.valueDeclaration.initializer;
                        q.enqueue(init);
                        if (isAssignmentExpression(init, 
                        /*excludeCompoundAssignment*/
                        true)) {
                            q.enqueue(init.left);
                            q.enqueue(init.right);
                        }
                    }
                }
            }
            return false;
        }
        function getContainerFlags(node) {
            switch (node.kind) {
                case 228 /* ClassExpression */:
                case 260 /* ClassDeclaration */:
                case 263 /* EnumDeclaration */:
                case 207 /* ObjectLiteralExpression */:
                case 184 /* TypeLiteral */:
                case 325 /* JSDocTypeLiteral */:
                case 289 /* JsxAttributes */:
                    return 1 /* IsContainer */;
                case 261 /* InterfaceDeclaration */:
                    return 1 /* IsContainer */ | 64 /* IsInterface */;
                case 264 /* ModuleDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 197 /* MappedType */:
                case 178 /* IndexSignature */:
                    return 1 /* IsContainer */ | 32 /* HasLocals */;
                case 308 /* SourceFile */:
                    return 1 /* IsContainer */ | 4 /* IsControlFlowContainer */ | 32 /* HasLocals */;
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 171 /* MethodDeclaration */:
                    if (isObjectLiteralOrClassExpressionMethodOrAccessor(node)) {
                        return 1 /* IsContainer */ | 4 /* IsControlFlowContainer */ | 32 /* HasLocals */ | 8 /* IsFunctionLike */ | 128 /* IsObjectLiteralOrClassExpressionMethodOrAccessor */;
                    }
                case 173 /* Constructor */:
                case 259 /* FunctionDeclaration */:
                case 170 /* MethodSignature */:
                case 176 /* CallSignature */:
                case 326 /* JSDocSignature */:
                case 320 /* JSDocFunctionType */:
                case 181 /* FunctionType */:
                case 177 /* ConstructSignature */:
                case 182 /* ConstructorType */:
                case 172 /* ClassStaticBlockDeclaration */:
                    return 1 /* IsContainer */ | 4 /* IsControlFlowContainer */ | 32 /* HasLocals */ | 8 /* IsFunctionLike */;
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                    return 1 /* IsContainer */ | 4 /* IsControlFlowContainer */ | 32 /* HasLocals */ | 8 /* IsFunctionLike */ | 16 /* IsFunctionExpression */;
                case 265 /* ModuleBlock */:
                    return 4 /* IsControlFlowContainer */;
                case 169 /* PropertyDeclaration */:
                    return node.initializer ? 4 /* IsControlFlowContainer */ : 0;
                case 295 /* CatchClause */:
                case 245 /* ForStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                case 266 /* CaseBlock */:
                    return 2 /* IsBlockScopedContainer */ | 32 /* HasLocals */;
                case 238 /* Block */:
                    return isFunctionLike(node.parent) || isClassStaticBlockDeclaration(node.parent) ? 0 /* None */ : 2 /* IsBlockScopedContainer */ | 32 /* HasLocals */;
            }
            return 0 /* None */;
        }
        function lookupSymbolForName(container, name) {
            var _a2, _b, _c, _d, _e;
            const local = (_b = (_a2 = tryCast(container, canHaveLocals)) == null ? void 0 : _a2.locals) == null ? void 0 : _b.get(name);
            if (local) {
                return (_c = local.exportSymbol) != null ? _c : local;
            }
            if (isSourceFile(container) && container.jsGlobalAugmentations && container.jsGlobalAugmentations.has(name)) {
                return container.jsGlobalAugmentations.get(name);
            }
            if (canHaveSymbol(container)) {
                return (_e = (_d = container.symbol) == null ? void 0 : _d.exports) == null ? void 0 : _e.get(name);
            }
        }
        var ModuleInstanceState, binder;
        var init_binder = __esm({
            "src/compiler/binder.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                ModuleInstanceState = /* @__PURE__ */ ((ModuleInstanceState2) => {
                    ModuleInstanceState2[ModuleInstanceState2["NonInstantiated"] = 0] = "NonInstantiated";
                    ModuleInstanceState2[ModuleInstanceState2["Instantiated"] = 1] = "Instantiated";
                    ModuleInstanceState2[ModuleInstanceState2["ConstEnumOnly"] = 2] = "ConstEnumOnly";
                    return ModuleInstanceState2;
                })(ModuleInstanceState || {});
                binder = createBinder();
            }
        });
        // src/compiler/symbolWalker.ts
        function createGetSymbolWalker(getRestTypeOfSignature, getTypePredicateOfSignature, getReturnTypeOfSignature, getBaseTypes, resolveStructuredTypeMembers, getTypeOfSymbol, getResolvedSymbol, getConstraintOfTypeParameter, getFirstIdentifier2, getTypeArguments) {
            return getSymbolWalker;
            function getSymbolWalker(accept = () => true) {
                const visitedTypes = [];
                const visitedSymbols = [];
                return {
                    walkType: (type) => {
                        try {
                            visitType(type);
                            return { visitedTypes: getOwnValues(visitedTypes), visitedSymbols: getOwnValues(visitedSymbols) };
                        }
                        finally {
                            clear(visitedTypes);
                            clear(visitedSymbols);
                        }
                    },
                    walkSymbol: (symbol) => {
                        try {
                            visitSymbol(symbol);
                            return { visitedTypes: getOwnValues(visitedTypes), visitedSymbols: getOwnValues(visitedSymbols) };
                        }
                        finally {
                            clear(visitedTypes);
                            clear(visitedSymbols);
                        }
                    }
                };
                function visitType(type) {
                    if (!type) {
                        return;
                    }
                    if (visitedTypes[type.id]) {
                        return;
                    }
                    visitedTypes[type.id] = type;
                    const shouldBail = visitSymbol(type.symbol);
                    if (shouldBail)
                        return;
                    if (type.flags & 524288 /* Object */) {
                        const objectType = type;
                        const objectFlags = objectType.objectFlags;
                        if (objectFlags & 4 /* Reference */) {
                            visitTypeReference(type);
                        }
                        if (objectFlags & 32 /* Mapped */) {
                            visitMappedType(type);
                        }
                        if (objectFlags & (1 /* Class */ | 2 /* Interface */)) {
                            visitInterfaceType(type);
                        }
                        if (objectFlags & (8 /* Tuple */ | 16 /* Anonymous */)) {
                            visitObjectType(objectType);
                        }
                    }
                    if (type.flags & 262144 /* TypeParameter */) {
                        visitTypeParameter(type);
                    }
                    if (type.flags & 3145728 /* UnionOrIntersection */) {
                        visitUnionOrIntersectionType(type);
                    }
                    if (type.flags & 4194304 /* Index */) {
                        visitIndexType(type);
                    }
                    if (type.flags & 8388608 /* IndexedAccess */) {
                        visitIndexedAccessType(type);
                    }
                }
                function visitTypeReference(type) {
                    visitType(type.target);
                    forEach(getTypeArguments(type), visitType);
                }
                function visitTypeParameter(type) {
                    visitType(getConstraintOfTypeParameter(type));
                }
                function visitUnionOrIntersectionType(type) {
                    forEach(type.types, visitType);
                }
                function visitIndexType(type) {
                    visitType(type.type);
                }
                function visitIndexedAccessType(type) {
                    visitType(type.objectType);
                    visitType(type.indexType);
                    visitType(type.constraint);
                }
                function visitMappedType(type) {
                    visitType(type.typeParameter);
                    visitType(type.constraintType);
                    visitType(type.templateType);
                    visitType(type.modifiersType);
                }
                function visitSignature(signature) {
                    const typePredicate = getTypePredicateOfSignature(signature);
                    if (typePredicate) {
                        visitType(typePredicate.type);
                    }
                    forEach(signature.typeParameters, visitType);
                    for (const parameter of signature.parameters) {
                        visitSymbol(parameter);
                    }
                    visitType(getRestTypeOfSignature(signature));
                    visitType(getReturnTypeOfSignature(signature));
                }
                function visitInterfaceType(interfaceT) {
                    visitObjectType(interfaceT);
                    forEach(interfaceT.typeParameters, visitType);
                    forEach(getBaseTypes(interfaceT), visitType);
                    visitType(interfaceT.thisType);
                }
                function visitObjectType(type) {
                    const resolved = resolveStructuredTypeMembers(type);
                    for (const info of resolved.indexInfos) {
                        visitType(info.keyType);
                        visitType(info.type);
                    }
                    for (const signature of resolved.callSignatures) {
                        visitSignature(signature);
                    }
                    for (const signature of resolved.constructSignatures) {
                        visitSignature(signature);
                    }
                    for (const p of resolved.properties) {
                        visitSymbol(p);
                    }
                }
                function visitSymbol(symbol) {
                    if (!symbol) {
                        return false;
                    }
                    const symbolId = getSymbolId(symbol);
                    if (visitedSymbols[symbolId]) {
                        return false;
                    }
                    visitedSymbols[symbolId] = symbol;
                    if (!accept(symbol)) {
                        return true;
                    }
                    const t = getTypeOfSymbol(symbol);
                    visitType(t);
                    if (symbol.exports) {
                        symbol.exports.forEach(visitSymbol);
                    }
                    forEach(symbol.declarations, (d) => {
                        if (d.type && d.type.kind === 183 /* TypeQuery */) {
                            const query = d.type;
                            const entity = getResolvedSymbol(getFirstIdentifier2(query.exprName));
                            visitSymbol(entity);
                        }
                    });
                    return false;
                }
            }
        }
        var init_symbolWalker = __esm({
            "src/compiler/symbolWalker.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/moduleSpecifiers.ts
        function getPreferences({ importModuleSpecifierPreference, importModuleSpecifierEnding }, compilerOptions, importingSourceFile, oldImportSpecifier) {
            const preferredEnding = getPreferredEnding();
            return {
                relativePreference: oldImportSpecifier !== void 0 ? isExternalModuleNameRelative(oldImportSpecifier) ? 0 /* Relative */ : 1 /* NonRelative */ : importModuleSpecifierPreference === "relative" ? 0 /* Relative */ : importModuleSpecifierPreference === "non-relative" ? 1 /* NonRelative */ : importModuleSpecifierPreference === "project-relative" ? 3 /* ExternalNonRelative */ : 2 /* Shortest */,
                getAllowedEndingsInPreferredOrder: (syntaxImpliedNodeFormat) => {
                    if ((syntaxImpliedNodeFormat != null ? syntaxImpliedNodeFormat : importingSourceFile.impliedNodeFormat) === 99 /* ESNext */) {
                        if (shouldAllowImportingTsExtension(compilerOptions, importingSourceFile.fileName)) {
                            return [3 /* TsExtension */, 2 /* JsExtension */];
                        }
                        return [2 /* JsExtension */];
                    }
                    if (getEmitModuleResolutionKind(compilerOptions) === 1 /* Classic */) {
                        return [1 /* Index */, 2 /* JsExtension */];
                    }
                    switch (preferredEnding) {
                        case 2 /* JsExtension */:
                            return [2 /* JsExtension */, 0 /* Minimal */, 1 /* Index */];
                        case 3 /* TsExtension */:
                            return [3 /* TsExtension */, 0 /* Minimal */, 2 /* JsExtension */, 1 /* Index */];
                        case 1 /* Index */:
                            return [1 /* Index */, 0 /* Minimal */, 2 /* JsExtension */];
                        case 0 /* Minimal */:
                            return [0 /* Minimal */, 1 /* Index */, 2 /* JsExtension */];
                        default:
                            Debug.assertNever(preferredEnding);
                    }
                }
            };
            function getPreferredEnding() {
                if (oldImportSpecifier !== void 0) {
                    if (hasJSFileExtension(oldImportSpecifier))
                        return 2 /* JsExtension */;
                    if (endsWith(oldImportSpecifier, "/index"))
                        return 1 /* Index */;
                }
                return getModuleSpecifierEndingPreference(importModuleSpecifierEnding, importingSourceFile.impliedNodeFormat, compilerOptions, importingSourceFile);
            }
        }
        function updateModuleSpecifier(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, oldImportSpecifier, options = {}) {
            const res = getModuleSpecifierWorker(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, getPreferences({}, compilerOptions, importingSourceFile, oldImportSpecifier), {}, options);
            if (res === oldImportSpecifier)
                return void 0;
            return res;
        }
        function getModuleSpecifier(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, options = {}) {
            return getModuleSpecifierWorker(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, getPreferences({}, compilerOptions, importingSourceFile), {}, options);
        }
        function getNodeModulesPackageName(compilerOptions, importingSourceFile, nodeModulesFileName, host, preferences, options = {}) {
            const info = getInfo(importingSourceFile.path, host);
            const modulePaths = getAllModulePaths(importingSourceFile.path, nodeModulesFileName, host, preferences, options);
            return firstDefined(modulePaths, (modulePath) => tryGetModuleNameAsNodeModule(modulePath, info, importingSourceFile, host, compilerOptions, preferences, 
            /*packageNameOnly*/
            true, options.overrideImportMode));
        }
        function getModuleSpecifierWorker(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, preferences, userPreferences, options = {}) {
            const info = getInfo(importingSourceFileName, host);
            const modulePaths = getAllModulePaths(importingSourceFileName, toFileName2, host, userPreferences, options);
            return firstDefined(modulePaths, (modulePath) => tryGetModuleNameAsNodeModule(modulePath, info, importingSourceFile, host, compilerOptions, userPreferences, 
            /*packageNameOnly*/
            void 0, options.overrideImportMode)) || getLocalModuleSpecifier(toFileName2, info, compilerOptions, host, options.overrideImportMode || importingSourceFile.impliedNodeFormat, preferences);
        }
        function tryGetModuleSpecifiersFromCache(moduleSymbol, importingSourceFile, host, userPreferences, options = {}) {
            return tryGetModuleSpecifiersFromCacheWorker(moduleSymbol, importingSourceFile, host, userPreferences, options)[0];
        }
        function tryGetModuleSpecifiersFromCacheWorker(moduleSymbol, importingSourceFile, host, userPreferences, options = {}) {
            var _a2;
            const moduleSourceFile = getSourceFileOfModule(moduleSymbol);
            if (!moduleSourceFile) {
                return emptyArray;
            }
            const cache = (_a2 = host.getModuleSpecifierCache) == null ? void 0 : _a2.call(host);
            const cached = cache == null ? void 0 : cache.get(importingSourceFile.path, moduleSourceFile.path, userPreferences, options);
            return [cached == null ? void 0 : cached.moduleSpecifiers, moduleSourceFile, cached == null ? void 0 : cached.modulePaths, cache];
        }
        function getModuleSpecifiers(moduleSymbol, checker, compilerOptions, importingSourceFile, host, userPreferences, options = {}) {
            return getModuleSpecifiersWithCacheInfo(moduleSymbol, checker, compilerOptions, importingSourceFile, host, userPreferences, options).moduleSpecifiers;
        }
        function getModuleSpecifiersWithCacheInfo(moduleSymbol, checker, compilerOptions, importingSourceFile, host, userPreferences, options = {}) {
            let computedWithoutCache = false;
            const ambient = tryGetModuleNameFromAmbientModule(moduleSymbol, checker);
            if (ambient)
                return { moduleSpecifiers: [ambient], computedWithoutCache };
            let [specifiers, moduleSourceFile, modulePaths, cache] = tryGetModuleSpecifiersFromCacheWorker(moduleSymbol, importingSourceFile, host, userPreferences, options);
            if (specifiers)
                return { moduleSpecifiers: specifiers, computedWithoutCache };
            if (!moduleSourceFile)
                return { moduleSpecifiers: emptyArray, computedWithoutCache };
            computedWithoutCache = true;
            modulePaths || (modulePaths = getAllModulePathsWorker(importingSourceFile.path, moduleSourceFile.originalFileName, host));
            const result = computeModuleSpecifiers(modulePaths, compilerOptions, importingSourceFile, host, userPreferences, options);
            cache == null ? void 0 : cache.set(importingSourceFile.path, moduleSourceFile.path, userPreferences, options, modulePaths, result);
            return { moduleSpecifiers: result, computedWithoutCache };
        }
        function computeModuleSpecifiers(modulePaths, compilerOptions, importingSourceFile, host, userPreferences, options = {}) {
            const info = getInfo(importingSourceFile.path, host);
            const preferences = getPreferences(userPreferences, compilerOptions, importingSourceFile);
            const existingSpecifier = forEach(modulePaths, (modulePath) => forEach(host.getFileIncludeReasons().get(toPath(modulePath.path, host.getCurrentDirectory(), info.getCanonicalFileName)), (reason) => {
                if (reason.kind !== 3 /* Import */ || reason.file !== importingSourceFile.path)
                    return void 0;
                if (importingSourceFile.impliedNodeFormat && importingSourceFile.impliedNodeFormat !== getModeForResolutionAtIndex(importingSourceFile, reason.index))
                    return void 0;
                const specifier = getModuleNameStringLiteralAt(importingSourceFile, reason.index).text;
                return preferences.relativePreference !== 1 /* NonRelative */ || !pathIsRelative(specifier) ? specifier : void 0;
            }));
            if (existingSpecifier) {
                const moduleSpecifiers = [existingSpecifier];
                return moduleSpecifiers;
            }
            const importedFileIsInNodeModules = some(modulePaths, (p) => p.isInNodeModules);
            let nodeModulesSpecifiers;
            let pathsSpecifiers;
            let redirectPathsSpecifiers;
            let relativeSpecifiers;
            for (const modulePath of modulePaths) {
                const specifier = modulePath.isInNodeModules ? tryGetModuleNameAsNodeModule(modulePath, info, importingSourceFile, host, compilerOptions, userPreferences, 
                /*packageNameOnly*/
                void 0, options.overrideImportMode) : void 0;
                nodeModulesSpecifiers = append(nodeModulesSpecifiers, specifier);
                if (specifier && modulePath.isRedirect) {
                    return nodeModulesSpecifiers;
                }
                if (!specifier) {
                    const local = getLocalModuleSpecifier(modulePath.path, info, compilerOptions, host, options.overrideImportMode || importingSourceFile.impliedNodeFormat, preferences, 
                    /*pathsOnly*/
                    modulePath.isRedirect);
                    if (!local) {
                        continue;
                    }
                    if (modulePath.isRedirect) {
                        redirectPathsSpecifiers = append(redirectPathsSpecifiers, local);
                    }
                    else if (pathIsBareSpecifier(local)) {
                        pathsSpecifiers = append(pathsSpecifiers, local);
                    }
                    else if (!importedFileIsInNodeModules || modulePath.isInNodeModules) {
                        relativeSpecifiers = append(relativeSpecifiers, local);
                    }
                }
            }
            return (pathsSpecifiers == null ? void 0 : pathsSpecifiers.length) ? pathsSpecifiers : (redirectPathsSpecifiers == null ? void 0 : redirectPathsSpecifiers.length) ? redirectPathsSpecifiers : (nodeModulesSpecifiers == null ? void 0 : nodeModulesSpecifiers.length) ? nodeModulesSpecifiers : Debug.checkDefined(relativeSpecifiers);
        }
        function getInfo(importingSourceFileName, host) {
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames ? host.useCaseSensitiveFileNames() : true);
            const sourceDirectory = getDirectoryPath(importingSourceFileName);
            return { getCanonicalFileName, importingSourceFileName, sourceDirectory };
        }
        function getLocalModuleSpecifier(moduleFileName, info, compilerOptions, host, importMode, { getAllowedEndingsInPreferredOrder: getAllowedEndingsInPrefererredOrder, relativePreference }, pathsOnly) {
            const { baseUrl, paths, rootDirs } = compilerOptions;
            if (pathsOnly && !paths) {
                return void 0;
            }
            const { sourceDirectory, getCanonicalFileName } = info;
            const allowedEndings = getAllowedEndingsInPrefererredOrder(importMode);
            const relativePath = rootDirs && tryGetModuleNameFromRootDirs(rootDirs, moduleFileName, sourceDirectory, getCanonicalFileName, allowedEndings, compilerOptions) || processEnding(ensurePathIsNonModuleName(getRelativePathFromDirectory(sourceDirectory, moduleFileName, getCanonicalFileName)), allowedEndings, compilerOptions);
            if (!baseUrl && !paths || relativePreference === 0 /* Relative */) {
                return pathsOnly ? void 0 : relativePath;
            }
            const baseDirectory = getNormalizedAbsolutePath(getPathsBasePath(compilerOptions, host) || baseUrl, host.getCurrentDirectory());
            const relativeToBaseUrl = getRelativePathIfInDirectory(moduleFileName, baseDirectory, getCanonicalFileName);
            if (!relativeToBaseUrl) {
                return pathsOnly ? void 0 : relativePath;
            }
            const fromPaths = paths && tryGetModuleNameFromPaths(relativeToBaseUrl, paths, allowedEndings, host, compilerOptions);
            if (pathsOnly) {
                return fromPaths;
            }
            const maybeNonRelative = fromPaths === void 0 && baseUrl !== void 0 ? processEnding(relativeToBaseUrl, allowedEndings, compilerOptions) : fromPaths;
            if (!maybeNonRelative) {
                return relativePath;
            }
            if (relativePreference === 1 /* NonRelative */ && !pathIsRelative(maybeNonRelative)) {
                return maybeNonRelative;
            }
            if (relativePreference === 3 /* ExternalNonRelative */ && !pathIsRelative(maybeNonRelative)) {
                const projectDirectory = compilerOptions.configFilePath ? toPath(getDirectoryPath(compilerOptions.configFilePath), host.getCurrentDirectory(), info.getCanonicalFileName) : info.getCanonicalFileName(host.getCurrentDirectory());
                const modulePath = toPath(moduleFileName, projectDirectory, getCanonicalFileName);
                const sourceIsInternal = startsWith(sourceDirectory, projectDirectory);
                const targetIsInternal = startsWith(modulePath, projectDirectory);
                if (sourceIsInternal && !targetIsInternal || !sourceIsInternal && targetIsInternal) {
                    return maybeNonRelative;
                }
                const nearestTargetPackageJson = getNearestAncestorDirectoryWithPackageJson(host, getDirectoryPath(modulePath));
                const nearestSourcePackageJson = getNearestAncestorDirectoryWithPackageJson(host, sourceDirectory);
                if (nearestSourcePackageJson !== nearestTargetPackageJson) {
                    return maybeNonRelative;
                }
                return relativePath;
            }
            return isPathRelativeToParent(maybeNonRelative) || countPathComponents(relativePath) < countPathComponents(maybeNonRelative) ? relativePath : maybeNonRelative;
        }
        function countPathComponents(path) {
            let count = 0;
            for (let i = startsWith(path, "./") ? 2 : 0; i < path.length; i++) {
                if (path.charCodeAt(i) === 47 /* slash */)
                    count++;
            }
            return count;
        }
        function comparePathsByRedirectAndNumberOfDirectorySeparators(a, b) {
            return compareBooleans(b.isRedirect, a.isRedirect) || compareNumberOfDirectorySeparators(a.path, b.path);
        }
        function getNearestAncestorDirectoryWithPackageJson(host, fileName) {
            if (host.getNearestAncestorDirectoryWithPackageJson) {
                return host.getNearestAncestorDirectoryWithPackageJson(fileName);
            }
            return !!forEachAncestorDirectory(fileName, (directory) => {
                return host.fileExists(combinePaths(directory, "package.json")) ? true : void 0;
            });
        }
        function forEachFileNameOfModule(importingFileName, importedFileName, host, preferSymlinks, cb) {
            var _a2;
            const getCanonicalFileName = hostGetCanonicalFileName(host);
            const cwd = host.getCurrentDirectory();
            const referenceRedirect = host.isSourceOfProjectReferenceRedirect(importedFileName) ? host.getProjectReferenceRedirect(importedFileName) : void 0;
            const importedPath = toPath(importedFileName, cwd, getCanonicalFileName);
            const redirects = host.redirectTargetsMap.get(importedPath) || emptyArray;
            const importedFileNames = [...referenceRedirect ? [referenceRedirect] : emptyArray, importedFileName, ...redirects];
            const targets = importedFileNames.map((f) => getNormalizedAbsolutePath(f, cwd));
            let shouldFilterIgnoredPaths = !every(targets, containsIgnoredPath);
            if (!preferSymlinks) {
                const result2 = forEach(targets, (p) => !(shouldFilterIgnoredPaths && containsIgnoredPath(p)) && cb(p, referenceRedirect === p));
                if (result2)
                    return result2;
            }
            const symlinkedDirectories = (_a2 = host.getSymlinkCache) == null ? void 0 : _a2.call(host).getSymlinkedDirectoriesByRealpath();
            const fullImportedFileName = getNormalizedAbsolutePath(importedFileName, cwd);
            const result = symlinkedDirectories && forEachAncestorDirectory(getDirectoryPath(fullImportedFileName), (realPathDirectory) => {
                const symlinkDirectories = symlinkedDirectories.get(ensureTrailingDirectorySeparator(toPath(realPathDirectory, cwd, getCanonicalFileName)));
                if (!symlinkDirectories)
                    return void 0;
                if (startsWithDirectory(importingFileName, realPathDirectory, getCanonicalFileName)) {
                    return false;
                }
                return forEach(targets, (target) => {
                    if (!startsWithDirectory(target, realPathDirectory, getCanonicalFileName)) {
                        return;
                    }
                    const relative = getRelativePathFromDirectory(realPathDirectory, target, getCanonicalFileName);
                    for (const symlinkDirectory of symlinkDirectories) {
                        const option = resolvePath(symlinkDirectory, relative);
                        const result2 = cb(option, target === referenceRedirect);
                        shouldFilterIgnoredPaths = true;
                        if (result2)
                            return result2;
                    }
                });
            });
            return result || (preferSymlinks ? forEach(targets, (p) => shouldFilterIgnoredPaths && containsIgnoredPath(p) ? void 0 : cb(p, p === referenceRedirect)) : void 0);
        }
        function getAllModulePaths(importingFilePath, importedFileName, host, preferences, options = {}) {
            var _a2;
            const importedFilePath = toPath(importedFileName, host.getCurrentDirectory(), hostGetCanonicalFileName(host));
            const cache = (_a2 = host.getModuleSpecifierCache) == null ? void 0 : _a2.call(host);
            if (cache) {
                const cached = cache.get(importingFilePath, importedFilePath, preferences, options);
                if (cached == null ? void 0 : cached.modulePaths)
                    return cached.modulePaths;
            }
            const modulePaths = getAllModulePathsWorker(importingFilePath, importedFileName, host);
            if (cache) {
                cache.setModulePaths(importingFilePath, importedFilePath, preferences, options, modulePaths);
            }
            return modulePaths;
        }
        function getAllModulePathsWorker(importingFileName, importedFileName, host) {
            const getCanonicalFileName = hostGetCanonicalFileName(host);
            const allFileNames = /* @__PURE__ */ new Map();
            let importedFileFromNodeModules = false;
            forEachFileNameOfModule(importingFileName, importedFileName, host, 
            /*preferSymlinks*/
            true, (path, isRedirect) => {
                const isInNodeModules = pathContainsNodeModules(path);
                allFileNames.set(path, { path: getCanonicalFileName(path), isRedirect, isInNodeModules });
                importedFileFromNodeModules = importedFileFromNodeModules || isInNodeModules;
            });
            const sortedPaths = [];
            for (let directory = getDirectoryPath(importingFileName); allFileNames.size !== 0;) {
                const directoryStart = ensureTrailingDirectorySeparator(directory);
                let pathsInDirectory;
                allFileNames.forEach(({ path, isRedirect, isInNodeModules }, fileName) => {
                    if (startsWith(path, directoryStart)) {
                        (pathsInDirectory || (pathsInDirectory = [])).push({ path: fileName, isRedirect, isInNodeModules });
                        allFileNames.delete(fileName);
                    }
                });
                if (pathsInDirectory) {
                    if (pathsInDirectory.length > 1) {
                        pathsInDirectory.sort(comparePathsByRedirectAndNumberOfDirectorySeparators);
                    }
                    sortedPaths.push(...pathsInDirectory);
                }
                const newDirectory = getDirectoryPath(directory);
                if (newDirectory === directory)
                    break;
                directory = newDirectory;
            }
            if (allFileNames.size) {
                const remainingPaths = arrayFrom(allFileNames.values());
                if (remainingPaths.length > 1)
                    remainingPaths.sort(comparePathsByRedirectAndNumberOfDirectorySeparators);
                sortedPaths.push(...remainingPaths);
            }
            return sortedPaths;
        }
        function tryGetModuleNameFromAmbientModule(moduleSymbol, checker) {
            var _a2;
            const decl = (_a2 = moduleSymbol.declarations) == null ? void 0 : _a2.find((d) => isNonGlobalAmbientModule(d) && (!isExternalModuleAugmentation(d) || !isExternalModuleNameRelative(getTextOfIdentifierOrLiteral(d.name))));
            if (decl) {
                return decl.name.text;
            }
            const ambientModuleDeclareCandidates = mapDefined(moduleSymbol.declarations, (d) => {
                var _a3, _b, _c, _d;
                if (!isModuleDeclaration(d))
                    return;
                const topNamespace = getTopNamespace(d);
                if (!(((_a3 = topNamespace == null ? void 0 : topNamespace.parent) == null ? void 0 : _a3.parent) && isModuleBlock(topNamespace.parent) && isAmbientModule(topNamespace.parent.parent) && isSourceFile(topNamespace.parent.parent.parent)))
                    return;
                const exportAssignment = (_d = (_c = (_b = topNamespace.parent.parent.symbol.exports) == null ? void 0 : _b.get("export=")) == null ? void 0 : _c.valueDeclaration) == null ? void 0 : _d.expression;
                if (!exportAssignment)
                    return;
                const exportSymbol = checker.getSymbolAtLocation(exportAssignment);
                if (!exportSymbol)
                    return;
                const originalExportSymbol = (exportSymbol == null ? void 0 : exportSymbol.flags) & 2097152 /* Alias */ ? checker.getAliasedSymbol(exportSymbol) : exportSymbol;
                if (originalExportSymbol === d.symbol)
                    return topNamespace.parent.parent;
                function getTopNamespace(namespaceDeclaration) {
                    while (namespaceDeclaration.flags & 4 /* NestedNamespace */) {
                        namespaceDeclaration = namespaceDeclaration.parent;
                    }
                    return namespaceDeclaration;
                }
            });
            const ambientModuleDeclare = ambientModuleDeclareCandidates[0];
            if (ambientModuleDeclare) {
                return ambientModuleDeclare.name.text;
            }
        }
        function tryGetModuleNameFromPaths(relativeToBaseUrl, paths, allowedEndings, host, compilerOptions) {
            for (const key in paths) {
                for (const patternText2 of paths[key]) {
                    const pattern = normalizePath(patternText2);
                    const indexOfStar = pattern.indexOf("*");
                    const candidates = allowedEndings.map((ending) => ({
                        ending,
                        value: processEnding(relativeToBaseUrl, [ending], compilerOptions)
                    }));
                    if (tryGetExtensionFromPath2(pattern)) {
                        candidates.push({ ending: void 0, value: relativeToBaseUrl });
                    }
                    if (indexOfStar !== -1) {
                        const prefix = pattern.substring(0, indexOfStar);
                        const suffix = pattern.substring(indexOfStar + 1);
                        for (const { ending, value } of candidates) {
                            if (value.length >= prefix.length + suffix.length && startsWith(value, prefix) && endsWith(value, suffix) && validateEnding({ ending, value })) {
                                const matchedStar = value.substring(prefix.length, value.length - suffix.length);
                                return key.replace("*", matchedStar);
                            }
                        }
                    }
                    else if (some(candidates, (c) => c.ending !== 0 /* Minimal */ && pattern === c.value) || some(candidates, (c) => c.ending === 0 /* Minimal */ && pattern === c.value && validateEnding(c))) {
                        return key;
                    }
                }
            }
            function validateEnding({ ending, value }) {
                return ending !== 0 /* Minimal */ || value === processEnding(relativeToBaseUrl, [ending], compilerOptions, host);
            }
        }
        function tryGetModuleNameFromExports(options, targetFilePath, packageDirectory, packageName, exports, conditions, mode = 0 /* Exact */) {
            if (typeof exports === "string") {
                const pathOrPattern = getNormalizedAbsolutePath(combinePaths(packageDirectory, exports), 
                /*currentDirectory*/
                void 0);
                const extensionSwappedTarget = hasTSFileExtension(targetFilePath) ? removeFileExtension(targetFilePath) + tryGetJSExtensionForFile(targetFilePath, options) : void 0;
                switch (mode) {
                    case 0 /* Exact */:
                        if (comparePaths(targetFilePath, pathOrPattern) === 0 /* EqualTo */ || extensionSwappedTarget && comparePaths(extensionSwappedTarget, pathOrPattern) === 0 /* EqualTo */) {
                            return { moduleFileToTry: packageName };
                        }
                        break;
                    case 1 /* Directory */:
                        if (containsPath(pathOrPattern, targetFilePath)) {
                            const fragment = getRelativePathFromDirectory(pathOrPattern, targetFilePath, 
                            /*ignoreCase*/
                            false);
                            return { moduleFileToTry: getNormalizedAbsolutePath(combinePaths(combinePaths(packageName, exports), fragment), 
                                /*currentDirectory*/
                                void 0) };
                        }
                        break;
                    case 2 /* Pattern */:
                        const starPos = pathOrPattern.indexOf("*");
                        const leadingSlice = pathOrPattern.slice(0, starPos);
                        const trailingSlice = pathOrPattern.slice(starPos + 1);
                        if (startsWith(targetFilePath, leadingSlice) && endsWith(targetFilePath, trailingSlice)) {
                            const starReplacement = targetFilePath.slice(leadingSlice.length, targetFilePath.length - trailingSlice.length);
                            return { moduleFileToTry: packageName.replace("*", starReplacement) };
                        }
                        if (extensionSwappedTarget && startsWith(extensionSwappedTarget, leadingSlice) && endsWith(extensionSwappedTarget, trailingSlice)) {
                            const starReplacement = extensionSwappedTarget.slice(leadingSlice.length, extensionSwappedTarget.length - trailingSlice.length);
                            return { moduleFileToTry: packageName.replace("*", starReplacement) };
                        }
                        break;
                }
            }
            else if (Array.isArray(exports)) {
                return forEach(exports, (e) => tryGetModuleNameFromExports(options, targetFilePath, packageDirectory, packageName, e, conditions));
            }
            else if (typeof exports === "object" && exports !== null) {
                if (allKeysStartWithDot(exports)) {
                    return forEach(getOwnKeys(exports), (k) => {
                        const subPackageName = getNormalizedAbsolutePath(combinePaths(packageName, k), 
                        /*currentDirectory*/
                        void 0);
                        const mode2 = endsWith(k, "/") ? 1 /* Directory */ : stringContains(k, "*") ? 2 /* Pattern */ : 0 /* Exact */;
                        return tryGetModuleNameFromExports(options, targetFilePath, packageDirectory, subPackageName, exports[k], conditions, mode2);
                    });
                }
                else {
                    for (const key of getOwnKeys(exports)) {
                        if (key === "default" || conditions.indexOf(key) >= 0 || isApplicableVersionedTypesKey(conditions, key)) {
                            const subTarget = exports[key];
                            const result = tryGetModuleNameFromExports(options, targetFilePath, packageDirectory, packageName, subTarget, conditions);
                            if (result) {
                                return result;
                            }
                        }
                    }
                }
            }
            return void 0;
        }
        function tryGetModuleNameFromRootDirs(rootDirs, moduleFileName, sourceDirectory, getCanonicalFileName, allowedEndings, compilerOptions) {
            const normalizedTargetPaths = getPathsRelativeToRootDirs(moduleFileName, rootDirs, getCanonicalFileName);
            if (normalizedTargetPaths === void 0) {
                return void 0;
            }
            const normalizedSourcePaths = getPathsRelativeToRootDirs(sourceDirectory, rootDirs, getCanonicalFileName);
            const relativePaths = flatMap(normalizedSourcePaths, (sourcePath) => {
                return map(normalizedTargetPaths, (targetPath) => ensurePathIsNonModuleName(getRelativePathFromDirectory(sourcePath, targetPath, getCanonicalFileName)));
            });
            const shortest = min(relativePaths, compareNumberOfDirectorySeparators);
            if (!shortest) {
                return void 0;
            }
            return processEnding(shortest, allowedEndings, compilerOptions);
        }
        function tryGetModuleNameAsNodeModule({ path, isRedirect }, { getCanonicalFileName, sourceDirectory }, importingSourceFile, host, options, userPreferences, packageNameOnly, overrideMode) {
            if (!host.fileExists || !host.readFile) {
                return void 0;
            }
            const parts = getNodeModulePathParts(path);
            if (!parts) {
                return void 0;
            }
            const preferences = getPreferences(userPreferences, options, importingSourceFile);
            const allowedEndings = preferences.getAllowedEndingsInPreferredOrder();
            let moduleSpecifier = path;
            let isPackageRootPath = false;
            if (!packageNameOnly) {
                let packageRootIndex = parts.packageRootIndex;
                let moduleFileName;
                while (true) {
                    const { moduleFileToTry, packageRootPath, blockedByExports, verbatimFromExports } = tryDirectoryWithPackageJson(packageRootIndex);
                    if (getEmitModuleResolutionKind(options) !== 1 /* Classic */) {
                        if (blockedByExports) {
                            return void 0;
                        }
                        if (verbatimFromExports) {
                            return moduleFileToTry;
                        }
                    }
                    if (packageRootPath) {
                        moduleSpecifier = packageRootPath;
                        isPackageRootPath = true;
                        break;
                    }
                    if (!moduleFileName)
                        moduleFileName = moduleFileToTry;
                    packageRootIndex = path.indexOf(directorySeparator, packageRootIndex + 1);
                    if (packageRootIndex === -1) {
                        moduleSpecifier = processEnding(moduleFileName, allowedEndings, options, host);
                        break;
                    }
                }
            }
            if (isRedirect && !isPackageRootPath) {
                return void 0;
            }
            const globalTypingsCacheLocation = host.getGlobalTypingsCacheLocation && host.getGlobalTypingsCacheLocation();
            const pathToTopLevelNodeModules = getCanonicalFileName(moduleSpecifier.substring(0, parts.topLevelNodeModulesIndex));
            if (!(startsWith(sourceDirectory, pathToTopLevelNodeModules) || globalTypingsCacheLocation && startsWith(getCanonicalFileName(globalTypingsCacheLocation), pathToTopLevelNodeModules))) {
                return void 0;
            }
            const nodeModulesDirectoryName = moduleSpecifier.substring(parts.topLevelPackageNameIndex + 1);
            const packageName = getPackageNameFromTypesPackageName(nodeModulesDirectoryName);
            return getEmitModuleResolutionKind(options) === 1 /* Classic */ && packageName === nodeModulesDirectoryName ? void 0 : packageName;
            function tryDirectoryWithPackageJson(packageRootIndex) {
                var _a2, _b;
                const packageRootPath = path.substring(0, packageRootIndex);
                const packageJsonPath = combinePaths(packageRootPath, "package.json");
                let moduleFileToTry = path;
                let maybeBlockedByTypesVersions = false;
                const cachedPackageJson = (_b = (_a2 = host.getPackageJsonInfoCache) == null ? void 0 : _a2.call(host)) == null ? void 0 : _b.getPackageJsonInfo(packageJsonPath);
                if (typeof cachedPackageJson === "object" || cachedPackageJson === void 0 && host.fileExists(packageJsonPath)) {
                    const packageJsonContent = (cachedPackageJson == null ? void 0 : cachedPackageJson.contents.packageJsonContent) || JSON.parse(host.readFile(packageJsonPath));
                    const importMode = overrideMode || importingSourceFile.impliedNodeFormat;
                    if (getResolvePackageJsonExports(options)) {
                        const nodeModulesDirectoryName2 = packageRootPath.substring(parts.topLevelPackageNameIndex + 1);
                        const packageName2 = getPackageNameFromTypesPackageName(nodeModulesDirectoryName2);
                        const conditions = getConditions(options, importMode === 99 /* ESNext */);
                        const fromExports = packageJsonContent.exports ? tryGetModuleNameFromExports(options, path, packageRootPath, packageName2, packageJsonContent.exports, conditions) : void 0;
                        if (fromExports) {
                            const withJsExtension = !hasTSFileExtension(fromExports.moduleFileToTry) ? fromExports : { moduleFileToTry: removeFileExtension(fromExports.moduleFileToTry) + tryGetJSExtensionForFile(fromExports.moduleFileToTry, options) };
                            return { ...withJsExtension, verbatimFromExports: true };
                        }
                        if (packageJsonContent.exports) {
                            return { moduleFileToTry: path, blockedByExports: true };
                        }
                    }
                    const versionPaths = packageJsonContent.typesVersions ? getPackageJsonTypesVersionsPaths(packageJsonContent.typesVersions) : void 0;
                    if (versionPaths) {
                        const subModuleName = path.slice(packageRootPath.length + 1);
                        const fromPaths = tryGetModuleNameFromPaths(subModuleName, versionPaths.paths, allowedEndings, host, options);
                        if (fromPaths === void 0) {
                            maybeBlockedByTypesVersions = true;
                        }
                        else {
                            moduleFileToTry = combinePaths(packageRootPath, fromPaths);
                        }
                    }
                    const mainFileRelative = packageJsonContent.typings || packageJsonContent.types || packageJsonContent.main || "index.js";
                    if (isString(mainFileRelative) && !(maybeBlockedByTypesVersions && matchPatternOrExact(tryParsePatterns(versionPaths.paths), mainFileRelative))) {
                        const mainExportFile = toPath(mainFileRelative, packageRootPath, getCanonicalFileName);
                        if (removeFileExtension(mainExportFile) === removeFileExtension(getCanonicalFileName(moduleFileToTry))) {
                            return { packageRootPath, moduleFileToTry };
                        }
                    }
                }
                else {
                    const fileName = getCanonicalFileName(moduleFileToTry.substring(parts.packageRootIndex + 1));
                    if (fileName === "index.d.ts" || fileName === "index.js" || fileName === "index.ts" || fileName === "index.tsx") {
                        return { moduleFileToTry, packageRootPath };
                    }
                }
                return { moduleFileToTry };
            }
        }
        function tryGetAnyFileFromPath(host, path) {
            if (!host.fileExists)
                return;
            const extensions = flatten(getSupportedExtensions({ allowJs: true }, [{ extension: "node", isMixedContent: false }, { extension: "json", isMixedContent: false, scriptKind: 6 /* JSON */ }]));
            for (const e of extensions) {
                const fullPath = path + e;
                if (host.fileExists(fullPath)) {
                    return fullPath;
                }
            }
        }
        function getPathsRelativeToRootDirs(path, rootDirs, getCanonicalFileName) {
            return mapDefined(rootDirs, (rootDir) => {
                const relativePath = getRelativePathIfInDirectory(path, rootDir, getCanonicalFileName);
                return relativePath !== void 0 && isPathRelativeToParent(relativePath) ? void 0 : relativePath;
            });
        }
        function processEnding(fileName, allowedEndings, options, host) {
            if (fileExtensionIsOneOf(fileName, [".json" /* Json */, ".mjs" /* Mjs */, ".cjs" /* Cjs */])) {
                return fileName;
            }
            const noExtension = removeFileExtension(fileName);
            if (fileName === noExtension) {
                return fileName;
            }
            if (fileExtensionIsOneOf(fileName, [".d.mts" /* Dmts */, ".mts" /* Mts */, ".d.cts" /* Dcts */, ".cts" /* Cts */])) {
                return noExtension + getJSExtensionForFile(fileName, options);
            }
            else if (!fileExtensionIsOneOf(fileName, [".d.ts" /* Dts */]) && fileExtensionIsOneOf(fileName, [".ts" /* Ts */]) && stringContains(fileName, ".d.")) {
                return tryGetRealFileNameForNonJsDeclarationFileName(fileName);
            }
            switch (allowedEndings[0]) {
                case 0 /* Minimal */:
                    const withoutIndex = removeSuffix(noExtension, "/index");
                    if (host && withoutIndex !== noExtension && tryGetAnyFileFromPath(host, withoutIndex)) {
                        return noExtension;
                    }
                    return withoutIndex;
                case 1 /* Index */:
                    return noExtension;
                case 2 /* JsExtension */:
                    return noExtension + getJSExtensionForFile(fileName, options);
                case 3 /* TsExtension */:
                    if (isDeclarationFileName(fileName)) {
                        const extensionlessPriority = allowedEndings.findIndex((e) => e === 0 /* Minimal */ || e === 1 /* Index */);
                        const jsPriority = allowedEndings.indexOf(2 /* JsExtension */);
                        return extensionlessPriority !== -1 && extensionlessPriority < jsPriority ? noExtension : noExtension + getJSExtensionForFile(fileName, options);
                    }
                    return fileName;
                default:
                    return Debug.assertNever(allowedEndings[0]);
            }
        }
        function tryGetRealFileNameForNonJsDeclarationFileName(fileName) {
            const baseName = getBaseFileName(fileName);
            if (!endsWith(fileName, ".ts" /* Ts */) || !stringContains(baseName, ".d.") || fileExtensionIsOneOf(baseName, [".d.ts" /* Dts */]))
                return void 0;
            const noExtension = removeExtension(fileName, ".ts" /* Ts */);
            const ext = noExtension.substring(noExtension.lastIndexOf("."));
            return noExtension.substring(0, noExtension.indexOf(".d.")) + ext;
        }
        function getJSExtensionForFile(fileName, options) {
            var _a2;
            return (_a2 = tryGetJSExtensionForFile(fileName, options)) != null ? _a2 : Debug.fail(`Extension ${extensionFromPath(fileName)} is unsupported:: FileName:: ${fileName}`);
        }
        function tryGetJSExtensionForFile(fileName, options) {
            const ext = tryGetExtensionFromPath2(fileName);
            switch (ext) {
                case ".ts" /* Ts */:
                case ".d.ts" /* Dts */:
                    return ".js" /* Js */;
                case ".tsx" /* Tsx */:
                    return options.jsx === 1 /* Preserve */ ? ".jsx" /* Jsx */ : ".js" /* Js */;
                case ".js" /* Js */:
                case ".jsx" /* Jsx */:
                case ".json" /* Json */:
                    return ext;
                case ".d.mts" /* Dmts */:
                case ".mts" /* Mts */:
                case ".mjs" /* Mjs */:
                    return ".mjs" /* Mjs */;
                case ".d.cts" /* Dcts */:
                case ".cts" /* Cts */:
                case ".cjs" /* Cjs */:
                    return ".cjs" /* Cjs */;
                default:
                    return void 0;
            }
        }
        function getRelativePathIfInDirectory(path, directoryPath, getCanonicalFileName) {
            const relativePath = getRelativePathToDirectoryOrUrl(directoryPath, path, directoryPath, getCanonicalFileName, 
            /*isAbsolutePathAnUrl*/
            false);
            return isRootedDiskPath(relativePath) ? void 0 : relativePath;
        }
        function isPathRelativeToParent(path) {
            return startsWith(path, "..");
        }
        var init_moduleSpecifiers = __esm({
            "src/compiler/moduleSpecifiers.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/_namespaces/ts.moduleSpecifiers.ts
        var ts_moduleSpecifiers_exports = {};
        __export(ts_moduleSpecifiers_exports, {
            countPathComponents: () => countPathComponents,
            forEachFileNameOfModule: () => forEachFileNameOfModule,
            getModuleSpecifier: () => getModuleSpecifier,
            getModuleSpecifiers: () => getModuleSpecifiers,
            getModuleSpecifiersWithCacheInfo: () => getModuleSpecifiersWithCacheInfo,
            getNodeModulesPackageName: () => getNodeModulesPackageName,
            tryGetJSExtensionForFile: () => tryGetJSExtensionForFile,
            tryGetModuleSpecifiersFromCache: () => tryGetModuleSpecifiersFromCache,
            tryGetRealFileNameForNonJsDeclarationFileName: () => tryGetRealFileNameForNonJsDeclarationFileName,
            updateModuleSpecifier: () => updateModuleSpecifier
        });
        var init_ts_moduleSpecifiers = __esm({
            "src/compiler/_namespaces/ts.moduleSpecifiers.ts"() {
                "use strict";
                init_moduleSpecifiers();
            }
        });
        // src/compiler/checker.ts
        function NodeLinks() {
            this.flags = 0 /* None */;
        }
        function getNodeId(node) {
            if (!node.id) {
                node.id = nextNodeId;
                nextNodeId++;
            }
            return node.id;
        }
        function getSymbolId(symbol) {
            if (!symbol.id) {
                symbol.id = nextSymbolId;
                nextSymbolId++;
            }
            return symbol.id;
        }
        function isInstantiatedModule(node, preserveConstEnums) {
            const moduleState = getModuleInstanceState(node);
            return moduleState === 1 /* Instantiated */ || preserveConstEnums && moduleState === 2 /* ConstEnumOnly */;
        }
        function createTypeChecker(host) {
            var getPackagesMap = memoize(() => {
                var map2 = /* @__PURE__ */ new Map();
                host.getSourceFiles().forEach((sf) => {
                    if (!sf.resolvedModules)
                        return;
                    sf.resolvedModules.forEach(({ resolvedModule }) => {
                        if (resolvedModule == null ? void 0 : resolvedModule.packageId)
                            map2.set(resolvedModule.packageId.name, resolvedModule.extension === ".d.ts" /* Dts */ || !!map2.get(resolvedModule.packageId.name));
                    });
                });
                return map2;
            });
            var deferredDiagnosticsCallbacks = [];
            var addLazyDiagnostic = (arg) => {
                deferredDiagnosticsCallbacks.push(arg);
            };
            var cancellationToken;
            var requestedExternalEmitHelperNames = /* @__PURE__ */ new Set();
            var requestedExternalEmitHelpers;
            var externalHelpersModule;
            var Symbol46 = objectAllocator.getSymbolConstructor();
            var Type27 = objectAllocator.getTypeConstructor();
            var Signature15 = objectAllocator.getSignatureConstructor();
            var typeCount = 0;
            var symbolCount = 0;
            var totalInstantiationCount = 0;
            var instantiationCount = 0;
            var instantiationDepth = 0;
            var inlineLevel = 0;
            var currentNode;
            var varianceTypeParameter;
            var isInferencePartiallyBlocked = false;
            var emptySymbols = createSymbolTable();
            var arrayVariances = [1 /* Covariant */];
            var compilerOptions = host.getCompilerOptions();
            var languageVersion = getEmitScriptTarget(compilerOptions);
            var moduleKind = getEmitModuleKind(compilerOptions);
            var legacyDecorators = !!compilerOptions.experimentalDecorators;
            var useDefineForClassFields = getUseDefineForClassFields(compilerOptions);
            var allowSyntheticDefaultImports = getAllowSyntheticDefaultImports(compilerOptions);
            var strictNullChecks = getStrictOptionValue(compilerOptions, "strictNullChecks");
            var strictFunctionTypes = getStrictOptionValue(compilerOptions, "strictFunctionTypes");
            var strictBindCallApply = getStrictOptionValue(compilerOptions, "strictBindCallApply");
            var strictPropertyInitialization = getStrictOptionValue(compilerOptions, "strictPropertyInitialization");
            var noImplicitAny = getStrictOptionValue(compilerOptions, "noImplicitAny");
            var noImplicitThis = getStrictOptionValue(compilerOptions, "noImplicitThis");
            var useUnknownInCatchVariables = getStrictOptionValue(compilerOptions, "useUnknownInCatchVariables");
            var keyofStringsOnly = !!compilerOptions.keyofStringsOnly;
            var freshObjectLiteralFlag = compilerOptions.suppressExcessPropertyErrors ? 0 : 8192 /* FreshLiteral */;
            var exactOptionalPropertyTypes = compilerOptions.exactOptionalPropertyTypes;
            var checkBinaryExpression = createCheckBinaryExpression();
            var emitResolver = createResolver();
            var nodeBuilder = createNodeBuilder();
            var globals = createSymbolTable();
            var undefinedSymbol = createSymbol(4 /* Property */, "undefined");
            undefinedSymbol.declarations = [];
            var globalThisSymbol = createSymbol(1536 /* Module */, "globalThis", 8 /* Readonly */);
            globalThisSymbol.exports = globals;
            globalThisSymbol.declarations = [];
            globals.set(globalThisSymbol.escapedName, globalThisSymbol);
            var argumentsSymbol = createSymbol(4 /* Property */, "arguments");
            var requireSymbol = createSymbol(4 /* Property */, "require");
            var isolatedModulesLikeFlagName = compilerOptions.verbatimModuleSyntax ? "verbatimModuleSyntax" : "isolatedModules";
            var apparentArgumentCount;
            const checker = {
                getNodeCount: () => reduceLeft(host.getSourceFiles(), (n, s) => n + s.nodeCount, 0),
                getIdentifierCount: () => reduceLeft(host.getSourceFiles(), (n, s) => n + s.identifierCount, 0),
                getSymbolCount: () => reduceLeft(host.getSourceFiles(), (n, s) => n + s.symbolCount, symbolCount),
                getTypeCount: () => typeCount,
                getInstantiationCount: () => totalInstantiationCount,
                getRelationCacheSizes: () => ({
                    assignable: assignableRelation.size,
                    identity: identityRelation.size,
                    subtype: subtypeRelation.size,
                    strictSubtype: strictSubtypeRelation.size
                }),
                isUndefinedSymbol: (symbol) => symbol === undefinedSymbol,
                isArgumentsSymbol: (symbol) => symbol === argumentsSymbol,
                isUnknownSymbol: (symbol) => symbol === unknownSymbol,
                getMergedSymbol,
                getDiagnostics: getDiagnostics2,
                getGlobalDiagnostics,
                getRecursionIdentity,
                getUnmatchedProperties,
                getTypeOfSymbolAtLocation: (symbol, locationIn) => {
                    const location = getParseTreeNode(locationIn);
                    return location ? getTypeOfSymbolAtLocation(symbol, location) : errorType;
                },
                getTypeOfSymbol,
                getSymbolsOfParameterPropertyDeclaration: (parameterIn, parameterName) => {
                    const parameter = getParseTreeNode(parameterIn, isParameter);
                    if (parameter === void 0)
                        return Debug.fail("Cannot get symbols of a synthetic parameter that cannot be resolved to a parse-tree node.");
                    Debug.assert(isParameterPropertyDeclaration(parameter, parameter.parent));
                    return getSymbolsOfParameterPropertyDeclaration(parameter, escapeLeadingUnderscores(parameterName));
                },
                getDeclaredTypeOfSymbol,
                getPropertiesOfType,
                getPropertyOfType: (type, name) => getPropertyOfType(type, escapeLeadingUnderscores(name)),
                getPrivateIdentifierPropertyOfType: (leftType, name, location) => {
                    const node = getParseTreeNode(location);
                    if (!node) {
                        return void 0;
                    }
                    const propName = escapeLeadingUnderscores(name);
                    const lexicallyScopedIdentifier = lookupSymbolForPrivateIdentifierDeclaration(propName, node);
                    return lexicallyScopedIdentifier ? getPrivateIdentifierPropertyOfType(leftType, lexicallyScopedIdentifier) : void 0;
                },
                getTypeOfPropertyOfType: (type, name) => getTypeOfPropertyOfType(type, escapeLeadingUnderscores(name)),
                getIndexInfoOfType: (type, kind) => getIndexInfoOfType(type, kind === 0 /* String */ ? stringType : numberType),
                getIndexInfosOfType,
                getIndexInfosOfIndexSymbol,
                getSignaturesOfType,
                getIndexTypeOfType: (type, kind) => getIndexTypeOfType(type, kind === 0 /* String */ ? stringType : numberType),
                getIndexType: (type) => getIndexType(type),
                getBaseTypes,
                getBaseTypeOfLiteralType,
                getWidenedType,
                getTypeFromTypeNode: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isTypeNode);
                    return node ? getTypeFromTypeNode(node) : errorType;
                },
                getParameterType: getTypeAtPosition,
                getParameterIdentifierNameAtPosition,
                getPromisedTypeOfPromise,
                getAwaitedType: (type) => getAwaitedType(type),
                getReturnTypeOfSignature,
                isNullableType,
                getNullableType,
                getNonNullableType,
                getNonOptionalType: removeOptionalTypeMarker,
                getTypeArguments,
                typeToTypeNode: nodeBuilder.typeToTypeNode,
                indexInfoToIndexSignatureDeclaration: nodeBuilder.indexInfoToIndexSignatureDeclaration,
                signatureToSignatureDeclaration: nodeBuilder.signatureToSignatureDeclaration,
                symbolToEntityName: nodeBuilder.symbolToEntityName,
                symbolToExpression: nodeBuilder.symbolToExpression,
                symbolToNode: nodeBuilder.symbolToNode,
                symbolToTypeParameterDeclarations: nodeBuilder.symbolToTypeParameterDeclarations,
                symbolToParameterDeclaration: nodeBuilder.symbolToParameterDeclaration,
                typeParameterToDeclaration: nodeBuilder.typeParameterToDeclaration,
                getSymbolsInScope: (locationIn, meaning) => {
                    const location = getParseTreeNode(locationIn);
                    return location ? getSymbolsInScope(location, meaning) : [];
                },
                getSymbolAtLocation: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn);
                    return node ? getSymbolAtLocation(node, 
                    /*ignoreErrors*/
                    true) : void 0;
                },
                getIndexInfosAtLocation: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn);
                    return node ? getIndexInfosAtLocation(node) : void 0;
                },
                getShorthandAssignmentValueSymbol: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn);
                    return node ? getShorthandAssignmentValueSymbol(node) : void 0;
                },
                getExportSpecifierLocalTargetSymbol: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isExportSpecifier);
                    return node ? getExportSpecifierLocalTargetSymbol(node) : void 0;
                },
                getExportSymbolOfSymbol(symbol) {
                    return getMergedSymbol(symbol.exportSymbol || symbol);
                },
                getTypeAtLocation: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn);
                    return node ? getTypeOfNode(node) : errorType;
                },
                getTypeOfAssignmentPattern: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isAssignmentPattern);
                    return node && getTypeOfAssignmentPattern(node) || errorType;
                },
                getPropertySymbolOfDestructuringAssignment: (locationIn) => {
                    const location = getParseTreeNode(locationIn, isIdentifier);
                    return location ? getPropertySymbolOfDestructuringAssignment(location) : void 0;
                },
                signatureToString: (signature, enclosingDeclaration, flags, kind) => {
                    return signatureToString(signature, getParseTreeNode(enclosingDeclaration), flags, kind);
                },
                typeToString: (type, enclosingDeclaration, flags) => {
                    return typeToString(type, getParseTreeNode(enclosingDeclaration), flags);
                },
                symbolToString: (symbol, enclosingDeclaration, meaning, flags) => {
                    return symbolToString(symbol, getParseTreeNode(enclosingDeclaration), meaning, flags);
                },
                typePredicateToString: (predicate, enclosingDeclaration, flags) => {
                    return typePredicateToString(predicate, getParseTreeNode(enclosingDeclaration), flags);
                },
                writeSignature: (signature, enclosingDeclaration, flags, kind, writer) => {
                    return signatureToString(signature, getParseTreeNode(enclosingDeclaration), flags, kind, writer);
                },
                writeType: (type, enclosingDeclaration, flags, writer) => {
                    return typeToString(type, getParseTreeNode(enclosingDeclaration), flags, writer);
                },
                writeSymbol: (symbol, enclosingDeclaration, meaning, flags, writer) => {
                    return symbolToString(symbol, getParseTreeNode(enclosingDeclaration), meaning, flags, writer);
                },
                writeTypePredicate: (predicate, enclosingDeclaration, flags, writer) => {
                    return typePredicateToString(predicate, getParseTreeNode(enclosingDeclaration), flags, writer);
                },
                getAugmentedPropertiesOfType,
                getRootSymbols,
                getSymbolOfExpando,
                getContextualType: (nodeIn, contextFlags) => {
                    const node = getParseTreeNode(nodeIn, isExpression);
                    if (!node) {
                        return void 0;
                    }
                    if (contextFlags & 4 /* Completions */) {
                        return runWithInferenceBlockedFromSourceNode(node, () => getContextualType2(node, contextFlags));
                    }
                    return getContextualType2(node, contextFlags);
                },
                getContextualTypeForObjectLiteralElement: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isObjectLiteralElementLike);
                    return node ? getContextualTypeForObjectLiteralElement(node, 
                    /*contextFlags*/
                    void 0) : void 0;
                },
                getContextualTypeForArgumentAtIndex: (nodeIn, argIndex) => {
                    const node = getParseTreeNode(nodeIn, isCallLikeExpression);
                    return node && getContextualTypeForArgumentAtIndex(node, argIndex);
                },
                getContextualTypeForJsxAttribute: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isJsxAttributeLike);
                    return node && getContextualTypeForJsxAttribute(node, 
                    /*contextFlags*/
                    void 0);
                },
                isContextSensitive,
                getTypeOfPropertyOfContextualType,
                getFullyQualifiedName,
                getResolvedSignature: (node, candidatesOutArray, argumentCount) => getResolvedSignatureWorker(node, candidatesOutArray, argumentCount, 0 /* Normal */),
                getResolvedSignatureForStringLiteralCompletions: (call, editingArgument, candidatesOutArray) => runWithInferenceBlockedFromSourceNode(editingArgument, () => getResolvedSignatureWorker(call, candidatesOutArray, 
                /*argumentCount*/
                void 0, 32 /* IsForStringLiteralArgumentCompletions */)),
                getResolvedSignatureForSignatureHelp: (node, candidatesOutArray, argumentCount) => runWithoutResolvedSignatureCaching(node, () => getResolvedSignatureWorker(node, candidatesOutArray, argumentCount, 16 /* IsForSignatureHelp */)),
                getExpandedParameters,
                hasEffectiveRestParameter,
                containsArgumentsReference,
                getConstantValue: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, canHaveConstantValue);
                    return node ? getConstantValue2(node) : void 0;
                },
                isValidPropertyAccess: (nodeIn, propertyName) => {
                    const node = getParseTreeNode(nodeIn, isPropertyAccessOrQualifiedNameOrImportTypeNode);
                    return !!node && isValidPropertyAccess(node, escapeLeadingUnderscores(propertyName));
                },
                isValidPropertyAccessForCompletions: (nodeIn, type, property) => {
                    const node = getParseTreeNode(nodeIn, isPropertyAccessExpression);
                    return !!node && isValidPropertyAccessForCompletions(node, type, property);
                },
                getSignatureFromDeclaration: (declarationIn) => {
                    const declaration = getParseTreeNode(declarationIn, isFunctionLike);
                    return declaration ? getSignatureFromDeclaration(declaration) : void 0;
                },
                isImplementationOfOverload: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isFunctionLike);
                    return node ? isImplementationOfOverload(node) : void 0;
                },
                getImmediateAliasedSymbol,
                getAliasedSymbol: resolveAlias,
                getEmitResolver,
                getExportsOfModule: getExportsOfModuleAsArray,
                getExportsAndPropertiesOfModule,
                forEachExportAndPropertyOfModule,
                getSymbolWalker: createGetSymbolWalker(getRestTypeOfSignature, getTypePredicateOfSignature, getReturnTypeOfSignature, getBaseTypes, resolveStructuredTypeMembers, getTypeOfSymbol, getResolvedSymbol, getConstraintOfTypeParameter, getFirstIdentifier, getTypeArguments),
                getAmbientModules,
                getJsxIntrinsicTagNamesAt,
                isOptionalParameter: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isParameter);
                    return node ? isOptionalParameter(node) : false;
                },
                tryGetMemberInModuleExports: (name, symbol) => tryGetMemberInModuleExports(escapeLeadingUnderscores(name), symbol),
                tryGetMemberInModuleExportsAndProperties: (name, symbol) => tryGetMemberInModuleExportsAndProperties(escapeLeadingUnderscores(name), symbol),
                tryFindAmbientModule: (moduleName) => tryFindAmbientModule(moduleName, 
                /*withAugmentations*/
                true),
                tryFindAmbientModuleWithoutAugmentations: (moduleName) => {
                    return tryFindAmbientModule(moduleName, 
                    /*withAugmentations*/
                    false);
                },
                getApparentType,
                getUnionType,
                isTypeAssignableTo,
                createAnonymousType,
                createSignature,
                createSymbol,
                createIndexInfo,
                getAnyType: () => anyType,
                getStringType: () => stringType,
                getNumberType: () => numberType,
                createPromiseType,
                createArrayType,
                getElementTypeOfArrayType,
                getBooleanType: () => booleanType,
                getFalseType: (fresh) => fresh ? falseType : regularFalseType,
                getTrueType: (fresh) => fresh ? trueType : regularTrueType,
                getVoidType: () => voidType,
                getUndefinedType: () => undefinedType,
                getNullType: () => nullType,
                getESSymbolType: () => esSymbolType,
                getNeverType: () => neverType,
                getOptionalType: () => optionalType,
                getPromiseType: () => getGlobalPromiseType(
                /*reportErrors*/
                false),
                getPromiseLikeType: () => getGlobalPromiseLikeType(
                /*reportErrors*/
                false),
                getAsyncIterableType: () => {
                    const type = getGlobalAsyncIterableType(
                    /*reportErrors*/
                    false);
                    if (type === emptyGenericType)
                        return void 0;
                    return type;
                },
                isSymbolAccessible,
                isArrayType,
                isTupleType,
                isArrayLikeType,
                isEmptyAnonymousObjectType,
                isTypeInvalidDueToUnionDiscriminant,
                getExactOptionalProperties,
                getAllPossiblePropertiesOfTypes,
                getSuggestedSymbolForNonexistentProperty,
                getSuggestionForNonexistentProperty,
                getSuggestedSymbolForNonexistentJSXAttribute,
                getSuggestedSymbolForNonexistentSymbol: (location, name, meaning) => getSuggestedSymbolForNonexistentSymbol(location, escapeLeadingUnderscores(name), meaning),
                getSuggestionForNonexistentSymbol: (location, name, meaning) => getSuggestionForNonexistentSymbol(location, escapeLeadingUnderscores(name), meaning),
                getSuggestedSymbolForNonexistentModule,
                getSuggestionForNonexistentExport,
                getSuggestedSymbolForNonexistentClassMember,
                getBaseConstraintOfType,
                getDefaultFromTypeParameter: (type) => type && type.flags & 262144 /* TypeParameter */ ? getDefaultFromTypeParameter(type) : void 0,
                resolveName(name, location, meaning, excludeGlobals) {
                    return resolveName(location, escapeLeadingUnderscores(name), meaning, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false, excludeGlobals);
                },
                getJsxNamespace: (n) => unescapeLeadingUnderscores(getJsxNamespace(n)),
                getJsxFragmentFactory: (n) => {
                    const jsxFragmentFactory = getJsxFragmentFactoryEntity(n);
                    return jsxFragmentFactory && unescapeLeadingUnderscores(getFirstIdentifier(jsxFragmentFactory).escapedText);
                },
                getAccessibleSymbolChain,
                getTypePredicateOfSignature,
                resolveExternalModuleName: (moduleSpecifierIn) => {
                    const moduleSpecifier = getParseTreeNode(moduleSpecifierIn, isExpression);
                    return moduleSpecifier && resolveExternalModuleName(moduleSpecifier, moduleSpecifier, 
                    /*ignoreErrors*/
                    true);
                },
                resolveExternalModuleSymbol,
                tryGetThisTypeAt: (nodeIn, includeGlobalThis, container) => {
                    const node = getParseTreeNode(nodeIn);
                    return node && tryGetThisTypeAt(node, includeGlobalThis, container);
                },
                getTypeArgumentConstraint: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isTypeNode);
                    return node && getTypeArgumentConstraint(node);
                },
                getSuggestionDiagnostics: (fileIn, ct) => {
                    const file = getParseTreeNode(fileIn, isSourceFile) || Debug.fail("Could not determine parsed source file.");
                    if (skipTypeChecking(file, compilerOptions, host)) {
                        return emptyArray;
                    }
                    let diagnostics2;
                    try {
                        cancellationToken = ct;
                        checkSourceFileWithEagerDiagnostics(file);
                        Debug.assert(!!(getNodeLinks(file).flags & 1 /* TypeChecked */));
                        diagnostics2 = addRange(diagnostics2, suggestionDiagnostics.getDiagnostics(file.fileName));
                        checkUnusedIdentifiers(getPotentiallyUnusedIdentifiers(file), (containingNode, kind, diag2) => {
                            if (!containsParseError(containingNode) && !unusedIsError(kind, !!(containingNode.flags & 16777216 /* Ambient */))) {
                                (diagnostics2 || (diagnostics2 = [])).push({ ...diag2, category: 2 /* Suggestion */ });
                            }
                        });
                        return diagnostics2 || emptyArray;
                    }
                    finally {
                        cancellationToken = void 0;
                    }
                },
                runWithCancellationToken: (token, callback) => {
                    try {
                        cancellationToken = token;
                        return callback(checker);
                    }
                    finally {
                        cancellationToken = void 0;
                    }
                },
                getLocalTypeParametersOfClassOrInterfaceOrTypeAlias,
                isDeclarationVisible,
                isPropertyAccessible,
                getTypeOnlyAliasDeclaration,
                getMemberOverrideModifierStatus,
                isTypeParameterPossiblyReferenced,
                typeHasCallOrConstructSignatures
            };
            function runWithoutResolvedSignatureCaching(node, fn) {
                const containingCall = findAncestor(node, isCallLikeExpression);
                const containingCallResolvedSignature = containingCall && getNodeLinks(containingCall).resolvedSignature;
                if (containingCall) {
                    getNodeLinks(containingCall).resolvedSignature = void 0;
                }
                const result = fn();
                if (containingCall) {
                    getNodeLinks(containingCall).resolvedSignature = containingCallResolvedSignature;
                }
                return result;
            }
            function runWithInferenceBlockedFromSourceNode(node, fn) {
                const containingCall = findAncestor(node, isCallLikeExpression);
                if (containingCall) {
                    let toMarkSkip = node;
                    do {
                        getNodeLinks(toMarkSkip).skipDirectInference = true;
                        toMarkSkip = toMarkSkip.parent;
                    } while (toMarkSkip && toMarkSkip !== containingCall);
                }
                isInferencePartiallyBlocked = true;
                const result = runWithoutResolvedSignatureCaching(node, fn);
                isInferencePartiallyBlocked = false;
                if (containingCall) {
                    let toMarkSkip = node;
                    do {
                        getNodeLinks(toMarkSkip).skipDirectInference = void 0;
                        toMarkSkip = toMarkSkip.parent;
                    } while (toMarkSkip && toMarkSkip !== containingCall);
                }
                return result;
            }
            function getResolvedSignatureWorker(nodeIn, candidatesOutArray, argumentCount, checkMode) {
                const node = getParseTreeNode(nodeIn, isCallLikeExpression);
                apparentArgumentCount = argumentCount;
                const res = !node ? void 0 : getResolvedSignature(node, candidatesOutArray, checkMode);
                apparentArgumentCount = void 0;
                return res;
            }
            var tupleTypes = /* @__PURE__ */ new Map();
            var unionTypes = /* @__PURE__ */ new Map();
            var intersectionTypes = /* @__PURE__ */ new Map();
            var stringLiteralTypes = /* @__PURE__ */ new Map();
            var numberLiteralTypes = /* @__PURE__ */ new Map();
            var bigIntLiteralTypes = /* @__PURE__ */ new Map();
            var enumLiteralTypes = /* @__PURE__ */ new Map();
            var indexedAccessTypes = /* @__PURE__ */ new Map();
            var templateLiteralTypes = /* @__PURE__ */ new Map();
            var stringMappingTypes = /* @__PURE__ */ new Map();
            var substitutionTypes = /* @__PURE__ */ new Map();
            var subtypeReductionCache = /* @__PURE__ */ new Map();
            var decoratorContextOverrideTypeCache = /* @__PURE__ */ new Map();
            var cachedTypes = /* @__PURE__ */ new Map();
            var evolvingArrayTypes = [];
            var undefinedProperties = /* @__PURE__ */ new Map();
            var markerTypes = /* @__PURE__ */ new Set();
            var unknownSymbol = createSymbol(4 /* Property */, "unknown");
            var resolvingSymbol = createSymbol(0, "__resolving__" /* Resolving */);
            var unresolvedSymbols = /* @__PURE__ */ new Map();
            var errorTypes = /* @__PURE__ */ new Map();
            var anyType = createIntrinsicType(1 /* Any */, "any");
            var autoType = createIntrinsicType(1 /* Any */, "any", 262144 /* NonInferrableType */);
            var wildcardType = createIntrinsicType(1 /* Any */, "any");
            var errorType = createIntrinsicType(1 /* Any */, "error");
            var unresolvedType = createIntrinsicType(1 /* Any */, "unresolved");
            var nonInferrableAnyType = createIntrinsicType(1 /* Any */, "any", 65536 /* ContainsWideningType */);
            var intrinsicMarkerType = createIntrinsicType(1 /* Any */, "intrinsic");
            var unknownType = createIntrinsicType(2 /* Unknown */, "unknown");
            var nonNullUnknownType = createIntrinsicType(2 /* Unknown */, "unknown");
            var undefinedType = createIntrinsicType(32768 /* Undefined */, "undefined");
            var undefinedWideningType = strictNullChecks ? undefinedType : createIntrinsicType(32768 /* Undefined */, "undefined", 65536 /* ContainsWideningType */);
            var missingType = createIntrinsicType(32768 /* Undefined */, "undefined");
            var undefinedOrMissingType = exactOptionalPropertyTypes ? missingType : undefinedType;
            var optionalType = createIntrinsicType(32768 /* Undefined */, "undefined");
            var nullType = createIntrinsicType(65536 /* Null */, "null");
            var nullWideningType = strictNullChecks ? nullType : createIntrinsicType(65536 /* Null */, "null", 65536 /* ContainsWideningType */);
            var stringType = createIntrinsicType(4 /* String */, "string");
            var numberType = createIntrinsicType(8 /* Number */, "number");
            var bigintType = createIntrinsicType(64 /* BigInt */, "bigint");
            var falseType = createIntrinsicType(512 /* BooleanLiteral */, "false");
            var regularFalseType = createIntrinsicType(512 /* BooleanLiteral */, "false");
            var trueType = createIntrinsicType(512 /* BooleanLiteral */, "true");
            var regularTrueType = createIntrinsicType(512 /* BooleanLiteral */, "true");
            trueType.regularType = regularTrueType;
            trueType.freshType = trueType;
            regularTrueType.regularType = regularTrueType;
            regularTrueType.freshType = trueType;
            falseType.regularType = regularFalseType;
            falseType.freshType = falseType;
            regularFalseType.regularType = regularFalseType;
            regularFalseType.freshType = falseType;
            var booleanType = getUnionType([regularFalseType, regularTrueType]);
            var esSymbolType = createIntrinsicType(4096 /* ESSymbol */, "symbol");
            var voidType = createIntrinsicType(16384 /* Void */, "void");
            var neverType = createIntrinsicType(131072 /* Never */, "never");
            var silentNeverType = createIntrinsicType(131072 /* Never */, "never", 262144 /* NonInferrableType */);
            var implicitNeverType = createIntrinsicType(131072 /* Never */, "never");
            var unreachableNeverType = createIntrinsicType(131072 /* Never */, "never");
            var nonPrimitiveType = createIntrinsicType(67108864 /* NonPrimitive */, "object");
            var stringOrNumberType = getUnionType([stringType, numberType]);
            var stringNumberSymbolType = getUnionType([stringType, numberType, esSymbolType]);
            var keyofConstraintType = keyofStringsOnly ? stringType : stringNumberSymbolType;
            var numberOrBigIntType = getUnionType([numberType, bigintType]);
            var templateConstraintType = getUnionType([stringType, numberType, booleanType, bigintType, nullType, undefinedType]);
            var numericStringType = getTemplateLiteralType(["", ""], [numberType]);
            var restrictiveMapper = makeFunctionTypeMapper((t) => t.flags & 262144 /* TypeParameter */ ? getRestrictiveTypeParameter(t) : t, () => "(restrictive mapper)");
            var permissiveMapper = makeFunctionTypeMapper((t) => t.flags & 262144 /* TypeParameter */ ? wildcardType : t, () => "(permissive mapper)");
            var uniqueLiteralType = createIntrinsicType(131072 /* Never */, "never");
            var uniqueLiteralMapper = makeFunctionTypeMapper((t) => t.flags & 262144 /* TypeParameter */ ? uniqueLiteralType : t, () => "(unique literal mapper)");
            var outofbandVarianceMarkerHandler;
            var reportUnreliableMapper = makeFunctionTypeMapper((t) => {
                if (outofbandVarianceMarkerHandler && (t === markerSuperType || t === markerSubType || t === markerOtherType)) {
                    outofbandVarianceMarkerHandler(
                    /*onlyUnreliable*/
                    true);
                }
                return t;
            }, () => "(unmeasurable reporter)");
            var reportUnmeasurableMapper = makeFunctionTypeMapper((t) => {
                if (outofbandVarianceMarkerHandler && (t === markerSuperType || t === markerSubType || t === markerOtherType)) {
                    outofbandVarianceMarkerHandler(
                    /*onlyUnreliable*/
                    false);
                }
                return t;
            }, () => "(unreliable reporter)");
            var emptyObjectType = createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var emptyJsxObjectType = createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            emptyJsxObjectType.objectFlags |= 2048 /* JsxAttributes */;
            var emptyTypeLiteralSymbol = createSymbol(2048 /* TypeLiteral */, "__type" /* Type */);
            emptyTypeLiteralSymbol.members = createSymbolTable();
            var emptyTypeLiteralType = createAnonymousType(emptyTypeLiteralSymbol, emptySymbols, emptyArray, emptyArray, emptyArray);
            var unknownEmptyObjectType = createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var unknownUnionType = strictNullChecks ? getUnionType([undefinedType, nullType, unknownEmptyObjectType]) : unknownType;
            var emptyGenericType = createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            emptyGenericType.instantiations = /* @__PURE__ */ new Map();
            var anyFunctionType = createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            anyFunctionType.objectFlags |= 262144 /* NonInferrableType */;
            var noConstraintType = createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var circularConstraintType = createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var resolvingDefaultType = createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var markerSuperType = createTypeParameter();
            var markerSubType = createTypeParameter();
            markerSubType.constraint = markerSuperType;
            var markerOtherType = createTypeParameter();
            var markerSuperTypeForCheck = createTypeParameter();
            var markerSubTypeForCheck = createTypeParameter();
            markerSubTypeForCheck.constraint = markerSuperTypeForCheck;
            var noTypePredicate = createTypePredicate(1 /* Identifier */, "<<unresolved>>", 0, anyType);
            var anySignature = createSignature(void 0, void 0, void 0, emptyArray, anyType, 
            /*resolvedTypePredicate*/
            void 0, 0, 0 /* None */);
            var unknownSignature = createSignature(void 0, void 0, void 0, emptyArray, errorType, 
            /*resolvedTypePredicate*/
            void 0, 0, 0 /* None */);
            var resolvingSignature = createSignature(void 0, void 0, void 0, emptyArray, anyType, 
            /*resolvedTypePredicate*/
            void 0, 0, 0 /* None */);
            var silentNeverSignature = createSignature(void 0, void 0, void 0, emptyArray, silentNeverType, 
            /*resolvedTypePredicate*/
            void 0, 0, 0 /* None */);
            var enumNumberIndexInfo = createIndexInfo(numberType, stringType, 
            /*isReadonly*/
            true);
            var iterationTypesCache = /* @__PURE__ */ new Map();
            var noIterationTypes = {
                get yieldType() {
                    return Debug.fail("Not supported");
                },
                get returnType() {
                    return Debug.fail("Not supported");
                },
                get nextType() {
                    return Debug.fail("Not supported");
                }
            };
            var anyIterationTypes = createIterationTypes(anyType, anyType, anyType);
            var anyIterationTypesExceptNext = createIterationTypes(anyType, anyType, unknownType);
            var defaultIterationTypes = createIterationTypes(neverType, anyType, undefinedType);
            var asyncIterationTypesResolver = {
                iterableCacheKey: "iterationTypesOfAsyncIterable",
                iteratorCacheKey: "iterationTypesOfAsyncIterator",
                iteratorSymbolName: "asyncIterator",
                getGlobalIteratorType: getGlobalAsyncIteratorType,
                getGlobalIterableType: getGlobalAsyncIterableType,
                getGlobalIterableIteratorType: getGlobalAsyncIterableIteratorType,
                getGlobalGeneratorType: getGlobalAsyncGeneratorType,
                resolveIterationType: getAwaitedType,
                mustHaveANextMethodDiagnostic: Diagnostics.An_async_iterator_must_have_a_next_method,
                mustBeAMethodDiagnostic: Diagnostics.The_0_property_of_an_async_iterator_must_be_a_method,
                mustHaveAValueDiagnostic: Diagnostics.The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_property
            };
            var syncIterationTypesResolver = {
                iterableCacheKey: "iterationTypesOfIterable",
                iteratorCacheKey: "iterationTypesOfIterator",
                iteratorSymbolName: "iterator",
                getGlobalIteratorType,
                getGlobalIterableType,
                getGlobalIterableIteratorType,
                getGlobalGeneratorType,
                resolveIterationType: (type, _errorNode) => type,
                mustHaveANextMethodDiagnostic: Diagnostics.An_iterator_must_have_a_next_method,
                mustBeAMethodDiagnostic: Diagnostics.The_0_property_of_an_iterator_must_be_a_method,
                mustHaveAValueDiagnostic: Diagnostics.The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property
            };
            var amalgamatedDuplicates;
            var reverseMappedCache = /* @__PURE__ */ new Map();
            var inInferTypeForHomomorphicMappedType = false;
            var ambientModulesCache;
            var patternAmbientModules;
            var patternAmbientModuleAugmentations;
            var globalObjectType;
            var globalFunctionType;
            var globalCallableFunctionType;
            var globalNewableFunctionType;
            var globalArrayType;
            var globalReadonlyArrayType;
            var globalStringType;
            var globalNumberType;
            var globalBooleanType;
            var globalRegExpType;
            var globalThisType;
            var anyArrayType;
            var autoArrayType;
            var anyReadonlyArrayType;
            var deferredGlobalNonNullableTypeAlias;
            var deferredGlobalESSymbolConstructorSymbol;
            var deferredGlobalESSymbolConstructorTypeSymbol;
            var deferredGlobalESSymbolType;
            var deferredGlobalTypedPropertyDescriptorType;
            var deferredGlobalPromiseType;
            var deferredGlobalPromiseLikeType;
            var deferredGlobalPromiseConstructorSymbol;
            var deferredGlobalPromiseConstructorLikeType;
            var deferredGlobalIterableType;
            var deferredGlobalIteratorType;
            var deferredGlobalIterableIteratorType;
            var deferredGlobalGeneratorType;
            var deferredGlobalIteratorYieldResultType;
            var deferredGlobalIteratorReturnResultType;
            var deferredGlobalAsyncIterableType;
            var deferredGlobalAsyncIteratorType;
            var deferredGlobalAsyncIterableIteratorType;
            var deferredGlobalAsyncGeneratorType;
            var deferredGlobalTemplateStringsArrayType;
            var deferredGlobalImportMetaType;
            var deferredGlobalImportMetaExpressionType;
            var deferredGlobalImportCallOptionsType;
            var deferredGlobalExtractSymbol;
            var deferredGlobalOmitSymbol;
            var deferredGlobalAwaitedSymbol;
            var deferredGlobalBigIntType;
            var deferredGlobalNaNSymbol;
            var deferredGlobalRecordSymbol;
            var deferredGlobalClassDecoratorContextType;
            var deferredGlobalClassMethodDecoratorContextType;
            var deferredGlobalClassGetterDecoratorContextType;
            var deferredGlobalClassSetterDecoratorContextType;
            var deferredGlobalClassAccessorDecoratorContextType;
            var deferredGlobalClassAccessorDecoratorTargetType;
            var deferredGlobalClassAccessorDecoratorResultType;
            var deferredGlobalClassFieldDecoratorContextType;
            var allPotentiallyUnusedIdentifiers = /* @__PURE__ */ new Map();
            var flowLoopStart = 0;
            var flowLoopCount = 0;
            var sharedFlowCount = 0;
            var flowAnalysisDisabled = false;
            var flowInvocationCount = 0;
            var lastFlowNode;
            var lastFlowNodeReachable;
            var flowTypeCache;
            var contextualTypeNodes = [];
            var contextualTypes = [];
            var contextualIsCache = [];
            var contextualTypeCount = 0;
            var inferenceContextNodes = [];
            var inferenceContexts = [];
            var inferenceContextCount = 0;
            var emptyStringType = getStringLiteralType("");
            var zeroType = getNumberLiteralType(0);
            var zeroBigIntType = getBigIntLiteralType({ negative: false, base10Value: "0" });
            var resolutionTargets = [];
            var resolutionResults = [];
            var resolutionPropertyNames = [];
            var suggestionCount = 0;
            var maximumSuggestionCount = 10;
            var mergedSymbols = [];
            var symbolLinks = [];
            var nodeLinks = [];
            var flowLoopCaches = [];
            var flowLoopNodes = [];
            var flowLoopKeys = [];
            var flowLoopTypes = [];
            var sharedFlowNodes = [];
            var sharedFlowTypes = [];
            var flowNodeReachable = [];
            var flowNodePostSuper = [];
            var potentialThisCollisions = [];
            var potentialNewTargetCollisions = [];
            var potentialWeakMapSetCollisions = [];
            var potentialReflectCollisions = [];
            var potentialUnusedRenamedBindingElementsInTypes = [];
            var awaitedTypeStack = [];
            var diagnostics = createDiagnosticCollection();
            var suggestionDiagnostics = createDiagnosticCollection();
            var typeofType = createTypeofType();
            var _jsxNamespace;
            var _jsxFactoryEntity;
            var subtypeRelation = /* @__PURE__ */ new Map();
            var strictSubtypeRelation = /* @__PURE__ */ new Map();
            var assignableRelation = /* @__PURE__ */ new Map();
            var comparableRelation = /* @__PURE__ */ new Map();
            var identityRelation = /* @__PURE__ */ new Map();
            var enumRelation = /* @__PURE__ */ new Map();
            var builtinGlobals = createSymbolTable();
            builtinGlobals.set(undefinedSymbol.escapedName, undefinedSymbol);
            var suggestedExtensions = [
                [".mts", ".mjs"],
                [".ts", ".js"],
                [".cts", ".cjs"],
                [".mjs", ".mjs"],
                [".js", ".js"],
                [".cjs", ".cjs"],
                [".tsx", compilerOptions.jsx === 1 /* Preserve */ ? ".jsx" : ".js"],
                [".jsx", ".jsx"],
                [".json", ".json"]
            ];
            initializeTypeChecker();
            return checker;
            function getCachedType(key) {
                return key ? cachedTypes.get(key) : void 0;
            }
            function setCachedType(key, type) {
                if (key)
                    cachedTypes.set(key, type);
                return type;
            }
            function getJsxNamespace(location) {
                if (location) {
                    const file = getSourceFileOfNode(location);
                    if (file) {
                        if (isJsxOpeningFragment(location)) {
                            if (file.localJsxFragmentNamespace) {
                                return file.localJsxFragmentNamespace;
                            }
                            const jsxFragmentPragma = file.pragmas.get("jsxfrag");
                            if (jsxFragmentPragma) {
                                const chosenPragma = isArray(jsxFragmentPragma) ? jsxFragmentPragma[0] : jsxFragmentPragma;
                                file.localJsxFragmentFactory = parseIsolatedEntityName(chosenPragma.arguments.factory, languageVersion);
                                visitNode(file.localJsxFragmentFactory, markAsSynthetic, isEntityName);
                                if (file.localJsxFragmentFactory) {
                                    return file.localJsxFragmentNamespace = getFirstIdentifier(file.localJsxFragmentFactory).escapedText;
                                }
                            }
                            const entity = getJsxFragmentFactoryEntity(location);
                            if (entity) {
                                file.localJsxFragmentFactory = entity;
                                return file.localJsxFragmentNamespace = getFirstIdentifier(entity).escapedText;
                            }
                        }
                        else {
                            const localJsxNamespace = getLocalJsxNamespace(file);
                            if (localJsxNamespace) {
                                return file.localJsxNamespace = localJsxNamespace;
                            }
                        }
                    }
                }
                if (!_jsxNamespace) {
                    _jsxNamespace = "React";
                    if (compilerOptions.jsxFactory) {
                        _jsxFactoryEntity = parseIsolatedEntityName(compilerOptions.jsxFactory, languageVersion);
                        visitNode(_jsxFactoryEntity, markAsSynthetic);
                        if (_jsxFactoryEntity) {
                            _jsxNamespace = getFirstIdentifier(_jsxFactoryEntity).escapedText;
                        }
                    }
                    else if (compilerOptions.reactNamespace) {
                        _jsxNamespace = escapeLeadingUnderscores(compilerOptions.reactNamespace);
                    }
                }
                if (!_jsxFactoryEntity) {
                    _jsxFactoryEntity = factory.createQualifiedName(factory.createIdentifier(unescapeLeadingUnderscores(_jsxNamespace)), "createElement");
                }
                return _jsxNamespace;
            }
            function getLocalJsxNamespace(file) {
                if (file.localJsxNamespace) {
                    return file.localJsxNamespace;
                }
                const jsxPragma = file.pragmas.get("jsx");
                if (jsxPragma) {
                    const chosenPragma = isArray(jsxPragma) ? jsxPragma[0] : jsxPragma;
                    file.localJsxFactory = parseIsolatedEntityName(chosenPragma.arguments.factory, languageVersion);
                    visitNode(file.localJsxFactory, markAsSynthetic, isEntityName);
                    if (file.localJsxFactory) {
                        return file.localJsxNamespace = getFirstIdentifier(file.localJsxFactory).escapedText;
                    }
                }
            }
            function markAsSynthetic(node) {
                setTextRangePosEnd(node, -1, -1);
                return visitEachChild(node, markAsSynthetic, nullTransformationContext);
            }
            function getEmitResolver(sourceFile, cancellationToken2) {
                getDiagnostics2(sourceFile, cancellationToken2);
                return emitResolver;
            }
            function lookupOrIssueError(location, message, arg0, arg1, arg2, arg3) {
                const diagnostic = location ? createDiagnosticForNode(location, message, arg0, arg1, arg2, arg3) : createCompilerDiagnostic(message, arg0, arg1, arg2, arg3);
                const existing = diagnostics.lookup(diagnostic);
                if (existing) {
                    return existing;
                }
                else {
                    diagnostics.add(diagnostic);
                    return diagnostic;
                }
            }
            function errorSkippedOn(key, location, message, arg0, arg1, arg2, arg3) {
                const diagnostic = error(location, message, arg0, arg1, arg2, arg3);
                diagnostic.skippedOn = key;
                return diagnostic;
            }
            function createError(location, message, arg0, arg1, arg2, arg3) {
                return location ? createDiagnosticForNode(location, message, arg0, arg1, arg2, arg3) : createCompilerDiagnostic(message, arg0, arg1, arg2, arg3);
            }
            function error(location, message, arg0, arg1, arg2, arg3) {
                const diagnostic = createError(location, message, arg0, arg1, arg2, arg3);
                diagnostics.add(diagnostic);
                return diagnostic;
            }
            function addErrorOrSuggestion(isError, diagnostic) {
                if (isError) {
                    diagnostics.add(diagnostic);
                }
                else {
                    suggestionDiagnostics.add({ ...diagnostic, category: 2 /* Suggestion */ });
                }
            }
            function errorOrSuggestion(isError, location, message, arg0, arg1, arg2, arg3) {
                if (location.pos < 0 || location.end < 0) {
                    if (!isError) {
                        return;
                    }
                    const file = getSourceFileOfNode(location);
                    addErrorOrSuggestion(isError, "message" in message ? createFileDiagnostic(file, 0, 0, message, arg0, arg1, arg2, arg3) : createDiagnosticForFileFromMessageChain(file, message));
                    return;
                }
                addErrorOrSuggestion(isError, "message" in message ? createDiagnosticForNode(location, message, arg0, arg1, arg2, arg3) : createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(location), location, message));
            }
            function errorAndMaybeSuggestAwait(location, maybeMissingAwait, message, arg0, arg1, arg2, arg3) {
                const diagnostic = error(location, message, arg0, arg1, arg2, arg3);
                if (maybeMissingAwait) {
                    const related = createDiagnosticForNode(location, Diagnostics.Did_you_forget_to_use_await);
                    addRelatedInfo(diagnostic, related);
                }
                return diagnostic;
            }
            function addDeprecatedSuggestionWorker(declarations, diagnostic) {
                const deprecatedTag = Array.isArray(declarations) ? forEach(declarations, getJSDocDeprecatedTag) : getJSDocDeprecatedTag(declarations);
                if (deprecatedTag) {
                    addRelatedInfo(diagnostic, createDiagnosticForNode(deprecatedTag, Diagnostics.The_declaration_was_marked_as_deprecated_here));
                }
                suggestionDiagnostics.add(diagnostic);
                return diagnostic;
            }
            function isDeprecatedSymbol(symbol) {
                if (length(symbol.declarations) > 1) {
                    const parentSymbol = getParentOfSymbol(symbol);
                    if (parentSymbol && parentSymbol.flags & 64 /* Interface */) {
                        return some(symbol.declarations, (d) => !!(getCombinedNodeFlags(d) & 268435456 /* Deprecated */));
                    }
                }
                return !!(getDeclarationNodeFlagsFromSymbol(symbol) & 268435456 /* Deprecated */);
            }
            function addDeprecatedSuggestion(location, declarations, deprecatedEntity) {
                const diagnostic = createDiagnosticForNode(location, Diagnostics._0_is_deprecated, deprecatedEntity);
                return addDeprecatedSuggestionWorker(declarations, diagnostic);
            }
            function addDeprecatedSuggestionWithSignature(location, declaration, deprecatedEntity, signatureString) {
                const diagnostic = deprecatedEntity ? createDiagnosticForNode(location, Diagnostics.The_signature_0_of_1_is_deprecated, signatureString, deprecatedEntity) : createDiagnosticForNode(location, Diagnostics._0_is_deprecated, signatureString);
                return addDeprecatedSuggestionWorker(declaration, diagnostic);
            }
            function createSymbol(flags, name, checkFlags) {
                symbolCount++;
                const symbol = new Symbol46(flags | 33554432 /* Transient */, name);
                symbol.links = new SymbolLinks();
                symbol.links.checkFlags = checkFlags || 0 /* None */;
                return symbol;
            }
            function createParameter(name, type) {
                const symbol = createSymbol(1 /* FunctionScopedVariable */, name);
                symbol.links.type = type;
                return symbol;
            }
            function createProperty(name, type) {
                const symbol = createSymbol(4 /* Property */, name);
                symbol.links.type = type;
                return symbol;
            }
            function getExcludedSymbolFlags(flags) {
                let result = 0;
                if (flags & 2 /* BlockScopedVariable */)
                    result |= 111551 /* BlockScopedVariableExcludes */;
                if (flags & 1 /* FunctionScopedVariable */)
                    result |= 111550 /* FunctionScopedVariableExcludes */;
                if (flags & 4 /* Property */)
                    result |= 0 /* PropertyExcludes */;
                if (flags & 8 /* EnumMember */)
                    result |= 900095 /* EnumMemberExcludes */;
                if (flags & 16 /* Function */)
                    result |= 110991 /* FunctionExcludes */;
                if (flags & 32 /* Class */)
                    result |= 899503 /* ClassExcludes */;
                if (flags & 64 /* Interface */)
                    result |= 788872 /* InterfaceExcludes */;
                if (flags & 256 /* RegularEnum */)
                    result |= 899327 /* RegularEnumExcludes */;
                if (flags & 128 /* ConstEnum */)
                    result |= 899967 /* ConstEnumExcludes */;
                if (flags & 512 /* ValueModule */)
                    result |= 110735 /* ValueModuleExcludes */;
                if (flags & 8192 /* Method */)
                    result |= 103359 /* MethodExcludes */;
                if (flags & 32768 /* GetAccessor */)
                    result |= 46015 /* GetAccessorExcludes */;
                if (flags & 65536 /* SetAccessor */)
                    result |= 78783 /* SetAccessorExcludes */;
                if (flags & 262144 /* TypeParameter */)
                    result |= 526824 /* TypeParameterExcludes */;
                if (flags & 524288 /* TypeAlias */)
                    result |= 788968 /* TypeAliasExcludes */;
                if (flags & 2097152 /* Alias */)
                    result |= 2097152 /* AliasExcludes */;
                return result;
            }
            function recordMergedSymbol(target, source) {
                if (!source.mergeId) {
                    source.mergeId = nextMergeId;
                    nextMergeId++;
                }
                mergedSymbols[source.mergeId] = target;
            }
            function cloneSymbol(symbol) {
                const result = createSymbol(symbol.flags, symbol.escapedName);
                result.declarations = symbol.declarations ? symbol.declarations.slice() : [];
                result.parent = symbol.parent;
                if (symbol.valueDeclaration)
                    result.valueDeclaration = symbol.valueDeclaration;
                if (symbol.constEnumOnlyModule)
                    result.constEnumOnlyModule = true;
                if (symbol.members)
                    result.members = new Map(symbol.members);
                if (symbol.exports)
                    result.exports = new Map(symbol.exports);
                recordMergedSymbol(result, symbol);
                return result;
            }
            function mergeSymbol(target, source, unidirectional = false) {
                if (!(target.flags & getExcludedSymbolFlags(source.flags)) || (source.flags | target.flags) & 67108864 /* Assignment */) {
                    if (source === target) {
                        return target;
                    }
                    if (!(target.flags & 33554432 /* Transient */)) {
                        const resolvedTarget = resolveSymbol(target);
                        if (resolvedTarget === unknownSymbol) {
                            return source;
                        }
                        target = cloneSymbol(resolvedTarget);
                    }
                    if (source.flags & 512 /* ValueModule */ && target.flags & 512 /* ValueModule */ && target.constEnumOnlyModule && !source.constEnumOnlyModule) {
                        target.constEnumOnlyModule = false;
                    }
                    target.flags |= source.flags;
                    if (source.valueDeclaration) {
                        setValueDeclaration(target, source.valueDeclaration);
                    }
                    addRange(target.declarations, source.declarations);
                    if (source.members) {
                        if (!target.members)
                            target.members = createSymbolTable();
                        mergeSymbolTable(target.members, source.members, unidirectional);
                    }
                    if (source.exports) {
                        if (!target.exports)
                            target.exports = createSymbolTable();
                        mergeSymbolTable(target.exports, source.exports, unidirectional);
                    }
                    if (!unidirectional) {
                        recordMergedSymbol(target, source);
                    }
                }
                else if (target.flags & 1024 /* NamespaceModule */) {
                    if (target !== globalThisSymbol) {
                        error(source.declarations && getNameOfDeclaration(source.declarations[0]), Diagnostics.Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity, symbolToString(target));
                    }
                }
                else {
                    const isEitherEnum = !!(target.flags & 384 /* Enum */ || source.flags & 384 /* Enum */);
                    const isEitherBlockScoped = !!(target.flags & 2 /* BlockScopedVariable */ || source.flags & 2 /* BlockScopedVariable */);
                    const message = isEitherEnum ? Diagnostics.Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations : isEitherBlockScoped ? Diagnostics.Cannot_redeclare_block_scoped_variable_0 : Diagnostics.Duplicate_identifier_0;
                    const sourceSymbolFile = source.declarations && getSourceFileOfNode(source.declarations[0]);
                    const targetSymbolFile = target.declarations && getSourceFileOfNode(target.declarations[0]);
                    const isSourcePlainJs = isPlainJsFile(sourceSymbolFile, compilerOptions.checkJs);
                    const isTargetPlainJs = isPlainJsFile(targetSymbolFile, compilerOptions.checkJs);
                    const symbolName2 = symbolToString(source);
                    if (sourceSymbolFile && targetSymbolFile && amalgamatedDuplicates && !isEitherEnum && sourceSymbolFile !== targetSymbolFile) {
                        const firstFile = comparePaths(sourceSymbolFile.path, targetSymbolFile.path) === -1 /* LessThan */ ? sourceSymbolFile : targetSymbolFile;
                        const secondFile = firstFile === sourceSymbolFile ? targetSymbolFile : sourceSymbolFile;
                        const filesDuplicates = getOrUpdate(amalgamatedDuplicates, `${firstFile.path}|${secondFile.path}`, () => ({ firstFile, secondFile, conflictingSymbols: /* @__PURE__ */ new Map() }));
                        const conflictingSymbolInfo = getOrUpdate(filesDuplicates.conflictingSymbols, symbolName2, () => ({ isBlockScoped: isEitherBlockScoped, firstFileLocations: [], secondFileLocations: [] }));
                        if (!isSourcePlainJs)
                            addDuplicateLocations(conflictingSymbolInfo.firstFileLocations, source);
                        if (!isTargetPlainJs)
                            addDuplicateLocations(conflictingSymbolInfo.secondFileLocations, target);
                    }
                    else {
                        if (!isSourcePlainJs)
                            addDuplicateDeclarationErrorsForSymbols(source, message, symbolName2, target);
                        if (!isTargetPlainJs)
                            addDuplicateDeclarationErrorsForSymbols(target, message, symbolName2, source);
                    }
                }
                return target;
                function addDuplicateLocations(locs, symbol) {
                    if (symbol.declarations) {
                        for (const decl of symbol.declarations) {
                            pushIfUnique(locs, decl);
                        }
                    }
                }
            }
            function addDuplicateDeclarationErrorsForSymbols(target, message, symbolName2, source) {
                forEach(target.declarations, (node) => {
                    addDuplicateDeclarationError(node, message, symbolName2, source.declarations);
                });
            }
            function addDuplicateDeclarationError(node, message, symbolName2, relatedNodes) {
                const errorNode = (getExpandoInitializer(node, 
                /*isPrototypeAssignment*/
                false) ? getNameOfExpando(node) : getNameOfDeclaration(node)) || node;
                const err = lookupOrIssueError(errorNode, message, symbolName2);
                for (const relatedNode of relatedNodes || emptyArray) {
                    const adjustedNode = (getExpandoInitializer(relatedNode, 
                    /*isPrototypeAssignment*/
                    false) ? getNameOfExpando(relatedNode) : getNameOfDeclaration(relatedNode)) || relatedNode;
                    if (adjustedNode === errorNode)
                        continue;
                    err.relatedInformation = err.relatedInformation || [];
                    const leadingMessage = createDiagnosticForNode(adjustedNode, Diagnostics._0_was_also_declared_here, symbolName2);
                    const followOnMessage = createDiagnosticForNode(adjustedNode, Diagnostics.and_here);
                    if (length(err.relatedInformation) >= 5 || some(err.relatedInformation, (r) => compareDiagnostics(r, followOnMessage) === 0 /* EqualTo */ || compareDiagnostics(r, leadingMessage) === 0 /* EqualTo */))
                        continue;
                    addRelatedInfo(err, !length(err.relatedInformation) ? leadingMessage : followOnMessage);
                }
            }
            function combineSymbolTables(first2, second) {
                if (!(first2 == null ? void 0 : first2.size))
                    return second;
                if (!(second == null ? void 0 : second.size))
                    return first2;
                const combined = createSymbolTable();
                mergeSymbolTable(combined, first2);
                mergeSymbolTable(combined, second);
                return combined;
            }
            function mergeSymbolTable(target, source, unidirectional = false) {
                source.forEach((sourceSymbol, id) => {
                    const targetSymbol = target.get(id);
                    target.set(id, targetSymbol ? mergeSymbol(targetSymbol, sourceSymbol, unidirectional) : getMergedSymbol(sourceSymbol));
                });
            }
            function mergeModuleAugmentation(moduleName) {
                var _a2, _b, _c;
                const moduleAugmentation = moduleName.parent;
                if (((_a2 = moduleAugmentation.symbol.declarations) == null ? void 0 : _a2[0]) !== moduleAugmentation) {
                    Debug.assert(moduleAugmentation.symbol.declarations.length > 1);
                    return;
                }
                if (isGlobalScopeAugmentation(moduleAugmentation)) {
                    mergeSymbolTable(globals, moduleAugmentation.symbol.exports);
                }
                else {
                    const moduleNotFoundError = !(moduleName.parent.parent.flags & 16777216 /* Ambient */) ? Diagnostics.Invalid_module_name_in_augmentation_module_0_cannot_be_found : void 0;
                    let mainModule = resolveExternalModuleNameWorker(moduleName, moduleName, moduleNotFoundError, 
                    /*isForAugmentation*/
                    true);
                    if (!mainModule) {
                        return;
                    }
                    mainModule = resolveExternalModuleSymbol(mainModule);
                    if (mainModule.flags & 1920 /* Namespace */) {
                        if (some(patternAmbientModules, (module2) => mainModule === module2.symbol)) {
                            const merged = mergeSymbol(moduleAugmentation.symbol, mainModule, 
                            /*unidirectional*/
                            true);
                            if (!patternAmbientModuleAugmentations) {
                                patternAmbientModuleAugmentations = /* @__PURE__ */ new Map();
                            }
                            patternAmbientModuleAugmentations.set(moduleName.text, merged);
                        }
                        else {
                            if (((_b = mainModule.exports) == null ? void 0 : _b.get("__export" /* ExportStar */)) && ((_c = moduleAugmentation.symbol.exports) == null ? void 0 : _c.size)) {
                                const resolvedExports = getResolvedMembersOrExportsOfSymbol(mainModule, "resolvedExports" /* resolvedExports */);
                                for (const [key, value] of arrayFrom(moduleAugmentation.symbol.exports.entries())) {
                                    if (resolvedExports.has(key) && !mainModule.exports.has(key)) {
                                        mergeSymbol(resolvedExports.get(key), value);
                                    }
                                }
                            }
                            mergeSymbol(mainModule, moduleAugmentation.symbol);
                        }
                    }
                    else {
                        error(moduleName, Diagnostics.Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity, moduleName.text);
                    }
                }
            }
            function addToSymbolTable(target, source, message) {
                source.forEach((sourceSymbol, id) => {
                    const targetSymbol = target.get(id);
                    if (targetSymbol) {
                        forEach(targetSymbol.declarations, addDeclarationDiagnostic(unescapeLeadingUnderscores(id), message));
                    }
                    else {
                        target.set(id, sourceSymbol);
                    }
                });
                function addDeclarationDiagnostic(id, message2) {
                    return (declaration) => diagnostics.add(createDiagnosticForNode(declaration, message2, id));
                }
            }
            function getSymbolLinks(symbol) {
                var _a2;
                if (symbol.flags & 33554432 /* Transient */)
                    return symbol.links;
                const id = getSymbolId(symbol);
                return (_a2 = symbolLinks[id]) != null ? _a2 : symbolLinks[id] = new SymbolLinks();
            }
            function getNodeLinks(node) {
                const nodeId = getNodeId(node);
                return nodeLinks[nodeId] || (nodeLinks[nodeId] = new NodeLinks());
            }
            function isGlobalSourceFile(node) {
                return node.kind === 308 /* SourceFile */ && !isExternalOrCommonJsModule(node);
            }
            function getSymbol2(symbols, name, meaning) {
                if (meaning) {
                    const symbol = getMergedSymbol(symbols.get(name));
                    if (symbol) {
                        Debug.assert((getCheckFlags(symbol) & 1 /* Instantiated */) === 0, "Should never get an instantiated symbol here.");
                        if (symbol.flags & meaning) {
                            return symbol;
                        }
                        if (symbol.flags & 2097152 /* Alias */) {
                            const targetFlags = getAllSymbolFlags(symbol);
                            if (targetFlags & meaning) {
                                return symbol;
                            }
                        }
                    }
                }
            }
            function getSymbolsOfParameterPropertyDeclaration(parameter, parameterName) {
                const constructorDeclaration = parameter.parent;
                const classDeclaration = parameter.parent.parent;
                const parameterSymbol = getSymbol2(constructorDeclaration.locals, parameterName, 111551 /* Value */);
                const propertySymbol = getSymbol2(getMembersOfSymbol(classDeclaration.symbol), parameterName, 111551 /* Value */);
                if (parameterSymbol && propertySymbol) {
                    return [parameterSymbol, propertySymbol];
                }
                return Debug.fail("There should exist two symbols, one as property declaration and one as parameter declaration");
            }
            function isBlockScopedNameDeclaredBeforeUse(declaration, usage) {
                const declarationFile = getSourceFileOfNode(declaration);
                const useFile = getSourceFileOfNode(usage);
                const declContainer = getEnclosingBlockScopeContainer(declaration);
                if (declarationFile !== useFile) {
                    if (moduleKind && (declarationFile.externalModuleIndicator || useFile.externalModuleIndicator) || !outFile(compilerOptions) || isInTypeQuery(usage) || declaration.flags & 16777216 /* Ambient */) {
                        return true;
                    }
                    if (isUsedInFunctionOrInstanceProperty(usage, declaration)) {
                        return true;
                    }
                    const sourceFiles = host.getSourceFiles();
                    return sourceFiles.indexOf(declarationFile) <= sourceFiles.indexOf(useFile);
                }
                if (declaration.pos <= usage.pos && !(isPropertyDeclaration(declaration) && isThisProperty(usage.parent) && !declaration.initializer && !declaration.exclamationToken)) {
                    if (declaration.kind === 205 /* BindingElement */) {
                        const errorBindingElement = getAncestor(usage, 205 /* BindingElement */);
                        if (errorBindingElement) {
                            return findAncestor(errorBindingElement, isBindingElement) !== findAncestor(declaration, isBindingElement) || declaration.pos < errorBindingElement.pos;
                        }
                        return isBlockScopedNameDeclaredBeforeUse(getAncestor(declaration, 257 /* VariableDeclaration */), usage);
                    }
                    else if (declaration.kind === 257 /* VariableDeclaration */) {
                        return !isImmediatelyUsedInInitializerOfBlockScopedVariable(declaration, usage);
                    }
                    else if (isClassDeclaration(declaration)) {
                        return !findAncestor(usage, (n) => isComputedPropertyName(n) && n.parent.parent === declaration);
                    }
                    else if (isPropertyDeclaration(declaration)) {
                        return !isPropertyImmediatelyReferencedWithinDeclaration(declaration, usage, 
                        /*stopAtAnyPropertyDeclaration*/
                        false);
                    }
                    else if (isParameterPropertyDeclaration(declaration, declaration.parent)) {
                        return !(getEmitScriptTarget(compilerOptions) === 99 /* ESNext */ && useDefineForClassFields && getContainingClass(declaration) === getContainingClass(usage) && isUsedInFunctionOrInstanceProperty(usage, declaration));
                    }
                    return true;
                }
                if (usage.parent.kind === 278 /* ExportSpecifier */ || usage.parent.kind === 274 /* ExportAssignment */ && usage.parent.isExportEquals) {
                    return true;
                }
                if (usage.kind === 274 /* ExportAssignment */ && usage.isExportEquals) {
                    return true;
                }
                if (!!(usage.flags & 8388608 /* JSDoc */) || isInTypeQuery(usage) || isInAmbientOrTypeNode(usage)) {
                    return true;
                }
                if (isUsedInFunctionOrInstanceProperty(usage, declaration)) {
                    if (getEmitScriptTarget(compilerOptions) === 99 /* ESNext */ && useDefineForClassFields && getContainingClass(declaration) && (isPropertyDeclaration(declaration) || isParameterPropertyDeclaration(declaration, declaration.parent))) {
                        return !isPropertyImmediatelyReferencedWithinDeclaration(declaration, usage, 
                        /*stopAtAnyPropertyDeclaration*/
                        true);
                    }
                    else {
                        return true;
                    }
                }
                return false;
                function isImmediatelyUsedInInitializerOfBlockScopedVariable(declaration2, usage2) {
                    switch (declaration2.parent.parent.kind) {
                        case 240 /* VariableStatement */:
                        case 245 /* ForStatement */:
                        case 247 /* ForOfStatement */:
                            if (isSameScopeDescendentOf(usage2, declaration2, declContainer)) {
                                return true;
                            }
                            break;
                    }
                    const grandparent = declaration2.parent.parent;
                    return isForInOrOfStatement(grandparent) && isSameScopeDescendentOf(usage2, grandparent.expression, declContainer);
                }
                function isUsedInFunctionOrInstanceProperty(usage2, declaration2) {
                    return !!findAncestor(usage2, (current) => {
                        if (current === declContainer) {
                            return "quit";
                        }
                        if (isFunctionLike(current)) {
                            return true;
                        }
                        if (isClassStaticBlockDeclaration(current)) {
                            return declaration2.pos < usage2.pos;
                        }
                        const propertyDeclaration = tryCast(current.parent, isPropertyDeclaration);
                        if (propertyDeclaration) {
                            const initializerOfProperty = propertyDeclaration.initializer === current;
                            if (initializerOfProperty) {
                                if (isStatic(current.parent)) {
                                    if (declaration2.kind === 171 /* MethodDeclaration */) {
                                        return true;
                                    }
                                    if (isPropertyDeclaration(declaration2) && getContainingClass(usage2) === getContainingClass(declaration2)) {
                                        const propName = declaration2.name;
                                        if (isIdentifier(propName) || isPrivateIdentifier(propName)) {
                                            const type = getTypeOfSymbol(getSymbolOfDeclaration(declaration2));
                                            const staticBlocks = filter(declaration2.parent.members, isClassStaticBlockDeclaration);
                                            if (isPropertyInitializedInStaticBlocks(propName, type, staticBlocks, declaration2.parent.pos, current.pos)) {
                                                return true;
                                            }
                                        }
                                    }
                                }
                                else {
                                    const isDeclarationInstanceProperty = declaration2.kind === 169 /* PropertyDeclaration */ && !isStatic(declaration2);
                                    if (!isDeclarationInstanceProperty || getContainingClass(usage2) !== getContainingClass(declaration2)) {
                                        return true;
                                    }
                                }
                            }
                        }
                        return false;
                    });
                }
                function isPropertyImmediatelyReferencedWithinDeclaration(declaration2, usage2, stopAtAnyPropertyDeclaration) {
                    if (usage2.end > declaration2.end) {
                        return false;
                    }
                    const ancestorChangingReferenceScope = findAncestor(usage2, (node) => {
                        if (node === declaration2) {
                            return "quit";
                        }
                        switch (node.kind) {
                            case 216 /* ArrowFunction */:
                                return true;
                            case 169 /* PropertyDeclaration */:
                                return stopAtAnyPropertyDeclaration && (isPropertyDeclaration(declaration2) && node.parent === declaration2.parent || isParameterPropertyDeclaration(declaration2, declaration2.parent) && node.parent === declaration2.parent.parent) ? "quit" : true;
                            case 238 /* Block */:
                                switch (node.parent.kind) {
                                    case 174 /* GetAccessor */:
                                    case 171 /* MethodDeclaration */:
                                    case 175 /* SetAccessor */:
                                        return true;
                                    default:
                                        return false;
                                }
                            default:
                                return false;
                        }
                    });
                    return ancestorChangingReferenceScope === void 0;
                }
            }
            function useOuterVariableScopeInParameter(result, location, lastLocation) {
                const target = getEmitScriptTarget(compilerOptions);
                const functionLocation = location;
                if (isParameter(lastLocation) && functionLocation.body && result.valueDeclaration && result.valueDeclaration.pos >= functionLocation.body.pos && result.valueDeclaration.end <= functionLocation.body.end) {
                    if (target >= 2 /* ES2015 */) {
                        const links = getNodeLinks(functionLocation);
                        if (links.declarationRequiresScopeChange === void 0) {
                            links.declarationRequiresScopeChange = forEach(functionLocation.parameters, requiresScopeChange) || false;
                        }
                        return !links.declarationRequiresScopeChange;
                    }
                }
                return false;
                function requiresScopeChange(node) {
                    return requiresScopeChangeWorker(node.name) || !!node.initializer && requiresScopeChangeWorker(node.initializer);
                }
                function requiresScopeChangeWorker(node) {
                    switch (node.kind) {
                        case 216 /* ArrowFunction */:
                        case 215 /* FunctionExpression */:
                        case 259 /* FunctionDeclaration */:
                        case 173 /* Constructor */:
                            return false;
                        case 171 /* MethodDeclaration */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                        case 299 /* PropertyAssignment */:
                            return requiresScopeChangeWorker(node.name);
                        case 169 /* PropertyDeclaration */:
                            if (hasStaticModifier(node)) {
                                return target < 99 /* ESNext */ || !useDefineForClassFields;
                            }
                            return requiresScopeChangeWorker(node.name);
                        default:
                            if (isNullishCoalesce(node) || isOptionalChain(node)) {
                                return target < 7 /* ES2020 */;
                            }
                            if (isBindingElement(node) && node.dotDotDotToken && isObjectBindingPattern(node.parent)) {
                                return target < 4 /* ES2017 */;
                            }
                            if (isTypeNode(node))
                                return false;
                            return forEachChild(node, requiresScopeChangeWorker) || false;
                    }
                }
            }
            function isConstAssertion(location) {
                return isAssertionExpression(location) && isConstTypeReference(location.type) || isJSDocTypeTag(location) && isConstTypeReference(location.typeExpression);
            }
            function resolveName(location, name, meaning, nameNotFoundMessage, nameArg, isUse, excludeGlobals = false, getSpellingSuggestions = true) {
                return resolveNameHelper(location, name, meaning, nameNotFoundMessage, nameArg, isUse, excludeGlobals, getSpellingSuggestions, getSymbol2);
            }
            function resolveNameHelper(location, name, meaning, nameNotFoundMessage, nameArg, isUse, excludeGlobals, getSpellingSuggestions, lookup) {
                var _a2, _b, _c;
                const originalLocation = location;
                let result;
                let lastLocation;
                let lastSelfReferenceLocation;
                let propertyWithInvalidInitializer;
                let associatedDeclarationForContainingInitializerOrBindingName;
                let withinDeferredContext = false;
                const errorLocation = location;
                let grandparent;
                let isInExternalModule = false;
                loop: while (location) {
                    if (name === "const" && isConstAssertion(location)) {
                        return void 0;
                    }
                    if (canHaveLocals(location) && location.locals && !isGlobalSourceFile(location)) {
                        if (result = lookup(location.locals, name, meaning)) {
                            let useResult = true;
                            if (isFunctionLike(location) && lastLocation && lastLocation !== location.body) {
                                if (meaning & result.flags & 788968 /* Type */ && lastLocation.kind !== 323 /* JSDoc */) {
                                    useResult = result.flags & 262144 /* TypeParameter */ ? lastLocation === location.type || lastLocation.kind === 166 /* Parameter */ || lastLocation.kind === 344 /* JSDocParameterTag */ || lastLocation.kind === 345 /* JSDocReturnTag */ || lastLocation.kind === 165 /* TypeParameter */ : false;
                                }
                                if (meaning & result.flags & 3 /* Variable */) {
                                    if (useOuterVariableScopeInParameter(result, location, lastLocation)) {
                                        useResult = false;
                                    }
                                    else if (result.flags & 1 /* FunctionScopedVariable */) {
                                        useResult = lastLocation.kind === 166 /* Parameter */ || lastLocation === location.type && !!findAncestor(result.valueDeclaration, isParameter);
                                    }
                                }
                            }
                            else if (location.kind === 191 /* ConditionalType */) {
                                useResult = lastLocation === location.trueType;
                            }
                            if (useResult) {
                                break loop;
                            }
                            else {
                                result = void 0;
                            }
                        }
                    }
                    withinDeferredContext = withinDeferredContext || getIsDeferredContext(location, lastLocation);
                    switch (location.kind) {
                        case 308 /* SourceFile */:
                            if (!isExternalOrCommonJsModule(location))
                                break;
                            isInExternalModule = true;
                        case 264 /* ModuleDeclaration */:
                            const moduleExports = ((_a2 = getSymbolOfDeclaration(location)) == null ? void 0 : _a2.exports) || emptySymbols;
                            if (location.kind === 308 /* SourceFile */ || isModuleDeclaration(location) && location.flags & 16777216 /* Ambient */ && !isGlobalScopeAugmentation(location)) {
                                if (result = moduleExports.get("default" /* Default */)) {
                                    const localSymbol = getLocalSymbolForExportDefault(result);
                                    if (localSymbol && result.flags & meaning && localSymbol.escapedName === name) {
                                        break loop;
                                    }
                                    result = void 0;
                                }
                                const moduleExport = moduleExports.get(name);
                                if (moduleExport && moduleExport.flags === 2097152 /* Alias */ && (getDeclarationOfKind(moduleExport, 278 /* ExportSpecifier */) || getDeclarationOfKind(moduleExport, 277 /* NamespaceExport */))) {
                                    break;
                                }
                            }
                            if (name !== "default" /* Default */ && (result = lookup(moduleExports, name, meaning & 2623475 /* ModuleMember */))) {
                                if (isSourceFile(location) && location.commonJsModuleIndicator && !((_b = result.declarations) == null ? void 0 : _b.some(isJSDocTypeAlias))) {
                                    result = void 0;
                                }
                                else {
                                    break loop;
                                }
                            }
                            break;
                        case 263 /* EnumDeclaration */:
                            if (result = lookup(((_c = getSymbolOfDeclaration(location)) == null ? void 0 : _c.exports) || emptySymbols, name, meaning & 8 /* EnumMember */)) {
                                if (nameNotFoundMessage && getIsolatedModules(compilerOptions) && !(location.flags & 16777216 /* Ambient */) && getSourceFileOfNode(location) !== getSourceFileOfNode(result.valueDeclaration)) {
                                    error(errorLocation, Diagnostics.Cannot_access_0_from_another_file_without_qualification_when_1_is_enabled_Use_2_instead, unescapeLeadingUnderscores(name), isolatedModulesLikeFlagName, `${unescapeLeadingUnderscores(getSymbolOfNode(location).escapedName)}.${unescapeLeadingUnderscores(name)}`);
                                }
                                break loop;
                            }
                            break;
                        case 169 /* PropertyDeclaration */:
                            if (!isStatic(location)) {
                                const ctor = findConstructorDeclaration(location.parent);
                                if (ctor && ctor.locals) {
                                    if (lookup(ctor.locals, name, meaning & 111551 /* Value */)) {
                                        Debug.assertNode(location, isPropertyDeclaration);
                                        propertyWithInvalidInitializer = location;
                                    }
                                }
                            }
                            break;
                        case 260 /* ClassDeclaration */:
                        case 228 /* ClassExpression */:
                        case 261 /* InterfaceDeclaration */:
                            if (result = lookup(getSymbolOfDeclaration(location).members || emptySymbols, name, meaning & 788968 /* Type */)) {
                                if (!isTypeParameterSymbolDeclaredInContainer(result, location)) {
                                    result = void 0;
                                    break;
                                }
                                if (lastLocation && isStatic(lastLocation)) {
                                    if (nameNotFoundMessage) {
                                        error(errorLocation, Diagnostics.Static_members_cannot_reference_class_type_parameters);
                                    }
                                    return void 0;
                                }
                                break loop;
                            }
                            if (isClassExpression(location) && meaning & 32 /* Class */) {
                                const className = location.name;
                                if (className && name === className.escapedText) {
                                    result = location.symbol;
                                    break loop;
                                }
                            }
                            break;
                        case 230 /* ExpressionWithTypeArguments */:
                            if (lastLocation === location.expression && location.parent.token === 94 /* ExtendsKeyword */) {
                                const container = location.parent.parent;
                                if (isClassLike(container) && (result = lookup(getSymbolOfDeclaration(container).members, name, meaning & 788968 /* Type */))) {
                                    if (nameNotFoundMessage) {
                                        error(errorLocation, Diagnostics.Base_class_expressions_cannot_reference_class_type_parameters);
                                    }
                                    return void 0;
                                }
                            }
                            break;
                        case 164 /* ComputedPropertyName */:
                            grandparent = location.parent.parent;
                            if (isClassLike(grandparent) || grandparent.kind === 261 /* InterfaceDeclaration */) {
                                if (result = lookup(getSymbolOfDeclaration(grandparent).members, name, meaning & 788968 /* Type */)) {
                                    if (nameNotFoundMessage) {
                                        error(errorLocation, Diagnostics.A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type);
                                    }
                                    return void 0;
                                }
                            }
                            break;
                        case 216 /* ArrowFunction */:
                            if (getEmitScriptTarget(compilerOptions) >= 2 /* ES2015 */) {
                                break;
                            }
                        case 171 /* MethodDeclaration */:
                        case 173 /* Constructor */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                        case 259 /* FunctionDeclaration */:
                            if (meaning & 3 /* Variable */ && name === "arguments") {
                                result = argumentsSymbol;
                                break loop;
                            }
                            break;
                        case 215 /* FunctionExpression */:
                            if (meaning & 3 /* Variable */ && name === "arguments") {
                                result = argumentsSymbol;
                                break loop;
                            }
                            if (meaning & 16 /* Function */) {
                                const functionName = location.name;
                                if (functionName && name === functionName.escapedText) {
                                    result = location.symbol;
                                    break loop;
                                }
                            }
                            break;
                        case 167 /* Decorator */:
                            if (location.parent && location.parent.kind === 166 /* Parameter */) {
                                location = location.parent;
                            }
                            if (location.parent && (isClassElement(location.parent) || location.parent.kind === 260 /* ClassDeclaration */)) {
                                location = location.parent;
                            }
                            break;
                        case 349 /* JSDocTypedefTag */:
                        case 341 /* JSDocCallbackTag */:
                        case 343 /* JSDocEnumTag */:
                            const root = getJSDocRoot(location);
                            if (root) {
                                location = root.parent;
                            }
                            break;
                        case 166 /* Parameter */:
                            if (lastLocation && (lastLocation === location.initializer || lastLocation === location.name && isBindingPattern(lastLocation))) {
                                if (!associatedDeclarationForContainingInitializerOrBindingName) {
                                    associatedDeclarationForContainingInitializerOrBindingName = location;
                                }
                            }
                            break;
                        case 205 /* BindingElement */:
                            if (lastLocation && (lastLocation === location.initializer || lastLocation === location.name && isBindingPattern(lastLocation))) {
                                if (isParameterDeclaration(location) && !associatedDeclarationForContainingInitializerOrBindingName) {
                                    associatedDeclarationForContainingInitializerOrBindingName = location;
                                }
                            }
                            break;
                        case 192 /* InferType */:
                            if (meaning & 262144 /* TypeParameter */) {
                                const parameterName = location.typeParameter.name;
                                if (parameterName && name === parameterName.escapedText) {
                                    result = location.typeParameter.symbol;
                                    break loop;
                                }
                            }
                            break;
                    }
                    if (isSelfReferenceLocation(location)) {
                        lastSelfReferenceLocation = location;
                    }
                    lastLocation = location;
                    location = isJSDocTemplateTag(location) ? getEffectiveContainerForJSDocTemplateTag(location) || location.parent : isJSDocParameterTag(location) || isJSDocReturnTag(location) ? getHostSignatureFromJSDoc(location) || location.parent : location.parent;
                }
                if (isUse && result && (!lastSelfReferenceLocation || result !== lastSelfReferenceLocation.symbol)) {
                    result.isReferenced |= meaning;
                }
                if (!result) {
                    if (lastLocation) {
                        Debug.assertNode(lastLocation, isSourceFile);
                        if (lastLocation.commonJsModuleIndicator && name === "exports" && meaning & lastLocation.symbol.flags) {
                            return lastLocation.symbol;
                        }
                    }
                    if (!excludeGlobals) {
                        result = lookup(globals, name, meaning);
                    }
                }
                if (!result) {
                    if (originalLocation && isInJSFile(originalLocation) && originalLocation.parent) {
                        if (isRequireCall(originalLocation.parent, 
                        /*checkArgumentIsStringLiteralLike*/
                        false)) {
                            return requireSymbol;
                        }
                    }
                }
                function checkAndReportErrorForInvalidInitializer() {
                    if (propertyWithInvalidInitializer && !(useDefineForClassFields && getEmitScriptTarget(compilerOptions) >= 9 /* ES2022 */)) {
                        error(errorLocation, errorLocation && propertyWithInvalidInitializer.type && textRangeContainsPositionInclusive(propertyWithInvalidInitializer.type, errorLocation.pos) ? Diagnostics.Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor : Diagnostics.Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor, declarationNameToString(propertyWithInvalidInitializer.name), diagnosticName(nameArg));
                        return true;
                    }
                    return false;
                }
                if (!result) {
                    if (nameNotFoundMessage) {
                        addLazyDiagnostic(() => {
                            if (!errorLocation || !checkAndReportErrorForMissingPrefix(errorLocation, name, nameArg) && // TODO: GH#18217
                                !checkAndReportErrorForInvalidInitializer() && !checkAndReportErrorForExtendingInterface(errorLocation) && !checkAndReportErrorForUsingTypeAsNamespace(errorLocation, name, meaning) && !checkAndReportErrorForExportingPrimitiveType(errorLocation, name) && !checkAndReportErrorForUsingNamespaceAsTypeOrValue(errorLocation, name, meaning) && !checkAndReportErrorForUsingTypeAsValue(errorLocation, name, meaning) && !checkAndReportErrorForUsingValueAsType(errorLocation, name, meaning)) {
                                let suggestion;
                                let suggestedLib;
                                if (nameArg) {
                                    suggestedLib = getSuggestedLibForNonExistentName(nameArg);
                                    if (suggestedLib) {
                                        error(errorLocation, nameNotFoundMessage, diagnosticName(nameArg), suggestedLib);
                                    }
                                }
                                if (!suggestedLib && getSpellingSuggestions && suggestionCount < maximumSuggestionCount) {
                                    suggestion = getSuggestedSymbolForNonexistentSymbol(originalLocation, name, meaning);
                                    const isGlobalScopeAugmentationDeclaration = (suggestion == null ? void 0 : suggestion.valueDeclaration) && isAmbientModule(suggestion.valueDeclaration) && isGlobalScopeAugmentation(suggestion.valueDeclaration);
                                    if (isGlobalScopeAugmentationDeclaration) {
                                        suggestion = void 0;
                                    }
                                    if (suggestion) {
                                        const suggestionName = symbolToString(suggestion);
                                        const isUncheckedJS = isUncheckedJSSuggestion(originalLocation, suggestion, 
                                        /*excludeClasses*/
                                        false);
                                        const message = meaning === 1920 /* Namespace */ || nameArg && typeof nameArg !== "string" && nodeIsSynthesized(nameArg) ? Diagnostics.Cannot_find_namespace_0_Did_you_mean_1 : isUncheckedJS ? Diagnostics.Could_not_find_name_0_Did_you_mean_1 : Diagnostics.Cannot_find_name_0_Did_you_mean_1;
                                        const diagnostic = createError(errorLocation, message, diagnosticName(nameArg), suggestionName);
                                        addErrorOrSuggestion(!isUncheckedJS, diagnostic);
                                        if (suggestion.valueDeclaration) {
                                            addRelatedInfo(diagnostic, createDiagnosticForNode(suggestion.valueDeclaration, Diagnostics._0_is_declared_here, suggestionName));
                                        }
                                    }
                                }
                                if (!suggestion && !suggestedLib && nameArg) {
                                    error(errorLocation, nameNotFoundMessage, diagnosticName(nameArg));
                                }
                                suggestionCount++;
                            }
                        });
                    }
                    return void 0;
                }
                else if (nameNotFoundMessage && checkAndReportErrorForInvalidInitializer()) {
                    return void 0;
                }
                if (nameNotFoundMessage) {
                    addLazyDiagnostic(() => {
                        if (errorLocation && (meaning & 2 /* BlockScopedVariable */ || (meaning & 32 /* Class */ || meaning & 384 /* Enum */) && (meaning & 111551 /* Value */) === 111551 /* Value */)) {
                            const exportOrLocalSymbol = getExportSymbolOfValueSymbolIfExported(result);
                            if (exportOrLocalSymbol.flags & 2 /* BlockScopedVariable */ || exportOrLocalSymbol.flags & 32 /* Class */ || exportOrLocalSymbol.flags & 384 /* Enum */) {
                                checkResolvedBlockScopedVariable(exportOrLocalSymbol, errorLocation);
                            }
                        }
                        if (result && isInExternalModule && (meaning & 111551 /* Value */) === 111551 /* Value */ && !(originalLocation.flags & 8388608 /* JSDoc */)) {
                            const merged = getMergedSymbol(result);
                            if (length(merged.declarations) && every(merged.declarations, (d) => isNamespaceExportDeclaration(d) || isSourceFile(d) && !!d.symbol.globalExports)) {
                                errorOrSuggestion(!compilerOptions.allowUmdGlobalAccess, errorLocation, Diagnostics._0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead, unescapeLeadingUnderscores(name));
                            }
                        }
                        if (result && associatedDeclarationForContainingInitializerOrBindingName && !withinDeferredContext && (meaning & 111551 /* Value */) === 111551 /* Value */) {
                            const candidate = getMergedSymbol(getLateBoundSymbol(result));
                            const root = getRootDeclaration(associatedDeclarationForContainingInitializerOrBindingName);
                            if (candidate === getSymbolOfDeclaration(associatedDeclarationForContainingInitializerOrBindingName)) {
                                error(errorLocation, Diagnostics.Parameter_0_cannot_reference_itself, declarationNameToString(associatedDeclarationForContainingInitializerOrBindingName.name));
                            }
                            else if (candidate.valueDeclaration && candidate.valueDeclaration.pos > associatedDeclarationForContainingInitializerOrBindingName.pos && root.parent.locals && lookup(root.parent.locals, candidate.escapedName, meaning) === candidate) {
                                error(errorLocation, Diagnostics.Parameter_0_cannot_reference_identifier_1_declared_after_it, declarationNameToString(associatedDeclarationForContainingInitializerOrBindingName.name), declarationNameToString(errorLocation));
                            }
                        }
                        if (result && errorLocation && meaning & 111551 /* Value */ && result.flags & 2097152 /* Alias */ && !(result.flags & 111551 /* Value */) && !isValidTypeOnlyAliasUseSite(errorLocation)) {
                            const typeOnlyDeclaration = getTypeOnlyAliasDeclaration(result, 111551 /* Value */);
                            if (typeOnlyDeclaration) {
                                const message = typeOnlyDeclaration.kind === 278 /* ExportSpecifier */ || typeOnlyDeclaration.kind === 275 /* ExportDeclaration */ || typeOnlyDeclaration.kind === 277 /* NamespaceExport */ ? Diagnostics._0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type : Diagnostics._0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type;
                                const unescapedName = unescapeLeadingUnderscores(name);
                                addTypeOnlyDeclarationRelatedInfo(error(errorLocation, message, unescapedName), typeOnlyDeclaration, unescapedName);
                            }
                        }
                    });
                }
                return result;
            }
            function addTypeOnlyDeclarationRelatedInfo(diagnostic, typeOnlyDeclaration, unescapedName) {
                if (!typeOnlyDeclaration)
                    return diagnostic;
                return addRelatedInfo(diagnostic, createDiagnosticForNode(typeOnlyDeclaration, typeOnlyDeclaration.kind === 278 /* ExportSpecifier */ || typeOnlyDeclaration.kind === 275 /* ExportDeclaration */ || typeOnlyDeclaration.kind === 277 /* NamespaceExport */ ? Diagnostics._0_was_exported_here : Diagnostics._0_was_imported_here, unescapedName));
            }
            function getIsDeferredContext(location, lastLocation) {
                if (location.kind !== 216 /* ArrowFunction */ && location.kind !== 215 /* FunctionExpression */) {
                    return isTypeQueryNode(location) || (isFunctionLikeDeclaration(location) || location.kind === 169 /* PropertyDeclaration */ && !isStatic(location)) && (!lastLocation || lastLocation !== location.name);
                }
                if (lastLocation && lastLocation === location.name) {
                    return false;
                }
                if (location.asteriskToken || hasSyntacticModifier(location, 512 /* Async */)) {
                    return true;
                }
                return !getImmediatelyInvokedFunctionExpression(location);
            }
            function isSelfReferenceLocation(node) {
                switch (node.kind) {
                    case 259 /* FunctionDeclaration */:
                    case 260 /* ClassDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                    case 263 /* EnumDeclaration */:
                    case 262 /* TypeAliasDeclaration */:
                    case 264 /* ModuleDeclaration */:
                        return true;
                    default:
                        return false;
                }
            }
            function diagnosticName(nameArg) {
                return isString(nameArg) ? unescapeLeadingUnderscores(nameArg) : declarationNameToString(nameArg);
            }
            function isTypeParameterSymbolDeclaredInContainer(symbol, container) {
                if (symbol.declarations) {
                    for (const decl of symbol.declarations) {
                        if (decl.kind === 165 /* TypeParameter */) {
                            const parent2 = isJSDocTemplateTag(decl.parent) ? getJSDocHost(decl.parent) : decl.parent;
                            if (parent2 === container) {
                                return !(isJSDocTemplateTag(decl.parent) && find(decl.parent.parent.tags, isJSDocTypeAlias));
                            }
                        }
                    }
                }
                return false;
            }
            function checkAndReportErrorForMissingPrefix(errorLocation, name, nameArg) {
                if (!isIdentifier(errorLocation) || errorLocation.escapedText !== name || isTypeReferenceIdentifier(errorLocation) || isInTypeQuery(errorLocation)) {
                    return false;
                }
                const container = getThisContainer(errorLocation, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                let location = container;
                while (location) {
                    if (isClassLike(location.parent)) {
                        const classSymbol = getSymbolOfDeclaration(location.parent);
                        if (!classSymbol) {
                            break;
                        }
                        const constructorType = getTypeOfSymbol(classSymbol);
                        if (getPropertyOfType(constructorType, name)) {
                            error(errorLocation, Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0, diagnosticName(nameArg), symbolToString(classSymbol));
                            return true;
                        }
                        if (location === container && !isStatic(location)) {
                            const instanceType = getDeclaredTypeOfSymbol(classSymbol).thisType;
                            if (getPropertyOfType(instanceType, name)) {
                                error(errorLocation, Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0, diagnosticName(nameArg));
                                return true;
                            }
                        }
                    }
                    location = location.parent;
                }
                return false;
            }
            function checkAndReportErrorForExtendingInterface(errorLocation) {
                const expression = getEntityNameForExtendingInterface(errorLocation);
                if (expression && resolveEntityName(expression, 64 /* Interface */, 
                /*ignoreErrors*/
                true)) {
                    error(errorLocation, Diagnostics.Cannot_extend_an_interface_0_Did_you_mean_implements, getTextOfNode(expression));
                    return true;
                }
                return false;
            }
            function getEntityNameForExtendingInterface(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                    case 208 /* PropertyAccessExpression */:
                        return node.parent ? getEntityNameForExtendingInterface(node.parent) : void 0;
                    case 230 /* ExpressionWithTypeArguments */:
                        if (isEntityNameExpression(node.expression)) {
                            return node.expression;
                        }
                    default:
                        return void 0;
                }
            }
            function checkAndReportErrorForUsingTypeAsNamespace(errorLocation, name, meaning) {
                const namespaceMeaning = 1920 /* Namespace */ | (isInJSFile(errorLocation) ? 111551 /* Value */ : 0);
                if (meaning === namespaceMeaning) {
                    const symbol = resolveSymbol(resolveName(errorLocation, name, 788968 /* Type */ & ~namespaceMeaning, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    const parent2 = errorLocation.parent;
                    if (symbol) {
                        if (isQualifiedName(parent2)) {
                            Debug.assert(parent2.left === errorLocation, "Should only be resolving left side of qualified name as a namespace");
                            const propName = parent2.right.escapedText;
                            const propType = getPropertyOfType(getDeclaredTypeOfSymbol(symbol), propName);
                            if (propType) {
                                error(parent2, Diagnostics.Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1, unescapeLeadingUnderscores(name), unescapeLeadingUnderscores(propName));
                                return true;
                            }
                        }
                        error(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here, unescapeLeadingUnderscores(name));
                        return true;
                    }
                }
                return false;
            }
            function checkAndReportErrorForUsingValueAsType(errorLocation, name, meaning) {
                if (meaning & (788968 /* Type */ & ~1920 /* Namespace */)) {
                    const symbol = resolveSymbol(resolveName(errorLocation, name, ~788968 /* Type */ & 111551 /* Value */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    if (symbol && !(symbol.flags & 1920 /* Namespace */)) {
                        error(errorLocation, Diagnostics._0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0, unescapeLeadingUnderscores(name));
                        return true;
                    }
                }
                return false;
            }
            function isPrimitiveTypeName(name) {
                return name === "any" || name === "string" || name === "number" || name === "boolean" || name === "never" || name === "unknown";
            }
            function checkAndReportErrorForExportingPrimitiveType(errorLocation, name) {
                if (isPrimitiveTypeName(name) && errorLocation.parent.kind === 278 /* ExportSpecifier */) {
                    error(errorLocation, Diagnostics.Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module, name);
                    return true;
                }
                return false;
            }
            function checkAndReportErrorForUsingTypeAsValue(errorLocation, name, meaning) {
                if (meaning & 111551 /* Value */) {
                    if (isPrimitiveTypeName(name)) {
                        if (isExtendedByInterface(errorLocation)) {
                            error(errorLocation, Diagnostics.An_interface_cannot_extend_a_primitive_type_like_0_an_interface_can_only_extend_named_types_and_classes, unescapeLeadingUnderscores(name));
                        }
                        else {
                            error(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here, unescapeLeadingUnderscores(name));
                        }
                        return true;
                    }
                    const symbol = resolveSymbol(resolveName(errorLocation, name, 788968 /* Type */ & ~111551 /* Value */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    const allFlags = symbol && getAllSymbolFlags(symbol);
                    if (symbol && allFlags !== void 0 && !(allFlags & 111551 /* Value */)) {
                        const rawName = unescapeLeadingUnderscores(name);
                        if (isES2015OrLaterConstructorName(name)) {
                            error(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_es2015_or_later, rawName);
                        }
                        else if (maybeMappedType(errorLocation, symbol)) {
                            error(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0, rawName, rawName === "K" ? "P" : "K");
                        }
                        else {
                            error(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here, rawName);
                        }
                        return true;
                    }
                }
                return false;
            }
            function isExtendedByInterface(node) {
                const grandparent = node.parent.parent;
                const parentOfGrandparent = grandparent.parent;
                if (grandparent && parentOfGrandparent) {
                    const isExtending = isHeritageClause(grandparent) && grandparent.token === 94 /* ExtendsKeyword */;
                    const isInterface = isInterfaceDeclaration(parentOfGrandparent);
                    return isExtending && isInterface;
                }
                return false;
            }
            function maybeMappedType(node, symbol) {
                const container = findAncestor(node.parent, (n) => isComputedPropertyName(n) || isPropertySignature(n) ? false : isTypeLiteralNode(n) || "quit");
                if (container && container.members.length === 1) {
                    const type = getDeclaredTypeOfSymbol(symbol);
                    return !!(type.flags & 1048576 /* Union */) && allTypesAssignableToKind(type, 384 /* StringOrNumberLiteral */, 
                    /*strict*/
                    true);
                }
                return false;
            }
            function isES2015OrLaterConstructorName(n) {
                switch (n) {
                    case "Promise":
                    case "Symbol":
                    case "Map":
                    case "WeakMap":
                    case "Set":
                    case "WeakSet":
                        return true;
                }
                return false;
            }
            function checkAndReportErrorForUsingNamespaceAsTypeOrValue(errorLocation, name, meaning) {
                if (meaning & (111551 /* Value */ & ~788968 /* Type */)) {
                    const symbol = resolveSymbol(resolveName(errorLocation, name, 1024 /* NamespaceModule */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    if (symbol) {
                        error(errorLocation, Diagnostics.Cannot_use_namespace_0_as_a_value, unescapeLeadingUnderscores(name));
                        return true;
                    }
                }
                else if (meaning & (788968 /* Type */ & ~111551 /* Value */)) {
                    const symbol = resolveSymbol(resolveName(errorLocation, name, 1536 /* Module */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    if (symbol) {
                        error(errorLocation, Diagnostics.Cannot_use_namespace_0_as_a_type, unescapeLeadingUnderscores(name));
                        return true;
                    }
                }
                return false;
            }
            function checkResolvedBlockScopedVariable(result, errorLocation) {
                var _a2;
                Debug.assert(!!(result.flags & 2 /* BlockScopedVariable */ || result.flags & 32 /* Class */ || result.flags & 384 /* Enum */));
                if (result.flags & (16 /* Function */ | 1 /* FunctionScopedVariable */ | 67108864 /* Assignment */) && result.flags & 32 /* Class */) {
                    return;
                }
                const declaration = (_a2 = result.declarations) == null ? void 0 : _a2.find((d) => isBlockOrCatchScoped(d) || isClassLike(d) || d.kind === 263 /* EnumDeclaration */);
                if (declaration === void 0)
                    return Debug.fail("checkResolvedBlockScopedVariable could not find block-scoped declaration");
                if (!(declaration.flags & 16777216 /* Ambient */) && !isBlockScopedNameDeclaredBeforeUse(declaration, errorLocation)) {
                    let diagnosticMessage;
                    const declarationName = declarationNameToString(getNameOfDeclaration(declaration));
                    if (result.flags & 2 /* BlockScopedVariable */) {
                        diagnosticMessage = error(errorLocation, Diagnostics.Block_scoped_variable_0_used_before_its_declaration, declarationName);
                    }
                    else if (result.flags & 32 /* Class */) {
                        diagnosticMessage = error(errorLocation, Diagnostics.Class_0_used_before_its_declaration, declarationName);
                    }
                    else if (result.flags & 256 /* RegularEnum */) {
                        diagnosticMessage = error(errorLocation, Diagnostics.Enum_0_used_before_its_declaration, declarationName);
                    }
                    else {
                        Debug.assert(!!(result.flags & 128 /* ConstEnum */));
                        if (shouldPreserveConstEnums(compilerOptions)) {
                            diagnosticMessage = error(errorLocation, Diagnostics.Enum_0_used_before_its_declaration, declarationName);
                        }
                    }
                    if (diagnosticMessage) {
                        addRelatedInfo(diagnosticMessage, createDiagnosticForNode(declaration, Diagnostics._0_is_declared_here, declarationName));
                    }
                }
            }
            function isSameScopeDescendentOf(initial, parent2, stopAt) {
                return !!parent2 && !!findAncestor(initial, (n) => n === parent2 || (n === stopAt || isFunctionLike(n) && (!getImmediatelyInvokedFunctionExpression(n) || isAsyncFunction(n)) ? "quit" : false));
            }
            function getAnyImportSyntax(node) {
                switch (node.kind) {
                    case 268 /* ImportEqualsDeclaration */:
                        return node;
                    case 270 /* ImportClause */:
                        return node.parent;
                    case 271 /* NamespaceImport */:
                        return node.parent.parent;
                    case 273 /* ImportSpecifier */:
                        return node.parent.parent.parent;
                    default:
                        return void 0;
                }
            }
            function getDeclarationOfAliasSymbol(symbol) {
                return symbol.declarations && findLast(symbol.declarations, isAliasSymbolDeclaration2);
            }
            function isAliasSymbolDeclaration2(node) {
                return node.kind === 268 /* ImportEqualsDeclaration */ || node.kind === 267 /* NamespaceExportDeclaration */ || node.kind === 270 /* ImportClause */ && !!node.name || node.kind === 271 /* NamespaceImport */ || node.kind === 277 /* NamespaceExport */ || node.kind === 273 /* ImportSpecifier */ || node.kind === 278 /* ExportSpecifier */ || node.kind === 274 /* ExportAssignment */ && exportAssignmentIsAlias(node) || isBinaryExpression(node) && getAssignmentDeclarationKind(node) === 2 /* ModuleExports */ && exportAssignmentIsAlias(node) || isAccessExpression(node) && isBinaryExpression(node.parent) && node.parent.left === node && node.parent.operatorToken.kind === 63 /* EqualsToken */ && isAliasableOrJsExpression(node.parent.right) || node.kind === 300 /* ShorthandPropertyAssignment */ || node.kind === 299 /* PropertyAssignment */ && isAliasableOrJsExpression(node.initializer) || node.kind === 257 /* VariableDeclaration */ && isVariableDeclarationInitializedToBareOrAccessedRequire(node) || node.kind === 205 /* BindingElement */ && isVariableDeclarationInitializedToBareOrAccessedRequire(node.parent.parent);
            }
            function isAliasableOrJsExpression(e) {
                return isAliasableExpression(e) || isFunctionExpression(e) && isJSConstructor(e);
            }
            function getTargetOfImportEqualsDeclaration(node, dontResolveAlias) {
                const commonJSPropertyAccess = getCommonJSPropertyAccess(node);
                if (commonJSPropertyAccess) {
                    const name = getLeftmostAccessExpression(commonJSPropertyAccess.expression).arguments[0];
                    return isIdentifier(commonJSPropertyAccess.name) ? resolveSymbol(getPropertyOfType(resolveExternalModuleTypeByLiteral(name), commonJSPropertyAccess.name.escapedText)) : void 0;
                }
                if (isVariableDeclaration(node) || node.moduleReference.kind === 280 /* ExternalModuleReference */) {
                    const immediate = resolveExternalModuleName(node, getExternalModuleRequireArgument(node) || getExternalModuleImportEqualsDeclarationExpression(node));
                    const resolved2 = resolveExternalModuleSymbol(immediate);
                    markSymbolOfAliasDeclarationIfTypeOnly(node, immediate, resolved2, 
                    /*overwriteEmpty*/
                    false);
                    return resolved2;
                }
                const resolved = getSymbolOfPartOfRightHandSideOfImportEquals(node.moduleReference, dontResolveAlias);
                checkAndReportErrorForResolvingImportAliasToTypeOnlySymbol(node, resolved);
                return resolved;
            }
            function checkAndReportErrorForResolvingImportAliasToTypeOnlySymbol(node, resolved) {
                if (markSymbolOfAliasDeclarationIfTypeOnly(node, 
                /*immediateTarget*/
                void 0, resolved, 
                /*overwriteEmpty*/
                false) && !node.isTypeOnly) {
                    const typeOnlyDeclaration = getTypeOnlyAliasDeclaration(getSymbolOfDeclaration(node));
                    const isExport = typeOnlyDeclaration.kind === 278 /* ExportSpecifier */ || typeOnlyDeclaration.kind === 275 /* ExportDeclaration */;
                    const message = isExport ? Diagnostics.An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type : Diagnostics.An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type;
                    const relatedMessage = isExport ? Diagnostics._0_was_exported_here : Diagnostics._0_was_imported_here;
                    const name = typeOnlyDeclaration.kind === 275 /* ExportDeclaration */ ? "*" : unescapeLeadingUnderscores(typeOnlyDeclaration.name.escapedText);
                    addRelatedInfo(error(node.moduleReference, message), createDiagnosticForNode(typeOnlyDeclaration, relatedMessage, name));
                }
            }
            function resolveExportByName(moduleSymbol, name, sourceNode, dontResolveAlias) {
                const exportValue = moduleSymbol.exports.get("export=" /* ExportEquals */);
                const exportSymbol = exportValue ? getPropertyOfType(getTypeOfSymbol(exportValue), name, 
                /*skipObjectFunctionPropertyAugment*/
                true) : moduleSymbol.exports.get(name);
                const resolved = resolveSymbol(exportSymbol, dontResolveAlias);
                markSymbolOfAliasDeclarationIfTypeOnly(sourceNode, exportSymbol, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function isSyntacticDefault(node) {
                return isExportAssignment(node) && !node.isExportEquals || hasSyntacticModifier(node, 1024 /* Default */) || isExportSpecifier(node);
            }
            function getUsageModeForExpression(usage) {
                return isStringLiteralLike(usage) ? getModeForUsageLocation(getSourceFileOfNode(usage), usage) : void 0;
            }
            function isESMFormatImportImportingCommonjsFormatFile(usageMode, targetMode) {
                return usageMode === 99 /* ESNext */ && targetMode === 1 /* CommonJS */;
            }
            function isOnlyImportedAsDefault(usage) {
                const usageMode = getUsageModeForExpression(usage);
                return usageMode === 99 /* ESNext */ && endsWith(usage.text, ".json" /* Json */);
            }
            function canHaveSyntheticDefault(file, moduleSymbol, dontResolveAlias, usage) {
                const usageMode = file && getUsageModeForExpression(usage);
                if (file && usageMode !== void 0) {
                    const result = isESMFormatImportImportingCommonjsFormatFile(usageMode, file.impliedNodeFormat);
                    if (usageMode === 99 /* ESNext */ || result) {
                        return result;
                    }
                }
                if (!allowSyntheticDefaultImports) {
                    return false;
                }
                if (!file || file.isDeclarationFile) {
                    const defaultExportSymbol = resolveExportByName(moduleSymbol, "default" /* Default */, 
                    /*sourceNode*/
                    void 0, 
                    /*dontResolveAlias*/
                    true);
                    if (defaultExportSymbol && some(defaultExportSymbol.declarations, isSyntacticDefault)) {
                        return false;
                    }
                    if (resolveExportByName(moduleSymbol, escapeLeadingUnderscores("__esModule"), 
                    /*sourceNode*/
                    void 0, dontResolveAlias)) {
                        return false;
                    }
                    return true;
                }
                if (!isSourceFileJS(file)) {
                    return hasExportAssignmentSymbol(moduleSymbol);
                }
                return typeof file.externalModuleIndicator !== "object" && !resolveExportByName(moduleSymbol, escapeLeadingUnderscores("__esModule"), 
                /*sourceNode*/
                void 0, dontResolveAlias);
            }
            function getTargetOfImportClause(node, dontResolveAlias) {
                const moduleSymbol = resolveExternalModuleName(node, node.parent.moduleSpecifier);
                if (moduleSymbol) {
                    return getTargetofModuleDefault(moduleSymbol, node, dontResolveAlias);
                }
            }
            function getTargetofModuleDefault(moduleSymbol, node, dontResolveAlias) {
                var _a2;
                let exportDefaultSymbol;
                if (isShorthandAmbientModuleSymbol(moduleSymbol)) {
                    exportDefaultSymbol = moduleSymbol;
                }
                else {
                    exportDefaultSymbol = resolveExportByName(moduleSymbol, "default" /* Default */, node, dontResolveAlias);
                }
                const file = (_a2 = moduleSymbol.declarations) == null ? void 0 : _a2.find(isSourceFile);
                const specifier = getModuleSpecifierForImportOrExport(node);
                if (!specifier) {
                    return exportDefaultSymbol;
                }
                const hasDefaultOnly = isOnlyImportedAsDefault(specifier);
                const hasSyntheticDefault = canHaveSyntheticDefault(file, moduleSymbol, dontResolveAlias, specifier);
                if (!exportDefaultSymbol && !hasSyntheticDefault && !hasDefaultOnly) {
                    if (hasExportAssignmentSymbol(moduleSymbol) && !allowSyntheticDefaultImports) {
                        const compilerOptionName = moduleKind >= 5 /* ES2015 */ ? "allowSyntheticDefaultImports" : "esModuleInterop";
                        const exportEqualsSymbol = moduleSymbol.exports.get("export=" /* ExportEquals */);
                        const exportAssignment = exportEqualsSymbol.valueDeclaration;
                        const err = error(node.name, Diagnostics.Module_0_can_only_be_default_imported_using_the_1_flag, symbolToString(moduleSymbol), compilerOptionName);
                        if (exportAssignment) {
                            addRelatedInfo(err, createDiagnosticForNode(exportAssignment, Diagnostics.This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag, compilerOptionName));
                        }
                    }
                    else if (isImportClause(node)) {
                        reportNonDefaultExport(moduleSymbol, node);
                    }
                    else {
                        errorNoModuleMemberSymbol(moduleSymbol, moduleSymbol, node, isImportOrExportSpecifier(node) && node.propertyName || node.name);
                    }
                }
                else if (hasSyntheticDefault || hasDefaultOnly) {
                    const resolved = resolveExternalModuleSymbol(moduleSymbol, dontResolveAlias) || resolveSymbol(moduleSymbol, dontResolveAlias);
                    markSymbolOfAliasDeclarationIfTypeOnly(node, moduleSymbol, resolved, 
                    /*overwriteTypeOnly*/
                    false);
                    return resolved;
                }
                markSymbolOfAliasDeclarationIfTypeOnly(node, exportDefaultSymbol, 
                /*finalTarget*/
                void 0, 
                /*overwriteTypeOnly*/
                false);
                return exportDefaultSymbol;
            }
            function getModuleSpecifierForImportOrExport(node) {
                switch (node.kind) {
                    case 270 /* ImportClause */:
                        return node.parent.moduleSpecifier;
                    case 268 /* ImportEqualsDeclaration */:
                        return isExternalModuleReference(node.moduleReference) ? node.moduleReference.expression : void 0;
                    case 271 /* NamespaceImport */:
                        return node.parent.parent.moduleSpecifier;
                    case 273 /* ImportSpecifier */:
                        return node.parent.parent.parent.moduleSpecifier;
                    case 278 /* ExportSpecifier */:
                        return node.parent.parent.moduleSpecifier;
                    default:
                        return Debug.assertNever(node);
                }
            }
            function reportNonDefaultExport(moduleSymbol, node) {
                var _a2, _b, _c;
                if ((_a2 = moduleSymbol.exports) == null ? void 0 : _a2.has(node.symbol.escapedName)) {
                    error(node.name, Diagnostics.Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead, symbolToString(moduleSymbol), symbolToString(node.symbol));
                }
                else {
                    const diagnostic = error(node.name, Diagnostics.Module_0_has_no_default_export, symbolToString(moduleSymbol));
                    const exportStar = (_b = moduleSymbol.exports) == null ? void 0 : _b.get("__export" /* ExportStar */);
                    if (exportStar) {
                        const defaultExport = (_c = exportStar.declarations) == null ? void 0 : _c.find((decl) => {
                            var _a3, _b2;
                            return !!(isExportDeclaration(decl) && decl.moduleSpecifier && ((_b2 = (_a3 = resolveExternalModuleName(decl, decl.moduleSpecifier)) == null ? void 0 : _a3.exports) == null ? void 0 : _b2.has("default" /* Default */)));
                        });
                        if (defaultExport) {
                            addRelatedInfo(diagnostic, createDiagnosticForNode(defaultExport, Diagnostics.export_Asterisk_does_not_re_export_a_default));
                        }
                    }
                }
            }
            function getTargetOfNamespaceImport(node, dontResolveAlias) {
                const moduleSpecifier = node.parent.parent.moduleSpecifier;
                const immediate = resolveExternalModuleName(node, moduleSpecifier);
                const resolved = resolveESModuleSymbol(immediate, moduleSpecifier, dontResolveAlias, 
                /*suppressUsageError*/
                false);
                markSymbolOfAliasDeclarationIfTypeOnly(node, immediate, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function getTargetOfNamespaceExport(node, dontResolveAlias) {
                const moduleSpecifier = node.parent.moduleSpecifier;
                const immediate = moduleSpecifier && resolveExternalModuleName(node, moduleSpecifier);
                const resolved = moduleSpecifier && resolveESModuleSymbol(immediate, moduleSpecifier, dontResolveAlias, 
                /*suppressUsageError*/
                false);
                markSymbolOfAliasDeclarationIfTypeOnly(node, immediate, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function combineValueAndTypeSymbols(valueSymbol, typeSymbol) {
                if (valueSymbol === unknownSymbol && typeSymbol === unknownSymbol) {
                    return unknownSymbol;
                }
                if (valueSymbol.flags & (788968 /* Type */ | 1920 /* Namespace */)) {
                    return valueSymbol;
                }
                const result = createSymbol(valueSymbol.flags | typeSymbol.flags, valueSymbol.escapedName);
                Debug.assert(valueSymbol.declarations || typeSymbol.declarations);
                result.declarations = deduplicate(concatenate(valueSymbol.declarations, typeSymbol.declarations), equateValues);
                result.parent = valueSymbol.parent || typeSymbol.parent;
                if (valueSymbol.valueDeclaration)
                    result.valueDeclaration = valueSymbol.valueDeclaration;
                if (typeSymbol.members)
                    result.members = new Map(typeSymbol.members);
                if (valueSymbol.exports)
                    result.exports = new Map(valueSymbol.exports);
                return result;
            }
            function getExportOfModule(symbol, name, specifier, dontResolveAlias) {
                var _a2;
                if (symbol.flags & 1536 /* Module */) {
                    const exportSymbol = getExportsOfSymbol(symbol).get(name.escapedText);
                    const resolved = resolveSymbol(exportSymbol, dontResolveAlias);
                    const exportStarDeclaration = (_a2 = getSymbolLinks(symbol).typeOnlyExportStarMap) == null ? void 0 : _a2.get(name.escapedText);
                    markSymbolOfAliasDeclarationIfTypeOnly(specifier, exportSymbol, resolved, 
                    /*overwriteEmpty*/
                    false, exportStarDeclaration, name.escapedText);
                    return resolved;
                }
            }
            function getPropertyOfVariable(symbol, name) {
                if (symbol.flags & 3 /* Variable */) {
                    const typeAnnotation = symbol.valueDeclaration.type;
                    if (typeAnnotation) {
                        return resolveSymbol(getPropertyOfType(getTypeFromTypeNode(typeAnnotation), name));
                    }
                }
            }
            function getExternalModuleMember(node, specifier, dontResolveAlias = false) {
                var _a2;
                const moduleSpecifier = getExternalModuleRequireArgument(node) || node.moduleSpecifier;
                const moduleSymbol = resolveExternalModuleName(node, moduleSpecifier);
                const name = !isPropertyAccessExpression(specifier) && specifier.propertyName || specifier.name;
                if (!isIdentifier(name)) {
                    return void 0;
                }
                const suppressInteropError = name.escapedText === "default" /* Default */ && allowSyntheticDefaultImports;
                const targetSymbol = resolveESModuleSymbol(moduleSymbol, moduleSpecifier, 
                /*dontResolveAlias*/
                false, suppressInteropError);
                if (targetSymbol) {
                    if (name.escapedText) {
                        if (isShorthandAmbientModuleSymbol(moduleSymbol)) {
                            return moduleSymbol;
                        }
                        let symbolFromVariable;
                        if (moduleSymbol && moduleSymbol.exports && moduleSymbol.exports.get("export=" /* ExportEquals */)) {
                            symbolFromVariable = getPropertyOfType(getTypeOfSymbol(targetSymbol), name.escapedText, 
                            /*skipObjectFunctionPropertyAugment*/
                            true);
                        }
                        else {
                            symbolFromVariable = getPropertyOfVariable(targetSymbol, name.escapedText);
                        }
                        symbolFromVariable = resolveSymbol(symbolFromVariable, dontResolveAlias);
                        let symbolFromModule = getExportOfModule(targetSymbol, name, specifier, dontResolveAlias);
                        if (symbolFromModule === void 0 && name.escapedText === "default" /* Default */) {
                            const file = (_a2 = moduleSymbol.declarations) == null ? void 0 : _a2.find(isSourceFile);
                            if (isOnlyImportedAsDefault(moduleSpecifier) || canHaveSyntheticDefault(file, moduleSymbol, dontResolveAlias, moduleSpecifier)) {
                                symbolFromModule = resolveExternalModuleSymbol(moduleSymbol, dontResolveAlias) || resolveSymbol(moduleSymbol, dontResolveAlias);
                            }
                        }
                        const symbol = symbolFromModule && symbolFromVariable && symbolFromModule !== symbolFromVariable ? combineValueAndTypeSymbols(symbolFromVariable, symbolFromModule) : symbolFromModule || symbolFromVariable;
                        if (!symbol) {
                            errorNoModuleMemberSymbol(moduleSymbol, targetSymbol, node, name);
                        }
                        return symbol;
                    }
                }
            }
            function errorNoModuleMemberSymbol(moduleSymbol, targetSymbol, node, name) {
                var _a2;
                const moduleName = getFullyQualifiedName(moduleSymbol, node);
                const declarationName = declarationNameToString(name);
                const suggestion = getSuggestedSymbolForNonexistentModule(name, targetSymbol);
                if (suggestion !== void 0) {
                    const suggestionName = symbolToString(suggestion);
                    const diagnostic = error(name, Diagnostics._0_has_no_exported_member_named_1_Did_you_mean_2, moduleName, declarationName, suggestionName);
                    if (suggestion.valueDeclaration) {
                        addRelatedInfo(diagnostic, createDiagnosticForNode(suggestion.valueDeclaration, Diagnostics._0_is_declared_here, suggestionName));
                    }
                }
                else {
                    if ((_a2 = moduleSymbol.exports) == null ? void 0 : _a2.has("default" /* Default */)) {
                        error(name, Diagnostics.Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead, moduleName, declarationName);
                    }
                    else {
                        reportNonExportedMember(node, name, declarationName, moduleSymbol, moduleName);
                    }
                }
            }
            function reportNonExportedMember(node, name, declarationName, moduleSymbol, moduleName) {
                var _a2, _b;
                const localSymbol = (_b = (_a2 = tryCast(moduleSymbol.valueDeclaration, canHaveLocals)) == null ? void 0 : _a2.locals) == null ? void 0 : _b.get(name.escapedText);
                const exports = moduleSymbol.exports;
                if (localSymbol) {
                    const exportedEqualsSymbol = exports == null ? void 0 : exports.get("export=" /* ExportEquals */);
                    if (exportedEqualsSymbol) {
                        getSymbolIfSameReference(exportedEqualsSymbol, localSymbol) ? reportInvalidImportEqualsExportMember(node, name, declarationName, moduleName) : error(name, Diagnostics.Module_0_has_no_exported_member_1, moduleName, declarationName);
                    }
                    else {
                        const exportedSymbol = exports ? find(symbolsToArray(exports), (symbol) => !!getSymbolIfSameReference(symbol, localSymbol)) : void 0;
                        const diagnostic = exportedSymbol ? error(name, Diagnostics.Module_0_declares_1_locally_but_it_is_exported_as_2, moduleName, declarationName, symbolToString(exportedSymbol)) : error(name, Diagnostics.Module_0_declares_1_locally_but_it_is_not_exported, moduleName, declarationName);
                        if (localSymbol.declarations) {
                            addRelatedInfo(diagnostic, ...map(localSymbol.declarations, (decl, index) => createDiagnosticForNode(decl, index === 0 ? Diagnostics._0_is_declared_here : Diagnostics.and_here, declarationName)));
                        }
                    }
                }
                else {
                    error(name, Diagnostics.Module_0_has_no_exported_member_1, moduleName, declarationName);
                }
            }
            function reportInvalidImportEqualsExportMember(node, name, declarationName, moduleName) {
                if (moduleKind >= 5 /* ES2015 */) {
                    const message = getESModuleInterop(compilerOptions) ? Diagnostics._0_can_only_be_imported_by_using_a_default_import : Diagnostics._0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import;
                    error(name, message, declarationName);
                }
                else {
                    if (isInJSFile(node)) {
                        const message = getESModuleInterop(compilerOptions) ? Diagnostics._0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import : Diagnostics._0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import;
                        error(name, message, declarationName);
                    }
                    else {
                        const message = getESModuleInterop(compilerOptions) ? Diagnostics._0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import : Diagnostics._0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import;
                        error(name, message, declarationName, declarationName, moduleName);
                    }
                }
            }
            function getTargetOfImportSpecifier(node, dontResolveAlias) {
                if (isImportSpecifier(node) && idText(node.propertyName || node.name) === "default" /* Default */) {
                    const specifier = getModuleSpecifierForImportOrExport(node);
                    const moduleSymbol = specifier && resolveExternalModuleName(node, specifier);
                    if (moduleSymbol) {
                        return getTargetofModuleDefault(moduleSymbol, node, dontResolveAlias);
                    }
                }
                const root = isBindingElement(node) ? getRootDeclaration(node) : node.parent.parent.parent;
                const commonJSPropertyAccess = getCommonJSPropertyAccess(root);
                const resolved = getExternalModuleMember(root, commonJSPropertyAccess || node, dontResolveAlias);
                const name = node.propertyName || node.name;
                if (commonJSPropertyAccess && resolved && isIdentifier(name)) {
                    return resolveSymbol(getPropertyOfType(getTypeOfSymbol(resolved), name.escapedText), dontResolveAlias);
                }
                markSymbolOfAliasDeclarationIfTypeOnly(node, 
                /*immediateTarget*/
                void 0, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function getCommonJSPropertyAccess(node) {
                if (isVariableDeclaration(node) && node.initializer && isPropertyAccessExpression(node.initializer)) {
                    return node.initializer;
                }
            }
            function getTargetOfNamespaceExportDeclaration(node, dontResolveAlias) {
                if (canHaveSymbol(node.parent)) {
                    const resolved = resolveExternalModuleSymbol(node.parent.symbol, dontResolveAlias);
                    markSymbolOfAliasDeclarationIfTypeOnly(node, 
                    /*immediateTarget*/
                    void 0, resolved, 
                    /*overwriteEmpty*/
                    false);
                    return resolved;
                }
            }
            function getTargetOfExportSpecifier(node, meaning, dontResolveAlias) {
                if (idText(node.propertyName || node.name) === "default" /* Default */) {
                    const specifier = getModuleSpecifierForImportOrExport(node);
                    const moduleSymbol = specifier && resolveExternalModuleName(node, specifier);
                    if (moduleSymbol) {
                        return getTargetofModuleDefault(moduleSymbol, node, !!dontResolveAlias);
                    }
                }
                const resolved = node.parent.parent.moduleSpecifier ? getExternalModuleMember(node.parent.parent, node, dontResolveAlias) : resolveEntityName(node.propertyName || node.name, meaning, 
                /*ignoreErrors*/
                false, dontResolveAlias);
                markSymbolOfAliasDeclarationIfTypeOnly(node, 
                /*immediateTarget*/
                void 0, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function getTargetOfExportAssignment(node, dontResolveAlias) {
                const expression = isExportAssignment(node) ? node.expression : node.right;
                const resolved = getTargetOfAliasLikeExpression(expression, dontResolveAlias);
                markSymbolOfAliasDeclarationIfTypeOnly(node, 
                /*immediateTarget*/
                void 0, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function getTargetOfAliasLikeExpression(expression, dontResolveAlias) {
                if (isClassExpression(expression)) {
                    return checkExpressionCached(expression).symbol;
                }
                if (!isEntityName(expression) && !isEntityNameExpression(expression)) {
                    return void 0;
                }
                const aliasLike = resolveEntityName(expression, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, 
                /*ignoreErrors*/
                true, dontResolveAlias);
                if (aliasLike) {
                    return aliasLike;
                }
                checkExpressionCached(expression);
                return getNodeLinks(expression).resolvedSymbol;
            }
            function getTargetOfAccessExpression(node, dontRecursivelyResolve) {
                if (!(isBinaryExpression(node.parent) && node.parent.left === node && node.parent.operatorToken.kind === 63 /* EqualsToken */)) {
                    return void 0;
                }
                return getTargetOfAliasLikeExpression(node.parent.right, dontRecursivelyResolve);
            }
            function getTargetOfAliasDeclaration(node, dontRecursivelyResolve = false) {
                switch (node.kind) {
                    case 268 /* ImportEqualsDeclaration */:
                    case 257 /* VariableDeclaration */:
                        return getTargetOfImportEqualsDeclaration(node, dontRecursivelyResolve);
                    case 270 /* ImportClause */:
                        return getTargetOfImportClause(node, dontRecursivelyResolve);
                    case 271 /* NamespaceImport */:
                        return getTargetOfNamespaceImport(node, dontRecursivelyResolve);
                    case 277 /* NamespaceExport */:
                        return getTargetOfNamespaceExport(node, dontRecursivelyResolve);
                    case 273 /* ImportSpecifier */:
                    case 205 /* BindingElement */:
                        return getTargetOfImportSpecifier(node, dontRecursivelyResolve);
                    case 278 /* ExportSpecifier */:
                        return getTargetOfExportSpecifier(node, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, dontRecursivelyResolve);
                    case 274 /* ExportAssignment */:
                    case 223 /* BinaryExpression */:
                        return getTargetOfExportAssignment(node, dontRecursivelyResolve);
                    case 267 /* NamespaceExportDeclaration */:
                        return getTargetOfNamespaceExportDeclaration(node, dontRecursivelyResolve);
                    case 300 /* ShorthandPropertyAssignment */:
                        return resolveEntityName(node.name, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, 
                        /*ignoreErrors*/
                        true, dontRecursivelyResolve);
                    case 299 /* PropertyAssignment */:
                        return getTargetOfAliasLikeExpression(node.initializer, dontRecursivelyResolve);
                    case 209 /* ElementAccessExpression */:
                    case 208 /* PropertyAccessExpression */:
                        return getTargetOfAccessExpression(node, dontRecursivelyResolve);
                    default:
                        return Debug.fail();
                }
            }
            function isNonLocalAlias(symbol, excludes = 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */) {
                if (!symbol)
                    return false;
                return (symbol.flags & (2097152 /* Alias */ | excludes)) === 2097152 /* Alias */ || !!(symbol.flags & 2097152 /* Alias */ && symbol.flags & 67108864 /* Assignment */);
            }
            function resolveSymbol(symbol, dontResolveAlias) {
                return !dontResolveAlias && isNonLocalAlias(symbol) ? resolveAlias(symbol) : symbol;
            }
            function resolveAlias(symbol) {
                Debug.assert((symbol.flags & 2097152 /* Alias */) !== 0, "Should only get Alias here.");
                const links = getSymbolLinks(symbol);
                if (!links.aliasTarget) {
                    links.aliasTarget = resolvingSymbol;
                    const node = getDeclarationOfAliasSymbol(symbol);
                    if (!node)
                        return Debug.fail();
                    const target = getTargetOfAliasDeclaration(node);
                    if (links.aliasTarget === resolvingSymbol) {
                        links.aliasTarget = target || unknownSymbol;
                    }
                    else {
                        error(node, Diagnostics.Circular_definition_of_import_alias_0, symbolToString(symbol));
                    }
                }
                else if (links.aliasTarget === resolvingSymbol) {
                    links.aliasTarget = unknownSymbol;
                }
                return links.aliasTarget;
            }
            function tryResolveAlias(symbol) {
                const links = getSymbolLinks(symbol);
                if (links.aliasTarget !== resolvingSymbol) {
                    return resolveAlias(symbol);
                }
                return void 0;
            }
            function getAllSymbolFlags(symbol) {
                let flags = symbol.flags;
                let seenSymbols;
                while (symbol.flags & 2097152 /* Alias */) {
                    const target = resolveAlias(symbol);
                    if (target === unknownSymbol) {
                        return 67108863 /* All */;
                    }
                    if (target === symbol || (seenSymbols == null ? void 0 : seenSymbols.has(target))) {
                        break;
                    }
                    if (target.flags & 2097152 /* Alias */) {
                        if (seenSymbols) {
                            seenSymbols.add(target);
                        }
                        else {
                            seenSymbols = /* @__PURE__ */ new Set([symbol, target]);
                        }
                    }
                    flags |= target.flags;
                    symbol = target;
                }
                return flags;
            }
            function markSymbolOfAliasDeclarationIfTypeOnly(aliasDeclaration, immediateTarget, finalTarget, overwriteEmpty, exportStarDeclaration, exportStarName) {
                if (!aliasDeclaration || isPropertyAccessExpression(aliasDeclaration))
                    return false;
                const sourceSymbol = getSymbolOfDeclaration(aliasDeclaration);
                if (isTypeOnlyImportOrExportDeclaration(aliasDeclaration)) {
                    const links2 = getSymbolLinks(sourceSymbol);
                    links2.typeOnlyDeclaration = aliasDeclaration;
                    return true;
                }
                if (exportStarDeclaration) {
                    const links2 = getSymbolLinks(sourceSymbol);
                    links2.typeOnlyDeclaration = exportStarDeclaration;
                    if (sourceSymbol.escapedName !== exportStarName) {
                        links2.typeOnlyExportStarName = exportStarName;
                    }
                    return true;
                }
                const links = getSymbolLinks(sourceSymbol);
                return markSymbolOfAliasDeclarationIfTypeOnlyWorker(links, immediateTarget, overwriteEmpty) || markSymbolOfAliasDeclarationIfTypeOnlyWorker(links, finalTarget, overwriteEmpty);
            }
            function markSymbolOfAliasDeclarationIfTypeOnlyWorker(aliasDeclarationLinks, target, overwriteEmpty) {
                var _a2, _b, _c;
                if (target && (aliasDeclarationLinks.typeOnlyDeclaration === void 0 || overwriteEmpty && aliasDeclarationLinks.typeOnlyDeclaration === false)) {
                    const exportSymbol = (_b = (_a2 = target.exports) == null ? void 0 : _a2.get("export=" /* ExportEquals */)) != null ? _b : target;
                    const typeOnly = exportSymbol.declarations && find(exportSymbol.declarations, isTypeOnlyImportOrExportDeclaration);
                    aliasDeclarationLinks.typeOnlyDeclaration = (_c = typeOnly != null ? typeOnly : getSymbolLinks(exportSymbol).typeOnlyDeclaration) != null ? _c : false;
                }
                return !!aliasDeclarationLinks.typeOnlyDeclaration;
            }
            function getTypeOnlyAliasDeclaration(symbol, include) {
                if (!(symbol.flags & 2097152 /* Alias */)) {
                    return void 0;
                }
                const links = getSymbolLinks(symbol);
                if (include === void 0) {
                    return links.typeOnlyDeclaration || void 0;
                }
                if (links.typeOnlyDeclaration) {
                    const resolved = links.typeOnlyDeclaration.kind === 275 /* ExportDeclaration */ ? resolveSymbol(getExportsOfModule(links.typeOnlyDeclaration.symbol.parent).get(links.typeOnlyExportStarName || symbol.escapedName)) : resolveAlias(links.typeOnlyDeclaration.symbol);
                    return getAllSymbolFlags(resolved) & include ? links.typeOnlyDeclaration : void 0;
                }
                return void 0;
            }
            function markExportAsReferenced(node) {
                if (compilerOptions.verbatimModuleSyntax) {
                    return;
                }
                const symbol = getSymbolOfDeclaration(node);
                const target = resolveAlias(symbol);
                if (target) {
                    const markAlias = target === unknownSymbol || getAllSymbolFlags(target) & 111551 /* Value */ && !isConstEnumOrConstEnumOnlyModule(target) && !getTypeOnlyAliasDeclaration(symbol, 111551 /* Value */);
                    if (markAlias) {
                        markAliasSymbolAsReferenced(symbol);
                    }
                }
            }
            function markAliasSymbolAsReferenced(symbol) {
                Debug.assert(!compilerOptions.verbatimModuleSyntax);
                const links = getSymbolLinks(symbol);
                if (!links.referenced) {
                    links.referenced = true;
                    const node = getDeclarationOfAliasSymbol(symbol);
                    if (!node)
                        return Debug.fail();
                    if (isInternalModuleImportEqualsDeclaration(node)) {
                        if (getAllSymbolFlags(resolveSymbol(symbol)) & 111551 /* Value */) {
                            checkExpressionCached(node.moduleReference);
                        }
                    }
                }
            }
            function markConstEnumAliasAsReferenced(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.constEnumReferenced) {
                    links.constEnumReferenced = true;
                }
            }
            function getSymbolOfPartOfRightHandSideOfImportEquals(entityName, dontResolveAlias) {
                if (entityName.kind === 79 /* Identifier */ && isRightSideOfQualifiedNameOrPropertyAccess(entityName)) {
                    entityName = entityName.parent;
                }
                if (entityName.kind === 79 /* Identifier */ || entityName.parent.kind === 163 /* QualifiedName */) {
                    return resolveEntityName(entityName, 1920 /* Namespace */, 
                    /*ignoreErrors*/
                    false, dontResolveAlias);
                }
                else {
                    Debug.assert(entityName.parent.kind === 268 /* ImportEqualsDeclaration */);
                    return resolveEntityName(entityName, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, 
                    /*ignoreErrors*/
                    false, dontResolveAlias);
                }
            }
            function getFullyQualifiedName(symbol, containingLocation) {
                return symbol.parent ? getFullyQualifiedName(symbol.parent, containingLocation) + "." + symbolToString(symbol) : symbolToString(symbol, containingLocation, 
                /*meaning*/
                void 0, 32 /* DoNotIncludeSymbolChain */ | 4 /* AllowAnyNodeKind */);
            }
            function getContainingQualifiedNameNode(node) {
                while (isQualifiedName(node.parent)) {
                    node = node.parent;
                }
                return node;
            }
            function tryGetQualifiedNameAsValue(node) {
                let left = getFirstIdentifier(node);
                let symbol = resolveName(left, left.escapedText, 111551 /* Value */, void 0, left, 
                /*isUse*/
                true);
                if (!symbol) {
                    return void 0;
                }
                while (isQualifiedName(left.parent)) {
                    const type = getTypeOfSymbol(symbol);
                    symbol = getPropertyOfType(type, left.parent.right.escapedText);
                    if (!symbol) {
                        return void 0;
                    }
                    left = left.parent;
                }
                return symbol;
            }
            function resolveEntityName(name, meaning, ignoreErrors, dontResolveAlias, location) {
                if (nodeIsMissing(name)) {
                    return void 0;
                }
                const namespaceMeaning = 1920 /* Namespace */ | (isInJSFile(name) ? meaning & 111551 /* Value */ : 0);
                let symbol;
                if (name.kind === 79 /* Identifier */) {
                    const message = meaning === namespaceMeaning || nodeIsSynthesized(name) ? Diagnostics.Cannot_find_namespace_0 : getCannotFindNameDiagnosticForName(getFirstIdentifier(name));
                    const symbolFromJSPrototype = isInJSFile(name) && !nodeIsSynthesized(name) ? resolveEntityNameFromAssignmentDeclaration(name, meaning) : void 0;
                    symbol = getMergedSymbol(resolveName(location || name, name.escapedText, meaning, ignoreErrors || symbolFromJSPrototype ? void 0 : message, name, 
                    /*isUse*/
                    true, false));
                    if (!symbol) {
                        return getMergedSymbol(symbolFromJSPrototype);
                    }
                }
                else if (name.kind === 163 /* QualifiedName */ || name.kind === 208 /* PropertyAccessExpression */) {
                    const left = name.kind === 163 /* QualifiedName */ ? name.left : name.expression;
                    const right = name.kind === 163 /* QualifiedName */ ? name.right : name.name;
                    let namespace = resolveEntityName(left, namespaceMeaning, ignoreErrors, 
                    /*dontResolveAlias*/
                    false, location);
                    if (!namespace || nodeIsMissing(right)) {
                        return void 0;
                    }
                    else if (namespace === unknownSymbol) {
                        return namespace;
                    }
                    if (namespace.valueDeclaration && isInJSFile(namespace.valueDeclaration) && getEmitModuleResolutionKind(compilerOptions) !== 100 /* Bundler */ && isVariableDeclaration(namespace.valueDeclaration) && namespace.valueDeclaration.initializer && isCommonJsRequire(namespace.valueDeclaration.initializer)) {
                        const moduleName = namespace.valueDeclaration.initializer.arguments[0];
                        const moduleSym = resolveExternalModuleName(moduleName, moduleName);
                        if (moduleSym) {
                            const resolvedModuleSymbol = resolveExternalModuleSymbol(moduleSym);
                            if (resolvedModuleSymbol) {
                                namespace = resolvedModuleSymbol;
                            }
                        }
                    }
                    symbol = getMergedSymbol(getSymbol2(getExportsOfSymbol(namespace), right.escapedText, meaning));
                    if (!symbol) {
                        if (!ignoreErrors) {
                            const namespaceName = getFullyQualifiedName(namespace);
                            const declarationName = declarationNameToString(right);
                            const suggestionForNonexistentModule = getSuggestedSymbolForNonexistentModule(right, namespace);
                            if (suggestionForNonexistentModule) {
                                error(right, Diagnostics._0_has_no_exported_member_named_1_Did_you_mean_2, namespaceName, declarationName, symbolToString(suggestionForNonexistentModule));
                                return void 0;
                            }
                            const containingQualifiedName = isQualifiedName(name) && getContainingQualifiedNameNode(name);
                            const canSuggestTypeof = globalObjectType && meaning & 788968 /* Type */ && containingQualifiedName && !isTypeOfExpression(containingQualifiedName.parent) && tryGetQualifiedNameAsValue(containingQualifiedName);
                            if (canSuggestTypeof) {
                                error(containingQualifiedName, Diagnostics._0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0, entityNameToString(containingQualifiedName));
                                return void 0;
                            }
                            if (meaning & 1920 /* Namespace */ && isQualifiedName(name.parent)) {
                                const exportedTypeSymbol = getMergedSymbol(getSymbol2(getExportsOfSymbol(namespace), right.escapedText, 788968 /* Type */));
                                if (exportedTypeSymbol) {
                                    error(name.parent.right, Diagnostics.Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1, symbolToString(exportedTypeSymbol), unescapeLeadingUnderscores(name.parent.right.escapedText));
                                    return void 0;
                                }
                            }
                            error(right, Diagnostics.Namespace_0_has_no_exported_member_1, namespaceName, declarationName);
                        }
                        return void 0;
                    }
                }
                else {
                    throw Debug.assertNever(name, "Unknown entity name kind.");
                }
                Debug.assert((getCheckFlags(symbol) & 1 /* Instantiated */) === 0, "Should never get an instantiated symbol here.");
                if (!nodeIsSynthesized(name) && isEntityName(name) && (symbol.flags & 2097152 /* Alias */ || name.parent.kind === 274 /* ExportAssignment */)) {
                    markSymbolOfAliasDeclarationIfTypeOnly(getAliasDeclarationFromName(name), symbol, 
                    /*finalTarget*/
                    void 0, 
                    /*overwriteEmpty*/
                    true);
                }
                return symbol.flags & meaning || dontResolveAlias ? symbol : resolveAlias(symbol);
            }
            function resolveEntityNameFromAssignmentDeclaration(name, meaning) {
                if (isJSDocTypeReference(name.parent)) {
                    const secondaryLocation = getAssignmentDeclarationLocation(name.parent);
                    if (secondaryLocation) {
                        return resolveName(secondaryLocation, name.escapedText, meaning, 
                        /*nameNotFoundMessage*/
                        void 0, name, 
                        /*isUse*/
                        true);
                    }
                }
            }
            function getAssignmentDeclarationLocation(node) {
                const typeAlias = findAncestor(node, (node2) => !(isJSDocNode(node2) || node2.flags & 8388608 /* JSDoc */) ? "quit" : isJSDocTypeAlias(node2));
                if (typeAlias) {
                    return;
                }
                const host2 = getJSDocHost(node);
                if (host2 && isExpressionStatement(host2) && isPrototypePropertyAssignment(host2.expression)) {
                    const symbol = getSymbolOfDeclaration(host2.expression.left);
                    if (symbol) {
                        return getDeclarationOfJSPrototypeContainer(symbol);
                    }
                }
                if (host2 && isFunctionExpression(host2) && isPrototypePropertyAssignment(host2.parent) && isExpressionStatement(host2.parent.parent)) {
                    const symbol = getSymbolOfDeclaration(host2.parent.left);
                    if (symbol) {
                        return getDeclarationOfJSPrototypeContainer(symbol);
                    }
                }
                if (host2 && (isObjectLiteralMethod(host2) || isPropertyAssignment(host2)) && isBinaryExpression(host2.parent.parent) && getAssignmentDeclarationKind(host2.parent.parent) === 6 /* Prototype */) {
                    const symbol = getSymbolOfDeclaration(host2.parent.parent.left);
                    if (symbol) {
                        return getDeclarationOfJSPrototypeContainer(symbol);
                    }
                }
                const sig = getEffectiveJSDocHost(node);
                if (sig && isFunctionLike(sig)) {
                    const symbol = getSymbolOfDeclaration(sig);
                    return symbol && symbol.valueDeclaration;
                }
            }
            function getDeclarationOfJSPrototypeContainer(symbol) {
                const decl = symbol.parent.valueDeclaration;
                if (!decl) {
                    return void 0;
                }
                const initializer = isAssignmentDeclaration(decl) ? getAssignedExpandoInitializer(decl) : hasOnlyExpressionInitializer(decl) ? getDeclaredExpandoInitializer(decl) : void 0;
                return initializer || decl;
            }
            function getExpandoSymbol(symbol) {
                const decl = symbol.valueDeclaration;
                if (!decl || !isInJSFile(decl) || symbol.flags & 524288 /* TypeAlias */ || getExpandoInitializer(decl, 
                /*isPrototypeAssignment*/
                false)) {
                    return void 0;
                }
                const init = isVariableDeclaration(decl) ? getDeclaredExpandoInitializer(decl) : getAssignedExpandoInitializer(decl);
                if (init) {
                    const initSymbol = getSymbolOfNode(init);
                    if (initSymbol) {
                        return mergeJSSymbols(initSymbol, symbol);
                    }
                }
            }
            function resolveExternalModuleName(location, moduleReferenceExpression, ignoreErrors) {
                const isClassic = getEmitModuleResolutionKind(compilerOptions) === 1 /* Classic */;
                const errorMessage = isClassic ? Diagnostics.Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_to_the_paths_option : Diagnostics.Cannot_find_module_0_or_its_corresponding_type_declarations;
                return resolveExternalModuleNameWorker(location, moduleReferenceExpression, ignoreErrors ? void 0 : errorMessage);
            }
            function resolveExternalModuleNameWorker(location, moduleReferenceExpression, moduleNotFoundError, isForAugmentation = false) {
                return isStringLiteralLike(moduleReferenceExpression) ? resolveExternalModule(location, moduleReferenceExpression.text, moduleNotFoundError, moduleReferenceExpression, isForAugmentation) : void 0;
            }
            function resolveExternalModule(location, moduleReference, moduleNotFoundError, errorNode, isForAugmentation = false) {
                var _a2, _b, _c, _d, _e, _f, _g, _h, _i;
                if (startsWith(moduleReference, "@types/")) {
                    const diag2 = Diagnostics.Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1;
                    const withoutAtTypePrefix = removePrefix(moduleReference, "@types/");
                    error(errorNode, diag2, withoutAtTypePrefix, moduleReference);
                }
                const ambientModule = tryFindAmbientModule(moduleReference, 
                /*withAugmentations*/
                true);
                if (ambientModule) {
                    return ambientModule;
                }
                const currentSourceFile = getSourceFileOfNode(location);
                const contextSpecifier = isStringLiteralLike(location) ? location : ((_a2 = findAncestor(location, isImportCall)) == null ? void 0 : _a2.arguments[0]) || ((_b = findAncestor(location, isImportDeclaration)) == null ? void 0 : _b.moduleSpecifier) || ((_c = findAncestor(location, isExternalModuleImportEqualsDeclaration)) == null ? void 0 : _c.moduleReference.expression) || ((_d = findAncestor(location, isExportDeclaration)) == null ? void 0 : _d.moduleSpecifier) || ((_e = isModuleDeclaration(location) ? location : location.parent && isModuleDeclaration(location.parent) && location.parent.name === location ? location.parent : void 0) == null ? void 0 : _e.name) || ((_f = isLiteralImportTypeNode(location) ? location : void 0) == null ? void 0 : _f.argument.literal);
                const mode = contextSpecifier && isStringLiteralLike(contextSpecifier) ? getModeForUsageLocation(currentSourceFile, contextSpecifier) : currentSourceFile.impliedNodeFormat;
                const moduleResolutionKind = getEmitModuleResolutionKind(compilerOptions);
                const resolvedModule = getResolvedModule(currentSourceFile, moduleReference, mode);
                const resolutionDiagnostic = resolvedModule && getResolutionDiagnostic(compilerOptions, resolvedModule, currentSourceFile);
                const sourceFile = resolvedModule && (!resolutionDiagnostic || resolutionDiagnostic === Diagnostics.Module_0_was_resolved_to_1_but_jsx_is_not_set) && host.getSourceFile(resolvedModule.resolvedFileName);
                if (sourceFile) {
                    if (resolutionDiagnostic) {
                        error(errorNode, resolutionDiagnostic, moduleReference, resolvedModule.resolvedFileName);
                    }
                    if (resolvedModule.resolvedUsingTsExtension && isDeclarationFileName(moduleReference)) {
                        const importOrExport = ((_g = findAncestor(location, isImportDeclaration)) == null ? void 0 : _g.importClause) || findAncestor(location, or(isImportEqualsDeclaration, isExportDeclaration));
                        if (importOrExport && !importOrExport.isTypeOnly || findAncestor(location, isImportCall)) {
                            error(errorNode, Diagnostics.A_declaration_file_cannot_be_imported_without_import_type_Did_you_mean_to_import_an_implementation_file_0_instead, getSuggestedImportSource(Debug.checkDefined(tryExtractTSExtension(moduleReference))));
                        }
                    }
                    else if (resolvedModule.resolvedUsingTsExtension && !shouldAllowImportingTsExtension(compilerOptions, currentSourceFile.fileName)) {
                        const tsExtension = Debug.checkDefined(tryExtractTSExtension(moduleReference));
                        error(errorNode, Diagnostics.An_import_path_can_only_end_with_a_0_extension_when_allowImportingTsExtensions_is_enabled, tsExtension);
                    }
                    if (sourceFile.symbol) {
                        if (resolvedModule.isExternalLibraryImport && !resolutionExtensionIsTSOrJson(resolvedModule.extension)) {
                            errorOnImplicitAnyModule(
                            /*isError*/
                            false, errorNode, currentSourceFile, mode, resolvedModule, moduleReference);
                        }
                        if (moduleResolutionKind === 3 /* Node16 */ || moduleResolutionKind === 99 /* NodeNext */) {
                            const isSyncImport = currentSourceFile.impliedNodeFormat === 1 /* CommonJS */ && !findAncestor(location, isImportCall) || !!findAncestor(location, isImportEqualsDeclaration);
                            const overrideClauseHost = findAncestor(location, (l) => isImportTypeNode(l) || isExportDeclaration(l) || isImportDeclaration(l));
                            const overrideClause = overrideClauseHost && isImportTypeNode(overrideClauseHost) ? (_h = overrideClauseHost.assertions) == null ? void 0 : _h.assertClause : overrideClauseHost == null ? void 0 : overrideClauseHost.assertClause;
                            if (isSyncImport && sourceFile.impliedNodeFormat === 99 /* ESNext */ && !getResolutionModeOverrideForClause(overrideClause)) {
                                if (findAncestor(location, isImportEqualsDeclaration)) {
                                    error(errorNode, Diagnostics.Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_cannot_be_imported_with_require_Use_an_ECMAScript_import_instead, moduleReference);
                                }
                                else {
                                    let diagnosticDetails;
                                    const ext = tryGetExtensionFromPath2(currentSourceFile.fileName);
                                    if (ext === ".ts" /* Ts */ || ext === ".js" /* Js */ || ext === ".tsx" /* Tsx */ || ext === ".jsx" /* Jsx */) {
                                        const scope = currentSourceFile.packageJsonScope;
                                        const targetExt = ext === ".ts" /* Ts */ ? ".mts" /* Mts */ : ext === ".js" /* Js */ ? ".mjs" /* Mjs */ : void 0;
                                        if (scope && !scope.contents.packageJsonContent.type) {
                                            if (targetExt) {
                                                diagnosticDetails = chainDiagnosticMessages(
                                                /*details*/
                                                void 0, Diagnostics.To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Colon_module_to_1, targetExt, combinePaths(scope.packageDirectory, "package.json"));
                                            }
                                            else {
                                                diagnosticDetails = chainDiagnosticMessages(
                                                /*details*/
                                                void 0, Diagnostics.To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0, combinePaths(scope.packageDirectory, "package.json"));
                                            }
                                        }
                                        else {
                                            if (targetExt) {
                                                diagnosticDetails = chainDiagnosticMessages(
                                                /*details*/
                                                void 0, Diagnostics.To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_package_json_file_with_type_Colon_module, targetExt);
                                            }
                                            else {
                                                diagnosticDetails = chainDiagnosticMessages(
                                                /*details*/
                                                void 0, Diagnostics.To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module);
                                            }
                                        }
                                    }
                                    diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(errorNode), errorNode, chainDiagnosticMessages(diagnosticDetails, Diagnostics.The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_referenced_file_is_an_ECMAScript_module_and_cannot_be_imported_with_require_Consider_writing_a_dynamic_import_0_call_instead, moduleReference)));
                                }
                            }
                        }
                        return getMergedSymbol(sourceFile.symbol);
                    }
                    if (moduleNotFoundError) {
                        error(errorNode, Diagnostics.File_0_is_not_a_module, sourceFile.fileName);
                    }
                    return void 0;
                }
                if (patternAmbientModules) {
                    const pattern = findBestPatternMatch(patternAmbientModules, (_) => _.pattern, moduleReference);
                    if (pattern) {
                        const augmentation = patternAmbientModuleAugmentations && patternAmbientModuleAugmentations.get(moduleReference);
                        if (augmentation) {
                            return getMergedSymbol(augmentation);
                        }
                        return getMergedSymbol(pattern.symbol);
                    }
                }
                if (resolvedModule && !resolutionExtensionIsTSOrJson(resolvedModule.extension) && resolutionDiagnostic === void 0 || resolutionDiagnostic === Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type) {
                    if (isForAugmentation) {
                        const diag2 = Diagnostics.Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augmented;
                        error(errorNode, diag2, moduleReference, resolvedModule.resolvedFileName);
                    }
                    else {
                        errorOnImplicitAnyModule(
                        /*isError*/
                        noImplicitAny && !!moduleNotFoundError, errorNode, currentSourceFile, mode, resolvedModule, moduleReference);
                    }
                    return void 0;
                }
                if (moduleNotFoundError) {
                    if (resolvedModule) {
                        const redirect = host.getProjectReferenceRedirect(resolvedModule.resolvedFileName);
                        if (redirect) {
                            error(errorNode, Diagnostics.Output_file_0_has_not_been_built_from_source_file_1, redirect, resolvedModule.resolvedFileName);
                            return void 0;
                        }
                    }
                    if (resolutionDiagnostic) {
                        error(errorNode, resolutionDiagnostic, moduleReference, resolvedModule.resolvedFileName);
                    }
                    else {
                        const isExtensionlessRelativePathImport = pathIsRelative(moduleReference) && !hasExtension(moduleReference);
                        const resolutionIsNode16OrNext = moduleResolutionKind === 3 /* Node16 */ || moduleResolutionKind === 99 /* NodeNext */;
                        if (!getResolveJsonModule(compilerOptions) && fileExtensionIs(moduleReference, ".json" /* Json */) && moduleResolutionKind !== 1 /* Classic */ && hasJsonModuleEmitEnabled(compilerOptions)) {
                            error(errorNode, Diagnostics.Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension, moduleReference);
                        }
                        else if (mode === 99 /* ESNext */ && resolutionIsNode16OrNext && isExtensionlessRelativePathImport) {
                            const absoluteRef = getNormalizedAbsolutePath(moduleReference, getDirectoryPath(currentSourceFile.path));
                            const suggestedExt = (_i = suggestedExtensions.find(([actualExt, _importExt]) => host.fileExists(absoluteRef + actualExt))) == null ? void 0 : _i[1];
                            if (suggestedExt) {
                                error(errorNode, Diagnostics.Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_node16_or_nodenext_Did_you_mean_0, moduleReference + suggestedExt);
                            }
                            else {
                                error(errorNode, Diagnostics.Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_node16_or_nodenext_Consider_adding_an_extension_to_the_import_path);
                            }
                        }
                        else {
                            error(errorNode, moduleNotFoundError, moduleReference);
                        }
                    }
                }
                return void 0;
                function getSuggestedImportSource(tsExtension) {
                    const importSourceWithoutExtension = removeExtension(moduleReference, tsExtension);
                    if (emitModuleKindIsNonNodeESM(moduleKind) || mode === 99 /* ESNext */) {
                        const preferTs = isDeclarationFileName(moduleReference) && shouldAllowImportingTsExtension(compilerOptions);
                        const ext = tsExtension === ".mts" /* Mts */ || tsExtension === ".d.mts" /* Dmts */ ? preferTs ? ".mts" : ".mjs" : tsExtension === ".cts" /* Cts */ || tsExtension === ".d.mts" /* Dmts */ ? preferTs ? ".cts" : ".cjs" : preferTs ? ".ts" : ".js";
                        return importSourceWithoutExtension + ext;
                    }
                    return importSourceWithoutExtension;
                }
            }
            function errorOnImplicitAnyModule(isError, errorNode, sourceFile, mode, { packageId, resolvedFileName }, moduleReference) {
                var _a2, _b;
                let errorInfo;
                if (!isExternalModuleNameRelative(moduleReference) && packageId) {
                    const node10Result = (_b = (_a2 = sourceFile.resolvedModules) == null ? void 0 : _a2.get(moduleReference, mode)) == null ? void 0 : _b.node10Result;
                    errorInfo = node10Result ? chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics.There_are_types_at_0_but_this_result_could_not_be_resolved_when_respecting_package_json_exports_The_1_library_may_need_to_update_its_package_json_or_typings, node10Result, node10Result.indexOf(nodeModulesPathPart + "@types/") > -1 ? `@types/${mangleScopedPackageName(packageId.name)}` : packageId.name) : typesPackageExists(packageId.name) ? chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics.If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_Slash_Slashgithub_com_SlashDefinitelyTyped_SlashDefinitelyTyped_Slashtree_Slashmaster_Slashtypes_Slash_1, packageId.name, mangleScopedPackageName(packageId.name)) : packageBundlesTypes(packageId.name) ? chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics.If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_declare_module_1, packageId.name, moduleReference) : chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics.Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare_module_0, moduleReference, mangleScopedPackageName(packageId.name));
                }
                errorOrSuggestion(isError, errorNode, chainDiagnosticMessages(errorInfo, Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type, moduleReference, resolvedFileName));
            }
            function typesPackageExists(packageName) {
                return getPackagesMap().has(getTypesPackageName(packageName));
            }
            function packageBundlesTypes(packageName) {
                return !!getPackagesMap().get(packageName);
            }
            function resolveExternalModuleSymbol(moduleSymbol, dontResolveAlias) {
                if (moduleSymbol == null ? void 0 : moduleSymbol.exports) {
                    const exportEquals = resolveSymbol(moduleSymbol.exports.get("export=" /* ExportEquals */), dontResolveAlias);
                    const exported = getCommonJsExportEquals(getMergedSymbol(exportEquals), getMergedSymbol(moduleSymbol));
                    return getMergedSymbol(exported) || moduleSymbol;
                }
                return void 0;
            }
            function getCommonJsExportEquals(exported, moduleSymbol) {
                if (!exported || exported === unknownSymbol || exported === moduleSymbol || moduleSymbol.exports.size === 1 || exported.flags & 2097152 /* Alias */) {
                    return exported;
                }
                const links = getSymbolLinks(exported);
                if (links.cjsExportMerged) {
                    return links.cjsExportMerged;
                }
                const merged = exported.flags & 33554432 /* Transient */ ? exported : cloneSymbol(exported);
                merged.flags = merged.flags | 512 /* ValueModule */;
                if (merged.exports === void 0) {
                    merged.exports = createSymbolTable();
                }
                moduleSymbol.exports.forEach((s, name) => {
                    if (name === "export=" /* ExportEquals */)
                        return;
                    merged.exports.set(name, merged.exports.has(name) ? mergeSymbol(merged.exports.get(name), s) : s);
                });
                getSymbolLinks(merged).cjsExportMerged = merged;
                return links.cjsExportMerged = merged;
            }
            function resolveESModuleSymbol(moduleSymbol, referencingLocation, dontResolveAlias, suppressInteropError) {
                var _a2;
                const symbol = resolveExternalModuleSymbol(moduleSymbol, dontResolveAlias);
                if (!dontResolveAlias && symbol) {
                    if (!suppressInteropError && !(symbol.flags & (1536 /* Module */ | 3 /* Variable */)) && !getDeclarationOfKind(symbol, 308 /* SourceFile */)) {
                        const compilerOptionName = moduleKind >= 5 /* ES2015 */ ? "allowSyntheticDefaultImports" : "esModuleInterop";
                        error(referencingLocation, Diagnostics.This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_referencing_its_default_export, compilerOptionName);
                        return symbol;
                    }
                    const referenceParent = referencingLocation.parent;
                    if (isImportDeclaration(referenceParent) && getNamespaceDeclarationNode(referenceParent) || isImportCall(referenceParent)) {
                        const reference = isImportCall(referenceParent) ? referenceParent.arguments[0] : referenceParent.moduleSpecifier;
                        const type = getTypeOfSymbol(symbol);
                        const defaultOnlyType = getTypeWithSyntheticDefaultOnly(type, symbol, moduleSymbol, reference);
                        if (defaultOnlyType) {
                            return cloneTypeAsModuleType(symbol, defaultOnlyType, referenceParent);
                        }
                        const targetFile = (_a2 = moduleSymbol == null ? void 0 : moduleSymbol.declarations) == null ? void 0 : _a2.find(isSourceFile);
                        const isEsmCjsRef = targetFile && isESMFormatImportImportingCommonjsFormatFile(getUsageModeForExpression(reference), targetFile.impliedNodeFormat);
                        if (getESModuleInterop(compilerOptions) || isEsmCjsRef) {
                            let sigs = getSignaturesOfStructuredType(type, 0 /* Call */);
                            if (!sigs || !sigs.length) {
                                sigs = getSignaturesOfStructuredType(type, 1 /* Construct */);
                            }
                            if (sigs && sigs.length || getPropertyOfType(type, "default" /* Default */, 
                            /*skipObjectFunctionPropertyAugment*/
                            true) || isEsmCjsRef) {
                                const moduleType = getTypeWithSyntheticDefaultImportType(type, symbol, moduleSymbol, reference);
                                return cloneTypeAsModuleType(symbol, moduleType, referenceParent);
                            }
                        }
                    }
                }
                return symbol;
            }
            function cloneTypeAsModuleType(symbol, moduleType, referenceParent) {
                const result = createSymbol(symbol.flags, symbol.escapedName);
                result.declarations = symbol.declarations ? symbol.declarations.slice() : [];
                result.parent = symbol.parent;
                result.links.target = symbol;
                result.links.originatingImport = referenceParent;
                if (symbol.valueDeclaration)
                    result.valueDeclaration = symbol.valueDeclaration;
                if (symbol.constEnumOnlyModule)
                    result.constEnumOnlyModule = true;
                if (symbol.members)
                    result.members = new Map(symbol.members);
                if (symbol.exports)
                    result.exports = new Map(symbol.exports);
                const resolvedModuleType = resolveStructuredTypeMembers(moduleType);
                result.links.type = createAnonymousType(result, resolvedModuleType.members, emptyArray, emptyArray, resolvedModuleType.indexInfos);
                return result;
            }
            function hasExportAssignmentSymbol(moduleSymbol) {
                return moduleSymbol.exports.get("export=" /* ExportEquals */) !== void 0;
            }
            function getExportsOfModuleAsArray(moduleSymbol) {
                return symbolsToArray(getExportsOfModule(moduleSymbol));
            }
            function getExportsAndPropertiesOfModule(moduleSymbol) {
                const exports = getExportsOfModuleAsArray(moduleSymbol);
                const exportEquals = resolveExternalModuleSymbol(moduleSymbol);
                if (exportEquals !== moduleSymbol) {
                    const type = getTypeOfSymbol(exportEquals);
                    if (shouldTreatPropertiesOfExternalModuleAsExports(type)) {
                        addRange(exports, getPropertiesOfType(type));
                    }
                }
                return exports;
            }
            function forEachExportAndPropertyOfModule(moduleSymbol, cb) {
                const exports = getExportsOfModule(moduleSymbol);
                exports.forEach((symbol, key) => {
                    if (!isReservedMemberName(key)) {
                        cb(symbol, key);
                    }
                });
                const exportEquals = resolveExternalModuleSymbol(moduleSymbol);
                if (exportEquals !== moduleSymbol) {
                    const type = getTypeOfSymbol(exportEquals);
                    if (shouldTreatPropertiesOfExternalModuleAsExports(type)) {
                        forEachPropertyOfType(type, (symbol, escapedName) => {
                            cb(symbol, escapedName);
                        });
                    }
                }
            }
            function tryGetMemberInModuleExports(memberName, moduleSymbol) {
                const symbolTable = getExportsOfModule(moduleSymbol);
                if (symbolTable) {
                    return symbolTable.get(memberName);
                }
            }
            function tryGetMemberInModuleExportsAndProperties(memberName, moduleSymbol) {
                const symbol = tryGetMemberInModuleExports(memberName, moduleSymbol);
                if (symbol) {
                    return symbol;
                }
                const exportEquals = resolveExternalModuleSymbol(moduleSymbol);
                if (exportEquals === moduleSymbol) {
                    return void 0;
                }
                const type = getTypeOfSymbol(exportEquals);
                return shouldTreatPropertiesOfExternalModuleAsExports(type) ? getPropertyOfType(type, memberName) : void 0;
            }
            function shouldTreatPropertiesOfExternalModuleAsExports(resolvedExternalModuleType) {
                return !(resolvedExternalModuleType.flags & 134348796 /* Primitive */ || getObjectFlags(resolvedExternalModuleType) & 1 /* Class */ || // `isArrayOrTupleLikeType` is too expensive to use in this auto-imports hot path
                    isArrayType(resolvedExternalModuleType) || isTupleType(resolvedExternalModuleType));
            }
            function getExportsOfSymbol(symbol) {
                return symbol.flags & 6256 /* LateBindingContainer */ ? getResolvedMembersOrExportsOfSymbol(symbol, "resolvedExports" /* resolvedExports */) : symbol.flags & 1536 /* Module */ ? getExportsOfModule(symbol) : symbol.exports || emptySymbols;
            }
            function getExportsOfModule(moduleSymbol) {
                const links = getSymbolLinks(moduleSymbol);
                if (!links.resolvedExports) {
                    const { exports, typeOnlyExportStarMap } = getExportsOfModuleWorker(moduleSymbol);
                    links.resolvedExports = exports;
                    links.typeOnlyExportStarMap = typeOnlyExportStarMap;
                }
                return links.resolvedExports;
            }
            function extendExportSymbols(target, source, lookupTable, exportNode) {
                if (!source)
                    return;
                source.forEach((sourceSymbol, id) => {
                    if (id === "default" /* Default */)
                        return;
                    const targetSymbol = target.get(id);
                    if (!targetSymbol) {
                        target.set(id, sourceSymbol);
                        if (lookupTable && exportNode) {
                            lookupTable.set(id, {
                                specifierText: getTextOfNode(exportNode.moduleSpecifier)
                            });
                        }
                    }
                    else if (lookupTable && exportNode && targetSymbol && resolveSymbol(targetSymbol) !== resolveSymbol(sourceSymbol)) {
                        const collisionTracker = lookupTable.get(id);
                        if (!collisionTracker.exportsWithDuplicate) {
                            collisionTracker.exportsWithDuplicate = [exportNode];
                        }
                        else {
                            collisionTracker.exportsWithDuplicate.push(exportNode);
                        }
                    }
                });
            }
            function getExportsOfModuleWorker(moduleSymbol) {
                const visitedSymbols = [];
                let typeOnlyExportStarMap;
                const nonTypeOnlyNames = /* @__PURE__ */ new Set();
                moduleSymbol = resolveExternalModuleSymbol(moduleSymbol);
                const exports = visit(moduleSymbol) || emptySymbols;
                if (typeOnlyExportStarMap) {
                    nonTypeOnlyNames.forEach((name) => typeOnlyExportStarMap.delete(name));
                }
                return {
                    exports,
                    typeOnlyExportStarMap
                };
                function visit(symbol, exportStar, isTypeOnly) {
                    if (!isTypeOnly && (symbol == null ? void 0 : symbol.exports)) {
                        symbol.exports.forEach((_, name) => nonTypeOnlyNames.add(name));
                    }
                    if (!(symbol && symbol.exports && pushIfUnique(visitedSymbols, symbol))) {
                        return;
                    }
                    const symbols = new Map(symbol.exports);
                    const exportStars = symbol.exports.get("__export" /* ExportStar */);
                    if (exportStars) {
                        const nestedSymbols = createSymbolTable();
                        const lookupTable = /* @__PURE__ */ new Map();
                        if (exportStars.declarations) {
                            for (const node of exportStars.declarations) {
                                const resolvedModule = resolveExternalModuleName(node, node.moduleSpecifier);
                                const exportedSymbols = visit(resolvedModule, node, isTypeOnly || node.isTypeOnly);
                                extendExportSymbols(nestedSymbols, exportedSymbols, lookupTable, node);
                            }
                        }
                        lookupTable.forEach(({ exportsWithDuplicate }, id) => {
                            if (id === "export=" || !(exportsWithDuplicate && exportsWithDuplicate.length) || symbols.has(id)) {
                                return;
                            }
                            for (const node of exportsWithDuplicate) {
                                diagnostics.add(createDiagnosticForNode(node, Diagnostics.Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity, lookupTable.get(id).specifierText, unescapeLeadingUnderscores(id)));
                            }
                        });
                        extendExportSymbols(symbols, nestedSymbols);
                    }
                    if (exportStar == null ? void 0 : exportStar.isTypeOnly) {
                        typeOnlyExportStarMap != null ? typeOnlyExportStarMap : typeOnlyExportStarMap = /* @__PURE__ */ new Map();
                        symbols.forEach((_, escapedName) => typeOnlyExportStarMap.set(escapedName, exportStar));
                    }
                    return symbols;
                }
            }
            function getMergedSymbol(symbol) {
                let merged;
                return symbol && symbol.mergeId && (merged = mergedSymbols[symbol.mergeId]) ? merged : symbol;
            }
            function getSymbolOfDeclaration(node) {
                return getMergedSymbol(node.symbol && getLateBoundSymbol(node.symbol));
            }
            function getSymbolOfNode(node) {
                return canHaveSymbol(node) ? getSymbolOfDeclaration(node) : void 0;
            }
            function getParentOfSymbol(symbol) {
                return getMergedSymbol(symbol.parent && getLateBoundSymbol(symbol.parent));
            }
            function getAlternativeContainingModules(symbol, enclosingDeclaration) {
                const containingFile = getSourceFileOfNode(enclosingDeclaration);
                const id = getNodeId(containingFile);
                const links = getSymbolLinks(symbol);
                let results;
                if (links.extendedContainersByFile && (results = links.extendedContainersByFile.get(id))) {
                    return results;
                }
                if (containingFile && containingFile.imports) {
                    for (const importRef of containingFile.imports) {
                        if (nodeIsSynthesized(importRef))
                            continue;
                        const resolvedModule = resolveExternalModuleName(enclosingDeclaration, importRef, 
                        /*ignoreErrors*/
                        true);
                        if (!resolvedModule)
                            continue;
                        const ref = getAliasForSymbolInContainer(resolvedModule, symbol);
                        if (!ref)
                            continue;
                        results = append(results, resolvedModule);
                    }
                    if (length(results)) {
                        (links.extendedContainersByFile || (links.extendedContainersByFile = /* @__PURE__ */ new Map())).set(id, results);
                        return results;
                    }
                }
                if (links.extendedContainers) {
                    return links.extendedContainers;
                }
                const otherFiles = host.getSourceFiles();
                for (const file of otherFiles) {
                    if (!isExternalModule(file))
                        continue;
                    const sym = getSymbolOfDeclaration(file);
                    const ref = getAliasForSymbolInContainer(sym, symbol);
                    if (!ref)
                        continue;
                    results = append(results, sym);
                }
                return links.extendedContainers = results || emptyArray;
            }
            function getContainersOfSymbol(symbol, enclosingDeclaration, meaning) {
                const container = getParentOfSymbol(symbol);
                if (container && !(symbol.flags & 262144 /* TypeParameter */)) {
                    const additionalContainers = mapDefined(container.declarations, fileSymbolIfFileSymbolExportEqualsContainer);
                    const reexportContainers = enclosingDeclaration && getAlternativeContainingModules(symbol, enclosingDeclaration);
                    const objectLiteralContainer = getVariableDeclarationOfObjectLiteral(container, meaning);
                    if (enclosingDeclaration && container.flags & getQualifiedLeftMeaning(meaning) && getAccessibleSymbolChain(container, enclosingDeclaration, 1920 /* Namespace */, 
                    /*externalOnly*/
                    false)) {
                        return append(concatenate(concatenate([container], additionalContainers), reexportContainers), objectLiteralContainer);
                    }
                    const firstVariableMatch = !(container.flags & getQualifiedLeftMeaning(meaning)) && container.flags & 788968 /* Type */ && getDeclaredTypeOfSymbol(container).flags & 524288 /* Object */ && meaning === 111551 /* Value */ ? forEachSymbolTableInScope(enclosingDeclaration, (t) => {
                        return forEachEntry(t, (s) => {
                            if (s.flags & getQualifiedLeftMeaning(meaning) && getTypeOfSymbol(s) === getDeclaredTypeOfSymbol(container)) {
                                return s;
                            }
                        });
                    }) : void 0;
                    let res = firstVariableMatch ? [firstVariableMatch, ...additionalContainers, container] : [...additionalContainers, container];
                    res = append(res, objectLiteralContainer);
                    res = addRange(res, reexportContainers);
                    return res;
                }
                const candidates = mapDefined(symbol.declarations, (d) => {
                    if (!isAmbientModule(d) && d.parent) {
                        if (hasNonGlobalAugmentationExternalModuleSymbol(d.parent)) {
                            return getSymbolOfDeclaration(d.parent);
                        }
                        if (isModuleBlock(d.parent) && d.parent.parent && resolveExternalModuleSymbol(getSymbolOfDeclaration(d.parent.parent)) === symbol) {
                            return getSymbolOfDeclaration(d.parent.parent);
                        }
                    }
                    if (isClassExpression(d) && isBinaryExpression(d.parent) && d.parent.operatorToken.kind === 63 /* EqualsToken */ && isAccessExpression(d.parent.left) && isEntityNameExpression(d.parent.left.expression)) {
                        if (isModuleExportsAccessExpression(d.parent.left) || isExportsIdentifier(d.parent.left.expression)) {
                            return getSymbolOfDeclaration(getSourceFileOfNode(d));
                        }
                        checkExpressionCached(d.parent.left.expression);
                        return getNodeLinks(d.parent.left.expression).resolvedSymbol;
                    }
                });
                if (!length(candidates)) {
                    return void 0;
                }
                return mapDefined(candidates, (candidate) => getAliasForSymbolInContainer(candidate, symbol) ? candidate : void 0);
                function fileSymbolIfFileSymbolExportEqualsContainer(d) {
                    return container && getFileSymbolIfFileSymbolExportEqualsContainer(d, container);
                }
            }
            function getVariableDeclarationOfObjectLiteral(symbol, meaning) {
                const firstDecl = !!length(symbol.declarations) && first(symbol.declarations);
                if (meaning & 111551 /* Value */ && firstDecl && firstDecl.parent && isVariableDeclaration(firstDecl.parent)) {
                    if (isObjectLiteralExpression(firstDecl) && firstDecl === firstDecl.parent.initializer || isTypeLiteralNode(firstDecl) && firstDecl === firstDecl.parent.type) {
                        return getSymbolOfDeclaration(firstDecl.parent);
                    }
                }
            }
            function getFileSymbolIfFileSymbolExportEqualsContainer(d, container) {
                const fileSymbol = getExternalModuleContainer(d);
                const exported = fileSymbol && fileSymbol.exports && fileSymbol.exports.get("export=" /* ExportEquals */);
                return exported && getSymbolIfSameReference(exported, container) ? fileSymbol : void 0;
            }
            function getAliasForSymbolInContainer(container, symbol) {
                if (container === getParentOfSymbol(symbol)) {
                    return symbol;
                }
                const exportEquals = container.exports && container.exports.get("export=" /* ExportEquals */);
                if (exportEquals && getSymbolIfSameReference(exportEquals, symbol)) {
                    return container;
                }
                const exports = getExportsOfSymbol(container);
                const quick = exports.get(symbol.escapedName);
                if (quick && getSymbolIfSameReference(quick, symbol)) {
                    return quick;
                }
                return forEachEntry(exports, (exported) => {
                    if (getSymbolIfSameReference(exported, symbol)) {
                        return exported;
                    }
                });
            }
            function getSymbolIfSameReference(s1, s2) {
                if (getMergedSymbol(resolveSymbol(getMergedSymbol(s1))) === getMergedSymbol(resolveSymbol(getMergedSymbol(s2)))) {
                    return s1;
                }
            }
            function getExportSymbolOfValueSymbolIfExported(symbol) {
                return getMergedSymbol(symbol && (symbol.flags & 1048576 /* ExportValue */) !== 0 && symbol.exportSymbol || symbol);
            }
            function symbolIsValue(symbol, includeTypeOnlyMembers) {
                return !!(symbol.flags & 111551 /* Value */ || symbol.flags & 2097152 /* Alias */ && getAllSymbolFlags(symbol) & 111551 /* Value */ && (includeTypeOnlyMembers || !getTypeOnlyAliasDeclaration(symbol)));
            }
            function findConstructorDeclaration(node) {
                const members = node.members;
                for (const member of members) {
                    if (member.kind === 173 /* Constructor */ && nodeIsPresent(member.body)) {
                        return member;
                    }
                }
            }
            function createType(flags) {
                var _a2;
                const result = new Type27(checker, flags);
                typeCount++;
                result.id = typeCount;
                (_a2 = tracing) == null ? void 0 : _a2.recordType(result);
                return result;
            }
            function createTypeWithSymbol(flags, symbol) {
                const result = createType(flags);
                result.symbol = symbol;
                return result;
            }
            function createOriginType(flags) {
                return new Type27(checker, flags);
            }
            function createIntrinsicType(kind, intrinsicName, objectFlags = 0 /* None */) {
                const type = createType(kind);
                type.intrinsicName = intrinsicName;
                type.objectFlags = objectFlags;
                return type;
            }
            function createObjectType(objectFlags, symbol) {
                const type = createTypeWithSymbol(524288 /* Object */, symbol);
                type.objectFlags = objectFlags;
                type.members = void 0;
                type.properties = void 0;
                type.callSignatures = void 0;
                type.constructSignatures = void 0;
                type.indexInfos = void 0;
                return type;
            }
            function createTypeofType() {
                return getUnionType(arrayFrom(typeofNEFacts.keys(), getStringLiteralType));
            }
            function createTypeParameter(symbol) {
                return createTypeWithSymbol(262144 /* TypeParameter */, symbol);
            }
            function isReservedMemberName(name) {
                return name.charCodeAt(0) === 95 /* _ */ && name.charCodeAt(1) === 95 /* _ */ && name.charCodeAt(2) !== 95 /* _ */ && name.charCodeAt(2) !== 64 /* at */ && name.charCodeAt(2) !== 35 /* hash */;
            }
            function getNamedMembers(members) {
                let result;
                members.forEach((symbol, id) => {
                    if (isNamedMember(symbol, id)) {
                        (result || (result = [])).push(symbol);
                    }
                });
                return result || emptyArray;
            }
            function isNamedMember(member, escapedName) {
                return !isReservedMemberName(escapedName) && symbolIsValue(member);
            }
            function getNamedOrIndexSignatureMembers(members) {
                const result = getNamedMembers(members);
                const index = getIndexSymbolFromSymbolTable(members);
                return index ? concatenate(result, [index]) : result;
            }
            function setStructuredTypeMembers(type, members, callSignatures, constructSignatures, indexInfos) {
                const resolved = type;
                resolved.members = members;
                resolved.properties = emptyArray;
                resolved.callSignatures = callSignatures;
                resolved.constructSignatures = constructSignatures;
                resolved.indexInfos = indexInfos;
                if (members !== emptySymbols)
                    resolved.properties = getNamedMembers(members);
                return resolved;
            }
            function createAnonymousType(symbol, members, callSignatures, constructSignatures, indexInfos) {
                return setStructuredTypeMembers(createObjectType(16 /* Anonymous */, symbol), members, callSignatures, constructSignatures, indexInfos);
            }
            function getResolvedTypeWithoutAbstractConstructSignatures(type) {
                if (type.constructSignatures.length === 0)
                    return type;
                if (type.objectTypeWithoutAbstractConstructSignatures)
                    return type.objectTypeWithoutAbstractConstructSignatures;
                const constructSignatures = filter(type.constructSignatures, (signature) => !(signature.flags & 4 /* Abstract */));
                if (type.constructSignatures === constructSignatures)
                    return type;
                const typeCopy = createAnonymousType(type.symbol, type.members, type.callSignatures, some(constructSignatures) ? constructSignatures : emptyArray, type.indexInfos);
                type.objectTypeWithoutAbstractConstructSignatures = typeCopy;
                typeCopy.objectTypeWithoutAbstractConstructSignatures = typeCopy;
                return typeCopy;
            }
            function forEachSymbolTableInScope(enclosingDeclaration, callback) {
                let result;
                for (let location = enclosingDeclaration; location; location = location.parent) {
                    if (canHaveLocals(location) && location.locals && !isGlobalSourceFile(location)) {
                        if (result = callback(location.locals, 
                        /*ignoreQualification*/
                        void 0, 
                        /*isLocalNameLookup*/
                        true, location)) {
                            return result;
                        }
                    }
                    switch (location.kind) {
                        case 308 /* SourceFile */:
                            if (!isExternalOrCommonJsModule(location)) {
                                break;
                            }
                        case 264 /* ModuleDeclaration */:
                            const sym = getSymbolOfDeclaration(location);
                            if (result = callback((sym == null ? void 0 : sym.exports) || emptySymbols, 
                            /*ignoreQualification*/
                            void 0, 
                            /*isLocalNameLookup*/
                            true, location)) {
                                return result;
                            }
                            break;
                        case 260 /* ClassDeclaration */:
                        case 228 /* ClassExpression */:
                        case 261 /* InterfaceDeclaration */:
                            let table;
                            (getSymbolOfDeclaration(location).members || emptySymbols).forEach((memberSymbol, key) => {
                                if (memberSymbol.flags & (788968 /* Type */ & ~67108864 /* Assignment */)) {
                                    (table || (table = createSymbolTable())).set(key, memberSymbol);
                                }
                            });
                            if (table && (result = callback(table, 
                            /*ignoreQualification*/
                            void 0, 
                            /*isLocalNameLookup*/
                            false, location))) {
                                return result;
                            }
                            break;
                    }
                }
                return callback(globals, 
                /*ignoreQualification*/
                void 0, 
                /*isLocalNameLookup*/
                true);
            }
            function getQualifiedLeftMeaning(rightMeaning) {
                return rightMeaning === 111551 /* Value */ ? 111551 /* Value */ : 1920 /* Namespace */;
            }
            function getAccessibleSymbolChain(symbol, enclosingDeclaration, meaning, useOnlyExternalAliasing, visitedSymbolTablesMap = /* @__PURE__ */ new Map()) {
                if (!(symbol && !isPropertyOrMethodDeclarationSymbol(symbol))) {
                    return void 0;
                }
                const links = getSymbolLinks(symbol);
                const cache = links.accessibleChainCache || (links.accessibleChainCache = /* @__PURE__ */ new Map());
                const firstRelevantLocation = forEachSymbolTableInScope(enclosingDeclaration, (_, __, ___, node) => node);
                const key = `${useOnlyExternalAliasing ? 0 : 1}|${firstRelevantLocation && getNodeId(firstRelevantLocation)}|${meaning}`;
                if (cache.has(key)) {
                    return cache.get(key);
                }
                const id = getSymbolId(symbol);
                let visitedSymbolTables = visitedSymbolTablesMap.get(id);
                if (!visitedSymbolTables) {
                    visitedSymbolTablesMap.set(id, visitedSymbolTables = []);
                }
                const result = forEachSymbolTableInScope(enclosingDeclaration, getAccessibleSymbolChainFromSymbolTable);
                cache.set(key, result);
                return result;
                function getAccessibleSymbolChainFromSymbolTable(symbols, ignoreQualification, isLocalNameLookup) {
                    if (!pushIfUnique(visitedSymbolTables, symbols)) {
                        return void 0;
                    }
                    const result2 = trySymbolTable(symbols, ignoreQualification, isLocalNameLookup);
                    visitedSymbolTables.pop();
                    return result2;
                }
                function canQualifySymbol(symbolFromSymbolTable, meaning2) {
                    return !needsQualification(symbolFromSymbolTable, enclosingDeclaration, meaning2) || // If symbol needs qualification, make sure that parent is accessible, if it is then this symbol is accessible too
                        !!getAccessibleSymbolChain(symbolFromSymbolTable.parent, enclosingDeclaration, getQualifiedLeftMeaning(meaning2), useOnlyExternalAliasing, visitedSymbolTablesMap);
                }
                function isAccessible(symbolFromSymbolTable, resolvedAliasSymbol, ignoreQualification) {
                    return (symbol === (resolvedAliasSymbol || symbolFromSymbolTable) || getMergedSymbol(symbol) === getMergedSymbol(resolvedAliasSymbol || symbolFromSymbolTable)) && // if the symbolFromSymbolTable is not external module (it could be if it was determined as ambient external module and would be in globals table)
                        // and if symbolFromSymbolTable or alias resolution matches the symbol,
                        // check the symbol can be qualified, it is only then this symbol is accessible
                        !some(symbolFromSymbolTable.declarations, hasNonGlobalAugmentationExternalModuleSymbol) && (ignoreQualification || canQualifySymbol(getMergedSymbol(symbolFromSymbolTable), meaning));
                }
                function trySymbolTable(symbols, ignoreQualification, isLocalNameLookup) {
                    if (isAccessible(symbols.get(symbol.escapedName), 
                    /*resolvedAliasSymbol*/
                    void 0, ignoreQualification)) {
                        return [symbol];
                    }
                    const result2 = forEachEntry(symbols, (symbolFromSymbolTable) => {
                        if (symbolFromSymbolTable.flags & 2097152 /* Alias */ && symbolFromSymbolTable.escapedName !== "export=" /* ExportEquals */ && symbolFromSymbolTable.escapedName !== "default" /* Default */ && !(isUMDExportSymbol(symbolFromSymbolTable) && enclosingDeclaration && isExternalModule(getSourceFileOfNode(enclosingDeclaration))) && (!useOnlyExternalAliasing || some(symbolFromSymbolTable.declarations, isExternalModuleImportEqualsDeclaration)) && (isLocalNameLookup ? !some(symbolFromSymbolTable.declarations, isNamespaceReexportDeclaration) : true) && (ignoreQualification || !getDeclarationOfKind(symbolFromSymbolTable, 278 /* ExportSpecifier */))) {
                            const resolvedImportedSymbol = resolveAlias(symbolFromSymbolTable);
                            const candidate = getCandidateListForSymbol(symbolFromSymbolTable, resolvedImportedSymbol, ignoreQualification);
                            if (candidate) {
                                return candidate;
                            }
                        }
                        if (symbolFromSymbolTable.escapedName === symbol.escapedName && symbolFromSymbolTable.exportSymbol) {
                            if (isAccessible(getMergedSymbol(symbolFromSymbolTable.exportSymbol), 
                            /*aliasSymbol*/
                            void 0, ignoreQualification)) {
                                return [symbol];
                            }
                        }
                    });
                    return result2 || (symbols === globals ? getCandidateListForSymbol(globalThisSymbol, globalThisSymbol, ignoreQualification) : void 0);
                }
                function getCandidateListForSymbol(symbolFromSymbolTable, resolvedImportedSymbol, ignoreQualification) {
                    if (isAccessible(symbolFromSymbolTable, resolvedImportedSymbol, ignoreQualification)) {
                        return [symbolFromSymbolTable];
                    }
                    const candidateTable = getExportsOfSymbol(resolvedImportedSymbol);
                    const accessibleSymbolsFromExports = candidateTable && getAccessibleSymbolChainFromSymbolTable(candidateTable, 
                    /*ignoreQualification*/
                    true);
                    if (accessibleSymbolsFromExports && canQualifySymbol(symbolFromSymbolTable, getQualifiedLeftMeaning(meaning))) {
                        return [symbolFromSymbolTable].concat(accessibleSymbolsFromExports);
                    }
                }
            }
            function needsQualification(symbol, enclosingDeclaration, meaning) {
                let qualify = false;
                forEachSymbolTableInScope(enclosingDeclaration, (symbolTable) => {
                    let symbolFromSymbolTable = getMergedSymbol(symbolTable.get(symbol.escapedName));
                    if (!symbolFromSymbolTable) {
                        return false;
                    }
                    if (symbolFromSymbolTable === symbol) {
                        return true;
                    }
                    const shouldResolveAlias = symbolFromSymbolTable.flags & 2097152 /* Alias */ && !getDeclarationOfKind(symbolFromSymbolTable, 278 /* ExportSpecifier */);
                    symbolFromSymbolTable = shouldResolveAlias ? resolveAlias(symbolFromSymbolTable) : symbolFromSymbolTable;
                    const flags = shouldResolveAlias ? getAllSymbolFlags(symbolFromSymbolTable) : symbolFromSymbolTable.flags;
                    if (flags & meaning) {
                        qualify = true;
                        return true;
                    }
                    return false;
                });
                return qualify;
            }
            function isPropertyOrMethodDeclarationSymbol(symbol) {
                if (symbol.declarations && symbol.declarations.length) {
                    for (const declaration of symbol.declarations) {
                        switch (declaration.kind) {
                            case 169 /* PropertyDeclaration */:
                            case 171 /* MethodDeclaration */:
                            case 174 /* GetAccessor */:
                            case 175 /* SetAccessor */:
                                continue;
                            default:
                                return false;
                        }
                    }
                    return true;
                }
                return false;
            }
            function isTypeSymbolAccessible(typeSymbol, enclosingDeclaration) {
                const access = isSymbolAccessibleWorker(typeSymbol, enclosingDeclaration, 788968 /* Type */, 
                /*shouldComputeAliasesToMakeVisible*/
                false, 
                /*allowModules*/
                true);
                return access.accessibility === 0 /* Accessible */;
            }
            function isValueSymbolAccessible(typeSymbol, enclosingDeclaration) {
                const access = isSymbolAccessibleWorker(typeSymbol, enclosingDeclaration, 111551 /* Value */, 
                /*shouldComputeAliasesToMakeVisible*/
                false, 
                /*allowModules*/
                true);
                return access.accessibility === 0 /* Accessible */;
            }
            function isSymbolAccessibleByFlags(typeSymbol, enclosingDeclaration, flags) {
                const access = isSymbolAccessibleWorker(typeSymbol, enclosingDeclaration, flags, 
                /*shouldComputeAliasesToMakeVisible*/
                false, 
                /*allowModules*/
                false);
                return access.accessibility === 0 /* Accessible */;
            }
            function isAnySymbolAccessible(symbols, enclosingDeclaration, initialSymbol, meaning, shouldComputeAliasesToMakeVisible, allowModules) {
                if (!length(symbols))
                    return;
                let hadAccessibleChain;
                let earlyModuleBail = false;
                for (const symbol of symbols) {
                    const accessibleSymbolChain = getAccessibleSymbolChain(symbol, enclosingDeclaration, meaning, 
                    /*useOnlyExternalAliasing*/
                    false);
                    if (accessibleSymbolChain) {
                        hadAccessibleChain = symbol;
                        const hasAccessibleDeclarations = hasVisibleDeclarations(accessibleSymbolChain[0], shouldComputeAliasesToMakeVisible);
                        if (hasAccessibleDeclarations) {
                            return hasAccessibleDeclarations;
                        }
                    }
                    if (allowModules) {
                        if (some(symbol.declarations, hasNonGlobalAugmentationExternalModuleSymbol)) {
                            if (shouldComputeAliasesToMakeVisible) {
                                earlyModuleBail = true;
                                continue;
                            }
                            return {
                                accessibility: 0 /* Accessible */
                            };
                        }
                    }
                    const containers = getContainersOfSymbol(symbol, enclosingDeclaration, meaning);
                    const parentResult = isAnySymbolAccessible(containers, enclosingDeclaration, initialSymbol, initialSymbol === symbol ? getQualifiedLeftMeaning(meaning) : meaning, shouldComputeAliasesToMakeVisible, allowModules);
                    if (parentResult) {
                        return parentResult;
                    }
                }
                if (earlyModuleBail) {
                    return {
                        accessibility: 0 /* Accessible */
                    };
                }
                if (hadAccessibleChain) {
                    return {
                        accessibility: 1 /* NotAccessible */,
                        errorSymbolName: symbolToString(initialSymbol, enclosingDeclaration, meaning),
                        errorModuleName: hadAccessibleChain !== initialSymbol ? symbolToString(hadAccessibleChain, enclosingDeclaration, 1920 /* Namespace */) : void 0
                    };
                }
            }
            function isSymbolAccessible(symbol, enclosingDeclaration, meaning, shouldComputeAliasesToMakeVisible) {
                return isSymbolAccessibleWorker(symbol, enclosingDeclaration, meaning, shouldComputeAliasesToMakeVisible, 
                /*allowModules*/
                true);
            }
            function isSymbolAccessibleWorker(symbol, enclosingDeclaration, meaning, shouldComputeAliasesToMakeVisible, allowModules) {
                if (symbol && enclosingDeclaration) {
                    const result = isAnySymbolAccessible([symbol], enclosingDeclaration, symbol, meaning, shouldComputeAliasesToMakeVisible, allowModules);
                    if (result) {
                        return result;
                    }
                    const symbolExternalModule = forEach(symbol.declarations, getExternalModuleContainer);
                    if (symbolExternalModule) {
                        const enclosingExternalModule = getExternalModuleContainer(enclosingDeclaration);
                        if (symbolExternalModule !== enclosingExternalModule) {
                            return {
                                accessibility: 2 /* CannotBeNamed */,
                                errorSymbolName: symbolToString(symbol, enclosingDeclaration, meaning),
                                errorModuleName: symbolToString(symbolExternalModule),
                                errorNode: isInJSFile(enclosingDeclaration) ? enclosingDeclaration : void 0
                            };
                        }
                    }
                    return {
                        accessibility: 1 /* NotAccessible */,
                        errorSymbolName: symbolToString(symbol, enclosingDeclaration, meaning)
                    };
                }
                return { accessibility: 0 /* Accessible */ };
            }
            function getExternalModuleContainer(declaration) {
                const node = findAncestor(declaration, hasExternalModuleSymbol);
                return node && getSymbolOfDeclaration(node);
            }
            function hasExternalModuleSymbol(declaration) {
                return isAmbientModule(declaration) || declaration.kind === 308 /* SourceFile */ && isExternalOrCommonJsModule(declaration);
            }
            function hasNonGlobalAugmentationExternalModuleSymbol(declaration) {
                return isModuleWithStringLiteralName(declaration) || declaration.kind === 308 /* SourceFile */ && isExternalOrCommonJsModule(declaration);
            }
            function hasVisibleDeclarations(symbol, shouldComputeAliasToMakeVisible) {
                let aliasesToMakeVisible;
                if (!every(filter(symbol.declarations, (d) => d.kind !== 79 /* Identifier */), getIsDeclarationVisible)) {
                    return void 0;
                }
                return { accessibility: 0 /* Accessible */, aliasesToMakeVisible };
                function getIsDeclarationVisible(declaration) {
                    var _a2, _b;
                    if (!isDeclarationVisible(declaration)) {
                        const anyImportSyntax = getAnyImportSyntax(declaration);
                        if (anyImportSyntax && !hasSyntacticModifier(anyImportSyntax, 1 /* Export */) && // import clause without export
                            isDeclarationVisible(anyImportSyntax.parent)) {
                            return addVisibleAlias(declaration, anyImportSyntax);
                        }
                        else if (isVariableDeclaration(declaration) && isVariableStatement(declaration.parent.parent) && !hasSyntacticModifier(declaration.parent.parent, 1 /* Export */) && // unexported variable statement
                            isDeclarationVisible(declaration.parent.parent.parent)) {
                            return addVisibleAlias(declaration, declaration.parent.parent);
                        }
                        else if (isLateVisibilityPaintedStatement(declaration) && !hasSyntacticModifier(declaration, 1 /* Export */) && isDeclarationVisible(declaration.parent)) {
                            return addVisibleAlias(declaration, declaration);
                        }
                        else if (isBindingElement(declaration)) {
                            if (symbol.flags & 2097152 /* Alias */ && isInJSFile(declaration) && ((_a2 = declaration.parent) == null ? void 0 : _a2.parent) && isVariableDeclaration(declaration.parent.parent) && ((_b = declaration.parent.parent.parent) == null ? void 0 : _b.parent) && isVariableStatement(declaration.parent.parent.parent.parent) && !hasSyntacticModifier(declaration.parent.parent.parent.parent, 1 /* Export */) && declaration.parent.parent.parent.parent.parent && isDeclarationVisible(declaration.parent.parent.parent.parent.parent)) {
                                return addVisibleAlias(declaration, declaration.parent.parent.parent.parent);
                            }
                            else if (symbol.flags & 2 /* BlockScopedVariable */) {
                                const variableStatement = findAncestor(declaration, isVariableStatement);
                                if (hasSyntacticModifier(variableStatement, 1 /* Export */)) {
                                    return true;
                                }
                                if (!isDeclarationVisible(variableStatement.parent)) {
                                    return false;
                                }
                                return addVisibleAlias(declaration, variableStatement);
                            }
                        }
                        return false;
                    }
                    return true;
                }
                function addVisibleAlias(declaration, aliasingStatement) {
                    if (shouldComputeAliasToMakeVisible) {
                        getNodeLinks(declaration).isVisible = true;
                        aliasesToMakeVisible = appendIfUnique(aliasesToMakeVisible, aliasingStatement);
                    }
                    return true;
                }
            }
            function isEntityNameVisible(entityName, enclosingDeclaration) {
                let meaning;
                if (entityName.parent.kind === 183 /* TypeQuery */ || entityName.parent.kind === 230 /* ExpressionWithTypeArguments */ && !isPartOfTypeNode(entityName.parent) || entityName.parent.kind === 164 /* ComputedPropertyName */) {
                    meaning = 111551 /* Value */ | 1048576 /* ExportValue */;
                }
                else if (entityName.kind === 163 /* QualifiedName */ || entityName.kind === 208 /* PropertyAccessExpression */ || entityName.parent.kind === 268 /* ImportEqualsDeclaration */) {
                    meaning = 1920 /* Namespace */;
                }
                else {
                    meaning = 788968 /* Type */;
                }
                const firstIdentifier = getFirstIdentifier(entityName);
                const symbol = resolveName(enclosingDeclaration, firstIdentifier.escapedText, meaning, 
                /*nodeNotFoundErrorMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                false);
                if (symbol && symbol.flags & 262144 /* TypeParameter */ && meaning & 788968 /* Type */) {
                    return { accessibility: 0 /* Accessible */ };
                }
                if (!symbol && isThisIdentifier(firstIdentifier) && isSymbolAccessible(getSymbolOfDeclaration(getThisContainer(firstIdentifier, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false)), firstIdentifier, meaning, 
                /*computeAliases*/
                false).accessibility === 0 /* Accessible */) {
                    return { accessibility: 0 /* Accessible */ };
                }
                return symbol && hasVisibleDeclarations(symbol, 
                /*shouldComputeAliasToMakeVisible*/
                true) || {
                    accessibility: 1 /* NotAccessible */,
                    errorSymbolName: getTextOfNode(firstIdentifier),
                    errorNode: firstIdentifier
                };
            }
            function symbolToString(symbol, enclosingDeclaration, meaning, flags = 4 /* AllowAnyNodeKind */, writer) {
                let nodeFlags = 70221824 /* IgnoreErrors */;
                if (flags & 2 /* UseOnlyExternalAliasing */) {
                    nodeFlags |= 128 /* UseOnlyExternalAliasing */;
                }
                if (flags & 1 /* WriteTypeParametersOrArguments */) {
                    nodeFlags |= 512 /* WriteTypeParametersInQualifiedName */;
                }
                if (flags & 8 /* UseAliasDefinedOutsideCurrentScope */) {
                    nodeFlags |= 16384 /* UseAliasDefinedOutsideCurrentScope */;
                }
                if (flags & 32 /* DoNotIncludeSymbolChain */) {
                    nodeFlags |= 134217728 /* DoNotIncludeSymbolChain */;
                }
                if (flags & 16 /* WriteComputedProps */) {
                    nodeFlags |= 1073741824 /* WriteComputedProps */;
                }
                const builder = flags & 4 /* AllowAnyNodeKind */ ? nodeBuilder.symbolToNode : nodeBuilder.symbolToEntityName;
                return writer ? symbolToStringWorker(writer).getText() : usingSingleLineStringWriter(symbolToStringWorker);
                function symbolToStringWorker(writer2) {
                    const entity = builder(symbol, meaning, enclosingDeclaration, nodeFlags);
                    const printer = (enclosingDeclaration == null ? void 0 : enclosingDeclaration.kind) === 308 /* SourceFile */ ? createPrinterWithRemoveCommentsNeverAsciiEscape() : createPrinterWithRemoveComments();
                    const sourceFile = enclosingDeclaration && getSourceFileOfNode(enclosingDeclaration);
                    printer.writeNode(4 /* Unspecified */, entity, 
                    /*sourceFile*/
                    sourceFile, writer2);
                    return writer2;
                }
            }
            function signatureToString(signature, enclosingDeclaration, flags = 0 /* None */, kind, writer) {
                return writer ? signatureToStringWorker(writer).getText() : usingSingleLineStringWriter(signatureToStringWorker);
                function signatureToStringWorker(writer2) {
                    let sigOutput;
                    if (flags & 262144 /* WriteArrowStyleSignature */) {
                        sigOutput = kind === 1 /* Construct */ ? 182 /* ConstructorType */ : 181 /* FunctionType */;
                    }
                    else {
                        sigOutput = kind === 1 /* Construct */ ? 177 /* ConstructSignature */ : 176 /* CallSignature */;
                    }
                    const sig = nodeBuilder.signatureToSignatureDeclaration(signature, sigOutput, enclosingDeclaration, toNodeBuilderFlags(flags) | 70221824 /* IgnoreErrors */ | 512 /* WriteTypeParametersInQualifiedName */);
                    const printer = createPrinterWithRemoveCommentsOmitTrailingSemicolon();
                    const sourceFile = enclosingDeclaration && getSourceFileOfNode(enclosingDeclaration);
                    printer.writeNode(4 /* Unspecified */, sig, 
                    /*sourceFile*/
                    sourceFile, getTrailingSemicolonDeferringWriter(writer2));
                    return writer2;
                }
            }
            function typeToString(type, enclosingDeclaration, flags = 1048576 /* AllowUniqueESSymbolType */ | 16384 /* UseAliasDefinedOutsideCurrentScope */, writer = createTextWriter("")) {
                const noTruncation = compilerOptions.noErrorTruncation || flags & 1 /* NoTruncation */;
                const typeNode = nodeBuilder.typeToTypeNode(type, enclosingDeclaration, toNodeBuilderFlags(flags) | 70221824 /* IgnoreErrors */ | (noTruncation ? 1 /* NoTruncation */ : 0));
                if (typeNode === void 0)
                    return Debug.fail("should always get typenode");
                const printer = type !== unresolvedType ? createPrinterWithRemoveComments() : createPrinterWithDefaults();
                const sourceFile = enclosingDeclaration && getSourceFileOfNode(enclosingDeclaration);
                printer.writeNode(4 /* Unspecified */, typeNode, 
                /*sourceFile*/
                sourceFile, writer);
                const result = writer.getText();
                const maxLength2 = noTruncation ? noTruncationMaximumTruncationLength * 2 : defaultMaximumTruncationLength * 2;
                if (maxLength2 && result && result.length >= maxLength2) {
                    return result.substr(0, maxLength2 - "...".length) + "...";
                }
                return result;
            }
            function getTypeNamesForErrorDisplay(left, right) {
                let leftStr = symbolValueDeclarationIsContextSensitive(left.symbol) ? typeToString(left, left.symbol.valueDeclaration) : typeToString(left);
                let rightStr = symbolValueDeclarationIsContextSensitive(right.symbol) ? typeToString(right, right.symbol.valueDeclaration) : typeToString(right);
                if (leftStr === rightStr) {
                    leftStr = getTypeNameForErrorDisplay(left);
                    rightStr = getTypeNameForErrorDisplay(right);
                }
                return [leftStr, rightStr];
            }
            function getTypeNameForErrorDisplay(type) {
                return typeToString(type, 
                /*enclosingDeclaration*/
                void 0, 64 /* UseFullyQualifiedType */);
            }
            function symbolValueDeclarationIsContextSensitive(symbol) {
                return symbol && !!symbol.valueDeclaration && isExpression(symbol.valueDeclaration) && !isContextSensitive(symbol.valueDeclaration);
            }
            function toNodeBuilderFlags(flags = 0 /* None */) {
                return flags & 848330091 /* NodeBuilderFlagsMask */;
            }
            function isClassInstanceSide(type) {
                return !!type.symbol && !!(type.symbol.flags & 32 /* Class */) && (type === getDeclaredTypeOfClassOrInterface(type.symbol) || !!(type.flags & 524288 /* Object */) && !!(getObjectFlags(type) & 16777216 /* IsClassInstanceClone */));
            }
            function createNodeBuilder() {
                return {
                    typeToTypeNode: (type, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => typeToTypeNodeHelper(type, context)),
                    indexInfoToIndexSignatureDeclaration: (indexInfo, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => indexInfoToIndexSignatureDeclarationHelper(indexInfo, context, 
                    /*typeNode*/
                    void 0)),
                    signatureToSignatureDeclaration: (signature, kind, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => signatureToSignatureDeclarationHelper(signature, kind, context)),
                    symbolToEntityName: (symbol, meaning, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolToName(symbol, context, meaning, 
                    /*expectsIdentifier*/
                    false)),
                    symbolToExpression: (symbol, meaning, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolToExpression(symbol, context, meaning)),
                    symbolToTypeParameterDeclarations: (symbol, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => typeParametersToTypeParameterDeclarations(symbol, context)),
                    symbolToParameterDeclaration: (symbol, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolToParameterDeclaration(symbol, context)),
                    typeParameterToDeclaration: (parameter, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => typeParameterToDeclaration(parameter, context)),
                    symbolTableToDeclarationStatements: (symbolTable, enclosingDeclaration, flags, tracker, bundled) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolTableToDeclarationStatements(symbolTable, context, bundled)),
                    symbolToNode: (symbol, meaning, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolToNode(symbol, context, meaning))
                };
                function symbolToNode(symbol, context, meaning) {
                    if (context.flags & 1073741824 /* WriteComputedProps */) {
                        if (symbol.valueDeclaration) {
                            const name = getNameOfDeclaration(symbol.valueDeclaration);
                            if (name && isComputedPropertyName(name))
                                return name;
                        }
                        const nameType = getSymbolLinks(symbol).nameType;
                        if (nameType && nameType.flags & (1024 /* EnumLiteral */ | 8192 /* UniqueESSymbol */)) {
                            context.enclosingDeclaration = nameType.symbol.valueDeclaration;
                            return factory.createComputedPropertyName(symbolToExpression(nameType.symbol, context, meaning));
                        }
                    }
                    return symbolToExpression(symbol, context, meaning);
                }
                function withContext(enclosingDeclaration, flags, tracker, cb) {
                    Debug.assert(enclosingDeclaration === void 0 || (enclosingDeclaration.flags & 8 /* Synthesized */) === 0);
                    const moduleResolverHost = (tracker == null ? void 0 : tracker.trackSymbol) ? tracker.moduleResolverHost : flags & 134217728 /* DoNotIncludeSymbolChain */ ? createBasicNodeBuilderModuleSpecifierResolutionHost(host) : void 0;
                    const context = {
                        enclosingDeclaration,
                        flags: flags || 0 /* None */,
                        tracker: void 0,
                        encounteredError: false,
                        reportedDiagnostic: false,
                        visitedTypes: void 0,
                        symbolDepth: void 0,
                        inferTypeParameters: void 0,
                        approximateLength: 0
                    };
                    context.tracker = new SymbolTrackerImpl(context, tracker, moduleResolverHost);
                    const resultingNode = cb(context);
                    if (context.truncating && context.flags & 1 /* NoTruncation */) {
                        context.tracker.reportTruncationError();
                    }
                    return context.encounteredError ? void 0 : resultingNode;
                }
                function checkTruncationLength(context) {
                    if (context.truncating)
                        return context.truncating;
                    return context.truncating = context.approximateLength > (context.flags & 1 /* NoTruncation */ ? noTruncationMaximumTruncationLength : defaultMaximumTruncationLength);
                }
                function typeToTypeNodeHelper(type, context) {
                    const savedFlags = context.flags;
                    const typeNode = typeToTypeNodeWorker(type, context);
                    context.flags = savedFlags;
                    return typeNode;
                }
                function typeToTypeNodeWorker(type, context) {
                    var _a2, _b;
                    if (cancellationToken && cancellationToken.throwIfCancellationRequested) {
                        cancellationToken.throwIfCancellationRequested();
                    }
                    const inTypeAlias = context.flags & 8388608 /* InTypeAlias */;
                    context.flags &= ~8388608 /* InTypeAlias */;
                    if (!type) {
                        if (!(context.flags & 262144 /* AllowEmptyUnionOrIntersection */)) {
                            context.encounteredError = true;
                            return void 0;
                        }
                        context.approximateLength += 3;
                        return factory.createKeywordTypeNode(131 /* AnyKeyword */);
                    }
                    if (!(context.flags & 536870912 /* NoTypeReduction */)) {
                        type = getReducedType(type);
                    }
                    if (type.flags & 1 /* Any */) {
                        if (type.aliasSymbol) {
                            return factory.createTypeReferenceNode(symbolToEntityNameNode(type.aliasSymbol), mapToTypeNodes(type.aliasTypeArguments, context));
                        }
                        if (type === unresolvedType) {
                            return addSyntheticLeadingComment(factory.createKeywordTypeNode(131 /* AnyKeyword */), 3 /* MultiLineCommentTrivia */, "unresolved");
                        }
                        context.approximateLength += 3;
                        return factory.createKeywordTypeNode(type === intrinsicMarkerType ? 139 /* IntrinsicKeyword */ : 131 /* AnyKeyword */);
                    }
                    if (type.flags & 2 /* Unknown */) {
                        return factory.createKeywordTypeNode(157 /* UnknownKeyword */);
                    }
                    if (type.flags & 4 /* String */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(152 /* StringKeyword */);
                    }
                    if (type.flags & 8 /* Number */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(148 /* NumberKeyword */);
                    }
                    if (type.flags & 64 /* BigInt */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(160 /* BigIntKeyword */);
                    }
                    if (type.flags & 16 /* Boolean */ && !type.aliasSymbol) {
                        context.approximateLength += 7;
                        return factory.createKeywordTypeNode(134 /* BooleanKeyword */);
                    }
                    if (type.flags & 1056 /* EnumLike */) {
                        if (type.symbol.flags & 8 /* EnumMember */) {
                            const parentSymbol = getParentOfSymbol(type.symbol);
                            const parentName = symbolToTypeNode(parentSymbol, context, 788968 /* Type */);
                            if (getDeclaredTypeOfSymbol(parentSymbol) === type) {
                                return parentName;
                            }
                            const memberName = symbolName(type.symbol);
                            if (isIdentifierText(memberName, 0 /* ES3 */)) {
                                return appendReferenceToType(parentName, factory.createTypeReferenceNode(memberName, 
                                /*typeArguments*/
                                void 0));
                            }
                            if (isImportTypeNode(parentName)) {
                                parentName.isTypeOf = true;
                                return factory.createIndexedAccessTypeNode(parentName, factory.createLiteralTypeNode(factory.createStringLiteral(memberName)));
                            }
                            else if (isTypeReferenceNode(parentName)) {
                                return factory.createIndexedAccessTypeNode(factory.createTypeQueryNode(parentName.typeName), factory.createLiteralTypeNode(factory.createStringLiteral(memberName)));
                            }
                            else {
                                return Debug.fail("Unhandled type node kind returned from `symbolToTypeNode`.");
                            }
                        }
                        return symbolToTypeNode(type.symbol, context, 788968 /* Type */);
                    }
                    if (type.flags & 128 /* StringLiteral */) {
                        context.approximateLength += type.value.length + 2;
                        return factory.createLiteralTypeNode(setEmitFlags(factory.createStringLiteral(type.value, !!(context.flags & 268435456 /* UseSingleQuotesForStringLiteralType */)), 33554432 /* NoAsciiEscaping */));
                    }
                    if (type.flags & 256 /* NumberLiteral */) {
                        const value = type.value;
                        context.approximateLength += ("" + value).length;
                        return factory.createLiteralTypeNode(value < 0 ? factory.createPrefixUnaryExpression(40 /* MinusToken */, factory.createNumericLiteral(-value)) : factory.createNumericLiteral(value));
                    }
                    if (type.flags & 2048 /* BigIntLiteral */) {
                        context.approximateLength += pseudoBigIntToString(type.value).length + 1;
                        return factory.createLiteralTypeNode(factory.createBigIntLiteral(type.value));
                    }
                    if (type.flags & 512 /* BooleanLiteral */) {
                        context.approximateLength += type.intrinsicName.length;
                        return factory.createLiteralTypeNode(type.intrinsicName === "true" ? factory.createTrue() : factory.createFalse());
                    }
                    if (type.flags & 8192 /* UniqueESSymbol */) {
                        if (!(context.flags & 1048576 /* AllowUniqueESSymbolType */)) {
                            if (isValueSymbolAccessible(type.symbol, context.enclosingDeclaration)) {
                                context.approximateLength += 6;
                                return symbolToTypeNode(type.symbol, context, 111551 /* Value */);
                            }
                            if (context.tracker.reportInaccessibleUniqueSymbolError) {
                                context.tracker.reportInaccessibleUniqueSymbolError();
                            }
                        }
                        context.approximateLength += 13;
                        return factory.createTypeOperatorNode(156 /* UniqueKeyword */, factory.createKeywordTypeNode(153 /* SymbolKeyword */));
                    }
                    if (type.flags & 16384 /* Void */) {
                        context.approximateLength += 4;
                        return factory.createKeywordTypeNode(114 /* VoidKeyword */);
                    }
                    if (type.flags & 32768 /* Undefined */) {
                        context.approximateLength += 9;
                        return factory.createKeywordTypeNode(155 /* UndefinedKeyword */);
                    }
                    if (type.flags & 65536 /* Null */) {
                        context.approximateLength += 4;
                        return factory.createLiteralTypeNode(factory.createNull());
                    }
                    if (type.flags & 131072 /* Never */) {
                        context.approximateLength += 5;
                        return factory.createKeywordTypeNode(144 /* NeverKeyword */);
                    }
                    if (type.flags & 4096 /* ESSymbol */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(153 /* SymbolKeyword */);
                    }
                    if (type.flags & 67108864 /* NonPrimitive */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(149 /* ObjectKeyword */);
                    }
                    if (isThisTypeParameter(type)) {
                        if (context.flags & 4194304 /* InObjectTypeLiteral */) {
                            if (!context.encounteredError && !(context.flags & 32768 /* AllowThisInObjectLiteral */)) {
                                context.encounteredError = true;
                            }
                            (_b = (_a2 = context.tracker).reportInaccessibleThisError) == null ? void 0 : _b.call(_a2);
                        }
                        context.approximateLength += 4;
                        return factory.createThisTypeNode();
                    }
                    if (!inTypeAlias && type.aliasSymbol && (context.flags & 16384 /* UseAliasDefinedOutsideCurrentScope */ || isTypeSymbolAccessible(type.aliasSymbol, context.enclosingDeclaration))) {
                        const typeArgumentNodes = mapToTypeNodes(type.aliasTypeArguments, context);
                        if (isReservedMemberName(type.aliasSymbol.escapedName) && !(type.aliasSymbol.flags & 32 /* Class */))
                            return factory.createTypeReferenceNode(factory.createIdentifier(""), typeArgumentNodes);
                        if (length(typeArgumentNodes) === 1 && type.aliasSymbol === globalArrayType.symbol) {
                            return factory.createArrayTypeNode(typeArgumentNodes[0]);
                        }
                        return symbolToTypeNode(type.aliasSymbol, context, 788968 /* Type */, typeArgumentNodes);
                    }
                    const objectFlags = getObjectFlags(type);
                    if (objectFlags & 4 /* Reference */) {
                        Debug.assert(!!(type.flags & 524288 /* Object */));
                        return type.node ? visitAndTransformType(type, typeReferenceToTypeNode) : typeReferenceToTypeNode(type);
                    }
                    if (type.flags & 262144 /* TypeParameter */ || objectFlags & 3 /* ClassOrInterface */) {
                        if (type.flags & 262144 /* TypeParameter */ && contains(context.inferTypeParameters, type)) {
                            context.approximateLength += symbolName(type.symbol).length + 6;
                            let constraintNode;
                            const constraint = getConstraintOfTypeParameter(type);
                            if (constraint) {
                                const inferredConstraint = getInferredTypeParameterConstraint(type, 
                                /*omitTypeReferences*/
                                true);
                                if (!(inferredConstraint && isTypeIdenticalTo(constraint, inferredConstraint))) {
                                    context.approximateLength += 9;
                                    constraintNode = constraint && typeToTypeNodeHelper(constraint, context);
                                }
                            }
                            return factory.createInferTypeNode(typeParameterToDeclarationWithConstraint(type, context, constraintNode));
                        }
                        if (context.flags & 4 /* GenerateNamesForShadowedTypeParams */ && type.flags & 262144 /* TypeParameter */ && !isTypeSymbolAccessible(type.symbol, context.enclosingDeclaration)) {
                            const name2 = typeParameterToName(type, context);
                            context.approximateLength += idText(name2).length;
                            return factory.createTypeReferenceNode(factory.createIdentifier(idText(name2)), 
                            /*typeArguments*/
                            void 0);
                        }
                        if (type.symbol) {
                            return symbolToTypeNode(type.symbol, context, 788968 /* Type */);
                        }
                        const name = (type === markerSuperTypeForCheck || type === markerSubTypeForCheck) && varianceTypeParameter && varianceTypeParameter.symbol ? (type === markerSubTypeForCheck ? "sub-" : "super-") + symbolName(varianceTypeParameter.symbol) : "?";
                        return factory.createTypeReferenceNode(factory.createIdentifier(name), 
                        /*typeArguments*/
                        void 0);
                    }
                    if (type.flags & 1048576 /* Union */ && type.origin) {
                        type = type.origin;
                    }
                    if (type.flags & (1048576 /* Union */ | 2097152 /* Intersection */)) {
                        const types = type.flags & 1048576 /* Union */ ? formatUnionTypes(type.types) : type.types;
                        if (length(types) === 1) {
                            return typeToTypeNodeHelper(types[0], context);
                        }
                        const typeNodes = mapToTypeNodes(types, context, 
                        /*isBareList*/
                        true);
                        if (typeNodes && typeNodes.length > 0) {
                            return type.flags & 1048576 /* Union */ ? factory.createUnionTypeNode(typeNodes) : factory.createIntersectionTypeNode(typeNodes);
                        }
                        else {
                            if (!context.encounteredError && !(context.flags & 262144 /* AllowEmptyUnionOrIntersection */)) {
                                context.encounteredError = true;
                            }
                            return void 0;
                        }
                    }
                    if (objectFlags & (16 /* Anonymous */ | 32 /* Mapped */)) {
                        Debug.assert(!!(type.flags & 524288 /* Object */));
                        return createAnonymousTypeNode(type);
                    }
                    if (type.flags & 4194304 /* Index */) {
                        const indexedType = type.type;
                        context.approximateLength += 6;
                        const indexTypeNode = typeToTypeNodeHelper(indexedType, context);
                        return factory.createTypeOperatorNode(141 /* KeyOfKeyword */, indexTypeNode);
                    }
                    if (type.flags & 134217728 /* TemplateLiteral */) {
                        const texts = type.texts;
                        const types = type.types;
                        const templateHead = factory.createTemplateHead(texts[0]);
                        const templateSpans = factory.createNodeArray(map(types, (t, i) => factory.createTemplateLiteralTypeSpan(typeToTypeNodeHelper(t, context), (i < types.length - 1 ? factory.createTemplateMiddle : factory.createTemplateTail)(texts[i + 1]))));
                        context.approximateLength += 2;
                        return factory.createTemplateLiteralType(templateHead, templateSpans);
                    }
                    if (type.flags & 268435456 /* StringMapping */) {
                        const typeNode = typeToTypeNodeHelper(type.type, context);
                        return symbolToTypeNode(type.symbol, context, 788968 /* Type */, [typeNode]);
                    }
                    if (type.flags & 8388608 /* IndexedAccess */) {
                        const objectTypeNode = typeToTypeNodeHelper(type.objectType, context);
                        const indexTypeNode = typeToTypeNodeHelper(type.indexType, context);
                        context.approximateLength += 2;
                        return factory.createIndexedAccessTypeNode(objectTypeNode, indexTypeNode);
                    }
                    if (type.flags & 16777216 /* Conditional */) {
                        return visitAndTransformType(type, (type2) => conditionalTypeToTypeNode(type2));
                    }
                    if (type.flags & 33554432 /* Substitution */) {
                        return typeToTypeNodeHelper(type.baseType, context);
                    }
                    return Debug.fail("Should be unreachable.");
                    function conditionalTypeToTypeNode(type2) {
                        const checkTypeNode = typeToTypeNodeHelper(type2.checkType, context);
                        context.approximateLength += 15;
                        if (context.flags & 4 /* GenerateNamesForShadowedTypeParams */ && type2.root.isDistributive && !(type2.checkType.flags & 262144 /* TypeParameter */)) {
                            const newParam = createTypeParameter(createSymbol(262144 /* TypeParameter */, "T"));
                            const name = typeParameterToName(newParam, context);
                            const newTypeVariable = factory.createTypeReferenceNode(name);
                            context.approximateLength += 37;
                            const newMapper = prependTypeMapping(type2.root.checkType, newParam, type2.mapper);
                            const saveInferTypeParameters2 = context.inferTypeParameters;
                            context.inferTypeParameters = type2.root.inferTypeParameters;
                            const extendsTypeNode2 = typeToTypeNodeHelper(instantiateType(type2.root.extendsType, newMapper), context);
                            context.inferTypeParameters = saveInferTypeParameters2;
                            const trueTypeNode2 = typeToTypeNodeOrCircularityElision(instantiateType(getTypeFromTypeNode(type2.root.node.trueType), newMapper));
                            const falseTypeNode2 = typeToTypeNodeOrCircularityElision(instantiateType(getTypeFromTypeNode(type2.root.node.falseType), newMapper));
                            return factory.createConditionalTypeNode(checkTypeNode, factory.createInferTypeNode(factory.createTypeParameterDeclaration(
                            /*modifiers*/
                            void 0, factory.cloneNode(newTypeVariable.typeName))), factory.createConditionalTypeNode(factory.createTypeReferenceNode(factory.cloneNode(name)), typeToTypeNodeHelper(type2.checkType, context), factory.createConditionalTypeNode(newTypeVariable, extendsTypeNode2, trueTypeNode2, falseTypeNode2), factory.createKeywordTypeNode(144 /* NeverKeyword */)), factory.createKeywordTypeNode(144 /* NeverKeyword */));
                        }
                        const saveInferTypeParameters = context.inferTypeParameters;
                        context.inferTypeParameters = type2.root.inferTypeParameters;
                        const extendsTypeNode = typeToTypeNodeHelper(type2.extendsType, context);
                        context.inferTypeParameters = saveInferTypeParameters;
                        const trueTypeNode = typeToTypeNodeOrCircularityElision(getTrueTypeFromConditionalType(type2));
                        const falseTypeNode = typeToTypeNodeOrCircularityElision(getFalseTypeFromConditionalType(type2));
                        return factory.createConditionalTypeNode(checkTypeNode, extendsTypeNode, trueTypeNode, falseTypeNode);
                    }
                    function typeToTypeNodeOrCircularityElision(type2) {
                        var _a3, _b2, _c;
                        if (type2.flags & 1048576 /* Union */) {
                            if ((_a3 = context.visitedTypes) == null ? void 0 : _a3.has(getTypeId(type2))) {
                                if (!(context.flags & 131072 /* AllowAnonymousIdentifier */)) {
                                    context.encounteredError = true;
                                    (_c = (_b2 = context.tracker) == null ? void 0 : _b2.reportCyclicStructureError) == null ? void 0 : _c.call(_b2);
                                }
                                return createElidedInformationPlaceholder(context);
                            }
                            return visitAndTransformType(type2, (type3) => typeToTypeNodeHelper(type3, context));
                        }
                        return typeToTypeNodeHelper(type2, context);
                    }
                    function isHomomorphicMappedTypeWithNonHomomorphicInstantiation(type2) {
                        return isMappedTypeWithKeyofConstraintDeclaration(type2) && !(getModifiersTypeFromMappedType(type2).flags & 262144 /* TypeParameter */);
                    }
                    function createMappedTypeNodeFromType(type2) {
                        Debug.assert(!!(type2.flags & 524288 /* Object */));
                        const readonlyToken = type2.declaration.readonlyToken ? factory.createToken(type2.declaration.readonlyToken.kind) : void 0;
                        const questionToken = type2.declaration.questionToken ? factory.createToken(type2.declaration.questionToken.kind) : void 0;
                        let appropriateConstraintTypeNode;
                        let newTypeVariable;
                        if (isMappedTypeWithKeyofConstraintDeclaration(type2)) {
                            if (isHomomorphicMappedTypeWithNonHomomorphicInstantiation(type2) && context.flags & 4 /* GenerateNamesForShadowedTypeParams */) {
                                const newParam = createTypeParameter(createSymbol(262144 /* TypeParameter */, "T"));
                                const name = typeParameterToName(newParam, context);
                                newTypeVariable = factory.createTypeReferenceNode(name);
                            }
                            appropriateConstraintTypeNode = factory.createTypeOperatorNode(141 /* KeyOfKeyword */, newTypeVariable || typeToTypeNodeHelper(getModifiersTypeFromMappedType(type2), context));
                        }
                        else {
                            appropriateConstraintTypeNode = typeToTypeNodeHelper(getConstraintTypeFromMappedType(type2), context);
                        }
                        const typeParameterNode = typeParameterToDeclarationWithConstraint(getTypeParameterFromMappedType(type2), context, appropriateConstraintTypeNode);
                        const nameTypeNode = type2.declaration.nameType ? typeToTypeNodeHelper(getNameTypeFromMappedType(type2), context) : void 0;
                        const templateTypeNode = typeToTypeNodeHelper(removeMissingType(getTemplateTypeFromMappedType(type2), !!(getMappedTypeModifiers(type2) & 4 /* IncludeOptional */)), context);
                        const mappedTypeNode = factory.createMappedTypeNode(readonlyToken, typeParameterNode, nameTypeNode, questionToken, templateTypeNode, 
                        /*members*/
                        void 0);
                        context.approximateLength += 10;
                        const result = setEmitFlags(mappedTypeNode, 1 /* SingleLine */);
                        if (isHomomorphicMappedTypeWithNonHomomorphicInstantiation(type2) && context.flags & 4 /* GenerateNamesForShadowedTypeParams */) {
                            const originalConstraint = instantiateType(getConstraintOfTypeParameter(getTypeFromTypeNode(type2.declaration.typeParameter.constraint.type)) || unknownType, type2.mapper);
                            return factory.createConditionalTypeNode(typeToTypeNodeHelper(getModifiersTypeFromMappedType(type2), context), factory.createInferTypeNode(factory.createTypeParameterDeclaration(
                            /*modifiers*/
                            void 0, factory.cloneNode(newTypeVariable.typeName), originalConstraint.flags & 2 /* Unknown */ ? void 0 : typeToTypeNodeHelper(originalConstraint, context))), result, factory.createKeywordTypeNode(144 /* NeverKeyword */));
                        }
                        return result;
                    }
                    function createAnonymousTypeNode(type2) {
                        var _a3, _b2;
                        const typeId = type2.id;
                        const symbol = type2.symbol;
                        if (symbol) {
                            const isInstanceType = isClassInstanceSide(type2) ? 788968 /* Type */ : 111551 /* Value */;
                            if (isJSConstructor(symbol.valueDeclaration)) {
                                return symbolToTypeNode(symbol, context, isInstanceType);
                            }
                            else if (symbol.flags & 32 /* Class */ && !getBaseTypeVariableOfClass(symbol) && !(symbol.valueDeclaration && isClassLike(symbol.valueDeclaration) && context.flags & 2048 /* WriteClassExpressionAsTypeLiteral */ && (!isClassDeclaration(symbol.valueDeclaration) || isSymbolAccessible(symbol, context.enclosingDeclaration, isInstanceType, 
                            /*computeAliases*/
                            false).accessibility !== 0 /* Accessible */)) || symbol.flags & (384 /* Enum */ | 512 /* ValueModule */) || shouldWriteTypeOfFunctionSymbol()) {
                                return symbolToTypeNode(symbol, context, isInstanceType);
                            }
                            else if ((_a3 = context.visitedTypes) == null ? void 0 : _a3.has(typeId)) {
                                const typeAlias = getTypeAliasForTypeLiteral(type2);
                                if (typeAlias) {
                                    return symbolToTypeNode(typeAlias, context, 788968 /* Type */);
                                }
                                else {
                                    return createElidedInformationPlaceholder(context);
                                }
                            }
                            else {
                                return visitAndTransformType(type2, createTypeNodeFromObjectType);
                            }
                        }
                        else {
                            const isInstantiationExpressionType = !!(getObjectFlags(type2) & 8388608 /* InstantiationExpressionType */);
                            if (isInstantiationExpressionType) {
                                const instantiationExpressionType = type2;
                                if (isTypeQueryNode(instantiationExpressionType.node)) {
                                    const typeNode = serializeExistingTypeNode(context, instantiationExpressionType.node);
                                    if (typeNode) {
                                        return typeNode;
                                    }
                                }
                                if ((_b2 = context.visitedTypes) == null ? void 0 : _b2.has(typeId)) {
                                    return createElidedInformationPlaceholder(context);
                                }
                                return visitAndTransformType(type2, createTypeNodeFromObjectType);
                            }
                            return createTypeNodeFromObjectType(type2);
                        }
                        function shouldWriteTypeOfFunctionSymbol() {
                            var _a4;
                            const isStaticMethodSymbol = !!(symbol.flags & 8192 /* Method */) && // typeof static method
                                some(symbol.declarations, (declaration) => isStatic(declaration));
                            const isNonLocalFunctionSymbol = !!(symbol.flags & 16 /* Function */) && (symbol.parent || // is exported function symbol
                                forEach(symbol.declarations, (declaration) => declaration.parent.kind === 308 /* SourceFile */ || declaration.parent.kind === 265 /* ModuleBlock */));
                            if (isStaticMethodSymbol || isNonLocalFunctionSymbol) {
                                return (!!(context.flags & 4096 /* UseTypeOfFunction */) || ((_a4 = context.visitedTypes) == null ? void 0 : _a4.has(typeId))) && // it is type of the symbol uses itself recursively
                                    (!(context.flags & 8 /* UseStructuralFallback */) || isValueSymbolAccessible(symbol, context.enclosingDeclaration));
                            }
                        }
                    }
                    function visitAndTransformType(type2, transform2) {
                        var _a3, _b2;
                        const typeId = type2.id;
                        const isConstructorObject = getObjectFlags(type2) & 16 /* Anonymous */ && type2.symbol && type2.symbol.flags & 32 /* Class */;
                        const id = getObjectFlags(type2) & 4 /* Reference */ && type2.node ? "N" + getNodeId(type2.node) : type2.flags & 16777216 /* Conditional */ ? "N" + getNodeId(type2.root.node) : type2.symbol ? (isConstructorObject ? "+" : "") + getSymbolId(type2.symbol) : void 0;
                        if (!context.visitedTypes) {
                            context.visitedTypes = /* @__PURE__ */ new Set();
                        }
                        if (id && !context.symbolDepth) {
                            context.symbolDepth = /* @__PURE__ */ new Map();
                        }
                        const links = context.enclosingDeclaration && getNodeLinks(context.enclosingDeclaration);
                        const key = `${getTypeId(type2)}|${context.flags}`;
                        if (links) {
                            links.serializedTypes || (links.serializedTypes = /* @__PURE__ */ new Map());
                        }
                        const cachedResult = (_a3 = links == null ? void 0 : links.serializedTypes) == null ? void 0 : _a3.get(key);
                        if (cachedResult) {
                            if (cachedResult.truncating) {
                                context.truncating = true;
                            }
                            context.approximateLength += cachedResult.addedLength;
                            return deepCloneOrReuseNode(cachedResult.node);
                        }
                        let depth;
                        if (id) {
                            depth = context.symbolDepth.get(id) || 0;
                            if (depth > 10) {
                                return createElidedInformationPlaceholder(context);
                            }
                            context.symbolDepth.set(id, depth + 1);
                        }
                        context.visitedTypes.add(typeId);
                        const startLength = context.approximateLength;
                        const result = transform2(type2);
                        const addedLength = context.approximateLength - startLength;
                        if (!context.reportedDiagnostic && !context.encounteredError) {
                            (_b2 = links == null ? void 0 : links.serializedTypes) == null ? void 0 : _b2.set(key, { node: result, truncating: context.truncating, addedLength });
                        }
                        context.visitedTypes.delete(typeId);
                        if (id) {
                            context.symbolDepth.set(id, depth);
                        }
                        return result;
                        function deepCloneOrReuseNode(node) {
                            if (!nodeIsSynthesized(node) && getParseTreeNode(node) === node) {
                                return node;
                            }
                            return setTextRange(factory.cloneNode(visitEachChild(node, deepCloneOrReuseNode, nullTransformationContext, deepCloneOrReuseNodes)), node);
                        }
                        function deepCloneOrReuseNodes(nodes, visitor, test, start, count) {
                            if (nodes && nodes.length === 0) {
                                return setTextRange(factory.createNodeArray(
                                /*nodes*/
                                void 0, nodes.hasTrailingComma), nodes);
                            }
                            return visitNodes2(nodes, visitor, test, start, count);
                        }
                    }
                    function createTypeNodeFromObjectType(type2) {
                        if (isGenericMappedType(type2) || type2.containsError) {
                            return createMappedTypeNodeFromType(type2);
                        }
                        const resolved = resolveStructuredTypeMembers(type2);
                        if (!resolved.properties.length && !resolved.indexInfos.length) {
                            if (!resolved.callSignatures.length && !resolved.constructSignatures.length) {
                                context.approximateLength += 2;
                                return setEmitFlags(factory.createTypeLiteralNode(
                                /*members*/
                                void 0), 1 /* SingleLine */);
                            }
                            if (resolved.callSignatures.length === 1 && !resolved.constructSignatures.length) {
                                const signature = resolved.callSignatures[0];
                                const signatureNode = signatureToSignatureDeclarationHelper(signature, 181 /* FunctionType */, context);
                                return signatureNode;
                            }
                            if (resolved.constructSignatures.length === 1 && !resolved.callSignatures.length) {
                                const signature = resolved.constructSignatures[0];
                                const signatureNode = signatureToSignatureDeclarationHelper(signature, 182 /* ConstructorType */, context);
                                return signatureNode;
                            }
                        }
                        const abstractSignatures = filter(resolved.constructSignatures, (signature) => !!(signature.flags & 4 /* Abstract */));
                        if (some(abstractSignatures)) {
                            const types = map(abstractSignatures, getOrCreateTypeFromSignature);
                            const typeElementCount = resolved.callSignatures.length + (resolved.constructSignatures.length - abstractSignatures.length) + resolved.indexInfos.length + // exclude `prototype` when writing a class expression as a type literal, as per
                                // the logic in `createTypeNodesFromResolvedType`.
                                (context.flags & 2048 /* WriteClassExpressionAsTypeLiteral */ ? countWhere(resolved.properties, (p) => !(p.flags & 4194304 /* Prototype */)) : length(resolved.properties));
                            if (typeElementCount) {
                                types.push(getResolvedTypeWithoutAbstractConstructSignatures(resolved));
                            }
                            return typeToTypeNodeHelper(getIntersectionType(types), context);
                        }
                        const savedFlags = context.flags;
                        context.flags |= 4194304 /* InObjectTypeLiteral */;
                        const members = createTypeNodesFromResolvedType(resolved);
                        context.flags = savedFlags;
                        const typeLiteralNode = factory.createTypeLiteralNode(members);
                        context.approximateLength += 2;
                        setEmitFlags(typeLiteralNode, context.flags & 1024 /* MultilineObjectLiterals */ ? 0 : 1 /* SingleLine */);
                        return typeLiteralNode;
                    }
                    function typeReferenceToTypeNode(type2) {
                        let typeArguments = getTypeArguments(type2);
                        if (type2.target === globalArrayType || type2.target === globalReadonlyArrayType) {
                            if (context.flags & 2 /* WriteArrayAsGenericType */) {
                                const typeArgumentNode = typeToTypeNodeHelper(typeArguments[0], context);
                                return factory.createTypeReferenceNode(type2.target === globalArrayType ? "Array" : "ReadonlyArray", [typeArgumentNode]);
                            }
                            const elementType = typeToTypeNodeHelper(typeArguments[0], context);
                            const arrayType = factory.createArrayTypeNode(elementType);
                            return type2.target === globalArrayType ? arrayType : factory.createTypeOperatorNode(146 /* ReadonlyKeyword */, arrayType);
                        }
                        else if (type2.target.objectFlags & 8 /* Tuple */) {
                            typeArguments = sameMap(typeArguments, (t, i) => removeMissingType(t, !!(type2.target.elementFlags[i] & 2 /* Optional */)));
                            if (typeArguments.length > 0) {
                                const arity = getTypeReferenceArity(type2);
                                const tupleConstituentNodes = mapToTypeNodes(typeArguments.slice(0, arity), context);
                                if (tupleConstituentNodes) {
                                    if (type2.target.labeledElementDeclarations) {
                                        for (let i = 0; i < tupleConstituentNodes.length; i++) {
                                            const flags = type2.target.elementFlags[i];
                                            tupleConstituentNodes[i] = factory.createNamedTupleMember(flags & 12 /* Variable */ ? factory.createToken(25 /* DotDotDotToken */) : void 0, factory.createIdentifier(unescapeLeadingUnderscores(getTupleElementLabel(type2.target.labeledElementDeclarations[i]))), flags & 2 /* Optional */ ? factory.createToken(57 /* QuestionToken */) : void 0, flags & 4 /* Rest */ ? factory.createArrayTypeNode(tupleConstituentNodes[i]) : tupleConstituentNodes[i]);
                                        }
                                    }
                                    else {
                                        for (let i = 0; i < Math.min(arity, tupleConstituentNodes.length); i++) {
                                            const flags = type2.target.elementFlags[i];
                                            tupleConstituentNodes[i] = flags & 12 /* Variable */ ? factory.createRestTypeNode(flags & 4 /* Rest */ ? factory.createArrayTypeNode(tupleConstituentNodes[i]) : tupleConstituentNodes[i]) : flags & 2 /* Optional */ ? factory.createOptionalTypeNode(tupleConstituentNodes[i]) : tupleConstituentNodes[i];
                                        }
                                    }
                                    const tupleTypeNode = setEmitFlags(factory.createTupleTypeNode(tupleConstituentNodes), 1 /* SingleLine */);
                                    return type2.target.readonly ? factory.createTypeOperatorNode(146 /* ReadonlyKeyword */, tupleTypeNode) : tupleTypeNode;
                                }
                            }
                            if (context.encounteredError || context.flags & 524288 /* AllowEmptyTuple */) {
                                const tupleTypeNode = setEmitFlags(factory.createTupleTypeNode([]), 1 /* SingleLine */);
                                return type2.target.readonly ? factory.createTypeOperatorNode(146 /* ReadonlyKeyword */, tupleTypeNode) : tupleTypeNode;
                            }
                            context.encounteredError = true;
                            return void 0;
                        }
                        else if (context.flags & 2048 /* WriteClassExpressionAsTypeLiteral */ && type2.symbol.valueDeclaration && isClassLike(type2.symbol.valueDeclaration) && !isValueSymbolAccessible(type2.symbol, context.enclosingDeclaration)) {
                            return createAnonymousTypeNode(type2);
                        }
                        else {
                            const outerTypeParameters = type2.target.outerTypeParameters;
                            let i = 0;
                            let resultType;
                            if (outerTypeParameters) {
                                const length2 = outerTypeParameters.length;
                                while (i < length2) {
                                    const start = i;
                                    const parent2 = getParentSymbolOfTypeParameter(outerTypeParameters[i]);
                                    do {
                                        i++;
                                    } while (i < length2 && getParentSymbolOfTypeParameter(outerTypeParameters[i]) === parent2);
                                    if (!rangeEquals(outerTypeParameters, typeArguments, start, i)) {
                                        const typeArgumentSlice = mapToTypeNodes(typeArguments.slice(start, i), context);
                                        const flags2 = context.flags;
                                        context.flags |= 16 /* ForbidIndexedAccessSymbolReferences */;
                                        const ref = symbolToTypeNode(parent2, context, 788968 /* Type */, typeArgumentSlice);
                                        context.flags = flags2;
                                        resultType = !resultType ? ref : appendReferenceToType(resultType, ref);
                                    }
                                }
                            }
                            let typeArgumentNodes;
                            if (typeArguments.length > 0) {
                                const typeParameterCount = (type2.target.typeParameters || emptyArray).length;
                                typeArgumentNodes = mapToTypeNodes(typeArguments.slice(i, typeParameterCount), context);
                            }
                            const flags = context.flags;
                            context.flags |= 16 /* ForbidIndexedAccessSymbolReferences */;
                            const finalRef = symbolToTypeNode(type2.symbol, context, 788968 /* Type */, typeArgumentNodes);
                            context.flags = flags;
                            return !resultType ? finalRef : appendReferenceToType(resultType, finalRef);
                        }
                    }
                    function appendReferenceToType(root, ref) {
                        if (isImportTypeNode(root)) {
                            let typeArguments = root.typeArguments;
                            let qualifier = root.qualifier;
                            if (qualifier) {
                                if (isIdentifier(qualifier)) {
                                    if (typeArguments !== getIdentifierTypeArguments(qualifier)) {
                                        qualifier = setIdentifierTypeArguments(factory.cloneNode(qualifier), typeArguments);
                                    }
                                }
                                else {
                                    if (typeArguments !== getIdentifierTypeArguments(qualifier.right)) {
                                        qualifier = factory.updateQualifiedName(qualifier, qualifier.left, setIdentifierTypeArguments(factory.cloneNode(qualifier.right), typeArguments));
                                    }
                                }
                            }
                            typeArguments = ref.typeArguments;
                            const ids = getAccessStack(ref);
                            for (const id of ids) {
                                qualifier = qualifier ? factory.createQualifiedName(qualifier, id) : id;
                            }
                            return factory.updateImportTypeNode(root, root.argument, root.assertions, qualifier, typeArguments, root.isTypeOf);
                        }
                        else {
                            let typeArguments = root.typeArguments;
                            let typeName = root.typeName;
                            if (isIdentifier(typeName)) {
                                if (typeArguments !== getIdentifierTypeArguments(typeName)) {
                                    typeName = setIdentifierTypeArguments(factory.cloneNode(typeName), typeArguments);
                                }
                            }
                            else {
                                if (typeArguments !== getIdentifierTypeArguments(typeName.right)) {
                                    typeName = factory.updateQualifiedName(typeName, typeName.left, setIdentifierTypeArguments(factory.cloneNode(typeName.right), typeArguments));
                                }
                            }
                            typeArguments = ref.typeArguments;
                            const ids = getAccessStack(ref);
                            for (const id of ids) {
                                typeName = factory.createQualifiedName(typeName, id);
                            }
                            return factory.updateTypeReferenceNode(root, typeName, typeArguments);
                        }
                    }
                    function getAccessStack(ref) {
                        let state = ref.typeName;
                        const ids = [];
                        while (!isIdentifier(state)) {
                            ids.unshift(state.right);
                            state = state.left;
                        }
                        ids.unshift(state);
                        return ids;
                    }
                    function createTypeNodesFromResolvedType(resolvedType) {
                        if (checkTruncationLength(context)) {
                            return [factory.createPropertySignature(
                                /*modifiers*/
                                void 0, "...", 
                                /*questionToken*/
                                void 0, 
                                /*type*/
                                void 0)];
                        }
                        const typeElements = [];
                        for (const signature of resolvedType.callSignatures) {
                            typeElements.push(signatureToSignatureDeclarationHelper(signature, 176 /* CallSignature */, context));
                        }
                        for (const signature of resolvedType.constructSignatures) {
                            if (signature.flags & 4 /* Abstract */)
                                continue;
                            typeElements.push(signatureToSignatureDeclarationHelper(signature, 177 /* ConstructSignature */, context));
                        }
                        for (const info of resolvedType.indexInfos) {
                            typeElements.push(indexInfoToIndexSignatureDeclarationHelper(info, context, resolvedType.objectFlags & 1024 /* ReverseMapped */ ? createElidedInformationPlaceholder(context) : void 0));
                        }
                        const properties = resolvedType.properties;
                        if (!properties) {
                            return typeElements;
                        }
                        let i = 0;
                        for (const propertySymbol of properties) {
                            i++;
                            if (context.flags & 2048 /* WriteClassExpressionAsTypeLiteral */) {
                                if (propertySymbol.flags & 4194304 /* Prototype */) {
                                    continue;
                                }
                                if (getDeclarationModifierFlagsFromSymbol(propertySymbol) & (8 /* Private */ | 16 /* Protected */) && context.tracker.reportPrivateInBaseOfClassExpression) {
                                    context.tracker.reportPrivateInBaseOfClassExpression(unescapeLeadingUnderscores(propertySymbol.escapedName));
                                }
                            }
                            if (checkTruncationLength(context) && i + 2 < properties.length - 1) {
                                typeElements.push(factory.createPropertySignature(
                                /*modifiers*/
                                void 0, `... ${properties.length - i} more ...`, 
                                /*questionToken*/
                                void 0, 
                                /*type*/
                                void 0));
                                addPropertyToElementList(properties[properties.length - 1], context, typeElements);
                                break;
                            }
                            addPropertyToElementList(propertySymbol, context, typeElements);
                        }
                        return typeElements.length ? typeElements : void 0;
                    }
                }
                function createElidedInformationPlaceholder(context) {
                    context.approximateLength += 3;
                    if (!(context.flags & 1 /* NoTruncation */)) {
                        return factory.createTypeReferenceNode(factory.createIdentifier("..."), 
                        /*typeArguments*/
                        void 0);
                    }
                    return factory.createKeywordTypeNode(131 /* AnyKeyword */);
                }
                function shouldUsePlaceholderForProperty(propertySymbol, context) {
                    var _a2;
                    return !!(getCheckFlags(propertySymbol) & 8192 /* ReverseMapped */) && (contains(context.reverseMappedStack, propertySymbol) || ((_a2 = context.reverseMappedStack) == null ? void 0 : _a2[0]) && !(getObjectFlags(last(context.reverseMappedStack).links.propertyType) & 16 /* Anonymous */));
                }
                function addPropertyToElementList(propertySymbol, context, typeElements) {
                    var _a2;
                    const propertyIsReverseMapped = !!(getCheckFlags(propertySymbol) & 8192 /* ReverseMapped */);
                    const propertyType = shouldUsePlaceholderForProperty(propertySymbol, context) ? anyType : getNonMissingTypeOfSymbol(propertySymbol);
                    const saveEnclosingDeclaration = context.enclosingDeclaration;
                    context.enclosingDeclaration = void 0;
                    if (context.tracker.canTrackSymbol && isLateBoundName(propertySymbol.escapedName)) {
                        if (propertySymbol.declarations) {
                            const decl = first(propertySymbol.declarations);
                            if (hasLateBindableName(decl)) {
                                if (isBinaryExpression(decl)) {
                                    const name = getNameOfDeclaration(decl);
                                    if (name && isElementAccessExpression(name) && isPropertyAccessEntityNameExpression(name.argumentExpression)) {
                                        trackComputedName(name.argumentExpression, saveEnclosingDeclaration, context);
                                    }
                                }
                                else {
                                    trackComputedName(decl.name.expression, saveEnclosingDeclaration, context);
                                }
                            }
                        }
                        else {
                            context.tracker.reportNonSerializableProperty(symbolToString(propertySymbol));
                        }
                    }
                    context.enclosingDeclaration = propertySymbol.valueDeclaration || ((_a2 = propertySymbol.declarations) == null ? void 0 : _a2[0]) || saveEnclosingDeclaration;
                    const propertyName = getPropertyNameNodeForSymbol(propertySymbol, context);
                    context.enclosingDeclaration = saveEnclosingDeclaration;
                    context.approximateLength += symbolName(propertySymbol).length + 1;
                    const optionalToken = propertySymbol.flags & 16777216 /* Optional */ ? factory.createToken(57 /* QuestionToken */) : void 0;
                    if (propertySymbol.flags & (16 /* Function */ | 8192 /* Method */) && !getPropertiesOfObjectType(propertyType).length && !isReadonlySymbol(propertySymbol)) {
                        const signatures = getSignaturesOfType(filterType(propertyType, (t) => !(t.flags & 32768 /* Undefined */)), 0 /* Call */);
                        for (const signature of signatures) {
                            const methodDeclaration = signatureToSignatureDeclarationHelper(signature, 170 /* MethodSignature */, context, { name: propertyName, questionToken: optionalToken });
                            typeElements.push(preserveCommentsOn(methodDeclaration));
                        }
                    }
                    else {
                        let propertyTypeNode;
                        if (shouldUsePlaceholderForProperty(propertySymbol, context)) {
                            propertyTypeNode = createElidedInformationPlaceholder(context);
                        }
                        else {
                            if (propertyIsReverseMapped) {
                                context.reverseMappedStack || (context.reverseMappedStack = []);
                                context.reverseMappedStack.push(propertySymbol);
                            }
                            propertyTypeNode = propertyType ? serializeTypeForDeclaration(context, propertyType, propertySymbol, saveEnclosingDeclaration) : factory.createKeywordTypeNode(131 /* AnyKeyword */);
                            if (propertyIsReverseMapped) {
                                context.reverseMappedStack.pop();
                            }
                        }
                        const modifiers = isReadonlySymbol(propertySymbol) ? [factory.createToken(146 /* ReadonlyKeyword */)] : void 0;
                        if (modifiers) {
                            context.approximateLength += 9;
                        }
                        const propertySignature = factory.createPropertySignature(modifiers, propertyName, optionalToken, propertyTypeNode);
                        typeElements.push(preserveCommentsOn(propertySignature));
                    }
                    function preserveCommentsOn(node) {
                        var _a3;
                        if (some(propertySymbol.declarations, (d) => d.kind === 351 /* JSDocPropertyTag */)) {
                            const d = (_a3 = propertySymbol.declarations) == null ? void 0 : _a3.find((d2) => d2.kind === 351 /* JSDocPropertyTag */);
                            const commentText = getTextOfJSDocComment(d.comment);
                            if (commentText) {
                                setSyntheticLeadingComments(node, [{ kind: 3 /* MultiLineCommentTrivia */, text: "*\n * " + commentText.replace(/\n/g, "\n * ") + "\n ", pos: -1, end: -1, hasTrailingNewLine: true }]);
                            }
                        }
                        else if (propertySymbol.valueDeclaration) {
                            setCommentRange(node, propertySymbol.valueDeclaration);
                        }
                        return node;
                    }
                }
                function mapToTypeNodes(types, context, isBareList) {
                    if (some(types)) {
                        if (checkTruncationLength(context)) {
                            if (!isBareList) {
                                return [factory.createTypeReferenceNode("...", 
                                    /*typeArguments*/
                                    void 0)];
                            }
                            else if (types.length > 2) {
                                return [
                                    typeToTypeNodeHelper(types[0], context),
                                    factory.createTypeReferenceNode(`... ${types.length - 2} more ...`, 
                                    /*typeArguments*/
                                    void 0),
                                    typeToTypeNodeHelper(types[types.length - 1], context)
                                ];
                            }
                        }
                        const mayHaveNameCollisions = !(context.flags & 64 /* UseFullyQualifiedType */);
                        const seenNames = mayHaveNameCollisions ? createUnderscoreEscapedMultiMap() : void 0;
                        const result = [];
                        let i = 0;
                        for (const type of types) {
                            i++;
                            if (checkTruncationLength(context) && i + 2 < types.length - 1) {
                                result.push(factory.createTypeReferenceNode(`... ${types.length - i} more ...`, 
                                /*typeArguments*/
                                void 0));
                                const typeNode2 = typeToTypeNodeHelper(types[types.length - 1], context);
                                if (typeNode2) {
                                    result.push(typeNode2);
                                }
                                break;
                            }
                            context.approximateLength += 2;
                            const typeNode = typeToTypeNodeHelper(type, context);
                            if (typeNode) {
                                result.push(typeNode);
                                if (seenNames && isIdentifierTypeReference(typeNode)) {
                                    seenNames.add(typeNode.typeName.escapedText, [type, result.length - 1]);
                                }
                            }
                        }
                        if (seenNames) {
                            const saveContextFlags = context.flags;
                            context.flags |= 64 /* UseFullyQualifiedType */;
                            seenNames.forEach((types2) => {
                                if (!arrayIsHomogeneous(types2, ([a], [b]) => typesAreSameReference(a, b))) {
                                    for (const [type, resultIndex] of types2) {
                                        result[resultIndex] = typeToTypeNodeHelper(type, context);
                                    }
                                }
                            });
                            context.flags = saveContextFlags;
                        }
                        return result;
                    }
                }
                function typesAreSameReference(a, b) {
                    return a === b || !!a.symbol && a.symbol === b.symbol || !!a.aliasSymbol && a.aliasSymbol === b.aliasSymbol;
                }
                function indexInfoToIndexSignatureDeclarationHelper(indexInfo, context, typeNode) {
                    const name = getNameFromIndexInfo(indexInfo) || "x";
                    const indexerTypeNode = typeToTypeNodeHelper(indexInfo.keyType, context);
                    const indexingParameter = factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, name, 
                    /*questionToken*/
                    void 0, indexerTypeNode, 
                    /*initializer*/
                    void 0);
                    if (!typeNode) {
                        typeNode = typeToTypeNodeHelper(indexInfo.type || anyType, context);
                    }
                    if (!indexInfo.type && !(context.flags & 2097152 /* AllowEmptyIndexInfoType */)) {
                        context.encounteredError = true;
                    }
                    context.approximateLength += name.length + 4;
                    return factory.createIndexSignature(indexInfo.isReadonly ? [factory.createToken(146 /* ReadonlyKeyword */)] : void 0, [indexingParameter], typeNode);
                }
                function signatureToSignatureDeclarationHelper(signature, kind, context, options) {
                    var _a2, _b, _c, _d, _e;
                    const suppressAny = context.flags & 256 /* SuppressAnyReturnType */;
                    if (suppressAny)
                        context.flags &= ~256 /* SuppressAnyReturnType */;
                    context.approximateLength += 3;
                    let typeParameters;
                    let typeArguments;
                    if (context.flags & 32 /* WriteTypeArgumentsOfSignature */ && signature.target && signature.mapper && signature.target.typeParameters) {
                        typeArguments = signature.target.typeParameters.map((parameter) => typeToTypeNodeHelper(instantiateType(parameter, signature.mapper), context));
                    }
                    else {
                        typeParameters = signature.typeParameters && signature.typeParameters.map((parameter) => typeParameterToDeclaration(parameter, context));
                    }
                    const expandedParams = getExpandedParameters(signature, 
                    /*skipUnionExpanding*/
                    true)[0];
                    let cleanup;
                    if (context.enclosingDeclaration && signature.declaration && signature.declaration !== context.enclosingDeclaration && !isInJSFile(signature.declaration) && some(expandedParams)) {
                        const existingFakeScope = getNodeLinks(context.enclosingDeclaration).fakeScopeForSignatureDeclaration ? context.enclosingDeclaration : void 0;
                        Debug.assertOptionalNode(existingFakeScope, isBlock);
                        const locals = (_a2 = existingFakeScope == null ? void 0 : existingFakeScope.locals) != null ? _a2 : createSymbolTable();
                        let newLocals;
                        for (const param of expandedParams) {
                            if (!locals.has(param.escapedName)) {
                                newLocals = append(newLocals, param.escapedName);
                                locals.set(param.escapedName, param);
                            }
                        }
                        if (newLocals) {
                            let removeNewLocals2 = function () {
                                forEach(newLocals, (s) => locals.delete(s));
                            };
                            var removeNewLocals = removeNewLocals2;
                            if (existingFakeScope) {
                                cleanup = removeNewLocals2;
                            }
                            else {
                                const fakeScope = parseNodeFactory.createBlock(emptyArray);
                                getNodeLinks(fakeScope).fakeScopeForSignatureDeclaration = true;
                                fakeScope.locals = locals;
                                const saveEnclosingDeclaration = context.enclosingDeclaration;
                                setParent(fakeScope, saveEnclosingDeclaration);
                                context.enclosingDeclaration = fakeScope;
                                cleanup = () => {
                                    context.enclosingDeclaration = saveEnclosingDeclaration;
                                    removeNewLocals2();
                                };
                            }
                        }
                    }
                    const parameters = (some(expandedParams, (p) => p !== expandedParams[expandedParams.length - 1] && !!(getCheckFlags(p) & 32768 /* RestParameter */)) ? signature.parameters : expandedParams).map((parameter) => symbolToParameterDeclaration(parameter, context, kind === 173 /* Constructor */, options == null ? void 0 : options.privateSymbolVisitor, options == null ? void 0 : options.bundledImports));
                    const thisParameter = context.flags & 33554432 /* OmitThisParameter */ ? void 0 : tryGetThisParameterDeclaration(signature, context);
                    if (thisParameter) {
                        parameters.unshift(thisParameter);
                    }
                    let returnTypeNode;
                    const typePredicate = getTypePredicateOfSignature(signature);
                    if (typePredicate) {
                        const assertsModifier = typePredicate.kind === 2 /* AssertsThis */ || typePredicate.kind === 3 /* AssertsIdentifier */ ? factory.createToken(129 /* AssertsKeyword */) : void 0;
                        const parameterName = typePredicate.kind === 1 /* Identifier */ || typePredicate.kind === 3 /* AssertsIdentifier */ ? setEmitFlags(factory.createIdentifier(typePredicate.parameterName), 33554432 /* NoAsciiEscaping */) : factory.createThisTypeNode();
                        const typeNode = typePredicate.type && typeToTypeNodeHelper(typePredicate.type, context);
                        returnTypeNode = factory.createTypePredicateNode(assertsModifier, parameterName, typeNode);
                    }
                    else {
                        const returnType = getReturnTypeOfSignature(signature);
                        if (returnType && !(suppressAny && isTypeAny(returnType))) {
                            returnTypeNode = serializeReturnTypeForSignature(context, returnType, signature, options == null ? void 0 : options.privateSymbolVisitor, options == null ? void 0 : options.bundledImports);
                        }
                        else if (!suppressAny) {
                            returnTypeNode = factory.createKeywordTypeNode(131 /* AnyKeyword */);
                        }
                    }
                    let modifiers = options == null ? void 0 : options.modifiers;
                    if (kind === 182 /* ConstructorType */ && signature.flags & 4 /* Abstract */) {
                        const flags = modifiersToFlags(modifiers);
                        modifiers = factory.createModifiersFromModifierFlags(flags | 256 /* Abstract */);
                    }
                    const node = kind === 176 /* CallSignature */ ? factory.createCallSignature(typeParameters, parameters, returnTypeNode) : kind === 177 /* ConstructSignature */ ? factory.createConstructSignature(typeParameters, parameters, returnTypeNode) : kind === 170 /* MethodSignature */ ? factory.createMethodSignature(modifiers, (_b = options == null ? void 0 : options.name) != null ? _b : factory.createIdentifier(""), options == null ? void 0 : options.questionToken, typeParameters, parameters, returnTypeNode) : kind === 171 /* MethodDeclaration */ ? factory.createMethodDeclaration(modifiers, 
                    /*asteriskToken*/
                    void 0, (_c = options == null ? void 0 : options.name) != null ? _c : factory.createIdentifier(""), 
                    /*questionToken*/
                    void 0, typeParameters, parameters, returnTypeNode, 
                    /*body*/
                    void 0) : kind === 173 /* Constructor */ ? factory.createConstructorDeclaration(modifiers, parameters, 
                    /*body*/
                    void 0) : kind === 174 /* GetAccessor */ ? factory.createGetAccessorDeclaration(modifiers, (_d = options == null ? void 0 : options.name) != null ? _d : factory.createIdentifier(""), parameters, returnTypeNode, 
                    /*body*/
                    void 0) : kind === 175 /* SetAccessor */ ? factory.createSetAccessorDeclaration(modifiers, (_e = options == null ? void 0 : options.name) != null ? _e : factory.createIdentifier(""), parameters, 
                    /*body*/
                    void 0) : kind === 178 /* IndexSignature */ ? factory.createIndexSignature(modifiers, parameters, returnTypeNode) : kind === 320 /* JSDocFunctionType */ ? factory.createJSDocFunctionType(parameters, returnTypeNode) : kind === 181 /* FunctionType */ ? factory.createFunctionTypeNode(typeParameters, parameters, returnTypeNode != null ? returnTypeNode : factory.createTypeReferenceNode(factory.createIdentifier(""))) : kind === 182 /* ConstructorType */ ? factory.createConstructorTypeNode(modifiers, typeParameters, parameters, returnTypeNode != null ? returnTypeNode : factory.createTypeReferenceNode(factory.createIdentifier(""))) : kind === 259 /* FunctionDeclaration */ ? factory.createFunctionDeclaration(modifiers, 
                    /*asteriskToken*/
                    void 0, (options == null ? void 0 : options.name) ? cast(options.name, isIdentifier) : factory.createIdentifier(""), typeParameters, parameters, returnTypeNode, 
                    /*body*/
                    void 0) : kind === 215 /* FunctionExpression */ ? factory.createFunctionExpression(modifiers, 
                    /*asteriskToken*/
                    void 0, (options == null ? void 0 : options.name) ? cast(options.name, isIdentifier) : factory.createIdentifier(""), typeParameters, parameters, returnTypeNode, factory.createBlock([])) : kind === 216 /* ArrowFunction */ ? factory.createArrowFunction(modifiers, typeParameters, parameters, returnTypeNode, 
                    /*equalsGreaterThanToken*/
                    void 0, factory.createBlock([])) : Debug.assertNever(kind);
                    if (typeArguments) {
                        node.typeArguments = factory.createNodeArray(typeArguments);
                    }
                    cleanup == null ? void 0 : cleanup();
                    return node;
                }
                function tryGetThisParameterDeclaration(signature, context) {
                    if (signature.thisParameter) {
                        return symbolToParameterDeclaration(signature.thisParameter, context);
                    }
                    if (signature.declaration && isInJSFile(signature.declaration)) {
                        const thisTag = getJSDocThisTag(signature.declaration);
                        if (thisTag && thisTag.typeExpression) {
                            return factory.createParameterDeclaration(
                            /* modifiers */
                            void 0, 
                            /* dotDotDotToken */
                            void 0, "this", 
                            /* questionToken */
                            void 0, typeToTypeNodeHelper(getTypeFromTypeNode(thisTag.typeExpression), context));
                        }
                    }
                }
                function typeParameterToDeclarationWithConstraint(type, context, constraintNode) {
                    const savedContextFlags = context.flags;
                    context.flags &= ~512 /* WriteTypeParametersInQualifiedName */;
                    const modifiers = factory.createModifiersFromModifierFlags(getTypeParameterModifiers(type));
                    const name = typeParameterToName(type, context);
                    const defaultParameter = getDefaultFromTypeParameter(type);
                    const defaultParameterNode = defaultParameter && typeToTypeNodeHelper(defaultParameter, context);
                    context.flags = savedContextFlags;
                    return factory.createTypeParameterDeclaration(modifiers, name, constraintNode, defaultParameterNode);
                }
                function typeParameterToDeclaration(type, context, constraint = getConstraintOfTypeParameter(type)) {
                    const constraintNode = constraint && typeToTypeNodeHelper(constraint, context);
                    return typeParameterToDeclarationWithConstraint(type, context, constraintNode);
                }
                function symbolToParameterDeclaration(parameterSymbol, context, preserveModifierFlags, privateSymbolVisitor, bundledImports) {
                    let parameterDeclaration = getDeclarationOfKind(parameterSymbol, 166 /* Parameter */);
                    if (!parameterDeclaration && !isTransientSymbol(parameterSymbol)) {
                        parameterDeclaration = getDeclarationOfKind(parameterSymbol, 344 /* JSDocParameterTag */);
                    }
                    let parameterType = getTypeOfSymbol(parameterSymbol);
                    if (parameterDeclaration && isRequiredInitializedParameter(parameterDeclaration)) {
                        parameterType = getOptionalType(parameterType);
                    }
                    const parameterTypeNode = serializeTypeForDeclaration(context, parameterType, parameterSymbol, context.enclosingDeclaration, privateSymbolVisitor, bundledImports);
                    const modifiers = !(context.flags & 8192 /* OmitParameterModifiers */) && preserveModifierFlags && parameterDeclaration && canHaveModifiers(parameterDeclaration) ? map(getModifiers(parameterDeclaration), factory.cloneNode) : void 0;
                    const isRest = parameterDeclaration && isRestParameter(parameterDeclaration) || getCheckFlags(parameterSymbol) & 32768 /* RestParameter */;
                    const dotDotDotToken = isRest ? factory.createToken(25 /* DotDotDotToken */) : void 0;
                    const name = parameterDeclaration ? parameterDeclaration.name ? parameterDeclaration.name.kind === 79 /* Identifier */ ? setEmitFlags(factory.cloneNode(parameterDeclaration.name), 33554432 /* NoAsciiEscaping */) : parameterDeclaration.name.kind === 163 /* QualifiedName */ ? setEmitFlags(factory.cloneNode(parameterDeclaration.name.right), 33554432 /* NoAsciiEscaping */) : cloneBindingName(parameterDeclaration.name) : symbolName(parameterSymbol) : symbolName(parameterSymbol);
                    const isOptional = parameterDeclaration && isOptionalParameter(parameterDeclaration) || getCheckFlags(parameterSymbol) & 16384 /* OptionalParameter */;
                    const questionToken = isOptional ? factory.createToken(57 /* QuestionToken */) : void 0;
                    const parameterNode = factory.createParameterDeclaration(modifiers, dotDotDotToken, name, questionToken, parameterTypeNode, 
                    /*initializer*/
                    void 0);
                    context.approximateLength += symbolName(parameterSymbol).length + 3;
                    return parameterNode;
                    function cloneBindingName(node) {
                        return elideInitializerAndSetEmitFlags(node);
                        function elideInitializerAndSetEmitFlags(node2) {
                            if (context.tracker.canTrackSymbol && isComputedPropertyName(node2) && isLateBindableName(node2)) {
                                trackComputedName(node2.expression, context.enclosingDeclaration, context);
                            }
                            let visited = visitEachChild(node2, elideInitializerAndSetEmitFlags, nullTransformationContext, 
                            /*nodesVisitor*/
                            void 0, elideInitializerAndSetEmitFlags);
                            if (isBindingElement(visited)) {
                                visited = factory.updateBindingElement(visited, visited.dotDotDotToken, visited.propertyName, visited.name, 
                                /*initializer*/
                                void 0);
                            }
                            if (!nodeIsSynthesized(visited)) {
                                visited = factory.cloneNode(visited);
                            }
                            return setEmitFlags(visited, 1 /* SingleLine */ | 33554432 /* NoAsciiEscaping */);
                        }
                    }
                }
                function trackComputedName(accessExpression, enclosingDeclaration, context) {
                    if (!context.tracker.canTrackSymbol)
                        return;
                    const firstIdentifier = getFirstIdentifier(accessExpression);
                    const name = resolveName(firstIdentifier, firstIdentifier.escapedText, 111551 /* Value */ | 1048576 /* ExportValue */, 
                    /*nodeNotFoundErrorMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    true);
                    if (name) {
                        context.tracker.trackSymbol(name, enclosingDeclaration, 111551 /* Value */);
                    }
                }
                function lookupSymbolChain(symbol, context, meaning, yieldModuleSymbol) {
                    context.tracker.trackSymbol(symbol, context.enclosingDeclaration, meaning);
                    return lookupSymbolChainWorker(symbol, context, meaning, yieldModuleSymbol);
                }
                function lookupSymbolChainWorker(symbol, context, meaning, yieldModuleSymbol) {
                    let chain;
                    const isTypeParameter = symbol.flags & 262144 /* TypeParameter */;
                    if (!isTypeParameter && (context.enclosingDeclaration || context.flags & 64 /* UseFullyQualifiedType */) && !(context.flags & 134217728 /* DoNotIncludeSymbolChain */)) {
                        chain = Debug.checkDefined(getSymbolChain(symbol, meaning, 
                        /*endOfChain*/
                        true));
                        Debug.assert(chain && chain.length > 0);
                    }
                    else {
                        chain = [symbol];
                    }
                    return chain;
                    function getSymbolChain(symbol2, meaning2, endOfChain) {
                        let accessibleSymbolChain = getAccessibleSymbolChain(symbol2, context.enclosingDeclaration, meaning2, !!(context.flags & 128 /* UseOnlyExternalAliasing */));
                        let parentSpecifiers;
                        if (!accessibleSymbolChain || needsQualification(accessibleSymbolChain[0], context.enclosingDeclaration, accessibleSymbolChain.length === 1 ? meaning2 : getQualifiedLeftMeaning(meaning2))) {
                            const parents = getContainersOfSymbol(accessibleSymbolChain ? accessibleSymbolChain[0] : symbol2, context.enclosingDeclaration, meaning2);
                            if (length(parents)) {
                                parentSpecifiers = parents.map((symbol3) => some(symbol3.declarations, hasNonGlobalAugmentationExternalModuleSymbol) ? getSpecifierForModuleSymbol(symbol3, context) : void 0);
                                const indices = parents.map((_, i) => i);
                                indices.sort(sortByBestName);
                                const sortedParents = indices.map((i) => parents[i]);
                                for (const parent2 of sortedParents) {
                                    const parentChain = getSymbolChain(parent2, getQualifiedLeftMeaning(meaning2), 
                                    /*endOfChain*/
                                    false);
                                    if (parentChain) {
                                        if (parent2.exports && parent2.exports.get("export=" /* ExportEquals */) && getSymbolIfSameReference(parent2.exports.get("export=" /* ExportEquals */), symbol2)) {
                                            accessibleSymbolChain = parentChain;
                                            break;
                                        }
                                        accessibleSymbolChain = parentChain.concat(accessibleSymbolChain || [getAliasForSymbolInContainer(parent2, symbol2) || symbol2]);
                                        break;
                                    }
                                }
                            }
                        }
                        if (accessibleSymbolChain) {
                            return accessibleSymbolChain;
                        }
                        if (
                        // If this is the last part of outputting the symbol, always output. The cases apply only to parent symbols.
                        endOfChain || // If a parent symbol is an anonymous type, don't write it.
                            !(symbol2.flags & (2048 /* TypeLiteral */ | 4096 /* ObjectLiteral */))) {
                            if (!endOfChain && !yieldModuleSymbol && !!forEach(symbol2.declarations, hasNonGlobalAugmentationExternalModuleSymbol)) {
                                return;
                            }
                            return [symbol2];
                        }
                        function sortByBestName(a, b) {
                            const specifierA = parentSpecifiers[a];
                            const specifierB = parentSpecifiers[b];
                            if (specifierA && specifierB) {
                                const isBRelative = pathIsRelative(specifierB);
                                if (pathIsRelative(specifierA) === isBRelative) {
                                    return countPathComponents(specifierA) - countPathComponents(specifierB);
                                }
                                if (isBRelative) {
                                    return -1;
                                }
                                return 1;
                            }
                            return 0;
                        }
                    }
                }
                function typeParametersToTypeParameterDeclarations(symbol, context) {
                    let typeParameterNodes;
                    const targetSymbol = getTargetSymbol(symbol);
                    if (targetSymbol.flags & (32 /* Class */ | 64 /* Interface */ | 524288 /* TypeAlias */)) {
                        typeParameterNodes = factory.createNodeArray(map(getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol), (tp) => typeParameterToDeclaration(tp, context)));
                    }
                    return typeParameterNodes;
                }
                function lookupTypeParameterNodes(chain, index, context) {
                    var _a2;
                    Debug.assert(chain && 0 <= index && index < chain.length);
                    const symbol = chain[index];
                    const symbolId = getSymbolId(symbol);
                    if ((_a2 = context.typeParameterSymbolList) == null ? void 0 : _a2.has(symbolId)) {
                        return void 0;
                    }
                    (context.typeParameterSymbolList || (context.typeParameterSymbolList = /* @__PURE__ */ new Set())).add(symbolId);
                    let typeParameterNodes;
                    if (context.flags & 512 /* WriteTypeParametersInQualifiedName */ && index < chain.length - 1) {
                        const parentSymbol = symbol;
                        const nextSymbol = chain[index + 1];
                        if (getCheckFlags(nextSymbol) & 1 /* Instantiated */) {
                            const params = getTypeParametersOfClassOrInterface(parentSymbol.flags & 2097152 /* Alias */ ? resolveAlias(parentSymbol) : parentSymbol);
                            typeParameterNodes = mapToTypeNodes(map(params, (t) => getMappedType(t, nextSymbol.links.mapper)), context);
                        }
                        else {
                            typeParameterNodes = typeParametersToTypeParameterDeclarations(symbol, context);
                        }
                    }
                    return typeParameterNodes;
                }
                function getTopmostIndexedAccessType(top) {
                    if (isIndexedAccessTypeNode(top.objectType)) {
                        return getTopmostIndexedAccessType(top.objectType);
                    }
                    return top;
                }
                function getSpecifierForModuleSymbol(symbol, context, overrideImportMode) {
                    var _a2;
                    let file = getDeclarationOfKind(symbol, 308 /* SourceFile */);
                    if (!file) {
                        const equivalentFileSymbol = firstDefined(symbol.declarations, (d) => getFileSymbolIfFileSymbolExportEqualsContainer(d, symbol));
                        if (equivalentFileSymbol) {
                            file = getDeclarationOfKind(equivalentFileSymbol, 308 /* SourceFile */);
                        }
                    }
                    if (file && file.moduleName !== void 0) {
                        return file.moduleName;
                    }
                    if (!file) {
                        if (context.tracker.trackReferencedAmbientModule) {
                            const ambientDecls = filter(symbol.declarations, isAmbientModule);
                            if (length(ambientDecls)) {
                                for (const decl of ambientDecls) {
                                    context.tracker.trackReferencedAmbientModule(decl, symbol);
                                }
                            }
                        }
                        if (ambientModuleSymbolRegex.test(symbol.escapedName)) {
                            return symbol.escapedName.substring(1, symbol.escapedName.length - 1);
                        }
                    }
                    if (!context.enclosingDeclaration || !context.tracker.moduleResolverHost) {
                        if (ambientModuleSymbolRegex.test(symbol.escapedName)) {
                            return symbol.escapedName.substring(1, symbol.escapedName.length - 1);
                        }
                        return getSourceFileOfNode(getNonAugmentationDeclaration(symbol)).fileName;
                    }
                    const contextFile = getSourceFileOfNode(getOriginalNode(context.enclosingDeclaration));
                    const resolutionMode = overrideImportMode || (contextFile == null ? void 0 : contextFile.impliedNodeFormat);
                    const cacheKey = createModeAwareCacheKey(contextFile.path, resolutionMode);
                    const links = getSymbolLinks(symbol);
                    let specifier = links.specifierCache && links.specifierCache.get(cacheKey);
                    if (!specifier) {
                        const isBundle2 = !!outFile(compilerOptions);
                        const { moduleResolverHost } = context.tracker;
                        const specifierCompilerOptions = isBundle2 ? { ...compilerOptions, baseUrl: moduleResolverHost.getCommonSourceDirectory() } : compilerOptions;
                        specifier = first(getModuleSpecifiers(symbol, checker, specifierCompilerOptions, contextFile, moduleResolverHost, {
                            importModuleSpecifierPreference: isBundle2 ? "non-relative" : "project-relative",
                            importModuleSpecifierEnding: isBundle2 ? "minimal" : resolutionMode === 99 /* ESNext */ ? "js" : void 0
                        }, { overrideImportMode }));
                        (_a2 = links.specifierCache) != null ? _a2 : links.specifierCache = /* @__PURE__ */ new Map();
                        links.specifierCache.set(cacheKey, specifier);
                    }
                    return specifier;
                }
                function symbolToEntityNameNode(symbol) {
                    const identifier = factory.createIdentifier(unescapeLeadingUnderscores(symbol.escapedName));
                    return symbol.parent ? factory.createQualifiedName(symbolToEntityNameNode(symbol.parent), identifier) : identifier;
                }
                function symbolToTypeNode(symbol, context, meaning, overrideTypeArguments) {
                    var _a2, _b, _c, _d;
                    const chain = lookupSymbolChain(symbol, context, meaning, !(context.flags & 16384 /* UseAliasDefinedOutsideCurrentScope */));
                    const isTypeOf = meaning === 111551 /* Value */;
                    if (some(chain[0].declarations, hasNonGlobalAugmentationExternalModuleSymbol)) {
                        const nonRootParts = chain.length > 1 ? createAccessFromSymbolChain(chain, chain.length - 1, 1) : void 0;
                        const typeParameterNodes = overrideTypeArguments || lookupTypeParameterNodes(chain, 0, context);
                        const contextFile = getSourceFileOfNode(getOriginalNode(context.enclosingDeclaration));
                        const targetFile = getSourceFileOfModule(chain[0]);
                        let specifier;
                        let assertion;
                        if (getEmitModuleResolutionKind(compilerOptions) === 3 /* Node16 */ || getEmitModuleResolutionKind(compilerOptions) === 99 /* NodeNext */) {
                            if ((targetFile == null ? void 0 : targetFile.impliedNodeFormat) === 99 /* ESNext */ && targetFile.impliedNodeFormat !== (contextFile == null ? void 0 : contextFile.impliedNodeFormat)) {
                                specifier = getSpecifierForModuleSymbol(chain[0], context, 99 /* ESNext */);
                                assertion = factory.createImportTypeAssertionContainer(factory.createAssertClause(factory.createNodeArray([
                                    factory.createAssertEntry(factory.createStringLiteral("resolution-mode"), factory.createStringLiteral("import"))
                                ])));
                                (_b = (_a2 = context.tracker).reportImportTypeNodeResolutionModeOverride) == null ? void 0 : _b.call(_a2);
                            }
                        }
                        if (!specifier) {
                            specifier = getSpecifierForModuleSymbol(chain[0], context);
                        }
                        if (!(context.flags & 67108864 /* AllowNodeModulesRelativePaths */) && getEmitModuleResolutionKind(compilerOptions) !== 1 /* Classic */ && specifier.indexOf("/node_modules/") >= 0) {
                            const oldSpecifier = specifier;
                            if (getEmitModuleResolutionKind(compilerOptions) === 3 /* Node16 */ || getEmitModuleResolutionKind(compilerOptions) === 99 /* NodeNext */) {
                                const swappedMode = (contextFile == null ? void 0 : contextFile.impliedNodeFormat) === 99 /* ESNext */ ? 1 /* CommonJS */ : 99 /* ESNext */;
                                specifier = getSpecifierForModuleSymbol(chain[0], context, swappedMode);
                                if (specifier.indexOf("/node_modules/") >= 0) {
                                    specifier = oldSpecifier;
                                }
                                else {
                                    assertion = factory.createImportTypeAssertionContainer(factory.createAssertClause(factory.createNodeArray([
                                        factory.createAssertEntry(factory.createStringLiteral("resolution-mode"), factory.createStringLiteral(swappedMode === 99 /* ESNext */ ? "import" : "require"))
                                    ])));
                                    (_d = (_c = context.tracker).reportImportTypeNodeResolutionModeOverride) == null ? void 0 : _d.call(_c);
                                }
                            }
                            if (!assertion) {
                                context.encounteredError = true;
                                if (context.tracker.reportLikelyUnsafeImportRequiredError) {
                                    context.tracker.reportLikelyUnsafeImportRequiredError(oldSpecifier);
                                }
                            }
                        }
                        const lit = factory.createLiteralTypeNode(factory.createStringLiteral(specifier));
                        if (context.tracker.trackExternalModuleSymbolOfImportTypeNode)
                            context.tracker.trackExternalModuleSymbolOfImportTypeNode(chain[0]);
                        context.approximateLength += specifier.length + 10;
                        if (!nonRootParts || isEntityName(nonRootParts)) {
                            if (nonRootParts) {
                                const lastId = isIdentifier(nonRootParts) ? nonRootParts : nonRootParts.right;
                                setIdentifierTypeArguments(lastId, 
                                /*typeArguments*/
                                void 0);
                            }
                            return factory.createImportTypeNode(lit, assertion, nonRootParts, typeParameterNodes, isTypeOf);
                        }
                        else {
                            const splitNode = getTopmostIndexedAccessType(nonRootParts);
                            const qualifier = splitNode.objectType.typeName;
                            return factory.createIndexedAccessTypeNode(factory.createImportTypeNode(lit, assertion, qualifier, typeParameterNodes, isTypeOf), splitNode.indexType);
                        }
                    }
                    const entityName = createAccessFromSymbolChain(chain, chain.length - 1, 0);
                    if (isIndexedAccessTypeNode(entityName)) {
                        return entityName;
                    }
                    if (isTypeOf) {
                        return factory.createTypeQueryNode(entityName);
                    }
                    else {
                        const lastId = isIdentifier(entityName) ? entityName : entityName.right;
                        const lastTypeArgs = getIdentifierTypeArguments(lastId);
                        setIdentifierTypeArguments(lastId, 
                        /*typeArguments*/
                        void 0);
                        return factory.createTypeReferenceNode(entityName, lastTypeArgs);
                    }
                    function createAccessFromSymbolChain(chain2, index, stopper) {
                        const typeParameterNodes = index === chain2.length - 1 ? overrideTypeArguments : lookupTypeParameterNodes(chain2, index, context);
                        const symbol2 = chain2[index];
                        const parent2 = chain2[index - 1];
                        let symbolName2;
                        if (index === 0) {
                            context.flags |= 16777216 /* InInitialEntityName */;
                            symbolName2 = getNameOfSymbolAsWritten(symbol2, context);
                            context.approximateLength += (symbolName2 ? symbolName2.length : 0) + 1;
                            context.flags ^= 16777216 /* InInitialEntityName */;
                        }
                        else {
                            if (parent2 && getExportsOfSymbol(parent2)) {
                                const exports = getExportsOfSymbol(parent2);
                                forEachEntry(exports, (ex, name) => {
                                    if (getSymbolIfSameReference(ex, symbol2) && !isLateBoundName(name) && name !== "export=" /* ExportEquals */) {
                                        symbolName2 = unescapeLeadingUnderscores(name);
                                        return true;
                                    }
                                });
                            }
                        }
                        if (symbolName2 === void 0) {
                            const name = firstDefined(symbol2.declarations, getNameOfDeclaration);
                            if (name && isComputedPropertyName(name) && isEntityName(name.expression)) {
                                const LHS = createAccessFromSymbolChain(chain2, index - 1, stopper);
                                if (isEntityName(LHS)) {
                                    return factory.createIndexedAccessTypeNode(factory.createParenthesizedType(factory.createTypeQueryNode(LHS)), factory.createTypeQueryNode(name.expression));
                                }
                                return LHS;
                            }
                            symbolName2 = getNameOfSymbolAsWritten(symbol2, context);
                        }
                        context.approximateLength += symbolName2.length + 1;
                        if (!(context.flags & 16 /* ForbidIndexedAccessSymbolReferences */) && parent2 && getMembersOfSymbol(parent2) && getMembersOfSymbol(parent2).get(symbol2.escapedName) && getSymbolIfSameReference(getMembersOfSymbol(parent2).get(symbol2.escapedName), symbol2)) {
                            const LHS = createAccessFromSymbolChain(chain2, index - 1, stopper);
                            if (isIndexedAccessTypeNode(LHS)) {
                                return factory.createIndexedAccessTypeNode(LHS, factory.createLiteralTypeNode(factory.createStringLiteral(symbolName2)));
                            }
                            else {
                                return factory.createIndexedAccessTypeNode(factory.createTypeReferenceNode(LHS, typeParameterNodes), factory.createLiteralTypeNode(factory.createStringLiteral(symbolName2)));
                            }
                        }
                        const identifier = setEmitFlags(factory.createIdentifier(symbolName2), 33554432 /* NoAsciiEscaping */);
                        if (typeParameterNodes)
                            setIdentifierTypeArguments(identifier, factory.createNodeArray(typeParameterNodes));
                        identifier.symbol = symbol2;
                        if (index > stopper) {
                            const LHS = createAccessFromSymbolChain(chain2, index - 1, stopper);
                            if (!isEntityName(LHS)) {
                                return Debug.fail("Impossible construct - an export of an indexed access cannot be reachable");
                            }
                            return factory.createQualifiedName(LHS, identifier);
                        }
                        return identifier;
                    }
                }
                function typeParameterShadowsNameInScope(escapedName, context, type) {
                    const result = resolveName(context.enclosingDeclaration, escapedName, 788968 /* Type */, 
                    /*nameNotFoundArg*/
                    void 0, escapedName, 
                    /*isUse*/
                    false);
                    if (result) {
                        if (result.flags & 262144 /* TypeParameter */ && result === type.symbol) {
                            return false;
                        }
                        return true;
                    }
                    return false;
                }
                function typeParameterToName(type, context) {
                    var _a2, _b;
                    if (context.flags & 4 /* GenerateNamesForShadowedTypeParams */ && context.typeParameterNames) {
                        const cached = context.typeParameterNames.get(getTypeId(type));
                        if (cached) {
                            return cached;
                        }
                    }
                    let result = symbolToName(type.symbol, context, 788968 /* Type */, 
                    /*expectsIdentifier*/
                    true);
                    if (!(result.kind & 79 /* Identifier */)) {
                        return factory.createIdentifier("(Missing type parameter)");
                    }
                    if (context.flags & 4 /* GenerateNamesForShadowedTypeParams */) {
                        const rawtext = result.escapedText;
                        let i = ((_a2 = context.typeParameterNamesByTextNextNameCount) == null ? void 0 : _a2.get(rawtext)) || 0;
                        let text = rawtext;
                        while (((_b = context.typeParameterNamesByText) == null ? void 0 : _b.has(text)) || typeParameterShadowsNameInScope(text, context, type)) {
                            i++;
                            text = `${rawtext}_${i}`;
                        }
                        if (text !== rawtext) {
                            const typeArguments = getIdentifierTypeArguments(result);
                            result = factory.createIdentifier(text);
                            setIdentifierTypeArguments(result, typeArguments);
                        }
                        (context.typeParameterNamesByTextNextNameCount || (context.typeParameterNamesByTextNextNameCount = /* @__PURE__ */ new Map())).set(rawtext, i);
                        (context.typeParameterNames || (context.typeParameterNames = /* @__PURE__ */ new Map())).set(getTypeId(type), result);
                        (context.typeParameterNamesByText || (context.typeParameterNamesByText = /* @__PURE__ */ new Set())).add(rawtext);
                    }
                    return result;
                }
                function symbolToName(symbol, context, meaning, expectsIdentifier) {
                    const chain = lookupSymbolChain(symbol, context, meaning);
                    if (expectsIdentifier && chain.length !== 1 && !context.encounteredError && !(context.flags & 65536 /* AllowQualifiedNameInPlaceOfIdentifier */)) {
                        context.encounteredError = true;
                    }
                    return createEntityNameFromSymbolChain(chain, chain.length - 1);
                    function createEntityNameFromSymbolChain(chain2, index) {
                        const typeParameterNodes = lookupTypeParameterNodes(chain2, index, context);
                        const symbol2 = chain2[index];
                        if (index === 0) {
                            context.flags |= 16777216 /* InInitialEntityName */;
                        }
                        const symbolName2 = getNameOfSymbolAsWritten(symbol2, context);
                        if (index === 0) {
                            context.flags ^= 16777216 /* InInitialEntityName */;
                        }
                        const identifier = setEmitFlags(factory.createIdentifier(symbolName2), 33554432 /* NoAsciiEscaping */);
                        if (typeParameterNodes)
                            setIdentifierTypeArguments(identifier, factory.createNodeArray(typeParameterNodes));
                        identifier.symbol = symbol2;
                        return index > 0 ? factory.createQualifiedName(createEntityNameFromSymbolChain(chain2, index - 1), identifier) : identifier;
                    }
                }
                function symbolToExpression(symbol, context, meaning) {
                    const chain = lookupSymbolChain(symbol, context, meaning);
                    return createExpressionFromSymbolChain(chain, chain.length - 1);
                    function createExpressionFromSymbolChain(chain2, index) {
                        const typeParameterNodes = lookupTypeParameterNodes(chain2, index, context);
                        const symbol2 = chain2[index];
                        if (index === 0) {
                            context.flags |= 16777216 /* InInitialEntityName */;
                        }
                        let symbolName2 = getNameOfSymbolAsWritten(symbol2, context);
                        if (index === 0) {
                            context.flags ^= 16777216 /* InInitialEntityName */;
                        }
                        let firstChar = symbolName2.charCodeAt(0);
                        if (isSingleOrDoubleQuote(firstChar) && some(symbol2.declarations, hasNonGlobalAugmentationExternalModuleSymbol)) {
                            return factory.createStringLiteral(getSpecifierForModuleSymbol(symbol2, context));
                        }
                        if (index === 0 || canUsePropertyAccess(symbolName2, languageVersion)) {
                            const identifier = setEmitFlags(factory.createIdentifier(symbolName2), 33554432 /* NoAsciiEscaping */);
                            if (typeParameterNodes)
                                setIdentifierTypeArguments(identifier, factory.createNodeArray(typeParameterNodes));
                            identifier.symbol = symbol2;
                            return index > 0 ? factory.createPropertyAccessExpression(createExpressionFromSymbolChain(chain2, index - 1), identifier) : identifier;
                        }
                        else {
                            if (firstChar === 91 /* openBracket */) {
                                symbolName2 = symbolName2.substring(1, symbolName2.length - 1);
                                firstChar = symbolName2.charCodeAt(0);
                            }
                            let expression;
                            if (isSingleOrDoubleQuote(firstChar) && !(symbol2.flags & 8 /* EnumMember */)) {
                                expression = factory.createStringLiteral(stripQuotes(symbolName2).replace(/\\./g, (s) => s.substring(1)), firstChar === 39 /* singleQuote */);
                            }
                            else if ("" + +symbolName2 === symbolName2) {
                                expression = factory.createNumericLiteral(+symbolName2);
                            }
                            if (!expression) {
                                const identifier = setEmitFlags(factory.createIdentifier(symbolName2), 33554432 /* NoAsciiEscaping */);
                                if (typeParameterNodes)
                                    setIdentifierTypeArguments(identifier, factory.createNodeArray(typeParameterNodes));
                                identifier.symbol = symbol2;
                                expression = identifier;
                            }
                            return factory.createElementAccessExpression(createExpressionFromSymbolChain(chain2, index - 1), expression);
                        }
                    }
                }
                function isStringNamed(d) {
                    const name = getNameOfDeclaration(d);
                    return !!name && isStringLiteral(name);
                }
                function isSingleQuotedStringNamed(d) {
                    const name = getNameOfDeclaration(d);
                    return !!(name && isStringLiteral(name) && (name.singleQuote || !nodeIsSynthesized(name) && startsWith(getTextOfNode(name, 
                    /*includeTrivia*/
                    false), "'")));
                }
                function getPropertyNameNodeForSymbol(symbol, context) {
                    const stringNamed = !!length(symbol.declarations) && every(symbol.declarations, isStringNamed);
                    const singleQuote = !!length(symbol.declarations) && every(symbol.declarations, isSingleQuotedStringNamed);
                    const fromNameType = getPropertyNameNodeForSymbolFromNameType(symbol, context, singleQuote, stringNamed);
                    if (fromNameType) {
                        return fromNameType;
                    }
                    const rawName = unescapeLeadingUnderscores(symbol.escapedName);
                    return createPropertyNameNodeForIdentifierOrLiteral(rawName, getEmitScriptTarget(compilerOptions), singleQuote, stringNamed);
                }
                function getPropertyNameNodeForSymbolFromNameType(symbol, context, singleQuote, stringNamed) {
                    const nameType = getSymbolLinks(symbol).nameType;
                    if (nameType) {
                        if (nameType.flags & 384 /* StringOrNumberLiteral */) {
                            const name = "" + nameType.value;
                            if (!isIdentifierText(name, getEmitScriptTarget(compilerOptions)) && (stringNamed || !isNumericLiteralName(name))) {
                                return factory.createStringLiteral(name, !!singleQuote);
                            }
                            if (isNumericLiteralName(name) && startsWith(name, "-")) {
                                return factory.createComputedPropertyName(factory.createNumericLiteral(+name));
                            }
                            return createPropertyNameNodeForIdentifierOrLiteral(name, getEmitScriptTarget(compilerOptions));
                        }
                        if (nameType.flags & 8192 /* UniqueESSymbol */) {
                            return factory.createComputedPropertyName(symbolToExpression(nameType.symbol, context, 111551 /* Value */));
                        }
                    }
                }
                function cloneNodeBuilderContext(context) {
                    const initial = { ...context };
                    if (initial.typeParameterNames) {
                        initial.typeParameterNames = new Map(initial.typeParameterNames);
                    }
                    if (initial.typeParameterNamesByText) {
                        initial.typeParameterNamesByText = new Set(initial.typeParameterNamesByText);
                    }
                    if (initial.typeParameterSymbolList) {
                        initial.typeParameterSymbolList = new Set(initial.typeParameterSymbolList);
                    }
                    initial.tracker = new SymbolTrackerImpl(initial, initial.tracker.inner, initial.tracker.moduleResolverHost);
                    return initial;
                }
                function getDeclarationWithTypeAnnotation(symbol, enclosingDeclaration) {
                    return symbol.declarations && find(symbol.declarations, (s) => !!getEffectiveTypeAnnotationNode(s) && (!enclosingDeclaration || !!findAncestor(s, (n) => n === enclosingDeclaration)));
                }
                function existingTypeNodeIsNotReferenceOrIsReferenceWithCompatibleTypeArgumentCount(existing, type) {
                    return !(getObjectFlags(type) & 4 /* Reference */) || !isTypeReferenceNode(existing) || length(existing.typeArguments) >= getMinTypeArgumentCount(type.target.typeParameters);
                }
                function getEnclosingDeclarationIgnoringFakeScope(enclosingDeclaration) {
                    return getNodeLinks(enclosingDeclaration).fakeScopeForSignatureDeclaration ? enclosingDeclaration.parent : enclosingDeclaration;
                }
                function serializeTypeForDeclaration(context, type, symbol, enclosingDeclaration, includePrivateSymbol, bundled) {
                    if (!isErrorType(type) && enclosingDeclaration) {
                        const declWithExistingAnnotation = getDeclarationWithTypeAnnotation(symbol, getEnclosingDeclarationIgnoringFakeScope(enclosingDeclaration));
                        if (declWithExistingAnnotation && !isFunctionLikeDeclaration(declWithExistingAnnotation) && !isGetAccessorDeclaration(declWithExistingAnnotation)) {
                            const existing = getEffectiveTypeAnnotationNode(declWithExistingAnnotation);
                            if (typeNodeIsEquivalentToType(existing, declWithExistingAnnotation, type) && existingTypeNodeIsNotReferenceOrIsReferenceWithCompatibleTypeArgumentCount(existing, type)) {
                                const result2 = serializeExistingTypeNode(context, existing, includePrivateSymbol, bundled);
                                if (result2) {
                                    return result2;
                                }
                            }
                        }
                    }
                    const oldFlags = context.flags;
                    if (type.flags & 8192 /* UniqueESSymbol */ && type.symbol === symbol && (!context.enclosingDeclaration || some(symbol.declarations, (d) => getSourceFileOfNode(d) === getSourceFileOfNode(context.enclosingDeclaration)))) {
                        context.flags |= 1048576 /* AllowUniqueESSymbolType */;
                    }
                    const result = typeToTypeNodeHelper(type, context);
                    context.flags = oldFlags;
                    return result;
                }
                function typeNodeIsEquivalentToType(typeNode, annotatedDeclaration, type) {
                    const typeFromTypeNode = getTypeFromTypeNode(typeNode);
                    if (typeFromTypeNode === type) {
                        return true;
                    }
                    if (isParameter(annotatedDeclaration) && annotatedDeclaration.questionToken) {
                        return getTypeWithFacts(type, 524288 /* NEUndefined */) === typeFromTypeNode;
                    }
                    return false;
                }
                function serializeReturnTypeForSignature(context, type, signature, includePrivateSymbol, bundled) {
                    if (!isErrorType(type) && context.enclosingDeclaration) {
                        const annotation = signature.declaration && getEffectiveReturnTypeNode(signature.declaration);
                        const enclosingDeclarationIgnoringFakeScope = getEnclosingDeclarationIgnoringFakeScope(context.enclosingDeclaration);
                        if (!!findAncestor(annotation, (n) => n === enclosingDeclarationIgnoringFakeScope) && annotation) {
                            const annotated = getTypeFromTypeNode(annotation);
                            const thisInstantiated = annotated.flags & 262144 /* TypeParameter */ && annotated.isThisType ? instantiateType(annotated, signature.mapper) : annotated;
                            if (thisInstantiated === type && existingTypeNodeIsNotReferenceOrIsReferenceWithCompatibleTypeArgumentCount(annotation, type)) {
                                const result = serializeExistingTypeNode(context, annotation, includePrivateSymbol, bundled);
                                if (result) {
                                    return result;
                                }
                            }
                        }
                    }
                    return typeToTypeNodeHelper(type, context);
                }
                function trackExistingEntityName(node, context, includePrivateSymbol) {
                    let introducesError = false;
                    const leftmost = getFirstIdentifier(node);
                    if (isInJSFile(node) && (isExportsIdentifier(leftmost) || isModuleExportsAccessExpression(leftmost.parent) || isQualifiedName(leftmost.parent) && isModuleIdentifier(leftmost.parent.left) && isExportsIdentifier(leftmost.parent.right))) {
                        introducesError = true;
                        return { introducesError, node };
                    }
                    const sym = resolveEntityName(leftmost, 67108863 /* All */, 
                    /*ignoreErrors*/
                    true, 
                    /*dontResolveALias*/
                    true);
                    if (sym) {
                        if (isSymbolAccessible(sym, context.enclosingDeclaration, 67108863 /* All */, 
                        /*shouldComputeAliasesToMakeVisible*/
                        false).accessibility !== 0 /* Accessible */) {
                            introducesError = true;
                        }
                        else {
                            context.tracker.trackSymbol(sym, context.enclosingDeclaration, 67108863 /* All */);
                            includePrivateSymbol == null ? void 0 : includePrivateSymbol(sym);
                        }
                        if (isIdentifier(node)) {
                            const type = getDeclaredTypeOfSymbol(sym);
                            const name = sym.flags & 262144 /* TypeParameter */ && !isTypeSymbolAccessible(type.symbol, context.enclosingDeclaration) ? typeParameterToName(type, context) : factory.cloneNode(node);
                            name.symbol = sym;
                            return { introducesError, node: setEmitFlags(setOriginalNode(name, node), 33554432 /* NoAsciiEscaping */) };
                        }
                    }
                    return { introducesError, node };
                }
                function serializeExistingTypeNode(context, existing, includePrivateSymbol, bundled) {
                    if (cancellationToken && cancellationToken.throwIfCancellationRequested) {
                        cancellationToken.throwIfCancellationRequested();
                    }
                    let hadError = false;
                    const file = getSourceFileOfNode(existing);
                    const transformed = visitNode(existing, visitExistingNodeTreeSymbols, isTypeNode);
                    if (hadError) {
                        return void 0;
                    }
                    return transformed === existing ? setTextRange(factory.cloneNode(existing), existing) : transformed;
                    function visitExistingNodeTreeSymbols(node) {
                        if (isJSDocAllType(node) || node.kind === 322 /* JSDocNamepathType */) {
                            return factory.createKeywordTypeNode(131 /* AnyKeyword */);
                        }
                        if (isJSDocUnknownType(node)) {
                            return factory.createKeywordTypeNode(157 /* UnknownKeyword */);
                        }
                        if (isJSDocNullableType(node)) {
                            return factory.createUnionTypeNode([visitNode(node.type, visitExistingNodeTreeSymbols, isTypeNode), factory.createLiteralTypeNode(factory.createNull())]);
                        }
                        if (isJSDocOptionalType(node)) {
                            return factory.createUnionTypeNode([visitNode(node.type, visitExistingNodeTreeSymbols, isTypeNode), factory.createKeywordTypeNode(155 /* UndefinedKeyword */)]);
                        }
                        if (isJSDocNonNullableType(node)) {
                            return visitNode(node.type, visitExistingNodeTreeSymbols);
                        }
                        if (isJSDocVariadicType(node)) {
                            return factory.createArrayTypeNode(visitNode(node.type, visitExistingNodeTreeSymbols, isTypeNode));
                        }
                        if (isJSDocTypeLiteral(node)) {
                            return factory.createTypeLiteralNode(map(node.jsDocPropertyTags, (t) => {
                                const name = isIdentifier(t.name) ? t.name : t.name.right;
                                const typeViaParent = getTypeOfPropertyOfType(getTypeFromTypeNode(node), name.escapedText);
                                const overrideTypeNode = typeViaParent && t.typeExpression && getTypeFromTypeNode(t.typeExpression.type) !== typeViaParent ? typeToTypeNodeHelper(typeViaParent, context) : void 0;
                                return factory.createPropertySignature(
                                /*modifiers*/
                                void 0, name, t.isBracketed || t.typeExpression && isJSDocOptionalType(t.typeExpression.type) ? factory.createToken(57 /* QuestionToken */) : void 0, overrideTypeNode || t.typeExpression && visitNode(t.typeExpression.type, visitExistingNodeTreeSymbols, isTypeNode) || factory.createKeywordTypeNode(131 /* AnyKeyword */));
                            }));
                        }
                        if (isTypeReferenceNode(node) && isIdentifier(node.typeName) && node.typeName.escapedText === "") {
                            return setOriginalNode(factory.createKeywordTypeNode(131 /* AnyKeyword */), node);
                        }
                        if ((isExpressionWithTypeArguments(node) || isTypeReferenceNode(node)) && isJSDocIndexSignature(node)) {
                            return factory.createTypeLiteralNode([factory.createIndexSignature(
                                /*modifiers*/
                                void 0, [factory.createParameterDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*dotdotdotToken*/
                                    void 0, "x", 
                                    /*questionToken*/
                                    void 0, visitNode(node.typeArguments[0], visitExistingNodeTreeSymbols, isTypeNode))], visitNode(node.typeArguments[1], visitExistingNodeTreeSymbols, isTypeNode))]);
                        }
                        if (isJSDocFunctionType(node)) {
                            if (isJSDocConstructSignature(node)) {
                                let newTypeNode;
                                return factory.createConstructorTypeNode(
                                /*modifiers*/
                                void 0, visitNodes2(node.typeParameters, visitExistingNodeTreeSymbols, isTypeParameterDeclaration), mapDefined(node.parameters, (p, i) => p.name && isIdentifier(p.name) && p.name.escapedText === "new" ? (newTypeNode = p.type, void 0) : factory.createParameterDeclaration(
                                /*modifiers*/
                                void 0, getEffectiveDotDotDotForParameter(p), getNameForJSDocFunctionParameter(p, i), p.questionToken, visitNode(p.type, visitExistingNodeTreeSymbols, isTypeNode), 
                                /*initializer*/
                                void 0)), visitNode(newTypeNode || node.type, visitExistingNodeTreeSymbols, isTypeNode) || factory.createKeywordTypeNode(131 /* AnyKeyword */));
                            }
                            else {
                                return factory.createFunctionTypeNode(visitNodes2(node.typeParameters, visitExistingNodeTreeSymbols, isTypeParameterDeclaration), map(node.parameters, (p, i) => factory.createParameterDeclaration(
                                /*modifiers*/
                                void 0, getEffectiveDotDotDotForParameter(p), getNameForJSDocFunctionParameter(p, i), p.questionToken, visitNode(p.type, visitExistingNodeTreeSymbols, isTypeNode), 
                                /*initializer*/
                                void 0)), visitNode(node.type, visitExistingNodeTreeSymbols, isTypeNode) || factory.createKeywordTypeNode(131 /* AnyKeyword */));
                            }
                        }
                        if (isTypeReferenceNode(node) && isInJSDoc(node) && (!existingTypeNodeIsNotReferenceOrIsReferenceWithCompatibleTypeArgumentCount(node, getTypeFromTypeNode(node)) || getIntendedTypeFromJSDocTypeReference(node) || unknownSymbol === resolveTypeReferenceName(node, 788968 /* Type */, 
                        /*ignoreErrors*/
                        true))) {
                            return setOriginalNode(typeToTypeNodeHelper(getTypeFromTypeNode(node), context), node);
                        }
                        if (isLiteralImportTypeNode(node)) {
                            const nodeSymbol = getNodeLinks(node).resolvedSymbol;
                            if (isInJSDoc(node) && nodeSymbol && // The import type resolved using jsdoc fallback logic
                                (!node.isTypeOf && !(nodeSymbol.flags & 788968 /* Type */) || // The import type had type arguments autofilled by js fallback logic
                                    !(length(node.typeArguments) >= getMinTypeArgumentCount(getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(nodeSymbol))))) {
                                return setOriginalNode(typeToTypeNodeHelper(getTypeFromTypeNode(node), context), node);
                            }
                            return factory.updateImportTypeNode(node, factory.updateLiteralTypeNode(node.argument, rewriteModuleSpecifier(node, node.argument.literal)), node.assertions, node.qualifier, visitNodes2(node.typeArguments, visitExistingNodeTreeSymbols, isTypeNode), node.isTypeOf);
                        }
                        if (isEntityName(node) || isEntityNameExpression(node)) {
                            const { introducesError, node: result } = trackExistingEntityName(node, context, includePrivateSymbol);
                            hadError = hadError || introducesError;
                            if (result !== node) {
                                return result;
                            }
                        }
                        if (file && isTupleTypeNode(node) && getLineAndCharacterOfPosition(file, node.pos).line === getLineAndCharacterOfPosition(file, node.end).line) {
                            setEmitFlags(node, 1 /* SingleLine */);
                        }
                        return visitEachChild(node, visitExistingNodeTreeSymbols, nullTransformationContext);
                        function getEffectiveDotDotDotForParameter(p) {
                            return p.dotDotDotToken || (p.type && isJSDocVariadicType(p.type) ? factory.createToken(25 /* DotDotDotToken */) : void 0);
                        }
                        function getNameForJSDocFunctionParameter(p, index) {
                            return p.name && isIdentifier(p.name) && p.name.escapedText === "this" ? "this" : getEffectiveDotDotDotForParameter(p) ? `args` : `arg${index}`;
                        }
                        function rewriteModuleSpecifier(parent2, lit) {
                            if (bundled) {
                                if (context.tracker && context.tracker.moduleResolverHost) {
                                    const targetFile = getExternalModuleFileFromDeclaration(parent2);
                                    if (targetFile) {
                                        const getCanonicalFileName = createGetCanonicalFileName(!!host.useCaseSensitiveFileNames);
                                        const resolverHost = {
                                            getCanonicalFileName,
                                            getCurrentDirectory: () => context.tracker.moduleResolverHost.getCurrentDirectory(),
                                            getCommonSourceDirectory: () => context.tracker.moduleResolverHost.getCommonSourceDirectory()
                                        };
                                        const newName = getResolvedExternalModuleName(resolverHost, targetFile);
                                        return factory.createStringLiteral(newName);
                                    }
                                }
                            }
                            else {
                                if (context.tracker && context.tracker.trackExternalModuleSymbolOfImportTypeNode) {
                                    const moduleSym = resolveExternalModuleNameWorker(lit, lit, 
                                    /*moduleNotFoundError*/
                                    void 0);
                                    if (moduleSym) {
                                        context.tracker.trackExternalModuleSymbolOfImportTypeNode(moduleSym);
                                    }
                                }
                            }
                            return lit;
                        }
                    }
                }
                function symbolTableToDeclarationStatements(symbolTable, context, bundled) {
                    const serializePropertySymbolForClass = makeSerializePropertySymbol(factory.createPropertyDeclaration, 171 /* MethodDeclaration */, 
                    /*useAcessors*/
                    true);
                    const serializePropertySymbolForInterfaceWorker = makeSerializePropertySymbol((mods, name, question, type) => factory.createPropertySignature(mods, name, question, type), 170 /* MethodSignature */, 
                    /*useAcessors*/
                    false);
                    const enclosingDeclaration = context.enclosingDeclaration;
                    let results = [];
                    const visitedSymbols = /* @__PURE__ */ new Set();
                    const deferredPrivatesStack = [];
                    const oldcontext = context;
                    context = {
                        ...oldcontext,
                        usedSymbolNames: new Set(oldcontext.usedSymbolNames),
                        remappedSymbolNames: /* @__PURE__ */ new Map(),
                        tracker: void 0
                    };
                    const tracker = {
                        ...oldcontext.tracker.inner,
                        trackSymbol: (sym, decl, meaning) => {
                            var _a2;
                            const accessibleResult = isSymbolAccessible(sym, decl, meaning, 
                            /*computeAliases*/
                            false);
                            if (accessibleResult.accessibility === 0 /* Accessible */) {
                                const chain = lookupSymbolChainWorker(sym, context, meaning);
                                if (!(sym.flags & 4 /* Property */)) {
                                    includePrivateSymbol(chain[0]);
                                }
                            }
                            else if ((_a2 = oldcontext.tracker.inner) == null ? void 0 : _a2.trackSymbol) {
                                return oldcontext.tracker.inner.trackSymbol(sym, decl, meaning);
                            }
                            return false;
                        }
                    };
                    context.tracker = new SymbolTrackerImpl(context, tracker, oldcontext.tracker.moduleResolverHost);
                    forEachEntry(symbolTable, (symbol, name) => {
                        const baseName = unescapeLeadingUnderscores(name);
                        void getInternalSymbolName(symbol, baseName);
                    });
                    let addingDeclare = !bundled;
                    const exportEquals = symbolTable.get("export=" /* ExportEquals */);
                    if (exportEquals && symbolTable.size > 1 && exportEquals.flags & 2097152 /* Alias */) {
                        symbolTable = createSymbolTable();
                        symbolTable.set("export=" /* ExportEquals */, exportEquals);
                    }
                    visitSymbolTable(symbolTable);
                    return mergeRedundantStatements(results);
                    function isIdentifierAndNotUndefined(node) {
                        return !!node && node.kind === 79 /* Identifier */;
                    }
                    function getNamesOfDeclaration(statement) {
                        if (isVariableStatement(statement)) {
                            return filter(map(statement.declarationList.declarations, getNameOfDeclaration), isIdentifierAndNotUndefined);
                        }
                        return filter([getNameOfDeclaration(statement)], isIdentifierAndNotUndefined);
                    }
                    function flattenExportAssignedNamespace(statements) {
                        const exportAssignment = find(statements, isExportAssignment);
                        const nsIndex = findIndex(statements, isModuleDeclaration);
                        let ns = nsIndex !== -1 ? statements[nsIndex] : void 0;
                        if (ns && exportAssignment && exportAssignment.isExportEquals && isIdentifier(exportAssignment.expression) && isIdentifier(ns.name) && idText(ns.name) === idText(exportAssignment.expression) && ns.body && isModuleBlock(ns.body)) {
                            const excessExports = filter(statements, (s) => !!(getEffectiveModifierFlags(s) & 1 /* Export */));
                            const name = ns.name;
                            let body = ns.body;
                            if (length(excessExports)) {
                                ns = factory.updateModuleDeclaration(ns, ns.modifiers, ns.name, body = factory.updateModuleBlock(body, factory.createNodeArray([...ns.body.statements, factory.createExportDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    false, factory.createNamedExports(map(flatMap(excessExports, (e) => getNamesOfDeclaration(e)), (id) => factory.createExportSpecifier(
                                    /*isTypeOnly*/
                                    false, 
                                    /*alias*/
                                    void 0, id))), 
                                    /*moduleSpecifier*/
                                    void 0)])));
                                statements = [...statements.slice(0, nsIndex), ns, ...statements.slice(nsIndex + 1)];
                            }
                            if (!find(statements, (s) => s !== ns && nodeHasName(s, name))) {
                                results = [];
                                const mixinExportFlag = !some(body.statements, (s) => hasSyntacticModifier(s, 1 /* Export */) || isExportAssignment(s) || isExportDeclaration(s));
                                forEach(body.statements, (s) => {
                                    addResult(s, mixinExportFlag ? 1 /* Export */ : 0 /* None */);
                                });
                                statements = [...filter(statements, (s) => s !== ns && s !== exportAssignment), ...results];
                            }
                        }
                        return statements;
                    }
                    function mergeExportDeclarations(statements) {
                        const exports = filter(statements, (d) => isExportDeclaration(d) && !d.moduleSpecifier && !!d.exportClause && isNamedExports(d.exportClause));
                        if (length(exports) > 1) {
                            const nonExports = filter(statements, (d) => !isExportDeclaration(d) || !!d.moduleSpecifier || !d.exportClause);
                            statements = [...nonExports, factory.createExportDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory.createNamedExports(flatMap(exports, (e) => cast(e.exportClause, isNamedExports).elements)), 
                                /*moduleSpecifier*/
                                void 0)];
                        }
                        const reexports = filter(statements, (d) => isExportDeclaration(d) && !!d.moduleSpecifier && !!d.exportClause && isNamedExports(d.exportClause));
                        if (length(reexports) > 1) {
                            const groups = group(reexports, (decl) => isStringLiteral(decl.moduleSpecifier) ? ">" + decl.moduleSpecifier.text : ">");
                            if (groups.length !== reexports.length) {
                                for (const group2 of groups) {
                                    if (group2.length > 1) {
                                        statements = [
                                            ...filter(statements, (s) => group2.indexOf(s) === -1),
                                            factory.createExportDeclaration(
                                            /*modifiers*/
                                            void 0, 
                                            /*isTypeOnly*/
                                            false, factory.createNamedExports(flatMap(group2, (e) => cast(e.exportClause, isNamedExports).elements)), group2[0].moduleSpecifier)
                                        ];
                                    }
                                }
                            }
                        }
                        return statements;
                    }
                    function inlineExportModifiers(statements) {
                        const index = findIndex(statements, (d) => isExportDeclaration(d) && !d.moduleSpecifier && !d.assertClause && !!d.exportClause && isNamedExports(d.exportClause));
                        if (index >= 0) {
                            const exportDecl = statements[index];
                            const replacements = mapDefined(exportDecl.exportClause.elements, (e) => {
                                if (!e.propertyName) {
                                    const indices = indicesOf(statements);
                                    const associatedIndices = filter(indices, (i) => nodeHasName(statements[i], e.name));
                                    if (length(associatedIndices) && every(associatedIndices, (i) => canHaveExportModifier(statements[i]))) {
                                        for (const index2 of associatedIndices) {
                                            statements[index2] = addExportModifier(statements[index2]);
                                        }
                                        return void 0;
                                    }
                                }
                                return e;
                            });
                            if (!length(replacements)) {
                                orderedRemoveItemAt(statements, index);
                            }
                            else {
                                statements[index] = factory.updateExportDeclaration(exportDecl, exportDecl.modifiers, exportDecl.isTypeOnly, factory.updateNamedExports(exportDecl.exportClause, replacements), exportDecl.moduleSpecifier, exportDecl.assertClause);
                            }
                        }
                        return statements;
                    }
                    function mergeRedundantStatements(statements) {
                        statements = flattenExportAssignedNamespace(statements);
                        statements = mergeExportDeclarations(statements);
                        statements = inlineExportModifiers(statements);
                        if (enclosingDeclaration && (isSourceFile(enclosingDeclaration) && isExternalOrCommonJsModule(enclosingDeclaration) || isModuleDeclaration(enclosingDeclaration)) && (!some(statements, isExternalModuleIndicator) || !hasScopeMarker(statements) && some(statements, needsScopeMarker))) {
                            statements.push(createEmptyExports(factory));
                        }
                        return statements;
                    }
                    function addExportModifier(node) {
                        const flags = (getEffectiveModifierFlags(node) | 1 /* Export */) & ~2 /* Ambient */;
                        return factory.updateModifiers(node, flags);
                    }
                    function removeExportModifier(node) {
                        const flags = getEffectiveModifierFlags(node) & ~1 /* Export */;
                        return factory.updateModifiers(node, flags);
                    }
                    function visitSymbolTable(symbolTable2, suppressNewPrivateContext, propertyAsAlias) {
                        if (!suppressNewPrivateContext) {
                            deferredPrivatesStack.push(/* @__PURE__ */ new Map());
                        }
                        symbolTable2.forEach((symbol) => {
                            serializeSymbol(symbol, 
                            /*isPrivate*/
                            false, !!propertyAsAlias);
                        });
                        if (!suppressNewPrivateContext) {
                            deferredPrivatesStack[deferredPrivatesStack.length - 1].forEach((symbol) => {
                                serializeSymbol(symbol, 
                                /*isPrivate*/
                                true, !!propertyAsAlias);
                            });
                            deferredPrivatesStack.pop();
                        }
                    }
                    function serializeSymbol(symbol, isPrivate, propertyAsAlias) {
                        const visitedSym = getMergedSymbol(symbol);
                        if (visitedSymbols.has(getSymbolId(visitedSym))) {
                            return;
                        }
                        visitedSymbols.add(getSymbolId(visitedSym));
                        const skipMembershipCheck = !isPrivate;
                        if (skipMembershipCheck || !!length(symbol.declarations) && some(symbol.declarations, (d) => !!findAncestor(d, (n) => n === enclosingDeclaration))) {
                            const oldContext = context;
                            context = cloneNodeBuilderContext(context);
                            serializeSymbolWorker(symbol, isPrivate, propertyAsAlias);
                            if (context.reportedDiagnostic) {
                                oldcontext.reportedDiagnostic = context.reportedDiagnostic;
                            }
                            context = oldContext;
                        }
                    }
                    function serializeSymbolWorker(symbol, isPrivate, propertyAsAlias) {
                        var _a2, _b, _c, _d;
                        const symbolName2 = unescapeLeadingUnderscores(symbol.escapedName);
                        const isDefault = symbol.escapedName === "default" /* Default */;
                        if (isPrivate && !(context.flags & 131072 /* AllowAnonymousIdentifier */) && isStringANonContextualKeyword(symbolName2) && !isDefault) {
                            context.encounteredError = true;
                            return;
                        }
                        let needsPostExportDefault = isDefault && !!(symbol.flags & -113 /* ExportDoesNotSupportDefaultModifier */ || symbol.flags & 16 /* Function */ && length(getPropertiesOfType(getTypeOfSymbol(symbol)))) && !(symbol.flags & 2097152 /* Alias */);
                        let needsExportDeclaration = !needsPostExportDefault && !isPrivate && isStringANonContextualKeyword(symbolName2) && !isDefault;
                        if (needsPostExportDefault || needsExportDeclaration) {
                            isPrivate = true;
                        }
                        const modifierFlags = (!isPrivate ? 1 /* Export */ : 0) | (isDefault && !needsPostExportDefault ? 1024 /* Default */ : 0);
                        const isConstMergedWithNS = symbol.flags & 1536 /* Module */ && symbol.flags & (2 /* BlockScopedVariable */ | 1 /* FunctionScopedVariable */ | 4 /* Property */) && symbol.escapedName !== "export=" /* ExportEquals */;
                        const isConstMergedWithNSPrintableAsSignatureMerge = isConstMergedWithNS && isTypeRepresentableAsFunctionNamespaceMerge(getTypeOfSymbol(symbol), symbol);
                        if (symbol.flags & (16 /* Function */ | 8192 /* Method */) || isConstMergedWithNSPrintableAsSignatureMerge) {
                            serializeAsFunctionNamespaceMerge(getTypeOfSymbol(symbol), symbol, getInternalSymbolName(symbol, symbolName2), modifierFlags);
                        }
                        if (symbol.flags & 524288 /* TypeAlias */) {
                            serializeTypeAlias(symbol, symbolName2, modifierFlags);
                        }
                        if (symbol.flags & (2 /* BlockScopedVariable */ | 1 /* FunctionScopedVariable */ | 4 /* Property */) && symbol.escapedName !== "export=" /* ExportEquals */ && !(symbol.flags & 4194304 /* Prototype */) && !(symbol.flags & 32 /* Class */) && !(symbol.flags & 8192 /* Method */) && !isConstMergedWithNSPrintableAsSignatureMerge) {
                            if (propertyAsAlias) {
                                const createdExport = serializeMaybeAliasAssignment(symbol);
                                if (createdExport) {
                                    needsExportDeclaration = false;
                                    needsPostExportDefault = false;
                                }
                            }
                            else {
                                const type = getTypeOfSymbol(symbol);
                                const localName = getInternalSymbolName(symbol, symbolName2);
                                if (!(symbol.flags & 16 /* Function */) && isTypeRepresentableAsFunctionNamespaceMerge(type, symbol)) {
                                    serializeAsFunctionNamespaceMerge(type, symbol, localName, modifierFlags);
                                }
                                else {
                                    const flags = !(symbol.flags & 2 /* BlockScopedVariable */) ? ((_a2 = symbol.parent) == null ? void 0 : _a2.valueDeclaration) && isSourceFile((_b = symbol.parent) == null ? void 0 : _b.valueDeclaration) ? 2 /* Const */ : void 0 : isConstVariable(symbol) ? 2 /* Const */ : 1 /* Let */;
                                    const name = needsPostExportDefault || !(symbol.flags & 4 /* Property */) ? localName : getUnusedName(localName, symbol);
                                    let textRange = symbol.declarations && find(symbol.declarations, (d) => isVariableDeclaration(d));
                                    if (textRange && isVariableDeclarationList(textRange.parent) && textRange.parent.declarations.length === 1) {
                                        textRange = textRange.parent.parent;
                                    }
                                    const propertyAccessRequire = (_c = symbol.declarations) == null ? void 0 : _c.find(isPropertyAccessExpression);
                                    if (propertyAccessRequire && isBinaryExpression(propertyAccessRequire.parent) && isIdentifier(propertyAccessRequire.parent.right) && ((_d = type.symbol) == null ? void 0 : _d.valueDeclaration) && isSourceFile(type.symbol.valueDeclaration)) {
                                        const alias = localName === propertyAccessRequire.parent.right.escapedText ? void 0 : propertyAccessRequire.parent.right;
                                        addResult(factory.createExportDeclaration(
                                        /*modifiers*/
                                        void 0, 
                                        /*isTypeOnly*/
                                        false, factory.createNamedExports([factory.createExportSpecifier(
                                            /*isTypeOnly*/
                                            false, alias, localName)])), 0 /* None */);
                                        context.tracker.trackSymbol(type.symbol, context.enclosingDeclaration, 111551 /* Value */);
                                    }
                                    else {
                                        const statement = setTextRange(factory.createVariableStatement(
                                        /*modifiers*/
                                        void 0, factory.createVariableDeclarationList([
                                            factory.createVariableDeclaration(name, 
                                            /*exclamationToken*/
                                            void 0, serializeTypeForDeclaration(context, type, symbol, enclosingDeclaration, includePrivateSymbol, bundled))
                                        ], flags)), textRange);
                                        addResult(statement, name !== localName ? modifierFlags & ~1 /* Export */ : modifierFlags);
                                        if (name !== localName && !isPrivate) {
                                            addResult(factory.createExportDeclaration(
                                            /*modifiers*/
                                            void 0, 
                                            /*isTypeOnly*/
                                            false, factory.createNamedExports([factory.createExportSpecifier(
                                                /*isTypeOnly*/
                                                false, name, localName)])), 0 /* None */);
                                            needsExportDeclaration = false;
                                            needsPostExportDefault = false;
                                        }
                                    }
                                }
                            }
                        }
                        if (symbol.flags & 384 /* Enum */) {
                            serializeEnum(symbol, symbolName2, modifierFlags);
                        }
                        if (symbol.flags & 32 /* Class */) {
                            if (symbol.flags & 4 /* Property */ && symbol.valueDeclaration && isBinaryExpression(symbol.valueDeclaration.parent) && isClassExpression(symbol.valueDeclaration.parent.right)) {
                                serializeAsAlias(symbol, getInternalSymbolName(symbol, symbolName2), modifierFlags);
                            }
                            else {
                                serializeAsClass(symbol, getInternalSymbolName(symbol, symbolName2), modifierFlags);
                            }
                        }
                        if (symbol.flags & (512 /* ValueModule */ | 1024 /* NamespaceModule */) && (!isConstMergedWithNS || isTypeOnlyNamespace(symbol)) || isConstMergedWithNSPrintableAsSignatureMerge) {
                            serializeModule(symbol, symbolName2, modifierFlags);
                        }
                        if (symbol.flags & 64 /* Interface */ && !(symbol.flags & 32 /* Class */)) {
                            serializeInterface(symbol, symbolName2, modifierFlags);
                        }
                        if (symbol.flags & 2097152 /* Alias */) {
                            serializeAsAlias(symbol, getInternalSymbolName(symbol, symbolName2), modifierFlags);
                        }
                        if (symbol.flags & 4 /* Property */ && symbol.escapedName === "export=" /* ExportEquals */) {
                            serializeMaybeAliasAssignment(symbol);
                        }
                        if (symbol.flags & 8388608 /* ExportStar */) {
                            if (symbol.declarations) {
                                for (const node of symbol.declarations) {
                                    const resolvedModule = resolveExternalModuleName(node, node.moduleSpecifier);
                                    if (!resolvedModule)
                                        continue;
                                    addResult(factory.createExportDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    node.isTypeOnly, 
                                    /*exportClause*/
                                    void 0, factory.createStringLiteral(getSpecifierForModuleSymbol(resolvedModule, context))), 0 /* None */);
                                }
                            }
                        }
                        if (needsPostExportDefault) {
                            addResult(factory.createExportAssignment(
                            /*modifiers*/
                            void 0, 
                            /*isExportAssignment*/
                            false, factory.createIdentifier(getInternalSymbolName(symbol, symbolName2))), 0 /* None */);
                        }
                        else if (needsExportDeclaration) {
                            addResult(factory.createExportDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*isTypeOnly*/
                            false, factory.createNamedExports([factory.createExportSpecifier(
                                /*isTypeOnly*/
                                false, getInternalSymbolName(symbol, symbolName2), symbolName2)])), 0 /* None */);
                        }
                    }
                    function includePrivateSymbol(symbol) {
                        if (some(symbol.declarations, isParameterDeclaration))
                            return;
                        Debug.assertIsDefined(deferredPrivatesStack[deferredPrivatesStack.length - 1]);
                        getUnusedName(unescapeLeadingUnderscores(symbol.escapedName), symbol);
                        const isExternalImportAlias = !!(symbol.flags & 2097152 /* Alias */) && !some(symbol.declarations, (d) => !!findAncestor(d, isExportDeclaration) || isNamespaceExport(d) || isImportEqualsDeclaration(d) && !isExternalModuleReference(d.moduleReference));
                        deferredPrivatesStack[isExternalImportAlias ? 0 : deferredPrivatesStack.length - 1].set(getSymbolId(symbol), symbol);
                    }
                    function isExportingScope(enclosingDeclaration2) {
                        return isSourceFile(enclosingDeclaration2) && (isExternalOrCommonJsModule(enclosingDeclaration2) || isJsonSourceFile(enclosingDeclaration2)) || isAmbientModule(enclosingDeclaration2) && !isGlobalScopeAugmentation(enclosingDeclaration2);
                    }
                    function addResult(node, additionalModifierFlags) {
                        if (canHaveModifiers(node)) {
                            let newModifierFlags = 0 /* None */;
                            const enclosingDeclaration2 = context.enclosingDeclaration && (isJSDocTypeAlias(context.enclosingDeclaration) ? getSourceFileOfNode(context.enclosingDeclaration) : context.enclosingDeclaration);
                            if (additionalModifierFlags & 1 /* Export */ && enclosingDeclaration2 && (isExportingScope(enclosingDeclaration2) || isModuleDeclaration(enclosingDeclaration2)) && canHaveExportModifier(node)) {
                                newModifierFlags |= 1 /* Export */;
                            }
                            if (addingDeclare && !(newModifierFlags & 1 /* Export */) && (!enclosingDeclaration2 || !(enclosingDeclaration2.flags & 16777216 /* Ambient */)) && (isEnumDeclaration(node) || isVariableStatement(node) || isFunctionDeclaration(node) || isClassDeclaration(node) || isModuleDeclaration(node))) {
                                newModifierFlags |= 2 /* Ambient */;
                            }
                            if (additionalModifierFlags & 1024 /* Default */ && (isClassDeclaration(node) || isInterfaceDeclaration(node) || isFunctionDeclaration(node))) {
                                newModifierFlags |= 1024 /* Default */;
                            }
                            if (newModifierFlags) {
                                node = factory.updateModifiers(node, newModifierFlags | getEffectiveModifierFlags(node));
                            }
                        }
                        results.push(node);
                    }
                    function serializeTypeAlias(symbol, symbolName2, modifierFlags) {
                        var _a2;
                        const aliasType = getDeclaredTypeOfTypeAlias(symbol);
                        const typeParams = getSymbolLinks(symbol).typeParameters;
                        const typeParamDecls = map(typeParams, (p) => typeParameterToDeclaration(p, context));
                        const jsdocAliasDecl = (_a2 = symbol.declarations) == null ? void 0 : _a2.find(isJSDocTypeAlias);
                        const commentText = getTextOfJSDocComment(jsdocAliasDecl ? jsdocAliasDecl.comment || jsdocAliasDecl.parent.comment : void 0);
                        const oldFlags = context.flags;
                        context.flags |= 8388608 /* InTypeAlias */;
                        const oldEnclosingDecl = context.enclosingDeclaration;
                        context.enclosingDeclaration = jsdocAliasDecl;
                        const typeNode = jsdocAliasDecl && jsdocAliasDecl.typeExpression && isJSDocTypeExpression(jsdocAliasDecl.typeExpression) && serializeExistingTypeNode(context, jsdocAliasDecl.typeExpression.type, includePrivateSymbol, bundled) || typeToTypeNodeHelper(aliasType, context);
                        addResult(setSyntheticLeadingComments(factory.createTypeAliasDeclaration(
                        /*modifiers*/
                        void 0, getInternalSymbolName(symbol, symbolName2), typeParamDecls, typeNode), !commentText ? [] : [{ kind: 3 /* MultiLineCommentTrivia */, text: "*\n * " + commentText.replace(/\n/g, "\n * ") + "\n ", pos: -1, end: -1, hasTrailingNewLine: true }]), modifierFlags);
                        context.flags = oldFlags;
                        context.enclosingDeclaration = oldEnclosingDecl;
                    }
                    function serializeInterface(symbol, symbolName2, modifierFlags) {
                        const interfaceType = getDeclaredTypeOfClassOrInterface(symbol);
                        const localParams = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
                        const typeParamDecls = map(localParams, (p) => typeParameterToDeclaration(p, context));
                        const baseTypes = getBaseTypes(interfaceType);
                        const baseType = length(baseTypes) ? getIntersectionType(baseTypes) : void 0;
                        const members = flatMap(getPropertiesOfType(interfaceType), (p) => serializePropertySymbolForInterface(p, baseType));
                        const callSignatures = serializeSignatures(0 /* Call */, interfaceType, baseType, 176 /* CallSignature */);
                        const constructSignatures = serializeSignatures(1 /* Construct */, interfaceType, baseType, 177 /* ConstructSignature */);
                        const indexSignatures = serializeIndexSignatures(interfaceType, baseType);
                        const heritageClauses = !length(baseTypes) ? void 0 : [factory.createHeritageClause(94 /* ExtendsKeyword */, mapDefined(baseTypes, (b) => trySerializeAsTypeReference(b, 111551 /* Value */)))];
                        addResult(factory.createInterfaceDeclaration(
                        /*modifiers*/
                        void 0, getInternalSymbolName(symbol, symbolName2), typeParamDecls, heritageClauses, [...indexSignatures, ...constructSignatures, ...callSignatures, ...members]), modifierFlags);
                    }
                    function getNamespaceMembersForSerialization(symbol) {
                        return !symbol.exports ? [] : filter(arrayFrom(symbol.exports.values()), isNamespaceMember);
                    }
                    function isTypeOnlyNamespace(symbol) {
                        return every(getNamespaceMembersForSerialization(symbol), (m) => !(getAllSymbolFlags(resolveSymbol(m)) & 111551 /* Value */));
                    }
                    function serializeModule(symbol, symbolName2, modifierFlags) {
                        const members = getNamespaceMembersForSerialization(symbol);
                        const locationMap = arrayToMultiMap(members, (m) => m.parent && m.parent === symbol ? "real" : "merged");
                        const realMembers = locationMap.get("real") || emptyArray;
                        const mergedMembers = locationMap.get("merged") || emptyArray;
                        if (length(realMembers)) {
                            const localName = getInternalSymbolName(symbol, symbolName2);
                            serializeAsNamespaceDeclaration(realMembers, localName, modifierFlags, !!(symbol.flags & (16 /* Function */ | 67108864 /* Assignment */)));
                        }
                        if (length(mergedMembers)) {
                            const containingFile = getSourceFileOfNode(context.enclosingDeclaration);
                            const localName = getInternalSymbolName(symbol, symbolName2);
                            const nsBody = factory.createModuleBlock([factory.createExportDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory.createNamedExports(mapDefined(filter(mergedMembers, (n) => n.escapedName !== "export=" /* ExportEquals */), (s) => {
                                    var _a2, _b;
                                    const name = unescapeLeadingUnderscores(s.escapedName);
                                    const localName2 = getInternalSymbolName(s, name);
                                    const aliasDecl = s.declarations && getDeclarationOfAliasSymbol(s);
                                    if (containingFile && (aliasDecl ? containingFile !== getSourceFileOfNode(aliasDecl) : !some(s.declarations, (d) => getSourceFileOfNode(d) === containingFile))) {
                                        (_b = (_a2 = context.tracker) == null ? void 0 : _a2.reportNonlocalAugmentation) == null ? void 0 : _b.call(_a2, containingFile, symbol, s);
                                        return void 0;
                                    }
                                    const target = aliasDecl && getTargetOfAliasDeclaration(aliasDecl, 
                                    /*dontRecursivelyResolve*/
                                    true);
                                    includePrivateSymbol(target || s);
                                    const targetName = target ? getInternalSymbolName(target, unescapeLeadingUnderscores(target.escapedName)) : localName2;
                                    return factory.createExportSpecifier(
                                    /*isTypeOnly*/
                                    false, name === targetName ? void 0 : targetName, name);
                                })))]);
                            addResult(factory.createModuleDeclaration(
                            /*modifiers*/
                            void 0, factory.createIdentifier(localName), nsBody, 16 /* Namespace */), 0 /* None */);
                        }
                    }
                    function serializeEnum(symbol, symbolName2, modifierFlags) {
                        addResult(factory.createEnumDeclaration(factory.createModifiersFromModifierFlags(isConstEnumSymbol(symbol) ? 2048 /* Const */ : 0), getInternalSymbolName(symbol, symbolName2), map(filter(getPropertiesOfType(getTypeOfSymbol(symbol)), (p) => !!(p.flags & 8 /* EnumMember */)), (p) => {
                            const initializedValue = p.declarations && p.declarations[0] && isEnumMember(p.declarations[0]) ? getConstantValue2(p.declarations[0]) : void 0;
                            return factory.createEnumMember(unescapeLeadingUnderscores(p.escapedName), initializedValue === void 0 ? void 0 : typeof initializedValue === "string" ? factory.createStringLiteral(initializedValue) : factory.createNumericLiteral(initializedValue));
                        })), modifierFlags);
                    }
                    function serializeAsFunctionNamespaceMerge(type, symbol, localName, modifierFlags) {
                        const signatures = getSignaturesOfType(type, 0 /* Call */);
                        for (const sig of signatures) {
                            const decl = signatureToSignatureDeclarationHelper(sig, 259 /* FunctionDeclaration */, context, { name: factory.createIdentifier(localName), privateSymbolVisitor: includePrivateSymbol, bundledImports: bundled });
                            addResult(setTextRange(decl, getSignatureTextRangeLocation(sig)), modifierFlags);
                        }
                        if (!(symbol.flags & (512 /* ValueModule */ | 1024 /* NamespaceModule */) && !!symbol.exports && !!symbol.exports.size)) {
                            const props = filter(getPropertiesOfType(type), isNamespaceMember);
                            serializeAsNamespaceDeclaration(props, localName, modifierFlags, 
                            /*suppressNewPrivateContext*/
                            true);
                        }
                    }
                    function getSignatureTextRangeLocation(signature) {
                        if (signature.declaration && signature.declaration.parent) {
                            if (isBinaryExpression(signature.declaration.parent) && getAssignmentDeclarationKind(signature.declaration.parent) === 5 /* Property */) {
                                return signature.declaration.parent;
                            }
                            if (isVariableDeclaration(signature.declaration.parent) && signature.declaration.parent.parent) {
                                return signature.declaration.parent.parent;
                            }
                        }
                        return signature.declaration;
                    }
                    function serializeAsNamespaceDeclaration(props, localName, modifierFlags, suppressNewPrivateContext) {
                        if (length(props)) {
                            const localVsRemoteMap = arrayToMultiMap(props, (p) => !length(p.declarations) || some(p.declarations, (d) => getSourceFileOfNode(d) === getSourceFileOfNode(context.enclosingDeclaration)) ? "local" : "remote");
                            const localProps = localVsRemoteMap.get("local") || emptyArray;
                            let fakespace = parseNodeFactory.createModuleDeclaration(
                            /*modifiers*/
                            void 0, factory.createIdentifier(localName), factory.createModuleBlock([]), 16 /* Namespace */);
                            setParent(fakespace, enclosingDeclaration);
                            fakespace.locals = createSymbolTable(props);
                            fakespace.symbol = props[0].parent;
                            const oldResults = results;
                            results = [];
                            const oldAddingDeclare = addingDeclare;
                            addingDeclare = false;
                            const subcontext = { ...context, enclosingDeclaration: fakespace };
                            const oldContext = context;
                            context = subcontext;
                            visitSymbolTable(createSymbolTable(localProps), suppressNewPrivateContext, 
                            /*propertyAsAlias*/
                            true);
                            context = oldContext;
                            addingDeclare = oldAddingDeclare;
                            const declarations = results;
                            results = oldResults;
                            const defaultReplaced = map(declarations, (d) => isExportAssignment(d) && !d.isExportEquals && isIdentifier(d.expression) ? factory.createExportDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*isTypeOnly*/
                            false, factory.createNamedExports([factory.createExportSpecifier(
                                /*isTypeOnly*/
                                false, d.expression, factory.createIdentifier("default" /* Default */))])) : d);
                            const exportModifierStripped = every(defaultReplaced, (d) => hasSyntacticModifier(d, 1 /* Export */)) ? map(defaultReplaced, removeExportModifier) : defaultReplaced;
                            fakespace = factory.updateModuleDeclaration(fakespace, fakespace.modifiers, fakespace.name, factory.createModuleBlock(exportModifierStripped));
                            addResult(fakespace, modifierFlags);
                        }
                    }
                    function isNamespaceMember(p) {
                        return !!(p.flags & (788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */)) || !(p.flags & 4194304 /* Prototype */ || p.escapedName === "prototype" || p.valueDeclaration && isStatic(p.valueDeclaration) && isClassLike(p.valueDeclaration.parent));
                    }
                    function sanitizeJSDocImplements(clauses) {
                        const result = mapDefined(clauses, (e) => {
                            const oldEnclosing = context.enclosingDeclaration;
                            context.enclosingDeclaration = e;
                            let expr = e.expression;
                            if (isEntityNameExpression(expr)) {
                                if (isIdentifier(expr) && idText(expr) === "") {
                                    return cleanup(
                                    /*result*/
                                    void 0);
                                }
                                let introducesError;
                                ({ introducesError, node: expr } = trackExistingEntityName(expr, context, includePrivateSymbol));
                                if (introducesError) {
                                    return cleanup(
                                    /*result*/
                                    void 0);
                                }
                            }
                            return cleanup(factory.createExpressionWithTypeArguments(expr, map(e.typeArguments, (a) => serializeExistingTypeNode(context, a, includePrivateSymbol, bundled) || typeToTypeNodeHelper(getTypeFromTypeNode(a), context))));
                            function cleanup(result2) {
                                context.enclosingDeclaration = oldEnclosing;
                                return result2;
                            }
                        });
                        if (result.length === clauses.length) {
                            return result;
                        }
                        return void 0;
                    }
                    function serializeAsClass(symbol, localName, modifierFlags) {
                        var _a2, _b;
                        const originalDecl = (_a2 = symbol.declarations) == null ? void 0 : _a2.find(isClassLike);
                        const oldEnclosing = context.enclosingDeclaration;
                        context.enclosingDeclaration = originalDecl || oldEnclosing;
                        const localParams = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
                        const typeParamDecls = map(localParams, (p) => typeParameterToDeclaration(p, context));
                        const classType = getDeclaredTypeOfClassOrInterface(symbol);
                        const baseTypes = getBaseTypes(classType);
                        const originalImplements = originalDecl && getEffectiveImplementsTypeNodes(originalDecl);
                        const implementsExpressions = originalImplements && sanitizeJSDocImplements(originalImplements) || mapDefined(getImplementsTypes(classType), serializeImplementedType);
                        const staticType = getTypeOfSymbol(symbol);
                        const isClass = !!((_b = staticType.symbol) == null ? void 0 : _b.valueDeclaration) && isClassLike(staticType.symbol.valueDeclaration);
                        const staticBaseType = isClass ? getBaseConstructorTypeOfClass(staticType) : anyType;
                        const heritageClauses = [
                            ...!length(baseTypes) ? [] : [factory.createHeritageClause(94 /* ExtendsKeyword */, map(baseTypes, (b) => serializeBaseType(b, staticBaseType, localName)))],
                            ...!length(implementsExpressions) ? [] : [factory.createHeritageClause(117 /* ImplementsKeyword */, implementsExpressions)]
                        ];
                        const symbolProps = getNonInheritedProperties(classType, baseTypes, getPropertiesOfType(classType));
                        const publicSymbolProps = filter(symbolProps, (s) => {
                            const valueDecl = s.valueDeclaration;
                            return !!valueDecl && !(isNamedDeclaration(valueDecl) && isPrivateIdentifier(valueDecl.name));
                        });
                        const hasPrivateIdentifier = some(symbolProps, (s) => {
                            const valueDecl = s.valueDeclaration;
                            return !!valueDecl && isNamedDeclaration(valueDecl) && isPrivateIdentifier(valueDecl.name);
                        });
                        const privateProperties = hasPrivateIdentifier ? [factory.createPropertyDeclaration(
                            /*modifiers*/
                            void 0, factory.createPrivateIdentifier("#private"), 
                            /*questionOrExclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, 
                            /*initializer*/
                            void 0)] : emptyArray;
                        const publicProperties = flatMap(publicSymbolProps, (p) => serializePropertySymbolForClass(p, 
                        /*isStatic*/
                        false, baseTypes[0]));
                        const staticMembers = flatMap(filter(getPropertiesOfType(staticType), (p) => !(p.flags & 4194304 /* Prototype */) && p.escapedName !== "prototype" && !isNamespaceMember(p)), (p) => serializePropertySymbolForClass(p, 
                        /*isStatic*/
                        true, staticBaseType));
                        const isNonConstructableClassLikeInJsFile = !isClass && !!symbol.valueDeclaration && isInJSFile(symbol.valueDeclaration) && !some(getSignaturesOfType(staticType, 1 /* Construct */));
                        const constructors = isNonConstructableClassLikeInJsFile ? [factory.createConstructorDeclaration(factory.createModifiersFromModifierFlags(8 /* Private */), [], 
                            /*body*/
                            void 0)] : serializeSignatures(1 /* Construct */, staticType, staticBaseType, 173 /* Constructor */);
                        const indexSignatures = serializeIndexSignatures(classType, baseTypes[0]);
                        context.enclosingDeclaration = oldEnclosing;
                        addResult(setTextRange(factory.createClassDeclaration(
                        /*modifiers*/
                        void 0, localName, typeParamDecls, heritageClauses, [...indexSignatures, ...staticMembers, ...constructors, ...publicProperties, ...privateProperties]), symbol.declarations && filter(symbol.declarations, (d) => isClassDeclaration(d) || isClassExpression(d))[0]), modifierFlags);
                    }
                    function getSomeTargetNameFromDeclarations(declarations) {
                        return firstDefined(declarations, (d) => {
                            if (isImportSpecifier(d) || isExportSpecifier(d)) {
                                return idText(d.propertyName || d.name);
                            }
                            if (isBinaryExpression(d) || isExportAssignment(d)) {
                                const expression = isExportAssignment(d) ? d.expression : d.right;
                                if (isPropertyAccessExpression(expression)) {
                                    return idText(expression.name);
                                }
                            }
                            if (isAliasSymbolDeclaration2(d)) {
                                const name = getNameOfDeclaration(d);
                                if (name && isIdentifier(name)) {
                                    return idText(name);
                                }
                            }
                            return void 0;
                        });
                    }
                    function serializeAsAlias(symbol, localName, modifierFlags) {
                        var _a2, _b, _c, _d, _e;
                        const node = getDeclarationOfAliasSymbol(symbol);
                        if (!node)
                            return Debug.fail();
                        const target = getMergedSymbol(getTargetOfAliasDeclaration(node, 
                        /*dontRecursivelyResolve*/
                        true));
                        if (!target) {
                            return;
                        }
                        let verbatimTargetName = isShorthandAmbientModuleSymbol(target) && getSomeTargetNameFromDeclarations(symbol.declarations) || unescapeLeadingUnderscores(target.escapedName);
                        if (verbatimTargetName === "export=" /* ExportEquals */ && allowSyntheticDefaultImports) {
                            verbatimTargetName = "default" /* Default */;
                        }
                        const targetName = getInternalSymbolName(target, verbatimTargetName);
                        includePrivateSymbol(target);
                        switch (node.kind) {
                            case 205 /* BindingElement */:
                                if (((_b = (_a2 = node.parent) == null ? void 0 : _a2.parent) == null ? void 0 : _b.kind) === 257 /* VariableDeclaration */) {
                                    const specifier2 = getSpecifierForModuleSymbol(target.parent || target, context);
                                    const { propertyName } = node;
                                    addResult(factory.createImportDeclaration(
                                    /*modifiers*/
                                    void 0, factory.createImportClause(
                                    /*isTypeOnly*/
                                    false, 
                                    /*name*/
                                    void 0, factory.createNamedImports([factory.createImportSpecifier(
                                        /*isTypeOnly*/
                                        false, propertyName && isIdentifier(propertyName) ? factory.createIdentifier(idText(propertyName)) : void 0, factory.createIdentifier(localName))])), factory.createStringLiteral(specifier2), 
                                    /*importClause*/
                                    void 0), 0 /* None */);
                                    break;
                                }
                                Debug.failBadSyntaxKind(((_c = node.parent) == null ? void 0 : _c.parent) || node, "Unhandled binding element grandparent kind in declaration serialization");
                                break;
                            case 300 /* ShorthandPropertyAssignment */:
                                if (((_e = (_d = node.parent) == null ? void 0 : _d.parent) == null ? void 0 : _e.kind) === 223 /* BinaryExpression */) {
                                    serializeExportSpecifier(unescapeLeadingUnderscores(symbol.escapedName), targetName);
                                }
                                break;
                            case 257 /* VariableDeclaration */:
                                if (isPropertyAccessExpression(node.initializer)) {
                                    const initializer = node.initializer;
                                    const uniqueName = factory.createUniqueName(localName);
                                    const specifier2 = getSpecifierForModuleSymbol(target.parent || target, context);
                                    addResult(factory.createImportEqualsDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    false, uniqueName, factory.createExternalModuleReference(factory.createStringLiteral(specifier2))), 0 /* None */);
                                    addResult(factory.createImportEqualsDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    false, factory.createIdentifier(localName), factory.createQualifiedName(uniqueName, initializer.name)), modifierFlags);
                                    break;
                                }
                            case 268 /* ImportEqualsDeclaration */:
                                if (target.escapedName === "export=" /* ExportEquals */ && some(target.declarations, (d) => isSourceFile(d) && isJsonSourceFile(d))) {
                                    serializeMaybeAliasAssignment(symbol);
                                    break;
                                }
                                const isLocalImport = !(target.flags & 512 /* ValueModule */) && !isVariableDeclaration(node);
                                addResult(factory.createImportEqualsDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory.createIdentifier(localName), isLocalImport ? symbolToName(target, context, 67108863 /* All */, 
                                /*expectsIdentifier*/
                                false) : factory.createExternalModuleReference(factory.createStringLiteral(getSpecifierForModuleSymbol(target, context)))), isLocalImport ? modifierFlags : 0 /* None */);
                                break;
                            case 267 /* NamespaceExportDeclaration */:
                                addResult(factory.createNamespaceExportDeclaration(idText(node.name)), 0 /* None */);
                                break;
                            case 270 /* ImportClause */: {
                                const generatedSpecifier = getSpecifierForModuleSymbol(target.parent || target, context);
                                const specifier2 = bundled ? factory.createStringLiteral(generatedSpecifier) : node.parent.moduleSpecifier;
                                addResult(factory.createImportDeclaration(
                                /*modifiers*/
                                void 0, factory.createImportClause(
                                /*isTypeOnly*/
                                false, factory.createIdentifier(localName), 
                                /*namedBindings*/
                                void 0), specifier2, node.parent.assertClause), 0 /* None */);
                                break;
                            }
                            case 271 /* NamespaceImport */: {
                                const generatedSpecifier = getSpecifierForModuleSymbol(target.parent || target, context);
                                const specifier2 = bundled ? factory.createStringLiteral(generatedSpecifier) : node.parent.parent.moduleSpecifier;
                                addResult(factory.createImportDeclaration(
                                /*modifiers*/
                                void 0, factory.createImportClause(
                                /*isTypeOnly*/
                                false, 
                                /*importClause*/
                                void 0, factory.createNamespaceImport(factory.createIdentifier(localName))), specifier2, node.parent.parent.assertClause), 0 /* None */);
                                break;
                            }
                            case 277 /* NamespaceExport */:
                                addResult(factory.createExportDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory.createNamespaceExport(factory.createIdentifier(localName)), factory.createStringLiteral(getSpecifierForModuleSymbol(target, context))), 0 /* None */);
                                break;
                            case 273 /* ImportSpecifier */: {
                                const generatedSpecifier = getSpecifierForModuleSymbol(target.parent || target, context);
                                const specifier2 = bundled ? factory.createStringLiteral(generatedSpecifier) : node.parent.parent.parent.moduleSpecifier;
                                addResult(factory.createImportDeclaration(
                                /*modifiers*/
                                void 0, factory.createImportClause(
                                /*isTypeOnly*/
                                false, 
                                /*importClause*/
                                void 0, factory.createNamedImports([
                                    factory.createImportSpecifier(
                                    /*isTypeOnly*/
                                    false, localName !== verbatimTargetName ? factory.createIdentifier(verbatimTargetName) : void 0, factory.createIdentifier(localName))
                                ])), specifier2, node.parent.parent.parent.assertClause), 0 /* None */);
                                break;
                            }
                            case 278 /* ExportSpecifier */:
                                const specifier = node.parent.parent.moduleSpecifier;
                                serializeExportSpecifier(unescapeLeadingUnderscores(symbol.escapedName), specifier ? verbatimTargetName : targetName, specifier && isStringLiteralLike(specifier) ? factory.createStringLiteral(specifier.text) : void 0);
                                break;
                            case 274 /* ExportAssignment */:
                                serializeMaybeAliasAssignment(symbol);
                                break;
                            case 223 /* BinaryExpression */:
                            case 208 /* PropertyAccessExpression */:
                            case 209 /* ElementAccessExpression */:
                                if (symbol.escapedName === "default" /* Default */ || symbol.escapedName === "export=" /* ExportEquals */) {
                                    serializeMaybeAliasAssignment(symbol);
                                }
                                else {
                                    serializeExportSpecifier(localName, targetName);
                                }
                                break;
                            default:
                                return Debug.failBadSyntaxKind(node, "Unhandled alias declaration kind in symbol serializer!");
                        }
                    }
                    function serializeExportSpecifier(localName, targetName, specifier) {
                        addResult(factory.createExportDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*isTypeOnly*/
                        false, factory.createNamedExports([factory.createExportSpecifier(
                            /*isTypeOnly*/
                            false, localName !== targetName ? targetName : void 0, localName)]), specifier), 0 /* None */);
                    }
                    function serializeMaybeAliasAssignment(symbol) {
                        if (symbol.flags & 4194304 /* Prototype */) {
                            return false;
                        }
                        const name = unescapeLeadingUnderscores(symbol.escapedName);
                        const isExportEquals = name === "export=" /* ExportEquals */;
                        const isDefault = name === "default" /* Default */;
                        const isExportAssignmentCompatibleSymbolName = isExportEquals || isDefault;
                        const aliasDecl = symbol.declarations && getDeclarationOfAliasSymbol(symbol);
                        const target = aliasDecl && getTargetOfAliasDeclaration(aliasDecl, 
                        /*dontRecursivelyResolve*/
                        true);
                        if (target && length(target.declarations) && some(target.declarations, (d) => getSourceFileOfNode(d) === getSourceFileOfNode(enclosingDeclaration))) {
                            const expr = aliasDecl && (isExportAssignment(aliasDecl) || isBinaryExpression(aliasDecl) ? getExportAssignmentExpression(aliasDecl) : getPropertyAssignmentAliasLikeExpression(aliasDecl));
                            const first2 = expr && isEntityNameExpression(expr) ? getFirstNonModuleExportsIdentifier(expr) : void 0;
                            const referenced = first2 && resolveEntityName(first2, 67108863 /* All */, 
                            /*ignoreErrors*/
                            true, 
                            /*dontResolveAlias*/
                            true, enclosingDeclaration);
                            if (referenced || target) {
                                includePrivateSymbol(referenced || target);
                            }
                            const prevDisableTrackSymbol = context.tracker.disableTrackSymbol;
                            context.tracker.disableTrackSymbol = true;
                            if (isExportAssignmentCompatibleSymbolName) {
                                results.push(factory.createExportAssignment(
                                /*modifiers*/
                                void 0, isExportEquals, symbolToExpression(target, context, 67108863 /* All */)));
                            }
                            else {
                                if (first2 === expr && first2) {
                                    serializeExportSpecifier(name, idText(first2));
                                }
                                else if (expr && isClassExpression(expr)) {
                                    serializeExportSpecifier(name, getInternalSymbolName(target, symbolName(target)));
                                }
                                else {
                                    const varName = getUnusedName(name, symbol);
                                    addResult(factory.createImportEqualsDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    false, factory.createIdentifier(varName), symbolToName(target, context, 67108863 /* All */, 
                                    /*expectsIdentifier*/
                                    false)), 0 /* None */);
                                    serializeExportSpecifier(name, varName);
                                }
                            }
                            context.tracker.disableTrackSymbol = prevDisableTrackSymbol;
                            return true;
                        }
                        else {
                            const varName = getUnusedName(name, symbol);
                            const typeToSerialize = getWidenedType(getTypeOfSymbol(getMergedSymbol(symbol)));
                            if (isTypeRepresentableAsFunctionNamespaceMerge(typeToSerialize, symbol)) {
                                serializeAsFunctionNamespaceMerge(typeToSerialize, symbol, varName, isExportAssignmentCompatibleSymbolName ? 0 /* None */ : 1 /* Export */);
                            }
                            else {
                                const statement = factory.createVariableStatement(
                                /*modifiers*/
                                void 0, factory.createVariableDeclarationList([
                                    factory.createVariableDeclaration(varName, 
                                    /*exclamationToken*/
                                    void 0, serializeTypeForDeclaration(context, typeToSerialize, symbol, enclosingDeclaration, includePrivateSymbol, bundled))
                                ], 2 /* Const */));
                                addResult(statement, target && target.flags & 4 /* Property */ && target.escapedName === "export=" /* ExportEquals */ ? 2 /* Ambient */ : name === varName ? 1 /* Export */ : 0 /* None */);
                            }
                            if (isExportAssignmentCompatibleSymbolName) {
                                results.push(factory.createExportAssignment(
                                /*modifiers*/
                                void 0, isExportEquals, factory.createIdentifier(varName)));
                                return true;
                            }
                            else if (name !== varName) {
                                serializeExportSpecifier(name, varName);
                                return true;
                            }
                            return false;
                        }
                    }
                    function isTypeRepresentableAsFunctionNamespaceMerge(typeToSerialize, hostSymbol) {
                        const ctxSrc = getSourceFileOfNode(context.enclosingDeclaration);
                        return getObjectFlags(typeToSerialize) & (16 /* Anonymous */ | 32 /* Mapped */) && !length(getIndexInfosOfType(typeToSerialize)) && !isClassInstanceSide(typeToSerialize) && // While a class instance is potentially representable as a NS, prefer printing a reference to the instance type and serializing the class
                            !!(length(filter(getPropertiesOfType(typeToSerialize), isNamespaceMember)) || length(getSignaturesOfType(typeToSerialize, 0 /* Call */))) && !length(getSignaturesOfType(typeToSerialize, 1 /* Construct */)) && // TODO: could probably serialize as function + ns + class, now that that's OK
                            !getDeclarationWithTypeAnnotation(hostSymbol, enclosingDeclaration) && !(typeToSerialize.symbol && some(typeToSerialize.symbol.declarations, (d) => getSourceFileOfNode(d) !== ctxSrc)) && !some(getPropertiesOfType(typeToSerialize), (p) => isLateBoundName(p.escapedName)) && !some(getPropertiesOfType(typeToSerialize), (p) => some(p.declarations, (d) => getSourceFileOfNode(d) !== ctxSrc)) && every(getPropertiesOfType(typeToSerialize), (p) => isIdentifierText(symbolName(p), languageVersion));
                    }
                    function makeSerializePropertySymbol(createProperty2, methodKind, useAccessors) {
                        return function serializePropertySymbol(p, isStatic2, baseType) {
                            var _a2, _b, _c, _d, _e;
                            const modifierFlags = getDeclarationModifierFlagsFromSymbol(p);
                            const isPrivate = !!(modifierFlags & 8 /* Private */);
                            if (isStatic2 && p.flags & (788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */)) {
                                return [];
                            }
                            if (p.flags & 4194304 /* Prototype */ || baseType && getPropertyOfType(baseType, p.escapedName) && isReadonlySymbol(getPropertyOfType(baseType, p.escapedName)) === isReadonlySymbol(p) && (p.flags & 16777216 /* Optional */) === (getPropertyOfType(baseType, p.escapedName).flags & 16777216 /* Optional */) && isTypeIdenticalTo(getTypeOfSymbol(p), getTypeOfPropertyOfType(baseType, p.escapedName))) {
                                return [];
                            }
                            const flag = modifierFlags & ~512 /* Async */ | (isStatic2 ? 32 /* Static */ : 0);
                            const name = getPropertyNameNodeForSymbol(p, context);
                            const firstPropertyLikeDecl = (_a2 = p.declarations) == null ? void 0 : _a2.find(or(isPropertyDeclaration, isAccessor, isVariableDeclaration, isPropertySignature, isBinaryExpression, isPropertyAccessExpression));
                            if (p.flags & 98304 /* Accessor */ && useAccessors) {
                                const result = [];
                                if (p.flags & 65536 /* SetAccessor */) {
                                    result.push(setTextRange(factory.createSetAccessorDeclaration(factory.createModifiersFromModifierFlags(flag), name, [factory.createParameterDeclaration(
                                        /*modifiers*/
                                        void 0, 
                                        /*dotDotDotToken*/
                                        void 0, "arg", 
                                        /*questionToken*/
                                        void 0, isPrivate ? void 0 : serializeTypeForDeclaration(context, getTypeOfSymbol(p), p, enclosingDeclaration, includePrivateSymbol, bundled))], 
                                    /*body*/
                                    void 0), ((_b = p.declarations) == null ? void 0 : _b.find(isSetAccessor)) || firstPropertyLikeDecl));
                                }
                                if (p.flags & 32768 /* GetAccessor */) {
                                    const isPrivate2 = modifierFlags & 8 /* Private */;
                                    result.push(setTextRange(factory.createGetAccessorDeclaration(factory.createModifiersFromModifierFlags(flag), name, [], isPrivate2 ? void 0 : serializeTypeForDeclaration(context, getTypeOfSymbol(p), p, enclosingDeclaration, includePrivateSymbol, bundled), 
                                    /*body*/
                                    void 0), ((_c = p.declarations) == null ? void 0 : _c.find(isGetAccessor)) || firstPropertyLikeDecl));
                                }
                                return result;
                            }
                            else if (p.flags & (4 /* Property */ | 3 /* Variable */ | 98304 /* Accessor */)) {
                                return setTextRange(createProperty2(factory.createModifiersFromModifierFlags((isReadonlySymbol(p) ? 64 /* Readonly */ : 0) | flag), name, p.flags & 16777216 /* Optional */ ? factory.createToken(57 /* QuestionToken */) : void 0, isPrivate ? void 0 : serializeTypeForDeclaration(context, getWriteTypeOfSymbol(p), p, enclosingDeclaration, includePrivateSymbol, bundled), 
                                // TODO: https://github.com/microsoft/TypeScript/pull/32372#discussion_r328386357
                                // interface members can't have initializers, however class members _can_
                                /*initializer*/
                                void 0), ((_d = p.declarations) == null ? void 0 : _d.find(or(isPropertyDeclaration, isVariableDeclaration))) || firstPropertyLikeDecl);
                            }
                            if (p.flags & (8192 /* Method */ | 16 /* Function */)) {
                                const type = getTypeOfSymbol(p);
                                const signatures = getSignaturesOfType(type, 0 /* Call */);
                                if (flag & 8 /* Private */) {
                                    return setTextRange(createProperty2(factory.createModifiersFromModifierFlags((isReadonlySymbol(p) ? 64 /* Readonly */ : 0) | flag), name, p.flags & 16777216 /* Optional */ ? factory.createToken(57 /* QuestionToken */) : void 0, 
                                    /*type*/
                                    void 0, 
                                    /*initializer*/
                                    void 0), ((_e = p.declarations) == null ? void 0 : _e.find(isFunctionLikeDeclaration)) || signatures[0] && signatures[0].declaration || p.declarations && p.declarations[0]);
                                }
                                const results2 = [];
                                for (const sig of signatures) {
                                    const decl = signatureToSignatureDeclarationHelper(sig, methodKind, context, {
                                        name,
                                        questionToken: p.flags & 16777216 /* Optional */ ? factory.createToken(57 /* QuestionToken */) : void 0,
                                        modifiers: flag ? factory.createModifiersFromModifierFlags(flag) : void 0
                                    });
                                    const location = sig.declaration && isPrototypePropertyAssignment(sig.declaration.parent) ? sig.declaration.parent : sig.declaration;
                                    results2.push(setTextRange(decl, location));
                                }
                                return results2;
                            }
                            return Debug.fail(`Unhandled class member kind! ${p.__debugFlags || p.flags}`);
                        };
                    }
                    function serializePropertySymbolForInterface(p, baseType) {
                        return serializePropertySymbolForInterfaceWorker(p, 
                        /*isStatic*/
                        false, baseType);
                    }
                    function serializeSignatures(kind, input, baseType, outputKind) {
                        const signatures = getSignaturesOfType(input, kind);
                        if (kind === 1 /* Construct */) {
                            if (!baseType && every(signatures, (s) => length(s.parameters) === 0)) {
                                return [];
                            }
                            if (baseType) {
                                const baseSigs = getSignaturesOfType(baseType, 1 /* Construct */);
                                if (!length(baseSigs) && every(signatures, (s) => length(s.parameters) === 0)) {
                                    return [];
                                }
                                if (baseSigs.length === signatures.length) {
                                    let failed = false;
                                    for (let i = 0; i < baseSigs.length; i++) {
                                        if (!compareSignaturesIdentical(signatures[i], baseSigs[i], 
                                        /*partialMatch*/
                                        false, 
                                        /*ignoreThisTypes*/
                                        false, 
                                        /*ignoreReturnTypes*/
                                        true, compareTypesIdentical)) {
                                            failed = true;
                                            break;
                                        }
                                    }
                                    if (!failed) {
                                        return [];
                                    }
                                }
                            }
                            let privateProtected = 0;
                            for (const s of signatures) {
                                if (s.declaration) {
                                    privateProtected |= getSelectedEffectiveModifierFlags(s.declaration, 8 /* Private */ | 16 /* Protected */);
                                }
                            }
                            if (privateProtected) {
                                return [setTextRange(factory.createConstructorDeclaration(factory.createModifiersFromModifierFlags(privateProtected), 
                                    /*parameters*/
                                    [], 
                                    /*body*/
                                    void 0), signatures[0].declaration)];
                            }
                        }
                        const results2 = [];
                        for (const sig of signatures) {
                            const decl = signatureToSignatureDeclarationHelper(sig, outputKind, context);
                            results2.push(setTextRange(decl, sig.declaration));
                        }
                        return results2;
                    }
                    function serializeIndexSignatures(input, baseType) {
                        const results2 = [];
                        for (const info of getIndexInfosOfType(input)) {
                            if (baseType) {
                                const baseInfo = getIndexInfoOfType(baseType, info.keyType);
                                if (baseInfo) {
                                    if (isTypeIdenticalTo(info.type, baseInfo.type)) {
                                        continue;
                                    }
                                }
                            }
                            results2.push(indexInfoToIndexSignatureDeclarationHelper(info, context, 
                            /*typeNode*/
                            void 0));
                        }
                        return results2;
                    }
                    function serializeBaseType(t, staticType, rootName) {
                        const ref = trySerializeAsTypeReference(t, 111551 /* Value */);
                        if (ref) {
                            return ref;
                        }
                        const tempName = getUnusedName(`${rootName}_base`);
                        const statement = factory.createVariableStatement(
                        /*modifiers*/
                        void 0, factory.createVariableDeclarationList([
                            factory.createVariableDeclaration(tempName, 
                            /*exclamationToken*/
                            void 0, typeToTypeNodeHelper(staticType, context))
                        ], 2 /* Const */));
                        addResult(statement, 0 /* None */);
                        return factory.createExpressionWithTypeArguments(factory.createIdentifier(tempName), 
                        /*typeArgs*/
                        void 0);
                    }
                    function trySerializeAsTypeReference(t, flags) {
                        let typeArgs;
                        let reference;
                        if (t.target && isSymbolAccessibleByFlags(t.target.symbol, enclosingDeclaration, flags)) {
                            typeArgs = map(getTypeArguments(t), (t2) => typeToTypeNodeHelper(t2, context));
                            reference = symbolToExpression(t.target.symbol, context, 788968 /* Type */);
                        }
                        else if (t.symbol && isSymbolAccessibleByFlags(t.symbol, enclosingDeclaration, flags)) {
                            reference = symbolToExpression(t.symbol, context, 788968 /* Type */);
                        }
                        if (reference) {
                            return factory.createExpressionWithTypeArguments(reference, typeArgs);
                        }
                    }
                    function serializeImplementedType(t) {
                        const ref = trySerializeAsTypeReference(t, 788968 /* Type */);
                        if (ref) {
                            return ref;
                        }
                        if (t.symbol) {
                            return factory.createExpressionWithTypeArguments(symbolToExpression(t.symbol, context, 788968 /* Type */), 
                            /*typeArgs*/
                            void 0);
                        }
                    }
                    function getUnusedName(input, symbol) {
                        var _a2, _b;
                        const id = symbol ? getSymbolId(symbol) : void 0;
                        if (id) {
                            if (context.remappedSymbolNames.has(id)) {
                                return context.remappedSymbolNames.get(id);
                            }
                        }
                        if (symbol) {
                            input = getNameCandidateWorker(symbol, input);
                        }
                        let i = 0;
                        const original = input;
                        while ((_a2 = context.usedSymbolNames) == null ? void 0 : _a2.has(input)) {
                            i++;
                            input = `${original}_${i}`;
                        }
                        (_b = context.usedSymbolNames) == null ? void 0 : _b.add(input);
                        if (id) {
                            context.remappedSymbolNames.set(id, input);
                        }
                        return input;
                    }
                    function getNameCandidateWorker(symbol, localName) {
                        if (localName === "default" /* Default */ || localName === "__class" /* Class */ || localName === "__function" /* Function */) {
                            const flags = context.flags;
                            context.flags |= 16777216 /* InInitialEntityName */;
                            const nameCandidate = getNameOfSymbolAsWritten(symbol, context);
                            context.flags = flags;
                            localName = nameCandidate.length > 0 && isSingleOrDoubleQuote(nameCandidate.charCodeAt(0)) ? stripQuotes(nameCandidate) : nameCandidate;
                        }
                        if (localName === "default" /* Default */) {
                            localName = "_default";
                        }
                        else if (localName === "export=" /* ExportEquals */) {
                            localName = "_exports";
                        }
                        localName = isIdentifierText(localName, languageVersion) && !isStringANonContextualKeyword(localName) ? localName : "_" + localName.replace(/[^a-zA-Z0-9]/g, "_");
                        return localName;
                    }
                    function getInternalSymbolName(symbol, localName) {
                        const id = getSymbolId(symbol);
                        if (context.remappedSymbolNames.has(id)) {
                            return context.remappedSymbolNames.get(id);
                        }
                        localName = getNameCandidateWorker(symbol, localName);
                        context.remappedSymbolNames.set(id, localName);
                        return localName;
                    }
                }
            }
            function typePredicateToString(typePredicate, enclosingDeclaration, flags = 16384 /* UseAliasDefinedOutsideCurrentScope */, writer) {
                return writer ? typePredicateToStringWorker(writer).getText() : usingSingleLineStringWriter(typePredicateToStringWorker);
                function typePredicateToStringWorker(writer2) {
                    const predicate = factory.createTypePredicateNode(typePredicate.kind === 2 /* AssertsThis */ || typePredicate.kind === 3 /* AssertsIdentifier */ ? factory.createToken(129 /* AssertsKeyword */) : void 0, typePredicate.kind === 1 /* Identifier */ || typePredicate.kind === 3 /* AssertsIdentifier */ ? factory.createIdentifier(typePredicate.parameterName) : factory.createThisTypeNode(), typePredicate.type && nodeBuilder.typeToTypeNode(typePredicate.type, enclosingDeclaration, toNodeBuilderFlags(flags) | 70221824 /* IgnoreErrors */ | 512 /* WriteTypeParametersInQualifiedName */)
                    // TODO: GH#18217
                    );
                    const printer = createPrinterWithRemoveComments();
                    const sourceFile = enclosingDeclaration && getSourceFileOfNode(enclosingDeclaration);
                    printer.writeNode(4 /* Unspecified */, predicate, 
                    /*sourceFile*/
                    sourceFile, writer2);
                    return writer2;
                }
            }
            function formatUnionTypes(types) {
                const result = [];
                let flags = 0;
                for (let i = 0; i < types.length; i++) {
                    const t = types[i];
                    flags |= t.flags;
                    if (!(t.flags & 98304 /* Nullable */)) {
                        if (t.flags & (512 /* BooleanLiteral */ | 1056 /* EnumLike */)) {
                            const baseType = t.flags & 512 /* BooleanLiteral */ ? booleanType : getBaseTypeOfEnumLikeType(t);
                            if (baseType.flags & 1048576 /* Union */) {
                                const count = baseType.types.length;
                                if (i + count <= types.length && getRegularTypeOfLiteralType(types[i + count - 1]) === getRegularTypeOfLiteralType(baseType.types[count - 1])) {
                                    result.push(baseType);
                                    i += count - 1;
                                    continue;
                                }
                            }
                        }
                        result.push(t);
                    }
                }
                if (flags & 65536 /* Null */)
                    result.push(nullType);
                if (flags & 32768 /* Undefined */)
                    result.push(undefinedType);
                return result || types;
            }
            function visibilityToString(flags) {
                if (flags === 8 /* Private */) {
                    return "private";
                }
                if (flags === 16 /* Protected */) {
                    return "protected";
                }
                return "public";
            }
            function getTypeAliasForTypeLiteral(type) {
                if (type.symbol && type.symbol.flags & 2048 /* TypeLiteral */ && type.symbol.declarations) {
                    const node = walkUpParenthesizedTypes(type.symbol.declarations[0].parent);
                    if (isTypeAliasDeclaration(node)) {
                        return getSymbolOfDeclaration(node);
                    }
                }
                return void 0;
            }
            function isTopLevelInExternalModuleAugmentation(node) {
                return node && node.parent && node.parent.kind === 265 /* ModuleBlock */ && isExternalModuleAugmentation(node.parent.parent);
            }
            function isDefaultBindingContext(location) {
                return location.kind === 308 /* SourceFile */ || isAmbientModule(location);
            }
            function getNameOfSymbolFromNameType(symbol, context) {
                const nameType = getSymbolLinks(symbol).nameType;
                if (nameType) {
                    if (nameType.flags & 384 /* StringOrNumberLiteral */) {
                        const name = "" + nameType.value;
                        if (!isIdentifierText(name, getEmitScriptTarget(compilerOptions)) && !isNumericLiteralName(name)) {
                            return `"${escapeString(name, 34 /* doubleQuote */)}"`;
                        }
                        if (isNumericLiteralName(name) && startsWith(name, "-")) {
                            return `[${name}]`;
                        }
                        return name;
                    }
                    if (nameType.flags & 8192 /* UniqueESSymbol */) {
                        return `[${getNameOfSymbolAsWritten(nameType.symbol, context)}]`;
                    }
                }
            }
            function getNameOfSymbolAsWritten(symbol, context) {
                if (context && symbol.escapedName === "default" /* Default */ && !(context.flags & 16384 /* UseAliasDefinedOutsideCurrentScope */) && // If it's not the first part of an entity name, it must print as `default`
                    (!(context.flags & 16777216 /* InInitialEntityName */) || // if the symbol is synthesized, it will only be referenced externally it must print as `default`
                        !symbol.declarations || // if not in the same binding context (source file, module declaration), it must print as `default`
                        context.enclosingDeclaration && findAncestor(symbol.declarations[0], isDefaultBindingContext) !== findAncestor(context.enclosingDeclaration, isDefaultBindingContext))) {
                    return "default";
                }
                if (symbol.declarations && symbol.declarations.length) {
                    let declaration = firstDefined(symbol.declarations, (d) => getNameOfDeclaration(d) ? d : void 0);
                    const name2 = declaration && getNameOfDeclaration(declaration);
                    if (declaration && name2) {
                        if (isCallExpression(declaration) && isBindableObjectDefinePropertyCall(declaration)) {
                            return symbolName(symbol);
                        }
                        if (isComputedPropertyName(name2) && !(getCheckFlags(symbol) & 4096 /* Late */)) {
                            const nameType = getSymbolLinks(symbol).nameType;
                            if (nameType && nameType.flags & 384 /* StringOrNumberLiteral */) {
                                const result = getNameOfSymbolFromNameType(symbol, context);
                                if (result !== void 0) {
                                    return result;
                                }
                            }
                        }
                        return declarationNameToString(name2);
                    }
                    if (!declaration) {
                        declaration = symbol.declarations[0];
                    }
                    if (declaration.parent && declaration.parent.kind === 257 /* VariableDeclaration */) {
                        return declarationNameToString(declaration.parent.name);
                    }
                    switch (declaration.kind) {
                        case 228 /* ClassExpression */:
                        case 215 /* FunctionExpression */:
                        case 216 /* ArrowFunction */:
                            if (context && !context.encounteredError && !(context.flags & 131072 /* AllowAnonymousIdentifier */)) {
                                context.encounteredError = true;
                            }
                            return declaration.kind === 228 /* ClassExpression */ ? "(Anonymous class)" : "(Anonymous function)";
                    }
                }
                const name = getNameOfSymbolFromNameType(symbol, context);
                return name !== void 0 ? name : symbolName(symbol);
            }
            function isDeclarationVisible(node) {
                if (node) {
                    const links = getNodeLinks(node);
                    if (links.isVisible === void 0) {
                        links.isVisible = !!determineIfDeclarationIsVisible();
                    }
                    return links.isVisible;
                }
                return false;
                function determineIfDeclarationIsVisible() {
                    switch (node.kind) {
                        case 341 /* JSDocCallbackTag */:
                        case 349 /* JSDocTypedefTag */:
                        case 343 /* JSDocEnumTag */:
                            return !!(node.parent && node.parent.parent && node.parent.parent.parent && isSourceFile(node.parent.parent.parent));
                        case 205 /* BindingElement */:
                            return isDeclarationVisible(node.parent.parent);
                        case 257 /* VariableDeclaration */:
                            if (isBindingPattern(node.name) && !node.name.elements.length) {
                                return false;
                            }
                        case 264 /* ModuleDeclaration */:
                        case 260 /* ClassDeclaration */:
                        case 261 /* InterfaceDeclaration */:
                        case 262 /* TypeAliasDeclaration */:
                        case 259 /* FunctionDeclaration */:
                        case 263 /* EnumDeclaration */:
                        case 268 /* ImportEqualsDeclaration */:
                            if (isExternalModuleAugmentation(node)) {
                                return true;
                            }
                            const parent2 = getDeclarationContainer(node);
                            if (!(getCombinedModifierFlags(node) & 1 /* Export */) && !(node.kind !== 268 /* ImportEqualsDeclaration */ && parent2.kind !== 308 /* SourceFile */ && parent2.flags & 16777216 /* Ambient */)) {
                                return isGlobalSourceFile(parent2);
                            }
                            return isDeclarationVisible(parent2);
                        case 169 /* PropertyDeclaration */:
                        case 168 /* PropertySignature */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                        case 171 /* MethodDeclaration */:
                        case 170 /* MethodSignature */:
                            if (hasEffectiveModifier(node, 8 /* Private */ | 16 /* Protected */)) {
                                return false;
                            }
                        case 173 /* Constructor */:
                        case 177 /* ConstructSignature */:
                        case 176 /* CallSignature */:
                        case 178 /* IndexSignature */:
                        case 166 /* Parameter */:
                        case 265 /* ModuleBlock */:
                        case 181 /* FunctionType */:
                        case 182 /* ConstructorType */:
                        case 184 /* TypeLiteral */:
                        case 180 /* TypeReference */:
                        case 185 /* ArrayType */:
                        case 186 /* TupleType */:
                        case 189 /* UnionType */:
                        case 190 /* IntersectionType */:
                        case 193 /* ParenthesizedType */:
                        case 199 /* NamedTupleMember */:
                            return isDeclarationVisible(node.parent);
                        case 270 /* ImportClause */:
                        case 271 /* NamespaceImport */:
                        case 273 /* ImportSpecifier */:
                            return false;
                        case 165 /* TypeParameter */:
                        case 308 /* SourceFile */:
                        case 267 /* NamespaceExportDeclaration */:
                            return true;
                        case 274 /* ExportAssignment */:
                            return false;
                        default:
                            return false;
                    }
                }
            }
            function collectLinkedAliases(node, setVisibility) {
                let exportSymbol;
                if (node.parent && node.parent.kind === 274 /* ExportAssignment */) {
                    exportSymbol = resolveName(node, node.escapedText, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */, 
                    /*nameNotFoundMessage*/
                    void 0, node, 
                    /*isUse*/
                    false);
                }
                else if (node.parent.kind === 278 /* ExportSpecifier */) {
                    exportSymbol = getTargetOfExportSpecifier(node.parent, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */);
                }
                let result;
                let visited;
                if (exportSymbol) {
                    visited = /* @__PURE__ */ new Set();
                    visited.add(getSymbolId(exportSymbol));
                    buildVisibleNodeList(exportSymbol.declarations);
                }
                return result;
                function buildVisibleNodeList(declarations) {
                    forEach(declarations, (declaration) => {
                        const resultNode = getAnyImportSyntax(declaration) || declaration;
                        if (setVisibility) {
                            getNodeLinks(declaration).isVisible = true;
                        }
                        else {
                            result = result || [];
                            pushIfUnique(result, resultNode);
                        }
                        if (isInternalModuleImportEqualsDeclaration(declaration)) {
                            const internalModuleReference = declaration.moduleReference;
                            const firstIdentifier = getFirstIdentifier(internalModuleReference);
                            const importSymbol = resolveName(declaration, firstIdentifier.escapedText, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, void 0, void 0, 
                            /*isUse*/
                            false);
                            if (importSymbol && visited) {
                                if (tryAddToSet(visited, getSymbolId(importSymbol))) {
                                    buildVisibleNodeList(importSymbol.declarations);
                                }
                            }
                        }
                    });
                }
            }
            function pushTypeResolution(target, propertyName) {
                const resolutionCycleStartIndex = findResolutionCycleStartIndex(target, propertyName);
                if (resolutionCycleStartIndex >= 0) {
                    const { length: length2 } = resolutionTargets;
                    for (let i = resolutionCycleStartIndex; i < length2; i++) {
                        resolutionResults[i] = false;
                    }
                    return false;
                }
                resolutionTargets.push(target);
                resolutionResults.push(
                /*items*/
                true);
                resolutionPropertyNames.push(propertyName);
                return true;
            }
            function findResolutionCycleStartIndex(target, propertyName) {
                for (let i = resolutionTargets.length - 1; i >= 0; i--) {
                    if (resolutionTargetHasProperty(resolutionTargets[i], resolutionPropertyNames[i])) {
                        return -1;
                    }
                    if (resolutionTargets[i] === target && resolutionPropertyNames[i] === propertyName) {
                        return i;
                    }
                }
                return -1;
            }
            function resolutionTargetHasProperty(target, propertyName) {
                switch (propertyName) {
                    case 0 /* Type */:
                        return !!getSymbolLinks(target).type;
                    case 5 /* EnumTagType */:
                        return !!getNodeLinks(target).resolvedEnumType;
                    case 2 /* DeclaredType */:
                        return !!getSymbolLinks(target).declaredType;
                    case 1 /* ResolvedBaseConstructorType */:
                        return !!target.resolvedBaseConstructorType;
                    case 3 /* ResolvedReturnType */:
                        return !!target.resolvedReturnType;
                    case 4 /* ImmediateBaseConstraint */:
                        return !!target.immediateBaseConstraint;
                    case 6 /* ResolvedTypeArguments */:
                        return !!target.resolvedTypeArguments;
                    case 7 /* ResolvedBaseTypes */:
                        return !!target.baseTypesResolved;
                    case 8 /* WriteType */:
                        return !!getSymbolLinks(target).writeType;
                    case 9 /* ParameterInitializerContainsUndefined */:
                        return getNodeLinks(target).parameterInitializerContainsUndefined !== void 0;
                }
                return Debug.assertNever(propertyName);
            }
            function popTypeResolution() {
                resolutionTargets.pop();
                resolutionPropertyNames.pop();
                return resolutionResults.pop();
            }
            function getDeclarationContainer(node) {
                return findAncestor(getRootDeclaration(node), (node2) => {
                    switch (node2.kind) {
                        case 257 /* VariableDeclaration */:
                        case 258 /* VariableDeclarationList */:
                        case 273 /* ImportSpecifier */:
                        case 272 /* NamedImports */:
                        case 271 /* NamespaceImport */:
                        case 270 /* ImportClause */:
                            return false;
                        default:
                            return true;
                    }
                }).parent;
            }
            function getTypeOfPrototypeProperty(prototype) {
                const classType = getDeclaredTypeOfSymbol(getParentOfSymbol(prototype));
                return classType.typeParameters ? createTypeReference(classType, map(classType.typeParameters, (_) => anyType)) : classType;
            }
            function getTypeOfPropertyOfType(type, name) {
                const prop = getPropertyOfType(type, name);
                return prop ? getTypeOfSymbol(prop) : void 0;
            }
            function getTypeOfPropertyOrIndexSignature(type, name) {
                var _a2;
                return getTypeOfPropertyOfType(type, name) || ((_a2 = getApplicableIndexInfoForName(type, name)) == null ? void 0 : _a2.type) || unknownType;
            }
            function isTypeAny(type) {
                return type && (type.flags & 1 /* Any */) !== 0;
            }
            function isErrorType(type) {
                return type === errorType || !!(type.flags & 1 /* Any */ && type.aliasSymbol);
            }
            function getTypeForBindingElementParent(node, checkMode) {
                if (checkMode !== 0 /* Normal */) {
                    return getTypeForVariableLikeDeclaration(node, 
                    /*includeOptionality*/
                    false, checkMode);
                }
                const symbol = getSymbolOfDeclaration(node);
                return symbol && getSymbolLinks(symbol).type || getTypeForVariableLikeDeclaration(node, 
                /*includeOptionality*/
                false, checkMode);
            }
            function getRestType(source, properties, symbol) {
                source = filterType(source, (t) => !(t.flags & 98304 /* Nullable */));
                if (source.flags & 131072 /* Never */) {
                    return emptyObjectType;
                }
                if (source.flags & 1048576 /* Union */) {
                    return mapType(source, (t) => getRestType(t, properties, symbol));
                }
                let omitKeyType = getUnionType(map(properties, getLiteralTypeFromPropertyName));
                const spreadableProperties = [];
                const unspreadableToRestKeys = [];
                for (const prop of getPropertiesOfType(source)) {
                    const literalTypeFromProperty = getLiteralTypeFromProperty(prop, 8576 /* StringOrNumberLiteralOrUnique */);
                    if (!isTypeAssignableTo(literalTypeFromProperty, omitKeyType) && !(getDeclarationModifierFlagsFromSymbol(prop) & (8 /* Private */ | 16 /* Protected */)) && isSpreadableProperty(prop)) {
                        spreadableProperties.push(prop);
                    }
                    else {
                        unspreadableToRestKeys.push(literalTypeFromProperty);
                    }
                }
                if (isGenericObjectType(source) || isGenericIndexType(omitKeyType)) {
                    if (unspreadableToRestKeys.length) {
                        omitKeyType = getUnionType([omitKeyType, ...unspreadableToRestKeys]);
                    }
                    if (omitKeyType.flags & 131072 /* Never */) {
                        return source;
                    }
                    const omitTypeAlias = getGlobalOmitSymbol();
                    if (!omitTypeAlias) {
                        return errorType;
                    }
                    return getTypeAliasInstantiation(omitTypeAlias, [source, omitKeyType]);
                }
                const members = createSymbolTable();
                for (const prop of spreadableProperties) {
                    members.set(prop.escapedName, getSpreadSymbol(prop, 
                    /*readonly*/
                    false));
                }
                const result = createAnonymousType(symbol, members, emptyArray, emptyArray, getIndexInfosOfType(source));
                result.objectFlags |= 4194304 /* ObjectRestType */;
                return result;
            }
            function isGenericTypeWithUndefinedConstraint(type) {
                return !!(type.flags & 465829888 /* Instantiable */) && maybeTypeOfKind(getBaseConstraintOfType(type) || unknownType, 32768 /* Undefined */);
            }
            function getNonUndefinedType(type) {
                const typeOrConstraint = someType(type, isGenericTypeWithUndefinedConstraint) ? mapType(type, (t) => t.flags & 465829888 /* Instantiable */ ? getBaseConstraintOrType(t) : t) : type;
                return getTypeWithFacts(typeOrConstraint, 524288 /* NEUndefined */);
            }
            function getFlowTypeOfDestructuring(node, declaredType) {
                const reference = getSyntheticElementAccess(node);
                return reference ? getFlowTypeOfReference(reference, declaredType) : declaredType;
            }
            function getSyntheticElementAccess(node) {
                const parentAccess = getParentElementAccess(node);
                if (parentAccess && canHaveFlowNode(parentAccess) && parentAccess.flowNode) {
                    const propName = getDestructuringPropertyName(node);
                    if (propName) {
                        const literal = setTextRange(parseNodeFactory.createStringLiteral(propName), node);
                        const lhsExpr = isLeftHandSideExpression(parentAccess) ? parentAccess : parseNodeFactory.createParenthesizedExpression(parentAccess);
                        const result = setTextRange(parseNodeFactory.createElementAccessExpression(lhsExpr, literal), node);
                        setParent(literal, result);
                        setParent(result, node);
                        if (lhsExpr !== parentAccess) {
                            setParent(lhsExpr, result);
                        }
                        result.flowNode = parentAccess.flowNode;
                        return result;
                    }
                }
            }
            function getParentElementAccess(node) {
                const ancestor = node.parent.parent;
                switch (ancestor.kind) {
                    case 205 /* BindingElement */:
                    case 299 /* PropertyAssignment */:
                        return getSyntheticElementAccess(ancestor);
                    case 206 /* ArrayLiteralExpression */:
                        return getSyntheticElementAccess(node.parent);
                    case 257 /* VariableDeclaration */:
                        return ancestor.initializer;
                    case 223 /* BinaryExpression */:
                        return ancestor.right;
                }
            }
            function getDestructuringPropertyName(node) {
                const parent2 = node.parent;
                if (node.kind === 205 /* BindingElement */ && parent2.kind === 203 /* ObjectBindingPattern */) {
                    return getLiteralPropertyNameText(node.propertyName || node.name);
                }
                if (node.kind === 299 /* PropertyAssignment */ || node.kind === 300 /* ShorthandPropertyAssignment */) {
                    return getLiteralPropertyNameText(node.name);
                }
                return "" + parent2.elements.indexOf(node);
            }
            function getLiteralPropertyNameText(name) {
                const type = getLiteralTypeFromPropertyName(name);
                return type.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */) ? "" + type.value : void 0;
            }
            function getTypeForBindingElement(declaration) {
                const checkMode = declaration.dotDotDotToken ? 64 /* RestBindingElement */ : 0 /* Normal */;
                const parentType = getTypeForBindingElementParent(declaration.parent.parent, checkMode);
                return parentType && getBindingElementTypeFromParentType(declaration, parentType);
            }
            function getBindingElementTypeFromParentType(declaration, parentType) {
                if (isTypeAny(parentType)) {
                    return parentType;
                }
                const pattern = declaration.parent;
                if (strictNullChecks && declaration.flags & 16777216 /* Ambient */ && isParameterDeclaration(declaration)) {
                    parentType = getNonNullableType(parentType);
                }
                else if (strictNullChecks && pattern.parent.initializer && !(getTypeFacts(getTypeOfInitializer(pattern.parent.initializer)) & 65536 /* EQUndefined */)) {
                    parentType = getTypeWithFacts(parentType, 524288 /* NEUndefined */);
                }
                let type;
                if (pattern.kind === 203 /* ObjectBindingPattern */) {
                    if (declaration.dotDotDotToken) {
                        parentType = getReducedType(parentType);
                        if (parentType.flags & 2 /* Unknown */ || !isValidSpreadType(parentType)) {
                            error(declaration, Diagnostics.Rest_types_may_only_be_created_from_object_types);
                            return errorType;
                        }
                        const literalMembers = [];
                        for (const element of pattern.elements) {
                            if (!element.dotDotDotToken) {
                                literalMembers.push(element.propertyName || element.name);
                            }
                        }
                        type = getRestType(parentType, literalMembers, declaration.symbol);
                    }
                    else {
                        const name = declaration.propertyName || declaration.name;
                        const indexType = getLiteralTypeFromPropertyName(name);
                        const declaredType = getIndexedAccessType(parentType, indexType, 32 /* ExpressionPosition */, name);
                        type = getFlowTypeOfDestructuring(declaration, declaredType);
                    }
                }
                else {
                    const elementType = checkIteratedTypeOrElementType(65 /* Destructuring */ | (declaration.dotDotDotToken ? 0 : 128 /* PossiblyOutOfBounds */), parentType, undefinedType, pattern);
                    const index = pattern.elements.indexOf(declaration);
                    if (declaration.dotDotDotToken) {
                        const baseConstraint = getBaseConstraintOrType(parentType);
                        type = everyType(baseConstraint, isTupleType) ? mapType(baseConstraint, (t) => sliceTupleType(t, index)) : createArrayType(elementType);
                    }
                    else if (isArrayLikeType(parentType)) {
                        const indexType = getNumberLiteralType(index);
                        const accessFlags = 32 /* ExpressionPosition */ | (hasDefaultValue(declaration) ? 16 /* NoTupleBoundsCheck */ : 0);
                        const declaredType = getIndexedAccessTypeOrUndefined(parentType, indexType, accessFlags, declaration.name) || errorType;
                        type = getFlowTypeOfDestructuring(declaration, declaredType);
                    }
                    else {
                        type = elementType;
                    }
                }
                if (!declaration.initializer) {
                    return type;
                }
                if (getEffectiveTypeAnnotationNode(walkUpBindingElementsAndPatterns(declaration))) {
                    return strictNullChecks && !(getTypeFacts(checkDeclarationInitializer(declaration, 0 /* Normal */)) & 16777216 /* IsUndefined */) ? getNonUndefinedType(type) : type;
                }
                return widenTypeInferredFromInitializer(declaration, getUnionType([getNonUndefinedType(type), checkDeclarationInitializer(declaration, 0 /* Normal */)], 2 /* Subtype */));
            }
            function getTypeForDeclarationFromJSDocComment(declaration) {
                const jsdocType = getJSDocType(declaration);
                if (jsdocType) {
                    return getTypeFromTypeNode(jsdocType);
                }
                return void 0;
            }
            function isNullOrUndefined3(node) {
                const expr = skipParentheses(node, 
                /*excludeJSDocTypeAssertions*/
                true);
                return expr.kind === 104 /* NullKeyword */ || expr.kind === 79 /* Identifier */ && getResolvedSymbol(expr) === undefinedSymbol;
            }
            function isEmptyArrayLiteral2(node) {
                const expr = skipParentheses(node, 
                /*excludeJSDocTypeAssertions*/
                true);
                return expr.kind === 206 /* ArrayLiteralExpression */ && expr.elements.length === 0;
            }
            function addOptionality(type, isProperty = false, isOptional = true) {
                return strictNullChecks && isOptional ? getOptionalType(type, isProperty) : type;
            }
            function getTypeForVariableLikeDeclaration(declaration, includeOptionality, checkMode) {
                if (isVariableDeclaration(declaration) && declaration.parent.parent.kind === 246 /* ForInStatement */) {
                    const indexType = getIndexType(getNonNullableTypeIfNeeded(checkExpression(declaration.parent.parent.expression, 
                    /*checkMode*/
                    checkMode)));
                    return indexType.flags & (262144 /* TypeParameter */ | 4194304 /* Index */) ? getExtractStringType(indexType) : stringType;
                }
                if (isVariableDeclaration(declaration) && declaration.parent.parent.kind === 247 /* ForOfStatement */) {
                    const forOfStatement = declaration.parent.parent;
                    return checkRightHandSideOfForOf(forOfStatement) || anyType;
                }
                if (isBindingPattern(declaration.parent)) {
                    return getTypeForBindingElement(declaration);
                }
                const isProperty = isPropertyDeclaration(declaration) && !hasAccessorModifier(declaration) || isPropertySignature(declaration) || isJSDocPropertyTag(declaration);
                const isOptional = includeOptionality && isOptionalDeclaration(declaration);
                const declaredType = tryGetTypeFromEffectiveTypeNode(declaration);
                if (isCatchClauseVariableDeclarationOrBindingElement(declaration)) {
                    if (declaredType) {
                        return isTypeAny(declaredType) || declaredType === unknownType ? declaredType : errorType;
                    }
                    return useUnknownInCatchVariables ? unknownType : anyType;
                }
                if (declaredType) {
                    return addOptionality(declaredType, isProperty, isOptional);
                }
                if ((noImplicitAny || isInJSFile(declaration)) && isVariableDeclaration(declaration) && !isBindingPattern(declaration.name) && !(getCombinedModifierFlags(declaration) & 1 /* Export */) && !(declaration.flags & 16777216 /* Ambient */)) {
                    if (!(getCombinedNodeFlags(declaration) & 2 /* Const */) && (!declaration.initializer || isNullOrUndefined3(declaration.initializer))) {
                        return autoType;
                    }
                    if (declaration.initializer && isEmptyArrayLiteral2(declaration.initializer)) {
                        return autoArrayType;
                    }
                }
                if (isParameter(declaration)) {
                    const func = declaration.parent;
                    if (func.kind === 175 /* SetAccessor */ && hasBindableName(func)) {
                        const getter = getDeclarationOfKind(getSymbolOfDeclaration(declaration.parent), 174 /* GetAccessor */);
                        if (getter) {
                            const getterSignature = getSignatureFromDeclaration(getter);
                            const thisParameter = getAccessorThisParameter(func);
                            if (thisParameter && declaration === thisParameter) {
                                Debug.assert(!thisParameter.type);
                                return getTypeOfSymbol(getterSignature.thisParameter);
                            }
                            return getReturnTypeOfSignature(getterSignature);
                        }
                    }
                    const parameterTypeOfTypeTag = getParameterTypeOfTypeTag(func, declaration);
                    if (parameterTypeOfTypeTag)
                        return parameterTypeOfTypeTag;
                    const type = declaration.symbol.escapedName === "this" /* This */ ? getContextualThisParameterType(func) : getContextuallyTypedParameterType(declaration);
                    if (type) {
                        return addOptionality(type, 
                        /*isProperty*/
                        false, isOptional);
                    }
                }
                if (hasOnlyExpressionInitializer(declaration) && !!declaration.initializer) {
                    if (isInJSFile(declaration) && !isParameter(declaration)) {
                        const containerObjectType = getJSContainerObjectType(declaration, getSymbolOfDeclaration(declaration), getDeclaredExpandoInitializer(declaration));
                        if (containerObjectType) {
                            return containerObjectType;
                        }
                    }
                    const type = widenTypeInferredFromInitializer(declaration, checkDeclarationInitializer(declaration, checkMode));
                    return addOptionality(type, isProperty, isOptional);
                }
                if (isPropertyDeclaration(declaration) && (noImplicitAny || isInJSFile(declaration))) {
                    if (!hasStaticModifier(declaration)) {
                        const constructor = findConstructorDeclaration(declaration.parent);
                        const type = constructor ? getFlowTypeInConstructor(declaration.symbol, constructor) : getEffectiveModifierFlags(declaration) & 2 /* Ambient */ ? getTypeOfPropertyInBaseClass(declaration.symbol) : void 0;
                        return type && addOptionality(type, 
                        /*isProperty*/
                        true, isOptional);
                    }
                    else {
                        const staticBlocks = filter(declaration.parent.members, isClassStaticBlockDeclaration);
                        const type = staticBlocks.length ? getFlowTypeInStaticBlocks(declaration.symbol, staticBlocks) : getEffectiveModifierFlags(declaration) & 2 /* Ambient */ ? getTypeOfPropertyInBaseClass(declaration.symbol) : void 0;
                        return type && addOptionality(type, 
                        /*isProperty*/
                        true, isOptional);
                    }
                }
                if (isJsxAttribute(declaration)) {
                    return trueType;
                }
                if (isBindingPattern(declaration.name)) {
                    return getTypeFromBindingPattern(declaration.name, 
                    /*includePatternInType*/
                    false, 
                    /*reportErrors*/
                    true);
                }
                return void 0;
            }
            function isConstructorDeclaredProperty(symbol) {
                if (symbol.valueDeclaration && isBinaryExpression(symbol.valueDeclaration)) {
                    const links = getSymbolLinks(symbol);
                    if (links.isConstructorDeclaredProperty === void 0) {
                        links.isConstructorDeclaredProperty = false;
                        links.isConstructorDeclaredProperty = !!getDeclaringConstructor(symbol) && every(symbol.declarations, (declaration) => isBinaryExpression(declaration) && isPossiblyAliasedThisProperty(declaration) && (declaration.left.kind !== 209 /* ElementAccessExpression */ || isStringOrNumericLiteralLike(declaration.left.argumentExpression)) && !getAnnotatedTypeForAssignmentDeclaration(
                        /*declaredType*/
                        void 0, declaration, symbol, declaration));
                    }
                    return links.isConstructorDeclaredProperty;
                }
                return false;
            }
            function isAutoTypedProperty(symbol) {
                const declaration = symbol.valueDeclaration;
                return declaration && isPropertyDeclaration(declaration) && !getEffectiveTypeAnnotationNode(declaration) && !declaration.initializer && (noImplicitAny || isInJSFile(declaration));
            }
            function getDeclaringConstructor(symbol) {
                if (!symbol.declarations) {
                    return;
                }
                for (const declaration of symbol.declarations) {
                    const container = getThisContainer(declaration, 
                    /*includeArrowFunctions*/
                    false, 
                    /*includeClassComputedPropertyName*/
                    false);
                    if (container && (container.kind === 173 /* Constructor */ || isJSConstructor(container))) {
                        return container;
                    }
                }
            }
            function getFlowTypeFromCommonJSExport(symbol) {
                const file = getSourceFileOfNode(symbol.declarations[0]);
                const accessName = unescapeLeadingUnderscores(symbol.escapedName);
                const areAllModuleExports = symbol.declarations.every((d) => isInJSFile(d) && isAccessExpression(d) && isModuleExportsAccessExpression(d.expression));
                const reference = areAllModuleExports ? factory.createPropertyAccessExpression(factory.createPropertyAccessExpression(factory.createIdentifier("module"), factory.createIdentifier("exports")), accessName) : factory.createPropertyAccessExpression(factory.createIdentifier("exports"), accessName);
                if (areAllModuleExports) {
                    setParent(reference.expression.expression, reference.expression);
                }
                setParent(reference.expression, reference);
                setParent(reference, file);
                reference.flowNode = file.endFlowNode;
                return getFlowTypeOfReference(reference, autoType, undefinedType);
            }
            function getFlowTypeInStaticBlocks(symbol, staticBlocks) {
                const accessName = startsWith(symbol.escapedName, "__#") ? factory.createPrivateIdentifier(symbol.escapedName.split("@")[1]) : unescapeLeadingUnderscores(symbol.escapedName);
                for (const staticBlock of staticBlocks) {
                    const reference = factory.createPropertyAccessExpression(factory.createThis(), accessName);
                    setParent(reference.expression, reference);
                    setParent(reference, staticBlock);
                    reference.flowNode = staticBlock.returnFlowNode;
                    const flowType = getFlowTypeOfProperty(reference, symbol);
                    if (noImplicitAny && (flowType === autoType || flowType === autoArrayType)) {
                        error(symbol.valueDeclaration, Diagnostics.Member_0_implicitly_has_an_1_type, symbolToString(symbol), typeToString(flowType));
                    }
                    if (everyType(flowType, isNullableType)) {
                        continue;
                    }
                    return convertAutoToAny(flowType);
                }
            }
            function getFlowTypeInConstructor(symbol, constructor) {
                const accessName = startsWith(symbol.escapedName, "__#") ? factory.createPrivateIdentifier(symbol.escapedName.split("@")[1]) : unescapeLeadingUnderscores(symbol.escapedName);
                const reference = factory.createPropertyAccessExpression(factory.createThis(), accessName);
                setParent(reference.expression, reference);
                setParent(reference, constructor);
                reference.flowNode = constructor.returnFlowNode;
                const flowType = getFlowTypeOfProperty(reference, symbol);
                if (noImplicitAny && (flowType === autoType || flowType === autoArrayType)) {
                    error(symbol.valueDeclaration, Diagnostics.Member_0_implicitly_has_an_1_type, symbolToString(symbol), typeToString(flowType));
                }
                return everyType(flowType, isNullableType) ? void 0 : convertAutoToAny(flowType);
            }
            function getFlowTypeOfProperty(reference, prop) {
                const initialType = (prop == null ? void 0 : prop.valueDeclaration) && (!isAutoTypedProperty(prop) || getEffectiveModifierFlags(prop.valueDeclaration) & 2 /* Ambient */) && getTypeOfPropertyInBaseClass(prop) || undefinedType;
                return getFlowTypeOfReference(reference, autoType, initialType);
            }
            function getWidenedTypeForAssignmentDeclaration(symbol, resolvedSymbol) {
                const container = getAssignedExpandoInitializer(symbol.valueDeclaration);
                if (container) {
                    const tag = isInJSFile(container) ? getJSDocTypeTag(container) : void 0;
                    if (tag && tag.typeExpression) {
                        return getTypeFromTypeNode(tag.typeExpression);
                    }
                    const containerObjectType = symbol.valueDeclaration && getJSContainerObjectType(symbol.valueDeclaration, symbol, container);
                    return containerObjectType || getWidenedLiteralType(checkExpressionCached(container));
                }
                let type;
                let definedInConstructor = false;
                let definedInMethod = false;
                if (isConstructorDeclaredProperty(symbol)) {
                    type = getFlowTypeInConstructor(symbol, getDeclaringConstructor(symbol));
                }
                if (!type) {
                    let types;
                    if (symbol.declarations) {
                        let jsdocType;
                        for (const declaration of symbol.declarations) {
                            const expression = isBinaryExpression(declaration) || isCallExpression(declaration) ? declaration : isAccessExpression(declaration) ? isBinaryExpression(declaration.parent) ? declaration.parent : declaration : void 0;
                            if (!expression) {
                                continue;
                            }
                            const kind = isAccessExpression(expression) ? getAssignmentDeclarationPropertyAccessKind(expression) : getAssignmentDeclarationKind(expression);
                            if (kind === 4 /* ThisProperty */ || isBinaryExpression(expression) && isPossiblyAliasedThisProperty(expression, kind)) {
                                if (isDeclarationInConstructor(expression)) {
                                    definedInConstructor = true;
                                }
                                else {
                                    definedInMethod = true;
                                }
                            }
                            if (!isCallExpression(expression)) {
                                jsdocType = getAnnotatedTypeForAssignmentDeclaration(jsdocType, expression, symbol, declaration);
                            }
                            if (!jsdocType) {
                                (types || (types = [])).push(isBinaryExpression(expression) || isCallExpression(expression) ? getInitializerTypeFromAssignmentDeclaration(symbol, resolvedSymbol, expression, kind) : neverType);
                            }
                        }
                        type = jsdocType;
                    }
                    if (!type) {
                        if (!length(types)) {
                            return errorType;
                        }
                        let constructorTypes = definedInConstructor && symbol.declarations ? getConstructorDefinedThisAssignmentTypes(types, symbol.declarations) : void 0;
                        if (definedInMethod) {
                            const propType = getTypeOfPropertyInBaseClass(symbol);
                            if (propType) {
                                (constructorTypes || (constructorTypes = [])).push(propType);
                                definedInConstructor = true;
                            }
                        }
                        const sourceTypes = some(constructorTypes, (t) => !!(t.flags & ~98304 /* Nullable */)) ? constructorTypes : types;
                        type = getUnionType(sourceTypes);
                    }
                }
                const widened = getWidenedType(addOptionality(type, 
                /*isProperty*/
                false, definedInMethod && !definedInConstructor));
                if (symbol.valueDeclaration && filterType(widened, (t) => !!(t.flags & ~98304 /* Nullable */)) === neverType) {
                    reportImplicitAny(symbol.valueDeclaration, anyType);
                    return anyType;
                }
                return widened;
            }
            function getJSContainerObjectType(decl, symbol, init) {
                var _a2, _b;
                if (!isInJSFile(decl) || !init || !isObjectLiteralExpression(init) || init.properties.length) {
                    return void 0;
                }
                const exports = createSymbolTable();
                while (isBinaryExpression(decl) || isPropertyAccessExpression(decl)) {
                    const s2 = getSymbolOfNode(decl);
                    if ((_a2 = s2 == null ? void 0 : s2.exports) == null ? void 0 : _a2.size) {
                        mergeSymbolTable(exports, s2.exports);
                    }
                    decl = isBinaryExpression(decl) ? decl.parent : decl.parent.parent;
                }
                const s = getSymbolOfNode(decl);
                if ((_b = s == null ? void 0 : s.exports) == null ? void 0 : _b.size) {
                    mergeSymbolTable(exports, s.exports);
                }
                const type = createAnonymousType(symbol, exports, emptyArray, emptyArray, emptyArray);
                type.objectFlags |= 4096 /* JSLiteral */;
                return type;
            }
            function getAnnotatedTypeForAssignmentDeclaration(declaredType, expression, symbol, declaration) {
                var _a2;
                const typeNode = getEffectiveTypeAnnotationNode(expression.parent);
                if (typeNode) {
                    const type = getWidenedType(getTypeFromTypeNode(typeNode));
                    if (!declaredType) {
                        return type;
                    }
                    else if (!isErrorType(declaredType) && !isErrorType(type) && !isTypeIdenticalTo(declaredType, type)) {
                        errorNextVariableOrPropertyDeclarationMustHaveSameType(
                        /*firstDeclaration*/
                        void 0, declaredType, declaration, type);
                    }
                }
                if ((_a2 = symbol.parent) == null ? void 0 : _a2.valueDeclaration) {
                    const typeNode2 = getEffectiveTypeAnnotationNode(symbol.parent.valueDeclaration);
                    if (typeNode2) {
                        const annotationSymbol = getPropertyOfType(getTypeFromTypeNode(typeNode2), symbol.escapedName);
                        if (annotationSymbol) {
                            return getNonMissingTypeOfSymbol(annotationSymbol);
                        }
                    }
                }
                return declaredType;
            }
            function getInitializerTypeFromAssignmentDeclaration(symbol, resolvedSymbol, expression, kind) {
                if (isCallExpression(expression)) {
                    if (resolvedSymbol) {
                        return getTypeOfSymbol(resolvedSymbol);
                    }
                    const objectLitType = checkExpressionCached(expression.arguments[2]);
                    const valueType = getTypeOfPropertyOfType(objectLitType, "value");
                    if (valueType) {
                        return valueType;
                    }
                    const getFunc = getTypeOfPropertyOfType(objectLitType, "get");
                    if (getFunc) {
                        const getSig = getSingleCallSignature(getFunc);
                        if (getSig) {
                            return getReturnTypeOfSignature(getSig);
                        }
                    }
                    const setFunc = getTypeOfPropertyOfType(objectLitType, "set");
                    if (setFunc) {
                        const setSig = getSingleCallSignature(setFunc);
                        if (setSig) {
                            return getTypeOfFirstParameterOfSignature(setSig);
                        }
                    }
                    return anyType;
                }
                if (containsSameNamedThisProperty(expression.left, expression.right)) {
                    return anyType;
                }
                const isDirectExport = kind === 1 /* ExportsProperty */ && (isPropertyAccessExpression(expression.left) || isElementAccessExpression(expression.left)) && (isModuleExportsAccessExpression(expression.left.expression) || isIdentifier(expression.left.expression) && isExportsIdentifier(expression.left.expression));
                const type = resolvedSymbol ? getTypeOfSymbol(resolvedSymbol) : isDirectExport ? getRegularTypeOfLiteralType(checkExpressionCached(expression.right)) : getWidenedLiteralType(checkExpressionCached(expression.right));
                if (type.flags & 524288 /* Object */ && kind === 2 /* ModuleExports */ && symbol.escapedName === "export=" /* ExportEquals */) {
                    const exportedType = resolveStructuredTypeMembers(type);
                    const members = createSymbolTable();
                    copyEntries(exportedType.members, members);
                    const initialSize = members.size;
                    if (resolvedSymbol && !resolvedSymbol.exports) {
                        resolvedSymbol.exports = createSymbolTable();
                    }
                    (resolvedSymbol || symbol).exports.forEach((s, name) => {
                        var _a2;
                        const exportedMember = members.get(name);
                        if (exportedMember && exportedMember !== s && !(s.flags & 2097152 /* Alias */)) {
                            if (s.flags & 111551 /* Value */ && exportedMember.flags & 111551 /* Value */) {
                                if (s.valueDeclaration && exportedMember.valueDeclaration && getSourceFileOfNode(s.valueDeclaration) !== getSourceFileOfNode(exportedMember.valueDeclaration)) {
                                    const unescapedName = unescapeLeadingUnderscores(s.escapedName);
                                    const exportedMemberName = ((_a2 = tryCast(exportedMember.valueDeclaration, isNamedDeclaration)) == null ? void 0 : _a2.name) || exportedMember.valueDeclaration;
                                    addRelatedInfo(error(s.valueDeclaration, Diagnostics.Duplicate_identifier_0, unescapedName), createDiagnosticForNode(exportedMemberName, Diagnostics._0_was_also_declared_here, unescapedName));
                                    addRelatedInfo(error(exportedMemberName, Diagnostics.Duplicate_identifier_0, unescapedName), createDiagnosticForNode(s.valueDeclaration, Diagnostics._0_was_also_declared_here, unescapedName));
                                }
                                const union = createSymbol(s.flags | exportedMember.flags, name);
                                union.links.type = getUnionType([getTypeOfSymbol(s), getTypeOfSymbol(exportedMember)]);
                                union.valueDeclaration = exportedMember.valueDeclaration;
                                union.declarations = concatenate(exportedMember.declarations, s.declarations);
                                members.set(name, union);
                            }
                            else {
                                members.set(name, mergeSymbol(s, exportedMember));
                            }
                        }
                        else {
                            members.set(name, s);
                        }
                    });
                    const result = createAnonymousType(initialSize !== members.size ? void 0 : exportedType.symbol, 
                    // Only set the type's symbol if it looks to be the same as the original type
                    members, exportedType.callSignatures, exportedType.constructSignatures, exportedType.indexInfos);
                    if (initialSize === members.size) {
                        if (type.aliasSymbol) {
                            result.aliasSymbol = type.aliasSymbol;
                            result.aliasTypeArguments = type.aliasTypeArguments;
                        }
                        if (getObjectFlags(type) & 4 /* Reference */) {
                            result.aliasSymbol = type.symbol;
                            const args = getTypeArguments(type);
                            result.aliasTypeArguments = length(args) ? args : void 0;
                        }
                    }
                    result.objectFlags |= getObjectFlags(type) & 4096 /* JSLiteral */;
                    if (result.symbol && result.symbol.flags & 32 /* Class */ && type === getDeclaredTypeOfClassOrInterface(result.symbol)) {
                        result.objectFlags |= 16777216 /* IsClassInstanceClone */;
                    }
                    return result;
                }
                if (isEmptyArrayLiteralType(type)) {
                    reportImplicitAny(expression, anyArrayType);
                    return anyArrayType;
                }
                return type;
            }
            function containsSameNamedThisProperty(thisProperty, expression) {
                return isPropertyAccessExpression(thisProperty) && thisProperty.expression.kind === 108 /* ThisKeyword */ && forEachChildRecursively(expression, (n) => isMatchingReference(thisProperty, n));
            }
            function isDeclarationInConstructor(expression) {
                const thisContainer = getThisContainer(expression, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                return thisContainer.kind === 173 /* Constructor */ || thisContainer.kind === 259 /* FunctionDeclaration */ || thisContainer.kind === 215 /* FunctionExpression */ && !isPrototypePropertyAssignment(thisContainer.parent);
            }
            function getConstructorDefinedThisAssignmentTypes(types, declarations) {
                Debug.assert(types.length === declarations.length);
                return types.filter((_, i) => {
                    const declaration = declarations[i];
                    const expression = isBinaryExpression(declaration) ? declaration : isBinaryExpression(declaration.parent) ? declaration.parent : void 0;
                    return expression && isDeclarationInConstructor(expression);
                });
            }
            function getTypeFromBindingElement(element, includePatternInType, reportErrors2) {
                if (element.initializer) {
                    const contextualType = isBindingPattern(element.name) ? getTypeFromBindingPattern(element.name, 
                    /*includePatternInType*/
                    true, 
                    /*reportErrors*/
                    false) : unknownType;
                    return addOptionality(widenTypeInferredFromInitializer(element, checkDeclarationInitializer(element, 0 /* Normal */, contextualType)));
                }
                if (isBindingPattern(element.name)) {
                    return getTypeFromBindingPattern(element.name, includePatternInType, reportErrors2);
                }
                if (reportErrors2 && !declarationBelongsToPrivateAmbientMember(element)) {
                    reportImplicitAny(element, anyType);
                }
                return includePatternInType ? nonInferrableAnyType : anyType;
            }
            function getTypeFromObjectBindingPattern(pattern, includePatternInType, reportErrors2) {
                const members = createSymbolTable();
                let stringIndexInfo;
                let objectFlags = 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                forEach(pattern.elements, (e) => {
                    const name = e.propertyName || e.name;
                    if (e.dotDotDotToken) {
                        stringIndexInfo = createIndexInfo(stringType, anyType, 
                        /*isReadonly*/
                        false);
                        return;
                    }
                    const exprType = getLiteralTypeFromPropertyName(name);
                    if (!isTypeUsableAsPropertyName(exprType)) {
                        objectFlags |= 512 /* ObjectLiteralPatternWithComputedProperties */;
                        return;
                    }
                    const text = getPropertyNameFromType(exprType);
                    const flags = 4 /* Property */ | (e.initializer ? 16777216 /* Optional */ : 0);
                    const symbol = createSymbol(flags, text);
                    symbol.links.type = getTypeFromBindingElement(e, includePatternInType, reportErrors2);
                    symbol.links.bindingElement = e;
                    members.set(symbol.escapedName, symbol);
                });
                const result = createAnonymousType(void 0, members, emptyArray, emptyArray, stringIndexInfo ? [stringIndexInfo] : emptyArray);
                result.objectFlags |= objectFlags;
                if (includePatternInType) {
                    result.pattern = pattern;
                    result.objectFlags |= 131072 /* ContainsObjectOrArrayLiteral */;
                }
                return result;
            }
            function getTypeFromArrayBindingPattern(pattern, includePatternInType, reportErrors2) {
                const elements = pattern.elements;
                const lastElement = lastOrUndefined(elements);
                const restElement = lastElement && lastElement.kind === 205 /* BindingElement */ && lastElement.dotDotDotToken ? lastElement : void 0;
                if (elements.length === 0 || elements.length === 1 && restElement) {
                    return languageVersion >= 2 /* ES2015 */ ? createIterableType(anyType) : anyArrayType;
                }
                const elementTypes = map(elements, (e) => isOmittedExpression(e) ? anyType : getTypeFromBindingElement(e, includePatternInType, reportErrors2));
                const minLength = findLastIndex(elements, (e) => !(e === restElement || isOmittedExpression(e) || hasDefaultValue(e)), elements.length - 1) + 1;
                const elementFlags = map(elements, (e, i) => e === restElement ? 4 /* Rest */ : i >= minLength ? 2 /* Optional */ : 1 /* Required */);
                let result = createTupleType(elementTypes, elementFlags);
                if (includePatternInType) {
                    result = cloneTypeReference(result);
                    result.pattern = pattern;
                    result.objectFlags |= 131072 /* ContainsObjectOrArrayLiteral */;
                }
                return result;
            }
            function getTypeFromBindingPattern(pattern, includePatternInType = false, reportErrors2 = false) {
                return pattern.kind === 203 /* ObjectBindingPattern */ ? getTypeFromObjectBindingPattern(pattern, includePatternInType, reportErrors2) : getTypeFromArrayBindingPattern(pattern, includePatternInType, reportErrors2);
            }
            function getWidenedTypeForVariableLikeDeclaration(declaration, reportErrors2) {
                return widenTypeForVariableLikeDeclaration(getTypeForVariableLikeDeclaration(declaration, 
                /*includeOptionality*/
                true, 0 /* Normal */), declaration, reportErrors2);
            }
            function isGlobalSymbolConstructor(node) {
                const symbol = getSymbolOfNode(node);
                const globalSymbol = getGlobalESSymbolConstructorTypeSymbol(
                /*reportErrors*/
                false);
                return globalSymbol && symbol && symbol === globalSymbol;
            }
            function widenTypeForVariableLikeDeclaration(type, declaration, reportErrors2) {
                if (type) {
                    if (type.flags & 4096 /* ESSymbol */ && isGlobalSymbolConstructor(declaration.parent)) {
                        type = getESSymbolLikeTypeForNode(declaration);
                    }
                    if (reportErrors2) {
                        reportErrorsFromWidening(declaration, type);
                    }
                    if (type.flags & 8192 /* UniqueESSymbol */ && (isBindingElement(declaration) || !declaration.type) && type.symbol !== getSymbolOfDeclaration(declaration)) {
                        type = esSymbolType;
                    }
                    return getWidenedType(type);
                }
                type = isParameter(declaration) && declaration.dotDotDotToken ? anyArrayType : anyType;
                if (reportErrors2) {
                    if (!declarationBelongsToPrivateAmbientMember(declaration)) {
                        reportImplicitAny(declaration, type);
                    }
                }
                return type;
            }
            function declarationBelongsToPrivateAmbientMember(declaration) {
                const root = getRootDeclaration(declaration);
                const memberDeclaration = root.kind === 166 /* Parameter */ ? root.parent : root;
                return isPrivateWithinAmbient(memberDeclaration);
            }
            function tryGetTypeFromEffectiveTypeNode(node) {
                const typeNode = getEffectiveTypeAnnotationNode(node);
                if (typeNode) {
                    return getTypeFromTypeNode(typeNode);
                }
            }
            function isParameterOfContextSensitiveSignature(symbol) {
                let decl = symbol.valueDeclaration;
                if (!decl) {
                    return false;
                }
                if (isBindingElement(decl)) {
                    decl = walkUpBindingElementsAndPatterns(decl);
                }
                if (isParameter(decl)) {
                    return isContextSensitiveFunctionOrObjectLiteralMethod(decl.parent);
                }
                return false;
            }
            function getTypeOfVariableOrParameterOrProperty(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    const type = getTypeOfVariableOrParameterOrPropertyWorker(symbol);
                    if (!links.type && !isParameterOfContextSensitiveSignature(symbol)) {
                        links.type = type;
                    }
                    return type;
                }
                return links.type;
            }
            function getTypeOfVariableOrParameterOrPropertyWorker(symbol) {
                if (symbol.flags & 4194304 /* Prototype */) {
                    return getTypeOfPrototypeProperty(symbol);
                }
                if (symbol === requireSymbol) {
                    return anyType;
                }
                if (symbol.flags & 134217728 /* ModuleExports */ && symbol.valueDeclaration) {
                    const fileSymbol = getSymbolOfDeclaration(getSourceFileOfNode(symbol.valueDeclaration));
                    const result = createSymbol(fileSymbol.flags, "exports");
                    result.declarations = fileSymbol.declarations ? fileSymbol.declarations.slice() : [];
                    result.parent = symbol;
                    result.links.target = fileSymbol;
                    if (fileSymbol.valueDeclaration)
                        result.valueDeclaration = fileSymbol.valueDeclaration;
                    if (fileSymbol.members)
                        result.members = new Map(fileSymbol.members);
                    if (fileSymbol.exports)
                        result.exports = new Map(fileSymbol.exports);
                    const members = createSymbolTable();
                    members.set("exports", result);
                    return createAnonymousType(symbol, members, emptyArray, emptyArray, emptyArray);
                }
                Debug.assertIsDefined(symbol.valueDeclaration);
                const declaration = symbol.valueDeclaration;
                if (isSourceFile(declaration) && isJsonSourceFile(declaration)) {
                    if (!declaration.statements.length) {
                        return emptyObjectType;
                    }
                    return getWidenedType(getWidenedLiteralType(checkExpression(declaration.statements[0].expression)));
                }
                if (isAccessor(declaration)) {
                    return getTypeOfAccessors(symbol);
                }
                if (!pushTypeResolution(symbol, 0 /* Type */)) {
                    if (symbol.flags & 512 /* ValueModule */ && !(symbol.flags & 67108864 /* Assignment */)) {
                        return getTypeOfFuncClassEnumModule(symbol);
                    }
                    return reportCircularityError(symbol);
                }
                let type;
                if (declaration.kind === 274 /* ExportAssignment */) {
                    type = widenTypeForVariableLikeDeclaration(tryGetTypeFromEffectiveTypeNode(declaration) || checkExpressionCached(declaration.expression), declaration);
                }
                else if (isBinaryExpression(declaration) || isInJSFile(declaration) && (isCallExpression(declaration) || (isPropertyAccessExpression(declaration) || isBindableStaticElementAccessExpression(declaration)) && isBinaryExpression(declaration.parent))) {
                    type = getWidenedTypeForAssignmentDeclaration(symbol);
                }
                else if (isPropertyAccessExpression(declaration) || isElementAccessExpression(declaration) || isIdentifier(declaration) || isStringLiteralLike(declaration) || isNumericLiteral(declaration) || isClassDeclaration(declaration) || isFunctionDeclaration(declaration) || isMethodDeclaration(declaration) && !isObjectLiteralMethod(declaration) || isMethodSignature(declaration) || isSourceFile(declaration)) {
                    if (symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 384 /* Enum */ | 512 /* ValueModule */)) {
                        return getTypeOfFuncClassEnumModule(symbol);
                    }
                    type = isBinaryExpression(declaration.parent) ? getWidenedTypeForAssignmentDeclaration(symbol) : tryGetTypeFromEffectiveTypeNode(declaration) || anyType;
                }
                else if (isPropertyAssignment(declaration)) {
                    type = tryGetTypeFromEffectiveTypeNode(declaration) || checkPropertyAssignment(declaration);
                }
                else if (isJsxAttribute(declaration)) {
                    type = tryGetTypeFromEffectiveTypeNode(declaration) || checkJsxAttribute(declaration);
                }
                else if (isShorthandPropertyAssignment(declaration)) {
                    type = tryGetTypeFromEffectiveTypeNode(declaration) || checkExpressionForMutableLocation(declaration.name, 0 /* Normal */);
                }
                else if (isObjectLiteralMethod(declaration)) {
                    type = tryGetTypeFromEffectiveTypeNode(declaration) || checkObjectLiteralMethod(declaration, 0 /* Normal */);
                }
                else if (isParameter(declaration) || isPropertyDeclaration(declaration) || isPropertySignature(declaration) || isVariableDeclaration(declaration) || isBindingElement(declaration) || isJSDocPropertyLikeTag(declaration)) {
                    type = getWidenedTypeForVariableLikeDeclaration(declaration, 
                    /*includeOptionality*/
                    true);
                }
                else if (isEnumDeclaration(declaration)) {
                    type = getTypeOfFuncClassEnumModule(symbol);
                }
                else if (isEnumMember(declaration)) {
                    type = getTypeOfEnumMember(symbol);
                }
                else {
                    return Debug.fail("Unhandled declaration kind! " + Debug.formatSyntaxKind(declaration.kind) + " for " + Debug.formatSymbol(symbol));
                }
                if (!popTypeResolution()) {
                    if (symbol.flags & 512 /* ValueModule */ && !(symbol.flags & 67108864 /* Assignment */)) {
                        return getTypeOfFuncClassEnumModule(symbol);
                    }
                    return reportCircularityError(symbol);
                }
                return type;
            }
            function getAnnotatedAccessorTypeNode(accessor) {
                if (accessor) {
                    switch (accessor.kind) {
                        case 174 /* GetAccessor */:
                            const getterTypeAnnotation = getEffectiveReturnTypeNode(accessor);
                            return getterTypeAnnotation;
                        case 175 /* SetAccessor */:
                            const setterTypeAnnotation = getEffectiveSetAccessorTypeAnnotationNode(accessor);
                            return setterTypeAnnotation;
                        case 169 /* PropertyDeclaration */:
                            Debug.assert(hasAccessorModifier(accessor));
                            const accessorTypeAnnotation = getEffectiveTypeAnnotationNode(accessor);
                            return accessorTypeAnnotation;
                    }
                }
                return void 0;
            }
            function getAnnotatedAccessorType(accessor) {
                const node = getAnnotatedAccessorTypeNode(accessor);
                return node && getTypeFromTypeNode(node);
            }
            function getAnnotatedAccessorThisParameter(accessor) {
                const parameter = getAccessorThisParameter(accessor);
                return parameter && parameter.symbol;
            }
            function getThisTypeOfDeclaration(declaration) {
                return getThisTypeOfSignature(getSignatureFromDeclaration(declaration));
            }
            function getTypeOfAccessors(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    if (!pushTypeResolution(symbol, 0 /* Type */)) {
                        return errorType;
                    }
                    const getter = getDeclarationOfKind(symbol, 174 /* GetAccessor */);
                    const setter = getDeclarationOfKind(symbol, 175 /* SetAccessor */);
                    const accessor = tryCast(getDeclarationOfKind(symbol, 169 /* PropertyDeclaration */), isAutoAccessorPropertyDeclaration);
                    let type = getter && isInJSFile(getter) && getTypeForDeclarationFromJSDocComment(getter) || getAnnotatedAccessorType(getter) || getAnnotatedAccessorType(setter) || getAnnotatedAccessorType(accessor) || getter && getter.body && getReturnTypeFromBody(getter) || accessor && accessor.initializer && getWidenedTypeForVariableLikeDeclaration(accessor, 
                    /*includeOptionality*/
                    true);
                    if (!type) {
                        if (setter && !isPrivateWithinAmbient(setter)) {
                            errorOrSuggestion(noImplicitAny, setter, Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation, symbolToString(symbol));
                        }
                        else if (getter && !isPrivateWithinAmbient(getter)) {
                            errorOrSuggestion(noImplicitAny, getter, Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation, symbolToString(symbol));
                        }
                        else if (accessor && !isPrivateWithinAmbient(accessor)) {
                            errorOrSuggestion(noImplicitAny, accessor, Diagnostics.Member_0_implicitly_has_an_1_type, symbolToString(symbol), "any");
                        }
                        type = anyType;
                    }
                    if (!popTypeResolution()) {
                        if (getAnnotatedAccessorTypeNode(getter)) {
                            error(getter, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                        }
                        else if (getAnnotatedAccessorTypeNode(setter)) {
                            error(setter, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                        }
                        else if (getAnnotatedAccessorTypeNode(accessor)) {
                            error(setter, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                        }
                        else if (getter && noImplicitAny) {
                            error(getter, Diagnostics._0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions, symbolToString(symbol));
                        }
                        type = anyType;
                    }
                    links.type = type;
                }
                return links.type;
            }
            function getWriteTypeOfAccessors(symbol) {
                var _a2;
                const links = getSymbolLinks(symbol);
                if (!links.writeType) {
                    if (!pushTypeResolution(symbol, 8 /* WriteType */)) {
                        return errorType;
                    }
                    const setter = (_a2 = getDeclarationOfKind(symbol, 175 /* SetAccessor */)) != null ? _a2 : tryCast(getDeclarationOfKind(symbol, 169 /* PropertyDeclaration */), isAutoAccessorPropertyDeclaration);
                    let writeType = getAnnotatedAccessorType(setter);
                    if (!popTypeResolution()) {
                        if (getAnnotatedAccessorTypeNode(setter)) {
                            error(setter, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                        }
                        writeType = anyType;
                    }
                    links.writeType = writeType || getTypeOfAccessors(symbol);
                }
                return links.writeType;
            }
            function getBaseTypeVariableOfClass(symbol) {
                const baseConstructorType = getBaseConstructorTypeOfClass(getDeclaredTypeOfClassOrInterface(symbol));
                return baseConstructorType.flags & 8650752 /* TypeVariable */ ? baseConstructorType : baseConstructorType.flags & 2097152 /* Intersection */ ? find(baseConstructorType.types, (t) => !!(t.flags & 8650752 /* TypeVariable */)) : void 0;
            }
            function getTypeOfFuncClassEnumModule(symbol) {
                let links = getSymbolLinks(symbol);
                const originalLinks = links;
                if (!links.type) {
                    const expando = symbol.valueDeclaration && getSymbolOfExpando(symbol.valueDeclaration, 
                    /*allowDeclaration*/
                    false);
                    if (expando) {
                        const merged = mergeJSSymbols(symbol, expando);
                        if (merged) {
                            symbol = merged;
                            links = merged.links;
                        }
                    }
                    originalLinks.type = links.type = getTypeOfFuncClassEnumModuleWorker(symbol);
                }
                return links.type;
            }
            function getTypeOfFuncClassEnumModuleWorker(symbol) {
                const declaration = symbol.valueDeclaration;
                if (symbol.flags & 1536 /* Module */ && isShorthandAmbientModuleSymbol(symbol)) {
                    return anyType;
                }
                else if (declaration && (declaration.kind === 223 /* BinaryExpression */ || isAccessExpression(declaration) && declaration.parent.kind === 223 /* BinaryExpression */)) {
                    return getWidenedTypeForAssignmentDeclaration(symbol);
                }
                else if (symbol.flags & 512 /* ValueModule */ && declaration && isSourceFile(declaration) && declaration.commonJsModuleIndicator) {
                    const resolvedModule = resolveExternalModuleSymbol(symbol);
                    if (resolvedModule !== symbol) {
                        if (!pushTypeResolution(symbol, 0 /* Type */)) {
                            return errorType;
                        }
                        const exportEquals = getMergedSymbol(symbol.exports.get("export=" /* ExportEquals */));
                        const type2 = getWidenedTypeForAssignmentDeclaration(exportEquals, exportEquals === resolvedModule ? void 0 : resolvedModule);
                        if (!popTypeResolution()) {
                            return reportCircularityError(symbol);
                        }
                        return type2;
                    }
                }
                const type = createObjectType(16 /* Anonymous */, symbol);
                if (symbol.flags & 32 /* Class */) {
                    const baseTypeVariable = getBaseTypeVariableOfClass(symbol);
                    return baseTypeVariable ? getIntersectionType([type, baseTypeVariable]) : type;
                }
                else {
                    return strictNullChecks && symbol.flags & 16777216 /* Optional */ ? getOptionalType(type) : type;
                }
            }
            function getTypeOfEnumMember(symbol) {
                const links = getSymbolLinks(symbol);
                return links.type || (links.type = getDeclaredTypeOfEnumMember(symbol));
            }
            function getTypeOfAlias(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    const targetSymbol = resolveAlias(symbol);
                    const exportSymbol = symbol.declarations && getTargetOfAliasDeclaration(getDeclarationOfAliasSymbol(symbol), 
                    /*dontResolveAlias*/
                    true);
                    const declaredType = firstDefined(exportSymbol == null ? void 0 : exportSymbol.declarations, (d) => isExportAssignment(d) ? tryGetTypeFromEffectiveTypeNode(d) : void 0);
                    links.type = (exportSymbol == null ? void 0 : exportSymbol.declarations) && isDuplicatedCommonJSExport(exportSymbol.declarations) && symbol.declarations.length ? getFlowTypeFromCommonJSExport(exportSymbol) : isDuplicatedCommonJSExport(symbol.declarations) ? autoType : declaredType ? declaredType : getAllSymbolFlags(targetSymbol) & 111551 /* Value */ ? getTypeOfSymbol(targetSymbol) : errorType;
                }
                return links.type;
            }
            function getTypeOfInstantiatedSymbol(symbol) {
                const links = getSymbolLinks(symbol);
                return links.type || (links.type = instantiateType(getTypeOfSymbol(links.target), links.mapper));
            }
            function getWriteTypeOfInstantiatedSymbol(symbol) {
                const links = getSymbolLinks(symbol);
                return links.writeType || (links.writeType = instantiateType(getWriteTypeOfSymbol(links.target), links.mapper));
            }
            function reportCircularityError(symbol) {
                const declaration = symbol.valueDeclaration;
                if (getEffectiveTypeAnnotationNode(declaration)) {
                    error(symbol.valueDeclaration, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                    return errorType;
                }
                if (noImplicitAny && (declaration.kind !== 166 /* Parameter */ || declaration.initializer)) {
                    error(symbol.valueDeclaration, Diagnostics._0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer, symbolToString(symbol));
                }
                return anyType;
            }
            function getTypeOfSymbolWithDeferredType(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    Debug.assertIsDefined(links.deferralParent);
                    Debug.assertIsDefined(links.deferralConstituents);
                    links.type = links.deferralParent.flags & 1048576 /* Union */ ? getUnionType(links.deferralConstituents) : getIntersectionType(links.deferralConstituents);
                }
                return links.type;
            }
            function getWriteTypeOfSymbolWithDeferredType(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.writeType && links.deferralWriteConstituents) {
                    Debug.assertIsDefined(links.deferralParent);
                    Debug.assertIsDefined(links.deferralConstituents);
                    links.writeType = links.deferralParent.flags & 1048576 /* Union */ ? getUnionType(links.deferralWriteConstituents) : getIntersectionType(links.deferralWriteConstituents);
                }
                return links.writeType;
            }
            function getWriteTypeOfSymbol(symbol) {
                const checkFlags = getCheckFlags(symbol);
                if (symbol.flags & 4 /* Property */) {
                    return checkFlags & 2 /* SyntheticProperty */ ? checkFlags & 65536 /* DeferredType */ ? getWriteTypeOfSymbolWithDeferredType(symbol) || getTypeOfSymbolWithDeferredType(symbol) : (
                    // NOTE: cast to TransientSymbol should be safe because only TransientSymbols can have CheckFlags.SyntheticProperty
                    symbol.links.writeType || symbol.links.type) : getTypeOfSymbol(symbol);
                }
                if (symbol.flags & 98304 /* Accessor */) {
                    return checkFlags & 1 /* Instantiated */ ? getWriteTypeOfInstantiatedSymbol(symbol) : getWriteTypeOfAccessors(symbol);
                }
                return getTypeOfSymbol(symbol);
            }
            function getTypeOfSymbol(symbol) {
                const checkFlags = getCheckFlags(symbol);
                if (checkFlags & 65536 /* DeferredType */) {
                    return getTypeOfSymbolWithDeferredType(symbol);
                }
                if (checkFlags & 1 /* Instantiated */) {
                    return getTypeOfInstantiatedSymbol(symbol);
                }
                if (checkFlags & 262144 /* Mapped */) {
                    return getTypeOfMappedSymbol(symbol);
                }
                if (checkFlags & 8192 /* ReverseMapped */) {
                    return getTypeOfReverseMappedSymbol(symbol);
                }
                if (symbol.flags & (3 /* Variable */ | 4 /* Property */)) {
                    return getTypeOfVariableOrParameterOrProperty(symbol);
                }
                if (symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 384 /* Enum */ | 512 /* ValueModule */)) {
                    return getTypeOfFuncClassEnumModule(symbol);
                }
                if (symbol.flags & 8 /* EnumMember */) {
                    return getTypeOfEnumMember(symbol);
                }
                if (symbol.flags & 98304 /* Accessor */) {
                    return getTypeOfAccessors(symbol);
                }
                if (symbol.flags & 2097152 /* Alias */) {
                    return getTypeOfAlias(symbol);
                }
                return errorType;
            }
            function getNonMissingTypeOfSymbol(symbol) {
                return removeMissingType(getTypeOfSymbol(symbol), !!(symbol.flags & 16777216 /* Optional */));
            }
            function isReferenceToType2(type, target) {
                return type !== void 0 && target !== void 0 && (getObjectFlags(type) & 4 /* Reference */) !== 0 && type.target === target;
            }
            function getTargetType(type) {
                return getObjectFlags(type) & 4 /* Reference */ ? type.target : type;
            }
            function hasBaseType(type, checkBase) {
                return check(type);
                function check(type2) {
                    if (getObjectFlags(type2) & (3 /* ClassOrInterface */ | 4 /* Reference */)) {
                        const target = getTargetType(type2);
                        return target === checkBase || some(getBaseTypes(target), check);
                    }
                    else if (type2.flags & 2097152 /* Intersection */) {
                        return some(type2.types, check);
                    }
                    return false;
                }
            }
            function appendTypeParameters(typeParameters, declarations) {
                for (const declaration of declarations) {
                    typeParameters = appendIfUnique(typeParameters, getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(declaration)));
                }
                return typeParameters;
            }
            function getOuterTypeParameters(node, includeThisTypes) {
                while (true) {
                    node = node.parent;
                    if (node && isBinaryExpression(node)) {
                        const assignmentKind = getAssignmentDeclarationKind(node);
                        if (assignmentKind === 6 /* Prototype */ || assignmentKind === 3 /* PrototypeProperty */) {
                            const symbol = getSymbolOfDeclaration(node.left);
                            if (symbol && symbol.parent && !findAncestor(symbol.parent.valueDeclaration, (d) => node === d)) {
                                node = symbol.parent.valueDeclaration;
                            }
                        }
                    }
                    if (!node) {
                        return void 0;
                    }
                    switch (node.kind) {
                        case 260 /* ClassDeclaration */:
                        case 228 /* ClassExpression */:
                        case 261 /* InterfaceDeclaration */:
                        case 176 /* CallSignature */:
                        case 177 /* ConstructSignature */:
                        case 170 /* MethodSignature */:
                        case 181 /* FunctionType */:
                        case 182 /* ConstructorType */:
                        case 320 /* JSDocFunctionType */:
                        case 259 /* FunctionDeclaration */:
                        case 171 /* MethodDeclaration */:
                        case 215 /* FunctionExpression */:
                        case 216 /* ArrowFunction */:
                        case 262 /* TypeAliasDeclaration */:
                        case 348 /* JSDocTemplateTag */:
                        case 349 /* JSDocTypedefTag */:
                        case 343 /* JSDocEnumTag */:
                        case 341 /* JSDocCallbackTag */:
                        case 197 /* MappedType */:
                        case 191 /* ConditionalType */: {
                            const outerTypeParameters = getOuterTypeParameters(node, includeThisTypes);
                            if (node.kind === 197 /* MappedType */) {
                                return append(outerTypeParameters, getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(node.typeParameter)));
                            }
                            else if (node.kind === 191 /* ConditionalType */) {
                                return concatenate(outerTypeParameters, getInferTypeParameters(node));
                            }
                            const outerAndOwnTypeParameters = appendTypeParameters(outerTypeParameters, getEffectiveTypeParameterDeclarations(node));
                            const thisType = includeThisTypes && (node.kind === 260 /* ClassDeclaration */ || node.kind === 228 /* ClassExpression */ || node.kind === 261 /* InterfaceDeclaration */ || isJSConstructor(node)) && getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(node)).thisType;
                            return thisType ? append(outerAndOwnTypeParameters, thisType) : outerAndOwnTypeParameters;
                        }
                        case 344 /* JSDocParameterTag */:
                            const paramSymbol = getParameterSymbolFromJSDoc(node);
                            if (paramSymbol) {
                                node = paramSymbol.valueDeclaration;
                            }
                            break;
                        case 323 /* JSDoc */: {
                            const outerTypeParameters = getOuterTypeParameters(node, includeThisTypes);
                            return node.tags ? appendTypeParameters(outerTypeParameters, flatMap(node.tags, (t) => isJSDocTemplateTag(t) ? t.typeParameters : void 0)) : outerTypeParameters;
                        }
                    }
                }
            }
            function getOuterTypeParametersOfClassOrInterface(symbol) {
                var _a2;
                const declaration = symbol.flags & 32 /* Class */ || symbol.flags & 16 /* Function */ ? symbol.valueDeclaration : (_a2 = symbol.declarations) == null ? void 0 : _a2.find((decl) => {
                    if (decl.kind === 261 /* InterfaceDeclaration */) {
                        return true;
                    }
                    if (decl.kind !== 257 /* VariableDeclaration */) {
                        return false;
                    }
                    const initializer = decl.initializer;
                    return !!initializer && (initializer.kind === 215 /* FunctionExpression */ || initializer.kind === 216 /* ArrowFunction */);
                });
                Debug.assert(!!declaration, "Class was missing valueDeclaration -OR- non-class had no interface declarations");
                return getOuterTypeParameters(declaration);
            }
            function getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol) {
                if (!symbol.declarations) {
                    return;
                }
                let result;
                for (const node of symbol.declarations) {
                    if (node.kind === 261 /* InterfaceDeclaration */ || node.kind === 260 /* ClassDeclaration */ || node.kind === 228 /* ClassExpression */ || isJSConstructor(node) || isTypeAlias(node)) {
                        const declaration = node;
                        result = appendTypeParameters(result, getEffectiveTypeParameterDeclarations(declaration));
                    }
                }
                return result;
            }
            function getTypeParametersOfClassOrInterface(symbol) {
                return concatenate(getOuterTypeParametersOfClassOrInterface(symbol), getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol));
            }
            function isMixinConstructorType(type) {
                const signatures = getSignaturesOfType(type, 1 /* Construct */);
                if (signatures.length === 1) {
                    const s = signatures[0];
                    if (!s.typeParameters && s.parameters.length === 1 && signatureHasRestParameter(s)) {
                        const paramType = getTypeOfParameter(s.parameters[0]);
                        return isTypeAny(paramType) || getElementTypeOfArrayType(paramType) === anyType;
                    }
                }
                return false;
            }
            function isConstructorType(type) {
                if (getSignaturesOfType(type, 1 /* Construct */).length > 0) {
                    return true;
                }
                if (type.flags & 8650752 /* TypeVariable */) {
                    const constraint = getBaseConstraintOfType(type);
                    return !!constraint && isMixinConstructorType(constraint);
                }
                return false;
            }
            function getBaseTypeNodeOfClass(type) {
                const decl = getClassLikeDeclarationOfSymbol(type.symbol);
                return decl && getEffectiveBaseTypeNode(decl);
            }
            function getConstructorsForTypeArguments(type, typeArgumentNodes, location) {
                const typeArgCount = length(typeArgumentNodes);
                const isJavascript = isInJSFile(location);
                return filter(getSignaturesOfType(type, 1 /* Construct */), (sig) => (isJavascript || typeArgCount >= getMinTypeArgumentCount(sig.typeParameters)) && typeArgCount <= length(sig.typeParameters));
            }
            function getInstantiatedConstructorsForTypeArguments(type, typeArgumentNodes, location) {
                const signatures = getConstructorsForTypeArguments(type, typeArgumentNodes, location);
                const typeArguments = map(typeArgumentNodes, getTypeFromTypeNode);
                return sameMap(signatures, (sig) => some(sig.typeParameters) ? getSignatureInstantiation(sig, typeArguments, isInJSFile(location)) : sig);
            }
            function getBaseConstructorTypeOfClass(type) {
                if (!type.resolvedBaseConstructorType) {
                    const decl = getClassLikeDeclarationOfSymbol(type.symbol);
                    const extended = decl && getEffectiveBaseTypeNode(decl);
                    const baseTypeNode = getBaseTypeNodeOfClass(type);
                    if (!baseTypeNode) {
                        return type.resolvedBaseConstructorType = undefinedType;
                    }
                    if (!pushTypeResolution(type, 1 /* ResolvedBaseConstructorType */)) {
                        return errorType;
                    }
                    const baseConstructorType = checkExpression(baseTypeNode.expression);
                    if (extended && baseTypeNode !== extended) {
                        Debug.assert(!extended.typeArguments);
                        checkExpression(extended.expression);
                    }
                    if (baseConstructorType.flags & (524288 /* Object */ | 2097152 /* Intersection */)) {
                        resolveStructuredTypeMembers(baseConstructorType);
                    }
                    if (!popTypeResolution()) {
                        error(type.symbol.valueDeclaration, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_base_expression, symbolToString(type.symbol));
                        return type.resolvedBaseConstructorType = errorType;
                    }
                    if (!(baseConstructorType.flags & 1 /* Any */) && baseConstructorType !== nullWideningType && !isConstructorType(baseConstructorType)) {
                        const err = error(baseTypeNode.expression, Diagnostics.Type_0_is_not_a_constructor_function_type, typeToString(baseConstructorType));
                        if (baseConstructorType.flags & 262144 /* TypeParameter */) {
                            const constraint = getConstraintFromTypeParameter(baseConstructorType);
                            let ctorReturn = unknownType;
                            if (constraint) {
                                const ctorSig = getSignaturesOfType(constraint, 1 /* Construct */);
                                if (ctorSig[0]) {
                                    ctorReturn = getReturnTypeOfSignature(ctorSig[0]);
                                }
                            }
                            if (baseConstructorType.symbol.declarations) {
                                addRelatedInfo(err, createDiagnosticForNode(baseConstructorType.symbol.declarations[0], Diagnostics.Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1, symbolToString(baseConstructorType.symbol), typeToString(ctorReturn)));
                            }
                        }
                        return type.resolvedBaseConstructorType = errorType;
                    }
                    type.resolvedBaseConstructorType = baseConstructorType;
                }
                return type.resolvedBaseConstructorType;
            }
            function getImplementsTypes(type) {
                let resolvedImplementsTypes = emptyArray;
                if (type.symbol.declarations) {
                    for (const declaration of type.symbol.declarations) {
                        const implementsTypeNodes = getEffectiveImplementsTypeNodes(declaration);
                        if (!implementsTypeNodes)
                            continue;
                        for (const node of implementsTypeNodes) {
                            const implementsType = getTypeFromTypeNode(node);
                            if (!isErrorType(implementsType)) {
                                if (resolvedImplementsTypes === emptyArray) {
                                    resolvedImplementsTypes = [implementsType];
                                }
                                else {
                                    resolvedImplementsTypes.push(implementsType);
                                }
                            }
                        }
                    }
                }
                return resolvedImplementsTypes;
            }
            function reportCircularBaseType(node, type) {
                error(node, Diagnostics.Type_0_recursively_references_itself_as_a_base_type, typeToString(type, 
                /*enclosingDeclaration*/
                void 0, 2 /* WriteArrayAsGenericType */));
            }
            function getBaseTypes(type) {
                if (!type.baseTypesResolved) {
                    if (pushTypeResolution(type, 7 /* ResolvedBaseTypes */)) {
                        if (type.objectFlags & 8 /* Tuple */) {
                            type.resolvedBaseTypes = [getTupleBaseType(type)];
                        }
                        else if (type.symbol.flags & (32 /* Class */ | 64 /* Interface */)) {
                            if (type.symbol.flags & 32 /* Class */) {
                                resolveBaseTypesOfClass(type);
                            }
                            if (type.symbol.flags & 64 /* Interface */) {
                                resolveBaseTypesOfInterface(type);
                            }
                        }
                        else {
                            Debug.fail("type must be class or interface");
                        }
                        if (!popTypeResolution() && type.symbol.declarations) {
                            for (const declaration of type.symbol.declarations) {
                                if (declaration.kind === 260 /* ClassDeclaration */ || declaration.kind === 261 /* InterfaceDeclaration */) {
                                    reportCircularBaseType(declaration, type);
                                }
                            }
                        }
                    }
                    type.baseTypesResolved = true;
                }
                return type.resolvedBaseTypes;
            }
            function getTupleBaseType(type) {
                const elementTypes = sameMap(type.typeParameters, (t, i) => type.elementFlags[i] & 8 /* Variadic */ ? getIndexedAccessType(t, numberType) : t);
                return createArrayType(getUnionType(elementTypes || emptyArray), type.readonly);
            }
            function resolveBaseTypesOfClass(type) {
                type.resolvedBaseTypes = resolvingEmptyArray;
                const baseConstructorType = getApparentType(getBaseConstructorTypeOfClass(type));
                if (!(baseConstructorType.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 1 /* Any */))) {
                    return type.resolvedBaseTypes = emptyArray;
                }
                const baseTypeNode = getBaseTypeNodeOfClass(type);
                let baseType;
                const originalBaseType = baseConstructorType.symbol ? getDeclaredTypeOfSymbol(baseConstructorType.symbol) : void 0;
                if (baseConstructorType.symbol && baseConstructorType.symbol.flags & 32 /* Class */ && areAllOuterTypeParametersApplied(originalBaseType)) {
                    baseType = getTypeFromClassOrInterfaceReference(baseTypeNode, baseConstructorType.symbol);
                }
                else if (baseConstructorType.flags & 1 /* Any */) {
                    baseType = baseConstructorType;
                }
                else {
                    const constructors = getInstantiatedConstructorsForTypeArguments(baseConstructorType, baseTypeNode.typeArguments, baseTypeNode);
                    if (!constructors.length) {
                        error(baseTypeNode.expression, Diagnostics.No_base_constructor_has_the_specified_number_of_type_arguments);
                        return type.resolvedBaseTypes = emptyArray;
                    }
                    baseType = getReturnTypeOfSignature(constructors[0]);
                }
                if (isErrorType(baseType)) {
                    return type.resolvedBaseTypes = emptyArray;
                }
                const reducedBaseType = getReducedType(baseType);
                if (!isValidBaseType(reducedBaseType)) {
                    const elaboration = elaborateNeverIntersection(
                    /*errorInfo*/
                    void 0, baseType);
                    const diagnostic = chainDiagnosticMessages(elaboration, Diagnostics.Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_known_members, typeToString(reducedBaseType));
                    diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(baseTypeNode.expression), baseTypeNode.expression, diagnostic));
                    return type.resolvedBaseTypes = emptyArray;
                }
                if (type === reducedBaseType || hasBaseType(reducedBaseType, type)) {
                    error(type.symbol.valueDeclaration, Diagnostics.Type_0_recursively_references_itself_as_a_base_type, typeToString(type, 
                    /*enclosingDeclaration*/
                    void 0, 2 /* WriteArrayAsGenericType */));
                    return type.resolvedBaseTypes = emptyArray;
                }
                if (type.resolvedBaseTypes === resolvingEmptyArray) {
                    type.members = void 0;
                }
                return type.resolvedBaseTypes = [reducedBaseType];
            }
            function areAllOuterTypeParametersApplied(type) {
                const outerTypeParameters = type.outerTypeParameters;
                if (outerTypeParameters) {
                    const last2 = outerTypeParameters.length - 1;
                    const typeArguments = getTypeArguments(type);
                    return outerTypeParameters[last2].symbol !== typeArguments[last2].symbol;
                }
                return true;
            }
            function isValidBaseType(type) {
                if (type.flags & 262144 /* TypeParameter */) {
                    const constraint = getBaseConstraintOfType(type);
                    if (constraint) {
                        return isValidBaseType(constraint);
                    }
                }
                return !!(type.flags & (524288 /* Object */ | 67108864 /* NonPrimitive */ | 1 /* Any */) && !isGenericMappedType(type) || type.flags & 2097152 /* Intersection */ && every(type.types, isValidBaseType));
            }
            function resolveBaseTypesOfInterface(type) {
                type.resolvedBaseTypes = type.resolvedBaseTypes || emptyArray;
                if (type.symbol.declarations) {
                    for (const declaration of type.symbol.declarations) {
                        if (declaration.kind === 261 /* InterfaceDeclaration */ && getInterfaceBaseTypeNodes(declaration)) {
                            for (const node of getInterfaceBaseTypeNodes(declaration)) {
                                const baseType = getReducedType(getTypeFromTypeNode(node));
                                if (!isErrorType(baseType)) {
                                    if (isValidBaseType(baseType)) {
                                        if (type !== baseType && !hasBaseType(baseType, type)) {
                                            if (type.resolvedBaseTypes === emptyArray) {
                                                type.resolvedBaseTypes = [baseType];
                                            }
                                            else {
                                                type.resolvedBaseTypes.push(baseType);
                                            }
                                        }
                                        else {
                                            reportCircularBaseType(declaration, type);
                                        }
                                    }
                                    else {
                                        error(node, Diagnostics.An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_members);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            function isThislessInterface(symbol) {
                if (!symbol.declarations) {
                    return true;
                }
                for (const declaration of symbol.declarations) {
                    if (declaration.kind === 261 /* InterfaceDeclaration */) {
                        if (declaration.flags & 128 /* ContainsThis */) {
                            return false;
                        }
                        const baseTypeNodes = getInterfaceBaseTypeNodes(declaration);
                        if (baseTypeNodes) {
                            for (const node of baseTypeNodes) {
                                if (isEntityNameExpression(node.expression)) {
                                    const baseSymbol = resolveEntityName(node.expression, 788968 /* Type */, 
                                    /*ignoreErrors*/
                                    true);
                                    if (!baseSymbol || !(baseSymbol.flags & 64 /* Interface */) || getDeclaredTypeOfClassOrInterface(baseSymbol).thisType) {
                                        return false;
                                    }
                                }
                            }
                        }
                    }
                }
                return true;
            }
            function getDeclaredTypeOfClassOrInterface(symbol) {
                let links = getSymbolLinks(symbol);
                const originalLinks = links;
                if (!links.declaredType) {
                    const kind = symbol.flags & 32 /* Class */ ? 1 /* Class */ : 2 /* Interface */;
                    const merged = mergeJSSymbols(symbol, symbol.valueDeclaration && getAssignedClassSymbol(symbol.valueDeclaration));
                    if (merged) {
                        symbol = merged;
                        links = merged.links;
                    }
                    const type = originalLinks.declaredType = links.declaredType = createObjectType(kind, symbol);
                    const outerTypeParameters = getOuterTypeParametersOfClassOrInterface(symbol);
                    const localTypeParameters = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
                    if (outerTypeParameters || localTypeParameters || kind === 1 /* Class */ || !isThislessInterface(symbol)) {
                        type.objectFlags |= 4 /* Reference */;
                        type.typeParameters = concatenate(outerTypeParameters, localTypeParameters);
                        type.outerTypeParameters = outerTypeParameters;
                        type.localTypeParameters = localTypeParameters;
                        type.instantiations = /* @__PURE__ */ new Map();
                        type.instantiations.set(getTypeListId(type.typeParameters), type);
                        type.target = type;
                        type.resolvedTypeArguments = type.typeParameters;
                        type.thisType = createTypeParameter(symbol);
                        type.thisType.isThisType = true;
                        type.thisType.constraint = type;
                    }
                }
                return links.declaredType;
            }
            function getDeclaredTypeOfTypeAlias(symbol) {
                var _a2;
                const links = getSymbolLinks(symbol);
                if (!links.declaredType) {
                    if (!pushTypeResolution(symbol, 2 /* DeclaredType */)) {
                        return errorType;
                    }
                    const declaration = Debug.checkDefined((_a2 = symbol.declarations) == null ? void 0 : _a2.find(isTypeAlias), "Type alias symbol with no valid declaration found");
                    const typeNode = isJSDocTypeAlias(declaration) ? declaration.typeExpression : declaration.type;
                    let type = typeNode ? getTypeFromTypeNode(typeNode) : errorType;
                    if (popTypeResolution()) {
                        const typeParameters = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
                        if (typeParameters) {
                            links.typeParameters = typeParameters;
                            links.instantiations = /* @__PURE__ */ new Map();
                            links.instantiations.set(getTypeListId(typeParameters), type);
                        }
                    }
                    else {
                        type = errorType;
                        if (declaration.kind === 343 /* JSDocEnumTag */) {
                            error(declaration.typeExpression.type, Diagnostics.Type_alias_0_circularly_references_itself, symbolToString(symbol));
                        }
                        else {
                            error(isNamedDeclaration(declaration) ? declaration.name || declaration : declaration, Diagnostics.Type_alias_0_circularly_references_itself, symbolToString(symbol));
                        }
                    }
                    links.declaredType = type;
                }
                return links.declaredType;
            }
            function getBaseTypeOfEnumLikeType(type) {
                return type.flags & 1056 /* EnumLike */ && type.symbol.flags & 8 /* EnumMember */ ? getDeclaredTypeOfSymbol(getParentOfSymbol(type.symbol)) : type;
            }
            function getDeclaredTypeOfEnum(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.declaredType) {
                    const memberTypeList = [];
                    if (symbol.declarations) {
                        for (const declaration of symbol.declarations) {
                            if (declaration.kind === 263 /* EnumDeclaration */) {
                                for (const member of declaration.members) {
                                    if (hasBindableName(member)) {
                                        const memberSymbol = getSymbolOfDeclaration(member);
                                        const value = getEnumMemberValue(member);
                                        const memberType = getFreshTypeOfLiteralType(value !== void 0 ? getEnumLiteralType(value, getSymbolId(symbol), memberSymbol) : createComputedEnumType(memberSymbol));
                                        getSymbolLinks(memberSymbol).declaredType = memberType;
                                        memberTypeList.push(getRegularTypeOfLiteralType(memberType));
                                    }
                                }
                            }
                        }
                    }
                    const enumType = memberTypeList.length ? getUnionType(memberTypeList, 1 /* Literal */, symbol, 
                    /*aliasTypeArguments*/
                    void 0) : createComputedEnumType(symbol);
                    if (enumType.flags & 1048576 /* Union */) {
                        enumType.flags |= 1024 /* EnumLiteral */;
                        enumType.symbol = symbol;
                    }
                    links.declaredType = enumType;
                }
                return links.declaredType;
            }
            function createComputedEnumType(symbol) {
                const regularType = createTypeWithSymbol(32 /* Enum */, symbol);
                const freshType = createTypeWithSymbol(32 /* Enum */, symbol);
                regularType.regularType = regularType;
                regularType.freshType = freshType;
                freshType.regularType = regularType;
                freshType.freshType = freshType;
                return regularType;
            }
            function getDeclaredTypeOfEnumMember(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.declaredType) {
                    const enumType = getDeclaredTypeOfEnum(getParentOfSymbol(symbol));
                    if (!links.declaredType) {
                        links.declaredType = enumType;
                    }
                }
                return links.declaredType;
            }
            function getDeclaredTypeOfTypeParameter(symbol) {
                const links = getSymbolLinks(symbol);
                return links.declaredType || (links.declaredType = createTypeParameter(symbol));
            }
            function getDeclaredTypeOfAlias(symbol) {
                const links = getSymbolLinks(symbol);
                return links.declaredType || (links.declaredType = getDeclaredTypeOfSymbol(resolveAlias(symbol)));
            }
            function getDeclaredTypeOfSymbol(symbol) {
                return tryGetDeclaredTypeOfSymbol(symbol) || errorType;
            }
            function tryGetDeclaredTypeOfSymbol(symbol) {
                if (symbol.flags & (32 /* Class */ | 64 /* Interface */)) {
                    return getDeclaredTypeOfClassOrInterface(symbol);
                }
                if (symbol.flags & 524288 /* TypeAlias */) {
                    return getDeclaredTypeOfTypeAlias(symbol);
                }
                if (symbol.flags & 262144 /* TypeParameter */) {
                    return getDeclaredTypeOfTypeParameter(symbol);
                }
                if (symbol.flags & 384 /* Enum */) {
                    return getDeclaredTypeOfEnum(symbol);
                }
                if (symbol.flags & 8 /* EnumMember */) {
                    return getDeclaredTypeOfEnumMember(symbol);
                }
                if (symbol.flags & 2097152 /* Alias */) {
                    return getDeclaredTypeOfAlias(symbol);
                }
                return void 0;
            }
            function isThislessType(node) {
                switch (node.kind) {
                    case 131 /* AnyKeyword */:
                    case 157 /* UnknownKeyword */:
                    case 152 /* StringKeyword */:
                    case 148 /* NumberKeyword */:
                    case 160 /* BigIntKeyword */:
                    case 134 /* BooleanKeyword */:
                    case 153 /* SymbolKeyword */:
                    case 149 /* ObjectKeyword */:
                    case 114 /* VoidKeyword */:
                    case 155 /* UndefinedKeyword */:
                    case 144 /* NeverKeyword */:
                    case 198 /* LiteralType */:
                        return true;
                    case 185 /* ArrayType */:
                        return isThislessType(node.elementType);
                    case 180 /* TypeReference */:
                        return !node.typeArguments || node.typeArguments.every(isThislessType);
                }
                return false;
            }
            function isThislessTypeParameter(node) {
                const constraint = getEffectiveConstraintOfTypeParameter(node);
                return !constraint || isThislessType(constraint);
            }
            function isThislessVariableLikeDeclaration(node) {
                const typeNode = getEffectiveTypeAnnotationNode(node);
                return typeNode ? isThislessType(typeNode) : !hasInitializer(node);
            }
            function isThislessFunctionLikeDeclaration(node) {
                const returnType = getEffectiveReturnTypeNode(node);
                const typeParameters = getEffectiveTypeParameterDeclarations(node);
                return (node.kind === 173 /* Constructor */ || !!returnType && isThislessType(returnType)) && node.parameters.every(isThislessVariableLikeDeclaration) && typeParameters.every(isThislessTypeParameter);
            }
            function isThisless(symbol) {
                if (symbol.declarations && symbol.declarations.length === 1) {
                    const declaration = symbol.declarations[0];
                    if (declaration) {
                        switch (declaration.kind) {
                            case 169 /* PropertyDeclaration */:
                            case 168 /* PropertySignature */:
                                return isThislessVariableLikeDeclaration(declaration);
                            case 171 /* MethodDeclaration */:
                            case 170 /* MethodSignature */:
                            case 173 /* Constructor */:
                            case 174 /* GetAccessor */:
                            case 175 /* SetAccessor */:
                                return isThislessFunctionLikeDeclaration(declaration);
                        }
                    }
                }
                return false;
            }
            function createInstantiatedSymbolTable(symbols, mapper, mappingThisOnly) {
                const result = createSymbolTable();
                for (const symbol of symbols) {
                    result.set(symbol.escapedName, mappingThisOnly && isThisless(symbol) ? symbol : instantiateSymbol(symbol, mapper));
                }
                return result;
            }
            function addInheritedMembers(symbols, baseSymbols) {
                for (const s of baseSymbols) {
                    if (!symbols.has(s.escapedName) && !isStaticPrivateIdentifierProperty(s)) {
                        symbols.set(s.escapedName, s);
                    }
                }
            }
            function isStaticPrivateIdentifierProperty(s) {
                return !!s.valueDeclaration && isPrivateIdentifierClassElementDeclaration(s.valueDeclaration) && isStatic(s.valueDeclaration);
            }
            function resolveDeclaredMembers(type) {
                if (!type.declaredProperties) {
                    const symbol = type.symbol;
                    const members = getMembersOfSymbol(symbol);
                    type.declaredProperties = getNamedMembers(members);
                    type.declaredCallSignatures = emptyArray;
                    type.declaredConstructSignatures = emptyArray;
                    type.declaredIndexInfos = emptyArray;
                    type.declaredCallSignatures = getSignaturesOfSymbol(members.get("__call" /* Call */));
                    type.declaredConstructSignatures = getSignaturesOfSymbol(members.get("__new" /* New */));
                    type.declaredIndexInfos = getIndexInfosOfSymbol(symbol);
                }
                return type;
            }
            function isTypeUsableAsPropertyName(type) {
                return !!(type.flags & 8576 /* StringOrNumberLiteralOrUnique */);
            }
            function isLateBindableName(node) {
                if (!isComputedPropertyName(node) && !isElementAccessExpression(node)) {
                    return false;
                }
                const expr = isComputedPropertyName(node) ? node.expression : node.argumentExpression;
                return isEntityNameExpression(expr) && isTypeUsableAsPropertyName(isComputedPropertyName(node) ? checkComputedPropertyName(node) : checkExpressionCached(expr));
            }
            function isLateBoundName(name) {
                return name.charCodeAt(0) === 95 /* _ */ && name.charCodeAt(1) === 95 /* _ */ && name.charCodeAt(2) === 64 /* at */;
            }
            function hasLateBindableName(node) {
                const name = getNameOfDeclaration(node);
                return !!name && isLateBindableName(name);
            }
            function hasBindableName(node) {
                return !hasDynamicName(node) || hasLateBindableName(node);
            }
            function isNonBindableDynamicName(node) {
                return isDynamicName(node) && !isLateBindableName(node);
            }
            function getPropertyNameFromType(type) {
                if (type.flags & 8192 /* UniqueESSymbol */) {
                    return type.escapedName;
                }
                if (type.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */)) {
                    return escapeLeadingUnderscores("" + type.value);
                }
                return Debug.fail();
            }
            function addDeclarationToLateBoundSymbol(symbol, member, symbolFlags) {
                Debug.assert(!!(getCheckFlags(symbol) & 4096 /* Late */), "Expected a late-bound symbol.");
                symbol.flags |= symbolFlags;
                getSymbolLinks(member.symbol).lateSymbol = symbol;
                if (!symbol.declarations) {
                    symbol.declarations = [member];
                }
                else if (!member.symbol.isReplaceableByMethod) {
                    symbol.declarations.push(member);
                }
                if (symbolFlags & 111551 /* Value */) {
                    if (!symbol.valueDeclaration || symbol.valueDeclaration.kind !== member.kind) {
                        symbol.valueDeclaration = member;
                    }
                }
            }
            function lateBindMember(parent2, earlySymbols, lateSymbols, decl) {
                Debug.assert(!!decl.symbol, "The member is expected to have a symbol.");
                const links = getNodeLinks(decl);
                if (!links.resolvedSymbol) {
                    links.resolvedSymbol = decl.symbol;
                    const declName = isBinaryExpression(decl) ? decl.left : decl.name;
                    const type = isElementAccessExpression(declName) ? checkExpressionCached(declName.argumentExpression) : checkComputedPropertyName(declName);
                    if (isTypeUsableAsPropertyName(type)) {
                        const memberName = getPropertyNameFromType(type);
                        const symbolFlags = decl.symbol.flags;
                        let lateSymbol = lateSymbols.get(memberName);
                        if (!lateSymbol)
                            lateSymbols.set(memberName, lateSymbol = createSymbol(0 /* None */, memberName, 4096 /* Late */));
                        const earlySymbol = earlySymbols && earlySymbols.get(memberName);
                        if (lateSymbol.flags & getExcludedSymbolFlags(symbolFlags) || earlySymbol) {
                            const declarations = earlySymbol ? concatenate(earlySymbol.declarations, lateSymbol.declarations) : lateSymbol.declarations;
                            const name = !(type.flags & 8192 /* UniqueESSymbol */) && unescapeLeadingUnderscores(memberName) || declarationNameToString(declName);
                            forEach(declarations, (declaration) => error(getNameOfDeclaration(declaration) || declaration, Diagnostics.Property_0_was_also_declared_here, name));
                            error(declName || decl, Diagnostics.Duplicate_property_0, name);
                            lateSymbol = createSymbol(0 /* None */, memberName, 4096 /* Late */);
                        }
                        lateSymbol.links.nameType = type;
                        addDeclarationToLateBoundSymbol(lateSymbol, decl, symbolFlags);
                        if (lateSymbol.parent) {
                            Debug.assert(lateSymbol.parent === parent2, "Existing symbol parent should match new one");
                        }
                        else {
                            lateSymbol.parent = parent2;
                        }
                        return links.resolvedSymbol = lateSymbol;
                    }
                }
                return links.resolvedSymbol;
            }
            function getResolvedMembersOrExportsOfSymbol(symbol, resolutionKind) {
                const links = getSymbolLinks(symbol);
                if (!links[resolutionKind]) {
                    const isStatic2 = resolutionKind === "resolvedExports" /* resolvedExports */;
                    const earlySymbols = !isStatic2 ? symbol.members : symbol.flags & 1536 /* Module */ ? getExportsOfModuleWorker(symbol).exports : symbol.exports;
                    links[resolutionKind] = earlySymbols || emptySymbols;
                    const lateSymbols = createSymbolTable();
                    for (const decl of symbol.declarations || emptyArray) {
                        const members = getMembersOfDeclaration(decl);
                        if (members) {
                            for (const member of members) {
                                if (isStatic2 === hasStaticModifier(member)) {
                                    if (hasLateBindableName(member)) {
                                        lateBindMember(symbol, earlySymbols, lateSymbols, member);
                                    }
                                }
                            }
                        }
                    }
                    const assignments = symbol.assignmentDeclarationMembers;
                    if (assignments) {
                        const decls = arrayFrom(assignments.values());
                        for (const member of decls) {
                            const assignmentKind = getAssignmentDeclarationKind(member);
                            const isInstanceMember = assignmentKind === 3 /* PrototypeProperty */ || isBinaryExpression(member) && isPossiblyAliasedThisProperty(member, assignmentKind) || assignmentKind === 9 /* ObjectDefinePrototypeProperty */ || assignmentKind === 6 /* Prototype */;
                            if (isStatic2 === !isInstanceMember) {
                                if (hasLateBindableName(member)) {
                                    lateBindMember(symbol, earlySymbols, lateSymbols, member);
                                }
                            }
                        }
                    }
                    links[resolutionKind] = combineSymbolTables(earlySymbols, lateSymbols) || emptySymbols;
                }
                return links[resolutionKind];
            }
            function getMembersOfSymbol(symbol) {
                return symbol.flags & 6256 /* LateBindingContainer */ ? getResolvedMembersOrExportsOfSymbol(symbol, "resolvedMembers" /* resolvedMembers */) : symbol.members || emptySymbols;
            }
            function getLateBoundSymbol(symbol) {
                if (symbol.flags & 106500 /* ClassMember */ && symbol.escapedName === "__computed" /* Computed */) {
                    const links = getSymbolLinks(symbol);
                    if (!links.lateSymbol && some(symbol.declarations, hasLateBindableName)) {
                        const parent2 = getMergedSymbol(symbol.parent);
                        if (some(symbol.declarations, hasStaticModifier)) {
                            getExportsOfSymbol(parent2);
                        }
                        else {
                            getMembersOfSymbol(parent2);
                        }
                    }
                    return links.lateSymbol || (links.lateSymbol = symbol);
                }
                return symbol;
            }
            function getTypeWithThisArgument(type, thisArgument, needApparentType) {
                if (getObjectFlags(type) & 4 /* Reference */) {
                    const target = type.target;
                    const typeArguments = getTypeArguments(type);
                    if (length(target.typeParameters) === length(typeArguments)) {
                        const ref = createTypeReference(target, concatenate(typeArguments, [thisArgument || target.thisType]));
                        return needApparentType ? getApparentType(ref) : ref;
                    }
                }
                else if (type.flags & 2097152 /* Intersection */) {
                    const types = sameMap(type.types, (t) => getTypeWithThisArgument(t, thisArgument, needApparentType));
                    return types !== type.types ? getIntersectionType(types) : type;
                }
                return needApparentType ? getApparentType(type) : type;
            }
            function resolveObjectTypeMembers(type, source, typeParameters, typeArguments) {
                let mapper;
                let members;
                let callSignatures;
                let constructSignatures;
                let indexInfos;
                if (rangeEquals(typeParameters, typeArguments, 0, typeParameters.length)) {
                    members = source.symbol ? getMembersOfSymbol(source.symbol) : createSymbolTable(source.declaredProperties);
                    callSignatures = source.declaredCallSignatures;
                    constructSignatures = source.declaredConstructSignatures;
                    indexInfos = source.declaredIndexInfos;
                }
                else {
                    mapper = createTypeMapper(typeParameters, typeArguments);
                    members = createInstantiatedSymbolTable(source.declaredProperties, mapper, 
                    /*mappingThisOnly*/
                    typeParameters.length === 1);
                    callSignatures = instantiateSignatures(source.declaredCallSignatures, mapper);
                    constructSignatures = instantiateSignatures(source.declaredConstructSignatures, mapper);
                    indexInfos = instantiateIndexInfos(source.declaredIndexInfos, mapper);
                }
                const baseTypes = getBaseTypes(source);
                if (baseTypes.length) {
                    if (source.symbol && members === getMembersOfSymbol(source.symbol)) {
                        members = createSymbolTable(source.declaredProperties);
                    }
                    setStructuredTypeMembers(type, members, callSignatures, constructSignatures, indexInfos);
                    const thisArgument = lastOrUndefined(typeArguments);
                    for (const baseType of baseTypes) {
                        const instantiatedBaseType = thisArgument ? getTypeWithThisArgument(instantiateType(baseType, mapper), thisArgument) : baseType;
                        addInheritedMembers(members, getPropertiesOfType(instantiatedBaseType));
                        callSignatures = concatenate(callSignatures, getSignaturesOfType(instantiatedBaseType, 0 /* Call */));
                        constructSignatures = concatenate(constructSignatures, getSignaturesOfType(instantiatedBaseType, 1 /* Construct */));
                        const inheritedIndexInfos = instantiatedBaseType !== anyType ? getIndexInfosOfType(instantiatedBaseType) : [createIndexInfo(stringType, anyType, 
                            /*isReadonly*/
                            false)];
                        indexInfos = concatenate(indexInfos, filter(inheritedIndexInfos, (info) => !findIndexInfo(indexInfos, info.keyType)));
                    }
                }
                setStructuredTypeMembers(type, members, callSignatures, constructSignatures, indexInfos);
            }
            function resolveClassOrInterfaceMembers(type) {
                resolveObjectTypeMembers(type, resolveDeclaredMembers(type), emptyArray, emptyArray);
            }
            function resolveTypeReferenceMembers(type) {
                const source = resolveDeclaredMembers(type.target);
                const typeParameters = concatenate(source.typeParameters, [source.thisType]);
                const typeArguments = getTypeArguments(type);
                const paddedTypeArguments = typeArguments.length === typeParameters.length ? typeArguments : concatenate(typeArguments, [type]);
                resolveObjectTypeMembers(type, source, typeParameters, paddedTypeArguments);
            }
            function createSignature(declaration, typeParameters, thisParameter, parameters, resolvedReturnType, resolvedTypePredicate, minArgumentCount, flags) {
                const sig = new Signature15(checker, flags);
                sig.declaration = declaration;
                sig.typeParameters = typeParameters;
                sig.parameters = parameters;
                sig.thisParameter = thisParameter;
                sig.resolvedReturnType = resolvedReturnType;
                sig.resolvedTypePredicate = resolvedTypePredicate;
                sig.minArgumentCount = minArgumentCount;
                sig.resolvedMinArgumentCount = void 0;
                sig.target = void 0;
                sig.mapper = void 0;
                sig.compositeSignatures = void 0;
                sig.compositeKind = void 0;
                return sig;
            }
            function cloneSignature(sig) {
                const result = createSignature(sig.declaration, sig.typeParameters, sig.thisParameter, sig.parameters, 
                /*resolvedReturnType*/
                void 0, 
                /*resolvedTypePredicate*/
                void 0, sig.minArgumentCount, sig.flags & 39 /* PropagatingFlags */);
                result.target = sig.target;
                result.mapper = sig.mapper;
                result.compositeSignatures = sig.compositeSignatures;
                result.compositeKind = sig.compositeKind;
                return result;
            }
            function createUnionSignature(signature, unionSignatures) {
                const result = cloneSignature(signature);
                result.compositeSignatures = unionSignatures;
                result.compositeKind = 1048576 /* Union */;
                result.target = void 0;
                result.mapper = void 0;
                return result;
            }
            function getOptionalCallSignature(signature, callChainFlags) {
                if ((signature.flags & 24 /* CallChainFlags */) === callChainFlags) {
                    return signature;
                }
                if (!signature.optionalCallSignatureCache) {
                    signature.optionalCallSignatureCache = {};
                }
                const key = callChainFlags === 8 /* IsInnerCallChain */ ? "inner" : "outer";
                return signature.optionalCallSignatureCache[key] || (signature.optionalCallSignatureCache[key] = createOptionalCallSignature(signature, callChainFlags));
            }
            function createOptionalCallSignature(signature, callChainFlags) {
                Debug.assert(callChainFlags === 8 /* IsInnerCallChain */ || callChainFlags === 16 /* IsOuterCallChain */, "An optional call signature can either be for an inner call chain or an outer call chain, but not both.");
                const result = cloneSignature(signature);
                result.flags |= callChainFlags;
                return result;
            }
            function getExpandedParameters(sig, skipUnionExpanding) {
                if (signatureHasRestParameter(sig)) {
                    const restIndex = sig.parameters.length - 1;
                    const restType = getTypeOfSymbol(sig.parameters[restIndex]);
                    if (isTupleType(restType)) {
                        return [expandSignatureParametersWithTupleMembers(restType, restIndex)];
                    }
                    else if (!skipUnionExpanding && restType.flags & 1048576 /* Union */ && every(restType.types, isTupleType)) {
                        return map(restType.types, (t) => expandSignatureParametersWithTupleMembers(t, restIndex));
                    }
                }
                return [sig.parameters];
                function expandSignatureParametersWithTupleMembers(restType, restIndex) {
                    const elementTypes = getTypeArguments(restType);
                    const associatedNames = restType.target.labeledElementDeclarations;
                    const restParams = map(elementTypes, (t, i) => {
                        const tupleLabelName = !!associatedNames && getTupleElementLabel(associatedNames[i]);
                        const name = tupleLabelName || getParameterNameAtPosition(sig, restIndex + i, restType);
                        const flags = restType.target.elementFlags[i];
                        const checkFlags = flags & 12 /* Variable */ ? 32768 /* RestParameter */ : flags & 2 /* Optional */ ? 16384 /* OptionalParameter */ : 0;
                        const symbol = createSymbol(1 /* FunctionScopedVariable */, name, checkFlags);
                        symbol.links.type = flags & 4 /* Rest */ ? createArrayType(t) : t;
                        return symbol;
                    });
                    return concatenate(sig.parameters.slice(0, restIndex), restParams);
                }
            }
            function getDefaultConstructSignatures(classType) {
                const baseConstructorType = getBaseConstructorTypeOfClass(classType);
                const baseSignatures = getSignaturesOfType(baseConstructorType, 1 /* Construct */);
                const declaration = getClassLikeDeclarationOfSymbol(classType.symbol);
                const isAbstract = !!declaration && hasSyntacticModifier(declaration, 256 /* Abstract */);
                if (baseSignatures.length === 0) {
                    return [createSignature(void 0, classType.localTypeParameters, void 0, emptyArray, classType, 
                        /*resolvedTypePredicate*/
                        void 0, 0, isAbstract ? 4 /* Abstract */ : 0 /* None */)];
                }
                const baseTypeNode = getBaseTypeNodeOfClass(classType);
                const isJavaScript = isInJSFile(baseTypeNode);
                const typeArguments = typeArgumentsFromTypeReferenceNode(baseTypeNode);
                const typeArgCount = length(typeArguments);
                const result = [];
                for (const baseSig of baseSignatures) {
                    const minTypeArgumentCount = getMinTypeArgumentCount(baseSig.typeParameters);
                    const typeParamCount = length(baseSig.typeParameters);
                    if (isJavaScript || typeArgCount >= minTypeArgumentCount && typeArgCount <= typeParamCount) {
                        const sig = typeParamCount ? createSignatureInstantiation(baseSig, fillMissingTypeArguments(typeArguments, baseSig.typeParameters, minTypeArgumentCount, isJavaScript)) : cloneSignature(baseSig);
                        sig.typeParameters = classType.localTypeParameters;
                        sig.resolvedReturnType = classType;
                        sig.flags = isAbstract ? sig.flags | 4 /* Abstract */ : sig.flags & ~4 /* Abstract */;
                        result.push(sig);
                    }
                }
                return result;
            }
            function findMatchingSignature(signatureList, signature, partialMatch, ignoreThisTypes, ignoreReturnTypes) {
                for (const s of signatureList) {
                    if (compareSignaturesIdentical(s, signature, partialMatch, ignoreThisTypes, ignoreReturnTypes, partialMatch ? compareTypesSubtypeOf : compareTypesIdentical)) {
                        return s;
                    }
                }
            }
            function findMatchingSignatures(signatureLists, signature, listIndex) {
                if (signature.typeParameters) {
                    if (listIndex > 0) {
                        return void 0;
                    }
                    for (let i = 1; i < signatureLists.length; i++) {
                        if (!findMatchingSignature(signatureLists[i], signature, 
                        /*partialMatch*/
                        false, 
                        /*ignoreThisTypes*/
                        false, 
                        /*ignoreReturnTypes*/
                        false)) {
                            return void 0;
                        }
                    }
                    return [signature];
                }
                let result;
                for (let i = 0; i < signatureLists.length; i++) {
                    const match = i === listIndex ? signature : findMatchingSignature(signatureLists[i], signature, 
                    /*partialMatch*/
                    true, 
                    /*ignoreThisTypes*/
                    false, 
                    /*ignoreReturnTypes*/
                    true);
                    if (!match) {
                        return void 0;
                    }
                    result = appendIfUnique(result, match);
                }
                return result;
            }
            function getUnionSignatures(signatureLists) {
                let result;
                let indexWithLengthOverOne;
                for (let i = 0; i < signatureLists.length; i++) {
                    if (signatureLists[i].length === 0)
                        return emptyArray;
                    if (signatureLists[i].length > 1) {
                        indexWithLengthOverOne = indexWithLengthOverOne === void 0 ? i : -1;
                    }
                    for (const signature of signatureLists[i]) {
                        if (!result || !findMatchingSignature(result, signature, 
                        /*partialMatch*/
                        false, 
                        /*ignoreThisTypes*/
                        false, 
                        /*ignoreReturnTypes*/
                        true)) {
                            const unionSignatures = findMatchingSignatures(signatureLists, signature, i);
                            if (unionSignatures) {
                                let s = signature;
                                if (unionSignatures.length > 1) {
                                    let thisParameter = signature.thisParameter;
                                    const firstThisParameterOfUnionSignatures = forEach(unionSignatures, (sig) => sig.thisParameter);
                                    if (firstThisParameterOfUnionSignatures) {
                                        const thisType = getIntersectionType(mapDefined(unionSignatures, (sig) => sig.thisParameter && getTypeOfSymbol(sig.thisParameter)));
                                        thisParameter = createSymbolWithType(firstThisParameterOfUnionSignatures, thisType);
                                    }
                                    s = createUnionSignature(signature, unionSignatures);
                                    s.thisParameter = thisParameter;
                                }
                                (result || (result = [])).push(s);
                            }
                        }
                    }
                }
                if (!length(result) && indexWithLengthOverOne !== -1) {
                    const masterList = signatureLists[indexWithLengthOverOne !== void 0 ? indexWithLengthOverOne : 0];
                    let results = masterList.slice();
                    for (const signatures of signatureLists) {
                        if (signatures !== masterList) {
                            const signature = signatures[0];
                            Debug.assert(!!signature, "getUnionSignatures bails early on empty signature lists and should not have empty lists on second pass");
                            results = !!signature.typeParameters && some(results, (s) => !!s.typeParameters && !compareTypeParametersIdentical(signature.typeParameters, s.typeParameters)) ? void 0 : map(results, (sig) => combineSignaturesOfUnionMembers(sig, signature));
                            if (!results) {
                                break;
                            }
                        }
                    }
                    result = results;
                }
                return result || emptyArray;
            }
            function compareTypeParametersIdentical(sourceParams, targetParams) {
                if (length(sourceParams) !== length(targetParams)) {
                    return false;
                }
                if (!sourceParams || !targetParams) {
                    return true;
                }
                const mapper = createTypeMapper(targetParams, sourceParams);
                for (let i = 0; i < sourceParams.length; i++) {
                    const source = sourceParams[i];
                    const target = targetParams[i];
                    if (source === target)
                        continue;
                    if (!isTypeIdenticalTo(getConstraintFromTypeParameter(source) || unknownType, instantiateType(getConstraintFromTypeParameter(target) || unknownType, mapper)))
                        return false;
                }
                return true;
            }
            function combineUnionThisParam(left, right, mapper) {
                if (!left || !right) {
                    return left || right;
                }
                const thisType = getIntersectionType([getTypeOfSymbol(left), instantiateType(getTypeOfSymbol(right), mapper)]);
                return createSymbolWithType(left, thisType);
            }
            function combineUnionParameters(left, right, mapper) {
                const leftCount = getParameterCount(left);
                const rightCount = getParameterCount(right);
                const longest = leftCount >= rightCount ? left : right;
                const shorter = longest === left ? right : left;
                const longestCount = longest === left ? leftCount : rightCount;
                const eitherHasEffectiveRest = hasEffectiveRestParameter(left) || hasEffectiveRestParameter(right);
                const needsExtraRestElement = eitherHasEffectiveRest && !hasEffectiveRestParameter(longest);
                const params = new Array(longestCount + (needsExtraRestElement ? 1 : 0));
                for (let i = 0; i < longestCount; i++) {
                    let longestParamType = tryGetTypeAtPosition(longest, i);
                    if (longest === right) {
                        longestParamType = instantiateType(longestParamType, mapper);
                    }
                    let shorterParamType = tryGetTypeAtPosition(shorter, i) || unknownType;
                    if (shorter === right) {
                        shorterParamType = instantiateType(shorterParamType, mapper);
                    }
                    const unionParamType = getIntersectionType([longestParamType, shorterParamType]);
                    const isRestParam = eitherHasEffectiveRest && !needsExtraRestElement && i === longestCount - 1;
                    const isOptional = i >= getMinArgumentCount(longest) && i >= getMinArgumentCount(shorter);
                    const leftName = i >= leftCount ? void 0 : getParameterNameAtPosition(left, i);
                    const rightName = i >= rightCount ? void 0 : getParameterNameAtPosition(right, i);
                    const paramName = leftName === rightName ? leftName : !leftName ? rightName : !rightName ? leftName : void 0;
                    const paramSymbol = createSymbol(1 /* FunctionScopedVariable */ | (isOptional && !isRestParam ? 16777216 /* Optional */ : 0), paramName || `arg${i}`);
                    paramSymbol.links.type = isRestParam ? createArrayType(unionParamType) : unionParamType;
                    params[i] = paramSymbol;
                }
                if (needsExtraRestElement) {
                    const restParamSymbol = createSymbol(1 /* FunctionScopedVariable */, "args");
                    restParamSymbol.links.type = createArrayType(getTypeAtPosition(shorter, longestCount));
                    if (shorter === right) {
                        restParamSymbol.links.type = instantiateType(restParamSymbol.links.type, mapper);
                    }
                    params[longestCount] = restParamSymbol;
                }
                return params;
            }
            function combineSignaturesOfUnionMembers(left, right) {
                const typeParams = left.typeParameters || right.typeParameters;
                let paramMapper;
                if (left.typeParameters && right.typeParameters) {
                    paramMapper = createTypeMapper(right.typeParameters, left.typeParameters);
                }
                const declaration = left.declaration;
                const params = combineUnionParameters(left, right, paramMapper);
                const thisParam = combineUnionThisParam(left.thisParameter, right.thisParameter, paramMapper);
                const minArgCount = Math.max(left.minArgumentCount, right.minArgumentCount);
                const result = createSignature(declaration, typeParams, thisParam, params, 
                /*resolvedReturnType*/
                void 0, 
                /*resolvedTypePredicate*/
                void 0, minArgCount, (left.flags | right.flags) & 39 /* PropagatingFlags */);
                result.compositeKind = 1048576 /* Union */;
                result.compositeSignatures = concatenate(left.compositeKind !== 2097152 /* Intersection */ && left.compositeSignatures || [left], [right]);
                if (paramMapper) {
                    result.mapper = left.compositeKind !== 2097152 /* Intersection */ && left.mapper && left.compositeSignatures ? combineTypeMappers(left.mapper, paramMapper) : paramMapper;
                }
                return result;
            }
            function getUnionIndexInfos(types) {
                const sourceInfos = getIndexInfosOfType(types[0]);
                if (sourceInfos) {
                    const result = [];
                    for (const info of sourceInfos) {
                        const indexType = info.keyType;
                        if (every(types, (t) => !!getIndexInfoOfType(t, indexType))) {
                            result.push(createIndexInfo(indexType, getUnionType(map(types, (t) => getIndexTypeOfType(t, indexType))), some(types, (t) => getIndexInfoOfType(t, indexType).isReadonly)));
                        }
                    }
                    return result;
                }
                return emptyArray;
            }
            function resolveUnionTypeMembers(type) {
                const callSignatures = getUnionSignatures(map(type.types, (t) => t === globalFunctionType ? [unknownSignature] : getSignaturesOfType(t, 0 /* Call */)));
                const constructSignatures = getUnionSignatures(map(type.types, (t) => getSignaturesOfType(t, 1 /* Construct */)));
                const indexInfos = getUnionIndexInfos(type.types);
                setStructuredTypeMembers(type, emptySymbols, callSignatures, constructSignatures, indexInfos);
            }
            function intersectTypes(type1, type2) {
                return !type1 ? type2 : !type2 ? type1 : getIntersectionType([type1, type2]);
            }
            function findMixins(types) {
                const constructorTypeCount = countWhere(types, (t) => getSignaturesOfType(t, 1 /* Construct */).length > 0);
                const mixinFlags = map(types, isMixinConstructorType);
                if (constructorTypeCount > 0 && constructorTypeCount === countWhere(mixinFlags, (b) => b)) {
                    const firstMixinIndex = mixinFlags.indexOf(
                    /*searchElement*/
                    true);
                    mixinFlags[firstMixinIndex] = false;
                }
                return mixinFlags;
            }
            function includeMixinType(type, types, mixinFlags, index) {
                const mixedTypes = [];
                for (let i = 0; i < types.length; i++) {
                    if (i === index) {
                        mixedTypes.push(type);
                    }
                    else if (mixinFlags[i]) {
                        mixedTypes.push(getReturnTypeOfSignature(getSignaturesOfType(types[i], 1 /* Construct */)[0]));
                    }
                }
                return getIntersectionType(mixedTypes);
            }
            function resolveIntersectionTypeMembers(type) {
                let callSignatures;
                let constructSignatures;
                let indexInfos;
                const types = type.types;
                const mixinFlags = findMixins(types);
                const mixinCount = countWhere(mixinFlags, (b) => b);
                for (let i = 0; i < types.length; i++) {
                    const t = type.types[i];
                    if (!mixinFlags[i]) {
                        let signatures = getSignaturesOfType(t, 1 /* Construct */);
                        if (signatures.length && mixinCount > 0) {
                            signatures = map(signatures, (s) => {
                                const clone2 = cloneSignature(s);
                                clone2.resolvedReturnType = includeMixinType(getReturnTypeOfSignature(s), types, mixinFlags, i);
                                return clone2;
                            });
                        }
                        constructSignatures = appendSignatures(constructSignatures, signatures);
                    }
                    callSignatures = appendSignatures(callSignatures, getSignaturesOfType(t, 0 /* Call */));
                    indexInfos = reduceLeft(getIndexInfosOfType(t), (infos, newInfo) => appendIndexInfo(infos, newInfo, 
                    /*union*/
                    false), indexInfos);
                }
                setStructuredTypeMembers(type, emptySymbols, callSignatures || emptyArray, constructSignatures || emptyArray, indexInfos || emptyArray);
            }
            function appendSignatures(signatures, newSignatures) {
                for (const sig of newSignatures) {
                    if (!signatures || every(signatures, (s) => !compareSignaturesIdentical(s, sig, 
                    /*partialMatch*/
                    false, 
                    /*ignoreThisTypes*/
                    false, 
                    /*ignoreReturnTypes*/
                    false, compareTypesIdentical))) {
                        signatures = append(signatures, sig);
                    }
                }
                return signatures;
            }
            function appendIndexInfo(indexInfos, newInfo, union) {
                if (indexInfos) {
                    for (let i = 0; i < indexInfos.length; i++) {
                        const info = indexInfos[i];
                        if (info.keyType === newInfo.keyType) {
                            indexInfos[i] = createIndexInfo(info.keyType, union ? getUnionType([info.type, newInfo.type]) : getIntersectionType([info.type, newInfo.type]), union ? info.isReadonly || newInfo.isReadonly : info.isReadonly && newInfo.isReadonly);
                            return indexInfos;
                        }
                    }
                }
                return append(indexInfos, newInfo);
            }
            function resolveAnonymousTypeMembers(type) {
                if (type.target) {
                    setStructuredTypeMembers(type, emptySymbols, emptyArray, emptyArray, emptyArray);
                    const members2 = createInstantiatedSymbolTable(getPropertiesOfObjectType(type.target), type.mapper, 
                    /*mappingThisOnly*/
                    false);
                    const callSignatures = instantiateSignatures(getSignaturesOfType(type.target, 0 /* Call */), type.mapper);
                    const constructSignatures = instantiateSignatures(getSignaturesOfType(type.target, 1 /* Construct */), type.mapper);
                    const indexInfos2 = instantiateIndexInfos(getIndexInfosOfType(type.target), type.mapper);
                    setStructuredTypeMembers(type, members2, callSignatures, constructSignatures, indexInfos2);
                    return;
                }
                const symbol = getMergedSymbol(type.symbol);
                if (symbol.flags & 2048 /* TypeLiteral */) {
                    setStructuredTypeMembers(type, emptySymbols, emptyArray, emptyArray, emptyArray);
                    const members2 = getMembersOfSymbol(symbol);
                    const callSignatures = getSignaturesOfSymbol(members2.get("__call" /* Call */));
                    const constructSignatures = getSignaturesOfSymbol(members2.get("__new" /* New */));
                    const indexInfos2 = getIndexInfosOfSymbol(symbol);
                    setStructuredTypeMembers(type, members2, callSignatures, constructSignatures, indexInfos2);
                    return;
                }
                let members = emptySymbols;
                let indexInfos;
                if (symbol.exports) {
                    members = getExportsOfSymbol(symbol);
                    if (symbol === globalThisSymbol) {
                        const varsOnly = /* @__PURE__ */ new Map();
                        members.forEach((p) => {
                            var _a2;
                            if (!(p.flags & 418 /* BlockScoped */) && !(p.flags & 512 /* ValueModule */ && ((_a2 = p.declarations) == null ? void 0 : _a2.length) && every(p.declarations, isAmbientModule))) {
                                varsOnly.set(p.escapedName, p);
                            }
                        });
                        members = varsOnly;
                    }
                }
                let baseConstructorIndexInfo;
                setStructuredTypeMembers(type, members, emptyArray, emptyArray, emptyArray);
                if (symbol.flags & 32 /* Class */) {
                    const classType = getDeclaredTypeOfClassOrInterface(symbol);
                    const baseConstructorType = getBaseConstructorTypeOfClass(classType);
                    if (baseConstructorType.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 8650752 /* TypeVariable */)) {
                        members = createSymbolTable(getNamedOrIndexSignatureMembers(members));
                        addInheritedMembers(members, getPropertiesOfType(baseConstructorType));
                    }
                    else if (baseConstructorType === anyType) {
                        baseConstructorIndexInfo = createIndexInfo(stringType, anyType, 
                        /*isReadonly*/
                        false);
                    }
                }
                const indexSymbol = getIndexSymbolFromSymbolTable(members);
                if (indexSymbol) {
                    indexInfos = getIndexInfosOfIndexSymbol(indexSymbol);
                }
                else {
                    if (baseConstructorIndexInfo) {
                        indexInfos = append(indexInfos, baseConstructorIndexInfo);
                    }
                    if (symbol.flags & 384 /* Enum */ && (getDeclaredTypeOfSymbol(symbol).flags & 32 /* Enum */ || some(type.properties, (prop) => !!(getTypeOfSymbol(prop).flags & 296 /* NumberLike */)))) {
                        indexInfos = append(indexInfos, enumNumberIndexInfo);
                    }
                }
                setStructuredTypeMembers(type, members, emptyArray, emptyArray, indexInfos || emptyArray);
                if (symbol.flags & (16 /* Function */ | 8192 /* Method */)) {
                    type.callSignatures = getSignaturesOfSymbol(symbol);
                }
                if (symbol.flags & 32 /* Class */) {
                    const classType = getDeclaredTypeOfClassOrInterface(symbol);
                    let constructSignatures = symbol.members ? getSignaturesOfSymbol(symbol.members.get("__constructor" /* Constructor */)) : emptyArray;
                    if (symbol.flags & 16 /* Function */) {
                        constructSignatures = addRange(constructSignatures.slice(), mapDefined(type.callSignatures, (sig) => isJSConstructor(sig.declaration) ? createSignature(sig.declaration, sig.typeParameters, sig.thisParameter, sig.parameters, classType, 
                        /*resolvedTypePredicate*/
                        void 0, sig.minArgumentCount, sig.flags & 39 /* PropagatingFlags */) : void 0));
                    }
                    if (!constructSignatures.length) {
                        constructSignatures = getDefaultConstructSignatures(classType);
                    }
                    type.constructSignatures = constructSignatures;
                }
            }
            function replaceIndexedAccess(instantiable, type, replacement) {
                return instantiateType(instantiable, createTypeMapper([type.indexType, type.objectType], [getNumberLiteralType(0), createTupleType([replacement])]));
            }
            function resolveReverseMappedTypeMembers(type) {
                const indexInfo = getIndexInfoOfType(type.source, stringType);
                const modifiers = getMappedTypeModifiers(type.mappedType);
                const readonlyMask = modifiers & 1 /* IncludeReadonly */ ? false : true;
                const optionalMask = modifiers & 4 /* IncludeOptional */ ? 0 : 16777216 /* Optional */;
                const indexInfos = indexInfo ? [createIndexInfo(stringType, inferReverseMappedType(indexInfo.type, type.mappedType, type.constraintType), readonlyMask && indexInfo.isReadonly)] : emptyArray;
                const members = createSymbolTable();
                for (const prop of getPropertiesOfType(type.source)) {
                    const checkFlags = 8192 /* ReverseMapped */ | (readonlyMask && isReadonlySymbol(prop) ? 8 /* Readonly */ : 0);
                    const inferredProp = createSymbol(4 /* Property */ | prop.flags & optionalMask, prop.escapedName, checkFlags);
                    inferredProp.declarations = prop.declarations;
                    inferredProp.links.nameType = getSymbolLinks(prop).nameType;
                    inferredProp.links.propertyType = getTypeOfSymbol(prop);
                    if (type.constraintType.type.flags & 8388608 /* IndexedAccess */ && type.constraintType.type.objectType.flags & 262144 /* TypeParameter */ && type.constraintType.type.indexType.flags & 262144 /* TypeParameter */) {
                        const newTypeParam = type.constraintType.type.objectType;
                        const newMappedType = replaceIndexedAccess(type.mappedType, type.constraintType.type, newTypeParam);
                        inferredProp.links.mappedType = newMappedType;
                        inferredProp.links.constraintType = getIndexType(newTypeParam);
                    }
                    else {
                        inferredProp.links.mappedType = type.mappedType;
                        inferredProp.links.constraintType = type.constraintType;
                    }
                    members.set(prop.escapedName, inferredProp);
                }
                setStructuredTypeMembers(type, members, emptyArray, emptyArray, indexInfos);
            }
            function getLowerBoundOfKeyType(type) {
                if (type.flags & 4194304 /* Index */) {
                    const t = getApparentType(type.type);
                    return isGenericTupleType(t) ? getKnownKeysOfTupleType(t) : getIndexType(t);
                }
                if (type.flags & 16777216 /* Conditional */) {
                    if (type.root.isDistributive) {
                        const checkType = type.checkType;
                        const constraint = getLowerBoundOfKeyType(checkType);
                        if (constraint !== checkType) {
                            return getConditionalTypeInstantiation(type, prependTypeMapping(type.root.checkType, constraint, type.mapper));
                        }
                    }
                    return type;
                }
                if (type.flags & 1048576 /* Union */) {
                    return mapType(type, getLowerBoundOfKeyType, 
                    /*noReductions*/
                    true);
                }
                if (type.flags & 2097152 /* Intersection */) {
                    const types = type.types;
                    if (types.length === 2 && !!(types[0].flags & (4 /* String */ | 8 /* Number */ | 64 /* BigInt */)) && types[1] === emptyTypeLiteralType) {
                        return type;
                    }
                    return getIntersectionType(sameMap(type.types, getLowerBoundOfKeyType));
                }
                return type;
            }
            function getIsLateCheckFlag(s) {
                return getCheckFlags(s) & 4096 /* Late */;
            }
            function forEachMappedTypePropertyKeyTypeAndIndexSignatureKeyType(type, include, stringsOnly, cb) {
                for (const prop of getPropertiesOfType(type)) {
                    cb(getLiteralTypeFromProperty(prop, include));
                }
                if (type.flags & 1 /* Any */) {
                    cb(stringType);
                }
                else {
                    for (const info of getIndexInfosOfType(type)) {
                        if (!stringsOnly || info.keyType.flags & (4 /* String */ | 134217728 /* TemplateLiteral */)) {
                            cb(info.keyType);
                        }
                    }
                }
            }
            function resolveMappedTypeMembers(type) {
                const members = createSymbolTable();
                let indexInfos;
                setStructuredTypeMembers(type, emptySymbols, emptyArray, emptyArray, emptyArray);
                const typeParameter = getTypeParameterFromMappedType(type);
                const constraintType = getConstraintTypeFromMappedType(type);
                const mappedType = type.target || type;
                const nameType = getNameTypeFromMappedType(mappedType);
                const shouldLinkPropDeclarations = !nameType || isFilteringMappedType(mappedType);
                const templateType = getTemplateTypeFromMappedType(mappedType);
                const modifiersType = getApparentType(getModifiersTypeFromMappedType(type));
                const templateModifiers = getMappedTypeModifiers(type);
                const include = keyofStringsOnly ? 128 /* StringLiteral */ : 8576 /* StringOrNumberLiteralOrUnique */;
                if (isMappedTypeWithKeyofConstraintDeclaration(type)) {
                    forEachMappedTypePropertyKeyTypeAndIndexSignatureKeyType(modifiersType, include, keyofStringsOnly, addMemberForKeyType);
                }
                else {
                    forEachType(getLowerBoundOfKeyType(constraintType), addMemberForKeyType);
                }
                setStructuredTypeMembers(type, members, emptyArray, emptyArray, indexInfos || emptyArray);
                function addMemberForKeyType(keyType) {
                    const propNameType = nameType ? instantiateType(nameType, appendTypeMapping(type.mapper, typeParameter, keyType)) : keyType;
                    forEachType(propNameType, (t) => addMemberForKeyTypeWorker(keyType, t));
                }
                function addMemberForKeyTypeWorker(keyType, propNameType) {
                    if (isTypeUsableAsPropertyName(propNameType)) {
                        const propName = getPropertyNameFromType(propNameType);
                        const existingProp = members.get(propName);
                        if (existingProp) {
                            existingProp.links.nameType = getUnionType([existingProp.links.nameType, propNameType]);
                            existingProp.links.keyType = getUnionType([existingProp.links.keyType, keyType]);
                        }
                        else {
                            const modifiersProp = isTypeUsableAsPropertyName(keyType) ? getPropertyOfType(modifiersType, getPropertyNameFromType(keyType)) : void 0;
                            const isOptional = !!(templateModifiers & 4 /* IncludeOptional */ || !(templateModifiers & 8 /* ExcludeOptional */) && modifiersProp && modifiersProp.flags & 16777216 /* Optional */);
                            const isReadonly = !!(templateModifiers & 1 /* IncludeReadonly */ || !(templateModifiers & 2 /* ExcludeReadonly */) && modifiersProp && isReadonlySymbol(modifiersProp));
                            const stripOptional = strictNullChecks && !isOptional && modifiersProp && modifiersProp.flags & 16777216 /* Optional */;
                            const lateFlag = modifiersProp ? getIsLateCheckFlag(modifiersProp) : 0;
                            const prop = createSymbol(4 /* Property */ | (isOptional ? 16777216 /* Optional */ : 0), propName, lateFlag | 262144 /* Mapped */ | (isReadonly ? 8 /* Readonly */ : 0) | (stripOptional ? 524288 /* StripOptional */ : 0));
                            prop.links.mappedType = type;
                            prop.links.nameType = propNameType;
                            prop.links.keyType = keyType;
                            if (modifiersProp) {
                                prop.links.syntheticOrigin = modifiersProp;
                                prop.declarations = shouldLinkPropDeclarations ? modifiersProp.declarations : void 0;
                            }
                            members.set(propName, prop);
                        }
                    }
                    else if (isValidIndexKeyType(propNameType) || propNameType.flags & (1 /* Any */ | 32 /* Enum */)) {
                        const indexKeyType = propNameType.flags & (1 /* Any */ | 4 /* String */) ? stringType : propNameType.flags & (8 /* Number */ | 32 /* Enum */) ? numberType : propNameType;
                        const propType = instantiateType(templateType, appendTypeMapping(type.mapper, typeParameter, keyType));
                        const indexInfo = createIndexInfo(indexKeyType, propType, !!(templateModifiers & 1 /* IncludeReadonly */));
                        indexInfos = appendIndexInfo(indexInfos, indexInfo, 
                        /*union*/
                        true);
                    }
                }
            }
            function getTypeOfMappedSymbol(symbol) {
                if (!symbol.links.type) {
                    const mappedType = symbol.links.mappedType;
                    if (!pushTypeResolution(symbol, 0 /* Type */)) {
                        mappedType.containsError = true;
                        return errorType;
                    }
                    const templateType = getTemplateTypeFromMappedType(mappedType.target || mappedType);
                    const mapper = appendTypeMapping(mappedType.mapper, getTypeParameterFromMappedType(mappedType), symbol.links.keyType);
                    const propType = instantiateType(templateType, mapper);
                    let type = strictNullChecks && symbol.flags & 16777216 /* Optional */ && !maybeTypeOfKind(propType, 32768 /* Undefined */ | 16384 /* Void */) ? getOptionalType(propType, 
                    /*isProperty*/
                    true) : symbol.links.checkFlags & 524288 /* StripOptional */ ? removeMissingOrUndefinedType(propType) : propType;
                    if (!popTypeResolution()) {
                        error(currentNode, Diagnostics.Type_of_property_0_circularly_references_itself_in_mapped_type_1, symbolToString(symbol), typeToString(mappedType));
                        type = errorType;
                    }
                    symbol.links.type = type;
                }
                return symbol.links.type;
            }
            function getTypeParameterFromMappedType(type) {
                return type.typeParameter || (type.typeParameter = getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(type.declaration.typeParameter)));
            }
            function getConstraintTypeFromMappedType(type) {
                return type.constraintType || (type.constraintType = getConstraintOfTypeParameter(getTypeParameterFromMappedType(type)) || errorType);
            }
            function getNameTypeFromMappedType(type) {
                return type.declaration.nameType ? type.nameType || (type.nameType = instantiateType(getTypeFromTypeNode(type.declaration.nameType), type.mapper)) : void 0;
            }
            function getTemplateTypeFromMappedType(type) {
                return type.templateType || (type.templateType = type.declaration.type ? instantiateType(addOptionality(getTypeFromTypeNode(type.declaration.type), 
                /*isProperty*/
                true, !!(getMappedTypeModifiers(type) & 4 /* IncludeOptional */)), type.mapper) : errorType);
            }
            function getConstraintDeclarationForMappedType(type) {
                return getEffectiveConstraintOfTypeParameter(type.declaration.typeParameter);
            }
            function isMappedTypeWithKeyofConstraintDeclaration(type) {
                const constraintDeclaration = getConstraintDeclarationForMappedType(type);
                return constraintDeclaration.kind === 195 /* TypeOperator */ && constraintDeclaration.operator === 141 /* KeyOfKeyword */;
            }
            function getModifiersTypeFromMappedType(type) {
                if (!type.modifiersType) {
                    if (isMappedTypeWithKeyofConstraintDeclaration(type)) {
                        type.modifiersType = instantiateType(getTypeFromTypeNode(getConstraintDeclarationForMappedType(type).type), type.mapper);
                    }
                    else {
                        const declaredType = getTypeFromMappedTypeNode(type.declaration);
                        const constraint = getConstraintTypeFromMappedType(declaredType);
                        const extendedConstraint = constraint && constraint.flags & 262144 /* TypeParameter */ ? getConstraintOfTypeParameter(constraint) : constraint;
                        type.modifiersType = extendedConstraint && extendedConstraint.flags & 4194304 /* Index */ ? instantiateType(extendedConstraint.type, type.mapper) : unknownType;
                    }
                }
                return type.modifiersType;
            }
            function getMappedTypeModifiers(type) {
                const declaration = type.declaration;
                return (declaration.readonlyToken ? declaration.readonlyToken.kind === 40 /* MinusToken */ ? 2 /* ExcludeReadonly */ : 1 /* IncludeReadonly */ : 0) | (declaration.questionToken ? declaration.questionToken.kind === 40 /* MinusToken */ ? 8 /* ExcludeOptional */ : 4 /* IncludeOptional */ : 0);
            }
            function getMappedTypeOptionality(type) {
                const modifiers = getMappedTypeModifiers(type);
                return modifiers & 8 /* ExcludeOptional */ ? -1 : modifiers & 4 /* IncludeOptional */ ? 1 : 0;
            }
            function getCombinedMappedTypeOptionality(type) {
                const optionality = getMappedTypeOptionality(type);
                const modifiersType = getModifiersTypeFromMappedType(type);
                return optionality || (isGenericMappedType(modifiersType) ? getMappedTypeOptionality(modifiersType) : 0);
            }
            function isPartialMappedType(type) {
                return !!(getObjectFlags(type) & 32 /* Mapped */ && getMappedTypeModifiers(type) & 4 /* IncludeOptional */);
            }
            function isGenericMappedType(type) {
                if (getObjectFlags(type) & 32 /* Mapped */) {
                    const constraint = getConstraintTypeFromMappedType(type);
                    if (isGenericIndexType(constraint)) {
                        return true;
                    }
                    const nameType = getNameTypeFromMappedType(type);
                    if (nameType && isGenericIndexType(instantiateType(nameType, makeUnaryTypeMapper(getTypeParameterFromMappedType(type), constraint)))) {
                        return true;
                    }
                }
                return false;
            }
            function isFilteringMappedType(type) {
                const nameType = getNameTypeFromMappedType(type);
                return !!nameType && isTypeAssignableTo(nameType, getTypeParameterFromMappedType(type));
            }
            function resolveStructuredTypeMembers(type) {
                if (!type.members) {
                    if (type.flags & 524288 /* Object */) {
                        if (type.objectFlags & 4 /* Reference */) {
                            resolveTypeReferenceMembers(type);
                        }
                        else if (type.objectFlags & 3 /* ClassOrInterface */) {
                            resolveClassOrInterfaceMembers(type);
                        }
                        else if (type.objectFlags & 1024 /* ReverseMapped */) {
                            resolveReverseMappedTypeMembers(type);
                        }
                        else if (type.objectFlags & 16 /* Anonymous */) {
                            resolveAnonymousTypeMembers(type);
                        }
                        else if (type.objectFlags & 32 /* Mapped */) {
                            resolveMappedTypeMembers(type);
                        }
                        else {
                            Debug.fail("Unhandled object type " + Debug.formatObjectFlags(type.objectFlags));
                        }
                    }
                    else if (type.flags & 1048576 /* Union */) {
                        resolveUnionTypeMembers(type);
                    }
                    else if (type.flags & 2097152 /* Intersection */) {
                        resolveIntersectionTypeMembers(type);
                    }
                    else {
                        Debug.fail("Unhandled type " + Debug.formatTypeFlags(type.flags));
                    }
                }
                return type;
            }
            function getPropertiesOfObjectType(type) {
                if (type.flags & 524288 /* Object */) {
                    return resolveStructuredTypeMembers(type).properties;
                }
                return emptyArray;
            }
            function getPropertyOfObjectType(type, name) {
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    const symbol = resolved.members.get(name);
                    if (symbol && symbolIsValue(symbol)) {
                        return symbol;
                    }
                }
            }
            function getPropertiesOfUnionOrIntersectionType(type) {
                if (!type.resolvedProperties) {
                    const members = createSymbolTable();
                    for (const current of type.types) {
                        for (const prop of getPropertiesOfType(current)) {
                            if (!members.has(prop.escapedName)) {
                                const combinedProp = getPropertyOfUnionOrIntersectionType(type, prop.escapedName);
                                if (combinedProp) {
                                    members.set(prop.escapedName, combinedProp);
                                }
                            }
                        }
                        if (type.flags & 1048576 /* Union */ && getIndexInfosOfType(current).length === 0) {
                            break;
                        }
                    }
                    type.resolvedProperties = getNamedMembers(members);
                }
                return type.resolvedProperties;
            }
            function getPropertiesOfType(type) {
                type = getReducedApparentType(type);
                return type.flags & 3145728 /* UnionOrIntersection */ ? getPropertiesOfUnionOrIntersectionType(type) : getPropertiesOfObjectType(type);
            }
            function forEachPropertyOfType(type, action) {
                type = getReducedApparentType(type);
                if (type.flags & 3670016 /* StructuredType */) {
                    resolveStructuredTypeMembers(type).members.forEach((symbol, escapedName) => {
                        if (isNamedMember(symbol, escapedName)) {
                            action(symbol, escapedName);
                        }
                    });
                }
            }
            function isTypeInvalidDueToUnionDiscriminant(contextualType, obj) {
                const list = obj.properties;
                return list.some((property) => {
                    const nameType = property.name && getLiteralTypeFromPropertyName(property.name);
                    const name = nameType && isTypeUsableAsPropertyName(nameType) ? getPropertyNameFromType(nameType) : void 0;
                    const expected = name === void 0 ? void 0 : getTypeOfPropertyOfType(contextualType, name);
                    return !!expected && isLiteralType(expected) && !isTypeAssignableTo(getTypeOfNode(property), expected);
                });
            }
            function getAllPossiblePropertiesOfTypes(types) {
                const unionType = getUnionType(types);
                if (!(unionType.flags & 1048576 /* Union */)) {
                    return getAugmentedPropertiesOfType(unionType);
                }
                const props = createSymbolTable();
                for (const memberType of types) {
                    for (const { escapedName } of getAugmentedPropertiesOfType(memberType)) {
                        if (!props.has(escapedName)) {
                            const prop = createUnionOrIntersectionProperty(unionType, escapedName);
                            if (prop)
                                props.set(escapedName, prop);
                        }
                    }
                }
                return arrayFrom(props.values());
            }
            function getConstraintOfType(type) {
                return type.flags & 262144 /* TypeParameter */ ? getConstraintOfTypeParameter(type) : type.flags & 8388608 /* IndexedAccess */ ? getConstraintOfIndexedAccess(type) : type.flags & 16777216 /* Conditional */ ? getConstraintOfConditionalType(type) : getBaseConstraintOfType(type);
            }
            function getConstraintOfTypeParameter(typeParameter) {
                return hasNonCircularBaseConstraint(typeParameter) ? getConstraintFromTypeParameter(typeParameter) : void 0;
            }
            function isConstTypeVariable(type) {
                var _a2;
                return !!(type.flags & 262144 /* TypeParameter */ && some((_a2 = type.symbol) == null ? void 0 : _a2.declarations, (d) => hasSyntacticModifier(d, 2048 /* Const */)) || isGenericTupleType(type) && findIndex(getTypeArguments(type), (t, i) => !!(type.target.elementFlags[i] & 8 /* Variadic */) && isConstTypeVariable(t)) >= 0 || type.flags & 8388608 /* IndexedAccess */ && isConstTypeVariable(type.objectType));
            }
            function getConstraintOfIndexedAccess(type) {
                return hasNonCircularBaseConstraint(type) ? getConstraintFromIndexedAccess(type) : void 0;
            }
            function getSimplifiedTypeOrConstraint(type) {
                const simplified = getSimplifiedType(type, 
                /*writing*/
                false);
                return simplified !== type ? simplified : getConstraintOfType(type);
            }
            function getConstraintFromIndexedAccess(type) {
                if (isMappedTypeGenericIndexedAccess(type)) {
                    return substituteIndexedMappedType(type.objectType, type.indexType);
                }
                const indexConstraint = getSimplifiedTypeOrConstraint(type.indexType);
                if (indexConstraint && indexConstraint !== type.indexType) {
                    const indexedAccess = getIndexedAccessTypeOrUndefined(type.objectType, indexConstraint, type.accessFlags);
                    if (indexedAccess) {
                        return indexedAccess;
                    }
                }
                const objectConstraint = getSimplifiedTypeOrConstraint(type.objectType);
                if (objectConstraint && objectConstraint !== type.objectType) {
                    return getIndexedAccessTypeOrUndefined(objectConstraint, type.indexType, type.accessFlags);
                }
                return void 0;
            }
            function getDefaultConstraintOfConditionalType(type) {
                if (!type.resolvedDefaultConstraint) {
                    const trueConstraint = getInferredTrueTypeFromConditionalType(type);
                    const falseConstraint = getFalseTypeFromConditionalType(type);
                    type.resolvedDefaultConstraint = isTypeAny(trueConstraint) ? falseConstraint : isTypeAny(falseConstraint) ? trueConstraint : getUnionType([trueConstraint, falseConstraint]);
                }
                return type.resolvedDefaultConstraint;
            }
            function getConstraintOfDistributiveConditionalType(type) {
                if (type.root.isDistributive && type.restrictiveInstantiation !== type) {
                    const simplified = getSimplifiedType(type.checkType, 
                    /*writing*/
                    false);
                    const constraint = simplified === type.checkType ? getConstraintOfType(simplified) : simplified;
                    if (constraint && constraint !== type.checkType) {
                        const instantiated = getConditionalTypeInstantiation(type, prependTypeMapping(type.root.checkType, constraint, type.mapper));
                        if (!(instantiated.flags & 131072 /* Never */)) {
                            return instantiated;
                        }
                    }
                }
                return void 0;
            }
            function getConstraintFromConditionalType(type) {
                return getConstraintOfDistributiveConditionalType(type) || getDefaultConstraintOfConditionalType(type);
            }
            function getConstraintOfConditionalType(type) {
                return hasNonCircularBaseConstraint(type) ? getConstraintFromConditionalType(type) : void 0;
            }
            function getEffectiveConstraintOfIntersection(types, targetIsUnion) {
                let constraints;
                let hasDisjointDomainType = false;
                for (const t of types) {
                    if (t.flags & 465829888 /* Instantiable */) {
                        let constraint = getConstraintOfType(t);
                        while (constraint && constraint.flags & (262144 /* TypeParameter */ | 4194304 /* Index */ | 16777216 /* Conditional */)) {
                            constraint = getConstraintOfType(constraint);
                        }
                        if (constraint) {
                            constraints = append(constraints, constraint);
                            if (targetIsUnion) {
                                constraints = append(constraints, t);
                            }
                        }
                    }
                    else if (t.flags & 469892092 /* DisjointDomains */ || isEmptyAnonymousObjectType(t)) {
                        hasDisjointDomainType = true;
                    }
                }
                if (constraints && (targetIsUnion || hasDisjointDomainType)) {
                    if (hasDisjointDomainType) {
                        for (const t of types) {
                            if (t.flags & 469892092 /* DisjointDomains */ || isEmptyAnonymousObjectType(t)) {
                                constraints = append(constraints, t);
                            }
                        }
                    }
                    return getNormalizedType(getIntersectionType(constraints), 
                    /*writing*/
                    false);
                }
                return void 0;
            }
            function getBaseConstraintOfType(type) {
                if (type.flags & (58982400 /* InstantiableNonPrimitive */ | 3145728 /* UnionOrIntersection */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */)) {
                    const constraint = getResolvedBaseConstraint(type);
                    return constraint !== noConstraintType && constraint !== circularConstraintType ? constraint : void 0;
                }
                return type.flags & 4194304 /* Index */ ? keyofConstraintType : void 0;
            }
            function getBaseConstraintOrType(type) {
                return getBaseConstraintOfType(type) || type;
            }
            function hasNonCircularBaseConstraint(type) {
                return getResolvedBaseConstraint(type) !== circularConstraintType;
            }
            function getResolvedBaseConstraint(type) {
                if (type.resolvedBaseConstraint) {
                    return type.resolvedBaseConstraint;
                }
                const stack = [];
                return type.resolvedBaseConstraint = getTypeWithThisArgument(getImmediateBaseConstraint(type), type);
                function getImmediateBaseConstraint(t) {
                    if (!t.immediateBaseConstraint) {
                        if (!pushTypeResolution(t, 4 /* ImmediateBaseConstraint */)) {
                            return circularConstraintType;
                        }
                        let result;
                        const identity2 = getRecursionIdentity(t);
                        if (stack.length < 10 || stack.length < 50 && !contains(stack, identity2)) {
                            stack.push(identity2);
                            result = computeBaseConstraint(getSimplifiedType(t, 
                            /*writing*/
                            false));
                            stack.pop();
                        }
                        if (!popTypeResolution()) {
                            if (t.flags & 262144 /* TypeParameter */) {
                                const errorNode = getConstraintDeclaration(t);
                                if (errorNode) {
                                    const diagnostic = error(errorNode, Diagnostics.Type_parameter_0_has_a_circular_constraint, typeToString(t));
                                    if (currentNode && !isNodeDescendantOf(errorNode, currentNode) && !isNodeDescendantOf(currentNode, errorNode)) {
                                        addRelatedInfo(diagnostic, createDiagnosticForNode(currentNode, Diagnostics.Circularity_originates_in_type_at_this_location));
                                    }
                                }
                            }
                            result = circularConstraintType;
                        }
                        t.immediateBaseConstraint = result || noConstraintType;
                    }
                    return t.immediateBaseConstraint;
                }
                function getBaseConstraint(t) {
                    const c = getImmediateBaseConstraint(t);
                    return c !== noConstraintType && c !== circularConstraintType ? c : void 0;
                }
                function computeBaseConstraint(t) {
                    if (t.flags & 262144 /* TypeParameter */) {
                        const constraint = getConstraintFromTypeParameter(t);
                        return t.isThisType || !constraint ? constraint : getBaseConstraint(constraint);
                    }
                    if (t.flags & 3145728 /* UnionOrIntersection */) {
                        const types = t.types;
                        const baseTypes = [];
                        let different = false;
                        for (const type2 of types) {
                            const baseType = getBaseConstraint(type2);
                            if (baseType) {
                                if (baseType !== type2) {
                                    different = true;
                                }
                                baseTypes.push(baseType);
                            }
                            else {
                                different = true;
                            }
                        }
                        if (!different) {
                            return t;
                        }
                        return t.flags & 1048576 /* Union */ && baseTypes.length === types.length ? getUnionType(baseTypes) : t.flags & 2097152 /* Intersection */ && baseTypes.length ? getIntersectionType(baseTypes) : void 0;
                    }
                    if (t.flags & 4194304 /* Index */) {
                        return keyofConstraintType;
                    }
                    if (t.flags & 134217728 /* TemplateLiteral */) {
                        const types = t.types;
                        const constraints = mapDefined(types, getBaseConstraint);
                        return constraints.length === types.length ? getTemplateLiteralType(t.texts, constraints) : stringType;
                    }
                    if (t.flags & 268435456 /* StringMapping */) {
                        const constraint = getBaseConstraint(t.type);
                        return constraint && constraint !== t.type ? getStringMappingType(t.symbol, constraint) : stringType;
                    }
                    if (t.flags & 8388608 /* IndexedAccess */) {
                        if (isMappedTypeGenericIndexedAccess(t)) {
                            return getBaseConstraint(substituteIndexedMappedType(t.objectType, t.indexType));
                        }
                        const baseObjectType = getBaseConstraint(t.objectType);
                        const baseIndexType = getBaseConstraint(t.indexType);
                        const baseIndexedAccess = baseObjectType && baseIndexType && getIndexedAccessTypeOrUndefined(baseObjectType, baseIndexType, t.accessFlags);
                        return baseIndexedAccess && getBaseConstraint(baseIndexedAccess);
                    }
                    if (t.flags & 16777216 /* Conditional */) {
                        const constraint = getConstraintFromConditionalType(t);
                        return constraint && getBaseConstraint(constraint);
                    }
                    if (t.flags & 33554432 /* Substitution */) {
                        return getBaseConstraint(getSubstitutionIntersection(t));
                    }
                    return t;
                }
            }
            function getApparentTypeOfIntersectionType(type) {
                return type.resolvedApparentType || (type.resolvedApparentType = getTypeWithThisArgument(type, type, 
                /*apparentType*/
                true));
            }
            function getResolvedTypeParameterDefault(typeParameter) {
                if (!typeParameter.default) {
                    if (typeParameter.target) {
                        const targetDefault = getResolvedTypeParameterDefault(typeParameter.target);
                        typeParameter.default = targetDefault ? instantiateType(targetDefault, typeParameter.mapper) : noConstraintType;
                    }
                    else {
                        typeParameter.default = resolvingDefaultType;
                        const defaultDeclaration = typeParameter.symbol && forEach(typeParameter.symbol.declarations, (decl) => isTypeParameterDeclaration(decl) && decl.default);
                        const defaultType = defaultDeclaration ? getTypeFromTypeNode(defaultDeclaration) : noConstraintType;
                        if (typeParameter.default === resolvingDefaultType) {
                            typeParameter.default = defaultType;
                        }
                    }
                }
                else if (typeParameter.default === resolvingDefaultType) {
                    typeParameter.default = circularConstraintType;
                }
                return typeParameter.default;
            }
            function getDefaultFromTypeParameter(typeParameter) {
                const defaultType = getResolvedTypeParameterDefault(typeParameter);
                return defaultType !== noConstraintType && defaultType !== circularConstraintType ? defaultType : void 0;
            }
            function hasNonCircularTypeParameterDefault(typeParameter) {
                return getResolvedTypeParameterDefault(typeParameter) !== circularConstraintType;
            }
            function hasTypeParameterDefault(typeParameter) {
                return !!(typeParameter.symbol && forEach(typeParameter.symbol.declarations, (decl) => isTypeParameterDeclaration(decl) && decl.default));
            }
            function getApparentTypeOfMappedType(type) {
                return type.resolvedApparentType || (type.resolvedApparentType = getResolvedApparentTypeOfMappedType(type));
            }
            function getResolvedApparentTypeOfMappedType(type) {
                const typeVariable = getHomomorphicTypeVariable(type);
                if (typeVariable && !type.declaration.nameType) {
                    const constraint = getConstraintOfTypeParameter(typeVariable);
                    if (constraint && isArrayOrTupleType(constraint)) {
                        return instantiateType(type, prependTypeMapping(typeVariable, constraint, type.mapper));
                    }
                }
                return type;
            }
            function isMappedTypeGenericIndexedAccess(type) {
                let objectType;
                return !!(type.flags & 8388608 /* IndexedAccess */ && getObjectFlags(objectType = type.objectType) & 32 /* Mapped */ && !isGenericMappedType(objectType) && isGenericIndexType(type.indexType) && !(getMappedTypeModifiers(objectType) & 8 /* ExcludeOptional */) && !objectType.declaration.nameType);
            }
            function getApparentType(type) {
                const t = !(type.flags & 465829888 /* Instantiable */) ? type : getBaseConstraintOfType(type) || unknownType;
                return getObjectFlags(t) & 32 /* Mapped */ ? getApparentTypeOfMappedType(t) : t.flags & 2097152 /* Intersection */ ? getApparentTypeOfIntersectionType(t) : t.flags & 402653316 /* StringLike */ ? globalStringType : t.flags & 296 /* NumberLike */ ? globalNumberType : t.flags & 2112 /* BigIntLike */ ? getGlobalBigIntType() : t.flags & 528 /* BooleanLike */ ? globalBooleanType : t.flags & 12288 /* ESSymbolLike */ ? getGlobalESSymbolType() : t.flags & 67108864 /* NonPrimitive */ ? emptyObjectType : t.flags & 4194304 /* Index */ ? keyofConstraintType : t.flags & 2 /* Unknown */ && !strictNullChecks ? emptyObjectType : t;
            }
            function getReducedApparentType(type) {
                return getReducedType(getApparentType(getReducedType(type)));
            }
            function createUnionOrIntersectionProperty(containingType, name, skipObjectFunctionPropertyAugment) {
                var _a2, _b, _c;
                let singleProp;
                let propSet;
                let indexTypes;
                const isUnion = containingType.flags & 1048576 /* Union */;
                let optionalFlag;
                let syntheticFlag = 4 /* SyntheticMethod */;
                let checkFlags = isUnion ? 0 : 8 /* Readonly */;
                let mergedInstantiations = false;
                for (const current of containingType.types) {
                    const type = getApparentType(current);
                    if (!(isErrorType(type) || type.flags & 131072 /* Never */)) {
                        const prop = getPropertyOfType(type, name, skipObjectFunctionPropertyAugment);
                        const modifiers = prop ? getDeclarationModifierFlagsFromSymbol(prop) : 0;
                        if (prop) {
                            if (prop.flags & 106500 /* ClassMember */) {
                                optionalFlag != null ? optionalFlag : optionalFlag = isUnion ? 0 /* None */ : 16777216 /* Optional */;
                                if (isUnion) {
                                    optionalFlag |= prop.flags & 16777216 /* Optional */;
                                }
                                else {
                                    optionalFlag &= prop.flags;
                                }
                            }
                            if (!singleProp) {
                                singleProp = prop;
                            }
                            else if (prop !== singleProp) {
                                const isInstantiation = (getTargetSymbol(prop) || prop) === (getTargetSymbol(singleProp) || singleProp);
                                if (isInstantiation && compareProperties2(singleProp, prop, (a, b) => a === b ? -1 /* True */ : 0 /* False */) === -1 /* True */) {
                                    mergedInstantiations = !!singleProp.parent && !!length(getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(singleProp.parent));
                                }
                                else {
                                    if (!propSet) {
                                        propSet = /* @__PURE__ */ new Map();
                                        propSet.set(getSymbolId(singleProp), singleProp);
                                    }
                                    const id = getSymbolId(prop);
                                    if (!propSet.has(id)) {
                                        propSet.set(id, prop);
                                    }
                                }
                            }
                            if (isUnion && isReadonlySymbol(prop)) {
                                checkFlags |= 8 /* Readonly */;
                            }
                            else if (!isUnion && !isReadonlySymbol(prop)) {
                                checkFlags &= ~8 /* Readonly */;
                            }
                            checkFlags |= (!(modifiers & 24 /* NonPublicAccessibilityModifier */) ? 256 /* ContainsPublic */ : 0) | (modifiers & 16 /* Protected */ ? 512 /* ContainsProtected */ : 0) | (modifiers & 8 /* Private */ ? 1024 /* ContainsPrivate */ : 0) | (modifiers & 32 /* Static */ ? 2048 /* ContainsStatic */ : 0);
                            if (!isPrototypeProperty(prop)) {
                                syntheticFlag = 2 /* SyntheticProperty */;
                            }
                        }
                        else if (isUnion) {
                            const indexInfo = !isLateBoundName(name) && getApplicableIndexInfoForName(type, name);
                            if (indexInfo) {
                                checkFlags |= 32 /* WritePartial */ | (indexInfo.isReadonly ? 8 /* Readonly */ : 0);
                                indexTypes = append(indexTypes, isTupleType(type) ? getRestTypeOfTupleType(type) || undefinedType : indexInfo.type);
                            }
                            else if (isObjectLiteralType2(type) && !(getObjectFlags(type) & 2097152 /* ContainsSpread */)) {
                                checkFlags |= 32 /* WritePartial */;
                                indexTypes = append(indexTypes, undefinedType);
                            }
                            else {
                                checkFlags |= 16 /* ReadPartial */;
                            }
                        }
                    }
                }
                if (!singleProp || isUnion && (propSet || checkFlags & 48 /* Partial */) && checkFlags & (1024 /* ContainsPrivate */ | 512 /* ContainsProtected */) && !(propSet && getCommonDeclarationsOfSymbols(propSet.values()))) {
                    return void 0;
                }
                if (!propSet && !(checkFlags & 16 /* ReadPartial */) && !indexTypes) {
                    if (mergedInstantiations) {
                        const links = (_a2 = tryCast(singleProp, isTransientSymbol)) == null ? void 0 : _a2.links;
                        const clone2 = createSymbolWithType(singleProp, links == null ? void 0 : links.type);
                        clone2.parent = (_c = (_b = singleProp.valueDeclaration) == null ? void 0 : _b.symbol) == null ? void 0 : _c.parent;
                        clone2.links.containingType = containingType;
                        clone2.links.mapper = links == null ? void 0 : links.mapper;
                        return clone2;
                    }
                    else {
                        return singleProp;
                    }
                }
                const props = propSet ? arrayFrom(propSet.values()) : [singleProp];
                let declarations;
                let firstType;
                let nameType;
                const propTypes = [];
                let writeTypes;
                let firstValueDeclaration;
                let hasNonUniformValueDeclaration = false;
                for (const prop of props) {
                    if (!firstValueDeclaration) {
                        firstValueDeclaration = prop.valueDeclaration;
                    }
                    else if (prop.valueDeclaration && prop.valueDeclaration !== firstValueDeclaration) {
                        hasNonUniformValueDeclaration = true;
                    }
                    declarations = addRange(declarations, prop.declarations);
                    const type = getTypeOfSymbol(prop);
                    if (!firstType) {
                        firstType = type;
                        nameType = getSymbolLinks(prop).nameType;
                    }
                    const writeType = getWriteTypeOfSymbol(prop);
                    if (writeTypes || writeType !== type) {
                        writeTypes = append(!writeTypes ? propTypes.slice() : writeTypes, writeType);
                    }
                    else if (type !== firstType) {
                        checkFlags |= 64 /* HasNonUniformType */;
                    }
                    if (isLiteralType(type) || isPatternLiteralType(type) || type === uniqueLiteralType) {
                        checkFlags |= 128 /* HasLiteralType */;
                    }
                    if (type.flags & 131072 /* Never */ && type !== uniqueLiteralType) {
                        checkFlags |= 131072 /* HasNeverType */;
                    }
                    propTypes.push(type);
                }
                addRange(propTypes, indexTypes);
                const result = createSymbol(4 /* Property */ | (optionalFlag != null ? optionalFlag : 0), name, syntheticFlag | checkFlags);
                result.links.containingType = containingType;
                if (!hasNonUniformValueDeclaration && firstValueDeclaration) {
                    result.valueDeclaration = firstValueDeclaration;
                    if (firstValueDeclaration.symbol.parent) {
                        result.parent = firstValueDeclaration.symbol.parent;
                    }
                }
                result.declarations = declarations;
                result.links.nameType = nameType;
                if (propTypes.length > 2) {
                    result.links.checkFlags |= 65536 /* DeferredType */;
                    result.links.deferralParent = containingType;
                    result.links.deferralConstituents = propTypes;
                    result.links.deferralWriteConstituents = writeTypes;
                }
                else {
                    result.links.type = isUnion ? getUnionType(propTypes) : getIntersectionType(propTypes);
                    if (writeTypes) {
                        result.links.writeType = isUnion ? getUnionType(writeTypes) : getIntersectionType(writeTypes);
                    }
                }
                return result;
            }
            function getUnionOrIntersectionProperty(type, name, skipObjectFunctionPropertyAugment) {
                var _a2, _b;
                let property = ((_a2 = type.propertyCacheWithoutObjectFunctionPropertyAugment) == null ? void 0 : _a2.get(name)) || !skipObjectFunctionPropertyAugment ? (_b = type.propertyCache) == null ? void 0 : _b.get(name) : void 0;
                if (!property) {
                    property = createUnionOrIntersectionProperty(type, name, skipObjectFunctionPropertyAugment);
                    if (property) {
                        const properties = skipObjectFunctionPropertyAugment ? type.propertyCacheWithoutObjectFunctionPropertyAugment || (type.propertyCacheWithoutObjectFunctionPropertyAugment = createSymbolTable()) : type.propertyCache || (type.propertyCache = createSymbolTable());
                        properties.set(name, property);
                    }
                }
                return property;
            }
            function getCommonDeclarationsOfSymbols(symbols) {
                let commonDeclarations;
                for (const symbol of symbols) {
                    if (!symbol.declarations) {
                        return void 0;
                    }
                    if (!commonDeclarations) {
                        commonDeclarations = new Set(symbol.declarations);
                        continue;
                    }
                    commonDeclarations.forEach((declaration) => {
                        if (!contains(symbol.declarations, declaration)) {
                            commonDeclarations.delete(declaration);
                        }
                    });
                    if (commonDeclarations.size === 0) {
                        return void 0;
                    }
                }
                return commonDeclarations;
            }
            function getPropertyOfUnionOrIntersectionType(type, name, skipObjectFunctionPropertyAugment) {
                const property = getUnionOrIntersectionProperty(type, name, skipObjectFunctionPropertyAugment);
                return property && !(getCheckFlags(property) & 16 /* ReadPartial */) ? property : void 0;
            }
            function getReducedType(type) {
                if (type.flags & 1048576 /* Union */ && type.objectFlags & 16777216 /* ContainsIntersections */) {
                    return type.resolvedReducedType || (type.resolvedReducedType = getReducedUnionType(type));
                }
                else if (type.flags & 2097152 /* Intersection */) {
                    if (!(type.objectFlags & 16777216 /* IsNeverIntersectionComputed */)) {
                        type.objectFlags |= 16777216 /* IsNeverIntersectionComputed */ | (some(getPropertiesOfUnionOrIntersectionType(type), isNeverReducedProperty) ? 33554432 /* IsNeverIntersection */ : 0);
                    }
                    return type.objectFlags & 33554432 /* IsNeverIntersection */ ? neverType : type;
                }
                return type;
            }
            function getReducedUnionType(unionType) {
                const reducedTypes = sameMap(unionType.types, getReducedType);
                if (reducedTypes === unionType.types) {
                    return unionType;
                }
                const reduced = getUnionType(reducedTypes);
                if (reduced.flags & 1048576 /* Union */) {
                    reduced.resolvedReducedType = reduced;
                }
                return reduced;
            }
            function isNeverReducedProperty(prop) {
                return isDiscriminantWithNeverType(prop) || isConflictingPrivateProperty(prop);
            }
            function isDiscriminantWithNeverType(prop) {
                return !(prop.flags & 16777216 /* Optional */) && (getCheckFlags(prop) & (192 /* Discriminant */ | 131072 /* HasNeverType */)) === 192 /* Discriminant */ && !!(getTypeOfSymbol(prop).flags & 131072 /* Never */);
            }
            function isConflictingPrivateProperty(prop) {
                return !prop.valueDeclaration && !!(getCheckFlags(prop) & 1024 /* ContainsPrivate */);
            }
            function elaborateNeverIntersection(errorInfo, type) {
                if (type.flags & 2097152 /* Intersection */ && getObjectFlags(type) & 33554432 /* IsNeverIntersection */) {
                    const neverProp = find(getPropertiesOfUnionOrIntersectionType(type), isDiscriminantWithNeverType);
                    if (neverProp) {
                        return chainDiagnosticMessages(errorInfo, Diagnostics.The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituents, typeToString(type, 
                        /*enclosingDeclaration*/
                        void 0, 536870912 /* NoTypeReduction */), symbolToString(neverProp));
                    }
                    const privateProp = find(getPropertiesOfUnionOrIntersectionType(type), isConflictingPrivateProperty);
                    if (privateProp) {
                        return chainDiagnosticMessages(errorInfo, Diagnostics.The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_private_in_some, typeToString(type, 
                        /*enclosingDeclaration*/
                        void 0, 536870912 /* NoTypeReduction */), symbolToString(privateProp));
                    }
                }
                return errorInfo;
            }
            function getPropertyOfType(type, name, skipObjectFunctionPropertyAugment, includeTypeOnlyMembers) {
                type = getReducedApparentType(type);
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    const symbol = resolved.members.get(name);
                    if (symbol && symbolIsValue(symbol, includeTypeOnlyMembers)) {
                        return symbol;
                    }
                    if (skipObjectFunctionPropertyAugment)
                        return void 0;
                    const functionType = resolved === anyFunctionType ? globalFunctionType : resolved.callSignatures.length ? globalCallableFunctionType : resolved.constructSignatures.length ? globalNewableFunctionType : void 0;
                    if (functionType) {
                        const symbol2 = getPropertyOfObjectType(functionType, name);
                        if (symbol2) {
                            return symbol2;
                        }
                    }
                    return getPropertyOfObjectType(globalObjectType, name);
                }
                if (type.flags & 3145728 /* UnionOrIntersection */) {
                    return getPropertyOfUnionOrIntersectionType(type, name, skipObjectFunctionPropertyAugment);
                }
                return void 0;
            }
            function getSignaturesOfStructuredType(type, kind) {
                if (type.flags & 3670016 /* StructuredType */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    return kind === 0 /* Call */ ? resolved.callSignatures : resolved.constructSignatures;
                }
                return emptyArray;
            }
            function getSignaturesOfType(type, kind) {
                return getSignaturesOfStructuredType(getReducedApparentType(type), kind);
            }
            function findIndexInfo(indexInfos, keyType) {
                return find(indexInfos, (info) => info.keyType === keyType);
            }
            function findApplicableIndexInfo(indexInfos, keyType) {
                let stringIndexInfo;
                let applicableInfo;
                let applicableInfos;
                for (const info of indexInfos) {
                    if (info.keyType === stringType) {
                        stringIndexInfo = info;
                    }
                    else if (isApplicableIndexType(keyType, info.keyType)) {
                        if (!applicableInfo) {
                            applicableInfo = info;
                        }
                        else {
                            (applicableInfos || (applicableInfos = [applicableInfo])).push(info);
                        }
                    }
                }
                return applicableInfos ? createIndexInfo(unknownType, getIntersectionType(map(applicableInfos, (info) => info.type)), reduceLeft(applicableInfos, (isReadonly, info) => isReadonly && info.isReadonly, 
                /*initial*/
                true)) : applicableInfo ? applicableInfo : stringIndexInfo && isApplicableIndexType(keyType, stringType) ? stringIndexInfo : void 0;
            }
            function isApplicableIndexType(source, target) {
                return isTypeAssignableTo(source, target) || target === stringType && isTypeAssignableTo(source, numberType) || target === numberType && (source === numericStringType || !!(source.flags & 128 /* StringLiteral */) && isNumericLiteralName(source.value));
            }
            function getIndexInfosOfStructuredType(type) {
                if (type.flags & 3670016 /* StructuredType */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    return resolved.indexInfos;
                }
                return emptyArray;
            }
            function getIndexInfosOfType(type) {
                return getIndexInfosOfStructuredType(getReducedApparentType(type));
            }
            function getIndexInfoOfType(type, keyType) {
                return findIndexInfo(getIndexInfosOfType(type), keyType);
            }
            function getIndexTypeOfType(type, keyType) {
                var _a2;
                return (_a2 = getIndexInfoOfType(type, keyType)) == null ? void 0 : _a2.type;
            }
            function getApplicableIndexInfos(type, keyType) {
                return getIndexInfosOfType(type).filter((info) => isApplicableIndexType(keyType, info.keyType));
            }
            function getApplicableIndexInfo(type, keyType) {
                return findApplicableIndexInfo(getIndexInfosOfType(type), keyType);
            }
            function getApplicableIndexInfoForName(type, name) {
                return getApplicableIndexInfo(type, isLateBoundName(name) ? esSymbolType : getStringLiteralType(unescapeLeadingUnderscores(name)));
            }
            function getTypeParametersFromDeclaration(declaration) {
                var _a2;
                let result;
                for (const node of getEffectiveTypeParameterDeclarations(declaration)) {
                    result = appendIfUnique(result, getDeclaredTypeOfTypeParameter(node.symbol));
                }
                return (result == null ? void 0 : result.length) ? result : isFunctionDeclaration(declaration) ? (_a2 = getSignatureOfTypeTag(declaration)) == null ? void 0 : _a2.typeParameters : void 0;
            }
            function symbolsToArray(symbols) {
                const result = [];
                symbols.forEach((symbol, id) => {
                    if (!isReservedMemberName(id)) {
                        result.push(symbol);
                    }
                });
                return result;
            }
            function tryFindAmbientModule(moduleName, withAugmentations) {
                if (isExternalModuleNameRelative(moduleName)) {
                    return void 0;
                }
                const symbol = getSymbol2(globals, '"' + moduleName + '"', 512 /* ValueModule */);
                return symbol && withAugmentations ? getMergedSymbol(symbol) : symbol;
            }
            function isOptionalParameter(node) {
                if (hasQuestionToken(node) || isOptionalJSDocPropertyLikeTag(node) || isJSDocOptionalParameter(node)) {
                    return true;
                }
                if (node.initializer) {
                    const signature = getSignatureFromDeclaration(node.parent);
                    const parameterIndex = node.parent.parameters.indexOf(node);
                    Debug.assert(parameterIndex >= 0);
                    return parameterIndex >= getMinArgumentCount(signature, 1 /* StrongArityForUntypedJS */ | 2 /* VoidIsNonOptional */);
                }
                const iife = getImmediatelyInvokedFunctionExpression(node.parent);
                if (iife) {
                    return !node.type && !node.dotDotDotToken && node.parent.parameters.indexOf(node) >= iife.arguments.length;
                }
                return false;
            }
            function isOptionalPropertyDeclaration(node) {
                return isPropertyDeclaration(node) && !hasAccessorModifier(node) && node.questionToken;
            }
            function createTypePredicate(kind, parameterName, parameterIndex, type) {
                return { kind, parameterName, parameterIndex, type };
            }
            function getMinTypeArgumentCount(typeParameters) {
                let minTypeArgumentCount = 0;
                if (typeParameters) {
                    for (let i = 0; i < typeParameters.length; i++) {
                        if (!hasTypeParameterDefault(typeParameters[i])) {
                            minTypeArgumentCount = i + 1;
                        }
                    }
                }
                return minTypeArgumentCount;
            }
            function fillMissingTypeArguments(typeArguments, typeParameters, minTypeArgumentCount, isJavaScriptImplicitAny) {
                const numTypeParameters = length(typeParameters);
                if (!numTypeParameters) {
                    return [];
                }
                const numTypeArguments = length(typeArguments);
                if (isJavaScriptImplicitAny || numTypeArguments >= minTypeArgumentCount && numTypeArguments <= numTypeParameters) {
                    const result = typeArguments ? typeArguments.slice() : [];
                    for (let i = numTypeArguments; i < numTypeParameters; i++) {
                        result[i] = errorType;
                    }
                    const baseDefaultType = getDefaultTypeArgumentType(isJavaScriptImplicitAny);
                    for (let i = numTypeArguments; i < numTypeParameters; i++) {
                        let defaultType = getDefaultFromTypeParameter(typeParameters[i]);
                        if (isJavaScriptImplicitAny && defaultType && (isTypeIdenticalTo(defaultType, unknownType) || isTypeIdenticalTo(defaultType, emptyObjectType))) {
                            defaultType = anyType;
                        }
                        result[i] = defaultType ? instantiateType(defaultType, createTypeMapper(typeParameters, result)) : baseDefaultType;
                    }
                    result.length = typeParameters.length;
                    return result;
                }
                return typeArguments && typeArguments.slice();
            }
            function getSignatureFromDeclaration(declaration) {
                const links = getNodeLinks(declaration);
                if (!links.resolvedSignature) {
                    const parameters = [];
                    let flags = 0 /* None */;
                    let minArgumentCount = 0;
                    let thisParameter;
                    let hasThisParameter2 = false;
                    const iife = getImmediatelyInvokedFunctionExpression(declaration);
                    const isJSConstructSignature = isJSDocConstructSignature(declaration);
                    const isUntypedSignatureInJSFile = !iife && isInJSFile(declaration) && isValueSignatureDeclaration(declaration) && !hasJSDocParameterTags(declaration) && !getJSDocType(declaration);
                    if (isUntypedSignatureInJSFile) {
                        flags |= 32 /* IsUntypedSignatureInJSFile */;
                    }
                    for (let i = isJSConstructSignature ? 1 : 0; i < declaration.parameters.length; i++) {
                        const param = declaration.parameters[i];
                        let paramSymbol = param.symbol;
                        const type = isJSDocParameterTag(param) ? param.typeExpression && param.typeExpression.type : param.type;
                        if (paramSymbol && !!(paramSymbol.flags & 4 /* Property */) && !isBindingPattern(param.name)) {
                            const resolvedSymbol = resolveName(param, paramSymbol.escapedName, 111551 /* Value */, void 0, void 0, 
                            /*isUse*/
                            false);
                            paramSymbol = resolvedSymbol;
                        }
                        if (i === 0 && paramSymbol.escapedName === "this" /* This */) {
                            hasThisParameter2 = true;
                            thisParameter = param.symbol;
                        }
                        else {
                            parameters.push(paramSymbol);
                        }
                        if (type && type.kind === 198 /* LiteralType */) {
                            flags |= 2 /* HasLiteralTypes */;
                        }
                        const isOptionalParameter2 = isOptionalJSDocPropertyLikeTag(param) || param.initializer || param.questionToken || isRestParameter(param) || iife && parameters.length > iife.arguments.length && !type || isJSDocOptionalParameter(param);
                        if (!isOptionalParameter2) {
                            minArgumentCount = parameters.length;
                        }
                    }
                    if ((declaration.kind === 174 /* GetAccessor */ || declaration.kind === 175 /* SetAccessor */) && hasBindableName(declaration) && (!hasThisParameter2 || !thisParameter)) {
                        const otherKind = declaration.kind === 174 /* GetAccessor */ ? 175 /* SetAccessor */ : 174 /* GetAccessor */;
                        const other = getDeclarationOfKind(getSymbolOfDeclaration(declaration), otherKind);
                        if (other) {
                            thisParameter = getAnnotatedAccessorThisParameter(other);
                        }
                    }
                    if (isInJSFile(declaration)) {
                        const thisTag = getJSDocThisTag(declaration);
                        if (thisTag && thisTag.typeExpression) {
                            thisParameter = createSymbolWithType(createSymbol(1 /* FunctionScopedVariable */, "this" /* This */), getTypeFromTypeNode(thisTag.typeExpression));
                        }
                    }
                    const classType = declaration.kind === 173 /* Constructor */ ? getDeclaredTypeOfClassOrInterface(getMergedSymbol(declaration.parent.symbol)) : void 0;
                    const typeParameters = classType ? classType.localTypeParameters : getTypeParametersFromDeclaration(declaration);
                    if (hasRestParameter(declaration) || isInJSFile(declaration) && maybeAddJsSyntheticRestParameter(declaration, parameters)) {
                        flags |= 1 /* HasRestParameter */;
                    }
                    if (isConstructorTypeNode(declaration) && hasSyntacticModifier(declaration, 256 /* Abstract */) || isConstructorDeclaration(declaration) && hasSyntacticModifier(declaration.parent, 256 /* Abstract */)) {
                        flags |= 4 /* Abstract */;
                    }
                    links.resolvedSignature = createSignature(declaration, typeParameters, thisParameter, parameters, 
                    /*resolvedReturnType*/
                    void 0, 
                    /*resolvedTypePredicate*/
                    void 0, minArgumentCount, flags);
                }
                return links.resolvedSignature;
            }
            function maybeAddJsSyntheticRestParameter(declaration, parameters) {
                if (isJSDocSignature(declaration) || !containsArgumentsReference(declaration)) {
                    return false;
                }
                const lastParam = lastOrUndefined(declaration.parameters);
                const lastParamTags = lastParam ? getJSDocParameterTags(lastParam) : getJSDocTags(declaration).filter(isJSDocParameterTag);
                const lastParamVariadicType = firstDefined(lastParamTags, (p) => p.typeExpression && isJSDocVariadicType(p.typeExpression.type) ? p.typeExpression.type : void 0);
                const syntheticArgsSymbol = createSymbol(3 /* Variable */, "args", 32768 /* RestParameter */);
                if (lastParamVariadicType) {
                    syntheticArgsSymbol.links.type = createArrayType(getTypeFromTypeNode(lastParamVariadicType.type));
                }
                else {
                    syntheticArgsSymbol.links.checkFlags |= 65536 /* DeferredType */;
                    syntheticArgsSymbol.links.deferralParent = neverType;
                    syntheticArgsSymbol.links.deferralConstituents = [anyArrayType];
                    syntheticArgsSymbol.links.deferralWriteConstituents = [anyArrayType];
                }
                if (lastParamVariadicType) {
                    parameters.pop();
                }
                parameters.push(syntheticArgsSymbol);
                return true;
            }
            function getSignatureOfTypeTag(node) {
                if (!(isInJSFile(node) && isFunctionLikeDeclaration(node)))
                    return void 0;
                const typeTag = getJSDocTypeTag(node);
                return (typeTag == null ? void 0 : typeTag.typeExpression) && getSingleCallSignature(getTypeFromTypeNode(typeTag.typeExpression));
            }
            function getParameterTypeOfTypeTag(func, parameter) {
                const signature = getSignatureOfTypeTag(func);
                if (!signature)
                    return void 0;
                const pos = func.parameters.indexOf(parameter);
                return parameter.dotDotDotToken ? getRestTypeAtPosition(signature, pos) : getTypeAtPosition(signature, pos);
            }
            function getReturnTypeOfTypeTag(node) {
                const signature = getSignatureOfTypeTag(node);
                return signature && getReturnTypeOfSignature(signature);
            }
            function containsArgumentsReference(declaration) {
                const links = getNodeLinks(declaration);
                if (links.containsArgumentsReference === void 0) {
                    if (links.flags & 512 /* CaptureArguments */) {
                        links.containsArgumentsReference = true;
                    }
                    else {
                        links.containsArgumentsReference = traverse(declaration.body);
                    }
                }
                return links.containsArgumentsReference;
                function traverse(node) {
                    if (!node)
                        return false;
                    switch (node.kind) {
                        case 79 /* Identifier */:
                            return node.escapedText === argumentsSymbol.escapedName && getReferencedValueSymbol(node) === argumentsSymbol;
                        case 169 /* PropertyDeclaration */:
                        case 171 /* MethodDeclaration */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            return node.name.kind === 164 /* ComputedPropertyName */ && traverse(node.name);
                        case 208 /* PropertyAccessExpression */:
                        case 209 /* ElementAccessExpression */:
                            return traverse(node.expression);
                        case 299 /* PropertyAssignment */:
                            return traverse(node.initializer);
                        default:
                            return !nodeStartsNewLexicalEnvironment(node) && !isPartOfTypeNode(node) && !!forEachChild(node, traverse);
                    }
                }
            }
            function getSignaturesOfSymbol(symbol) {
                if (!symbol || !symbol.declarations)
                    return emptyArray;
                const result = [];
                for (let i = 0; i < symbol.declarations.length; i++) {
                    const decl = symbol.declarations[i];
                    if (!isFunctionLike(decl))
                        continue;
                    if (i > 0 && decl.body) {
                        const previous = symbol.declarations[i - 1];
                        if (decl.parent === previous.parent && decl.kind === previous.kind && decl.pos === previous.end) {
                            continue;
                        }
                    }
                    if (isInJSFile(decl) && decl.jsDoc) {
                        let hasJSDocOverloads = false;
                        for (const node of decl.jsDoc) {
                            if (node.tags) {
                                for (const tag of node.tags) {
                                    if (isJSDocOverloadTag(tag)) {
                                        const jsDocSignature = tag.typeExpression;
                                        if (jsDocSignature.type === void 0 && !isConstructorDeclaration(decl)) {
                                            reportImplicitAny(jsDocSignature, anyType);
                                        }
                                        result.push(getSignatureFromDeclaration(jsDocSignature));
                                        hasJSDocOverloads = true;
                                    }
                                }
                            }
                        }
                        if (hasJSDocOverloads) {
                            continue;
                        }
                    }
                    result.push(!isFunctionExpressionOrArrowFunction(decl) && !isObjectLiteralMethod(decl) && getSignatureOfTypeTag(decl) || getSignatureFromDeclaration(decl));
                }
                return result;
            }
            function resolveExternalModuleTypeByLiteral(name) {
                const moduleSym = resolveExternalModuleName(name, name);
                if (moduleSym) {
                    const resolvedModuleSymbol = resolveExternalModuleSymbol(moduleSym);
                    if (resolvedModuleSymbol) {
                        return getTypeOfSymbol(resolvedModuleSymbol);
                    }
                }
                return anyType;
            }
            function getThisTypeOfSignature(signature) {
                if (signature.thisParameter) {
                    return getTypeOfSymbol(signature.thisParameter);
                }
            }
            function getTypePredicateOfSignature(signature) {
                if (!signature.resolvedTypePredicate) {
                    if (signature.target) {
                        const targetTypePredicate = getTypePredicateOfSignature(signature.target);
                        signature.resolvedTypePredicate = targetTypePredicate ? instantiateTypePredicate(targetTypePredicate, signature.mapper) : noTypePredicate;
                    }
                    else if (signature.compositeSignatures) {
                        signature.resolvedTypePredicate = getUnionOrIntersectionTypePredicate(signature.compositeSignatures, signature.compositeKind) || noTypePredicate;
                    }
                    else {
                        const type = signature.declaration && getEffectiveReturnTypeNode(signature.declaration);
                        let jsdocPredicate;
                        if (!type) {
                            const jsdocSignature = getSignatureOfTypeTag(signature.declaration);
                            if (jsdocSignature && signature !== jsdocSignature) {
                                jsdocPredicate = getTypePredicateOfSignature(jsdocSignature);
                            }
                        }
                        signature.resolvedTypePredicate = type && isTypePredicateNode(type) ? createTypePredicateFromTypePredicateNode(type, signature) : jsdocPredicate || noTypePredicate;
                    }
                    Debug.assert(!!signature.resolvedTypePredicate);
                }
                return signature.resolvedTypePredicate === noTypePredicate ? void 0 : signature.resolvedTypePredicate;
            }
            function createTypePredicateFromTypePredicateNode(node, signature) {
                const parameterName = node.parameterName;
                const type = node.type && getTypeFromTypeNode(node.type);
                return parameterName.kind === 194 /* ThisType */ ? createTypePredicate(node.assertsModifier ? 2 /* AssertsThis */ : 0 /* This */, 
                /*parameterName*/
                void 0, 
                /*parameterIndex*/
                void 0, type) : createTypePredicate(node.assertsModifier ? 3 /* AssertsIdentifier */ : 1 /* Identifier */, parameterName.escapedText, findIndex(signature.parameters, (p) => p.escapedName === parameterName.escapedText), type);
            }
            function getUnionOrIntersectionType(types, kind, unionReduction) {
                return kind !== 2097152 /* Intersection */ ? getUnionType(types, unionReduction) : getIntersectionType(types);
            }
            function getReturnTypeOfSignature(signature) {
                if (!signature.resolvedReturnType) {
                    if (!pushTypeResolution(signature, 3 /* ResolvedReturnType */)) {
                        return errorType;
                    }
                    let type = signature.target ? instantiateType(getReturnTypeOfSignature(signature.target), signature.mapper) : signature.compositeSignatures ? instantiateType(getUnionOrIntersectionType(map(signature.compositeSignatures, getReturnTypeOfSignature), signature.compositeKind, 2 /* Subtype */), signature.mapper) : getReturnTypeFromAnnotation(signature.declaration) || (nodeIsMissing(signature.declaration.body) ? anyType : getReturnTypeFromBody(signature.declaration));
                    if (signature.flags & 8 /* IsInnerCallChain */) {
                        type = addOptionalTypeMarker(type);
                    }
                    else if (signature.flags & 16 /* IsOuterCallChain */) {
                        type = getOptionalType(type);
                    }
                    if (!popTypeResolution()) {
                        if (signature.declaration) {
                            const typeNode = getEffectiveReturnTypeNode(signature.declaration);
                            if (typeNode) {
                                error(typeNode, Diagnostics.Return_type_annotation_circularly_references_itself);
                            }
                            else if (noImplicitAny) {
                                const declaration = signature.declaration;
                                const name = getNameOfDeclaration(declaration);
                                if (name) {
                                    error(name, Diagnostics._0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions, declarationNameToString(name));
                                }
                                else {
                                    error(declaration, Diagnostics.Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions);
                                }
                            }
                        }
                        type = anyType;
                    }
                    signature.resolvedReturnType = type;
                }
                return signature.resolvedReturnType;
            }
            function getReturnTypeFromAnnotation(declaration) {
                if (declaration.kind === 173 /* Constructor */) {
                    return getDeclaredTypeOfClassOrInterface(getMergedSymbol(declaration.parent.symbol));
                }
                if (isJSDocSignature(declaration)) {
                    const root = getJSDocRoot(declaration);
                    if (root && isConstructorDeclaration(root.parent)) {
                        return getDeclaredTypeOfClassOrInterface(getMergedSymbol(root.parent.parent.symbol));
                    }
                }
                if (isJSDocConstructSignature(declaration)) {
                    return getTypeFromTypeNode(declaration.parameters[0].type);
                }
                const typeNode = getEffectiveReturnTypeNode(declaration);
                if (typeNode) {
                    return getTypeFromTypeNode(typeNode);
                }
                if (declaration.kind === 174 /* GetAccessor */ && hasBindableName(declaration)) {
                    const jsDocType = isInJSFile(declaration) && getTypeForDeclarationFromJSDocComment(declaration);
                    if (jsDocType) {
                        return jsDocType;
                    }
                    const setter = getDeclarationOfKind(getSymbolOfDeclaration(declaration), 175 /* SetAccessor */);
                    const setterType = getAnnotatedAccessorType(setter);
                    if (setterType) {
                        return setterType;
                    }
                }
                return getReturnTypeOfTypeTag(declaration);
            }
            function isResolvingReturnTypeOfSignature(signature) {
                return !signature.resolvedReturnType && findResolutionCycleStartIndex(signature, 3 /* ResolvedReturnType */) >= 0;
            }
            function getRestTypeOfSignature(signature) {
                return tryGetRestTypeOfSignature(signature) || anyType;
            }
            function tryGetRestTypeOfSignature(signature) {
                if (signatureHasRestParameter(signature)) {
                    const sigRestType = getTypeOfSymbol(signature.parameters[signature.parameters.length - 1]);
                    const restType = isTupleType(sigRestType) ? getRestTypeOfTupleType(sigRestType) : sigRestType;
                    return restType && getIndexTypeOfType(restType, numberType);
                }
                return void 0;
            }
            function getSignatureInstantiation(signature, typeArguments, isJavascript, inferredTypeParameters) {
                const instantiatedSignature = getSignatureInstantiationWithoutFillingInTypeArguments(signature, fillMissingTypeArguments(typeArguments, signature.typeParameters, getMinTypeArgumentCount(signature.typeParameters), isJavascript));
                if (inferredTypeParameters) {
                    const returnSignature = getSingleCallOrConstructSignature(getReturnTypeOfSignature(instantiatedSignature));
                    if (returnSignature) {
                        const newReturnSignature = cloneSignature(returnSignature);
                        newReturnSignature.typeParameters = inferredTypeParameters;
                        const newInstantiatedSignature = cloneSignature(instantiatedSignature);
                        newInstantiatedSignature.resolvedReturnType = getOrCreateTypeFromSignature(newReturnSignature);
                        return newInstantiatedSignature;
                    }
                }
                return instantiatedSignature;
            }
            function getSignatureInstantiationWithoutFillingInTypeArguments(signature, typeArguments) {
                const instantiations = signature.instantiations || (signature.instantiations = /* @__PURE__ */ new Map());
                const id = getTypeListId(typeArguments);
                let instantiation = instantiations.get(id);
                if (!instantiation) {
                    instantiations.set(id, instantiation = createSignatureInstantiation(signature, typeArguments));
                }
                return instantiation;
            }
            function createSignatureInstantiation(signature, typeArguments) {
                return instantiateSignature(signature, createSignatureTypeMapper(signature, typeArguments), 
                /*eraseTypeParameters*/
                true);
            }
            function createSignatureTypeMapper(signature, typeArguments) {
                return createTypeMapper(signature.typeParameters, typeArguments);
            }
            function getErasedSignature(signature) {
                return signature.typeParameters ? signature.erasedSignatureCache || (signature.erasedSignatureCache = createErasedSignature(signature)) : signature;
            }
            function createErasedSignature(signature) {
                return instantiateSignature(signature, createTypeEraser(signature.typeParameters), 
                /*eraseTypeParameters*/
                true);
            }
            function getCanonicalSignature(signature) {
                return signature.typeParameters ? signature.canonicalSignatureCache || (signature.canonicalSignatureCache = createCanonicalSignature(signature)) : signature;
            }
            function createCanonicalSignature(signature) {
                return getSignatureInstantiation(signature, map(signature.typeParameters, (tp) => tp.target && !getConstraintOfTypeParameter(tp.target) ? tp.target : tp), isInJSFile(signature.declaration));
            }
            function getBaseSignature(signature) {
                const typeParameters = signature.typeParameters;
                if (typeParameters) {
                    if (signature.baseSignatureCache) {
                        return signature.baseSignatureCache;
                    }
                    const typeEraser = createTypeEraser(typeParameters);
                    const baseConstraintMapper = createTypeMapper(typeParameters, map(typeParameters, (tp) => getConstraintOfTypeParameter(tp) || unknownType));
                    let baseConstraints = map(typeParameters, (tp) => instantiateType(tp, baseConstraintMapper) || unknownType);
                    for (let i = 0; i < typeParameters.length - 1; i++) {
                        baseConstraints = instantiateTypes(baseConstraints, baseConstraintMapper);
                    }
                    baseConstraints = instantiateTypes(baseConstraints, typeEraser);
                    return signature.baseSignatureCache = instantiateSignature(signature, createTypeMapper(typeParameters, baseConstraints), 
                    /*eraseTypeParameters*/
                    true);
                }
                return signature;
            }
            function getOrCreateTypeFromSignature(signature) {
                var _a2;
                if (!signature.isolatedSignatureType) {
                    const kind = (_a2 = signature.declaration) == null ? void 0 : _a2.kind;
                    const isConstructor = kind === void 0 || kind === 173 /* Constructor */ || kind === 177 /* ConstructSignature */ || kind === 182 /* ConstructorType */;
                    const type = createObjectType(16 /* Anonymous */);
                    type.members = emptySymbols;
                    type.properties = emptyArray;
                    type.callSignatures = !isConstructor ? [signature] : emptyArray;
                    type.constructSignatures = isConstructor ? [signature] : emptyArray;
                    type.indexInfos = emptyArray;
                    signature.isolatedSignatureType = type;
                }
                return signature.isolatedSignatureType;
            }
            function getIndexSymbol(symbol) {
                return symbol.members ? getIndexSymbolFromSymbolTable(symbol.members) : void 0;
            }
            function getIndexSymbolFromSymbolTable(symbolTable) {
                return symbolTable.get("__index" /* Index */);
            }
            function createIndexInfo(keyType, type, isReadonly, declaration) {
                return { keyType, type, isReadonly, declaration };
            }
            function getIndexInfosOfSymbol(symbol) {
                const indexSymbol = getIndexSymbol(symbol);
                return indexSymbol ? getIndexInfosOfIndexSymbol(indexSymbol) : emptyArray;
            }
            function getIndexInfosOfIndexSymbol(indexSymbol) {
                if (indexSymbol.declarations) {
                    const indexInfos = [];
                    for (const declaration of indexSymbol.declarations) {
                        if (declaration.parameters.length === 1) {
                            const parameter = declaration.parameters[0];
                            if (parameter.type) {
                                forEachType(getTypeFromTypeNode(parameter.type), (keyType) => {
                                    if (isValidIndexKeyType(keyType) && !findIndexInfo(indexInfos, keyType)) {
                                        indexInfos.push(createIndexInfo(keyType, declaration.type ? getTypeFromTypeNode(declaration.type) : anyType, hasEffectiveModifier(declaration, 64 /* Readonly */), declaration));
                                    }
                                });
                            }
                        }
                    }
                    return indexInfos;
                }
                return emptyArray;
            }
            function isValidIndexKeyType(type) {
                return !!(type.flags & (4 /* String */ | 8 /* Number */ | 4096 /* ESSymbol */)) || isPatternLiteralType(type) || !!(type.flags & 2097152 /* Intersection */) && !isGenericType(type) && some(type.types, isValidIndexKeyType);
            }
            function getConstraintDeclaration(type) {
                return mapDefined(filter(type.symbol && type.symbol.declarations, isTypeParameterDeclaration), getEffectiveConstraintOfTypeParameter)[0];
            }
            function getInferredTypeParameterConstraint(typeParameter, omitTypeReferences) {
                var _a2;
                let inferences;
                if ((_a2 = typeParameter.symbol) == null ? void 0 : _a2.declarations) {
                    for (const declaration of typeParameter.symbol.declarations) {
                        if (declaration.parent.kind === 192 /* InferType */) {
                            const [childTypeParameter = declaration.parent, grandParent] = walkUpParenthesizedTypesAndGetParentAndChild(declaration.parent.parent);
                            if (grandParent.kind === 180 /* TypeReference */ && !omitTypeReferences) {
                                const typeReference = grandParent;
                                const typeParameters = getTypeParametersForTypeReferenceOrImport(typeReference);
                                if (typeParameters) {
                                    const index = typeReference.typeArguments.indexOf(childTypeParameter);
                                    if (index < typeParameters.length) {
                                        const declaredConstraint = getConstraintOfTypeParameter(typeParameters[index]);
                                        if (declaredConstraint) {
                                            const mapper = makeDeferredTypeMapper(typeParameters, typeParameters.map((_, index2) => () => {
                                                return getEffectiveTypeArgumentAtIndex(typeReference, typeParameters, index2);
                                            }));
                                            const constraint = instantiateType(declaredConstraint, mapper);
                                            if (constraint !== typeParameter) {
                                                inferences = append(inferences, constraint);
                                            }
                                        }
                                    }
                                }
                            }
                            else if (grandParent.kind === 166 /* Parameter */ && grandParent.dotDotDotToken || grandParent.kind === 188 /* RestType */ || grandParent.kind === 199 /* NamedTupleMember */ && grandParent.dotDotDotToken) {
                                inferences = append(inferences, createArrayType(unknownType));
                            }
                            else if (grandParent.kind === 201 /* TemplateLiteralTypeSpan */) {
                                inferences = append(inferences, stringType);
                            }
                            else if (grandParent.kind === 165 /* TypeParameter */ && grandParent.parent.kind === 197 /* MappedType */) {
                                inferences = append(inferences, keyofConstraintType);
                            }
                            else if (grandParent.kind === 197 /* MappedType */ && grandParent.type && skipParentheses(grandParent.type) === declaration.parent && grandParent.parent.kind === 191 /* ConditionalType */ && grandParent.parent.extendsType === grandParent && grandParent.parent.checkType.kind === 197 /* MappedType */ && grandParent.parent.checkType.type) {
                                const checkMappedType2 = grandParent.parent.checkType;
                                const nodeType = getTypeFromTypeNode(checkMappedType2.type);
                                inferences = append(inferences, instantiateType(nodeType, makeUnaryTypeMapper(getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(checkMappedType2.typeParameter)), checkMappedType2.typeParameter.constraint ? getTypeFromTypeNode(checkMappedType2.typeParameter.constraint) : keyofConstraintType)));
                            }
                        }
                    }
                }
                return inferences && getIntersectionType(inferences);
            }
            function getConstraintFromTypeParameter(typeParameter) {
                if (!typeParameter.constraint) {
                    if (typeParameter.target) {
                        const targetConstraint = getConstraintOfTypeParameter(typeParameter.target);
                        typeParameter.constraint = targetConstraint ? instantiateType(targetConstraint, typeParameter.mapper) : noConstraintType;
                    }
                    else {
                        const constraintDeclaration = getConstraintDeclaration(typeParameter);
                        if (!constraintDeclaration) {
                            typeParameter.constraint = getInferredTypeParameterConstraint(typeParameter) || noConstraintType;
                        }
                        else {
                            let type = getTypeFromTypeNode(constraintDeclaration);
                            if (type.flags & 1 /* Any */ && !isErrorType(type)) {
                                type = constraintDeclaration.parent.parent.kind === 197 /* MappedType */ ? keyofConstraintType : unknownType;
                            }
                            typeParameter.constraint = type;
                        }
                    }
                }
                return typeParameter.constraint === noConstraintType ? void 0 : typeParameter.constraint;
            }
            function getParentSymbolOfTypeParameter(typeParameter) {
                const tp = getDeclarationOfKind(typeParameter.symbol, 165 /* TypeParameter */);
                const host2 = isJSDocTemplateTag(tp.parent) ? getEffectiveContainerForJSDocTemplateTag(tp.parent) : tp.parent;
                return host2 && getSymbolOfNode(host2);
            }
            function getTypeListId(types) {
                let result = "";
                if (types) {
                    const length2 = types.length;
                    let i = 0;
                    while (i < length2) {
                        const startId = types[i].id;
                        let count = 1;
                        while (i + count < length2 && types[i + count].id === startId + count) {
                            count++;
                        }
                        if (result.length) {
                            result += ",";
                        }
                        result += startId;
                        if (count > 1) {
                            result += ":" + count;
                        }
                        i += count;
                    }
                }
                return result;
            }
            function getAliasId(aliasSymbol, aliasTypeArguments) {
                return aliasSymbol ? `@${getSymbolId(aliasSymbol)}` + (aliasTypeArguments ? `:${getTypeListId(aliasTypeArguments)}` : "") : "";
            }
            function getPropagatingFlagsOfTypes(types, excludeKinds) {
                let result = 0;
                for (const type of types) {
                    if (excludeKinds === void 0 || !(type.flags & excludeKinds)) {
                        result |= getObjectFlags(type);
                    }
                }
                return result & 458752 /* PropagatingFlags */;
            }
            function tryCreateTypeReference(target, typeArguments) {
                if (some(typeArguments) && target === emptyGenericType) {
                    return unknownType;
                }
                return createTypeReference(target, typeArguments);
            }
            function createTypeReference(target, typeArguments) {
                const id = getTypeListId(typeArguments);
                let type = target.instantiations.get(id);
                if (!type) {
                    type = createObjectType(4 /* Reference */, target.symbol);
                    target.instantiations.set(id, type);
                    type.objectFlags |= typeArguments ? getPropagatingFlagsOfTypes(typeArguments) : 0;
                    type.target = target;
                    type.resolvedTypeArguments = typeArguments;
                }
                return type;
            }
            function cloneTypeReference(source) {
                const type = createTypeWithSymbol(source.flags, source.symbol);
                type.objectFlags = source.objectFlags;
                type.target = source.target;
                type.resolvedTypeArguments = source.resolvedTypeArguments;
                return type;
            }
            function createDeferredTypeReference(target, node, mapper, aliasSymbol, aliasTypeArguments) {
                if (!aliasSymbol) {
                    aliasSymbol = getAliasSymbolForTypeNode(node);
                    const localAliasTypeArguments = getTypeArgumentsForAliasSymbol(aliasSymbol);
                    aliasTypeArguments = mapper ? instantiateTypes(localAliasTypeArguments, mapper) : localAliasTypeArguments;
                }
                const type = createObjectType(4 /* Reference */, target.symbol);
                type.target = target;
                type.node = node;
                type.mapper = mapper;
                type.aliasSymbol = aliasSymbol;
                type.aliasTypeArguments = aliasTypeArguments;
                return type;
            }
            function getTypeArguments(type) {
                var _a2, _b;
                if (!type.resolvedTypeArguments) {
                    if (!pushTypeResolution(type, 6 /* ResolvedTypeArguments */)) {
                        return ((_a2 = type.target.localTypeParameters) == null ? void 0 : _a2.map(() => errorType)) || emptyArray;
                    }
                    const node = type.node;
                    const typeArguments = !node ? emptyArray : node.kind === 180 /* TypeReference */ ? concatenate(type.target.outerTypeParameters, getEffectiveTypeArguments2(node, type.target.localTypeParameters)) : node.kind === 185 /* ArrayType */ ? [getTypeFromTypeNode(node.elementType)] : map(node.elements, getTypeFromTypeNode);
                    if (popTypeResolution()) {
                        type.resolvedTypeArguments = type.mapper ? instantiateTypes(typeArguments, type.mapper) : typeArguments;
                    }
                    else {
                        type.resolvedTypeArguments = ((_b = type.target.localTypeParameters) == null ? void 0 : _b.map(() => errorType)) || emptyArray;
                        error(type.node || currentNode, type.target.symbol ? Diagnostics.Type_arguments_for_0_circularly_reference_themselves : Diagnostics.Tuple_type_arguments_circularly_reference_themselves, type.target.symbol && symbolToString(type.target.symbol));
                    }
                }
                return type.resolvedTypeArguments;
            }
            function getTypeReferenceArity(type) {
                return length(type.target.typeParameters);
            }
            function getTypeFromClassOrInterfaceReference(node, symbol) {
                const type = getDeclaredTypeOfSymbol(getMergedSymbol(symbol));
                const typeParameters = type.localTypeParameters;
                if (typeParameters) {
                    const numTypeArguments = length(node.typeArguments);
                    const minTypeArgumentCount = getMinTypeArgumentCount(typeParameters);
                    const isJs = isInJSFile(node);
                    const isJsImplicitAny = !noImplicitAny && isJs;
                    if (!isJsImplicitAny && (numTypeArguments < minTypeArgumentCount || numTypeArguments > typeParameters.length)) {
                        const missingAugmentsTag = isJs && isExpressionWithTypeArguments(node) && !isJSDocAugmentsTag(node.parent);
                        const diag2 = minTypeArgumentCount === typeParameters.length ? missingAugmentsTag ? Diagnostics.Expected_0_type_arguments_provide_these_with_an_extends_tag : Diagnostics.Generic_type_0_requires_1_type_argument_s : missingAugmentsTag ? Diagnostics.Expected_0_1_type_arguments_provide_these_with_an_extends_tag : Diagnostics.Generic_type_0_requires_between_1_and_2_type_arguments;
                        const typeStr = typeToString(type, 
                        /*enclosingDeclaration*/
                        void 0, 2 /* WriteArrayAsGenericType */);
                        error(node, diag2, typeStr, minTypeArgumentCount, typeParameters.length);
                        if (!isJs) {
                            return errorType;
                        }
                    }
                    if (node.kind === 180 /* TypeReference */ && isDeferredTypeReferenceNode(node, length(node.typeArguments) !== typeParameters.length)) {
                        return createDeferredTypeReference(type, node, 
                        /*mapper*/
                        void 0);
                    }
                    const typeArguments = concatenate(type.outerTypeParameters, fillMissingTypeArguments(typeArgumentsFromTypeReferenceNode(node), typeParameters, minTypeArgumentCount, isJs));
                    return createTypeReference(type, typeArguments);
                }
                return checkNoTypeArguments(node, symbol) ? type : errorType;
            }
            function getTypeAliasInstantiation(symbol, typeArguments, aliasSymbol, aliasTypeArguments) {
                const type = getDeclaredTypeOfSymbol(symbol);
                if (type === intrinsicMarkerType && intrinsicTypeKinds.has(symbol.escapedName) && typeArguments && typeArguments.length === 1) {
                    return getStringMappingType(symbol, typeArguments[0]);
                }
                const links = getSymbolLinks(symbol);
                const typeParameters = links.typeParameters;
                const id = getTypeListId(typeArguments) + getAliasId(aliasSymbol, aliasTypeArguments);
                let instantiation = links.instantiations.get(id);
                if (!instantiation) {
                    links.instantiations.set(id, instantiation = instantiateTypeWithAlias(type, createTypeMapper(typeParameters, fillMissingTypeArguments(typeArguments, typeParameters, getMinTypeArgumentCount(typeParameters), isInJSFile(symbol.valueDeclaration))), aliasSymbol, aliasTypeArguments));
                }
                return instantiation;
            }
            function getTypeFromTypeAliasReference(node, symbol) {
                if (getCheckFlags(symbol) & 1048576 /* Unresolved */) {
                    const typeArguments = typeArgumentsFromTypeReferenceNode(node);
                    const id = getAliasId(symbol, typeArguments);
                    let errorType2 = errorTypes.get(id);
                    if (!errorType2) {
                        errorType2 = createIntrinsicType(1 /* Any */, "error");
                        errorType2.aliasSymbol = symbol;
                        errorType2.aliasTypeArguments = typeArguments;
                        errorTypes.set(id, errorType2);
                    }
                    return errorType2;
                }
                const type = getDeclaredTypeOfSymbol(symbol);
                const typeParameters = getSymbolLinks(symbol).typeParameters;
                if (typeParameters) {
                    const numTypeArguments = length(node.typeArguments);
                    const minTypeArgumentCount = getMinTypeArgumentCount(typeParameters);
                    if (numTypeArguments < minTypeArgumentCount || numTypeArguments > typeParameters.length) {
                        error(node, minTypeArgumentCount === typeParameters.length ? Diagnostics.Generic_type_0_requires_1_type_argument_s : Diagnostics.Generic_type_0_requires_between_1_and_2_type_arguments, symbolToString(symbol), minTypeArgumentCount, typeParameters.length);
                        return errorType;
                    }
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    let newAliasSymbol = aliasSymbol && (isLocalTypeAlias(symbol) || !isLocalTypeAlias(aliasSymbol)) ? aliasSymbol : void 0;
                    let aliasTypeArguments;
                    if (newAliasSymbol) {
                        aliasTypeArguments = getTypeArgumentsForAliasSymbol(newAliasSymbol);
                    }
                    else if (isTypeReferenceType(node)) {
                        const aliasSymbol2 = resolveTypeReferenceName(node, 2097152 /* Alias */, 
                        /*ignoreErrors*/
                        true);
                        if (aliasSymbol2 && aliasSymbol2 !== unknownSymbol) {
                            const resolved = resolveAlias(aliasSymbol2);
                            if (resolved && resolved.flags & 524288 /* TypeAlias */) {
                                newAliasSymbol = resolved;
                                aliasTypeArguments = typeArgumentsFromTypeReferenceNode(node) || (typeParameters ? [] : void 0);
                            }
                        }
                    }
                    return getTypeAliasInstantiation(symbol, typeArgumentsFromTypeReferenceNode(node), newAliasSymbol, aliasTypeArguments);
                }
                return checkNoTypeArguments(node, symbol) ? type : errorType;
            }
            function isLocalTypeAlias(symbol) {
                var _a2;
                const declaration = (_a2 = symbol.declarations) == null ? void 0 : _a2.find(isTypeAlias);
                return !!(declaration && getContainingFunction(declaration));
            }
            function getTypeReferenceName(node) {
                switch (node.kind) {
                    case 180 /* TypeReference */:
                        return node.typeName;
                    case 230 /* ExpressionWithTypeArguments */:
                        const expr = node.expression;
                        if (isEntityNameExpression(expr)) {
                            return expr;
                        }
                }
                return void 0;
            }
            function getSymbolPath(symbol) {
                return symbol.parent ? `${getSymbolPath(symbol.parent)}.${symbol.escapedName}` : symbol.escapedName;
            }
            function getUnresolvedSymbolForEntityName(name) {
                const identifier = name.kind === 163 /* QualifiedName */ ? name.right : name.kind === 208 /* PropertyAccessExpression */ ? name.name : name;
                const text = identifier.escapedText;
                if (text) {
                    const parentSymbol = name.kind === 163 /* QualifiedName */ ? getUnresolvedSymbolForEntityName(name.left) : name.kind === 208 /* PropertyAccessExpression */ ? getUnresolvedSymbolForEntityName(name.expression) : void 0;
                    const path = parentSymbol ? `${getSymbolPath(parentSymbol)}.${text}` : text;
                    let result = unresolvedSymbols.get(path);
                    if (!result) {
                        unresolvedSymbols.set(path, result = createSymbol(524288 /* TypeAlias */, text, 1048576 /* Unresolved */));
                        result.parent = parentSymbol;
                        result.links.declaredType = unresolvedType;
                    }
                    return result;
                }
                return unknownSymbol;
            }
            function resolveTypeReferenceName(typeReference, meaning, ignoreErrors) {
                const name = getTypeReferenceName(typeReference);
                if (!name) {
                    return unknownSymbol;
                }
                const symbol = resolveEntityName(name, meaning, ignoreErrors);
                return symbol && symbol !== unknownSymbol ? symbol : ignoreErrors ? unknownSymbol : getUnresolvedSymbolForEntityName(name);
            }
            function getTypeReferenceType(node, symbol) {
                if (symbol === unknownSymbol) {
                    return errorType;
                }
                symbol = getExpandoSymbol(symbol) || symbol;
                if (symbol.flags & (32 /* Class */ | 64 /* Interface */)) {
                    return getTypeFromClassOrInterfaceReference(node, symbol);
                }
                if (symbol.flags & 524288 /* TypeAlias */) {
                    return getTypeFromTypeAliasReference(node, symbol);
                }
                const res = tryGetDeclaredTypeOfSymbol(symbol);
                if (res) {
                    return checkNoTypeArguments(node, symbol) ? getRegularTypeOfLiteralType(res) : errorType;
                }
                if (symbol.flags & 111551 /* Value */ && isJSDocTypeReference(node)) {
                    const jsdocType = getTypeFromJSDocValueReference(node, symbol);
                    if (jsdocType) {
                        return jsdocType;
                    }
                    else {
                        resolveTypeReferenceName(node, 788968 /* Type */);
                        return getTypeOfSymbol(symbol);
                    }
                }
                return errorType;
            }
            function getTypeFromJSDocValueReference(node, symbol) {
                const links = getNodeLinks(node);
                if (!links.resolvedJSDocType) {
                    const valueType = getTypeOfSymbol(symbol);
                    let typeType = valueType;
                    if (symbol.valueDeclaration) {
                        const isImportTypeWithQualifier = node.kind === 202 /* ImportType */ && node.qualifier;
                        if (valueType.symbol && valueType.symbol !== symbol && isImportTypeWithQualifier) {
                            typeType = getTypeReferenceType(node, valueType.symbol);
                        }
                    }
                    links.resolvedJSDocType = typeType;
                }
                return links.resolvedJSDocType;
            }
            function getSubstitutionType(baseType, constraint) {
                if (constraint.flags & 3 /* AnyOrUnknown */ || constraint === baseType || baseType.flags & 1 /* Any */) {
                    return baseType;
                }
                const id = `${getTypeId(baseType)}>${getTypeId(constraint)}`;
                const cached = substitutionTypes.get(id);
                if (cached) {
                    return cached;
                }
                const result = createType(33554432 /* Substitution */);
                result.baseType = baseType;
                result.constraint = constraint;
                substitutionTypes.set(id, result);
                return result;
            }
            function getSubstitutionIntersection(substitutionType) {
                return getIntersectionType([substitutionType.constraint, substitutionType.baseType]);
            }
            function isUnaryTupleTypeNode(node) {
                return node.kind === 186 /* TupleType */ && node.elements.length === 1;
            }
            function getImpliedConstraint(type, checkNode, extendsNode) {
                return isUnaryTupleTypeNode(checkNode) && isUnaryTupleTypeNode(extendsNode) ? getImpliedConstraint(type, checkNode.elements[0], extendsNode.elements[0]) : getActualTypeVariable(getTypeFromTypeNode(checkNode)) === getActualTypeVariable(type) ? getTypeFromTypeNode(extendsNode) : void 0;
            }
            function getConditionalFlowTypeOfType(type, node) {
                let constraints;
                let covariant = true;
                while (node && !isStatement(node) && node.kind !== 323 /* JSDoc */) {
                    const parent2 = node.parent;
                    if (parent2.kind === 166 /* Parameter */) {
                        covariant = !covariant;
                    }
                    if ((covariant || type.flags & 8650752 /* TypeVariable */) && parent2.kind === 191 /* ConditionalType */ && node === parent2.trueType) {
                        const constraint = getImpliedConstraint(type, parent2.checkType, parent2.extendsType);
                        if (constraint) {
                            constraints = append(constraints, constraint);
                        }
                    }
                    else if (type.flags & 262144 /* TypeParameter */ && parent2.kind === 197 /* MappedType */ && node === parent2.type) {
                        const mappedType = getTypeFromTypeNode(parent2);
                        if (getTypeParameterFromMappedType(mappedType) === getActualTypeVariable(type)) {
                            const typeParameter = getHomomorphicTypeVariable(mappedType);
                            if (typeParameter) {
                                const constraint = getConstraintOfTypeParameter(typeParameter);
                                if (constraint && everyType(constraint, isArrayOrTupleType)) {
                                    constraints = append(constraints, getUnionType([numberType, numericStringType]));
                                }
                            }
                        }
                    }
                    node = parent2;
                }
                return constraints ? getSubstitutionType(type, getIntersectionType(constraints)) : type;
            }
            function isJSDocTypeReference(node) {
                return !!(node.flags & 8388608 /* JSDoc */) && (node.kind === 180 /* TypeReference */ || node.kind === 202 /* ImportType */);
            }
            function checkNoTypeArguments(node, symbol) {
                if (node.typeArguments) {
                    error(node, Diagnostics.Type_0_is_not_generic, symbol ? symbolToString(symbol) : node.typeName ? declarationNameToString(node.typeName) : anon);
                    return false;
                }
                return true;
            }
            function getIntendedTypeFromJSDocTypeReference(node) {
                if (isIdentifier(node.typeName)) {
                    const typeArgs = node.typeArguments;
                    switch (node.typeName.escapedText) {
                        case "String":
                            checkNoTypeArguments(node);
                            return stringType;
                        case "Number":
                            checkNoTypeArguments(node);
                            return numberType;
                        case "Boolean":
                            checkNoTypeArguments(node);
                            return booleanType;
                        case "Void":
                            checkNoTypeArguments(node);
                            return voidType;
                        case "Undefined":
                            checkNoTypeArguments(node);
                            return undefinedType;
                        case "Null":
                            checkNoTypeArguments(node);
                            return nullType;
                        case "Function":
                        case "function":
                            checkNoTypeArguments(node);
                            return globalFunctionType;
                        case "array":
                            return (!typeArgs || !typeArgs.length) && !noImplicitAny ? anyArrayType : void 0;
                        case "promise":
                            return (!typeArgs || !typeArgs.length) && !noImplicitAny ? createPromiseType(anyType) : void 0;
                        case "Object":
                            if (typeArgs && typeArgs.length === 2) {
                                if (isJSDocIndexSignature(node)) {
                                    const indexed = getTypeFromTypeNode(typeArgs[0]);
                                    const target = getTypeFromTypeNode(typeArgs[1]);
                                    const indexInfo = indexed === stringType || indexed === numberType ? [createIndexInfo(indexed, target, 
                                        /*isReadonly*/
                                        false)] : emptyArray;
                                    return createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, indexInfo);
                                }
                                return anyType;
                            }
                            checkNoTypeArguments(node);
                            return !noImplicitAny ? anyType : void 0;
                    }
                }
            }
            function getTypeFromJSDocNullableTypeNode(node) {
                const type = getTypeFromTypeNode(node.type);
                return strictNullChecks ? getNullableType(type, 65536 /* Null */) : type;
            }
            function getTypeFromTypeReference(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    if (isConstTypeReference(node) && isAssertionExpression(node.parent)) {
                        links.resolvedSymbol = unknownSymbol;
                        return links.resolvedType = checkExpressionCached(node.parent.expression);
                    }
                    let symbol;
                    let type;
                    const meaning = 788968 /* Type */;
                    if (isJSDocTypeReference(node)) {
                        type = getIntendedTypeFromJSDocTypeReference(node);
                        if (!type) {
                            symbol = resolveTypeReferenceName(node, meaning, 
                            /*ignoreErrors*/
                            true);
                            if (symbol === unknownSymbol) {
                                symbol = resolveTypeReferenceName(node, meaning | 111551 /* Value */);
                            }
                            else {
                                resolveTypeReferenceName(node, meaning);
                            }
                            type = getTypeReferenceType(node, symbol);
                        }
                    }
                    if (!type) {
                        symbol = resolveTypeReferenceName(node, meaning);
                        type = getTypeReferenceType(node, symbol);
                    }
                    links.resolvedSymbol = symbol;
                    links.resolvedType = type;
                }
                return links.resolvedType;
            }
            function typeArgumentsFromTypeReferenceNode(node) {
                return map(node.typeArguments, getTypeFromTypeNode);
            }
            function getTypeFromTypeQueryNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const type = checkExpressionWithTypeArguments(node);
                    links.resolvedType = getRegularTypeOfLiteralType(getWidenedType(type));
                }
                return links.resolvedType;
            }
            function getTypeOfGlobalSymbol(symbol, arity) {
                function getTypeDeclaration(symbol2) {
                    const declarations = symbol2.declarations;
                    if (declarations) {
                        for (const declaration of declarations) {
                            switch (declaration.kind) {
                                case 260 /* ClassDeclaration */:
                                case 261 /* InterfaceDeclaration */:
                                case 263 /* EnumDeclaration */:
                                    return declaration;
                            }
                        }
                    }
                }
                if (!symbol) {
                    return arity ? emptyGenericType : emptyObjectType;
                }
                const type = getDeclaredTypeOfSymbol(symbol);
                if (!(type.flags & 524288 /* Object */)) {
                    error(getTypeDeclaration(symbol), Diagnostics.Global_type_0_must_be_a_class_or_interface_type, symbolName(symbol));
                    return arity ? emptyGenericType : emptyObjectType;
                }
                if (length(type.typeParameters) !== arity) {
                    error(getTypeDeclaration(symbol), Diagnostics.Global_type_0_must_have_1_type_parameter_s, symbolName(symbol), arity);
                    return arity ? emptyGenericType : emptyObjectType;
                }
                return type;
            }
            function getGlobalValueSymbol(name, reportErrors2) {
                return getGlobalSymbol(name, 111551 /* Value */, reportErrors2 ? Diagnostics.Cannot_find_global_value_0 : void 0);
            }
            function getGlobalTypeSymbol(name, reportErrors2) {
                return getGlobalSymbol(name, 788968 /* Type */, reportErrors2 ? Diagnostics.Cannot_find_global_type_0 : void 0);
            }
            function getGlobalTypeAliasSymbol(name, arity, reportErrors2) {
                const symbol = getGlobalSymbol(name, 788968 /* Type */, reportErrors2 ? Diagnostics.Cannot_find_global_type_0 : void 0);
                if (symbol) {
                    getDeclaredTypeOfSymbol(symbol);
                    if (length(getSymbolLinks(symbol).typeParameters) !== arity) {
                        const decl = symbol.declarations && find(symbol.declarations, isTypeAliasDeclaration);
                        error(decl, Diagnostics.Global_type_0_must_have_1_type_parameter_s, symbolName(symbol), arity);
                        return void 0;
                    }
                }
                return symbol;
            }
            function getGlobalSymbol(name, meaning, diagnostic) {
                return resolveName(void 0, name, meaning, diagnostic, name, 
                /*isUse*/
                false, 
                /*excludeGlobals*/
                false, 
                /*getSpellingSuggestions*/
                false);
            }
            function getGlobalType(name, arity, reportErrors2) {
                const symbol = getGlobalTypeSymbol(name, reportErrors2);
                return symbol || reportErrors2 ? getTypeOfGlobalSymbol(symbol, arity) : void 0;
            }
            function getGlobalTypedPropertyDescriptorType() {
                return deferredGlobalTypedPropertyDescriptorType || (deferredGlobalTypedPropertyDescriptorType = getGlobalType("TypedPropertyDescriptor", 
                /*arity*/
                1, 
                /*reportErrors*/
                true) || emptyGenericType);
            }
            function getGlobalTemplateStringsArrayType() {
                return deferredGlobalTemplateStringsArrayType || (deferredGlobalTemplateStringsArrayType = getGlobalType("TemplateStringsArray", 
                /*arity*/
                0, 
                /*reportErrors*/
                true) || emptyObjectType);
            }
            function getGlobalImportMetaType() {
                return deferredGlobalImportMetaType || (deferredGlobalImportMetaType = getGlobalType("ImportMeta", 
                /*arity*/
                0, 
                /*reportErrors*/
                true) || emptyObjectType);
            }
            function getGlobalImportMetaExpressionType() {
                if (!deferredGlobalImportMetaExpressionType) {
                    const symbol = createSymbol(0 /* None */, "ImportMetaExpression");
                    const importMetaType = getGlobalImportMetaType();
                    const metaPropertySymbol = createSymbol(4 /* Property */, "meta", 8 /* Readonly */);
                    metaPropertySymbol.parent = symbol;
                    metaPropertySymbol.links.type = importMetaType;
                    const members = createSymbolTable([metaPropertySymbol]);
                    symbol.members = members;
                    deferredGlobalImportMetaExpressionType = createAnonymousType(symbol, members, emptyArray, emptyArray, emptyArray);
                }
                return deferredGlobalImportMetaExpressionType;
            }
            function getGlobalImportCallOptionsType(reportErrors2) {
                return deferredGlobalImportCallOptionsType || (deferredGlobalImportCallOptionsType = getGlobalType("ImportCallOptions", 
                /*arity*/
                0, reportErrors2)) || emptyObjectType;
            }
            function getGlobalESSymbolConstructorSymbol(reportErrors2) {
                return deferredGlobalESSymbolConstructorSymbol || (deferredGlobalESSymbolConstructorSymbol = getGlobalValueSymbol("Symbol", reportErrors2));
            }
            function getGlobalESSymbolConstructorTypeSymbol(reportErrors2) {
                return deferredGlobalESSymbolConstructorTypeSymbol || (deferredGlobalESSymbolConstructorTypeSymbol = getGlobalTypeSymbol("SymbolConstructor", reportErrors2));
            }
            function getGlobalESSymbolType() {
                return deferredGlobalESSymbolType || (deferredGlobalESSymbolType = getGlobalType("Symbol", 
                /*arity*/
                0, 
                /*reportErrors*/
                false)) || emptyObjectType;
            }
            function getGlobalPromiseType(reportErrors2) {
                return deferredGlobalPromiseType || (deferredGlobalPromiseType = getGlobalType("Promise", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalPromiseLikeType(reportErrors2) {
                return deferredGlobalPromiseLikeType || (deferredGlobalPromiseLikeType = getGlobalType("PromiseLike", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalPromiseConstructorSymbol(reportErrors2) {
                return deferredGlobalPromiseConstructorSymbol || (deferredGlobalPromiseConstructorSymbol = getGlobalValueSymbol("Promise", reportErrors2));
            }
            function getGlobalPromiseConstructorLikeType(reportErrors2) {
                return deferredGlobalPromiseConstructorLikeType || (deferredGlobalPromiseConstructorLikeType = getGlobalType("PromiseConstructorLike", 
                /*arity*/
                0, reportErrors2)) || emptyObjectType;
            }
            function getGlobalAsyncIterableType(reportErrors2) {
                return deferredGlobalAsyncIterableType || (deferredGlobalAsyncIterableType = getGlobalType("AsyncIterable", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalAsyncIteratorType(reportErrors2) {
                return deferredGlobalAsyncIteratorType || (deferredGlobalAsyncIteratorType = getGlobalType("AsyncIterator", 
                /*arity*/
                3, reportErrors2)) || emptyGenericType;
            }
            function getGlobalAsyncIterableIteratorType(reportErrors2) {
                return deferredGlobalAsyncIterableIteratorType || (deferredGlobalAsyncIterableIteratorType = getGlobalType("AsyncIterableIterator", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalAsyncGeneratorType(reportErrors2) {
                return deferredGlobalAsyncGeneratorType || (deferredGlobalAsyncGeneratorType = getGlobalType("AsyncGenerator", 
                /*arity*/
                3, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIterableType(reportErrors2) {
                return deferredGlobalIterableType || (deferredGlobalIterableType = getGlobalType("Iterable", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIteratorType(reportErrors2) {
                return deferredGlobalIteratorType || (deferredGlobalIteratorType = getGlobalType("Iterator", 
                /*arity*/
                3, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIterableIteratorType(reportErrors2) {
                return deferredGlobalIterableIteratorType || (deferredGlobalIterableIteratorType = getGlobalType("IterableIterator", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalGeneratorType(reportErrors2) {
                return deferredGlobalGeneratorType || (deferredGlobalGeneratorType = getGlobalType("Generator", 
                /*arity*/
                3, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIteratorYieldResultType(reportErrors2) {
                return deferredGlobalIteratorYieldResultType || (deferredGlobalIteratorYieldResultType = getGlobalType("IteratorYieldResult", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIteratorReturnResultType(reportErrors2) {
                return deferredGlobalIteratorReturnResultType || (deferredGlobalIteratorReturnResultType = getGlobalType("IteratorReturnResult", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalTypeOrUndefined(name, arity = 0) {
                const symbol = getGlobalSymbol(name, 788968 /* Type */, 
                /*diagnostic*/
                void 0);
                return symbol && getTypeOfGlobalSymbol(symbol, arity);
            }
            function getGlobalExtractSymbol() {
                deferredGlobalExtractSymbol || (deferredGlobalExtractSymbol = getGlobalTypeAliasSymbol("Extract", 
                /*arity*/
                2, 
                /*reportErrors*/
                true) || unknownSymbol);
                return deferredGlobalExtractSymbol === unknownSymbol ? void 0 : deferredGlobalExtractSymbol;
            }
            function getGlobalOmitSymbol() {
                deferredGlobalOmitSymbol || (deferredGlobalOmitSymbol = getGlobalTypeAliasSymbol("Omit", 
                /*arity*/
                2, 
                /*reportErrors*/
                true) || unknownSymbol);
                return deferredGlobalOmitSymbol === unknownSymbol ? void 0 : deferredGlobalOmitSymbol;
            }
            function getGlobalAwaitedSymbol(reportErrors2) {
                deferredGlobalAwaitedSymbol || (deferredGlobalAwaitedSymbol = getGlobalTypeAliasSymbol("Awaited", 
                /*arity*/
                1, reportErrors2) || (reportErrors2 ? unknownSymbol : void 0));
                return deferredGlobalAwaitedSymbol === unknownSymbol ? void 0 : deferredGlobalAwaitedSymbol;
            }
            function getGlobalBigIntType() {
                return deferredGlobalBigIntType || (deferredGlobalBigIntType = getGlobalType("BigInt", 
                /*arity*/
                0, 
                /*reportErrors*/
                false)) || emptyObjectType;
            }
            function getGlobalClassDecoratorContextType(reportErrors2) {
                var _a2;
                return (_a2 = deferredGlobalClassDecoratorContextType != null ? deferredGlobalClassDecoratorContextType : deferredGlobalClassDecoratorContextType = getGlobalType("ClassDecoratorContext", 
                /*arity*/
                1, reportErrors2)) != null ? _a2 : emptyGenericType;
            }
            function getGlobalClassMethodDecoratorContextType(reportErrors2) {
                var _a2;
                return (_a2 = deferredGlobalClassMethodDecoratorContextType != null ? deferredGlobalClassMethodDecoratorContextType : deferredGlobalClassMethodDecoratorContextType = getGlobalType("ClassMethodDecoratorContext", 
                /*arity*/
                2, reportErrors2)) != null ? _a2 : emptyGenericType;
            }
            function getGlobalClassGetterDecoratorContextType(reportErrors2) {
                var _a2;
                return (_a2 = deferredGlobalClassGetterDecoratorContextType != null ? deferredGlobalClassGetterDecoratorContextType : deferredGlobalClassGetterDecoratorContextType = getGlobalType("ClassGetterDecoratorContext", 
                /*arity*/
                2, reportErrors2)) != null ? _a2 : emptyGenericType;
            }
            function getGlobalClassSetterDecoratorContextType(reportErrors2) {
                var _a2;
                return (_a2 = deferredGlobalClassSetterDecoratorContextType != null ? deferredGlobalClassSetterDecoratorContextType : deferredGlobalClassSetterDecoratorContextType = getGlobalType("ClassSetterDecoratorContext", 
                /*arity*/
                2, reportErrors2)) != null ? _a2 : emptyGenericType;
            }
            function getGlobalClassAccessorDecoratorContextType(reportErrors2) {
                var _a2;
                return (_a2 = deferredGlobalClassAccessorDecoratorContextType != null ? deferredGlobalClassAccessorDecoratorContextType : deferredGlobalClassAccessorDecoratorContextType = getGlobalType("ClassAccessorDecoratorContext", 
                /*arity*/
                2, reportErrors2)) != null ? _a2 : emptyGenericType;
            }
            function getGlobalClassAccessorDecoratorTargetType(reportErrors2) {
                var _a2;
                return (_a2 = deferredGlobalClassAccessorDecoratorTargetType != null ? deferredGlobalClassAccessorDecoratorTargetType : deferredGlobalClassAccessorDecoratorTargetType = getGlobalType("ClassAccessorDecoratorTarget", 
                /*arity*/
                2, reportErrors2)) != null ? _a2 : emptyGenericType;
            }
            function getGlobalClassAccessorDecoratorResultType(reportErrors2) {
                var _a2;
                return (_a2 = deferredGlobalClassAccessorDecoratorResultType != null ? deferredGlobalClassAccessorDecoratorResultType : deferredGlobalClassAccessorDecoratorResultType = getGlobalType("ClassAccessorDecoratorResult", 
                /*arity*/
                2, reportErrors2)) != null ? _a2 : emptyGenericType;
            }
            function getGlobalClassFieldDecoratorContextType(reportErrors2) {
                var _a2;
                return (_a2 = deferredGlobalClassFieldDecoratorContextType != null ? deferredGlobalClassFieldDecoratorContextType : deferredGlobalClassFieldDecoratorContextType = getGlobalType("ClassFieldDecoratorContext", 
                /*arity*/
                2, reportErrors2)) != null ? _a2 : emptyGenericType;
            }
            function getGlobalNaNSymbol() {
                return deferredGlobalNaNSymbol || (deferredGlobalNaNSymbol = getGlobalValueSymbol("NaN", 
                /*reportErrors*/
                false));
            }
            function getGlobalRecordSymbol() {
                deferredGlobalRecordSymbol || (deferredGlobalRecordSymbol = getGlobalTypeAliasSymbol("Record", 
                /*arity*/
                2, 
                /*reportErrors*/
                true) || unknownSymbol);
                return deferredGlobalRecordSymbol === unknownSymbol ? void 0 : deferredGlobalRecordSymbol;
            }
            function createTypeFromGenericGlobalType(genericGlobalType, typeArguments) {
                return genericGlobalType !== emptyGenericType ? createTypeReference(genericGlobalType, typeArguments) : emptyObjectType;
            }
            function createTypedPropertyDescriptorType(propertyType) {
                return createTypeFromGenericGlobalType(getGlobalTypedPropertyDescriptorType(), [propertyType]);
            }
            function createIterableType(iteratedType) {
                return createTypeFromGenericGlobalType(getGlobalIterableType(
                /*reportErrors*/
                true), [iteratedType]);
            }
            function createArrayType(elementType, readonly) {
                return createTypeFromGenericGlobalType(readonly ? globalReadonlyArrayType : globalArrayType, [elementType]);
            }
            function getTupleElementFlags(node) {
                switch (node.kind) {
                    case 187 /* OptionalType */:
                        return 2 /* Optional */;
                    case 188 /* RestType */:
                        return getRestTypeElementFlags(node);
                    case 199 /* NamedTupleMember */:
                        return node.questionToken ? 2 /* Optional */ : node.dotDotDotToken ? getRestTypeElementFlags(node) : 1 /* Required */;
                    default:
                        return 1 /* Required */;
                }
            }
            function getRestTypeElementFlags(node) {
                return getArrayElementTypeNode(node.type) ? 4 /* Rest */ : 8 /* Variadic */;
            }
            function getArrayOrTupleTargetType(node) {
                const readonly = isReadonlyTypeOperator(node.parent);
                const elementType = getArrayElementTypeNode(node);
                if (elementType) {
                    return readonly ? globalReadonlyArrayType : globalArrayType;
                }
                const elementFlags = map(node.elements, getTupleElementFlags);
                const missingName = some(node.elements, (e) => e.kind !== 199 /* NamedTupleMember */);
                return getTupleTargetType(elementFlags, readonly, 
                /*associatedNames*/
                missingName ? void 0 : node.elements);
            }
            function isDeferredTypeReferenceNode(node, hasDefaultTypeArguments) {
                return !!getAliasSymbolForTypeNode(node) || isResolvedByTypeAlias(node) && (node.kind === 185 /* ArrayType */ ? mayResolveTypeAlias(node.elementType) : node.kind === 186 /* TupleType */ ? some(node.elements, mayResolveTypeAlias) : hasDefaultTypeArguments || some(node.typeArguments, mayResolveTypeAlias));
            }
            function isResolvedByTypeAlias(node) {
                const parent2 = node.parent;
                switch (parent2.kind) {
                    case 193 /* ParenthesizedType */:
                    case 199 /* NamedTupleMember */:
                    case 180 /* TypeReference */:
                    case 189 /* UnionType */:
                    case 190 /* IntersectionType */:
                    case 196 /* IndexedAccessType */:
                    case 191 /* ConditionalType */:
                    case 195 /* TypeOperator */:
                    case 185 /* ArrayType */:
                    case 186 /* TupleType */:
                        return isResolvedByTypeAlias(parent2);
                    case 262 /* TypeAliasDeclaration */:
                        return true;
                }
                return false;
            }
            function mayResolveTypeAlias(node) {
                switch (node.kind) {
                    case 180 /* TypeReference */:
                        return isJSDocTypeReference(node) || !!(resolveTypeReferenceName(node, 788968 /* Type */).flags & 524288 /* TypeAlias */);
                    case 183 /* TypeQuery */:
                        return true;
                    case 195 /* TypeOperator */:
                        return node.operator !== 156 /* UniqueKeyword */ && mayResolveTypeAlias(node.type);
                    case 193 /* ParenthesizedType */:
                    case 187 /* OptionalType */:
                    case 199 /* NamedTupleMember */:
                    case 319 /* JSDocOptionalType */:
                    case 317 /* JSDocNullableType */:
                    case 318 /* JSDocNonNullableType */:
                    case 312 /* JSDocTypeExpression */:
                        return mayResolveTypeAlias(node.type);
                    case 188 /* RestType */:
                        return node.type.kind !== 185 /* ArrayType */ || mayResolveTypeAlias(node.type.elementType);
                    case 189 /* UnionType */:
                    case 190 /* IntersectionType */:
                        return some(node.types, mayResolveTypeAlias);
                    case 196 /* IndexedAccessType */:
                        return mayResolveTypeAlias(node.objectType) || mayResolveTypeAlias(node.indexType);
                    case 191 /* ConditionalType */:
                        return mayResolveTypeAlias(node.checkType) || mayResolveTypeAlias(node.extendsType) || mayResolveTypeAlias(node.trueType) || mayResolveTypeAlias(node.falseType);
                }
                return false;
            }
            function getTypeFromArrayOrTupleTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const target = getArrayOrTupleTargetType(node);
                    if (target === emptyGenericType) {
                        links.resolvedType = emptyObjectType;
                    }
                    else if (!(node.kind === 186 /* TupleType */ && some(node.elements, (e) => !!(getTupleElementFlags(e) & 8 /* Variadic */))) && isDeferredTypeReferenceNode(node)) {
                        links.resolvedType = node.kind === 186 /* TupleType */ && node.elements.length === 0 ? target : createDeferredTypeReference(target, node, 
                        /*mapper*/
                        void 0);
                    }
                    else {
                        const elementTypes = node.kind === 185 /* ArrayType */ ? [getTypeFromTypeNode(node.elementType)] : map(node.elements, getTypeFromTypeNode);
                        links.resolvedType = createNormalizedTypeReference(target, elementTypes);
                    }
                }
                return links.resolvedType;
            }
            function isReadonlyTypeOperator(node) {
                return isTypeOperatorNode(node) && node.operator === 146 /* ReadonlyKeyword */;
            }
            function createTupleType(elementTypes, elementFlags, readonly = false, namedMemberDeclarations) {
                const tupleTarget = getTupleTargetType(elementFlags || map(elementTypes, (_) => 1 /* Required */), readonly, namedMemberDeclarations);
                return tupleTarget === emptyGenericType ? emptyObjectType : elementTypes.length ? createNormalizedTypeReference(tupleTarget, elementTypes) : tupleTarget;
            }
            function getTupleTargetType(elementFlags, readonly, namedMemberDeclarations) {
                if (elementFlags.length === 1 && elementFlags[0] & 4 /* Rest */) {
                    return readonly ? globalReadonlyArrayType : globalArrayType;
                }
                const key = map(elementFlags, (f) => f & 1 /* Required */ ? "#" : f & 2 /* Optional */ ? "?" : f & 4 /* Rest */ ? "." : "*").join() + (readonly ? "R" : "") + (namedMemberDeclarations && namedMemberDeclarations.length ? "," + map(namedMemberDeclarations, getNodeId).join(",") : "");
                let type = tupleTypes.get(key);
                if (!type) {
                    tupleTypes.set(key, type = createTupleTargetType(elementFlags, readonly, namedMemberDeclarations));
                }
                return type;
            }
            function createTupleTargetType(elementFlags, readonly, namedMemberDeclarations) {
                const arity = elementFlags.length;
                const minLength = countWhere(elementFlags, (f) => !!(f & (1 /* Required */ | 8 /* Variadic */)));
                let typeParameters;
                const properties = [];
                let combinedFlags = 0;
                if (arity) {
                    typeParameters = new Array(arity);
                    for (let i = 0; i < arity; i++) {
                        const typeParameter = typeParameters[i] = createTypeParameter();
                        const flags = elementFlags[i];
                        combinedFlags |= flags;
                        if (!(combinedFlags & 12 /* Variable */)) {
                            const property = createSymbol(4 /* Property */ | (flags & 2 /* Optional */ ? 16777216 /* Optional */ : 0), "" + i, readonly ? 8 /* Readonly */ : 0);
                            property.links.tupleLabelDeclaration = namedMemberDeclarations == null ? void 0 : namedMemberDeclarations[i];
                            property.links.type = typeParameter;
                            properties.push(property);
                        }
                    }
                }
                const fixedLength = properties.length;
                const lengthSymbol = createSymbol(4 /* Property */, "length", readonly ? 8 /* Readonly */ : 0);
                if (combinedFlags & 12 /* Variable */) {
                    lengthSymbol.links.type = numberType;
                }
                else {
                    const literalTypes = [];
                    for (let i = minLength; i <= arity; i++)
                        literalTypes.push(getNumberLiteralType(i));
                    lengthSymbol.links.type = getUnionType(literalTypes);
                }
                properties.push(lengthSymbol);
                const type = createObjectType(8 /* Tuple */ | 4 /* Reference */);
                type.typeParameters = typeParameters;
                type.outerTypeParameters = void 0;
                type.localTypeParameters = typeParameters;
                type.instantiations = /* @__PURE__ */ new Map();
                type.instantiations.set(getTypeListId(type.typeParameters), type);
                type.target = type;
                type.resolvedTypeArguments = type.typeParameters;
                type.thisType = createTypeParameter();
                type.thisType.isThisType = true;
                type.thisType.constraint = type;
                type.declaredProperties = properties;
                type.declaredCallSignatures = emptyArray;
                type.declaredConstructSignatures = emptyArray;
                type.declaredIndexInfos = emptyArray;
                type.elementFlags = elementFlags;
                type.minLength = minLength;
                type.fixedLength = fixedLength;
                type.hasRestElement = !!(combinedFlags & 12 /* Variable */);
                type.combinedFlags = combinedFlags;
                type.readonly = readonly;
                type.labeledElementDeclarations = namedMemberDeclarations;
                return type;
            }
            function createNormalizedTypeReference(target, typeArguments) {
                return target.objectFlags & 8 /* Tuple */ ? createNormalizedTupleType(target, typeArguments) : createTypeReference(target, typeArguments);
            }
            function createNormalizedTupleType(target, elementTypes) {
                var _a2, _b, _c;
                if (!(target.combinedFlags & 14 /* NonRequired */)) {
                    return createTypeReference(target, elementTypes);
                }
                if (target.combinedFlags & 8 /* Variadic */) {
                    const unionIndex = findIndex(elementTypes, (t, i) => !!(target.elementFlags[i] & 8 /* Variadic */ && t.flags & (131072 /* Never */ | 1048576 /* Union */)));
                    if (unionIndex >= 0) {
                        return checkCrossProductUnion(map(elementTypes, (t, i) => target.elementFlags[i] & 8 /* Variadic */ ? t : unknownType)) ? mapType(elementTypes[unionIndex], (t) => createNormalizedTupleType(target, replaceElement(elementTypes, unionIndex, t))) : errorType;
                    }
                }
                const expandedTypes = [];
                const expandedFlags = [];
                let expandedDeclarations = [];
                let lastRequiredIndex = -1;
                let firstRestIndex = -1;
                let lastOptionalOrRestIndex = -1;
                for (let i = 0; i < elementTypes.length; i++) {
                    const type = elementTypes[i];
                    const flags = target.elementFlags[i];
                    if (flags & 8 /* Variadic */) {
                        if (type.flags & 58982400 /* InstantiableNonPrimitive */ || isGenericMappedType(type)) {
                            addElement(type, 8 /* Variadic */, (_a2 = target.labeledElementDeclarations) == null ? void 0 : _a2[i]);
                        }
                        else if (isTupleType(type)) {
                            const elements = getTypeArguments(type);
                            if (elements.length + expandedTypes.length >= 1e4) {
                                error(currentNode, isPartOfTypeNode(currentNode) ? Diagnostics.Type_produces_a_tuple_type_that_is_too_large_to_represent : Diagnostics.Expression_produces_a_tuple_type_that_is_too_large_to_represent);
                                return errorType;
                            }
                            forEach(elements, (t, n) => {
                                var _a3;
                                return addElement(t, type.target.elementFlags[n], (_a3 = type.target.labeledElementDeclarations) == null ? void 0 : _a3[n]);
                            });
                        }
                        else {
                            addElement(isArrayLikeType(type) && getIndexTypeOfType(type, numberType) || errorType, 4 /* Rest */, (_b = target.labeledElementDeclarations) == null ? void 0 : _b[i]);
                        }
                    }
                    else {
                        addElement(type, flags, (_c = target.labeledElementDeclarations) == null ? void 0 : _c[i]);
                    }
                }
                for (let i = 0; i < lastRequiredIndex; i++) {
                    if (expandedFlags[i] & 2 /* Optional */)
                        expandedFlags[i] = 1 /* Required */;
                }
                if (firstRestIndex >= 0 && firstRestIndex < lastOptionalOrRestIndex) {
                    expandedTypes[firstRestIndex] = getUnionType(sameMap(expandedTypes.slice(firstRestIndex, lastOptionalOrRestIndex + 1), (t, i) => expandedFlags[firstRestIndex + i] & 8 /* Variadic */ ? getIndexedAccessType(t, numberType) : t));
                    expandedTypes.splice(firstRestIndex + 1, lastOptionalOrRestIndex - firstRestIndex);
                    expandedFlags.splice(firstRestIndex + 1, lastOptionalOrRestIndex - firstRestIndex);
                    expandedDeclarations == null ? void 0 : expandedDeclarations.splice(firstRestIndex + 1, lastOptionalOrRestIndex - firstRestIndex);
                }
                const tupleTarget = getTupleTargetType(expandedFlags, target.readonly, expandedDeclarations);
                return tupleTarget === emptyGenericType ? emptyObjectType : expandedFlags.length ? createTypeReference(tupleTarget, expandedTypes) : tupleTarget;
                function addElement(type, flags, declaration) {
                    if (flags & 1 /* Required */) {
                        lastRequiredIndex = expandedFlags.length;
                    }
                    if (flags & 4 /* Rest */ && firstRestIndex < 0) {
                        firstRestIndex = expandedFlags.length;
                    }
                    if (flags & (2 /* Optional */ | 4 /* Rest */)) {
                        lastOptionalOrRestIndex = expandedFlags.length;
                    }
                    expandedTypes.push(flags & 2 /* Optional */ ? addOptionality(type, 
                    /*isProperty*/
                    true) : type);
                    expandedFlags.push(flags);
                    if (expandedDeclarations && declaration) {
                        expandedDeclarations.push(declaration);
                    }
                    else {
                        expandedDeclarations = void 0;
                    }
                }
            }
            function sliceTupleType(type, index, endSkipCount = 0) {
                const target = type.target;
                const endIndex = getTypeReferenceArity(type) - endSkipCount;
                return index > target.fixedLength ? getRestArrayTypeOfTupleType(type) || createTupleType(emptyArray) : createTupleType(getTypeArguments(type).slice(index, endIndex), target.elementFlags.slice(index, endIndex), 
                /*readonly*/
                false, target.labeledElementDeclarations && target.labeledElementDeclarations.slice(index, endIndex));
            }
            function getKnownKeysOfTupleType(type) {
                return getUnionType(append(arrayOf(type.target.fixedLength, (i) => getStringLiteralType("" + i)), getIndexType(type.target.readonly ? globalReadonlyArrayType : globalArrayType)));
            }
            function getStartElementCount(type, flags) {
                const index = findIndex(type.elementFlags, (f) => !(f & flags));
                return index >= 0 ? index : type.elementFlags.length;
            }
            function getEndElementCount(type, flags) {
                return type.elementFlags.length - findLastIndex(type.elementFlags, (f) => !(f & flags)) - 1;
            }
            function getTypeFromOptionalTypeNode(node) {
                return addOptionality(getTypeFromTypeNode(node.type), 
                /*isProperty*/
                true);
            }
            function getTypeId(type) {
                return type.id;
            }
            function containsType(types, type) {
                return binarySearch(types, type, getTypeId, compareValues) >= 0;
            }
            function insertType(types, type) {
                const index = binarySearch(types, type, getTypeId, compareValues);
                if (index < 0) {
                    types.splice(~index, 0, type);
                    return true;
                }
                return false;
            }
            function addTypeToUnion(typeSet, includes, type) {
                const flags = type.flags;
                if (flags & 1048576 /* Union */) {
                    return addTypesToUnion(typeSet, includes | (isNamedUnionType(type) ? 1048576 /* Union */ : 0), type.types);
                }
                if (!(flags & 131072 /* Never */)) {
                    includes |= flags & 205258751 /* IncludesMask */;
                    if (flags & 465829888 /* Instantiable */)
                        includes |= 33554432 /* IncludesInstantiable */;
                    if (type === wildcardType)
                        includes |= 8388608 /* IncludesWildcard */;
                    if (!strictNullChecks && flags & 98304 /* Nullable */) {
                        if (!(getObjectFlags(type) & 65536 /* ContainsWideningType */))
                            includes |= 4194304 /* IncludesNonWideningType */;
                    }
                    else {
                        const len = typeSet.length;
                        const index = len && type.id > typeSet[len - 1].id ? ~len : binarySearch(typeSet, type, getTypeId, compareValues);
                        if (index < 0) {
                            typeSet.splice(~index, 0, type);
                        }
                    }
                }
                return includes;
            }
            function addTypesToUnion(typeSet, includes, types) {
                for (const type of types) {
                    includes = addTypeToUnion(typeSet, includes, type);
                }
                return includes;
            }
            function removeSubtypes(types, hasObjectTypes) {
                var _a2;
                if (types.length < 2) {
                    return types;
                }
                const id = getTypeListId(types);
                const match = subtypeReductionCache.get(id);
                if (match) {
                    return match;
                }
                const hasEmptyObject = hasObjectTypes && some(types, (t) => !!(t.flags & 524288 /* Object */) && !isGenericMappedType(t) && isEmptyResolvedType(resolveStructuredTypeMembers(t)));
                const len = types.length;
                let i = len;
                let count = 0;
                while (i > 0) {
                    i--;
                    const source = types[i];
                    if (hasEmptyObject || source.flags & 469499904 /* StructuredOrInstantiable */) {
                        if (source.flags & 262144 /* TypeParameter */ && getBaseConstraintOrType(source).flags & 1048576 /* Union */) {
                            if (isTypeRelatedTo(source, getUnionType(map(types, (t) => t === source ? neverType : t)), strictSubtypeRelation)) {
                                orderedRemoveItemAt(types, i);
                            }
                            continue;
                        }
                        const keyProperty = source.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 58982400 /* InstantiableNonPrimitive */) ? find(getPropertiesOfType(source), (p) => isUnitType(getTypeOfSymbol(p))) : void 0;
                        const keyPropertyType = keyProperty && getRegularTypeOfLiteralType(getTypeOfSymbol(keyProperty));
                        for (const target of types) {
                            if (source !== target) {
                                if (count === 1e5) {
                                    const estimatedCount = count / (len - i) * len;
                                    if (estimatedCount > 1e6) {
                                        (_a2 = tracing) == null ? void 0 : _a2.instant(tracing.Phase.CheckTypes, "removeSubtypes_DepthLimit", { typeIds: types.map((t) => t.id) });
                                        error(currentNode, Diagnostics.Expression_produces_a_union_type_that_is_too_complex_to_represent);
                                        return void 0;
                                    }
                                }
                                count++;
                                if (keyProperty && target.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 58982400 /* InstantiableNonPrimitive */)) {
                                    const t = getTypeOfPropertyOfType(target, keyProperty.escapedName);
                                    if (t && isUnitType(t) && getRegularTypeOfLiteralType(t) !== keyPropertyType) {
                                        continue;
                                    }
                                }
                                if (isTypeRelatedTo(source, target, strictSubtypeRelation) && (!(getObjectFlags(getTargetType(source)) & 1 /* Class */) || !(getObjectFlags(getTargetType(target)) & 1 /* Class */) || isTypeDerivedFrom(source, target))) {
                                    orderedRemoveItemAt(types, i);
                                    break;
                                }
                            }
                        }
                    }
                }
                subtypeReductionCache.set(id, types);
                return types;
            }
            function removeRedundantLiteralTypes(types, includes, reduceVoidUndefined) {
                let i = types.length;
                while (i > 0) {
                    i--;
                    const t = types[i];
                    const flags = t.flags;
                    const remove = flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) && includes & 4 /* String */ || flags & 256 /* NumberLiteral */ && includes & 8 /* Number */ || flags & 2048 /* BigIntLiteral */ && includes & 64 /* BigInt */ || flags & 8192 /* UniqueESSymbol */ && includes & 4096 /* ESSymbol */ || reduceVoidUndefined && flags & 32768 /* Undefined */ && includes & 16384 /* Void */ || isFreshLiteralType(t) && containsType(types, t.regularType);
                    if (remove) {
                        orderedRemoveItemAt(types, i);
                    }
                }
            }
            function removeStringLiteralsMatchedByTemplateLiterals(types) {
                const templates = filter(types, (t) => !!(t.flags & 134217728 /* TemplateLiteral */) && isPatternLiteralType(t));
                if (templates.length) {
                    let i = types.length;
                    while (i > 0) {
                        i--;
                        const t = types[i];
                        if (t.flags & 128 /* StringLiteral */ && some(templates, (template) => isTypeMatchedByTemplateLiteralType(t, template))) {
                            orderedRemoveItemAt(types, i);
                        }
                    }
                }
            }
            function isNamedUnionType(type) {
                return !!(type.flags & 1048576 /* Union */ && (type.aliasSymbol || type.origin));
            }
            function addNamedUnions(namedUnions, types) {
                for (const t of types) {
                    if (t.flags & 1048576 /* Union */) {
                        const origin = t.origin;
                        if (t.aliasSymbol || origin && !(origin.flags & 1048576 /* Union */)) {
                            pushIfUnique(namedUnions, t);
                        }
                        else if (origin && origin.flags & 1048576 /* Union */) {
                            addNamedUnions(namedUnions, origin.types);
                        }
                    }
                }
            }
            function createOriginUnionOrIntersectionType(flags, types) {
                const result = createOriginType(flags);
                result.types = types;
                return result;
            }
            function getUnionType(types, unionReduction = 1 /* Literal */, aliasSymbol, aliasTypeArguments, origin) {
                if (types.length === 0) {
                    return neverType;
                }
                if (types.length === 1) {
                    return types[0];
                }
                let typeSet = [];
                const includes = addTypesToUnion(typeSet, 0, types);
                if (unionReduction !== 0 /* None */) {
                    if (includes & 3 /* AnyOrUnknown */) {
                        return includes & 1 /* Any */ ? includes & 8388608 /* IncludesWildcard */ ? wildcardType : anyType : includes & 65536 /* Null */ || containsType(typeSet, unknownType) ? unknownType : nonNullUnknownType;
                    }
                    if (includes & 32768 /* Undefined */) {
                        if (typeSet.length >= 2 && typeSet[0] === undefinedType && typeSet[1] === missingType) {
                            orderedRemoveItemAt(typeSet, 1);
                        }
                    }
                    if (includes & (32 /* Enum */ | 2944 /* Literal */ | 8192 /* UniqueESSymbol */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) || includes & 16384 /* Void */ && includes & 32768 /* Undefined */) {
                        removeRedundantLiteralTypes(typeSet, includes, !!(unionReduction & 2 /* Subtype */));
                    }
                    if (includes & 128 /* StringLiteral */ && includes & 134217728 /* TemplateLiteral */) {
                        removeStringLiteralsMatchedByTemplateLiterals(typeSet);
                    }
                    if (unionReduction === 2 /* Subtype */) {
                        typeSet = removeSubtypes(typeSet, !!(includes & 524288 /* Object */));
                        if (!typeSet) {
                            return errorType;
                        }
                    }
                    if (typeSet.length === 0) {
                        return includes & 65536 /* Null */ ? includes & 4194304 /* IncludesNonWideningType */ ? nullType : nullWideningType : includes & 32768 /* Undefined */ ? includes & 4194304 /* IncludesNonWideningType */ ? undefinedType : undefinedWideningType : neverType;
                    }
                }
                if (!origin && includes & 1048576 /* Union */) {
                    const namedUnions = [];
                    addNamedUnions(namedUnions, types);
                    const reducedTypes = [];
                    for (const t of typeSet) {
                        if (!some(namedUnions, (union) => containsType(union.types, t))) {
                            reducedTypes.push(t);
                        }
                    }
                    if (!aliasSymbol && namedUnions.length === 1 && reducedTypes.length === 0) {
                        return namedUnions[0];
                    }
                    const namedTypesCount = reduceLeft(namedUnions, (sum, union) => sum + union.types.length, 0);
                    if (namedTypesCount + reducedTypes.length === typeSet.length) {
                        for (const t of namedUnions) {
                            insertType(reducedTypes, t);
                        }
                        origin = createOriginUnionOrIntersectionType(1048576 /* Union */, reducedTypes);
                    }
                }
                const objectFlags = (includes & 36323363 /* NotPrimitiveUnion */ ? 0 : 32768 /* PrimitiveUnion */) | (includes & 2097152 /* Intersection */ ? 16777216 /* ContainsIntersections */ : 0);
                return getUnionTypeFromSortedList(typeSet, objectFlags, aliasSymbol, aliasTypeArguments, origin);
            }
            function getUnionOrIntersectionTypePredicate(signatures, kind) {
                let first2;
                const types = [];
                for (const sig of signatures) {
                    const pred = getTypePredicateOfSignature(sig);
                    if (!pred || pred.kind === 2 /* AssertsThis */ || pred.kind === 3 /* AssertsIdentifier */) {
                        if (kind !== 2097152 /* Intersection */) {
                            continue;
                        }
                        else {
                            return;
                        }
                    }
                    if (first2) {
                        if (!typePredicateKindsMatch(first2, pred)) {
                            return void 0;
                        }
                    }
                    else {
                        first2 = pred;
                    }
                    types.push(pred.type);
                }
                if (!first2) {
                    return void 0;
                }
                const compositeType = getUnionOrIntersectionType(types, kind);
                return createTypePredicate(first2.kind, first2.parameterName, first2.parameterIndex, compositeType);
            }
            function typePredicateKindsMatch(a, b) {
                return a.kind === b.kind && a.parameterIndex === b.parameterIndex;
            }
            function getUnionTypeFromSortedList(types, precomputedObjectFlags, aliasSymbol, aliasTypeArguments, origin) {
                if (types.length === 0) {
                    return neverType;
                }
                if (types.length === 1) {
                    return types[0];
                }
                const typeKey = !origin ? getTypeListId(types) : origin.flags & 1048576 /* Union */ ? `|${getTypeListId(origin.types)}` : origin.flags & 2097152 /* Intersection */ ? `&${getTypeListId(origin.types)}` : `#${origin.type.id}|${getTypeListId(types)}`;
                const id = typeKey + getAliasId(aliasSymbol, aliasTypeArguments);
                let type = unionTypes.get(id);
                if (!type) {
                    type = createType(1048576 /* Union */);
                    type.objectFlags = precomputedObjectFlags | getPropagatingFlagsOfTypes(types, 
                    /*excludeKinds*/
                    98304 /* Nullable */);
                    type.types = types;
                    type.origin = origin;
                    type.aliasSymbol = aliasSymbol;
                    type.aliasTypeArguments = aliasTypeArguments;
                    if (types.length === 2 && types[0].flags & 512 /* BooleanLiteral */ && types[1].flags & 512 /* BooleanLiteral */) {
                        type.flags |= 16 /* Boolean */;
                        type.intrinsicName = "boolean";
                    }
                    unionTypes.set(id, type);
                }
                return type;
            }
            function getTypeFromUnionTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    links.resolvedType = getUnionType(map(node.types, getTypeFromTypeNode), 1 /* Literal */, aliasSymbol, getTypeArgumentsForAliasSymbol(aliasSymbol));
                }
                return links.resolvedType;
            }
            function addTypeToIntersection(typeSet, includes, type) {
                const flags = type.flags;
                if (flags & 2097152 /* Intersection */) {
                    return addTypesToIntersection(typeSet, includes, type.types);
                }
                if (isEmptyAnonymousObjectType(type)) {
                    if (!(includes & 16777216 /* IncludesEmptyObject */)) {
                        includes |= 16777216 /* IncludesEmptyObject */;
                        typeSet.set(type.id.toString(), type);
                    }
                }
                else {
                    if (flags & 3 /* AnyOrUnknown */) {
                        if (type === wildcardType)
                            includes |= 8388608 /* IncludesWildcard */;
                    }
                    else if (strictNullChecks || !(flags & 98304 /* Nullable */)) {
                        if (type === missingType) {
                            includes |= 262144 /* IncludesMissingType */;
                            type = undefinedType;
                        }
                        if (!typeSet.has(type.id.toString())) {
                            if (type.flags & 109472 /* Unit */ && includes & 109472 /* Unit */) {
                                includes |= 67108864 /* NonPrimitive */;
                            }
                            typeSet.set(type.id.toString(), type);
                        }
                    }
                    includes |= flags & 205258751 /* IncludesMask */;
                }
                return includes;
            }
            function addTypesToIntersection(typeSet, includes, types) {
                for (const type of types) {
                    includes = addTypeToIntersection(typeSet, includes, getRegularTypeOfLiteralType(type));
                }
                return includes;
            }
            function removeRedundantSupertypes(types, includes) {
                let i = types.length;
                while (i > 0) {
                    i--;
                    const t = types[i];
                    const remove = t.flags & 4 /* String */ && includes & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) || t.flags & 8 /* Number */ && includes & 256 /* NumberLiteral */ || t.flags & 64 /* BigInt */ && includes & 2048 /* BigIntLiteral */ || t.flags & 4096 /* ESSymbol */ && includes & 8192 /* UniqueESSymbol */ || t.flags & 16384 /* Void */ && includes & 32768 /* Undefined */ || isEmptyAnonymousObjectType(t) && includes & 470302716 /* DefinitelyNonNullable */;
                    if (remove) {
                        orderedRemoveItemAt(types, i);
                    }
                }
            }
            function eachUnionContains(unionTypes2, type) {
                for (const u of unionTypes2) {
                    if (!containsType(u.types, type)) {
                        const primitive = type.flags & 128 /* StringLiteral */ ? stringType : type.flags & 256 /* NumberLiteral */ ? numberType : type.flags & 2048 /* BigIntLiteral */ ? bigintType : type.flags & 8192 /* UniqueESSymbol */ ? esSymbolType : void 0;
                        if (!primitive || !containsType(u.types, primitive)) {
                            return false;
                        }
                    }
                }
                return true;
            }
            function extractRedundantTemplateLiterals(types) {
                let i = types.length;
                const literals = filter(types, (t) => !!(t.flags & 128 /* StringLiteral */));
                while (i > 0) {
                    i--;
                    const t = types[i];
                    if (!(t.flags & 134217728 /* TemplateLiteral */))
                        continue;
                    for (const t2 of literals) {
                        if (isTypeSubtypeOf(t2, t)) {
                            orderedRemoveItemAt(types, i);
                            break;
                        }
                        else if (isPatternLiteralType(t)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function eachIsUnionContaining(types, flag) {
                return every(types, (t) => !!(t.flags & 1048576 /* Union */) && some(t.types, (tt) => !!(tt.flags & flag)));
            }
            function removeFromEach(types, flag) {
                for (let i = 0; i < types.length; i++) {
                    types[i] = filterType(types[i], (t) => !(t.flags & flag));
                }
            }
            function intersectUnionsOfPrimitiveTypes(types) {
                let unionTypes2;
                const index = findIndex(types, (t) => !!(getObjectFlags(t) & 32768 /* PrimitiveUnion */));
                if (index < 0) {
                    return false;
                }
                let i = index + 1;
                while (i < types.length) {
                    const t = types[i];
                    if (getObjectFlags(t) & 32768 /* PrimitiveUnion */) {
                        (unionTypes2 || (unionTypes2 = [types[index]])).push(t);
                        orderedRemoveItemAt(types, i);
                    }
                    else {
                        i++;
                    }
                }
                if (!unionTypes2) {
                    return false;
                }
                const checked = [];
                const result = [];
                for (const u of unionTypes2) {
                    for (const t of u.types) {
                        if (insertType(checked, t)) {
                            if (eachUnionContains(unionTypes2, t)) {
                                insertType(result, t);
                            }
                        }
                    }
                }
                types[index] = getUnionTypeFromSortedList(result, 32768 /* PrimitiveUnion */);
                return true;
            }
            function createIntersectionType(types, aliasSymbol, aliasTypeArguments) {
                const result = createType(2097152 /* Intersection */);
                result.objectFlags = getPropagatingFlagsOfTypes(types, 
                /*excludeKinds*/
                98304 /* Nullable */);
                result.types = types;
                result.aliasSymbol = aliasSymbol;
                result.aliasTypeArguments = aliasTypeArguments;
                return result;
            }
            function getIntersectionType(types, aliasSymbol, aliasTypeArguments, noSupertypeReduction) {
                const typeMembershipMap = /* @__PURE__ */ new Map();
                const includes = addTypesToIntersection(typeMembershipMap, 0, types);
                const typeSet = arrayFrom(typeMembershipMap.values());
                if (includes & 131072 /* Never */) {
                    return contains(typeSet, silentNeverType) ? silentNeverType : neverType;
                }
                if (strictNullChecks && includes & 98304 /* Nullable */ && includes & (524288 /* Object */ | 67108864 /* NonPrimitive */ | 16777216 /* IncludesEmptyObject */) || includes & 67108864 /* NonPrimitive */ && includes & (469892092 /* DisjointDomains */ & ~67108864 /* NonPrimitive */) || includes & 402653316 /* StringLike */ && includes & (469892092 /* DisjointDomains */ & ~402653316 /* StringLike */) || includes & 296 /* NumberLike */ && includes & (469892092 /* DisjointDomains */ & ~296 /* NumberLike */) || includes & 2112 /* BigIntLike */ && includes & (469892092 /* DisjointDomains */ & ~2112 /* BigIntLike */) || includes & 12288 /* ESSymbolLike */ && includes & (469892092 /* DisjointDomains */ & ~12288 /* ESSymbolLike */) || includes & 49152 /* VoidLike */ && includes & (469892092 /* DisjointDomains */ & ~49152 /* VoidLike */)) {
                    return neverType;
                }
                if (includes & 134217728 /* TemplateLiteral */ && includes & 128 /* StringLiteral */ && extractRedundantTemplateLiterals(typeSet)) {
                    return neverType;
                }
                if (includes & 1 /* Any */) {
                    return includes & 8388608 /* IncludesWildcard */ ? wildcardType : anyType;
                }
                if (!strictNullChecks && includes & 98304 /* Nullable */) {
                    return includes & 16777216 /* IncludesEmptyObject */ ? neverType : includes & 32768 /* Undefined */ ? undefinedType : nullType;
                }
                if (includes & 4 /* String */ && includes & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) || includes & 8 /* Number */ && includes & 256 /* NumberLiteral */ || includes & 64 /* BigInt */ && includes & 2048 /* BigIntLiteral */ || includes & 4096 /* ESSymbol */ && includes & 8192 /* UniqueESSymbol */ || includes & 16384 /* Void */ && includes & 32768 /* Undefined */ || includes & 16777216 /* IncludesEmptyObject */ && includes & 470302716 /* DefinitelyNonNullable */) {
                    if (!noSupertypeReduction)
                        removeRedundantSupertypes(typeSet, includes);
                }
                if (includes & 262144 /* IncludesMissingType */) {
                    typeSet[typeSet.indexOf(undefinedType)] = missingType;
                }
                if (typeSet.length === 0) {
                    return unknownType;
                }
                if (typeSet.length === 1) {
                    return typeSet[0];
                }
                const id = getTypeListId(typeSet) + getAliasId(aliasSymbol, aliasTypeArguments);
                let result = intersectionTypes.get(id);
                if (!result) {
                    if (includes & 1048576 /* Union */) {
                        if (intersectUnionsOfPrimitiveTypes(typeSet)) {
                            result = getIntersectionType(typeSet, aliasSymbol, aliasTypeArguments);
                        }
                        else if (eachIsUnionContaining(typeSet, 32768 /* Undefined */)) {
                            const containedUndefinedType = some(typeSet, containsMissingType) ? missingType : undefinedType;
                            removeFromEach(typeSet, 32768 /* Undefined */);
                            result = getUnionType([getIntersectionType(typeSet), containedUndefinedType], 1 /* Literal */, aliasSymbol, aliasTypeArguments);
                        }
                        else if (eachIsUnionContaining(typeSet, 65536 /* Null */)) {
                            removeFromEach(typeSet, 65536 /* Null */);
                            result = getUnionType([getIntersectionType(typeSet), nullType], 1 /* Literal */, aliasSymbol, aliasTypeArguments);
                        }
                        else {
                            if (!checkCrossProductUnion(typeSet)) {
                                return errorType;
                            }
                            const constituents = getCrossProductIntersections(typeSet);
                            const origin = some(constituents, (t) => !!(t.flags & 2097152 /* Intersection */)) && getConstituentCountOfTypes(constituents) > getConstituentCountOfTypes(typeSet) ? createOriginUnionOrIntersectionType(2097152 /* Intersection */, typeSet) : void 0;
                            result = getUnionType(constituents, 1 /* Literal */, aliasSymbol, aliasTypeArguments, origin);
                        }
                    }
                    else {
                        result = createIntersectionType(typeSet, aliasSymbol, aliasTypeArguments);
                    }
                    intersectionTypes.set(id, result);
                }
                return result;
            }
            function getCrossProductUnionSize(types) {
                return reduceLeft(types, (n, t) => t.flags & 1048576 /* Union */ ? n * t.types.length : t.flags & 131072 /* Never */ ? 0 : n, 1);
            }
            function checkCrossProductUnion(types) {
                var _a2;
                const size = getCrossProductUnionSize(types);
                if (size >= 1e5) {
                    (_a2 = tracing) == null ? void 0 : _a2.instant(tracing.Phase.CheckTypes, "checkCrossProductUnion_DepthLimit", { typeIds: types.map((t) => t.id), size });
                    error(currentNode, Diagnostics.Expression_produces_a_union_type_that_is_too_complex_to_represent);
                    return false;
                }
                return true;
            }
            function getCrossProductIntersections(types) {
                const count = getCrossProductUnionSize(types);
                const intersections = [];
                for (let i = 0; i < count; i++) {
                    const constituents = types.slice();
                    let n = i;
                    for (let j = types.length - 1; j >= 0; j--) {
                        if (types[j].flags & 1048576 /* Union */) {
                            const sourceTypes = types[j].types;
                            const length2 = sourceTypes.length;
                            constituents[j] = sourceTypes[n % length2];
                            n = Math.floor(n / length2);
                        }
                    }
                    const t = getIntersectionType(constituents);
                    if (!(t.flags & 131072 /* Never */))
                        intersections.push(t);
                }
                return intersections;
            }
            function getConstituentCount(type) {
                return !(type.flags & 3145728 /* UnionOrIntersection */) || type.aliasSymbol ? 1 : type.flags & 1048576 /* Union */ && type.origin ? getConstituentCount(type.origin) : getConstituentCountOfTypes(type.types);
            }
            function getConstituentCountOfTypes(types) {
                return reduceLeft(types, (n, t) => n + getConstituentCount(t), 0);
            }
            function getTypeFromIntersectionTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    const types = map(node.types, getTypeFromTypeNode);
                    const noSupertypeReduction = types.length === 2 && !!(types[0].flags & (4 /* String */ | 8 /* Number */ | 64 /* BigInt */)) && types[1] === emptyTypeLiteralType;
                    links.resolvedType = getIntersectionType(types, aliasSymbol, getTypeArgumentsForAliasSymbol(aliasSymbol), noSupertypeReduction);
                }
                return links.resolvedType;
            }
            function createIndexType(type, stringsOnly) {
                const result = createType(4194304 /* Index */);
                result.type = type;
                result.stringsOnly = stringsOnly;
                return result;
            }
            function createOriginIndexType(type) {
                const result = createOriginType(4194304 /* Index */);
                result.type = type;
                return result;
            }
            function getIndexTypeForGenericType(type, stringsOnly) {
                return stringsOnly ? type.resolvedStringIndexType || (type.resolvedStringIndexType = createIndexType(type, 
                /*stringsOnly*/
                true)) : type.resolvedIndexType || (type.resolvedIndexType = createIndexType(type, 
                /*stringsOnly*/
                false));
            }
            function getIndexTypeForMappedType(type, stringsOnly, noIndexSignatures) {
                const typeParameter = getTypeParameterFromMappedType(type);
                const constraintType = getConstraintTypeFromMappedType(type);
                const nameType = getNameTypeFromMappedType(type.target || type);
                if (!nameType && !noIndexSignatures) {
                    return constraintType;
                }
                const keyTypes = [];
                if (isMappedTypeWithKeyofConstraintDeclaration(type)) {
                    if (!isGenericIndexType(constraintType)) {
                        const modifiersType = getApparentType(getModifiersTypeFromMappedType(type));
                        forEachMappedTypePropertyKeyTypeAndIndexSignatureKeyType(modifiersType, 8576 /* StringOrNumberLiteralOrUnique */, stringsOnly, addMemberForKeyType);
                    }
                    else {
                        return getIndexTypeForGenericType(type, stringsOnly);
                    }
                }
                else {
                    forEachType(getLowerBoundOfKeyType(constraintType), addMemberForKeyType);
                }
                if (isGenericIndexType(constraintType)) {
                    forEachType(constraintType, addMemberForKeyType);
                }
                const result = noIndexSignatures ? filterType(getUnionType(keyTypes), (t) => !(t.flags & (1 /* Any */ | 4 /* String */))) : getUnionType(keyTypes);
                if (result.flags & 1048576 /* Union */ && constraintType.flags & 1048576 /* Union */ && getTypeListId(result.types) === getTypeListId(constraintType.types)) {
                    return constraintType;
                }
                return result;
                function addMemberForKeyType(keyType) {
                    const propNameType = nameType ? instantiateType(nameType, appendTypeMapping(type.mapper, typeParameter, keyType)) : keyType;
                    keyTypes.push(propNameType === stringType ? stringOrNumberType : propNameType);
                }
            }
            function hasDistributiveNameType(mappedType) {
                const typeVariable = getTypeParameterFromMappedType(mappedType);
                return isDistributive(getNameTypeFromMappedType(mappedType) || typeVariable);
                function isDistributive(type) {
                    return type.flags & (3 /* AnyOrUnknown */ | 134348796 /* Primitive */ | 131072 /* Never */ | 262144 /* TypeParameter */ | 524288 /* Object */ | 67108864 /* NonPrimitive */) ? true : type.flags & 16777216 /* Conditional */ ? type.root.isDistributive && type.checkType === typeVariable : type.flags & (3145728 /* UnionOrIntersection */ | 134217728 /* TemplateLiteral */) ? every(type.types, isDistributive) : type.flags & 8388608 /* IndexedAccess */ ? isDistributive(type.objectType) && isDistributive(type.indexType) : type.flags & 33554432 /* Substitution */ ? isDistributive(type.baseType) && isDistributive(type.constraint) : type.flags & 268435456 /* StringMapping */ ? isDistributive(type.type) : false;
                }
            }
            function getLiteralTypeFromPropertyName(name) {
                if (isPrivateIdentifier(name)) {
                    return neverType;
                }
                return isIdentifier(name) ? getStringLiteralType(unescapeLeadingUnderscores(name.escapedText)) : getRegularTypeOfLiteralType(isComputedPropertyName(name) ? checkComputedPropertyName(name) : checkExpression(name));
            }
            function getLiteralTypeFromProperty(prop, include, includeNonPublic) {
                if (includeNonPublic || !(getDeclarationModifierFlagsFromSymbol(prop) & 24 /* NonPublicAccessibilityModifier */)) {
                    let type = getSymbolLinks(getLateBoundSymbol(prop)).nameType;
                    if (!type) {
                        const name = getNameOfDeclaration(prop.valueDeclaration);
                        type = prop.escapedName === "default" /* Default */ ? getStringLiteralType("default") : name && getLiteralTypeFromPropertyName(name) || (!isKnownSymbol(prop) ? getStringLiteralType(symbolName(prop)) : void 0);
                    }
                    if (type && type.flags & include) {
                        return type;
                    }
                }
                return neverType;
            }
            function isKeyTypeIncluded(keyType, include) {
                return !!(keyType.flags & include || keyType.flags & 2097152 /* Intersection */ && some(keyType.types, (t) => isKeyTypeIncluded(t, include)));
            }
            function getLiteralTypeFromProperties(type, include, includeOrigin) {
                const origin = includeOrigin && (getObjectFlags(type) & (3 /* ClassOrInterface */ | 4 /* Reference */) || type.aliasSymbol) ? createOriginIndexType(type) : void 0;
                const propertyTypes = map(getPropertiesOfType(type), (prop) => getLiteralTypeFromProperty(prop, include));
                const indexKeyTypes = map(getIndexInfosOfType(type), (info) => info !== enumNumberIndexInfo && isKeyTypeIncluded(info.keyType, include) ? info.keyType === stringType && include & 8 /* Number */ ? stringOrNumberType : info.keyType : neverType);
                return getUnionType(concatenate(propertyTypes, indexKeyTypes), 1 /* Literal */, 
                /*aliasSymbol*/
                void 0, 
                /*aliasTypeArguments*/
                void 0, origin);
            }
            function isPossiblyReducibleByInstantiation(type) {
                const uniqueFilled = getUniqueLiteralFilledInstantiation(type);
                return getReducedType(uniqueFilled) !== uniqueFilled;
            }
            function shouldDeferIndexType(type) {
                return !!(type.flags & 58982400 /* InstantiableNonPrimitive */ || isGenericTupleType(type) || isGenericMappedType(type) && !hasDistributiveNameType(type) || type.flags & 1048576 /* Union */ && some(type.types, isPossiblyReducibleByInstantiation) || type.flags & 2097152 /* Intersection */ && maybeTypeOfKind(type, 465829888 /* Instantiable */) && some(type.types, isEmptyAnonymousObjectType));
            }
            function getIndexType(type, stringsOnly = keyofStringsOnly, noIndexSignatures) {
                type = getReducedType(type);
                return shouldDeferIndexType(type) ? getIndexTypeForGenericType(type, stringsOnly) : type.flags & 1048576 /* Union */ ? getIntersectionType(map(type.types, (t) => getIndexType(t, stringsOnly, noIndexSignatures))) : type.flags & 2097152 /* Intersection */ ? getUnionType(map(type.types, (t) => getIndexType(t, stringsOnly, noIndexSignatures))) : getObjectFlags(type) & 32 /* Mapped */ ? getIndexTypeForMappedType(type, stringsOnly, noIndexSignatures) : type === wildcardType ? wildcardType : type.flags & 2 /* Unknown */ ? neverType : type.flags & (1 /* Any */ | 131072 /* Never */) ? keyofConstraintType : getLiteralTypeFromProperties(type, (noIndexSignatures ? 128 /* StringLiteral */ : 402653316 /* StringLike */) | (stringsOnly ? 0 : 296 /* NumberLike */ | 12288 /* ESSymbolLike */), stringsOnly === keyofStringsOnly && !noIndexSignatures);
            }
            function getExtractStringType(type) {
                if (keyofStringsOnly) {
                    return type;
                }
                const extractTypeAlias = getGlobalExtractSymbol();
                return extractTypeAlias ? getTypeAliasInstantiation(extractTypeAlias, [type, stringType]) : stringType;
            }
            function getIndexTypeOrString(type) {
                const indexType = getExtractStringType(getIndexType(type));
                return indexType.flags & 131072 /* Never */ ? stringType : indexType;
            }
            function getTypeFromTypeOperatorNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    switch (node.operator) {
                        case 141 /* KeyOfKeyword */:
                            links.resolvedType = getIndexType(getTypeFromTypeNode(node.type));
                            break;
                        case 156 /* UniqueKeyword */:
                            links.resolvedType = node.type.kind === 153 /* SymbolKeyword */ ? getESSymbolLikeTypeForNode(walkUpParenthesizedTypes(node.parent)) : errorType;
                            break;
                        case 146 /* ReadonlyKeyword */:
                            links.resolvedType = getTypeFromTypeNode(node.type);
                            break;
                        default:
                            throw Debug.assertNever(node.operator);
                    }
                }
                return links.resolvedType;
            }
            function getTypeFromTemplateTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    links.resolvedType = getTemplateLiteralType([node.head.text, ...map(node.templateSpans, (span) => span.literal.text)], map(node.templateSpans, (span) => getTypeFromTypeNode(span.type)));
                }
                return links.resolvedType;
            }
            function getTemplateLiteralType(texts, types) {
                const unionIndex = findIndex(types, (t) => !!(t.flags & (131072 /* Never */ | 1048576 /* Union */)));
                if (unionIndex >= 0) {
                    return checkCrossProductUnion(types) ? mapType(types[unionIndex], (t) => getTemplateLiteralType(texts, replaceElement(types, unionIndex, t))) : errorType;
                }
                if (contains(types, wildcardType)) {
                    return wildcardType;
                }
                const newTypes = [];
                const newTexts = [];
                let text = texts[0];
                if (!addSpans(texts, types)) {
                    return stringType;
                }
                if (newTypes.length === 0) {
                    return getStringLiteralType(text);
                }
                newTexts.push(text);
                if (every(newTexts, (t) => t === "")) {
                    if (every(newTypes, (t) => !!(t.flags & 4 /* String */))) {
                        return stringType;
                    }
                    if (newTypes.length === 1 && isPatternLiteralType(newTypes[0])) {
                        return newTypes[0];
                    }
                }
                const id = `${getTypeListId(newTypes)}|${map(newTexts, (t) => t.length).join(",")}|${newTexts.join("")}`;
                let type = templateLiteralTypes.get(id);
                if (!type) {
                    templateLiteralTypes.set(id, type = createTemplateLiteralType(newTexts, newTypes));
                }
                return type;
                function addSpans(texts2, types2) {
                    const isTextsArray = isArray(texts2);
                    for (let i = 0; i < types2.length; i++) {
                        const t = types2[i];
                        const addText = isTextsArray ? texts2[i + 1] : texts2;
                        if (t.flags & (2944 /* Literal */ | 65536 /* Null */ | 32768 /* Undefined */)) {
                            text += getTemplateStringForType(t) || "";
                            text += addText;
                            if (!isTextsArray)
                                return true;
                        }
                        else if (t.flags & 134217728 /* TemplateLiteral */) {
                            text += t.texts[0];
                            if (!addSpans(t.texts, t.types))
                                return false;
                            text += addText;
                            if (!isTextsArray)
                                return true;
                        }
                        else if (isGenericIndexType(t) || isPatternLiteralPlaceholderType(t)) {
                            newTypes.push(t);
                            newTexts.push(text);
                            text = addText;
                        }
                        else if (t.flags & 2097152 /* Intersection */) {
                            const added = addSpans(texts2[i + 1], t.types);
                            if (!added)
                                return false;
                        }
                        else if (isTextsArray) {
                            return false;
                        }
                    }
                    return true;
                }
            }
            function getTemplateStringForType(type) {
                return type.flags & 128 /* StringLiteral */ ? type.value : type.flags & 256 /* NumberLiteral */ ? "" + type.value : type.flags & 2048 /* BigIntLiteral */ ? pseudoBigIntToString(type.value) : type.flags & (512 /* BooleanLiteral */ | 98304 /* Nullable */) ? type.intrinsicName : void 0;
            }
            function createTemplateLiteralType(texts, types) {
                const type = createType(134217728 /* TemplateLiteral */);
                type.texts = texts;
                type.types = types;
                return type;
            }
            function getStringMappingType(symbol, type) {
                return type.flags & (1048576 /* Union */ | 131072 /* Never */) ? mapType(type, (t) => getStringMappingType(symbol, t)) : type.flags & 128 /* StringLiteral */ ? getStringLiteralType(applyStringMapping(symbol, type.value)) : type.flags & 134217728 /* TemplateLiteral */ ? getTemplateLiteralType(...applyTemplateStringMapping(symbol, type.texts, type.types)) : (
                // Mapping<Mapping<T>> === Mapping<T>
                type.flags & 268435456 /* StringMapping */ && symbol === type.symbol ? type : type.flags & (1 /* Any */ | 4 /* String */ | 268435456 /* StringMapping */) || isGenericIndexType(type) ? getStringMappingTypeForGenericType(symbol, type) : (
                // This handles Mapping<`${number}`> and Mapping<`${bigint}`>
                isPatternLiteralPlaceholderType(type) ? getStringMappingTypeForGenericType(symbol, getTemplateLiteralType(["", ""], [type])) : type));
            }
            function applyStringMapping(symbol, str) {
                switch (intrinsicTypeKinds.get(symbol.escapedName)) {
                    case 0 /* Uppercase */:
                        return str.toUpperCase();
                    case 1 /* Lowercase */:
                        return str.toLowerCase();
                    case 2 /* Capitalize */:
                        return str.charAt(0).toUpperCase() + str.slice(1);
                    case 3 /* Uncapitalize */:
                        return str.charAt(0).toLowerCase() + str.slice(1);
                }
                return str;
            }
            function applyTemplateStringMapping(symbol, texts, types) {
                switch (intrinsicTypeKinds.get(symbol.escapedName)) {
                    case 0 /* Uppercase */:
                        return [texts.map((t) => t.toUpperCase()), types.map((t) => getStringMappingType(symbol, t))];
                    case 1 /* Lowercase */:
                        return [texts.map((t) => t.toLowerCase()), types.map((t) => getStringMappingType(symbol, t))];
                    case 2 /* Capitalize */:
                        return [texts[0] === "" ? texts : [texts[0].charAt(0).toUpperCase() + texts[0].slice(1), ...texts.slice(1)], texts[0] === "" ? [getStringMappingType(symbol, types[0]), ...types.slice(1)] : types];
                    case 3 /* Uncapitalize */:
                        return [texts[0] === "" ? texts : [texts[0].charAt(0).toLowerCase() + texts[0].slice(1), ...texts.slice(1)], texts[0] === "" ? [getStringMappingType(symbol, types[0]), ...types.slice(1)] : types];
                }
                return [texts, types];
            }
            function getStringMappingTypeForGenericType(symbol, type) {
                const id = `${getSymbolId(symbol)},${getTypeId(type)}`;
                let result = stringMappingTypes.get(id);
                if (!result) {
                    stringMappingTypes.set(id, result = createStringMappingType(symbol, type));
                }
                return result;
            }
            function createStringMappingType(symbol, type) {
                const result = createTypeWithSymbol(268435456 /* StringMapping */, symbol);
                result.type = type;
                return result;
            }
            function createIndexedAccessType(objectType, indexType, accessFlags, aliasSymbol, aliasTypeArguments) {
                const type = createType(8388608 /* IndexedAccess */);
                type.objectType = objectType;
                type.indexType = indexType;
                type.accessFlags = accessFlags;
                type.aliasSymbol = aliasSymbol;
                type.aliasTypeArguments = aliasTypeArguments;
                return type;
            }
            function isJSLiteralType(type) {
                if (noImplicitAny) {
                    return false;
                }
                if (getObjectFlags(type) & 4096 /* JSLiteral */) {
                    return true;
                }
                if (type.flags & 1048576 /* Union */) {
                    return every(type.types, isJSLiteralType);
                }
                if (type.flags & 2097152 /* Intersection */) {
                    return some(type.types, isJSLiteralType);
                }
                if (type.flags & 465829888 /* Instantiable */) {
                    const constraint = getResolvedBaseConstraint(type);
                    return constraint !== type && isJSLiteralType(constraint);
                }
                return false;
            }
            function getPropertyNameFromIndex(indexType, accessNode) {
                return isTypeUsableAsPropertyName(indexType) ? getPropertyNameFromType(indexType) : accessNode && isPropertyName(accessNode) ? (
                // late bound names are handled in the first branch, so here we only need to handle normal names
                getPropertyNameForPropertyNameNode(accessNode)) : void 0;
            }
            function isUncalledFunctionReference(node, symbol) {
                if (symbol.flags & (16 /* Function */ | 8192 /* Method */)) {
                    const parent2 = findAncestor(node.parent, (n) => !isAccessExpression(n)) || node.parent;
                    if (isCallLikeExpression(parent2)) {
                        return isCallOrNewExpression(parent2) && isIdentifier(node) && hasMatchingArgument(parent2, node);
                    }
                    return every(symbol.declarations, (d) => !isFunctionLike(d) || !!(getCombinedNodeFlags(d) & 268435456 /* Deprecated */));
                }
                return true;
            }
            function getPropertyTypeForIndexType(originalObjectType, objectType, indexType, fullIndexType, accessNode, accessFlags) {
                var _a2;
                const accessExpression = accessNode && accessNode.kind === 209 /* ElementAccessExpression */ ? accessNode : void 0;
                const propName = accessNode && isPrivateIdentifier(accessNode) ? void 0 : getPropertyNameFromIndex(indexType, accessNode);
                if (propName !== void 0) {
                    if (accessFlags & 256 /* Contextual */) {
                        return getTypeOfPropertyOfContextualType(objectType, propName) || anyType;
                    }
                    const prop = getPropertyOfType(objectType, propName);
                    if (prop) {
                        if (accessFlags & 64 /* ReportDeprecated */ && accessNode && prop.declarations && isDeprecatedSymbol(prop) && isUncalledFunctionReference(accessNode, prop)) {
                            const deprecatedNode = (_a2 = accessExpression == null ? void 0 : accessExpression.argumentExpression) != null ? _a2 : isIndexedAccessTypeNode(accessNode) ? accessNode.indexType : accessNode;
                            addDeprecatedSuggestion(deprecatedNode, prop.declarations, propName);
                        }
                        if (accessExpression) {
                            markPropertyAsReferenced(prop, accessExpression, isSelfTypeAccess(accessExpression.expression, objectType.symbol));
                            if (isAssignmentToReadonlyEntity(accessExpression, prop, getAssignmentTargetKind(accessExpression))) {
                                error(accessExpression.argumentExpression, Diagnostics.Cannot_assign_to_0_because_it_is_a_read_only_property, symbolToString(prop));
                                return void 0;
                            }
                            if (accessFlags & 8 /* CacheSymbol */) {
                                getNodeLinks(accessNode).resolvedSymbol = prop;
                            }
                            if (isThisPropertyAccessInConstructor(accessExpression, prop)) {
                                return autoType;
                            }
                        }
                        const propType = getTypeOfSymbol(prop);
                        return accessExpression && getAssignmentTargetKind(accessExpression) !== 1 /* Definite */ ? getFlowTypeOfReference(accessExpression, propType) : accessNode && isIndexedAccessTypeNode(accessNode) && containsMissingType(propType) ? getUnionType([propType, undefinedType]) : propType;
                    }
                    if (everyType(objectType, isTupleType) && isNumericLiteralName(propName)) {
                        const index = +propName;
                        if (accessNode && everyType(objectType, (t) => !t.target.hasRestElement) && !(accessFlags & 16 /* NoTupleBoundsCheck */)) {
                            const indexNode = getIndexNodeForAccessExpression(accessNode);
                            if (isTupleType(objectType)) {
                                if (index < 0) {
                                    error(indexNode, Diagnostics.A_tuple_type_cannot_be_indexed_with_a_negative_value);
                                    return undefinedType;
                                }
                                error(indexNode, Diagnostics.Tuple_type_0_of_length_1_has_no_element_at_index_2, typeToString(objectType), getTypeReferenceArity(objectType), unescapeLeadingUnderscores(propName));
                            }
                            else {
                                error(indexNode, Diagnostics.Property_0_does_not_exist_on_type_1, unescapeLeadingUnderscores(propName), typeToString(objectType));
                            }
                        }
                        if (index >= 0) {
                            errorIfWritingToReadonlyIndex(getIndexInfoOfType(objectType, numberType));
                            return mapType(objectType, (t) => {
                                const restType = getRestTypeOfTupleType(t) || undefinedType;
                                return accessFlags & 1 /* IncludeUndefined */ ? getUnionType([restType, missingType]) : restType;
                            });
                        }
                    }
                }
                if (!(indexType.flags & 98304 /* Nullable */) && isTypeAssignableToKind(indexType, 402653316 /* StringLike */ | 296 /* NumberLike */ | 12288 /* ESSymbolLike */)) {
                    if (objectType.flags & (1 /* Any */ | 131072 /* Never */)) {
                        return objectType;
                    }
                    const indexInfo = getApplicableIndexInfo(objectType, indexType) || getIndexInfoOfType(objectType, stringType);
                    if (indexInfo) {
                        if (accessFlags & 2 /* NoIndexSignatures */ && indexInfo.keyType !== numberType) {
                            if (accessExpression) {
                                error(accessExpression, Diagnostics.Type_0_cannot_be_used_to_index_type_1, typeToString(indexType), typeToString(originalObjectType));
                            }
                            return void 0;
                        }
                        if (accessNode && indexInfo.keyType === stringType && !isTypeAssignableToKind(indexType, 4 /* String */ | 8 /* Number */)) {
                            const indexNode = getIndexNodeForAccessExpression(accessNode);
                            error(indexNode, Diagnostics.Type_0_cannot_be_used_as_an_index_type, typeToString(indexType));
                            return accessFlags & 1 /* IncludeUndefined */ ? getUnionType([indexInfo.type, missingType]) : indexInfo.type;
                        }
                        errorIfWritingToReadonlyIndex(indexInfo);
                        if (accessFlags & 1 /* IncludeUndefined */ && !(objectType.symbol && objectType.symbol.flags & (256 /* RegularEnum */ | 128 /* ConstEnum */) && (indexType.symbol && indexType.flags & 1024 /* EnumLiteral */ && getParentOfSymbol(indexType.symbol) === objectType.symbol))) {
                            return getUnionType([indexInfo.type, missingType]);
                        }
                        return indexInfo.type;
                    }
                    if (indexType.flags & 131072 /* Never */) {
                        return neverType;
                    }
                    if (isJSLiteralType(objectType)) {
                        return anyType;
                    }
                    if (accessExpression && !isConstEnumObjectType(objectType)) {
                        if (isObjectLiteralType2(objectType)) {
                            if (noImplicitAny && indexType.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */)) {
                                diagnostics.add(createDiagnosticForNode(accessExpression, Diagnostics.Property_0_does_not_exist_on_type_1, indexType.value, typeToString(objectType)));
                                return undefinedType;
                            }
                            else if (indexType.flags & (8 /* Number */ | 4 /* String */)) {
                                const types = map(objectType.properties, (property) => {
                                    return getTypeOfSymbol(property);
                                });
                                return getUnionType(append(types, undefinedType));
                            }
                        }
                        if (objectType.symbol === globalThisSymbol && propName !== void 0 && globalThisSymbol.exports.has(propName) && globalThisSymbol.exports.get(propName).flags & 418 /* BlockScoped */) {
                            error(accessExpression, Diagnostics.Property_0_does_not_exist_on_type_1, unescapeLeadingUnderscores(propName), typeToString(objectType));
                        }
                        else if (noImplicitAny && !compilerOptions.suppressImplicitAnyIndexErrors && !(accessFlags & 128 /* SuppressNoImplicitAnyError */)) {
                            if (propName !== void 0 && typeHasStaticProperty(propName, objectType)) {
                                const typeName = typeToString(objectType);
                                error(accessExpression, Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead, propName, typeName, typeName + "[" + getTextOfNode(accessExpression.argumentExpression) + "]");
                            }
                            else if (getIndexTypeOfType(objectType, numberType)) {
                                error(accessExpression.argumentExpression, Diagnostics.Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number);
                            }
                            else {
                                let suggestion;
                                if (propName !== void 0 && (suggestion = getSuggestionForNonexistentProperty(propName, objectType))) {
                                    if (suggestion !== void 0) {
                                        error(accessExpression.argumentExpression, Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2, propName, typeToString(objectType), suggestion);
                                    }
                                }
                                else {
                                    const suggestion2 = getSuggestionForNonexistentIndexSignature(objectType, accessExpression, indexType);
                                    if (suggestion2 !== void 0) {
                                        error(accessExpression, Diagnostics.Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1, typeToString(objectType), suggestion2);
                                    }
                                    else {
                                        let errorInfo;
                                        if (indexType.flags & 1024 /* EnumLiteral */) {
                                            errorInfo = chainDiagnosticMessages(
                                            /* details */
                                            void 0, Diagnostics.Property_0_does_not_exist_on_type_1, "[" + typeToString(indexType) + "]", typeToString(objectType));
                                        }
                                        else if (indexType.flags & 8192 /* UniqueESSymbol */) {
                                            const symbolName2 = getFullyQualifiedName(indexType.symbol, accessExpression);
                                            errorInfo = chainDiagnosticMessages(
                                            /* details */
                                            void 0, Diagnostics.Property_0_does_not_exist_on_type_1, "[" + symbolName2 + "]", typeToString(objectType));
                                        }
                                        else if (indexType.flags & 128 /* StringLiteral */) {
                                            errorInfo = chainDiagnosticMessages(
                                            /* details */
                                            void 0, Diagnostics.Property_0_does_not_exist_on_type_1, indexType.value, typeToString(objectType));
                                        }
                                        else if (indexType.flags & 256 /* NumberLiteral */) {
                                            errorInfo = chainDiagnosticMessages(
                                            /* details */
                                            void 0, Diagnostics.Property_0_does_not_exist_on_type_1, indexType.value, typeToString(objectType));
                                        }
                                        else if (indexType.flags & (8 /* Number */ | 4 /* String */)) {
                                            errorInfo = chainDiagnosticMessages(
                                            /* details */
                                            void 0, Diagnostics.No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1, typeToString(indexType), typeToString(objectType));
                                        }
                                        errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1, typeToString(fullIndexType), typeToString(objectType));
                                        diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(accessExpression), accessExpression, errorInfo));
                                    }
                                }
                            }
                        }
                        return void 0;
                    }
                }
                if (isJSLiteralType(objectType)) {
                    return anyType;
                }
                if (accessNode) {
                    const indexNode = getIndexNodeForAccessExpression(accessNode);
                    if (indexType.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */)) {
                        error(indexNode, Diagnostics.Property_0_does_not_exist_on_type_1, "" + indexType.value, typeToString(objectType));
                    }
                    else if (indexType.flags & (4 /* String */ | 8 /* Number */)) {
                        error(indexNode, Diagnostics.Type_0_has_no_matching_index_signature_for_type_1, typeToString(objectType), typeToString(indexType));
                    }
                    else {
                        error(indexNode, Diagnostics.Type_0_cannot_be_used_as_an_index_type, typeToString(indexType));
                    }
                }
                if (isTypeAny(indexType)) {
                    return indexType;
                }
                return void 0;
                function errorIfWritingToReadonlyIndex(indexInfo) {
                    if (indexInfo && indexInfo.isReadonly && accessExpression && (isAssignmentTarget(accessExpression) || isDeleteTarget(accessExpression))) {
                        error(accessExpression, Diagnostics.Index_signature_in_type_0_only_permits_reading, typeToString(objectType));
                    }
                }
            }
            function getIndexNodeForAccessExpression(accessNode) {
                return accessNode.kind === 209 /* ElementAccessExpression */ ? accessNode.argumentExpression : accessNode.kind === 196 /* IndexedAccessType */ ? accessNode.indexType : accessNode.kind === 164 /* ComputedPropertyName */ ? accessNode.expression : accessNode;
            }
            function isPatternLiteralPlaceholderType(type) {
                return !!(type.flags & (1 /* Any */ | 4 /* String */ | 8 /* Number */ | 64 /* BigInt */)) || isPatternLiteralType(type);
            }
            function isPatternLiteralType(type) {
                return !!(type.flags & 134217728 /* TemplateLiteral */) && every(type.types, isPatternLiteralPlaceholderType) || !!(type.flags & 268435456 /* StringMapping */) && isPatternLiteralPlaceholderType(type.type);
            }
            function isGenericType(type) {
                return !!getGenericObjectFlags(type);
            }
            function isGenericObjectType(type) {
                return !!(getGenericObjectFlags(type) & 4194304 /* IsGenericObjectType */);
            }
            function isGenericIndexType(type) {
                return !!(getGenericObjectFlags(type) & 8388608 /* IsGenericIndexType */);
            }
            function getGenericObjectFlags(type) {
                if (type.flags & 3145728 /* UnionOrIntersection */) {
                    if (!(type.objectFlags & 2097152 /* IsGenericTypeComputed */)) {
                        type.objectFlags |= 2097152 /* IsGenericTypeComputed */ | reduceLeft(type.types, (flags, t) => flags | getGenericObjectFlags(t), 0);
                    }
                    return type.objectFlags & 12582912 /* IsGenericType */;
                }
                if (type.flags & 33554432 /* Substitution */) {
                    if (!(type.objectFlags & 2097152 /* IsGenericTypeComputed */)) {
                        type.objectFlags |= 2097152 /* IsGenericTypeComputed */ | getGenericObjectFlags(type.baseType) | getGenericObjectFlags(type.constraint);
                    }
                    return type.objectFlags & 12582912 /* IsGenericType */;
                }
                return (type.flags & 58982400 /* InstantiableNonPrimitive */ || isGenericMappedType(type) || isGenericTupleType(type) ? 4194304 /* IsGenericObjectType */ : 0) | (type.flags & (58982400 /* InstantiableNonPrimitive */ | 4194304 /* Index */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) && !isPatternLiteralType(type) ? 8388608 /* IsGenericIndexType */ : 0);
            }
            function getSimplifiedType(type, writing) {
                return type.flags & 8388608 /* IndexedAccess */ ? getSimplifiedIndexedAccessType(type, writing) : type.flags & 16777216 /* Conditional */ ? getSimplifiedConditionalType(type, writing) : type;
            }
            function distributeIndexOverObjectType(objectType, indexType, writing) {
                if (objectType.flags & 1048576 /* Union */ || objectType.flags & 2097152 /* Intersection */ && !shouldDeferIndexType(objectType)) {
                    const types = map(objectType.types, (t) => getSimplifiedType(getIndexedAccessType(t, indexType), writing));
                    return objectType.flags & 2097152 /* Intersection */ || writing ? getIntersectionType(types) : getUnionType(types);
                }
            }
            function distributeObjectOverIndexType(objectType, indexType, writing) {
                if (indexType.flags & 1048576 /* Union */) {
                    const types = map(indexType.types, (t) => getSimplifiedType(getIndexedAccessType(objectType, t), writing));
                    return writing ? getIntersectionType(types) : getUnionType(types);
                }
            }
            function getSimplifiedIndexedAccessType(type, writing) {
                const cache = writing ? "simplifiedForWriting" : "simplifiedForReading";
                if (type[cache]) {
                    return type[cache] === circularConstraintType ? type : type[cache];
                }
                type[cache] = circularConstraintType;
                const objectType = getSimplifiedType(type.objectType, writing);
                const indexType = getSimplifiedType(type.indexType, writing);
                const distributedOverIndex = distributeObjectOverIndexType(objectType, indexType, writing);
                if (distributedOverIndex) {
                    return type[cache] = distributedOverIndex;
                }
                if (!(indexType.flags & 465829888 /* Instantiable */)) {
                    const distributedOverObject = distributeIndexOverObjectType(objectType, indexType, writing);
                    if (distributedOverObject) {
                        return type[cache] = distributedOverObject;
                    }
                }
                if (isGenericTupleType(objectType) && indexType.flags & 296 /* NumberLike */) {
                    const elementType = getElementTypeOfSliceOfTupleType(objectType, indexType.flags & 8 /* Number */ ? 0 : objectType.target.fixedLength, 
                    /*endSkipCount*/
                    0, writing);
                    if (elementType) {
                        return type[cache] = elementType;
                    }
                }
                if (isGenericMappedType(objectType)) {
                    if (!getNameTypeFromMappedType(objectType) || isFilteringMappedType(objectType)) {
                        return type[cache] = mapType(substituteIndexedMappedType(objectType, type.indexType), (t) => getSimplifiedType(t, writing));
                    }
                }
                return type[cache] = type;
            }
            function getSimplifiedConditionalType(type, writing) {
                const checkType = type.checkType;
                const extendsType = type.extendsType;
                const trueType2 = getTrueTypeFromConditionalType(type);
                const falseType2 = getFalseTypeFromConditionalType(type);
                if (falseType2.flags & 131072 /* Never */ && getActualTypeVariable(trueType2) === getActualTypeVariable(checkType)) {
                    if (checkType.flags & 1 /* Any */ || isTypeAssignableTo(getRestrictiveInstantiation(checkType), getRestrictiveInstantiation(extendsType))) {
                        return getSimplifiedType(trueType2, writing);
                    }
                    else if (isIntersectionEmpty(checkType, extendsType)) {
                        return neverType;
                    }
                }
                else if (trueType2.flags & 131072 /* Never */ && getActualTypeVariable(falseType2) === getActualTypeVariable(checkType)) {
                    if (!(checkType.flags & 1 /* Any */) && isTypeAssignableTo(getRestrictiveInstantiation(checkType), getRestrictiveInstantiation(extendsType))) {
                        return neverType;
                    }
                    else if (checkType.flags & 1 /* Any */ || isIntersectionEmpty(checkType, extendsType)) {
                        return getSimplifiedType(falseType2, writing);
                    }
                }
                return type;
            }
            function isIntersectionEmpty(type1, type2) {
                return !!(getUnionType([intersectTypes(type1, type2), neverType]).flags & 131072 /* Never */);
            }
            function substituteIndexedMappedType(objectType, index) {
                const mapper = createTypeMapper([getTypeParameterFromMappedType(objectType)], [index]);
                const templateMapper = combineTypeMappers(objectType.mapper, mapper);
                return instantiateType(getTemplateTypeFromMappedType(objectType.target || objectType), templateMapper);
            }
            function getIndexedAccessType(objectType, indexType, accessFlags = 0 /* None */, accessNode, aliasSymbol, aliasTypeArguments) {
                return getIndexedAccessTypeOrUndefined(objectType, indexType, accessFlags, accessNode, aliasSymbol, aliasTypeArguments) || (accessNode ? errorType : unknownType);
            }
            function indexTypeLessThan(indexType, limit) {
                return everyType(indexType, (t) => {
                    if (t.flags & 384 /* StringOrNumberLiteral */) {
                        const propName = getPropertyNameFromType(t);
                        if (isNumericLiteralName(propName)) {
                            const index = +propName;
                            return index >= 0 && index < limit;
                        }
                    }
                    return false;
                });
            }
            function getIndexedAccessTypeOrUndefined(objectType, indexType, accessFlags = 0 /* None */, accessNode, aliasSymbol, aliasTypeArguments) {
                if (objectType === wildcardType || indexType === wildcardType) {
                    return wildcardType;
                }
                if (isStringIndexSignatureOnlyType(objectType) && !(indexType.flags & 98304 /* Nullable */) && isTypeAssignableToKind(indexType, 4 /* String */ | 8 /* Number */)) {
                    indexType = stringType;
                }
                if (compilerOptions.noUncheckedIndexedAccess && accessFlags & 32 /* ExpressionPosition */)
                    accessFlags |= 1 /* IncludeUndefined */;
                if (isGenericIndexType(indexType) || (accessNode && accessNode.kind !== 196 /* IndexedAccessType */ ? isGenericTupleType(objectType) && !indexTypeLessThan(indexType, objectType.target.fixedLength) : isGenericObjectType(objectType) && !(isTupleType(objectType) && indexTypeLessThan(indexType, objectType.target.fixedLength)))) {
                    if (objectType.flags & 3 /* AnyOrUnknown */) {
                        return objectType;
                    }
                    const persistentAccessFlags = accessFlags & 1 /* Persistent */;
                    const id = objectType.id + "," + indexType.id + "," + persistentAccessFlags + getAliasId(aliasSymbol, aliasTypeArguments);
                    let type = indexedAccessTypes.get(id);
                    if (!type) {
                        indexedAccessTypes.set(id, type = createIndexedAccessType(objectType, indexType, persistentAccessFlags, aliasSymbol, aliasTypeArguments));
                    }
                    return type;
                }
                const apparentObjectType = getReducedApparentType(objectType);
                if (indexType.flags & 1048576 /* Union */ && !(indexType.flags & 16 /* Boolean */)) {
                    const propTypes = [];
                    let wasMissingProp = false;
                    for (const t of indexType.types) {
                        const propType = getPropertyTypeForIndexType(objectType, apparentObjectType, t, indexType, accessNode, accessFlags | (wasMissingProp ? 128 /* SuppressNoImplicitAnyError */ : 0));
                        if (propType) {
                            propTypes.push(propType);
                        }
                        else if (!accessNode) {
                            return void 0;
                        }
                        else {
                            wasMissingProp = true;
                        }
                    }
                    if (wasMissingProp) {
                        return void 0;
                    }
                    return accessFlags & 4 /* Writing */ ? getIntersectionType(propTypes, aliasSymbol, aliasTypeArguments) : getUnionType(propTypes, 1 /* Literal */, aliasSymbol, aliasTypeArguments);
                }
                return getPropertyTypeForIndexType(objectType, apparentObjectType, indexType, indexType, accessNode, accessFlags | 8 /* CacheSymbol */ | 64 /* ReportDeprecated */);
            }
            function getTypeFromIndexedAccessTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const objectType = getTypeFromTypeNode(node.objectType);
                    const indexType = getTypeFromTypeNode(node.indexType);
                    const potentialAlias = getAliasSymbolForTypeNode(node);
                    links.resolvedType = getIndexedAccessType(objectType, indexType, 0 /* None */, node, potentialAlias, getTypeArgumentsForAliasSymbol(potentialAlias));
                }
                return links.resolvedType;
            }
            function getTypeFromMappedTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const type = createObjectType(32 /* Mapped */, node.symbol);
                    type.declaration = node;
                    type.aliasSymbol = getAliasSymbolForTypeNode(node);
                    type.aliasTypeArguments = getTypeArgumentsForAliasSymbol(type.aliasSymbol);
                    links.resolvedType = type;
                    getConstraintTypeFromMappedType(type);
                }
                return links.resolvedType;
            }
            function getActualTypeVariable(type) {
                if (type.flags & 33554432 /* Substitution */) {
                    return getActualTypeVariable(type.baseType);
                }
                if (type.flags & 8388608 /* IndexedAccess */ && (type.objectType.flags & 33554432 /* Substitution */ || type.indexType.flags & 33554432 /* Substitution */)) {
                    return getIndexedAccessType(getActualTypeVariable(type.objectType), getActualTypeVariable(type.indexType));
                }
                return type;
            }
            function maybeCloneTypeParameter(p) {
                const constraint = getConstraintOfTypeParameter(p);
                return constraint && (isGenericObjectType(constraint) || isGenericIndexType(constraint)) ? cloneTypeParameter(p) : p;
            }
            function isSimpleTupleType(node) {
                return isTupleTypeNode(node) && length(node.elements) > 0 && !some(node.elements, (e) => isOptionalTypeNode(e) || isRestTypeNode(e) || isNamedTupleMember(e) && !!(e.questionToken || e.dotDotDotToken));
            }
            function isDeferredType(type, checkTuples) {
                return isGenericType(type) || checkTuples && isTupleType(type) && some(getTypeArguments(type), isGenericType);
            }
            function getConditionalType(root, mapper, aliasSymbol, aliasTypeArguments) {
                let result;
                let extraTypes;
                let tailCount = 0;
                while (true) {
                    if (tailCount === 1e3) {
                        error(currentNode, Diagnostics.Type_instantiation_is_excessively_deep_and_possibly_infinite);
                        result = errorType;
                        break;
                    }
                    const checkTuples = isSimpleTupleType(root.node.checkType) && isSimpleTupleType(root.node.extendsType) && length(root.node.checkType.elements) === length(root.node.extendsType.elements);
                    const checkType = instantiateType(getActualTypeVariable(root.checkType), mapper);
                    const checkTypeDeferred = isDeferredType(checkType, checkTuples);
                    const extendsType = instantiateType(root.extendsType, mapper);
                    if (checkType === wildcardType || extendsType === wildcardType) {
                        return wildcardType;
                    }
                    let combinedMapper;
                    if (root.inferTypeParameters) {
                        const freshParams = sameMap(root.inferTypeParameters, maybeCloneTypeParameter);
                        const freshMapper = freshParams !== root.inferTypeParameters ? createTypeMapper(root.inferTypeParameters, freshParams) : void 0;
                        const context = createInferenceContext(freshParams, 
                        /*signature*/
                        void 0, 0 /* None */);
                        if (freshMapper) {
                            const freshCombinedMapper = combineTypeMappers(mapper, freshMapper);
                            for (const p of freshParams) {
                                if (root.inferTypeParameters.indexOf(p) === -1) {
                                    p.mapper = freshCombinedMapper;
                                }
                            }
                        }
                        if (!checkTypeDeferred) {
                            inferTypes(context.inferences, checkType, instantiateType(extendsType, freshMapper), 512 /* NoConstraints */ | 1024 /* AlwaysStrict */);
                        }
                        const innerMapper = combineTypeMappers(freshMapper, context.mapper);
                        combinedMapper = mapper ? combineTypeMappers(innerMapper, mapper) : innerMapper;
                    }
                    const inferredExtendsType = combinedMapper ? instantiateType(root.extendsType, combinedMapper) : extendsType;
                    if (!checkTypeDeferred && !isDeferredType(inferredExtendsType, checkTuples)) {
                        if (!(inferredExtendsType.flags & 3 /* AnyOrUnknown */) && (checkType.flags & 1 /* Any */ || !isTypeAssignableTo(getPermissiveInstantiation(checkType), getPermissiveInstantiation(inferredExtendsType)))) {
                            if (checkType.flags & 1 /* Any */) {
                                (extraTypes || (extraTypes = [])).push(instantiateType(getTypeFromTypeNode(root.node.trueType), combinedMapper || mapper));
                            }
                            const falseType2 = getTypeFromTypeNode(root.node.falseType);
                            if (falseType2.flags & 16777216 /* Conditional */) {
                                const newRoot = falseType2.root;
                                if (newRoot.node.parent === root.node && (!newRoot.isDistributive || newRoot.checkType === root.checkType)) {
                                    root = newRoot;
                                    continue;
                                }
                                if (canTailRecurse(falseType2, mapper)) {
                                    continue;
                                }
                            }
                            result = instantiateType(falseType2, mapper);
                            break;
                        }
                        if (inferredExtendsType.flags & 3 /* AnyOrUnknown */ || isTypeAssignableTo(getRestrictiveInstantiation(checkType), getRestrictiveInstantiation(inferredExtendsType))) {
                            const trueType2 = getTypeFromTypeNode(root.node.trueType);
                            const trueMapper = combinedMapper || mapper;
                            if (canTailRecurse(trueType2, trueMapper)) {
                                continue;
                            }
                            result = instantiateType(trueType2, trueMapper);
                            break;
                        }
                    }
                    result = createType(16777216 /* Conditional */);
                    result.root = root;
                    result.checkType = instantiateType(root.checkType, mapper);
                    result.extendsType = instantiateType(root.extendsType, mapper);
                    result.mapper = mapper;
                    result.combinedMapper = combinedMapper;
                    result.aliasSymbol = aliasSymbol || root.aliasSymbol;
                    result.aliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(root.aliasTypeArguments, mapper);
                    break;
                }
                return extraTypes ? getUnionType(append(extraTypes, result)) : result;
                function canTailRecurse(newType, newMapper) {
                    if (newType.flags & 16777216 /* Conditional */ && newMapper) {
                        const newRoot = newType.root;
                        if (newRoot.outerTypeParameters) {
                            const typeParamMapper = combineTypeMappers(newType.mapper, newMapper);
                            const typeArguments = map(newRoot.outerTypeParameters, (t) => getMappedType(t, typeParamMapper));
                            const newRootMapper = createTypeMapper(newRoot.outerTypeParameters, typeArguments);
                            const newCheckType = newRoot.isDistributive ? getMappedType(newRoot.checkType, newRootMapper) : void 0;
                            if (!newCheckType || newCheckType === newRoot.checkType || !(newCheckType.flags & (1048576 /* Union */ | 131072 /* Never */))) {
                                root = newRoot;
                                mapper = newRootMapper;
                                aliasSymbol = void 0;
                                aliasTypeArguments = void 0;
                                if (newRoot.aliasSymbol) {
                                    tailCount++;
                                }
                                return true;
                            }
                        }
                    }
                    return false;
                }
            }
            function getTrueTypeFromConditionalType(type) {
                return type.resolvedTrueType || (type.resolvedTrueType = instantiateType(getTypeFromTypeNode(type.root.node.trueType), type.mapper));
            }
            function getFalseTypeFromConditionalType(type) {
                return type.resolvedFalseType || (type.resolvedFalseType = instantiateType(getTypeFromTypeNode(type.root.node.falseType), type.mapper));
            }
            function getInferredTrueTypeFromConditionalType(type) {
                return type.resolvedInferredTrueType || (type.resolvedInferredTrueType = type.combinedMapper ? instantiateType(getTypeFromTypeNode(type.root.node.trueType), type.combinedMapper) : getTrueTypeFromConditionalType(type));
            }
            function getInferTypeParameters(node) {
                let result;
                if (node.locals) {
                    node.locals.forEach((symbol) => {
                        if (symbol.flags & 262144 /* TypeParameter */) {
                            result = append(result, getDeclaredTypeOfSymbol(symbol));
                        }
                    });
                }
                return result;
            }
            function isDistributionDependent(root) {
                return root.isDistributive && (isTypeParameterPossiblyReferenced(root.checkType, root.node.trueType) || isTypeParameterPossiblyReferenced(root.checkType, root.node.falseType));
            }
            function getTypeFromConditionalTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const checkType = getTypeFromTypeNode(node.checkType);
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    const aliasTypeArguments = getTypeArgumentsForAliasSymbol(aliasSymbol);
                    const allOuterTypeParameters = getOuterTypeParameters(node, 
                    /*includeThisTypes*/
                    true);
                    const outerTypeParameters = aliasTypeArguments ? allOuterTypeParameters : filter(allOuterTypeParameters, (tp) => isTypeParameterPossiblyReferenced(tp, node));
                    const root = {
                        node,
                        checkType,
                        extendsType: getTypeFromTypeNode(node.extendsType),
                        isDistributive: !!(checkType.flags & 262144 /* TypeParameter */),
                        inferTypeParameters: getInferTypeParameters(node),
                        outerTypeParameters,
                        instantiations: void 0,
                        aliasSymbol,
                        aliasTypeArguments
                    };
                    links.resolvedType = getConditionalType(root, 
                    /*mapper*/
                    void 0);
                    if (outerTypeParameters) {
                        root.instantiations = /* @__PURE__ */ new Map();
                        root.instantiations.set(getTypeListId(outerTypeParameters), links.resolvedType);
                    }
                }
                return links.resolvedType;
            }
            function getTypeFromInferTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    links.resolvedType = getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(node.typeParameter));
                }
                return links.resolvedType;
            }
            function getIdentifierChain(node) {
                if (isIdentifier(node)) {
                    return [node];
                }
                else {
                    return append(getIdentifierChain(node.left), node.right);
                }
            }
            function getTypeFromImportTypeNode(node) {
                var _a2;
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    if (!isLiteralImportTypeNode(node)) {
                        error(node.argument, Diagnostics.String_literal_expected);
                        links.resolvedSymbol = unknownSymbol;
                        return links.resolvedType = errorType;
                    }
                    const targetMeaning = node.isTypeOf ? 111551 /* Value */ : node.flags & 8388608 /* JSDoc */ ? 111551 /* Value */ | 788968 /* Type */ : 788968 /* Type */;
                    const innerModuleSymbol = resolveExternalModuleName(node, node.argument.literal);
                    if (!innerModuleSymbol) {
                        links.resolvedSymbol = unknownSymbol;
                        return links.resolvedType = errorType;
                    }
                    const isExportEquals = !!((_a2 = innerModuleSymbol.exports) == null ? void 0 : _a2.get("export=" /* ExportEquals */));
                    const moduleSymbol = resolveExternalModuleSymbol(innerModuleSymbol, 
                    /*dontResolveAlias*/
                    false);
                    if (!nodeIsMissing(node.qualifier)) {
                        const nameStack = getIdentifierChain(node.qualifier);
                        let currentNamespace = moduleSymbol;
                        let current;
                        while (current = nameStack.shift()) {
                            const meaning = nameStack.length ? 1920 /* Namespace */ : targetMeaning;
                            const mergedResolvedSymbol = getMergedSymbol(resolveSymbol(currentNamespace));
                            const symbolFromVariable = node.isTypeOf || isInJSFile(node) && isExportEquals ? getPropertyOfType(getTypeOfSymbol(mergedResolvedSymbol), current.escapedText, 
                            /*skipObjectFunctionPropertyAugment*/
                            false, 
                            /*includeTypeOnlyMembers*/
                            true) : void 0;
                            const symbolFromModule = node.isTypeOf ? void 0 : getSymbol2(getExportsOfSymbol(mergedResolvedSymbol), current.escapedText, meaning);
                            const next = symbolFromModule != null ? symbolFromModule : symbolFromVariable;
                            if (!next) {
                                error(current, Diagnostics.Namespace_0_has_no_exported_member_1, getFullyQualifiedName(currentNamespace), declarationNameToString(current));
                                return links.resolvedType = errorType;
                            }
                            getNodeLinks(current).resolvedSymbol = next;
                            getNodeLinks(current.parent).resolvedSymbol = next;
                            currentNamespace = next;
                        }
                        links.resolvedType = resolveImportSymbolType(node, links, currentNamespace, targetMeaning);
                    }
                    else {
                        if (moduleSymbol.flags & targetMeaning) {
                            links.resolvedType = resolveImportSymbolType(node, links, moduleSymbol, targetMeaning);
                        }
                        else {
                            const errorMessage = targetMeaning === 111551 /* Value */ ? Diagnostics.Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here : Diagnostics.Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0;
                            error(node, errorMessage, node.argument.literal.text);
                            links.resolvedSymbol = unknownSymbol;
                            links.resolvedType = errorType;
                        }
                    }
                }
                return links.resolvedType;
            }
            function resolveImportSymbolType(node, links, symbol, meaning) {
                const resolvedSymbol = resolveSymbol(symbol);
                links.resolvedSymbol = resolvedSymbol;
                if (meaning === 111551 /* Value */) {
                    return getInstantiationExpressionType(getTypeOfSymbol(symbol), node);
                }
                else {
                    return getTypeReferenceType(node, resolvedSymbol);
                }
            }
            function getTypeFromTypeLiteralOrFunctionOrConstructorTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    if (getMembersOfSymbol(node.symbol).size === 0 && !aliasSymbol) {
                        links.resolvedType = emptyTypeLiteralType;
                    }
                    else {
                        let type = createObjectType(16 /* Anonymous */, node.symbol);
                        type.aliasSymbol = aliasSymbol;
                        type.aliasTypeArguments = getTypeArgumentsForAliasSymbol(aliasSymbol);
                        if (isJSDocTypeLiteral(node) && node.isArrayType) {
                            type = createArrayType(type);
                        }
                        links.resolvedType = type;
                    }
                }
                return links.resolvedType;
            }
            function getAliasSymbolForTypeNode(node) {
                let host2 = node.parent;
                while (isParenthesizedTypeNode(host2) || isJSDocTypeExpression(host2) || isTypeOperatorNode(host2) && host2.operator === 146 /* ReadonlyKeyword */) {
                    host2 = host2.parent;
                }
                return isTypeAlias(host2) ? getSymbolOfDeclaration(host2) : void 0;
            }
            function getTypeArgumentsForAliasSymbol(symbol) {
                return symbol ? getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol) : void 0;
            }
            function isNonGenericObjectType(type) {
                return !!(type.flags & 524288 /* Object */) && !isGenericMappedType(type);
            }
            function isEmptyObjectTypeOrSpreadsIntoEmptyObject(type) {
                return isEmptyObjectType(type) || !!(type.flags & (65536 /* Null */ | 32768 /* Undefined */ | 528 /* BooleanLike */ | 296 /* NumberLike */ | 2112 /* BigIntLike */ | 402653316 /* StringLike */ | 1056 /* EnumLike */ | 67108864 /* NonPrimitive */ | 4194304 /* Index */));
            }
            function tryMergeUnionOfObjectTypeAndEmptyObject(type, readonly) {
                if (!(type.flags & 1048576 /* Union */)) {
                    return type;
                }
                if (every(type.types, isEmptyObjectTypeOrSpreadsIntoEmptyObject)) {
                    return find(type.types, isEmptyObjectType) || emptyObjectType;
                }
                const firstType = find(type.types, (t) => !isEmptyObjectTypeOrSpreadsIntoEmptyObject(t));
                if (!firstType) {
                    return type;
                }
                const secondType = find(type.types, (t) => t !== firstType && !isEmptyObjectTypeOrSpreadsIntoEmptyObject(t));
                if (secondType) {
                    return type;
                }
                return getAnonymousPartialType(firstType);
                function getAnonymousPartialType(type2) {
                    const members = createSymbolTable();
                    for (const prop of getPropertiesOfType(type2)) {
                        if (getDeclarationModifierFlagsFromSymbol(prop) & (8 /* Private */ | 16 /* Protected */)) {
                        }
                        else if (isSpreadableProperty(prop)) {
                            const isSetonlyAccessor = prop.flags & 65536 /* SetAccessor */ && !(prop.flags & 32768 /* GetAccessor */);
                            const flags = 4 /* Property */ | 16777216 /* Optional */;
                            const result = createSymbol(flags, prop.escapedName, getIsLateCheckFlag(prop) | (readonly ? 8 /* Readonly */ : 0));
                            result.links.type = isSetonlyAccessor ? undefinedType : addOptionality(getTypeOfSymbol(prop), 
                            /*isProperty*/
                            true);
                            result.declarations = prop.declarations;
                            result.links.nameType = getSymbolLinks(prop).nameType;
                            result.links.syntheticOrigin = prop;
                            members.set(prop.escapedName, result);
                        }
                    }
                    const spread = createAnonymousType(type2.symbol, members, emptyArray, emptyArray, getIndexInfosOfType(type2));
                    spread.objectFlags |= 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                    return spread;
                }
            }
            function getSpreadType(left, right, symbol, objectFlags, readonly) {
                if (left.flags & 1 /* Any */ || right.flags & 1 /* Any */) {
                    return anyType;
                }
                if (left.flags & 2 /* Unknown */ || right.flags & 2 /* Unknown */) {
                    return unknownType;
                }
                if (left.flags & 131072 /* Never */) {
                    return right;
                }
                if (right.flags & 131072 /* Never */) {
                    return left;
                }
                left = tryMergeUnionOfObjectTypeAndEmptyObject(left, readonly);
                if (left.flags & 1048576 /* Union */) {
                    return checkCrossProductUnion([left, right]) ? mapType(left, (t) => getSpreadType(t, right, symbol, objectFlags, readonly)) : errorType;
                }
                right = tryMergeUnionOfObjectTypeAndEmptyObject(right, readonly);
                if (right.flags & 1048576 /* Union */) {
                    return checkCrossProductUnion([left, right]) ? mapType(right, (t) => getSpreadType(left, t, symbol, objectFlags, readonly)) : errorType;
                }
                if (right.flags & (528 /* BooleanLike */ | 296 /* NumberLike */ | 2112 /* BigIntLike */ | 402653316 /* StringLike */ | 1056 /* EnumLike */ | 67108864 /* NonPrimitive */ | 4194304 /* Index */)) {
                    return left;
                }
                if (isGenericObjectType(left) || isGenericObjectType(right)) {
                    if (isEmptyObjectType(left)) {
                        return right;
                    }
                    if (left.flags & 2097152 /* Intersection */) {
                        const types = left.types;
                        const lastLeft = types[types.length - 1];
                        if (isNonGenericObjectType(lastLeft) && isNonGenericObjectType(right)) {
                            return getIntersectionType(concatenate(types.slice(0, types.length - 1), [getSpreadType(lastLeft, right, symbol, objectFlags, readonly)]));
                        }
                    }
                    return getIntersectionType([left, right]);
                }
                const members = createSymbolTable();
                const skippedPrivateMembers = /* @__PURE__ */ new Set();
                const indexInfos = left === emptyObjectType ? getIndexInfosOfType(right) : getUnionIndexInfos([left, right]);
                for (const rightProp of getPropertiesOfType(right)) {
                    if (getDeclarationModifierFlagsFromSymbol(rightProp) & (8 /* Private */ | 16 /* Protected */)) {
                        skippedPrivateMembers.add(rightProp.escapedName);
                    }
                    else if (isSpreadableProperty(rightProp)) {
                        members.set(rightProp.escapedName, getSpreadSymbol(rightProp, readonly));
                    }
                }
                for (const leftProp of getPropertiesOfType(left)) {
                    if (skippedPrivateMembers.has(leftProp.escapedName) || !isSpreadableProperty(leftProp)) {
                        continue;
                    }
                    if (members.has(leftProp.escapedName)) {
                        const rightProp = members.get(leftProp.escapedName);
                        const rightType = getTypeOfSymbol(rightProp);
                        if (rightProp.flags & 16777216 /* Optional */) {
                            const declarations = concatenate(leftProp.declarations, rightProp.declarations);
                            const flags = 4 /* Property */ | leftProp.flags & 16777216 /* Optional */;
                            const result = createSymbol(flags, leftProp.escapedName);
                            result.links.type = getUnionType([getTypeOfSymbol(leftProp), removeMissingOrUndefinedType(rightType)], 2 /* Subtype */);
                            result.links.leftSpread = leftProp;
                            result.links.rightSpread = rightProp;
                            result.declarations = declarations;
                            result.links.nameType = getSymbolLinks(leftProp).nameType;
                            members.set(leftProp.escapedName, result);
                        }
                    }
                    else {
                        members.set(leftProp.escapedName, getSpreadSymbol(leftProp, readonly));
                    }
                }
                const spread = createAnonymousType(symbol, members, emptyArray, emptyArray, sameMap(indexInfos, (info) => getIndexInfoWithReadonly(info, readonly)));
                spread.objectFlags |= 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */ | 2097152 /* ContainsSpread */ | objectFlags;
                return spread;
            }
            function isSpreadableProperty(prop) {
                var _a2;
                return !some(prop.declarations, isPrivateIdentifierClassElementDeclaration) && (!(prop.flags & (8192 /* Method */ | 32768 /* GetAccessor */ | 65536 /* SetAccessor */)) || !((_a2 = prop.declarations) == null ? void 0 : _a2.some((decl) => isClassLike(decl.parent))));
            }
            function getSpreadSymbol(prop, readonly) {
                const isSetonlyAccessor = prop.flags & 65536 /* SetAccessor */ && !(prop.flags & 32768 /* GetAccessor */);
                if (!isSetonlyAccessor && readonly === isReadonlySymbol(prop)) {
                    return prop;
                }
                const flags = 4 /* Property */ | prop.flags & 16777216 /* Optional */;
                const result = createSymbol(flags, prop.escapedName, getIsLateCheckFlag(prop) | (readonly ? 8 /* Readonly */ : 0));
                result.links.type = isSetonlyAccessor ? undefinedType : getTypeOfSymbol(prop);
                result.declarations = prop.declarations;
                result.links.nameType = getSymbolLinks(prop).nameType;
                result.links.syntheticOrigin = prop;
                return result;
            }
            function getIndexInfoWithReadonly(info, readonly) {
                return info.isReadonly !== readonly ? createIndexInfo(info.keyType, info.type, readonly, info.declaration) : info;
            }
            function createLiteralType(flags, value, symbol, regularType) {
                const type = createTypeWithSymbol(flags, symbol);
                type.value = value;
                type.regularType = regularType || type;
                return type;
            }
            function getFreshTypeOfLiteralType(type) {
                if (type.flags & 2976 /* Freshable */) {
                    if (!type.freshType) {
                        const freshType = createLiteralType(type.flags, type.value, type.symbol, type);
                        freshType.freshType = freshType;
                        type.freshType = freshType;
                    }
                    return type.freshType;
                }
                return type;
            }
            function getRegularTypeOfLiteralType(type) {
                return type.flags & 2976 /* Freshable */ ? type.regularType : type.flags & 1048576 /* Union */ ? type.regularType || (type.regularType = mapType(type, getRegularTypeOfLiteralType)) : type;
            }
            function isFreshLiteralType(type) {
                return !!(type.flags & 2976 /* Freshable */) && type.freshType === type;
            }
            function getStringLiteralType(value) {
                let type;
                return stringLiteralTypes.get(value) || (stringLiteralTypes.set(value, type = createLiteralType(128 /* StringLiteral */, value)), type);
            }
            function getNumberLiteralType(value) {
                let type;
                return numberLiteralTypes.get(value) || (numberLiteralTypes.set(value, type = createLiteralType(256 /* NumberLiteral */, value)), type);
            }
            function getBigIntLiteralType(value) {
                let type;
                const key = pseudoBigIntToString(value);
                return bigIntLiteralTypes.get(key) || (bigIntLiteralTypes.set(key, type = createLiteralType(2048 /* BigIntLiteral */, value)), type);
            }
            function getEnumLiteralType(value, enumId, symbol) {
                let type;
                const key = `${enumId}${typeof value === "string" ? "@" : "#"}${value}`;
                const flags = 1024 /* EnumLiteral */ | (typeof value === "string" ? 128 /* StringLiteral */ : 256 /* NumberLiteral */);
                return enumLiteralTypes.get(key) || (enumLiteralTypes.set(key, type = createLiteralType(flags, value, symbol)), type);
            }
            function getTypeFromLiteralTypeNode(node) {
                if (node.literal.kind === 104 /* NullKeyword */) {
                    return nullType;
                }
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    links.resolvedType = getRegularTypeOfLiteralType(checkExpression(node.literal));
                }
                return links.resolvedType;
            }
            function createUniqueESSymbolType(symbol) {
                const type = createTypeWithSymbol(8192 /* UniqueESSymbol */, symbol);
                type.escapedName = `__@${type.symbol.escapedName}@${getSymbolId(type.symbol)}`;
                return type;
            }
            function getESSymbolLikeTypeForNode(node) {
                if (isValidESSymbolDeclaration(node)) {
                    const symbol = isCommonJsExportPropertyAssignment(node) ? getSymbolOfNode(node.left) : getSymbolOfNode(node);
                    if (symbol) {
                        const links = getSymbolLinks(symbol);
                        return links.uniqueESSymbolType || (links.uniqueESSymbolType = createUniqueESSymbolType(symbol));
                    }
                }
                return esSymbolType;
            }
            function getThisType(node) {
                const container = getThisContainer(node, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                const parent2 = container && container.parent;
                if (parent2 && (isClassLike(parent2) || parent2.kind === 261 /* InterfaceDeclaration */)) {
                    if (!isStatic(container) && (!isConstructorDeclaration(container) || isNodeDescendantOf(node, container.body))) {
                        return getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(parent2)).thisType;
                    }
                }
                if (parent2 && isObjectLiteralExpression(parent2) && isBinaryExpression(parent2.parent) && getAssignmentDeclarationKind(parent2.parent) === 6 /* Prototype */) {
                    return getDeclaredTypeOfClassOrInterface(getSymbolOfNode(parent2.parent.left).parent).thisType;
                }
                const host2 = node.flags & 8388608 /* JSDoc */ ? getHostSignatureFromJSDoc(node) : void 0;
                if (host2 && isFunctionExpression(host2) && isBinaryExpression(host2.parent) && getAssignmentDeclarationKind(host2.parent) === 3 /* PrototypeProperty */) {
                    return getDeclaredTypeOfClassOrInterface(getSymbolOfNode(host2.parent.left).parent).thisType;
                }
                if (isJSConstructor(container) && isNodeDescendantOf(node, container.body)) {
                    return getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(container)).thisType;
                }
                error(node, Diagnostics.A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface);
                return errorType;
            }
            function getTypeFromThisTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    links.resolvedType = getThisType(node);
                }
                return links.resolvedType;
            }
            function getTypeFromRestTypeNode(node) {
                return getTypeFromTypeNode(getArrayElementTypeNode(node.type) || node.type);
            }
            function getArrayElementTypeNode(node) {
                switch (node.kind) {
                    case 193 /* ParenthesizedType */:
                        return getArrayElementTypeNode(node.type);
                    case 186 /* TupleType */:
                        if (node.elements.length === 1) {
                            node = node.elements[0];
                            if (node.kind === 188 /* RestType */ || node.kind === 199 /* NamedTupleMember */ && node.dotDotDotToken) {
                                return getArrayElementTypeNode(node.type);
                            }
                        }
                        break;
                    case 185 /* ArrayType */:
                        return node.elementType;
                }
                return void 0;
            }
            function getTypeFromNamedTupleTypeNode(node) {
                const links = getNodeLinks(node);
                return links.resolvedType || (links.resolvedType = node.dotDotDotToken ? getTypeFromRestTypeNode(node) : addOptionality(getTypeFromTypeNode(node.type), 
                /*isProperty*/
                true, !!node.questionToken));
            }
            function getTypeFromTypeNode(node) {
                return getConditionalFlowTypeOfType(getTypeFromTypeNodeWorker(node), node);
            }
            function getTypeFromTypeNodeWorker(node) {
                switch (node.kind) {
                    case 131 /* AnyKeyword */:
                    case 315 /* JSDocAllType */:
                    case 316 /* JSDocUnknownType */:
                        return anyType;
                    case 157 /* UnknownKeyword */:
                        return unknownType;
                    case 152 /* StringKeyword */:
                        return stringType;
                    case 148 /* NumberKeyword */:
                        return numberType;
                    case 160 /* BigIntKeyword */:
                        return bigintType;
                    case 134 /* BooleanKeyword */:
                        return booleanType;
                    case 153 /* SymbolKeyword */:
                        return esSymbolType;
                    case 114 /* VoidKeyword */:
                        return voidType;
                    case 155 /* UndefinedKeyword */:
                        return undefinedType;
                    case 104 /* NullKeyword */:
                        return nullType;
                    case 144 /* NeverKeyword */:
                        return neverType;
                    case 149 /* ObjectKeyword */:
                        return node.flags & 262144 /* JavaScriptFile */ && !noImplicitAny ? anyType : nonPrimitiveType;
                    case 139 /* IntrinsicKeyword */:
                        return intrinsicMarkerType;
                    case 194 /* ThisType */:
                    case 108 /* ThisKeyword */:
                        return getTypeFromThisTypeNode(node);
                    case 198 /* LiteralType */:
                        return getTypeFromLiteralTypeNode(node);
                    case 180 /* TypeReference */:
                        return getTypeFromTypeReference(node);
                    case 179 /* TypePredicate */:
                        return node.assertsModifier ? voidType : booleanType;
                    case 230 /* ExpressionWithTypeArguments */:
                        return getTypeFromTypeReference(node);
                    case 183 /* TypeQuery */:
                        return getTypeFromTypeQueryNode(node);
                    case 185 /* ArrayType */:
                    case 186 /* TupleType */:
                        return getTypeFromArrayOrTupleTypeNode(node);
                    case 187 /* OptionalType */:
                        return getTypeFromOptionalTypeNode(node);
                    case 189 /* UnionType */:
                        return getTypeFromUnionTypeNode(node);
                    case 190 /* IntersectionType */:
                        return getTypeFromIntersectionTypeNode(node);
                    case 317 /* JSDocNullableType */:
                        return getTypeFromJSDocNullableTypeNode(node);
                    case 319 /* JSDocOptionalType */:
                        return addOptionality(getTypeFromTypeNode(node.type));
                    case 199 /* NamedTupleMember */:
                        return getTypeFromNamedTupleTypeNode(node);
                    case 193 /* ParenthesizedType */:
                    case 318 /* JSDocNonNullableType */:
                    case 312 /* JSDocTypeExpression */:
                        return getTypeFromTypeNode(node.type);
                    case 188 /* RestType */:
                        return getTypeFromRestTypeNode(node);
                    case 321 /* JSDocVariadicType */:
                        return getTypeFromJSDocVariadicType(node);
                    case 181 /* FunctionType */:
                    case 182 /* ConstructorType */:
                    case 184 /* TypeLiteral */:
                    case 325 /* JSDocTypeLiteral */:
                    case 320 /* JSDocFunctionType */:
                    case 326 /* JSDocSignature */:
                        return getTypeFromTypeLiteralOrFunctionOrConstructorTypeNode(node);
                    case 195 /* TypeOperator */:
                        return getTypeFromTypeOperatorNode(node);
                    case 196 /* IndexedAccessType */:
                        return getTypeFromIndexedAccessTypeNode(node);
                    case 197 /* MappedType */:
                        return getTypeFromMappedTypeNode(node);
                    case 191 /* ConditionalType */:
                        return getTypeFromConditionalTypeNode(node);
                    case 192 /* InferType */:
                        return getTypeFromInferTypeNode(node);
                    case 200 /* TemplateLiteralType */:
                        return getTypeFromTemplateTypeNode(node);
                    case 202 /* ImportType */:
                        return getTypeFromImportTypeNode(node);
                    case 79 /* Identifier */:
                    case 163 /* QualifiedName */:
                    case 208 /* PropertyAccessExpression */:
                        const symbol = getSymbolAtLocation(node);
                        return symbol ? getDeclaredTypeOfSymbol(symbol) : errorType;
                    default:
                        return errorType;
                }
            }
            function instantiateList(items, mapper, instantiator) {
                if (items && items.length) {
                    for (let i = 0; i < items.length; i++) {
                        const item = items[i];
                        const mapped = instantiator(item, mapper);
                        if (item !== mapped) {
                            const result = i === 0 ? [] : items.slice(0, i);
                            result.push(mapped);
                            for (i++; i < items.length; i++) {
                                result.push(instantiator(items[i], mapper));
                            }
                            return result;
                        }
                    }
                }
                return items;
            }
            function instantiateTypes(types, mapper) {
                return instantiateList(types, mapper, instantiateType);
            }
            function instantiateSignatures(signatures, mapper) {
                return instantiateList(signatures, mapper, instantiateSignature);
            }
            function instantiateIndexInfos(indexInfos, mapper) {
                return instantiateList(indexInfos, mapper, instantiateIndexInfo);
            }
            function createTypeMapper(sources, targets) {
                return sources.length === 1 ? makeUnaryTypeMapper(sources[0], targets ? targets[0] : anyType) : makeArrayTypeMapper(sources, targets);
            }
            function getMappedType(type, mapper) {
                switch (mapper.kind) {
                    case 0 /* Simple */:
                        return type === mapper.source ? mapper.target : type;
                    case 1 /* Array */: {
                        const sources = mapper.sources;
                        const targets = mapper.targets;
                        for (let i = 0; i < sources.length; i++) {
                            if (type === sources[i]) {
                                return targets ? targets[i] : anyType;
                            }
                        }
                        return type;
                    }
                    case 2 /* Deferred */: {
                        const sources = mapper.sources;
                        const targets = mapper.targets;
                        for (let i = 0; i < sources.length; i++) {
                            if (type === sources[i]) {
                                return targets[i]();
                            }
                        }
                        return type;
                    }
                    case 3 /* Function */:
                        return mapper.func(type);
                    case 4 /* Composite */:
                    case 5 /* Merged */:
                        const t1 = getMappedType(type, mapper.mapper1);
                        return t1 !== type && mapper.kind === 4 /* Composite */ ? instantiateType(t1, mapper.mapper2) : getMappedType(t1, mapper.mapper2);
                }
            }
            function makeUnaryTypeMapper(source, target) {
                return Debug.attachDebugPrototypeIfDebug({ kind: 0 /* Simple */, source, target });
            }
            function makeArrayTypeMapper(sources, targets) {
                return Debug.attachDebugPrototypeIfDebug({ kind: 1 /* Array */, sources, targets });
            }
            function makeFunctionTypeMapper(func, debugInfo) {
                return Debug.attachDebugPrototypeIfDebug({ kind: 3 /* Function */, func, debugInfo: Debug.isDebugging ? debugInfo : void 0 });
            }
            function makeDeferredTypeMapper(sources, targets) {
                return Debug.attachDebugPrototypeIfDebug({ kind: 2 /* Deferred */, sources, targets });
            }
            function makeCompositeTypeMapper(kind, mapper1, mapper2) {
                return Debug.attachDebugPrototypeIfDebug({ kind, mapper1, mapper2 });
            }
            function createTypeEraser(sources) {
                return createTypeMapper(sources, 
                /*targets*/
                void 0);
            }
            function createBackreferenceMapper(context, index) {
                const forwardInferences = context.inferences.slice(index);
                return createTypeMapper(map(forwardInferences, (i) => i.typeParameter), map(forwardInferences, () => unknownType));
            }
            function combineTypeMappers(mapper1, mapper2) {
                return mapper1 ? makeCompositeTypeMapper(4 /* Composite */, mapper1, mapper2) : mapper2;
            }
            function mergeTypeMappers(mapper1, mapper2) {
                return mapper1 ? makeCompositeTypeMapper(5 /* Merged */, mapper1, mapper2) : mapper2;
            }
            function prependTypeMapping(source, target, mapper) {
                return !mapper ? makeUnaryTypeMapper(source, target) : makeCompositeTypeMapper(5 /* Merged */, makeUnaryTypeMapper(source, target), mapper);
            }
            function appendTypeMapping(mapper, source, target) {
                return !mapper ? makeUnaryTypeMapper(source, target) : makeCompositeTypeMapper(5 /* Merged */, mapper, makeUnaryTypeMapper(source, target));
            }
            function getRestrictiveTypeParameter(tp) {
                return !tp.constraint && !getConstraintDeclaration(tp) || tp.constraint === noConstraintType ? tp : tp.restrictiveInstantiation || (tp.restrictiveInstantiation = createTypeParameter(tp.symbol), tp.restrictiveInstantiation.constraint = noConstraintType, tp.restrictiveInstantiation);
            }
            function cloneTypeParameter(typeParameter) {
                const result = createTypeParameter(typeParameter.symbol);
                result.target = typeParameter;
                return result;
            }
            function instantiateTypePredicate(predicate, mapper) {
                return createTypePredicate(predicate.kind, predicate.parameterName, predicate.parameterIndex, instantiateType(predicate.type, mapper));
            }
            function instantiateSignature(signature, mapper, eraseTypeParameters) {
                let freshTypeParameters;
                if (signature.typeParameters && !eraseTypeParameters) {
                    freshTypeParameters = map(signature.typeParameters, cloneTypeParameter);
                    mapper = combineTypeMappers(createTypeMapper(signature.typeParameters, freshTypeParameters), mapper);
                    for (const tp of freshTypeParameters) {
                        tp.mapper = mapper;
                    }
                }
                const result = createSignature(signature.declaration, freshTypeParameters, signature.thisParameter && instantiateSymbol(signature.thisParameter, mapper), instantiateList(signature.parameters, mapper, instantiateSymbol), 
                /*resolvedReturnType*/
                void 0, 
                /*resolvedTypePredicate*/
                void 0, signature.minArgumentCount, signature.flags & 39 /* PropagatingFlags */);
                result.target = signature;
                result.mapper = mapper;
                return result;
            }
            function instantiateSymbol(symbol, mapper) {
                const links = getSymbolLinks(symbol);
                if (links.type && !couldContainTypeVariables(links.type)) {
                    return symbol;
                }
                if (getCheckFlags(symbol) & 1 /* Instantiated */) {
                    symbol = links.target;
                    mapper = combineTypeMappers(links.mapper, mapper);
                }
                const result = createSymbol(symbol.flags, symbol.escapedName, 1 /* Instantiated */ | getCheckFlags(symbol) & (8 /* Readonly */ | 4096 /* Late */ | 16384 /* OptionalParameter */ | 32768 /* RestParameter */));
                result.declarations = symbol.declarations;
                result.parent = symbol.parent;
                result.links.target = symbol;
                result.links.mapper = mapper;
                if (symbol.valueDeclaration) {
                    result.valueDeclaration = symbol.valueDeclaration;
                }
                if (links.nameType) {
                    result.links.nameType = links.nameType;
                }
                return result;
            }
            function getObjectTypeInstantiation(type, mapper, aliasSymbol, aliasTypeArguments) {
                const declaration = type.objectFlags & 4 /* Reference */ ? type.node : type.objectFlags & 8388608 /* InstantiationExpressionType */ ? type.node : type.symbol.declarations[0];
                const links = getNodeLinks(declaration);
                const target = type.objectFlags & 4 /* Reference */ ? links.resolvedType : type.objectFlags & 64 /* Instantiated */ ? type.target : type;
                let typeParameters = links.outerTypeParameters;
                if (!typeParameters) {
                    let outerTypeParameters = getOuterTypeParameters(declaration, 
                    /*includeThisTypes*/
                    true);
                    if (isJSConstructor(declaration)) {
                        const templateTagParameters = getTypeParametersFromDeclaration(declaration);
                        outerTypeParameters = addRange(outerTypeParameters, templateTagParameters);
                    }
                    typeParameters = outerTypeParameters || emptyArray;
                    const allDeclarations = type.objectFlags & (4 /* Reference */ | 8388608 /* InstantiationExpressionType */) ? [declaration] : type.symbol.declarations;
                    typeParameters = (target.objectFlags & (4 /* Reference */ | 8388608 /* InstantiationExpressionType */) || target.symbol.flags & 8192 /* Method */ || target.symbol.flags & 2048 /* TypeLiteral */) && !target.aliasTypeArguments ? filter(typeParameters, (tp) => some(allDeclarations, (d) => isTypeParameterPossiblyReferenced(tp, d))) : typeParameters;
                    links.outerTypeParameters = typeParameters;
                }
                if (typeParameters.length) {
                    const combinedMapper = combineTypeMappers(type.mapper, mapper);
                    const typeArguments = map(typeParameters, (t) => getMappedType(t, combinedMapper));
                    const newAliasSymbol = aliasSymbol || type.aliasSymbol;
                    const newAliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(type.aliasTypeArguments, mapper);
                    const id = getTypeListId(typeArguments) + getAliasId(newAliasSymbol, newAliasTypeArguments);
                    if (!target.instantiations) {
                        target.instantiations = /* @__PURE__ */ new Map();
                        target.instantiations.set(getTypeListId(typeParameters) + getAliasId(target.aliasSymbol, target.aliasTypeArguments), target);
                    }
                    let result = target.instantiations.get(id);
                    if (!result) {
                        const newMapper = createTypeMapper(typeParameters, typeArguments);
                        result = target.objectFlags & 4 /* Reference */ ? createDeferredTypeReference(type.target, type.node, newMapper, newAliasSymbol, newAliasTypeArguments) : target.objectFlags & 32 /* Mapped */ ? instantiateMappedType(target, newMapper, newAliasSymbol, newAliasTypeArguments) : instantiateAnonymousType(target, newMapper, newAliasSymbol, newAliasTypeArguments);
                        target.instantiations.set(id, result);
                    }
                    return result;
                }
                return type;
            }
            function maybeTypeParameterReference(node) {
                return !(node.parent.kind === 180 /* TypeReference */ && node.parent.typeArguments && node === node.parent.typeName || node.parent.kind === 202 /* ImportType */ && node.parent.typeArguments && node === node.parent.qualifier);
            }
            function isTypeParameterPossiblyReferenced(tp, node) {
                if (tp.symbol && tp.symbol.declarations && tp.symbol.declarations.length === 1) {
                    const container = tp.symbol.declarations[0].parent;
                    for (let n = node; n !== container; n = n.parent) {
                        if (!n || n.kind === 238 /* Block */ || n.kind === 191 /* ConditionalType */ && forEachChild(n.extendsType, containsReference)) {
                            return true;
                        }
                    }
                    return containsReference(node);
                }
                return true;
                function containsReference(node2) {
                    switch (node2.kind) {
                        case 194 /* ThisType */:
                            return !!tp.isThisType;
                        case 79 /* Identifier */:
                            return !tp.isThisType && isPartOfTypeNode(node2) && maybeTypeParameterReference(node2) && getTypeFromTypeNodeWorker(node2) === tp;
                        case 183 /* TypeQuery */:
                            const entityName = node2.exprName;
                            const firstIdentifier = getFirstIdentifier(entityName);
                            const firstIdentifierSymbol = getResolvedSymbol(firstIdentifier);
                            const tpDeclaration = tp.symbol.declarations[0];
                            let tpScope;
                            if (tpDeclaration.kind === 165 /* TypeParameter */) {
                                tpScope = tpDeclaration.parent;
                            }
                            else if (tp.isThisType) {
                                tpScope = tpDeclaration;
                            }
                            else {
                                return true;
                            }
                            if (firstIdentifierSymbol.declarations) {
                                return some(firstIdentifierSymbol.declarations, (idDecl) => isNodeDescendantOf(idDecl, tpScope)) || some(node2.typeArguments, containsReference);
                            }
                            return true;
                        case 171 /* MethodDeclaration */:
                        case 170 /* MethodSignature */:
                            return !node2.type && !!node2.body || some(node2.typeParameters, containsReference) || some(node2.parameters, containsReference) || !!node2.type && containsReference(node2.type);
                    }
                    return !!forEachChild(node2, containsReference);
                }
            }
            function getHomomorphicTypeVariable(type) {
                const constraintType = getConstraintTypeFromMappedType(type);
                if (constraintType.flags & 4194304 /* Index */) {
                    const typeVariable = getActualTypeVariable(constraintType.type);
                    if (typeVariable.flags & 262144 /* TypeParameter */) {
                        return typeVariable;
                    }
                }
                return void 0;
            }
            function instantiateMappedType(type, mapper, aliasSymbol, aliasTypeArguments) {
                const typeVariable = getHomomorphicTypeVariable(type);
                if (typeVariable) {
                    const mappedTypeVariable = instantiateType(typeVariable, mapper);
                    if (typeVariable !== mappedTypeVariable) {
                        return mapTypeWithAlias(getReducedType(mappedTypeVariable), (t) => {
                            if (t.flags & (3 /* AnyOrUnknown */ | 58982400 /* InstantiableNonPrimitive */ | 524288 /* Object */ | 2097152 /* Intersection */) && t !== wildcardType && !isErrorType(t)) {
                                if (!type.declaration.nameType) {
                                    let constraint;
                                    if (isArrayType(t) || t.flags & 1 /* Any */ && findResolutionCycleStartIndex(typeVariable, 4 /* ImmediateBaseConstraint */) < 0 && (constraint = getConstraintOfTypeParameter(typeVariable)) && everyType(constraint, isArrayOrTupleType)) {
                                        return instantiateMappedArrayType(t, type, prependTypeMapping(typeVariable, t, mapper));
                                    }
                                    if (isGenericTupleType(t)) {
                                        return instantiateMappedGenericTupleType(t, type, typeVariable, mapper);
                                    }
                                    if (isTupleType(t)) {
                                        return instantiateMappedTupleType(t, type, prependTypeMapping(typeVariable, t, mapper));
                                    }
                                }
                                return instantiateAnonymousType(type, prependTypeMapping(typeVariable, t, mapper));
                            }
                            return t;
                        }, aliasSymbol, aliasTypeArguments);
                    }
                }
                return instantiateType(getConstraintTypeFromMappedType(type), mapper) === wildcardType ? wildcardType : instantiateAnonymousType(type, mapper, aliasSymbol, aliasTypeArguments);
            }
            function getModifiedReadonlyState(state, modifiers) {
                return modifiers & 1 /* IncludeReadonly */ ? true : modifiers & 2 /* ExcludeReadonly */ ? false : state;
            }
            function instantiateMappedGenericTupleType(tupleType, mappedType, typeVariable, mapper) {
                const elementFlags = tupleType.target.elementFlags;
                const elementTypes = map(getTypeArguments(tupleType), (t, i) => {
                    const singleton = elementFlags[i] & 8 /* Variadic */ ? t : elementFlags[i] & 4 /* Rest */ ? createArrayType(t) : createTupleType([t], [elementFlags[i]]);
                    return instantiateMappedType(mappedType, prependTypeMapping(typeVariable, singleton, mapper));
                });
                const newReadonly = getModifiedReadonlyState(tupleType.target.readonly, getMappedTypeModifiers(mappedType));
                return createTupleType(elementTypes, map(elementTypes, (_) => 8 /* Variadic */), newReadonly);
            }
            function instantiateMappedArrayType(arrayType, mappedType, mapper) {
                const elementType = instantiateMappedTypeTemplate(mappedType, numberType, 
                /*isOptional*/
                true, mapper);
                return isErrorType(elementType) ? errorType : createArrayType(elementType, getModifiedReadonlyState(isReadonlyArrayType(arrayType), getMappedTypeModifiers(mappedType)));
            }
            function instantiateMappedTupleType(tupleType, mappedType, mapper) {
                const elementFlags = tupleType.target.elementFlags;
                const elementTypes = map(getTypeArguments(tupleType), (_, i) => instantiateMappedTypeTemplate(mappedType, getStringLiteralType("" + i), !!(elementFlags[i] & 2 /* Optional */), mapper));
                const modifiers = getMappedTypeModifiers(mappedType);
                const newTupleModifiers = modifiers & 4 /* IncludeOptional */ ? map(elementFlags, (f) => f & 1 /* Required */ ? 2 /* Optional */ : f) : modifiers & 8 /* ExcludeOptional */ ? map(elementFlags, (f) => f & 2 /* Optional */ ? 1 /* Required */ : f) : elementFlags;
                const newReadonly = getModifiedReadonlyState(tupleType.target.readonly, modifiers);
                return contains(elementTypes, errorType) ? errorType : createTupleType(elementTypes, newTupleModifiers, newReadonly, tupleType.target.labeledElementDeclarations);
            }
            function instantiateMappedTypeTemplate(type, key, isOptional, mapper) {
                const templateMapper = appendTypeMapping(mapper, getTypeParameterFromMappedType(type), key);
                const propType = instantiateType(getTemplateTypeFromMappedType(type.target || type), templateMapper);
                const modifiers = getMappedTypeModifiers(type);
                return strictNullChecks && modifiers & 4 /* IncludeOptional */ && !maybeTypeOfKind(propType, 32768 /* Undefined */ | 16384 /* Void */) ? getOptionalType(propType, 
                /*isProperty*/
                true) : strictNullChecks && modifiers & 8 /* ExcludeOptional */ && isOptional ? getTypeWithFacts(propType, 524288 /* NEUndefined */) : propType;
            }
            function instantiateAnonymousType(type, mapper, aliasSymbol, aliasTypeArguments) {
                const result = createObjectType(type.objectFlags | 64 /* Instantiated */, type.symbol);
                if (type.objectFlags & 32 /* Mapped */) {
                    result.declaration = type.declaration;
                    const origTypeParameter = getTypeParameterFromMappedType(type);
                    const freshTypeParameter = cloneTypeParameter(origTypeParameter);
                    result.typeParameter = freshTypeParameter;
                    mapper = combineTypeMappers(makeUnaryTypeMapper(origTypeParameter, freshTypeParameter), mapper);
                    freshTypeParameter.mapper = mapper;
                }
                if (type.objectFlags & 8388608 /* InstantiationExpressionType */) {
                    result.node = type.node;
                }
                result.target = type;
                result.mapper = mapper;
                result.aliasSymbol = aliasSymbol || type.aliasSymbol;
                result.aliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(type.aliasTypeArguments, mapper);
                result.objectFlags |= result.aliasTypeArguments ? getPropagatingFlagsOfTypes(result.aliasTypeArguments) : 0;
                return result;
            }
            function getConditionalTypeInstantiation(type, mapper, aliasSymbol, aliasTypeArguments) {
                const root = type.root;
                if (root.outerTypeParameters) {
                    const typeArguments = map(root.outerTypeParameters, (t) => getMappedType(t, mapper));
                    const id = getTypeListId(typeArguments) + getAliasId(aliasSymbol, aliasTypeArguments);
                    let result = root.instantiations.get(id);
                    if (!result) {
                        const newMapper = createTypeMapper(root.outerTypeParameters, typeArguments);
                        const checkType = root.checkType;
                        const distributionType = root.isDistributive ? getMappedType(checkType, newMapper) : void 0;
                        result = distributionType && checkType !== distributionType && distributionType.flags & (1048576 /* Union */ | 131072 /* Never */) ? mapTypeWithAlias(getReducedType(distributionType), (t) => getConditionalType(root, prependTypeMapping(checkType, t, newMapper)), aliasSymbol, aliasTypeArguments) : getConditionalType(root, newMapper, aliasSymbol, aliasTypeArguments);
                        root.instantiations.set(id, result);
                    }
                    return result;
                }
                return type;
            }
            function instantiateType(type, mapper) {
                return type && mapper ? instantiateTypeWithAlias(type, mapper, 
                /*aliasSymbol*/
                void 0, 
                /*aliasTypeArguments*/
                void 0) : type;
            }
            function instantiateTypeWithAlias(type, mapper, aliasSymbol, aliasTypeArguments) {
                var _a2;
                if (!couldContainTypeVariables(type)) {
                    return type;
                }
                if (instantiationDepth === 100 || instantiationCount >= 5e6) {
                    (_a2 = tracing) == null ? void 0 : _a2.instant(tracing.Phase.CheckTypes, "instantiateType_DepthLimit", { typeId: type.id, instantiationDepth, instantiationCount });
                    error(currentNode, Diagnostics.Type_instantiation_is_excessively_deep_and_possibly_infinite);
                    return errorType;
                }
                totalInstantiationCount++;
                instantiationCount++;
                instantiationDepth++;
                const result = instantiateTypeWorker(type, mapper, aliasSymbol, aliasTypeArguments);
                instantiationDepth--;
                return result;
            }
            function instantiateTypeWorker(type, mapper, aliasSymbol, aliasTypeArguments) {
                const flags = type.flags;
                if (flags & 262144 /* TypeParameter */) {
                    return getMappedType(type, mapper);
                }
                if (flags & 524288 /* Object */) {
                    const objectFlags = type.objectFlags;
                    if (objectFlags & (4 /* Reference */ | 16 /* Anonymous */ | 32 /* Mapped */)) {
                        if (objectFlags & 4 /* Reference */ && !type.node) {
                            const resolvedTypeArguments = type.resolvedTypeArguments;
                            const newTypeArguments = instantiateTypes(resolvedTypeArguments, mapper);
                            return newTypeArguments !== resolvedTypeArguments ? createNormalizedTypeReference(type.target, newTypeArguments) : type;
                        }
                        if (objectFlags & 1024 /* ReverseMapped */) {
                            return instantiateReverseMappedType(type, mapper);
                        }
                        return getObjectTypeInstantiation(type, mapper, aliasSymbol, aliasTypeArguments);
                    }
                    return type;
                }
                if (flags & 3145728 /* UnionOrIntersection */) {
                    const origin = type.flags & 1048576 /* Union */ ? type.origin : void 0;
                    const types = origin && origin.flags & 3145728 /* UnionOrIntersection */ ? origin.types : type.types;
                    const newTypes = instantiateTypes(types, mapper);
                    if (newTypes === types && aliasSymbol === type.aliasSymbol) {
                        return type;
                    }
                    const newAliasSymbol = aliasSymbol || type.aliasSymbol;
                    const newAliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(type.aliasTypeArguments, mapper);
                    return flags & 2097152 /* Intersection */ || origin && origin.flags & 2097152 /* Intersection */ ? getIntersectionType(newTypes, newAliasSymbol, newAliasTypeArguments) : getUnionType(newTypes, 1 /* Literal */, newAliasSymbol, newAliasTypeArguments);
                }
                if (flags & 4194304 /* Index */) {
                    return getIndexType(instantiateType(type.type, mapper));
                }
                if (flags & 134217728 /* TemplateLiteral */) {
                    return getTemplateLiteralType(type.texts, instantiateTypes(type.types, mapper));
                }
                if (flags & 268435456 /* StringMapping */) {
                    return getStringMappingType(type.symbol, instantiateType(type.type, mapper));
                }
                if (flags & 8388608 /* IndexedAccess */) {
                    const newAliasSymbol = aliasSymbol || type.aliasSymbol;
                    const newAliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(type.aliasTypeArguments, mapper);
                    return getIndexedAccessType(instantiateType(type.objectType, mapper), instantiateType(type.indexType, mapper), type.accessFlags, 
                    /*accessNode*/
                    void 0, newAliasSymbol, newAliasTypeArguments);
                }
                if (flags & 16777216 /* Conditional */) {
                    return getConditionalTypeInstantiation(type, combineTypeMappers(type.mapper, mapper), aliasSymbol, aliasTypeArguments);
                }
                if (flags & 33554432 /* Substitution */) {
                    const newBaseType = instantiateType(type.baseType, mapper);
                    const newConstraint = instantiateType(type.constraint, mapper);
                    if (newBaseType.flags & 8650752 /* TypeVariable */ && isGenericType(newConstraint)) {
                        return getSubstitutionType(newBaseType, newConstraint);
                    }
                    if (newConstraint.flags & 3 /* AnyOrUnknown */ || isTypeAssignableTo(getRestrictiveInstantiation(newBaseType), getRestrictiveInstantiation(newConstraint))) {
                        return newBaseType;
                    }
                    return newBaseType.flags & 8650752 /* TypeVariable */ ? getSubstitutionType(newBaseType, newConstraint) : getIntersectionType([newConstraint, newBaseType]);
                }
                return type;
            }
            function instantiateReverseMappedType(type, mapper) {
                const innerMappedType = instantiateType(type.mappedType, mapper);
                if (!(getObjectFlags(innerMappedType) & 32 /* Mapped */)) {
                    return type;
                }
                const innerIndexType = instantiateType(type.constraintType, mapper);
                if (!(innerIndexType.flags & 4194304 /* Index */)) {
                    return type;
                }
                const instantiated = inferTypeForHomomorphicMappedType(instantiateType(type.source, mapper), innerMappedType, innerIndexType);
                if (instantiated) {
                    return instantiated;
                }
                return type;
            }
            function getUniqueLiteralFilledInstantiation(type) {
                return type.flags & (134348796 /* Primitive */ | 3 /* AnyOrUnknown */ | 131072 /* Never */) ? type : type.uniqueLiteralFilledInstantiation || (type.uniqueLiteralFilledInstantiation = instantiateType(type, uniqueLiteralMapper));
            }
            function getPermissiveInstantiation(type) {
                return type.flags & (134348796 /* Primitive */ | 3 /* AnyOrUnknown */ | 131072 /* Never */) ? type : type.permissiveInstantiation || (type.permissiveInstantiation = instantiateType(type, permissiveMapper));
            }
            function getRestrictiveInstantiation(type) {
                if (type.flags & (134348796 /* Primitive */ | 3 /* AnyOrUnknown */ | 131072 /* Never */)) {
                    return type;
                }
                if (type.restrictiveInstantiation) {
                    return type.restrictiveInstantiation;
                }
                type.restrictiveInstantiation = instantiateType(type, restrictiveMapper);
                type.restrictiveInstantiation.restrictiveInstantiation = type.restrictiveInstantiation;
                return type.restrictiveInstantiation;
            }
            function instantiateIndexInfo(info, mapper) {
                return createIndexInfo(info.keyType, instantiateType(info.type, mapper), info.isReadonly, info.declaration);
            }
            function isContextSensitive(node) {
                Debug.assert(node.kind !== 171 /* MethodDeclaration */ || isObjectLiteralMethod(node));
                switch (node.kind) {
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                    case 171 /* MethodDeclaration */:
                    case 259 /* FunctionDeclaration */:
                        return isContextSensitiveFunctionLikeDeclaration(node);
                    case 207 /* ObjectLiteralExpression */:
                        return some(node.properties, isContextSensitive);
                    case 206 /* ArrayLiteralExpression */:
                        return some(node.elements, isContextSensitive);
                    case 224 /* ConditionalExpression */:
                        return isContextSensitive(node.whenTrue) || isContextSensitive(node.whenFalse);
                    case 223 /* BinaryExpression */:
                        return (node.operatorToken.kind === 56 /* BarBarToken */ || node.operatorToken.kind === 60 /* QuestionQuestionToken */) && (isContextSensitive(node.left) || isContextSensitive(node.right));
                    case 299 /* PropertyAssignment */:
                        return isContextSensitive(node.initializer);
                    case 214 /* ParenthesizedExpression */:
                        return isContextSensitive(node.expression);
                    case 289 /* JsxAttributes */:
                        return some(node.properties, isContextSensitive) || isJsxOpeningElement(node.parent) && some(node.parent.parent.children, isContextSensitive);
                    case 288 /* JsxAttribute */: {
                        const { initializer } = node;
                        return !!initializer && isContextSensitive(initializer);
                    }
                    case 291 /* JsxExpression */: {
                        const { expression } = node;
                        return !!expression && isContextSensitive(expression);
                    }
                }
                return false;
            }
            function isContextSensitiveFunctionLikeDeclaration(node) {
                return hasContextSensitiveParameters(node) || hasContextSensitiveReturnExpression(node);
            }
            function hasContextSensitiveReturnExpression(node) {
                return !node.typeParameters && !getEffectiveReturnTypeNode(node) && !!node.body && node.body.kind !== 238 /* Block */ && isContextSensitive(node.body);
            }
            function isContextSensitiveFunctionOrObjectLiteralMethod(func) {
                return (isFunctionExpressionOrArrowFunction(func) || isObjectLiteralMethod(func)) && isContextSensitiveFunctionLikeDeclaration(func);
            }
            function getTypeWithoutSignatures(type) {
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    if (resolved.constructSignatures.length || resolved.callSignatures.length) {
                        const result = createObjectType(16 /* Anonymous */, type.symbol);
                        result.members = resolved.members;
                        result.properties = resolved.properties;
                        result.callSignatures = emptyArray;
                        result.constructSignatures = emptyArray;
                        result.indexInfos = emptyArray;
                        return result;
                    }
                }
                else if (type.flags & 2097152 /* Intersection */) {
                    return getIntersectionType(map(type.types, getTypeWithoutSignatures));
                }
                return type;
            }
            function isTypeIdenticalTo(source, target) {
                return isTypeRelatedTo(source, target, identityRelation);
            }
            function compareTypesIdentical(source, target) {
                return isTypeRelatedTo(source, target, identityRelation) ? -1 /* True */ : 0 /* False */;
            }
            function compareTypesAssignable(source, target) {
                return isTypeRelatedTo(source, target, assignableRelation) ? -1 /* True */ : 0 /* False */;
            }
            function compareTypesSubtypeOf(source, target) {
                return isTypeRelatedTo(source, target, subtypeRelation) ? -1 /* True */ : 0 /* False */;
            }
            function isTypeSubtypeOf(source, target) {
                return isTypeRelatedTo(source, target, subtypeRelation);
            }
            function isTypeStrictSubtypeOf(source, target) {
                return isTypeRelatedTo(source, target, strictSubtypeRelation);
            }
            function isTypeAssignableTo(source, target) {
                return isTypeRelatedTo(source, target, assignableRelation);
            }
            function isTypeDerivedFrom(source, target) {
                return source.flags & 1048576 /* Union */ ? every(source.types, (t) => isTypeDerivedFrom(t, target)) : target.flags & 1048576 /* Union */ ? some(target.types, (t) => isTypeDerivedFrom(source, t)) : source.flags & 2097152 /* Intersection */ ? some(source.types, (t) => isTypeDerivedFrom(t, target)) : source.flags & 58982400 /* InstantiableNonPrimitive */ ? isTypeDerivedFrom(getBaseConstraintOfType(source) || unknownType, target) : isEmptyAnonymousObjectType(target) ? !!(source.flags & (524288 /* Object */ | 67108864 /* NonPrimitive */)) : target === globalObjectType ? !!(source.flags & (524288 /* Object */ | 67108864 /* NonPrimitive */)) && !isEmptyAnonymousObjectType(source) : target === globalFunctionType ? !!(source.flags & 524288 /* Object */) && isFunctionObjectType(source) : hasBaseType(source, getTargetType(target)) || isArrayType(target) && !isReadonlyArrayType(target) && isTypeDerivedFrom(source, globalReadonlyArrayType);
            }
            function isTypeComparableTo(source, target) {
                return isTypeRelatedTo(source, target, comparableRelation);
            }
            function areTypesComparable(type1, type2) {
                return isTypeComparableTo(type1, type2) || isTypeComparableTo(type2, type1);
            }
            function checkTypeAssignableTo(source, target, errorNode, headMessage, containingMessageChain, errorOutputObject) {
                return checkTypeRelatedTo(source, target, assignableRelation, errorNode, headMessage, containingMessageChain, errorOutputObject);
            }
            function checkTypeAssignableToAndOptionallyElaborate(source, target, errorNode, expr, headMessage, containingMessageChain) {
                return checkTypeRelatedToAndOptionallyElaborate(source, target, assignableRelation, errorNode, expr, headMessage, containingMessageChain, 
                /*errorOutputContainer*/
                void 0);
            }
            function checkTypeRelatedToAndOptionallyElaborate(source, target, relation, errorNode, expr, headMessage, containingMessageChain, errorOutputContainer) {
                if (isTypeRelatedTo(source, target, relation))
                    return true;
                if (!errorNode || !elaborateError(expr, source, target, relation, headMessage, containingMessageChain, errorOutputContainer)) {
                    return checkTypeRelatedTo(source, target, relation, errorNode, headMessage, containingMessageChain, errorOutputContainer);
                }
                return false;
            }
            function isOrHasGenericConditional(type) {
                return !!(type.flags & 16777216 /* Conditional */ || type.flags & 2097152 /* Intersection */ && some(type.types, isOrHasGenericConditional));
            }
            function elaborateError(node, source, target, relation, headMessage, containingMessageChain, errorOutputContainer) {
                if (!node || isOrHasGenericConditional(target))
                    return false;
                if (!checkTypeRelatedTo(source, target, relation, 
                /*errorNode*/
                void 0) && elaborateDidYouMeanToCallOrConstruct(node, source, target, relation, headMessage, containingMessageChain, errorOutputContainer)) {
                    return true;
                }
                switch (node.kind) {
                    case 291 /* JsxExpression */:
                    case 214 /* ParenthesizedExpression */:
                        return elaborateError(node.expression, source, target, relation, headMessage, containingMessageChain, errorOutputContainer);
                    case 223 /* BinaryExpression */:
                        switch (node.operatorToken.kind) {
                            case 63 /* EqualsToken */:
                            case 27 /* CommaToken */:
                                return elaborateError(node.right, source, target, relation, headMessage, containingMessageChain, errorOutputContainer);
                        }
                        break;
                    case 207 /* ObjectLiteralExpression */:
                        return elaborateObjectLiteral(node, source, target, relation, containingMessageChain, errorOutputContainer);
                    case 206 /* ArrayLiteralExpression */:
                        return elaborateArrayLiteral(node, source, target, relation, containingMessageChain, errorOutputContainer);
                    case 289 /* JsxAttributes */:
                        return elaborateJsxComponents(node, source, target, relation, containingMessageChain, errorOutputContainer);
                    case 216 /* ArrowFunction */:
                        return elaborateArrowFunction(node, source, target, relation, containingMessageChain, errorOutputContainer);
                }
                return false;
            }
            function elaborateDidYouMeanToCallOrConstruct(node, source, target, relation, headMessage, containingMessageChain, errorOutputContainer) {
                const callSignatures = getSignaturesOfType(source, 0 /* Call */);
                const constructSignatures = getSignaturesOfType(source, 1 /* Construct */);
                for (const signatures of [constructSignatures, callSignatures]) {
                    if (some(signatures, (s) => {
                        const returnType = getReturnTypeOfSignature(s);
                        return !(returnType.flags & (1 /* Any */ | 131072 /* Never */)) && checkTypeRelatedTo(returnType, target, relation, 
                        /*errorNode*/
                        void 0);
                    })) {
                        const resultObj = errorOutputContainer || {};
                        checkTypeAssignableTo(source, target, node, headMessage, containingMessageChain, resultObj);
                        const diagnostic = resultObj.errors[resultObj.errors.length - 1];
                        addRelatedInfo(diagnostic, createDiagnosticForNode(node, signatures === constructSignatures ? Diagnostics.Did_you_mean_to_use_new_with_this_expression : Diagnostics.Did_you_mean_to_call_this_expression));
                        return true;
                    }
                }
                return false;
            }
            function elaborateArrowFunction(node, source, target, relation, containingMessageChain, errorOutputContainer) {
                if (isBlock(node.body)) {
                    return false;
                }
                if (some(node.parameters, hasType)) {
                    return false;
                }
                const sourceSig = getSingleCallSignature(source);
                if (!sourceSig) {
                    return false;
                }
                const targetSignatures = getSignaturesOfType(target, 0 /* Call */);
                if (!length(targetSignatures)) {
                    return false;
                }
                const returnExpression = node.body;
                const sourceReturn = getReturnTypeOfSignature(sourceSig);
                const targetReturn = getUnionType(map(targetSignatures, getReturnTypeOfSignature));
                if (!checkTypeRelatedTo(sourceReturn, targetReturn, relation, 
                /*errorNode*/
                void 0)) {
                    const elaborated = returnExpression && elaborateError(returnExpression, sourceReturn, targetReturn, relation, 
                    /*headMessage*/
                    void 0, containingMessageChain, errorOutputContainer);
                    if (elaborated) {
                        return elaborated;
                    }
                    const resultObj = errorOutputContainer || {};
                    checkTypeRelatedTo(sourceReturn, targetReturn, relation, returnExpression, 
                    /*message*/
                    void 0, containingMessageChain, resultObj);
                    if (resultObj.errors) {
                        if (target.symbol && length(target.symbol.declarations)) {
                            addRelatedInfo(resultObj.errors[resultObj.errors.length - 1], createDiagnosticForNode(target.symbol.declarations[0], Diagnostics.The_expected_type_comes_from_the_return_type_of_this_signature));
                        }
                        if ((getFunctionFlags(node) & 2 /* Async */) === 0 && !getTypeOfPropertyOfType(sourceReturn, "then") && checkTypeRelatedTo(createPromiseType(sourceReturn), targetReturn, relation, 
                        /*errorNode*/
                        void 0)) {
                            addRelatedInfo(resultObj.errors[resultObj.errors.length - 1], createDiagnosticForNode(node, Diagnostics.Did_you_mean_to_mark_this_function_as_async));
                        }
                        return true;
                    }
                }
                return false;
            }
            function getBestMatchIndexedAccessTypeOrUndefined(source, target, nameType) {
                const idx = getIndexedAccessTypeOrUndefined(target, nameType);
                if (idx) {
                    return idx;
                }
                if (target.flags & 1048576 /* Union */) {
                    const best = getBestMatchingType(source, target);
                    if (best) {
                        return getIndexedAccessTypeOrUndefined(best, nameType);
                    }
                }
            }
            function checkExpressionForMutableLocationWithContextualType(next, sourcePropType) {
                pushContextualType(next, sourcePropType, 
                /*isCache*/
                false);
                const result = checkExpressionForMutableLocation(next, 1 /* Contextual */);
                popContextualType();
                return result;
            }
            function elaborateElementwise(iterator, source, target, relation, containingMessageChain, errorOutputContainer) {
                let reportedError = false;
                for (const value of iterator) {
                    const { errorNode: prop, innerExpression: next, nameType, errorMessage } = value;
                    let targetPropType = getBestMatchIndexedAccessTypeOrUndefined(source, target, nameType);
                    if (!targetPropType || targetPropType.flags & 8388608 /* IndexedAccess */)
                        continue;
                    let sourcePropType = getIndexedAccessTypeOrUndefined(source, nameType);
                    if (!sourcePropType)
                        continue;
                    const propName = getPropertyNameFromIndex(nameType, 
                    /*accessNode*/
                    void 0);
                    if (!checkTypeRelatedTo(sourcePropType, targetPropType, relation, 
                    /*errorNode*/
                    void 0)) {
                        const elaborated = next && elaborateError(next, sourcePropType, targetPropType, relation, 
                        /*headMessage*/
                        void 0, containingMessageChain, errorOutputContainer);
                        reportedError = true;
                        if (!elaborated) {
                            const resultObj = errorOutputContainer || {};
                            const specificSource = next ? checkExpressionForMutableLocationWithContextualType(next, sourcePropType) : sourcePropType;
                            if (exactOptionalPropertyTypes && isExactOptionalPropertyMismatch(specificSource, targetPropType)) {
                                const diag2 = createDiagnosticForNode(prop, Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target, typeToString(specificSource), typeToString(targetPropType));
                                diagnostics.add(diag2);
                                resultObj.errors = [diag2];
                            }
                            else {
                                const targetIsOptional = !!(propName && (getPropertyOfType(target, propName) || unknownSymbol).flags & 16777216 /* Optional */);
                                const sourceIsOptional = !!(propName && (getPropertyOfType(source, propName) || unknownSymbol).flags & 16777216 /* Optional */);
                                targetPropType = removeMissingType(targetPropType, targetIsOptional);
                                sourcePropType = removeMissingType(sourcePropType, targetIsOptional && sourceIsOptional);
                                const result = checkTypeRelatedTo(specificSource, targetPropType, relation, prop, errorMessage, containingMessageChain, resultObj);
                                if (result && specificSource !== sourcePropType) {
                                    checkTypeRelatedTo(sourcePropType, targetPropType, relation, prop, errorMessage, containingMessageChain, resultObj);
                                }
                            }
                            if (resultObj.errors) {
                                const reportedDiag = resultObj.errors[resultObj.errors.length - 1];
                                const propertyName = isTypeUsableAsPropertyName(nameType) ? getPropertyNameFromType(nameType) : void 0;
                                const targetProp = propertyName !== void 0 ? getPropertyOfType(target, propertyName) : void 0;
                                let issuedElaboration = false;
                                if (!targetProp) {
                                    const indexInfo = getApplicableIndexInfo(target, nameType);
                                    if (indexInfo && indexInfo.declaration && !getSourceFileOfNode(indexInfo.declaration).hasNoDefaultLib) {
                                        issuedElaboration = true;
                                        addRelatedInfo(reportedDiag, createDiagnosticForNode(indexInfo.declaration, Diagnostics.The_expected_type_comes_from_this_index_signature));
                                    }
                                }
                                if (!issuedElaboration && (targetProp && length(targetProp.declarations) || target.symbol && length(target.symbol.declarations))) {
                                    const targetNode = targetProp && length(targetProp.declarations) ? targetProp.declarations[0] : target.symbol.declarations[0];
                                    if (!getSourceFileOfNode(targetNode).hasNoDefaultLib) {
                                        addRelatedInfo(reportedDiag, createDiagnosticForNode(targetNode, Diagnostics.The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1, propertyName && !(nameType.flags & 8192 /* UniqueESSymbol */) ? unescapeLeadingUnderscores(propertyName) : typeToString(nameType), typeToString(target)));
                                    }
                                }
                            }
                        }
                    }
                }
                return reportedError;
            }
            function elaborateIterableOrArrayLikeTargetElementwise(iterator, source, target, relation, containingMessageChain, errorOutputContainer) {
                const tupleOrArrayLikeTargetParts = filterType(target, isArrayOrTupleLikeType);
                const nonTupleOrArrayLikeTargetParts = filterType(target, (t) => !isArrayOrTupleLikeType(t));
                const iterationType = nonTupleOrArrayLikeTargetParts !== neverType ? getIterationTypeOfIterable(13 /* ForOf */, 0 /* Yield */, nonTupleOrArrayLikeTargetParts, 
                /*errorNode*/
                void 0) : void 0;
                let reportedError = false;
                for (let status = iterator.next(); !status.done; status = iterator.next()) {
                    const { errorNode: prop, innerExpression: next, nameType, errorMessage } = status.value;
                    let targetPropType = iterationType;
                    const targetIndexedPropType = tupleOrArrayLikeTargetParts !== neverType ? getBestMatchIndexedAccessTypeOrUndefined(source, tupleOrArrayLikeTargetParts, nameType) : void 0;
                    if (targetIndexedPropType && !(targetIndexedPropType.flags & 8388608 /* IndexedAccess */)) {
                        targetPropType = iterationType ? getUnionType([iterationType, targetIndexedPropType]) : targetIndexedPropType;
                    }
                    if (!targetPropType)
                        continue;
                    let sourcePropType = getIndexedAccessTypeOrUndefined(source, nameType);
                    if (!sourcePropType)
                        continue;
                    const propName = getPropertyNameFromIndex(nameType, 
                    /*accessNode*/
                    void 0);
                    if (!checkTypeRelatedTo(sourcePropType, targetPropType, relation, 
                    /*errorNode*/
                    void 0)) {
                        const elaborated = next && elaborateError(next, sourcePropType, targetPropType, relation, 
                        /*headMessage*/
                        void 0, containingMessageChain, errorOutputContainer);
                        reportedError = true;
                        if (!elaborated) {
                            const resultObj = errorOutputContainer || {};
                            const specificSource = next ? checkExpressionForMutableLocationWithContextualType(next, sourcePropType) : sourcePropType;
                            if (exactOptionalPropertyTypes && isExactOptionalPropertyMismatch(specificSource, targetPropType)) {
                                const diag2 = createDiagnosticForNode(prop, Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target, typeToString(specificSource), typeToString(targetPropType));
                                diagnostics.add(diag2);
                                resultObj.errors = [diag2];
                            }
                            else {
                                const targetIsOptional = !!(propName && (getPropertyOfType(tupleOrArrayLikeTargetParts, propName) || unknownSymbol).flags & 16777216 /* Optional */);
                                const sourceIsOptional = !!(propName && (getPropertyOfType(source, propName) || unknownSymbol).flags & 16777216 /* Optional */);
                                targetPropType = removeMissingType(targetPropType, targetIsOptional);
                                sourcePropType = removeMissingType(sourcePropType, targetIsOptional && sourceIsOptional);
                                const result = checkTypeRelatedTo(specificSource, targetPropType, relation, prop, errorMessage, containingMessageChain, resultObj);
                                if (result && specificSource !== sourcePropType) {
                                    checkTypeRelatedTo(sourcePropType, targetPropType, relation, prop, errorMessage, containingMessageChain, resultObj);
                                }
                            }
                        }
                    }
                }
                return reportedError;
            }
            function* generateJsxAttributes(node) {
                if (!length(node.properties))
                    return;
                for (const prop of node.properties) {
                    if (isJsxSpreadAttribute(prop) || isHyphenatedJsxName(idText(prop.name)))
                        continue;
                    yield { errorNode: prop.name, innerExpression: prop.initializer, nameType: getStringLiteralType(idText(prop.name)) };
                }
            }
            function* generateJsxChildren(node, getInvalidTextDiagnostic) {
                if (!length(node.children))
                    return;
                let memberOffset = 0;
                for (let i = 0; i < node.children.length; i++) {
                    const child = node.children[i];
                    const nameType = getNumberLiteralType(i - memberOffset);
                    const elem = getElaborationElementForJsxChild(child, nameType, getInvalidTextDiagnostic);
                    if (elem) {
                        yield elem;
                    }
                    else {
                        memberOffset++;
                    }
                }
            }
            function getElaborationElementForJsxChild(child, nameType, getInvalidTextDiagnostic) {
                switch (child.kind) {
                    case 291 /* JsxExpression */:
                        return { errorNode: child, innerExpression: child.expression, nameType };
                    case 11 /* JsxText */:
                        if (child.containsOnlyTriviaWhiteSpaces) {
                            break;
                        }
                        return { errorNode: child, innerExpression: void 0, nameType, errorMessage: getInvalidTextDiagnostic() };
                    case 281 /* JsxElement */:
                    case 282 /* JsxSelfClosingElement */:
                    case 285 /* JsxFragment */:
                        return { errorNode: child, innerExpression: child, nameType };
                    default:
                        return Debug.assertNever(child, "Found invalid jsx child");
                }
            }
            function elaborateJsxComponents(node, source, target, relation, containingMessageChain, errorOutputContainer) {
                let result = elaborateElementwise(generateJsxAttributes(node), source, target, relation, containingMessageChain, errorOutputContainer);
                let invalidTextDiagnostic;
                if (isJsxOpeningElement(node.parent) && isJsxElement(node.parent.parent)) {
                    const containingElement = node.parent.parent;
                    const childPropName = getJsxElementChildrenPropertyName(getJsxNamespaceAt(node));
                    const childrenPropName = childPropName === void 0 ? "children" : unescapeLeadingUnderscores(childPropName);
                    const childrenNameType = getStringLiteralType(childrenPropName);
                    const childrenTargetType = getIndexedAccessType(target, childrenNameType);
                    const validChildren = getSemanticJsxChildren(containingElement.children);
                    if (!length(validChildren)) {
                        return result;
                    }
                    const moreThanOneRealChildren = length(validChildren) > 1;
                    let arrayLikeTargetParts;
                    let nonArrayLikeTargetParts;
                    const iterableType = getGlobalIterableType(
                    /*reportErrors*/
                    false);
                    if (iterableType !== emptyGenericType) {
                        const anyIterable = createIterableType(anyType);
                        arrayLikeTargetParts = filterType(childrenTargetType, (t) => isTypeAssignableTo(t, anyIterable));
                        nonArrayLikeTargetParts = filterType(childrenTargetType, (t) => !isTypeAssignableTo(t, anyIterable));
                    }
                    else {
                        arrayLikeTargetParts = filterType(childrenTargetType, isArrayOrTupleLikeType);
                        nonArrayLikeTargetParts = filterType(childrenTargetType, (t) => !isArrayOrTupleLikeType(t));
                    }
                    if (moreThanOneRealChildren) {
                        if (arrayLikeTargetParts !== neverType) {
                            const realSource = createTupleType(checkJsxChildren(containingElement, 0 /* Normal */));
                            const children = generateJsxChildren(containingElement, getInvalidTextualChildDiagnostic);
                            result = elaborateIterableOrArrayLikeTargetElementwise(children, realSource, arrayLikeTargetParts, relation, containingMessageChain, errorOutputContainer) || result;
                        }
                        else if (!isTypeRelatedTo(getIndexedAccessType(source, childrenNameType), childrenTargetType, relation)) {
                            result = true;
                            const diag2 = error(containingElement.openingElement.tagName, Diagnostics.This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided, childrenPropName, typeToString(childrenTargetType));
                            if (errorOutputContainer && errorOutputContainer.skipLogging) {
                                (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                            }
                        }
                    }
                    else {
                        if (nonArrayLikeTargetParts !== neverType) {
                            const child = validChildren[0];
                            const elem = getElaborationElementForJsxChild(child, childrenNameType, getInvalidTextualChildDiagnostic);
                            if (elem) {
                                result = elaborateElementwise(function* () {
                                    yield elem;
                                }(), source, target, relation, containingMessageChain, errorOutputContainer) || result;
                            }
                        }
                        else if (!isTypeRelatedTo(getIndexedAccessType(source, childrenNameType), childrenTargetType, relation)) {
                            result = true;
                            const diag2 = error(containingElement.openingElement.tagName, Diagnostics.This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_provided, childrenPropName, typeToString(childrenTargetType));
                            if (errorOutputContainer && errorOutputContainer.skipLogging) {
                                (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                            }
                        }
                    }
                }
                return result;
                function getInvalidTextualChildDiagnostic() {
                    if (!invalidTextDiagnostic) {
                        const tagNameText = getTextOfNode(node.parent.tagName);
                        const childPropName = getJsxElementChildrenPropertyName(getJsxNamespaceAt(node));
                        const childrenPropName = childPropName === void 0 ? "children" : unescapeLeadingUnderscores(childPropName);
                        const childrenTargetType = getIndexedAccessType(target, getStringLiteralType(childrenPropName));
                        const diagnostic = Diagnostics._0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_type_of_1_is_2;
                        invalidTextDiagnostic = { ...diagnostic, key: "!!ALREADY FORMATTED!!", message: formatMessage(
                            /*_dummy*/
                            void 0, diagnostic, tagNameText, childrenPropName, typeToString(childrenTargetType)) };
                    }
                    return invalidTextDiagnostic;
                }
            }
            function* generateLimitedTupleElements(node, target) {
                const len = length(node.elements);
                if (!len)
                    return;
                for (let i = 0; i < len; i++) {
                    if (isTupleLikeType(target) && !getPropertyOfType(target, "" + i))
                        continue;
                    const elem = node.elements[i];
                    if (isOmittedExpression(elem))
                        continue;
                    const nameType = getNumberLiteralType(i);
                    yield { errorNode: elem, innerExpression: elem, nameType };
                }
            }
            function elaborateArrayLiteral(node, source, target, relation, containingMessageChain, errorOutputContainer) {
                if (target.flags & (134348796 /* Primitive */ | 131072 /* Never */))
                    return false;
                if (isTupleLikeType(source)) {
                    return elaborateElementwise(generateLimitedTupleElements(node, target), source, target, relation, containingMessageChain, errorOutputContainer);
                }
                pushContextualType(node, target, 
                /*isCache*/
                false);
                const tupleizedType = checkArrayLiteral(node, 1 /* Contextual */, 
                /*forceTuple*/
                true);
                popContextualType();
                if (isTupleLikeType(tupleizedType)) {
                    return elaborateElementwise(generateLimitedTupleElements(node, target), tupleizedType, target, relation, containingMessageChain, errorOutputContainer);
                }
                return false;
            }
            function* generateObjectLiteralElements(node) {
                if (!length(node.properties))
                    return;
                for (const prop of node.properties) {
                    if (isSpreadAssignment(prop))
                        continue;
                    const type = getLiteralTypeFromProperty(getSymbolOfDeclaration(prop), 8576 /* StringOrNumberLiteralOrUnique */);
                    if (!type || type.flags & 131072 /* Never */) {
                        continue;
                    }
                    switch (prop.kind) {
                        case 175 /* SetAccessor */:
                        case 174 /* GetAccessor */:
                        case 171 /* MethodDeclaration */:
                        case 300 /* ShorthandPropertyAssignment */:
                            yield { errorNode: prop.name, innerExpression: void 0, nameType: type };
                            break;
                        case 299 /* PropertyAssignment */:
                            yield { errorNode: prop.name, innerExpression: prop.initializer, nameType: type, errorMessage: isComputedNonLiteralName(prop.name) ? Diagnostics.Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1 : void 0 };
                            break;
                        default:
                            Debug.assertNever(prop);
                    }
                }
            }
            function elaborateObjectLiteral(node, source, target, relation, containingMessageChain, errorOutputContainer) {
                if (target.flags & (134348796 /* Primitive */ | 131072 /* Never */))
                    return false;
                return elaborateElementwise(generateObjectLiteralElements(node), source, target, relation, containingMessageChain, errorOutputContainer);
            }
            function checkTypeComparableTo(source, target, errorNode, headMessage, containingMessageChain) {
                return checkTypeRelatedTo(source, target, comparableRelation, errorNode, headMessage, containingMessageChain);
            }
            function isSignatureAssignableTo(source, target, ignoreReturnTypes) {
                return compareSignaturesRelated(source, target, ignoreReturnTypes ? 4 /* IgnoreReturnTypes */ : 0 /* None */, 
                /*reportErrors*/
                false, 
                /*errorReporter*/
                void 0, 
                /*errorReporter*/
                void 0, compareTypesAssignable, 
                /*reportUnreliableMarkers*/
                void 0) !== 0 /* False */;
            }
            function isTopSignature(s) {
                if (!s.typeParameters && (!s.thisParameter || isTypeAny(getTypeOfParameter(s.thisParameter))) && s.parameters.length === 1 && signatureHasRestParameter(s)) {
                    const paramType = getTypeOfParameter(s.parameters[0]);
                    const restType = isArrayType(paramType) ? getTypeArguments(paramType)[0] : paramType;
                    return !!(restType.flags & (1 /* Any */ | 131072 /* Never */) && getReturnTypeOfSignature(s).flags & 3 /* AnyOrUnknown */);
                }
                return false;
            }
            function compareSignaturesRelated(source, target, checkMode, reportErrors2, errorReporter, incompatibleErrorReporter, compareTypes, reportUnreliableMarkers) {
                if (source === target) {
                    return -1 /* True */;
                }
                if (!(checkMode & 16 /* StrictTopSignature */ && isTopSignature(source)) && isTopSignature(target)) {
                    return -1 /* True */;
                }
                if (checkMode & 16 /* StrictTopSignature */ && isTopSignature(source) && !isTopSignature(target)) {
                    return 0 /* False */;
                }
                const targetCount = getParameterCount(target);
                const sourceHasMoreParameters = !hasEffectiveRestParameter(target) && (checkMode & 8 /* StrictArity */ ? hasEffectiveRestParameter(source) || getParameterCount(source) > targetCount : getMinArgumentCount(source) > targetCount);
                if (sourceHasMoreParameters) {
                    return 0 /* False */;
                }
                if (source.typeParameters && source.typeParameters !== target.typeParameters) {
                    target = getCanonicalSignature(target);
                    source = instantiateSignatureInContextOf(source, target, 
                    /*inferenceContext*/
                    void 0, compareTypes);
                }
                const sourceCount = getParameterCount(source);
                const sourceRestType = getNonArrayRestType(source);
                const targetRestType = getNonArrayRestType(target);
                if (sourceRestType || targetRestType) {
                    void instantiateType(sourceRestType || targetRestType, reportUnreliableMarkers);
                }
                const kind = target.declaration ? target.declaration.kind : 0 /* Unknown */;
                const strictVariance = !(checkMode & 3 /* Callback */) && strictFunctionTypes && kind !== 171 /* MethodDeclaration */ && kind !== 170 /* MethodSignature */ && kind !== 173 /* Constructor */;
                let result = -1 /* True */;
                const sourceThisType = getThisTypeOfSignature(source);
                if (sourceThisType && sourceThisType !== voidType) {
                    const targetThisType = getThisTypeOfSignature(target);
                    if (targetThisType) {
                        const related = !strictVariance && compareTypes(sourceThisType, targetThisType, 
                        /*reportErrors*/
                        false) || compareTypes(targetThisType, sourceThisType, reportErrors2);
                        if (!related) {
                            if (reportErrors2) {
                                errorReporter(Diagnostics.The_this_types_of_each_signature_are_incompatible);
                            }
                            return 0 /* False */;
                        }
                        result &= related;
                    }
                }
                const paramCount = sourceRestType || targetRestType ? Math.min(sourceCount, targetCount) : Math.max(sourceCount, targetCount);
                const restIndex = sourceRestType || targetRestType ? paramCount - 1 : -1;
                for (let i = 0; i < paramCount; i++) {
                    const sourceType = i === restIndex ? getRestTypeAtPosition(source, i) : tryGetTypeAtPosition(source, i);
                    const targetType = i === restIndex ? getRestTypeAtPosition(target, i) : tryGetTypeAtPosition(target, i);
                    if (sourceType && targetType) {
                        const sourceSig = checkMode & 3 /* Callback */ ? void 0 : getSingleCallSignature(getNonNullableType(sourceType));
                        const targetSig = checkMode & 3 /* Callback */ ? void 0 : getSingleCallSignature(getNonNullableType(targetType));
                        const callbacks = sourceSig && targetSig && !getTypePredicateOfSignature(sourceSig) && !getTypePredicateOfSignature(targetSig) && (getTypeFacts(sourceType) & 50331648 /* IsUndefinedOrNull */) === (getTypeFacts(targetType) & 50331648 /* IsUndefinedOrNull */);
                        let related = callbacks ? compareSignaturesRelated(targetSig, sourceSig, checkMode & 8 /* StrictArity */ | (strictVariance ? 2 /* StrictCallback */ : 1 /* BivariantCallback */), reportErrors2, errorReporter, incompatibleErrorReporter, compareTypes, reportUnreliableMarkers) : !(checkMode & 3 /* Callback */) && !strictVariance && compareTypes(sourceType, targetType, 
                        /*reportErrors*/
                        false) || compareTypes(targetType, sourceType, reportErrors2);
                        if (related && checkMode & 8 /* StrictArity */ && i >= getMinArgumentCount(source) && i < getMinArgumentCount(target) && compareTypes(sourceType, targetType, 
                        /*reportErrors*/
                        false)) {
                            related = 0 /* False */;
                        }
                        if (!related) {
                            if (reportErrors2) {
                                errorReporter(Diagnostics.Types_of_parameters_0_and_1_are_incompatible, unescapeLeadingUnderscores(getParameterNameAtPosition(source, i)), unescapeLeadingUnderscores(getParameterNameAtPosition(target, i)));
                            }
                            return 0 /* False */;
                        }
                        result &= related;
                    }
                }
                if (!(checkMode & 4 /* IgnoreReturnTypes */)) {
                    const targetReturnType = isResolvingReturnTypeOfSignature(target) ? anyType : target.declaration && isJSConstructor(target.declaration) ? getDeclaredTypeOfClassOrInterface(getMergedSymbol(target.declaration.symbol)) : getReturnTypeOfSignature(target);
                    if (targetReturnType === voidType || targetReturnType === anyType) {
                        return result;
                    }
                    const sourceReturnType = isResolvingReturnTypeOfSignature(source) ? anyType : source.declaration && isJSConstructor(source.declaration) ? getDeclaredTypeOfClassOrInterface(getMergedSymbol(source.declaration.symbol)) : getReturnTypeOfSignature(source);
                    const targetTypePredicate = getTypePredicateOfSignature(target);
                    if (targetTypePredicate) {
                        const sourceTypePredicate = getTypePredicateOfSignature(source);
                        if (sourceTypePredicate) {
                            result &= compareTypePredicateRelatedTo(sourceTypePredicate, targetTypePredicate, reportErrors2, errorReporter, compareTypes);
                        }
                        else if (isIdentifierTypePredicate(targetTypePredicate)) {
                            if (reportErrors2) {
                                errorReporter(Diagnostics.Signature_0_must_be_a_type_predicate, signatureToString(source));
                            }
                            return 0 /* False */;
                        }
                    }
                    else {
                        result &= checkMode & 1 /* BivariantCallback */ && compareTypes(targetReturnType, sourceReturnType, 
                        /*reportErrors*/
                        false) || compareTypes(sourceReturnType, targetReturnType, reportErrors2);
                        if (!result && reportErrors2 && incompatibleErrorReporter) {
                            incompatibleErrorReporter(sourceReturnType, targetReturnType);
                        }
                    }
                }
                return result;
            }
            function compareTypePredicateRelatedTo(source, target, reportErrors2, errorReporter, compareTypes) {
                if (source.kind !== target.kind) {
                    if (reportErrors2) {
                        errorReporter(Diagnostics.A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard);
                        errorReporter(Diagnostics.Type_predicate_0_is_not_assignable_to_1, typePredicateToString(source), typePredicateToString(target));
                    }
                    return 0 /* False */;
                }
                if (source.kind === 1 /* Identifier */ || source.kind === 3 /* AssertsIdentifier */) {
                    if (source.parameterIndex !== target.parameterIndex) {
                        if (reportErrors2) {
                            errorReporter(Diagnostics.Parameter_0_is_not_in_the_same_position_as_parameter_1, source.parameterName, target.parameterName);
                            errorReporter(Diagnostics.Type_predicate_0_is_not_assignable_to_1, typePredicateToString(source), typePredicateToString(target));
                        }
                        return 0 /* False */;
                    }
                }
                const related = source.type === target.type ? -1 /* True */ : source.type && target.type ? compareTypes(source.type, target.type, reportErrors2) : 0 /* False */;
                if (related === 0 /* False */ && reportErrors2) {
                    errorReporter(Diagnostics.Type_predicate_0_is_not_assignable_to_1, typePredicateToString(source), typePredicateToString(target));
                }
                return related;
            }
            function isImplementationCompatibleWithOverload(implementation, overload) {
                const erasedSource = getErasedSignature(implementation);
                const erasedTarget = getErasedSignature(overload);
                const sourceReturnType = getReturnTypeOfSignature(erasedSource);
                const targetReturnType = getReturnTypeOfSignature(erasedTarget);
                if (targetReturnType === voidType || isTypeRelatedTo(targetReturnType, sourceReturnType, assignableRelation) || isTypeRelatedTo(sourceReturnType, targetReturnType, assignableRelation)) {
                    return isSignatureAssignableTo(erasedSource, erasedTarget, 
                    /*ignoreReturnTypes*/
                    true);
                }
                return false;
            }
            function isEmptyResolvedType(t) {
                return t !== anyFunctionType && t.properties.length === 0 && t.callSignatures.length === 0 && t.constructSignatures.length === 0 && t.indexInfos.length === 0;
            }
            function isEmptyObjectType(type) {
                return type.flags & 524288 /* Object */ ? !isGenericMappedType(type) && isEmptyResolvedType(resolveStructuredTypeMembers(type)) : type.flags & 67108864 /* NonPrimitive */ ? true : type.flags & 1048576 /* Union */ ? some(type.types, isEmptyObjectType) : type.flags & 2097152 /* Intersection */ ? every(type.types, isEmptyObjectType) : false;
            }
            function isEmptyAnonymousObjectType(type) {
                return !!(getObjectFlags(type) & 16 /* Anonymous */ && (type.members && isEmptyResolvedType(type) || type.symbol && type.symbol.flags & 2048 /* TypeLiteral */ && getMembersOfSymbol(type.symbol).size === 0));
            }
            function isUnknownLikeUnionType(type) {
                if (strictNullChecks && type.flags & 1048576 /* Union */) {
                    if (!(type.objectFlags & 33554432 /* IsUnknownLikeUnionComputed */)) {
                        const types = type.types;
                        type.objectFlags |= 33554432 /* IsUnknownLikeUnionComputed */ | (types.length >= 3 && types[0].flags & 32768 /* Undefined */ && types[1].flags & 65536 /* Null */ && some(types, isEmptyAnonymousObjectType) ? 67108864 /* IsUnknownLikeUnion */ : 0);
                    }
                    return !!(type.objectFlags & 67108864 /* IsUnknownLikeUnion */);
                }
                return false;
            }
            function containsUndefinedType(type) {
                return !!((type.flags & 1048576 /* Union */ ? type.types[0] : type).flags & 32768 /* Undefined */);
            }
            function isStringIndexSignatureOnlyType(type) {
                return type.flags & 524288 /* Object */ && !isGenericMappedType(type) && getPropertiesOfType(type).length === 0 && getIndexInfosOfType(type).length === 1 && !!getIndexInfoOfType(type, stringType) || type.flags & 3145728 /* UnionOrIntersection */ && every(type.types, isStringIndexSignatureOnlyType) || false;
            }
            function isEnumTypeRelatedTo(source, target, errorReporter) {
                const sourceSymbol = source.flags & 8 /* EnumMember */ ? getParentOfSymbol(source) : source;
                const targetSymbol = target.flags & 8 /* EnumMember */ ? getParentOfSymbol(target) : target;
                if (sourceSymbol === targetSymbol) {
                    return true;
                }
                if (sourceSymbol.escapedName !== targetSymbol.escapedName || !(sourceSymbol.flags & 256 /* RegularEnum */) || !(targetSymbol.flags & 256 /* RegularEnum */)) {
                    return false;
                }
                const id = getSymbolId(sourceSymbol) + "," + getSymbolId(targetSymbol);
                const entry = enumRelation.get(id);
                if (entry !== void 0 && !(!(entry & 4 /* Reported */) && entry & 2 /* Failed */ && errorReporter)) {
                    return !!(entry & 1 /* Succeeded */);
                }
                const targetEnumType = getTypeOfSymbol(targetSymbol);
                for (const property of getPropertiesOfType(getTypeOfSymbol(sourceSymbol))) {
                    if (property.flags & 8 /* EnumMember */) {
                        const targetProperty = getPropertyOfType(targetEnumType, property.escapedName);
                        if (!targetProperty || !(targetProperty.flags & 8 /* EnumMember */)) {
                            if (errorReporter) {
                                errorReporter(Diagnostics.Property_0_is_missing_in_type_1, symbolName(property), typeToString(getDeclaredTypeOfSymbol(targetSymbol), 
                                /*enclosingDeclaration*/
                                void 0, 64 /* UseFullyQualifiedType */));
                                enumRelation.set(id, 2 /* Failed */ | 4 /* Reported */);
                            }
                            else {
                                enumRelation.set(id, 2 /* Failed */);
                            }
                            return false;
                        }
                    }
                }
                enumRelation.set(id, 1 /* Succeeded */);
                return true;
            }
            function isSimpleTypeRelatedTo(source, target, relation, errorReporter) {
                const s = source.flags;
                const t = target.flags;
                if (t & 1 /* Any */ || s & 131072 /* Never */ || source === wildcardType)
                    return true;
                if (t & 2 /* Unknown */ && !(relation === strictSubtypeRelation && s & 1 /* Any */))
                    return true;
                if (t & 131072 /* Never */)
                    return false;
                if (s & 402653316 /* StringLike */ && t & 4 /* String */)
                    return true;
                if (s & 128 /* StringLiteral */ && s & 1024 /* EnumLiteral */ && t & 128 /* StringLiteral */ && !(t & 1024 /* EnumLiteral */) && source.value === target.value)
                    return true;
                if (s & 296 /* NumberLike */ && t & 8 /* Number */)
                    return true;
                if (s & 256 /* NumberLiteral */ && s & 1024 /* EnumLiteral */ && t & 256 /* NumberLiteral */ && !(t & 1024 /* EnumLiteral */) && source.value === target.value)
                    return true;
                if (s & 2112 /* BigIntLike */ && t & 64 /* BigInt */)
                    return true;
                if (s & 528 /* BooleanLike */ && t & 16 /* Boolean */)
                    return true;
                if (s & 12288 /* ESSymbolLike */ && t & 4096 /* ESSymbol */)
                    return true;
                if (s & 32 /* Enum */ && t & 32 /* Enum */ && source.symbol.escapedName === target.symbol.escapedName && isEnumTypeRelatedTo(source.symbol, target.symbol, errorReporter))
                    return true;
                if (s & 1024 /* EnumLiteral */ && t & 1024 /* EnumLiteral */) {
                    if (s & 1048576 /* Union */ && t & 1048576 /* Union */ && isEnumTypeRelatedTo(source.symbol, target.symbol, errorReporter))
                        return true;
                    if (s & 2944 /* Literal */ && t & 2944 /* Literal */ && source.value === target.value && isEnumTypeRelatedTo(source.symbol, target.symbol, errorReporter))
                        return true;
                }
                if (s & 32768 /* Undefined */ && (!strictNullChecks && !(t & 3145728 /* UnionOrIntersection */) || t & (32768 /* Undefined */ | 16384 /* Void */)))
                    return true;
                if (s & 65536 /* Null */ && (!strictNullChecks && !(t & 3145728 /* UnionOrIntersection */) || t & 65536 /* Null */))
                    return true;
                if (s & 524288 /* Object */ && t & 67108864 /* NonPrimitive */ && !(relation === strictSubtypeRelation && isEmptyAnonymousObjectType(source) && !(getObjectFlags(source) & 8192 /* FreshLiteral */)))
                    return true;
                if (relation === assignableRelation || relation === comparableRelation) {
                    if (s & 1 /* Any */)
                        return true;
                    if (s & 8 /* Number */ && (t & 32 /* Enum */ || t & 256 /* NumberLiteral */ && t & 1024 /* EnumLiteral */))
                        return true;
                    if (s & 256 /* NumberLiteral */ && !(s & 1024 /* EnumLiteral */) && (t & 32 /* Enum */ || t & 256 /* NumberLiteral */ && t & 1024 /* EnumLiteral */ && source.value === target.value))
                        return true;
                    if (isUnknownLikeUnionType(target))
                        return true;
                }
                return false;
            }
            function isTypeRelatedTo(source, target, relation) {
                if (isFreshLiteralType(source)) {
                    source = source.regularType;
                }
                if (isFreshLiteralType(target)) {
                    target = target.regularType;
                }
                if (source === target) {
                    return true;
                }
                if (relation !== identityRelation) {
                    if (relation === comparableRelation && !(target.flags & 131072 /* Never */) && isSimpleTypeRelatedTo(target, source, relation) || isSimpleTypeRelatedTo(source, target, relation)) {
                        return true;
                    }
                }
                else if (!((source.flags | target.flags) & (3145728 /* UnionOrIntersection */ | 8388608 /* IndexedAccess */ | 16777216 /* Conditional */ | 33554432 /* Substitution */))) {
                    if (source.flags !== target.flags)
                        return false;
                    if (source.flags & 67358815 /* Singleton */)
                        return true;
                }
                if (source.flags & 524288 /* Object */ && target.flags & 524288 /* Object */) {
                    const related = relation.get(getRelationKey(source, target, 0 /* None */, relation, 
                    /*ignoreConstraints*/
                    false));
                    if (related !== void 0) {
                        return !!(related & 1 /* Succeeded */);
                    }
                }
                if (source.flags & 469499904 /* StructuredOrInstantiable */ || target.flags & 469499904 /* StructuredOrInstantiable */) {
                    return checkTypeRelatedTo(source, target, relation, 
                    /*errorNode*/
                    void 0);
                }
                return false;
            }
            function isIgnoredJsxProperty(source, sourceProp) {
                return getObjectFlags(source) & 2048 /* JsxAttributes */ && isHyphenatedJsxName(sourceProp.escapedName);
            }
            function getNormalizedType(type, writing) {
                while (true) {
                    const t = isFreshLiteralType(type) ? type.regularType : getObjectFlags(type) & 4 /* Reference */ ? type.node ? createTypeReference(type.target, getTypeArguments(type)) : getSingleBaseForNonAugmentingSubtype(type) || type : type.flags & 3145728 /* UnionOrIntersection */ ? getNormalizedUnionOrIntersectionType(type, writing) : type.flags & 33554432 /* Substitution */ ? writing ? type.baseType : getSubstitutionIntersection(type) : type.flags & 25165824 /* Simplifiable */ ? getSimplifiedType(type, writing) : type;
                    if (t === type)
                        return t;
                    type = t;
                }
            }
            function getNormalizedUnionOrIntersectionType(type, writing) {
                const reduced = getReducedType(type);
                if (reduced !== type) {
                    return reduced;
                }
                if (type.flags & 2097152 /* Intersection */ && some(type.types, isEmptyAnonymousObjectType)) {
                    const normalizedTypes = sameMap(type.types, (t) => getNormalizedType(t, writing));
                    if (normalizedTypes !== type.types) {
                        return getIntersectionType(normalizedTypes);
                    }
                }
                return type;
            }
            function checkTypeRelatedTo(source, target, relation, errorNode, headMessage, containingMessageChain, errorOutputContainer) {
                var _a2;
                let errorInfo;
                let relatedInfo;
                let maybeKeys;
                let sourceStack;
                let targetStack;
                let maybeCount = 0;
                let sourceDepth = 0;
                let targetDepth = 0;
                let expandingFlags = 0 /* None */;
                let overflow = false;
                let overrideNextErrorInfo = 0;
                let lastSkippedInfo;
                let incompatibleStack;
                Debug.assert(relation !== identityRelation || !errorNode, "no error reporting in identity checking");
                const result = isRelatedTo(source, target, 3 /* Both */, 
                /*reportErrors*/
                !!errorNode, headMessage);
                if (incompatibleStack) {
                    reportIncompatibleStack();
                }
                if (overflow) {
                    (_a2 = tracing) == null ? void 0 : _a2.instant(tracing.Phase.CheckTypes, "checkTypeRelatedTo_DepthLimit", { sourceId: source.id, targetId: target.id, depth: sourceDepth, targetDepth });
                    const diag2 = error(errorNode || currentNode, Diagnostics.Excessive_stack_depth_comparing_types_0_and_1, typeToString(source), typeToString(target));
                    if (errorOutputContainer) {
                        (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                    }
                }
                else if (errorInfo) {
                    if (containingMessageChain) {
                        const chain = containingMessageChain();
                        if (chain) {
                            concatenateDiagnosticMessageChains(chain, errorInfo);
                            errorInfo = chain;
                        }
                    }
                    let relatedInformation;
                    if (headMessage && errorNode && !result && source.symbol) {
                        const links = getSymbolLinks(source.symbol);
                        if (links.originatingImport && !isImportCall(links.originatingImport)) {
                            const helpfulRetry = checkTypeRelatedTo(getTypeOfSymbol(links.target), target, relation, 
                            /*errorNode*/
                            void 0);
                            if (helpfulRetry) {
                                const diag3 = createDiagnosticForNode(links.originatingImport, Diagnostics.Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead);
                                relatedInformation = append(relatedInformation, diag3);
                            }
                        }
                    }
                    const diag2 = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(errorNode), errorNode, errorInfo, relatedInformation);
                    if (relatedInfo) {
                        addRelatedInfo(diag2, ...relatedInfo);
                    }
                    if (errorOutputContainer) {
                        (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                    }
                    if (!errorOutputContainer || !errorOutputContainer.skipLogging) {
                        diagnostics.add(diag2);
                    }
                }
                if (errorNode && errorOutputContainer && errorOutputContainer.skipLogging && result === 0 /* False */) {
                    Debug.assert(!!errorOutputContainer.errors, "missed opportunity to interact with error.");
                }
                return result !== 0 /* False */;
                function resetErrorInfo(saved) {
                    errorInfo = saved.errorInfo;
                    lastSkippedInfo = saved.lastSkippedInfo;
                    incompatibleStack = saved.incompatibleStack;
                    overrideNextErrorInfo = saved.overrideNextErrorInfo;
                    relatedInfo = saved.relatedInfo;
                }
                function captureErrorCalculationState() {
                    return {
                        errorInfo,
                        lastSkippedInfo,
                        incompatibleStack: incompatibleStack == null ? void 0 : incompatibleStack.slice(),
                        overrideNextErrorInfo,
                        relatedInfo: relatedInfo == null ? void 0 : relatedInfo.slice()
                    };
                }
                function reportIncompatibleError(message, arg0, arg1, arg2, arg3) {
                    overrideNextErrorInfo++;
                    lastSkippedInfo = void 0;
                    (incompatibleStack || (incompatibleStack = [])).push([message, arg0, arg1, arg2, arg3]);
                }
                function reportIncompatibleStack() {
                    const stack = incompatibleStack || [];
                    incompatibleStack = void 0;
                    const info = lastSkippedInfo;
                    lastSkippedInfo = void 0;
                    if (stack.length === 1) {
                        reportError(...stack[0]);
                        if (info) {
                            reportRelationError(
                            /*headMessage*/
                            void 0, ...info);
                        }
                        return;
                    }
                    let path = "";
                    const secondaryRootErrors = [];
                    while (stack.length) {
                        const [msg, ...args] = stack.pop();
                        switch (msg.code) {
                            case Diagnostics.Types_of_property_0_are_incompatible.code: {
                                if (path.indexOf("new ") === 0) {
                                    path = `(${path})`;
                                }
                                const str = "" + args[0];
                                if (path.length === 0) {
                                    path = `${str}`;
                                }
                                else if (isIdentifierText(str, getEmitScriptTarget(compilerOptions))) {
                                    path = `${path}.${str}`;
                                }
                                else if (str[0] === "[" && str[str.length - 1] === "]") {
                                    path = `${path}${str}`;
                                }
                                else {
                                    path = `${path}[${str}]`;
                                }
                                break;
                            }
                            case Diagnostics.Call_signature_return_types_0_and_1_are_incompatible.code:
                            case Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible.code:
                            case Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code:
                            case Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code: {
                                if (path.length === 0) {
                                    let mappedMsg = msg;
                                    if (msg.code === Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code) {
                                        mappedMsg = Diagnostics.Call_signature_return_types_0_and_1_are_incompatible;
                                    }
                                    else if (msg.code === Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code) {
                                        mappedMsg = Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible;
                                    }
                                    secondaryRootErrors.unshift([mappedMsg, args[0], args[1]]);
                                }
                                else {
                                    const prefix = msg.code === Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible.code || msg.code === Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code ? "new " : "";
                                    const params = msg.code === Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code || msg.code === Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code ? "" : "...";
                                    path = `${prefix}${path}(${params})`;
                                }
                                break;
                            }
                            case Diagnostics.Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target.code: {
                                secondaryRootErrors.unshift([Diagnostics.Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target, args[0], args[1]]);
                                break;
                            }
                            case Diagnostics.Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target.code: {
                                secondaryRootErrors.unshift([Diagnostics.Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target, args[0], args[1], args[2]]);
                                break;
                            }
                            default:
                                return Debug.fail(`Unhandled Diagnostic: ${msg.code}`);
                        }
                    }
                    if (path) {
                        reportError(path[path.length - 1] === ")" ? Diagnostics.The_types_returned_by_0_are_incompatible_between_these_types : Diagnostics.The_types_of_0_are_incompatible_between_these_types, path);
                    }
                    else {
                        secondaryRootErrors.shift();
                    }
                    for (const [msg, ...args] of secondaryRootErrors) {
                        const originalValue = msg.elidedInCompatabilityPyramid;
                        msg.elidedInCompatabilityPyramid = false;
                        reportError(msg, ...args);
                        msg.elidedInCompatabilityPyramid = originalValue;
                    }
                    if (info) {
                        reportRelationError(
                        /*headMessage*/
                        void 0, ...info);
                    }
                }
                function reportError(message, arg0, arg1, arg2, arg3) {
                    Debug.assert(!!errorNode);
                    if (incompatibleStack)
                        reportIncompatibleStack();
                    if (message.elidedInCompatabilityPyramid)
                        return;
                    errorInfo = chainDiagnosticMessages(errorInfo, message, arg0, arg1, arg2, arg3);
                }
                function associateRelatedInfo(info) {
                    Debug.assert(!!errorInfo);
                    if (!relatedInfo) {
                        relatedInfo = [info];
                    }
                    else {
                        relatedInfo.push(info);
                    }
                }
                function reportRelationError(message, source2, target2) {
                    if (incompatibleStack)
                        reportIncompatibleStack();
                    const [sourceType, targetType] = getTypeNamesForErrorDisplay(source2, target2);
                    let generalizedSource = source2;
                    let generalizedSourceType = sourceType;
                    if (isLiteralType(source2) && !typeCouldHaveTopLevelSingletonTypes(target2)) {
                        generalizedSource = getBaseTypeOfLiteralType(source2);
                        Debug.assert(!isTypeAssignableTo(generalizedSource, target2), "generalized source shouldn't be assignable");
                        generalizedSourceType = getTypeNameForErrorDisplay(generalizedSource);
                    }
                    const targetFlags = target2.flags & 8388608 /* IndexedAccess */ && !(source2.flags & 8388608 /* IndexedAccess */) ? target2.objectType.flags : target2.flags;
                    if (targetFlags & 262144 /* TypeParameter */ && target2 !== markerSuperTypeForCheck && target2 !== markerSubTypeForCheck) {
                        const constraint = getBaseConstraintOfType(target2);
                        let needsOriginalSource;
                        if (constraint && (isTypeAssignableTo(generalizedSource, constraint) || (needsOriginalSource = isTypeAssignableTo(source2, constraint)))) {
                            reportError(Diagnostics._0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_constraint_2, needsOriginalSource ? sourceType : generalizedSourceType, targetType, typeToString(constraint));
                        }
                        else {
                            errorInfo = void 0;
                            reportError(Diagnostics._0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1, targetType, generalizedSourceType);
                        }
                    }
                    if (!message) {
                        if (relation === comparableRelation) {
                            message = Diagnostics.Type_0_is_not_comparable_to_type_1;
                        }
                        else if (sourceType === targetType) {
                            message = Diagnostics.Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated;
                        }
                        else if (exactOptionalPropertyTypes && getExactOptionalUnassignableProperties(source2, target2).length) {
                            message = Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties;
                        }
                        else {
                            if (source2.flags & 128 /* StringLiteral */ && target2.flags & 1048576 /* Union */) {
                                const suggestedType = getSuggestedTypeForNonexistentStringLiteralType(source2, target2);
                                if (suggestedType) {
                                    reportError(Diagnostics.Type_0_is_not_assignable_to_type_1_Did_you_mean_2, generalizedSourceType, targetType, typeToString(suggestedType));
                                    return;
                                }
                            }
                            message = Diagnostics.Type_0_is_not_assignable_to_type_1;
                        }
                    }
                    else if (message === Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1 && exactOptionalPropertyTypes && getExactOptionalUnassignableProperties(source2, target2).length) {
                        message = Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties;
                    }
                    reportError(message, generalizedSourceType, targetType);
                }
                function tryElaborateErrorsForPrimitivesAndObjects(source2, target2) {
                    const sourceType = symbolValueDeclarationIsContextSensitive(source2.symbol) ? typeToString(source2, source2.symbol.valueDeclaration) : typeToString(source2);
                    const targetType = symbolValueDeclarationIsContextSensitive(target2.symbol) ? typeToString(target2, target2.symbol.valueDeclaration) : typeToString(target2);
                    if (globalStringType === source2 && stringType === target2 || globalNumberType === source2 && numberType === target2 || globalBooleanType === source2 && booleanType === target2 || getGlobalESSymbolType() === source2 && esSymbolType === target2) {
                        reportError(Diagnostics._0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible, targetType, sourceType);
                    }
                }
                function tryElaborateArrayLikeErrors(source2, target2, reportErrors2) {
                    if (isTupleType(source2)) {
                        if (source2.target.readonly && isMutableArrayOrTuple(target2)) {
                            if (reportErrors2) {
                                reportError(Diagnostics.The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1, typeToString(source2), typeToString(target2));
                            }
                            return false;
                        }
                        return isArrayOrTupleType(target2);
                    }
                    if (isReadonlyArrayType(source2) && isMutableArrayOrTuple(target2)) {
                        if (reportErrors2) {
                            reportError(Diagnostics.The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1, typeToString(source2), typeToString(target2));
                        }
                        return false;
                    }
                    if (isTupleType(target2)) {
                        return isArrayType(source2);
                    }
                    return true;
                }
                function isRelatedToWorker(source2, target2, reportErrors2) {
                    return isRelatedTo(source2, target2, 3 /* Both */, reportErrors2);
                }
                function isRelatedTo(originalSource, originalTarget, recursionFlags = 3 /* Both */, reportErrors2 = false, headMessage2, intersectionState = 0 /* None */) {
                    if (originalSource.flags & 524288 /* Object */ && originalTarget.flags & 134348796 /* Primitive */) {
                        if (relation === comparableRelation && !(originalTarget.flags & 131072 /* Never */) && isSimpleTypeRelatedTo(originalTarget, originalSource, relation) || isSimpleTypeRelatedTo(originalSource, originalTarget, relation, reportErrors2 ? reportError : void 0)) {
                            return -1 /* True */;
                        }
                        if (reportErrors2) {
                            reportErrorResults(originalSource, originalTarget, originalSource, originalTarget, headMessage2);
                        }
                        return 0 /* False */;
                    }
                    const source2 = getNormalizedType(originalSource, 
                    /*writing*/
                    false);
                    let target2 = getNormalizedType(originalTarget, 
                    /*writing*/
                    true);
                    if (source2 === target2)
                        return -1 /* True */;
                    if (relation === identityRelation) {
                        if (source2.flags !== target2.flags)
                            return 0 /* False */;
                        if (source2.flags & 67358815 /* Singleton */)
                            return -1 /* True */;
                        traceUnionsOrIntersectionsTooLarge(source2, target2);
                        return recursiveTypeRelatedTo(source2, target2, 
                        /*reportErrors*/
                        false, 0 /* None */, recursionFlags);
                    }
                    if (source2.flags & 262144 /* TypeParameter */ && getConstraintOfType(source2) === target2) {
                        return -1 /* True */;
                    }
                    if (source2.flags & 470302716 /* DefinitelyNonNullable */ && target2.flags & 1048576 /* Union */) {
                        const types = target2.types;
                        const candidate = types.length === 2 && types[0].flags & 98304 /* Nullable */ ? types[1] : types.length === 3 && types[0].flags & 98304 /* Nullable */ && types[1].flags & 98304 /* Nullable */ ? types[2] : void 0;
                        if (candidate && !(candidate.flags & 98304 /* Nullable */)) {
                            target2 = getNormalizedType(candidate, 
                            /*writing*/
                            true);
                            if (source2 === target2)
                                return -1 /* True */;
                        }
                    }
                    if (relation === comparableRelation && !(target2.flags & 131072 /* Never */) && isSimpleTypeRelatedTo(target2, source2, relation) || isSimpleTypeRelatedTo(source2, target2, relation, reportErrors2 ? reportError : void 0))
                        return -1 /* True */;
                    if (source2.flags & 469499904 /* StructuredOrInstantiable */ || target2.flags & 469499904 /* StructuredOrInstantiable */) {
                        const isPerformingExcessPropertyChecks = !(intersectionState & 2 /* Target */) && (isObjectLiteralType2(source2) && getObjectFlags(source2) & 8192 /* FreshLiteral */);
                        if (isPerformingExcessPropertyChecks) {
                            if (hasExcessProperties(source2, target2, reportErrors2)) {
                                if (reportErrors2) {
                                    reportRelationError(headMessage2, source2, originalTarget.aliasSymbol ? originalTarget : target2);
                                }
                                return 0 /* False */;
                            }
                        }
                        const isPerformingCommonPropertyChecks = (relation !== comparableRelation || isUnitType(source2)) && !(intersectionState & 2 /* Target */) && source2.flags & (134348796 /* Primitive */ | 524288 /* Object */ | 2097152 /* Intersection */) && source2 !== globalObjectType && target2.flags & (524288 /* Object */ | 2097152 /* Intersection */) && isWeakType(target2) && (getPropertiesOfType(source2).length > 0 || typeHasCallOrConstructSignatures(source2));
                        const isComparingJsxAttributes = !!(getObjectFlags(source2) & 2048 /* JsxAttributes */);
                        if (isPerformingCommonPropertyChecks && !hasCommonProperties(source2, target2, isComparingJsxAttributes)) {
                            if (reportErrors2) {
                                const sourceString = typeToString(originalSource.aliasSymbol ? originalSource : source2);
                                const targetString = typeToString(originalTarget.aliasSymbol ? originalTarget : target2);
                                const calls = getSignaturesOfType(source2, 0 /* Call */);
                                const constructs = getSignaturesOfType(source2, 1 /* Construct */);
                                if (calls.length > 0 && isRelatedTo(getReturnTypeOfSignature(calls[0]), target2, 1 /* Source */, 
                                /*reportErrors*/
                                false) || constructs.length > 0 && isRelatedTo(getReturnTypeOfSignature(constructs[0]), target2, 1 /* Source */, 
                                /*reportErrors*/
                                false)) {
                                    reportError(Diagnostics.Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it, sourceString, targetString);
                                }
                                else {
                                    reportError(Diagnostics.Type_0_has_no_properties_in_common_with_type_1, sourceString, targetString);
                                }
                            }
                            return 0 /* False */;
                        }
                        traceUnionsOrIntersectionsTooLarge(source2, target2);
                        const skipCaching = source2.flags & 1048576 /* Union */ && source2.types.length < 4 && !(target2.flags & 1048576 /* Union */) || target2.flags & 1048576 /* Union */ && target2.types.length < 4 && !(source2.flags & 469499904 /* StructuredOrInstantiable */);
                        const result2 = skipCaching ? unionOrIntersectionRelatedTo(source2, target2, reportErrors2, intersectionState) : recursiveTypeRelatedTo(source2, target2, reportErrors2, intersectionState, recursionFlags);
                        if (result2) {
                            return result2;
                        }
                    }
                    if (reportErrors2) {
                        reportErrorResults(originalSource, originalTarget, source2, target2, headMessage2);
                    }
                    return 0 /* False */;
                }
                function reportErrorResults(originalSource, originalTarget, source2, target2, headMessage2) {
                    var _a3, _b;
                    const sourceHasBase = !!getSingleBaseForNonAugmentingSubtype(originalSource);
                    const targetHasBase = !!getSingleBaseForNonAugmentingSubtype(originalTarget);
                    source2 = originalSource.aliasSymbol || sourceHasBase ? originalSource : source2;
                    target2 = originalTarget.aliasSymbol || targetHasBase ? originalTarget : target2;
                    let maybeSuppress = overrideNextErrorInfo > 0;
                    if (maybeSuppress) {
                        overrideNextErrorInfo--;
                    }
                    if (source2.flags & 524288 /* Object */ && target2.flags & 524288 /* Object */) {
                        const currentError = errorInfo;
                        tryElaborateArrayLikeErrors(source2, target2, 
                        /*reportErrors*/
                        true);
                        if (errorInfo !== currentError) {
                            maybeSuppress = !!errorInfo;
                        }
                    }
                    if (source2.flags & 524288 /* Object */ && target2.flags & 134348796 /* Primitive */) {
                        tryElaborateErrorsForPrimitivesAndObjects(source2, target2);
                    }
                    else if (source2.symbol && source2.flags & 524288 /* Object */ && globalObjectType === source2) {
                        reportError(Diagnostics.The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead);
                    }
                    else if (getObjectFlags(source2) & 2048 /* JsxAttributes */ && target2.flags & 2097152 /* Intersection */) {
                        const targetTypes = target2.types;
                        const intrinsicAttributes = getJsxType(JsxNames.IntrinsicAttributes, errorNode);
                        const intrinsicClassAttributes = getJsxType(JsxNames.IntrinsicClassAttributes, errorNode);
                        if (!isErrorType(intrinsicAttributes) && !isErrorType(intrinsicClassAttributes) && (contains(targetTypes, intrinsicAttributes) || contains(targetTypes, intrinsicClassAttributes))) {
                            return;
                        }
                    }
                    else {
                        errorInfo = elaborateNeverIntersection(errorInfo, originalTarget);
                    }
                    if (!headMessage2 && maybeSuppress) {
                        lastSkippedInfo = [source2, target2];
                        return;
                    }
                    reportRelationError(headMessage2, source2, target2);
                    if (source2.flags & 262144 /* TypeParameter */ && ((_b = (_a3 = source2.symbol) == null ? void 0 : _a3.declarations) == null ? void 0 : _b[0]) && !getConstraintOfType(source2)) {
                        const syntheticParam = cloneTypeParameter(source2);
                        syntheticParam.constraint = instantiateType(target2, makeUnaryTypeMapper(source2, syntheticParam));
                        if (hasNonCircularBaseConstraint(syntheticParam)) {
                            const targetConstraintString = typeToString(target2, source2.symbol.declarations[0]);
                            associateRelatedInfo(createDiagnosticForNode(source2.symbol.declarations[0], Diagnostics.This_type_parameter_might_need_an_extends_0_constraint, targetConstraintString));
                        }
                    }
                }
                function traceUnionsOrIntersectionsTooLarge(source2, target2) {
                    if (!tracing) {
                        return;
                    }
                    if (source2.flags & 3145728 /* UnionOrIntersection */ && target2.flags & 3145728 /* UnionOrIntersection */) {
                        const sourceUnionOrIntersection = source2;
                        const targetUnionOrIntersection = target2;
                        if (sourceUnionOrIntersection.objectFlags & targetUnionOrIntersection.objectFlags & 32768 /* PrimitiveUnion */) {
                            return;
                        }
                        const sourceSize = sourceUnionOrIntersection.types.length;
                        const targetSize = targetUnionOrIntersection.types.length;
                        if (sourceSize * targetSize > 1e6) {
                            tracing.instant(tracing.Phase.CheckTypes, "traceUnionsOrIntersectionsTooLarge_DepthLimit", {
                                sourceId: source2.id,
                                sourceSize,
                                targetId: target2.id,
                                targetSize,
                                pos: errorNode == null ? void 0 : errorNode.pos,
                                end: errorNode == null ? void 0 : errorNode.end
                            });
                        }
                    }
                }
                function getTypeOfPropertyInTypes(types, name) {
                    const appendPropType = (propTypes, type) => {
                        var _a3;
                        type = getApparentType(type);
                        const prop = type.flags & 3145728 /* UnionOrIntersection */ ? getPropertyOfUnionOrIntersectionType(type, name) : getPropertyOfObjectType(type, name);
                        const propType = prop && getTypeOfSymbol(prop) || ((_a3 = getApplicableIndexInfoForName(type, name)) == null ? void 0 : _a3.type) || undefinedType;
                        return append(propTypes, propType);
                    };
                    return getUnionType(reduceLeft(types, appendPropType, 
                    /*initial*/
                    void 0) || emptyArray);
                }
                function hasExcessProperties(source2, target2, reportErrors2) {
                    var _a3;
                    if (!isExcessPropertyCheckTarget(target2) || !noImplicitAny && getObjectFlags(target2) & 4096 /* JSLiteral */) {
                        return false;
                    }
                    const isComparingJsxAttributes = !!(getObjectFlags(source2) & 2048 /* JsxAttributes */);
                    if ((relation === assignableRelation || relation === comparableRelation) && (isTypeSubsetOf(globalObjectType, target2) || !isComparingJsxAttributes && isEmptyObjectType(target2))) {
                        return false;
                    }
                    let reducedTarget = target2;
                    let checkTypes;
                    if (target2.flags & 1048576 /* Union */) {
                        reducedTarget = findMatchingDiscriminantType(source2, target2, isRelatedTo) || filterPrimitivesIfContainsNonPrimitive(target2);
                        checkTypes = reducedTarget.flags & 1048576 /* Union */ ? reducedTarget.types : [reducedTarget];
                    }
                    for (const prop of getPropertiesOfType(source2)) {
                        if (shouldCheckAsExcessProperty(prop, source2.symbol) && !isIgnoredJsxProperty(source2, prop)) {
                            if (!isKnownProperty(reducedTarget, prop.escapedName, isComparingJsxAttributes)) {
                                if (reportErrors2) {
                                    const errorTarget = filterType(reducedTarget, isExcessPropertyCheckTarget);
                                    if (!errorNode)
                                        return Debug.fail();
                                    if (isJsxAttributes(errorNode) || isJsxOpeningLikeElement(errorNode) || isJsxOpeningLikeElement(errorNode.parent)) {
                                        if (prop.valueDeclaration && isJsxAttribute(prop.valueDeclaration) && getSourceFileOfNode(errorNode) === getSourceFileOfNode(prop.valueDeclaration.name)) {
                                            errorNode = prop.valueDeclaration.name;
                                        }
                                        const propName = symbolToString(prop);
                                        const suggestionSymbol = getSuggestedSymbolForNonexistentJSXAttribute(propName, errorTarget);
                                        const suggestion = suggestionSymbol ? symbolToString(suggestionSymbol) : void 0;
                                        if (suggestion) {
                                            reportError(Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2, propName, typeToString(errorTarget), suggestion);
                                        }
                                        else {
                                            reportError(Diagnostics.Property_0_does_not_exist_on_type_1, propName, typeToString(errorTarget));
                                        }
                                    }
                                    else {
                                        const objectLiteralDeclaration = ((_a3 = source2.symbol) == null ? void 0 : _a3.declarations) && firstOrUndefined(source2.symbol.declarations);
                                        let suggestion;
                                        if (prop.valueDeclaration && findAncestor(prop.valueDeclaration, (d) => d === objectLiteralDeclaration) && getSourceFileOfNode(objectLiteralDeclaration) === getSourceFileOfNode(errorNode)) {
                                            const propDeclaration = prop.valueDeclaration;
                                            Debug.assertNode(propDeclaration, isObjectLiteralElementLike);
                                            errorNode = propDeclaration;
                                            const name = propDeclaration.name;
                                            if (isIdentifier(name)) {
                                                suggestion = getSuggestionForNonexistentProperty(name, errorTarget);
                                            }
                                        }
                                        if (suggestion !== void 0) {
                                            reportError(Diagnostics.Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_write_2, symbolToString(prop), typeToString(errorTarget), suggestion);
                                        }
                                        else {
                                            reportError(Diagnostics.Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1, symbolToString(prop), typeToString(errorTarget));
                                        }
                                    }
                                }
                                return true;
                            }
                            if (checkTypes && !isRelatedTo(getTypeOfSymbol(prop), getTypeOfPropertyInTypes(checkTypes, prop.escapedName), 3 /* Both */, reportErrors2)) {
                                if (reportErrors2) {
                                    reportIncompatibleError(Diagnostics.Types_of_property_0_are_incompatible, symbolToString(prop));
                                }
                                return true;
                            }
                        }
                    }
                    return false;
                }
                function shouldCheckAsExcessProperty(prop, container) {
                    return prop.valueDeclaration && container.valueDeclaration && prop.valueDeclaration.parent === container.valueDeclaration;
                }
                function unionOrIntersectionRelatedTo(source2, target2, reportErrors2, intersectionState) {
                    if (source2.flags & 1048576 /* Union */) {
                        return relation === comparableRelation ? someTypeRelatedToType(source2, target2, reportErrors2 && !(source2.flags & 134348796 /* Primitive */), intersectionState) : eachTypeRelatedToType(source2, target2, reportErrors2 && !(source2.flags & 134348796 /* Primitive */), intersectionState);
                    }
                    if (target2.flags & 1048576 /* Union */) {
                        return typeRelatedToSomeType(getRegularTypeOfObjectLiteral(source2), target2, reportErrors2 && !(source2.flags & 134348796 /* Primitive */) && !(target2.flags & 134348796 /* Primitive */));
                    }
                    if (target2.flags & 2097152 /* Intersection */) {
                        return typeRelatedToEachType(source2, target2, reportErrors2, 2 /* Target */);
                    }
                    if (relation === comparableRelation && target2.flags & 134348796 /* Primitive */) {
                        const constraints = sameMap(source2.types, (t) => t.flags & 465829888 /* Instantiable */ ? getBaseConstraintOfType(t) || unknownType : t);
                        if (constraints !== source2.types) {
                            source2 = getIntersectionType(constraints);
                            if (source2.flags & 131072 /* Never */) {
                                return 0 /* False */;
                            }
                            if (!(source2.flags & 2097152 /* Intersection */)) {
                                return isRelatedTo(source2, target2, 1 /* Source */, 
                                /*reportErrors*/
                                false) || isRelatedTo(target2, source2, 1 /* Source */, 
                                /*reportErrors*/
                                false);
                            }
                        }
                    }
                    return someTypeRelatedToType(source2, target2, 
                    /*reportErrors*/
                    false, 1 /* Source */);
                }
                function eachTypeRelatedToSomeType(source2, target2) {
                    let result2 = -1 /* True */;
                    const sourceTypes = source2.types;
                    for (const sourceType of sourceTypes) {
                        const related = typeRelatedToSomeType(sourceType, target2, 
                        /*reportErrors*/
                        false);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function typeRelatedToSomeType(source2, target2, reportErrors2) {
                    const targetTypes = target2.types;
                    if (target2.flags & 1048576 /* Union */) {
                        if (containsType(targetTypes, source2)) {
                            return -1 /* True */;
                        }
                        const match = getMatchingUnionConstituentForType(target2, source2);
                        if (match) {
                            const related = isRelatedTo(source2, match, 2 /* Target */, 
                            /*reportErrors*/
                            false);
                            if (related) {
                                return related;
                            }
                        }
                    }
                    for (const type of targetTypes) {
                        const related = isRelatedTo(source2, type, 2 /* Target */, 
                        /*reportErrors*/
                        false);
                        if (related) {
                            return related;
                        }
                    }
                    if (reportErrors2) {
                        const bestMatchingType = getBestMatchingType(source2, target2, isRelatedTo);
                        if (bestMatchingType) {
                            isRelatedTo(source2, bestMatchingType, 2 /* Target */, 
                            /*reportErrors*/
                            true);
                        }
                    }
                    return 0 /* False */;
                }
                function typeRelatedToEachType(source2, target2, reportErrors2, intersectionState) {
                    let result2 = -1 /* True */;
                    const targetTypes = target2.types;
                    for (const targetType of targetTypes) {
                        const related = isRelatedTo(source2, targetType, 2 /* Target */, reportErrors2, 
                        /*headMessage*/
                        void 0, intersectionState);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function someTypeRelatedToType(source2, target2, reportErrors2, intersectionState) {
                    const sourceTypes = source2.types;
                    if (source2.flags & 1048576 /* Union */ && containsType(sourceTypes, target2)) {
                        return -1 /* True */;
                    }
                    const len = sourceTypes.length;
                    for (let i = 0; i < len; i++) {
                        const related = isRelatedTo(sourceTypes[i], target2, 1 /* Source */, reportErrors2 && i === len - 1, 
                        /*headMessage*/
                        void 0, intersectionState);
                        if (related) {
                            return related;
                        }
                    }
                    return 0 /* False */;
                }
                function getUndefinedStrippedTargetIfNeeded(source2, target2) {
                    if (source2.flags & 1048576 /* Union */ && target2.flags & 1048576 /* Union */ && !(source2.types[0].flags & 32768 /* Undefined */) && target2.types[0].flags & 32768 /* Undefined */) {
                        return extractTypesOfKind(target2, ~32768 /* Undefined */);
                    }
                    return target2;
                }
                function eachTypeRelatedToType(source2, target2, reportErrors2, intersectionState) {
                    let result2 = -1 /* True */;
                    const sourceTypes = source2.types;
                    const undefinedStrippedTarget = getUndefinedStrippedTargetIfNeeded(source2, target2);
                    for (let i = 0; i < sourceTypes.length; i++) {
                        const sourceType = sourceTypes[i];
                        if (undefinedStrippedTarget.flags & 1048576 /* Union */ && sourceTypes.length >= undefinedStrippedTarget.types.length && sourceTypes.length % undefinedStrippedTarget.types.length === 0) {
                            const related2 = isRelatedTo(sourceType, undefinedStrippedTarget.types[i % undefinedStrippedTarget.types.length], 3 /* Both */, 
                            /*reportErrors*/
                            false, 
                            /*headMessage*/
                            void 0, intersectionState);
                            if (related2) {
                                result2 &= related2;
                                continue;
                            }
                        }
                        const related = isRelatedTo(sourceType, target2, 1 /* Source */, reportErrors2, 
                        /*headMessage*/
                        void 0, intersectionState);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function typeArgumentsRelatedTo(sources = emptyArray, targets = emptyArray, variances = emptyArray, reportErrors2, intersectionState) {
                    if (sources.length !== targets.length && relation === identityRelation) {
                        return 0 /* False */;
                    }
                    const length2 = sources.length <= targets.length ? sources.length : targets.length;
                    let result2 = -1 /* True */;
                    for (let i = 0; i < length2; i++) {
                        const varianceFlags = i < variances.length ? variances[i] : 1 /* Covariant */;
                        const variance = varianceFlags & 7 /* VarianceMask */;
                        if (variance !== 4 /* Independent */) {
                            const s = sources[i];
                            const t = targets[i];
                            let related = -1 /* True */;
                            if (varianceFlags & 8 /* Unmeasurable */) {
                                related = relation === identityRelation ? isRelatedTo(s, t, 3 /* Both */, 
                                /*reportErrors*/
                                false) : compareTypesIdentical(s, t);
                            }
                            else if (variance === 1 /* Covariant */) {
                                related = isRelatedTo(s, t, 3 /* Both */, reportErrors2, 
                                /*headMessage*/
                                void 0, intersectionState);
                            }
                            else if (variance === 2 /* Contravariant */) {
                                related = isRelatedTo(t, s, 3 /* Both */, reportErrors2, 
                                /*headMessage*/
                                void 0, intersectionState);
                            }
                            else if (variance === 3 /* Bivariant */) {
                                related = isRelatedTo(t, s, 3 /* Both */, 
                                /*reportErrors*/
                                false);
                                if (!related) {
                                    related = isRelatedTo(s, t, 3 /* Both */, reportErrors2, 
                                    /*headMessage*/
                                    void 0, intersectionState);
                                }
                            }
                            else {
                                related = isRelatedTo(s, t, 3 /* Both */, reportErrors2, 
                                /*headMessage*/
                                void 0, intersectionState);
                                if (related) {
                                    related &= isRelatedTo(t, s, 3 /* Both */, reportErrors2, 
                                    /*headMessage*/
                                    void 0, intersectionState);
                                }
                            }
                            if (!related) {
                                return 0 /* False */;
                            }
                            result2 &= related;
                        }
                    }
                    return result2;
                }
                function recursiveTypeRelatedTo(source2, target2, reportErrors2, intersectionState, recursionFlags) {
                    var _a3, _b, _c;
                    if (overflow) {
                        return 0 /* False */;
                    }
                    const id = getRelationKey(source2, target2, intersectionState, relation, 
                    /*ingnoreConstraints*/
                    false);
                    const entry = relation.get(id);
                    if (entry !== void 0) {
                        if (reportErrors2 && entry & 2 /* Failed */ && !(entry & 4 /* Reported */)) {
                        }
                        else {
                            if (outofbandVarianceMarkerHandler) {
                                const saved = entry & 24 /* ReportsMask */;
                                if (saved & 8 /* ReportsUnmeasurable */) {
                                    instantiateType(source2, reportUnmeasurableMapper);
                                }
                                if (saved & 16 /* ReportsUnreliable */) {
                                    instantiateType(source2, reportUnreliableMapper);
                                }
                            }
                            return entry & 1 /* Succeeded */ ? -1 /* True */ : 0 /* False */;
                        }
                    }
                    if (!maybeKeys) {
                        maybeKeys = [];
                        sourceStack = [];
                        targetStack = [];
                    }
                    else {
                        const broadestEquivalentId = id.startsWith("*") ? getRelationKey(source2, target2, intersectionState, relation, 
                        /*ignoreConstraints*/
                        true) : void 0;
                        for (let i = 0; i < maybeCount; i++) {
                            if (id === maybeKeys[i] || broadestEquivalentId && broadestEquivalentId === maybeKeys[i]) {
                                return 3 /* Maybe */;
                            }
                        }
                        if (sourceDepth === 100 || targetDepth === 100) {
                            overflow = true;
                            return 0 /* False */;
                        }
                    }
                    const maybeStart = maybeCount;
                    maybeKeys[maybeCount] = id;
                    maybeCount++;
                    const saveExpandingFlags = expandingFlags;
                    if (recursionFlags & 1 /* Source */) {
                        sourceStack[sourceDepth] = source2;
                        sourceDepth++;
                        if (!(expandingFlags & 1 /* Source */) && isDeeplyNestedType(source2, sourceStack, sourceDepth))
                            expandingFlags |= 1 /* Source */;
                    }
                    if (recursionFlags & 2 /* Target */) {
                        targetStack[targetDepth] = target2;
                        targetDepth++;
                        if (!(expandingFlags & 2 /* Target */) && isDeeplyNestedType(target2, targetStack, targetDepth))
                            expandingFlags |= 2 /* Target */;
                    }
                    let originalHandler;
                    let propagatingVarianceFlags = 0;
                    if (outofbandVarianceMarkerHandler) {
                        originalHandler = outofbandVarianceMarkerHandler;
                        outofbandVarianceMarkerHandler = (onlyUnreliable) => {
                            propagatingVarianceFlags |= onlyUnreliable ? 16 /* ReportsUnreliable */ : 8 /* ReportsUnmeasurable */;
                            return originalHandler(onlyUnreliable);
                        };
                    }
                    let result2;
                    if (expandingFlags === 3 /* Both */) {
                        (_a3 = tracing) == null ? void 0 : _a3.instant(tracing.Phase.CheckTypes, "recursiveTypeRelatedTo_DepthLimit", {
                            sourceId: source2.id,
                            sourceIdStack: sourceStack.map((t) => t.id),
                            targetId: target2.id,
                            targetIdStack: targetStack.map((t) => t.id),
                            depth: sourceDepth,
                            targetDepth
                        });
                        result2 = 3 /* Maybe */;
                    }
                    else {
                        (_b = tracing) == null ? void 0 : _b.push(tracing.Phase.CheckTypes, "structuredTypeRelatedTo", { sourceId: source2.id, targetId: target2.id });
                        result2 = structuredTypeRelatedTo(source2, target2, reportErrors2, intersectionState);
                        (_c = tracing) == null ? void 0 : _c.pop();
                    }
                    if (outofbandVarianceMarkerHandler) {
                        outofbandVarianceMarkerHandler = originalHandler;
                    }
                    if (recursionFlags & 1 /* Source */) {
                        sourceDepth--;
                    }
                    if (recursionFlags & 2 /* Target */) {
                        targetDepth--;
                    }
                    expandingFlags = saveExpandingFlags;
                    if (result2) {
                        if (result2 === -1 /* True */ || sourceDepth === 0 && targetDepth === 0) {
                            if (result2 === -1 /* True */ || result2 === 3 /* Maybe */) {
                                for (let i = maybeStart; i < maybeCount; i++) {
                                    relation.set(maybeKeys[i], 1 /* Succeeded */ | propagatingVarianceFlags);
                                }
                            }
                            maybeCount = maybeStart;
                        }
                    }
                    else {
                        relation.set(id, (reportErrors2 ? 4 /* Reported */ : 0) | 2 /* Failed */ | propagatingVarianceFlags);
                        maybeCount = maybeStart;
                    }
                    return result2;
                }
                function structuredTypeRelatedTo(source2, target2, reportErrors2, intersectionState) {
                    const saveErrorInfo = captureErrorCalculationState();
                    let result2 = structuredTypeRelatedToWorker(source2, target2, reportErrors2, intersectionState, saveErrorInfo);
                    if (relation !== identityRelation) {
                        if (!result2 && (source2.flags & 2097152 /* Intersection */ || source2.flags & 262144 /* TypeParameter */ && target2.flags & 1048576 /* Union */)) {
                            const constraint = getEffectiveConstraintOfIntersection(source2.flags & 2097152 /* Intersection */ ? source2.types : [source2], !!(target2.flags & 1048576 /* Union */));
                            if (constraint && everyType(constraint, (c) => c !== source2)) {
                                result2 = isRelatedTo(constraint, target2, 1 /* Source */, 
                                /*reportErrors*/
                                false, 
                                /*headMessage*/
                                void 0, intersectionState);
                            }
                        }
                        if (result2 && !(intersectionState & 2 /* Target */) && target2.flags & 2097152 /* Intersection */ && !isGenericObjectType(target2) && source2.flags & (524288 /* Object */ | 2097152 /* Intersection */)) {
                            result2 &= propertiesRelatedTo(source2, target2, reportErrors2, 
                            /*excludedProperties*/
                            void 0, 
                            /*optionalsOnly*/
                            false, 0 /* None */);
                            if (result2 && isObjectLiteralType2(source2) && getObjectFlags(source2) & 8192 /* FreshLiteral */) {
                                result2 &= indexSignaturesRelatedTo(source2, target2, 
                                /*sourceIsPrimitive*/
                                false, reportErrors2, 0 /* None */);
                            }
                        }
                        else if (result2 && isNonGenericObjectType(target2) && !isArrayOrTupleType(target2) && source2.flags & 2097152 /* Intersection */ && getApparentType(source2).flags & 3670016 /* StructuredType */ && !some(source2.types, (t) => t === target2 || !!(getObjectFlags(t) & 262144 /* NonInferrableType */))) {
                            result2 &= propertiesRelatedTo(source2, target2, reportErrors2, 
                            /*excludedProperties*/
                            void 0, 
                            /*optionalsOnly*/
                            true, intersectionState);
                        }
                    }
                    if (result2) {
                        resetErrorInfo(saveErrorInfo);
                    }
                    return result2;
                }
                function structuredTypeRelatedToWorker(source2, target2, reportErrors2, intersectionState, saveErrorInfo) {
                    let result2;
                    let originalErrorInfo;
                    let varianceCheckFailed = false;
                    let sourceFlags = source2.flags;
                    const targetFlags = target2.flags;
                    if (relation === identityRelation) {
                        if (sourceFlags & 3145728 /* UnionOrIntersection */) {
                            let result3 = eachTypeRelatedToSomeType(source2, target2);
                            if (result3) {
                                result3 &= eachTypeRelatedToSomeType(target2, source2);
                            }
                            return result3;
                        }
                        if (sourceFlags & 4194304 /* Index */) {
                            return isRelatedTo(source2.type, target2.type, 3 /* Both */, 
                            /*reportErrors*/
                            false);
                        }
                        if (sourceFlags & 8388608 /* IndexedAccess */) {
                            if (result2 = isRelatedTo(source2.objectType, target2.objectType, 3 /* Both */, 
                            /*reportErrors*/
                            false)) {
                                if (result2 &= isRelatedTo(source2.indexType, target2.indexType, 3 /* Both */, 
                                /*reportErrors*/
                                false)) {
                                    return result2;
                                }
                            }
                        }
                        if (sourceFlags & 16777216 /* Conditional */) {
                            if (source2.root.isDistributive === target2.root.isDistributive) {
                                if (result2 = isRelatedTo(source2.checkType, target2.checkType, 3 /* Both */, 
                                /*reportErrors*/
                                false)) {
                                    if (result2 &= isRelatedTo(source2.extendsType, target2.extendsType, 3 /* Both */, 
                                    /*reportErrors*/
                                    false)) {
                                        if (result2 &= isRelatedTo(getTrueTypeFromConditionalType(source2), getTrueTypeFromConditionalType(target2), 3 /* Both */, 
                                        /*reportErrors*/
                                        false)) {
                                            if (result2 &= isRelatedTo(getFalseTypeFromConditionalType(source2), getFalseTypeFromConditionalType(target2), 3 /* Both */, 
                                            /*reportErrors*/
                                            false)) {
                                                return result2;
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        if (sourceFlags & 33554432 /* Substitution */) {
                            if (result2 = isRelatedTo(source2.baseType, target2.baseType, 3 /* Both */, 
                            /*reportErrors*/
                            false)) {
                                if (result2 &= isRelatedTo(source2.constraint, target2.constraint, 3 /* Both */, 
                                /*reportErrors*/
                                false)) {
                                    return result2;
                                }
                            }
                        }
                        if (!(sourceFlags & 524288 /* Object */)) {
                            return 0 /* False */;
                        }
                    }
                    else if (sourceFlags & 3145728 /* UnionOrIntersection */ || targetFlags & 3145728 /* UnionOrIntersection */) {
                        if (result2 = unionOrIntersectionRelatedTo(source2, target2, reportErrors2, intersectionState)) {
                            return result2;
                        }
                        if (!(sourceFlags & 465829888 /* Instantiable */ || sourceFlags & 524288 /* Object */ && targetFlags & 1048576 /* Union */ || sourceFlags & 2097152 /* Intersection */ && targetFlags & (524288 /* Object */ | 1048576 /* Union */ | 465829888 /* Instantiable */))) {
                            return 0 /* False */;
                        }
                    }
                    if (sourceFlags & (524288 /* Object */ | 16777216 /* Conditional */) && source2.aliasSymbol && source2.aliasTypeArguments && source2.aliasSymbol === target2.aliasSymbol && !(isMarkerType(source2) || isMarkerType(target2))) {
                        const variances = getAliasVariances(source2.aliasSymbol);
                        if (variances === emptyArray) {
                            return 1 /* Unknown */;
                        }
                        const params = getSymbolLinks(source2.aliasSymbol).typeParameters;
                        const minParams = getMinTypeArgumentCount(params);
                        const sourceTypes = fillMissingTypeArguments(source2.aliasTypeArguments, params, minParams, isInJSFile(source2.aliasSymbol.valueDeclaration));
                        const targetTypes = fillMissingTypeArguments(target2.aliasTypeArguments, params, minParams, isInJSFile(source2.aliasSymbol.valueDeclaration));
                        const varianceResult = relateVariances(sourceTypes, targetTypes, variances, intersectionState);
                        if (varianceResult !== void 0) {
                            return varianceResult;
                        }
                    }
                    if (isSingleElementGenericTupleType(source2) && !source2.target.readonly && (result2 = isRelatedTo(getTypeArguments(source2)[0], target2, 1 /* Source */)) || isSingleElementGenericTupleType(target2) && (target2.target.readonly || isMutableArrayOrTuple(getBaseConstraintOfType(source2) || source2)) && (result2 = isRelatedTo(source2, getTypeArguments(target2)[0], 2 /* Target */))) {
                        return result2;
                    }
                    if (targetFlags & 262144 /* TypeParameter */) {
                        if (getObjectFlags(source2) & 32 /* Mapped */ && !source2.declaration.nameType && isRelatedTo(getIndexType(target2), getConstraintTypeFromMappedType(source2), 3 /* Both */)) {
                            if (!(getMappedTypeModifiers(source2) & 4 /* IncludeOptional */)) {
                                const templateType = getTemplateTypeFromMappedType(source2);
                                const indexedAccessType = getIndexedAccessType(target2, getTypeParameterFromMappedType(source2));
                                if (result2 = isRelatedTo(templateType, indexedAccessType, 3 /* Both */, reportErrors2)) {
                                    return result2;
                                }
                            }
                        }
                        if (relation === comparableRelation && sourceFlags & 262144 /* TypeParameter */) {
                            let constraint = getConstraintOfTypeParameter(source2);
                            if (constraint && hasNonCircularBaseConstraint(source2)) {
                                while (constraint && someType(constraint, (c) => !!(c.flags & 262144 /* TypeParameter */))) {
                                    if (result2 = isRelatedTo(constraint, target2, 1 /* Source */, 
                                    /*reportErrors*/
                                    false)) {
                                        return result2;
                                    }
                                    constraint = getConstraintOfTypeParameter(constraint);
                                }
                            }
                            return 0 /* False */;
                        }
                    }
                    else if (targetFlags & 4194304 /* Index */) {
                        const targetType = target2.type;
                        if (sourceFlags & 4194304 /* Index */) {
                            if (result2 = isRelatedTo(targetType, source2.type, 3 /* Both */, 
                            /*reportErrors*/
                            false)) {
                                return result2;
                            }
                        }
                        if (isTupleType(targetType)) {
                            if (result2 = isRelatedTo(source2, getKnownKeysOfTupleType(targetType), 2 /* Target */, reportErrors2)) {
                                return result2;
                            }
                        }
                        else {
                            const constraint = getSimplifiedTypeOrConstraint(targetType);
                            if (constraint) {
                                if (isRelatedTo(source2, getIndexType(constraint, target2.stringsOnly), 2 /* Target */, reportErrors2) === -1 /* True */) {
                                    return -1 /* True */;
                                }
                            }
                            else if (isGenericMappedType(targetType)) {
                                const nameType = getNameTypeFromMappedType(targetType);
                                const constraintType = getConstraintTypeFromMappedType(targetType);
                                let targetKeys;
                                if (nameType && isMappedTypeWithKeyofConstraintDeclaration(targetType)) {
                                    const modifiersType = getApparentType(getModifiersTypeFromMappedType(targetType));
                                    const mappedKeys = [];
                                    forEachMappedTypePropertyKeyTypeAndIndexSignatureKeyType(modifiersType, 8576 /* StringOrNumberLiteralOrUnique */, 
                                    /*stringsOnly*/
                                    false, (t) => void mappedKeys.push(instantiateType(nameType, appendTypeMapping(targetType.mapper, getTypeParameterFromMappedType(targetType), t))));
                                    targetKeys = getUnionType([...mappedKeys, nameType]);
                                }
                                else {
                                    targetKeys = nameType || constraintType;
                                }
                                if (isRelatedTo(source2, targetKeys, 2 /* Target */, reportErrors2) === -1 /* True */) {
                                    return -1 /* True */;
                                }
                            }
                        }
                    }
                    else if (targetFlags & 8388608 /* IndexedAccess */) {
                        if (sourceFlags & 8388608 /* IndexedAccess */) {
                            if (result2 = isRelatedTo(source2.objectType, target2.objectType, 3 /* Both */, reportErrors2)) {
                                result2 &= isRelatedTo(source2.indexType, target2.indexType, 3 /* Both */, reportErrors2);
                            }
                            if (result2) {
                                return result2;
                            }
                            if (reportErrors2) {
                                originalErrorInfo = errorInfo;
                            }
                        }
                        if (relation === assignableRelation || relation === comparableRelation) {
                            const objectType = target2.objectType;
                            const indexType = target2.indexType;
                            const baseObjectType = getBaseConstraintOfType(objectType) || objectType;
                            const baseIndexType = getBaseConstraintOfType(indexType) || indexType;
                            if (!isGenericObjectType(baseObjectType) && !isGenericIndexType(baseIndexType)) {
                                const accessFlags = 4 /* Writing */ | (baseObjectType !== objectType ? 2 /* NoIndexSignatures */ : 0);
                                const constraint = getIndexedAccessTypeOrUndefined(baseObjectType, baseIndexType, accessFlags);
                                if (constraint) {
                                    if (reportErrors2 && originalErrorInfo) {
                                        resetErrorInfo(saveErrorInfo);
                                    }
                                    if (result2 = isRelatedTo(source2, constraint, 2 /* Target */, reportErrors2, 
                                    /* headMessage */
                                    void 0, intersectionState)) {
                                        return result2;
                                    }
                                    if (reportErrors2 && originalErrorInfo && errorInfo) {
                                        errorInfo = countMessageChainBreadth([originalErrorInfo]) <= countMessageChainBreadth([errorInfo]) ? originalErrorInfo : errorInfo;
                                    }
                                }
                            }
                        }
                        if (reportErrors2) {
                            originalErrorInfo = void 0;
                        }
                    }
                    else if (isGenericMappedType(target2) && relation !== identityRelation) {
                        const keysRemapped = !!target2.declaration.nameType;
                        const templateType = getTemplateTypeFromMappedType(target2);
                        const modifiers = getMappedTypeModifiers(target2);
                        if (!(modifiers & 8 /* ExcludeOptional */)) {
                            if (!keysRemapped && templateType.flags & 8388608 /* IndexedAccess */ && templateType.objectType === source2 && templateType.indexType === getTypeParameterFromMappedType(target2)) {
                                return -1 /* True */;
                            }
                            if (!isGenericMappedType(source2)) {
                                const targetKeys = keysRemapped ? getNameTypeFromMappedType(target2) : getConstraintTypeFromMappedType(target2);
                                const sourceKeys = getIndexType(source2, 
                                /*stringsOnly*/
                                void 0, 
                                /*noIndexSignatures*/
                                true);
                                const includeOptional = modifiers & 4 /* IncludeOptional */;
                                const filteredByApplicability = includeOptional ? intersectTypes(targetKeys, sourceKeys) : void 0;
                                if (includeOptional ? !(filteredByApplicability.flags & 131072 /* Never */) : isRelatedTo(targetKeys, sourceKeys, 3 /* Both */)) {
                                    const templateType2 = getTemplateTypeFromMappedType(target2);
                                    const typeParameter = getTypeParameterFromMappedType(target2);
                                    const nonNullComponent = extractTypesOfKind(templateType2, ~98304 /* Nullable */);
                                    if (!keysRemapped && nonNullComponent.flags & 8388608 /* IndexedAccess */ && nonNullComponent.indexType === typeParameter) {
                                        if (result2 = isRelatedTo(source2, nonNullComponent.objectType, 2 /* Target */, reportErrors2)) {
                                            return result2;
                                        }
                                    }
                                    else {
                                        const indexingType = keysRemapped ? filteredByApplicability || targetKeys : filteredByApplicability ? getIntersectionType([filteredByApplicability, typeParameter]) : typeParameter;
                                        const indexedAccessType = getIndexedAccessType(source2, indexingType);
                                        if (result2 = isRelatedTo(indexedAccessType, templateType2, 3 /* Both */, reportErrors2)) {
                                            return result2;
                                        }
                                    }
                                }
                                originalErrorInfo = errorInfo;
                                resetErrorInfo(saveErrorInfo);
                            }
                        }
                    }
                    else if (targetFlags & 16777216 /* Conditional */) {
                        if (isDeeplyNestedType(target2, targetStack, targetDepth, 10)) {
                            return 3 /* Maybe */;
                        }
                        const c = target2;
                        if (!c.root.inferTypeParameters && !isDistributionDependent(c.root)) {
                            const skipTrue = !isTypeAssignableTo(getPermissiveInstantiation(c.checkType), getPermissiveInstantiation(c.extendsType));
                            const skipFalse = !skipTrue && isTypeAssignableTo(getRestrictiveInstantiation(c.checkType), getRestrictiveInstantiation(c.extendsType));
                            if (result2 = skipTrue ? -1 /* True */ : isRelatedTo(source2, getTrueTypeFromConditionalType(c), 2 /* Target */, 
                            /*reportErrors*/
                            false, 
                            /*headMessage*/
                            void 0, intersectionState)) {
                                result2 &= skipFalse ? -1 /* True */ : isRelatedTo(source2, getFalseTypeFromConditionalType(c), 2 /* Target */, 
                                /*reportErrors*/
                                false, 
                                /*headMessage*/
                                void 0, intersectionState);
                                if (result2) {
                                    return result2;
                                }
                            }
                        }
                    }
                    else if (targetFlags & 134217728 /* TemplateLiteral */) {
                        if (sourceFlags & 134217728 /* TemplateLiteral */) {
                            if (relation === comparableRelation) {
                                return templateLiteralTypesDefinitelyUnrelated(source2, target2) ? 0 /* False */ : -1 /* True */;
                            }
                            instantiateType(source2, reportUnreliableMapper);
                        }
                        if (isTypeMatchedByTemplateLiteralType(source2, target2)) {
                            return -1 /* True */;
                        }
                    }
                    else if (target2.flags & 268435456 /* StringMapping */) {
                        if (!(source2.flags & 268435456 /* StringMapping */)) {
                            if (isMemberOfStringMapping(source2, target2)) {
                                return -1 /* True */;
                            }
                        }
                    }
                    if (sourceFlags & 8650752 /* TypeVariable */) {
                        if (!(sourceFlags & 8388608 /* IndexedAccess */ && targetFlags & 8388608 /* IndexedAccess */)) {
                            const constraint = getConstraintOfType(source2) || unknownType;
                            if (result2 = isRelatedTo(constraint, target2, 1 /* Source */, 
                            /*reportErrors*/
                            false, 
                            /*headMessage*/
                            void 0, intersectionState)) {
                                return result2;
                            }
                            else if (result2 = isRelatedTo(getTypeWithThisArgument(constraint, source2), target2, 1 /* Source */, reportErrors2 && constraint !== unknownType && !(targetFlags & sourceFlags & 262144 /* TypeParameter */), 
                            /*headMessage*/
                            void 0, intersectionState)) {
                                return result2;
                            }
                            if (isMappedTypeGenericIndexedAccess(source2)) {
                                const indexConstraint = getConstraintOfType(source2.indexType);
                                if (indexConstraint) {
                                    if (result2 = isRelatedTo(getIndexedAccessType(source2.objectType, indexConstraint), target2, 1 /* Source */, reportErrors2)) {
                                        return result2;
                                    }
                                }
                            }
                        }
                    }
                    else if (sourceFlags & 4194304 /* Index */) {
                        if (result2 = isRelatedTo(keyofConstraintType, target2, 1 /* Source */, reportErrors2)) {
                            return result2;
                        }
                    }
                    else if (sourceFlags & 134217728 /* TemplateLiteral */ && !(targetFlags & 524288 /* Object */)) {
                        if (!(targetFlags & 134217728 /* TemplateLiteral */)) {
                            const constraint = getBaseConstraintOfType(source2);
                            if (constraint && constraint !== source2 && (result2 = isRelatedTo(constraint, target2, 1 /* Source */, reportErrors2))) {
                                return result2;
                            }
                        }
                    }
                    else if (sourceFlags & 268435456 /* StringMapping */) {
                        if (targetFlags & 268435456 /* StringMapping */) {
                            if (source2.symbol !== target2.symbol) {
                                return 0 /* False */;
                            }
                            if (result2 = isRelatedTo(source2.type, target2.type, 3 /* Both */, reportErrors2)) {
                                return result2;
                            }
                        }
                        else {
                            const constraint = getBaseConstraintOfType(source2);
                            if (constraint && (result2 = isRelatedTo(constraint, target2, 1 /* Source */, reportErrors2))) {
                                return result2;
                            }
                        }
                    }
                    else if (sourceFlags & 16777216 /* Conditional */) {
                        if (isDeeplyNestedType(source2, sourceStack, sourceDepth, 10)) {
                            return 3 /* Maybe */;
                        }
                        if (targetFlags & 16777216 /* Conditional */) {
                            const sourceParams = source2.root.inferTypeParameters;
                            let sourceExtends = source2.extendsType;
                            let mapper;
                            if (sourceParams) {
                                const ctx = createInferenceContext(sourceParams, 
                                /*signature*/
                                void 0, 0 /* None */, isRelatedToWorker);
                                inferTypes(ctx.inferences, target2.extendsType, sourceExtends, 512 /* NoConstraints */ | 1024 /* AlwaysStrict */);
                                sourceExtends = instantiateType(sourceExtends, ctx.mapper);
                                mapper = ctx.mapper;
                            }
                            if (isTypeIdenticalTo(sourceExtends, target2.extendsType) && (isRelatedTo(source2.checkType, target2.checkType, 3 /* Both */) || isRelatedTo(target2.checkType, source2.checkType, 3 /* Both */))) {
                                if (result2 = isRelatedTo(instantiateType(getTrueTypeFromConditionalType(source2), mapper), getTrueTypeFromConditionalType(target2), 3 /* Both */, reportErrors2)) {
                                    result2 &= isRelatedTo(getFalseTypeFromConditionalType(source2), getFalseTypeFromConditionalType(target2), 3 /* Both */, reportErrors2);
                                }
                                if (result2) {
                                    return result2;
                                }
                            }
                        }
                        else {
                            const distributiveConstraint = hasNonCircularBaseConstraint(source2) ? getConstraintOfDistributiveConditionalType(source2) : void 0;
                            if (distributiveConstraint) {
                                if (result2 = isRelatedTo(distributiveConstraint, target2, 1 /* Source */, reportErrors2)) {
                                    return result2;
                                }
                            }
                        }
                        const defaultConstraint = getDefaultConstraintOfConditionalType(source2);
                        if (defaultConstraint) {
                            if (result2 = isRelatedTo(defaultConstraint, target2, 1 /* Source */, reportErrors2)) {
                                return result2;
                            }
                        }
                    }
                    else {
                        if (relation !== subtypeRelation && relation !== strictSubtypeRelation && isPartialMappedType(target2) && isEmptyObjectType(source2)) {
                            return -1 /* True */;
                        }
                        if (isGenericMappedType(target2)) {
                            if (isGenericMappedType(source2)) {
                                if (result2 = mappedTypeRelatedTo(source2, target2, reportErrors2)) {
                                    return result2;
                                }
                            }
                            return 0 /* False */;
                        }
                        const sourceIsPrimitive = !!(sourceFlags & 134348796 /* Primitive */);
                        if (relation !== identityRelation) {
                            source2 = getApparentType(source2);
                            sourceFlags = source2.flags;
                        }
                        else if (isGenericMappedType(source2)) {
                            return 0 /* False */;
                        }
                        if (getObjectFlags(source2) & 4 /* Reference */ && getObjectFlags(target2) & 4 /* Reference */ && source2.target === target2.target && !isTupleType(source2) && !(isMarkerType(source2) || isMarkerType(target2))) {
                            if (isEmptyArrayLiteralType(source2)) {
                                return -1 /* True */;
                            }
                            const variances = getVariances(source2.target);
                            if (variances === emptyArray) {
                                return 1 /* Unknown */;
                            }
                            const varianceResult = relateVariances(getTypeArguments(source2), getTypeArguments(target2), variances, intersectionState);
                            if (varianceResult !== void 0) {
                                return varianceResult;
                            }
                        }
                        else if (isReadonlyArrayType(target2) ? isArrayOrTupleType(source2) : isArrayType(target2) && isTupleType(source2) && !source2.target.readonly) {
                            if (relation !== identityRelation) {
                                return isRelatedTo(getIndexTypeOfType(source2, numberType) || anyType, getIndexTypeOfType(target2, numberType) || anyType, 3 /* Both */, reportErrors2);
                            }
                            else {
                                return 0 /* False */;
                            }
                        }
                        else if ((relation === subtypeRelation || relation === strictSubtypeRelation) && isEmptyObjectType(target2) && getObjectFlags(target2) & 8192 /* FreshLiteral */ && !isEmptyObjectType(source2)) {
                            return 0 /* False */;
                        }
                        if (sourceFlags & (524288 /* Object */ | 2097152 /* Intersection */) && targetFlags & 524288 /* Object */) {
                            const reportStructuralErrors = reportErrors2 && errorInfo === saveErrorInfo.errorInfo && !sourceIsPrimitive;
                            result2 = propertiesRelatedTo(source2, target2, reportStructuralErrors, 
                            /*excludedProperties*/
                            void 0, 
                            /*optionalsOnly*/
                            false, intersectionState);
                            if (result2) {
                                result2 &= signaturesRelatedTo(source2, target2, 0 /* Call */, reportStructuralErrors, intersectionState);
                                if (result2) {
                                    result2 &= signaturesRelatedTo(source2, target2, 1 /* Construct */, reportStructuralErrors, intersectionState);
                                    if (result2) {
                                        result2 &= indexSignaturesRelatedTo(source2, target2, sourceIsPrimitive, reportStructuralErrors, intersectionState);
                                    }
                                }
                            }
                            if (varianceCheckFailed && result2) {
                                errorInfo = originalErrorInfo || errorInfo || saveErrorInfo.errorInfo;
                            }
                            else if (result2) {
                                return result2;
                            }
                        }
                        if (sourceFlags & (524288 /* Object */ | 2097152 /* Intersection */) && targetFlags & 1048576 /* Union */) {
                            const objectOnlyTarget = extractTypesOfKind(target2, 524288 /* Object */ | 2097152 /* Intersection */ | 33554432 /* Substitution */);
                            if (objectOnlyTarget.flags & 1048576 /* Union */) {
                                const result3 = typeRelatedToDiscriminatedType(source2, objectOnlyTarget);
                                if (result3) {
                                    return result3;
                                }
                            }
                        }
                    }
                    return 0 /* False */;
                    function countMessageChainBreadth(info) {
                        if (!info)
                            return 0;
                        return reduceLeft(info, (value, chain) => value + 1 + countMessageChainBreadth(chain.next), 0);
                    }
                    function relateVariances(sourceTypeArguments, targetTypeArguments, variances, intersectionState2) {
                        if (result2 = typeArgumentsRelatedTo(sourceTypeArguments, targetTypeArguments, variances, reportErrors2, intersectionState2)) {
                            return result2;
                        }
                        if (some(variances, (v) => !!(v & 24 /* AllowsStructuralFallback */))) {
                            originalErrorInfo = void 0;
                            resetErrorInfo(saveErrorInfo);
                            return void 0;
                        }
                        const allowStructuralFallback = targetTypeArguments && hasCovariantVoidArgument(targetTypeArguments, variances);
                        varianceCheckFailed = !allowStructuralFallback;
                        if (variances !== emptyArray && !allowStructuralFallback) {
                            if (varianceCheckFailed && !(reportErrors2 && some(variances, (v) => (v & 7 /* VarianceMask */) === 0 /* Invariant */))) {
                                return 0 /* False */;
                            }
                            originalErrorInfo = errorInfo;
                            resetErrorInfo(saveErrorInfo);
                        }
                    }
                }
                function mappedTypeRelatedTo(source2, target2, reportErrors2) {
                    const modifiersRelated = relation === comparableRelation || (relation === identityRelation ? getMappedTypeModifiers(source2) === getMappedTypeModifiers(target2) : getCombinedMappedTypeOptionality(source2) <= getCombinedMappedTypeOptionality(target2));
                    if (modifiersRelated) {
                        let result2;
                        const targetConstraint = getConstraintTypeFromMappedType(target2);
                        const sourceConstraint = instantiateType(getConstraintTypeFromMappedType(source2), getCombinedMappedTypeOptionality(source2) < 0 ? reportUnmeasurableMapper : reportUnreliableMapper);
                        if (result2 = isRelatedTo(targetConstraint, sourceConstraint, 3 /* Both */, reportErrors2)) {
                            const mapper = createTypeMapper([getTypeParameterFromMappedType(source2)], [getTypeParameterFromMappedType(target2)]);
                            if (instantiateType(getNameTypeFromMappedType(source2), mapper) === instantiateType(getNameTypeFromMappedType(target2), mapper)) {
                                return result2 & isRelatedTo(instantiateType(getTemplateTypeFromMappedType(source2), mapper), getTemplateTypeFromMappedType(target2), 3 /* Both */, reportErrors2);
                            }
                        }
                    }
                    return 0 /* False */;
                }
                function typeRelatedToDiscriminatedType(source2, target2) {
                    var _a3;
                    const sourceProperties = getPropertiesOfType(source2);
                    const sourcePropertiesFiltered = findDiscriminantProperties(sourceProperties, target2);
                    if (!sourcePropertiesFiltered)
                        return 0 /* False */;
                    let numCombinations = 1;
                    for (const sourceProperty of sourcePropertiesFiltered) {
                        numCombinations *= countTypes(getNonMissingTypeOfSymbol(sourceProperty));
                        if (numCombinations > 25) {
                            (_a3 = tracing) == null ? void 0 : _a3.instant(tracing.Phase.CheckTypes, "typeRelatedToDiscriminatedType_DepthLimit", { sourceId: source2.id, targetId: target2.id, numCombinations });
                            return 0 /* False */;
                        }
                    }
                    const sourceDiscriminantTypes = new Array(sourcePropertiesFiltered.length);
                    const excludedProperties = /* @__PURE__ */ new Set();
                    for (let i = 0; i < sourcePropertiesFiltered.length; i++) {
                        const sourceProperty = sourcePropertiesFiltered[i];
                        const sourcePropertyType = getNonMissingTypeOfSymbol(sourceProperty);
                        sourceDiscriminantTypes[i] = sourcePropertyType.flags & 1048576 /* Union */ ? sourcePropertyType.types : [sourcePropertyType];
                        excludedProperties.add(sourceProperty.escapedName);
                    }
                    const discriminantCombinations = cartesianProduct(sourceDiscriminantTypes);
                    const matchingTypes = [];
                    for (const combination of discriminantCombinations) {
                        let hasMatch = false;
                        outer: for (const type of target2.types) {
                            for (let i = 0; i < sourcePropertiesFiltered.length; i++) {
                                const sourceProperty = sourcePropertiesFiltered[i];
                                const targetProperty = getPropertyOfType(type, sourceProperty.escapedName);
                                if (!targetProperty)
                                    continue outer;
                                if (sourceProperty === targetProperty)
                                    continue;
                                const related = propertyRelatedTo(source2, target2, sourceProperty, targetProperty, (_) => combination[i], 
                                /*reportErrors*/
                                false, 0 /* None */, 
                                /*skipOptional*/
                                strictNullChecks || relation === comparableRelation);
                                if (!related) {
                                    continue outer;
                                }
                            }
                            pushIfUnique(matchingTypes, type, equateValues);
                            hasMatch = true;
                        }
                        if (!hasMatch) {
                            return 0 /* False */;
                        }
                    }
                    let result2 = -1 /* True */;
                    for (const type of matchingTypes) {
                        result2 &= propertiesRelatedTo(source2, type, 
                        /*reportErrors*/
                        false, excludedProperties, 
                        /*optionalsOnly*/
                        false, 0 /* None */);
                        if (result2) {
                            result2 &= signaturesRelatedTo(source2, type, 0 /* Call */, 
                            /*reportStructuralErrors*/
                            false, 0 /* None */);
                            if (result2) {
                                result2 &= signaturesRelatedTo(source2, type, 1 /* Construct */, 
                                /*reportStructuralErrors*/
                                false, 0 /* None */);
                                if (result2 && !(isTupleType(source2) && isTupleType(type))) {
                                    result2 &= indexSignaturesRelatedTo(source2, type, 
                                    /*sourceIsPrimitive*/
                                    false, 
                                    /*reportStructuralErrors*/
                                    false, 0 /* None */);
                                }
                            }
                        }
                        if (!result2) {
                            return result2;
                        }
                    }
                    return result2;
                }
                function excludeProperties(properties, excludedProperties) {
                    if (!excludedProperties || properties.length === 0)
                        return properties;
                    let result2;
                    for (let i = 0; i < properties.length; i++) {
                        if (!excludedProperties.has(properties[i].escapedName)) {
                            if (result2) {
                                result2.push(properties[i]);
                            }
                        }
                        else if (!result2) {
                            result2 = properties.slice(0, i);
                        }
                    }
                    return result2 || properties;
                }
                function isPropertySymbolTypeRelated(sourceProp, targetProp, getTypeOfSourceProperty, reportErrors2, intersectionState) {
                    const targetIsOptional = strictNullChecks && !!(getCheckFlags(targetProp) & 48 /* Partial */);
                    const effectiveTarget = addOptionality(getNonMissingTypeOfSymbol(targetProp), 
                    /*isProperty*/
                    false, targetIsOptional);
                    const effectiveSource = getTypeOfSourceProperty(sourceProp);
                    return isRelatedTo(effectiveSource, effectiveTarget, 3 /* Both */, reportErrors2, 
                    /*headMessage*/
                    void 0, intersectionState);
                }
                function propertyRelatedTo(source2, target2, sourceProp, targetProp, getTypeOfSourceProperty, reportErrors2, intersectionState, skipOptional) {
                    const sourcePropFlags = getDeclarationModifierFlagsFromSymbol(sourceProp);
                    const targetPropFlags = getDeclarationModifierFlagsFromSymbol(targetProp);
                    if (sourcePropFlags & 8 /* Private */ || targetPropFlags & 8 /* Private */) {
                        if (sourceProp.valueDeclaration !== targetProp.valueDeclaration) {
                            if (reportErrors2) {
                                if (sourcePropFlags & 8 /* Private */ && targetPropFlags & 8 /* Private */) {
                                    reportError(Diagnostics.Types_have_separate_declarations_of_a_private_property_0, symbolToString(targetProp));
                                }
                                else {
                                    reportError(Diagnostics.Property_0_is_private_in_type_1_but_not_in_type_2, symbolToString(targetProp), typeToString(sourcePropFlags & 8 /* Private */ ? source2 : target2), typeToString(sourcePropFlags & 8 /* Private */ ? target2 : source2));
                                }
                            }
                            return 0 /* False */;
                        }
                    }
                    else if (targetPropFlags & 16 /* Protected */) {
                        if (!isValidOverrideOf(sourceProp, targetProp)) {
                            if (reportErrors2) {
                                reportError(Diagnostics.Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2, symbolToString(targetProp), typeToString(getDeclaringClass(sourceProp) || source2), typeToString(getDeclaringClass(targetProp) || target2));
                            }
                            return 0 /* False */;
                        }
                    }
                    else if (sourcePropFlags & 16 /* Protected */) {
                        if (reportErrors2) {
                            reportError(Diagnostics.Property_0_is_protected_in_type_1_but_public_in_type_2, symbolToString(targetProp), typeToString(source2), typeToString(target2));
                        }
                        return 0 /* False */;
                    }
                    if (relation === strictSubtypeRelation && isReadonlySymbol(sourceProp) && !isReadonlySymbol(targetProp)) {
                        return 0 /* False */;
                    }
                    const related = isPropertySymbolTypeRelated(sourceProp, targetProp, getTypeOfSourceProperty, reportErrors2, intersectionState);
                    if (!related) {
                        if (reportErrors2) {
                            reportIncompatibleError(Diagnostics.Types_of_property_0_are_incompatible, symbolToString(targetProp));
                        }
                        return 0 /* False */;
                    }
                    if (!skipOptional && sourceProp.flags & 16777216 /* Optional */ && targetProp.flags & 106500 /* ClassMember */ && !(targetProp.flags & 16777216 /* Optional */)) {
                        if (reportErrors2) {
                            reportError(Diagnostics.Property_0_is_optional_in_type_1_but_required_in_type_2, symbolToString(targetProp), typeToString(source2), typeToString(target2));
                        }
                        return 0 /* False */;
                    }
                    return related;
                }
                function reportUnmatchedProperty(source2, target2, unmatchedProperty, requireOptionalProperties) {
                    let shouldSkipElaboration = false;
                    if (unmatchedProperty.valueDeclaration && isNamedDeclaration(unmatchedProperty.valueDeclaration) && isPrivateIdentifier(unmatchedProperty.valueDeclaration.name) && source2.symbol && source2.symbol.flags & 32 /* Class */) {
                        const privateIdentifierDescription = unmatchedProperty.valueDeclaration.name.escapedText;
                        const symbolTableKey = getSymbolNameForPrivateIdentifier(source2.symbol, privateIdentifierDescription);
                        if (symbolTableKey && getPropertyOfType(source2, symbolTableKey)) {
                            const sourceName = factory.getDeclarationName(source2.symbol.valueDeclaration);
                            const targetName = factory.getDeclarationName(target2.symbol.valueDeclaration);
                            reportError(Diagnostics.Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2, diagnosticName(privateIdentifierDescription), diagnosticName(sourceName.escapedText === "" ? anon : sourceName), diagnosticName(targetName.escapedText === "" ? anon : targetName));
                            return;
                        }
                    }
                    const props = arrayFrom(getUnmatchedProperties(source2, target2, requireOptionalProperties, 
                    /*matchDiscriminantProperties*/
                    false));
                    if (!headMessage || headMessage.code !== Diagnostics.Class_0_incorrectly_implements_interface_1.code && headMessage.code !== Diagnostics.Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass.code) {
                        shouldSkipElaboration = true;
                    }
                    if (props.length === 1) {
                        const propName = symbolToString(unmatchedProperty, 
                        /*enclosingDeclaration*/
                        void 0, 0 /* None */, 4 /* AllowAnyNodeKind */ | 16 /* WriteComputedProps */);
                        reportError(Diagnostics.Property_0_is_missing_in_type_1_but_required_in_type_2, propName, ...getTypeNamesForErrorDisplay(source2, target2));
                        if (length(unmatchedProperty.declarations)) {
                            associateRelatedInfo(createDiagnosticForNode(unmatchedProperty.declarations[0], Diagnostics._0_is_declared_here, propName));
                        }
                        if (shouldSkipElaboration && errorInfo) {
                            overrideNextErrorInfo++;
                        }
                    }
                    else if (tryElaborateArrayLikeErrors(source2, target2, 
                    /*reportErrors*/
                    false)) {
                        if (props.length > 5) {
                            reportError(Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more, typeToString(source2), typeToString(target2), map(props.slice(0, 4), (p) => symbolToString(p)).join(", "), props.length - 4);
                        }
                        else {
                            reportError(Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2, typeToString(source2), typeToString(target2), map(props, (p) => symbolToString(p)).join(", "));
                        }
                        if (shouldSkipElaboration && errorInfo) {
                            overrideNextErrorInfo++;
                        }
                    }
                }
                function propertiesRelatedTo(source2, target2, reportErrors2, excludedProperties, optionalsOnly, intersectionState) {
                    if (relation === identityRelation) {
                        return propertiesIdenticalTo(source2, target2, excludedProperties);
                    }
                    let result2 = -1 /* True */;
                    if (isTupleType(target2)) {
                        if (isArrayOrTupleType(source2)) {
                            if (!target2.target.readonly && (isReadonlyArrayType(source2) || isTupleType(source2) && source2.target.readonly)) {
                                return 0 /* False */;
                            }
                            const sourceArity = getTypeReferenceArity(source2);
                            const targetArity = getTypeReferenceArity(target2);
                            const sourceRestFlag = isTupleType(source2) ? source2.target.combinedFlags & 4 /* Rest */ : 4 /* Rest */;
                            const targetRestFlag = target2.target.combinedFlags & 4 /* Rest */;
                            const sourceMinLength = isTupleType(source2) ? source2.target.minLength : 0;
                            const targetMinLength = target2.target.minLength;
                            if (!sourceRestFlag && sourceArity < targetMinLength) {
                                if (reportErrors2) {
                                    reportError(Diagnostics.Source_has_0_element_s_but_target_requires_1, sourceArity, targetMinLength);
                                }
                                return 0 /* False */;
                            }
                            if (!targetRestFlag && targetArity < sourceMinLength) {
                                if (reportErrors2) {
                                    reportError(Diagnostics.Source_has_0_element_s_but_target_allows_only_1, sourceMinLength, targetArity);
                                }
                                return 0 /* False */;
                            }
                            if (!targetRestFlag && (sourceRestFlag || targetArity < sourceArity)) {
                                if (reportErrors2) {
                                    if (sourceMinLength < targetMinLength) {
                                        reportError(Diagnostics.Target_requires_0_element_s_but_source_may_have_fewer, targetMinLength);
                                    }
                                    else {
                                        reportError(Diagnostics.Target_allows_only_0_element_s_but_source_may_have_more, targetArity);
                                    }
                                }
                                return 0 /* False */;
                            }
                            const sourceTypeArguments = getTypeArguments(source2);
                            const targetTypeArguments = getTypeArguments(target2);
                            const targetStartCount = getStartElementCount(target2.target, 11 /* NonRest */);
                            const targetEndCount = getEndElementCount(target2.target, 11 /* NonRest */);
                            const targetHasRestElement = target2.target.hasRestElement;
                            let canExcludeDiscriminants = !!excludedProperties;
                            for (let sourcePosition = 0; sourcePosition < sourceArity; sourcePosition++) {
                                const sourceFlags = isTupleType(source2) ? source2.target.elementFlags[sourcePosition] : 4 /* Rest */;
                                const sourcePositionFromEnd = sourceArity - 1 - sourcePosition;
                                const targetPosition = targetHasRestElement && sourcePosition >= targetStartCount ? targetArity - 1 - Math.min(sourcePositionFromEnd, targetEndCount) : sourcePosition;
                                const targetFlags = target2.target.elementFlags[targetPosition];
                                if (targetFlags & 8 /* Variadic */ && !(sourceFlags & 8 /* Variadic */)) {
                                    if (reportErrors2) {
                                        reportError(Diagnostics.Source_provides_no_match_for_variadic_element_at_position_0_in_target, targetPosition);
                                    }
                                    return 0 /* False */;
                                }
                                if (sourceFlags & 8 /* Variadic */ && !(targetFlags & 12 /* Variable */)) {
                                    if (reportErrors2) {
                                        reportError(Diagnostics.Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target, sourcePosition, targetPosition);
                                    }
                                    return 0 /* False */;
                                }
                                if (targetFlags & 1 /* Required */ && !(sourceFlags & 1 /* Required */)) {
                                    if (reportErrors2) {
                                        reportError(Diagnostics.Source_provides_no_match_for_required_element_at_position_0_in_target, targetPosition);
                                    }
                                    return 0 /* False */;
                                }
                                if (canExcludeDiscriminants) {
                                    if (sourceFlags & 12 /* Variable */ || targetFlags & 12 /* Variable */) {
                                        canExcludeDiscriminants = false;
                                    }
                                    if (canExcludeDiscriminants && (excludedProperties == null ? void 0 : excludedProperties.has("" + sourcePosition))) {
                                        continue;
                                    }
                                }
                                const sourceType = removeMissingType(sourceTypeArguments[sourcePosition], !!(sourceFlags & targetFlags & 2 /* Optional */));
                                const targetType = targetTypeArguments[targetPosition];
                                const targetCheckType = sourceFlags & 8 /* Variadic */ && targetFlags & 4 /* Rest */ ? createArrayType(targetType) : removeMissingType(targetType, !!(targetFlags & 2 /* Optional */));
                                const related = isRelatedTo(sourceType, targetCheckType, 3 /* Both */, reportErrors2, 
                                /*headMessage*/
                                void 0, intersectionState);
                                if (!related) {
                                    if (reportErrors2 && (targetArity > 1 || sourceArity > 1)) {
                                        if (targetHasRestElement && sourcePosition >= targetStartCount && sourcePositionFromEnd >= targetEndCount && targetStartCount !== sourceArity - targetEndCount - 1) {
                                            reportIncompatibleError(Diagnostics.Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target, targetStartCount, sourceArity - targetEndCount - 1, targetPosition);
                                        }
                                        else {
                                            reportIncompatibleError(Diagnostics.Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target, sourcePosition, targetPosition);
                                        }
                                    }
                                    return 0 /* False */;
                                }
                                result2 &= related;
                            }
                            return result2;
                        }
                        if (target2.target.combinedFlags & 12 /* Variable */) {
                            return 0 /* False */;
                        }
                    }
                    const requireOptionalProperties = (relation === subtypeRelation || relation === strictSubtypeRelation) && !isObjectLiteralType2(source2) && !isEmptyArrayLiteralType(source2) && !isTupleType(source2);
                    const unmatchedProperty = getUnmatchedProperty(source2, target2, requireOptionalProperties, 
                    /*matchDiscriminantProperties*/
                    false);
                    if (unmatchedProperty) {
                        if (reportErrors2 && shouldReportUnmatchedPropertyError(source2, target2)) {
                            reportUnmatchedProperty(source2, target2, unmatchedProperty, requireOptionalProperties);
                        }
                        return 0 /* False */;
                    }
                    if (isObjectLiteralType2(target2)) {
                        for (const sourceProp of excludeProperties(getPropertiesOfType(source2), excludedProperties)) {
                            if (!getPropertyOfObjectType(target2, sourceProp.escapedName)) {
                                const sourceType = getTypeOfSymbol(sourceProp);
                                if (!(sourceType.flags & 32768 /* Undefined */)) {
                                    if (reportErrors2) {
                                        reportError(Diagnostics.Property_0_does_not_exist_on_type_1, symbolToString(sourceProp), typeToString(target2));
                                    }
                                    return 0 /* False */;
                                }
                            }
                        }
                    }
                    const properties = getPropertiesOfType(target2);
                    const numericNamesOnly = isTupleType(source2) && isTupleType(target2);
                    for (const targetProp of excludeProperties(properties, excludedProperties)) {
                        const name = targetProp.escapedName;
                        if (!(targetProp.flags & 4194304 /* Prototype */) && (!numericNamesOnly || isNumericLiteralName(name) || name === "length") && (!optionalsOnly || targetProp.flags & 16777216 /* Optional */)) {
                            const sourceProp = getPropertyOfType(source2, name);
                            if (sourceProp && sourceProp !== targetProp) {
                                const related = propertyRelatedTo(source2, target2, sourceProp, targetProp, getNonMissingTypeOfSymbol, reportErrors2, intersectionState, relation === comparableRelation);
                                if (!related) {
                                    return 0 /* False */;
                                }
                                result2 &= related;
                            }
                        }
                    }
                    return result2;
                }
                function propertiesIdenticalTo(source2, target2, excludedProperties) {
                    if (!(source2.flags & 524288 /* Object */ && target2.flags & 524288 /* Object */)) {
                        return 0 /* False */;
                    }
                    const sourceProperties = excludeProperties(getPropertiesOfObjectType(source2), excludedProperties);
                    const targetProperties = excludeProperties(getPropertiesOfObjectType(target2), excludedProperties);
                    if (sourceProperties.length !== targetProperties.length) {
                        return 0 /* False */;
                    }
                    let result2 = -1 /* True */;
                    for (const sourceProp of sourceProperties) {
                        const targetProp = getPropertyOfObjectType(target2, sourceProp.escapedName);
                        if (!targetProp) {
                            return 0 /* False */;
                        }
                        const related = compareProperties2(sourceProp, targetProp, isRelatedTo);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function signaturesRelatedTo(source2, target2, kind, reportErrors2, intersectionState) {
                    var _a3, _b;
                    if (relation === identityRelation) {
                        return signaturesIdenticalTo(source2, target2, kind);
                    }
                    if (target2 === anyFunctionType || source2 === anyFunctionType) {
                        return -1 /* True */;
                    }
                    const sourceIsJSConstructor = source2.symbol && isJSConstructor(source2.symbol.valueDeclaration);
                    const targetIsJSConstructor = target2.symbol && isJSConstructor(target2.symbol.valueDeclaration);
                    const sourceSignatures = getSignaturesOfType(source2, sourceIsJSConstructor && kind === 1 /* Construct */ ? 0 /* Call */ : kind);
                    const targetSignatures = getSignaturesOfType(target2, targetIsJSConstructor && kind === 1 /* Construct */ ? 0 /* Call */ : kind);
                    if (kind === 1 /* Construct */ && sourceSignatures.length && targetSignatures.length) {
                        const sourceIsAbstract = !!(sourceSignatures[0].flags & 4 /* Abstract */);
                        const targetIsAbstract = !!(targetSignatures[0].flags & 4 /* Abstract */);
                        if (sourceIsAbstract && !targetIsAbstract) {
                            if (reportErrors2) {
                                reportError(Diagnostics.Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type);
                            }
                            return 0 /* False */;
                        }
                        if (!constructorVisibilitiesAreCompatible(sourceSignatures[0], targetSignatures[0], reportErrors2)) {
                            return 0 /* False */;
                        }
                    }
                    let result2 = -1 /* True */;
                    const incompatibleReporter = kind === 1 /* Construct */ ? reportIncompatibleConstructSignatureReturn : reportIncompatibleCallSignatureReturn;
                    const sourceObjectFlags = getObjectFlags(source2);
                    const targetObjectFlags = getObjectFlags(target2);
                    if (sourceObjectFlags & 64 /* Instantiated */ && targetObjectFlags & 64 /* Instantiated */ && source2.symbol === target2.symbol || sourceObjectFlags & 4 /* Reference */ && targetObjectFlags & 4 /* Reference */ && source2.target === target2.target) {
                        for (let i = 0; i < targetSignatures.length; i++) {
                            const related = signatureRelatedTo(sourceSignatures[i], targetSignatures[i], 
                            /*erase*/
                            true, reportErrors2, intersectionState, incompatibleReporter(sourceSignatures[i], targetSignatures[i]));
                            if (!related) {
                                return 0 /* False */;
                            }
                            result2 &= related;
                        }
                    }
                    else if (sourceSignatures.length === 1 && targetSignatures.length === 1) {
                        const eraseGenerics = relation === comparableRelation || !!compilerOptions.noStrictGenericChecks;
                        const sourceSignature = first(sourceSignatures);
                        const targetSignature = first(targetSignatures);
                        result2 = signatureRelatedTo(sourceSignature, targetSignature, eraseGenerics, reportErrors2, intersectionState, incompatibleReporter(sourceSignature, targetSignature));
                        if (!result2 && reportErrors2 && kind === 1 /* Construct */ && sourceObjectFlags & targetObjectFlags && (((_a3 = targetSignature.declaration) == null ? void 0 : _a3.kind) === 173 /* Constructor */ || ((_b = sourceSignature.declaration) == null ? void 0 : _b.kind) === 173 /* Constructor */)) {
                            const constructSignatureToString = (signature) => signatureToString(signature, 
                            /*enclosingDeclaration*/
                            void 0, 262144 /* WriteArrowStyleSignature */, kind);
                            reportError(Diagnostics.Type_0_is_not_assignable_to_type_1, constructSignatureToString(sourceSignature), constructSignatureToString(targetSignature));
                            reportError(Diagnostics.Types_of_construct_signatures_are_incompatible);
                            return result2;
                        }
                    }
                    else {
                        outer: for (const t of targetSignatures) {
                            const saveErrorInfo = captureErrorCalculationState();
                            let shouldElaborateErrors = reportErrors2;
                            for (const s of sourceSignatures) {
                                const related = signatureRelatedTo(s, t, 
                                /*erase*/
                                true, shouldElaborateErrors, intersectionState, incompatibleReporter(s, t));
                                if (related) {
                                    result2 &= related;
                                    resetErrorInfo(saveErrorInfo);
                                    continue outer;
                                }
                                shouldElaborateErrors = false;
                            }
                            if (shouldElaborateErrors) {
                                reportError(Diagnostics.Type_0_provides_no_match_for_the_signature_1, typeToString(source2), signatureToString(t, 
                                /*enclosingDeclaration*/
                                void 0, 
                                /*flags*/
                                void 0, kind));
                            }
                            return 0 /* False */;
                        }
                    }
                    return result2;
                }
                function shouldReportUnmatchedPropertyError(source2, target2) {
                    const typeCallSignatures = getSignaturesOfStructuredType(source2, 0 /* Call */);
                    const typeConstructSignatures = getSignaturesOfStructuredType(source2, 1 /* Construct */);
                    const typeProperties = getPropertiesOfObjectType(source2);
                    if ((typeCallSignatures.length || typeConstructSignatures.length) && !typeProperties.length) {
                        if (getSignaturesOfType(target2, 0 /* Call */).length && typeCallSignatures.length || getSignaturesOfType(target2, 1 /* Construct */).length && typeConstructSignatures.length) {
                            return true;
                        }
                        return false;
                    }
                    return true;
                }
                function reportIncompatibleCallSignatureReturn(siga, sigb) {
                    if (siga.parameters.length === 0 && sigb.parameters.length === 0) {
                        return (source2, target2) => reportIncompatibleError(Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1, typeToString(source2), typeToString(target2));
                    }
                    return (source2, target2) => reportIncompatibleError(Diagnostics.Call_signature_return_types_0_and_1_are_incompatible, typeToString(source2), typeToString(target2));
                }
                function reportIncompatibleConstructSignatureReturn(siga, sigb) {
                    if (siga.parameters.length === 0 && sigb.parameters.length === 0) {
                        return (source2, target2) => reportIncompatibleError(Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1, typeToString(source2), typeToString(target2));
                    }
                    return (source2, target2) => reportIncompatibleError(Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible, typeToString(source2), typeToString(target2));
                }
                function signatureRelatedTo(source2, target2, erase, reportErrors2, intersectionState, incompatibleReporter) {
                    const checkMode = relation === subtypeRelation ? 16 /* StrictTopSignature */ : relation === strictSubtypeRelation ? 16 /* StrictTopSignature */ | 8 /* StrictArity */ : 0 /* None */;
                    return compareSignaturesRelated(erase ? getErasedSignature(source2) : source2, erase ? getErasedSignature(target2) : target2, checkMode, reportErrors2, reportError, incompatibleReporter, isRelatedToWorker2, reportUnreliableMapper);
                    function isRelatedToWorker2(source3, target3, reportErrors3) {
                        return isRelatedTo(source3, target3, 3 /* Both */, reportErrors3, 
                        /*headMessage*/
                        void 0, intersectionState);
                    }
                }
                function signaturesIdenticalTo(source2, target2, kind) {
                    const sourceSignatures = getSignaturesOfType(source2, kind);
                    const targetSignatures = getSignaturesOfType(target2, kind);
                    if (sourceSignatures.length !== targetSignatures.length) {
                        return 0 /* False */;
                    }
                    let result2 = -1 /* True */;
                    for (let i = 0; i < sourceSignatures.length; i++) {
                        const related = compareSignaturesIdentical(sourceSignatures[i], targetSignatures[i], 
                        /*partialMatch*/
                        false, 
                        /*ignoreThisTypes*/
                        false, 
                        /*ignoreReturnTypes*/
                        false, isRelatedTo);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function membersRelatedToIndexInfo(source2, targetInfo, reportErrors2, intersectionState) {
                    let result2 = -1 /* True */;
                    const keyType = targetInfo.keyType;
                    const props = source2.flags & 2097152 /* Intersection */ ? getPropertiesOfUnionOrIntersectionType(source2) : getPropertiesOfObjectType(source2);
                    for (const prop of props) {
                        if (isIgnoredJsxProperty(source2, prop)) {
                            continue;
                        }
                        if (isApplicableIndexType(getLiteralTypeFromProperty(prop, 8576 /* StringOrNumberLiteralOrUnique */), keyType)) {
                            const propType = getNonMissingTypeOfSymbol(prop);
                            const type = exactOptionalPropertyTypes || propType.flags & 32768 /* Undefined */ || keyType === numberType || !(prop.flags & 16777216 /* Optional */) ? propType : getTypeWithFacts(propType, 524288 /* NEUndefined */);
                            const related = isRelatedTo(type, targetInfo.type, 3 /* Both */, reportErrors2, 
                            /*headMessage*/
                            void 0, intersectionState);
                            if (!related) {
                                if (reportErrors2) {
                                    reportError(Diagnostics.Property_0_is_incompatible_with_index_signature, symbolToString(prop));
                                }
                                return 0 /* False */;
                            }
                            result2 &= related;
                        }
                    }
                    for (const info of getIndexInfosOfType(source2)) {
                        if (isApplicableIndexType(info.keyType, keyType)) {
                            const related = indexInfoRelatedTo(info, targetInfo, reportErrors2, intersectionState);
                            if (!related) {
                                return 0 /* False */;
                            }
                            result2 &= related;
                        }
                    }
                    return result2;
                }
                function indexInfoRelatedTo(sourceInfo, targetInfo, reportErrors2, intersectionState) {
                    const related = isRelatedTo(sourceInfo.type, targetInfo.type, 3 /* Both */, reportErrors2, 
                    /*headMessage*/
                    void 0, intersectionState);
                    if (!related && reportErrors2) {
                        if (sourceInfo.keyType === targetInfo.keyType) {
                            reportError(Diagnostics._0_index_signatures_are_incompatible, typeToString(sourceInfo.keyType));
                        }
                        else {
                            reportError(Diagnostics._0_and_1_index_signatures_are_incompatible, typeToString(sourceInfo.keyType), typeToString(targetInfo.keyType));
                        }
                    }
                    return related;
                }
                function indexSignaturesRelatedTo(source2, target2, sourceIsPrimitive, reportErrors2, intersectionState) {
                    if (relation === identityRelation) {
                        return indexSignaturesIdenticalTo(source2, target2);
                    }
                    const indexInfos = getIndexInfosOfType(target2);
                    const targetHasStringIndex = some(indexInfos, (info) => info.keyType === stringType);
                    let result2 = -1 /* True */;
                    for (const targetInfo of indexInfos) {
                        const related = relation !== strictSubtypeRelation && !sourceIsPrimitive && targetHasStringIndex && targetInfo.type.flags & 1 /* Any */ ? -1 /* True */ : isGenericMappedType(source2) && targetHasStringIndex ? isRelatedTo(getTemplateTypeFromMappedType(source2), targetInfo.type, 3 /* Both */, reportErrors2) : typeRelatedToIndexInfo(source2, targetInfo, reportErrors2, intersectionState);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function typeRelatedToIndexInfo(source2, targetInfo, reportErrors2, intersectionState) {
                    const sourceInfo = getApplicableIndexInfo(source2, targetInfo.keyType);
                    if (sourceInfo) {
                        return indexInfoRelatedTo(sourceInfo, targetInfo, reportErrors2, intersectionState);
                    }
                    if (!(intersectionState & 1 /* Source */) && (relation !== strictSubtypeRelation || getObjectFlags(source2) & 8192 /* FreshLiteral */) && isObjectTypeWithInferableIndex(source2)) {
                        return membersRelatedToIndexInfo(source2, targetInfo, reportErrors2, intersectionState);
                    }
                    if (reportErrors2) {
                        reportError(Diagnostics.Index_signature_for_type_0_is_missing_in_type_1, typeToString(targetInfo.keyType), typeToString(source2));
                    }
                    return 0 /* False */;
                }
                function indexSignaturesIdenticalTo(source2, target2) {
                    const sourceInfos = getIndexInfosOfType(source2);
                    const targetInfos = getIndexInfosOfType(target2);
                    if (sourceInfos.length !== targetInfos.length) {
                        return 0 /* False */;
                    }
                    for (const targetInfo of targetInfos) {
                        const sourceInfo = getIndexInfoOfType(source2, targetInfo.keyType);
                        if (!(sourceInfo && isRelatedTo(sourceInfo.type, targetInfo.type, 3 /* Both */) && sourceInfo.isReadonly === targetInfo.isReadonly)) {
                            return 0 /* False */;
                        }
                    }
                    return -1 /* True */;
                }
                function constructorVisibilitiesAreCompatible(sourceSignature, targetSignature, reportErrors2) {
                    if (!sourceSignature.declaration || !targetSignature.declaration) {
                        return true;
                    }
                    const sourceAccessibility = getSelectedEffectiveModifierFlags(sourceSignature.declaration, 24 /* NonPublicAccessibilityModifier */);
                    const targetAccessibility = getSelectedEffectiveModifierFlags(targetSignature.declaration, 24 /* NonPublicAccessibilityModifier */);
                    if (targetAccessibility === 8 /* Private */) {
                        return true;
                    }
                    if (targetAccessibility === 16 /* Protected */ && sourceAccessibility !== 8 /* Private */) {
                        return true;
                    }
                    if (targetAccessibility !== 16 /* Protected */ && !sourceAccessibility) {
                        return true;
                    }
                    if (reportErrors2) {
                        reportError(Diagnostics.Cannot_assign_a_0_constructor_type_to_a_1_constructor_type, visibilityToString(sourceAccessibility), visibilityToString(targetAccessibility));
                    }
                    return false;
                }
            }
            function typeCouldHaveTopLevelSingletonTypes(type) {
                if (type.flags & 16 /* Boolean */) {
                    return false;
                }
                if (type.flags & 3145728 /* UnionOrIntersection */) {
                    return !!forEach(type.types, typeCouldHaveTopLevelSingletonTypes);
                }
                if (type.flags & 465829888 /* Instantiable */) {
                    const constraint = getConstraintOfType(type);
                    if (constraint && constraint !== type) {
                        return typeCouldHaveTopLevelSingletonTypes(constraint);
                    }
                }
                return isUnitType(type) || !!(type.flags & 134217728 /* TemplateLiteral */) || !!(type.flags & 268435456 /* StringMapping */);
            }
            function getExactOptionalUnassignableProperties(source, target) {
                if (isTupleType(source) && isTupleType(target))
                    return emptyArray;
                return getPropertiesOfType(target).filter((targetProp) => isExactOptionalPropertyMismatch(getTypeOfPropertyOfType(source, targetProp.escapedName), getTypeOfSymbol(targetProp)));
            }
            function isExactOptionalPropertyMismatch(source, target) {
                return !!source && !!target && maybeTypeOfKind(source, 32768 /* Undefined */) && !!containsMissingType(target);
            }
            function getExactOptionalProperties(type) {
                return getPropertiesOfType(type).filter((targetProp) => containsMissingType(getTypeOfSymbol(targetProp)));
            }
            function getBestMatchingType(source, target, isRelatedTo = compareTypesAssignable) {
                return findMatchingDiscriminantType(source, target, isRelatedTo, 
                /*skipPartial*/
                true) || findMatchingTypeReferenceOrTypeAliasReference(source, target) || findBestTypeForObjectLiteral(source, target) || findBestTypeForInvokable(source, target) || findMostOverlappyType(source, target);
            }
            function discriminateTypeByDiscriminableItems(target, discriminators, related, defaultValue, skipPartial) {
                const discriminable = target.types.map((_) => void 0);
                for (const [getDiscriminatingType, propertyName] of discriminators) {
                    const targetProp = getUnionOrIntersectionProperty(target, propertyName);
                    if (skipPartial && targetProp && getCheckFlags(targetProp) & 16 /* ReadPartial */) {
                        continue;
                    }
                    let i = 0;
                    for (const type of target.types) {
                        const targetType = getTypeOfPropertyOfType(type, propertyName);
                        if (targetType && related(getDiscriminatingType(), targetType)) {
                            discriminable[i] = discriminable[i] === void 0 ? true : discriminable[i];
                        }
                        else {
                            discriminable[i] = false;
                        }
                        i++;
                    }
                }
                const match = discriminable.indexOf(
                /*searchElement*/
                true);
                if (match === -1) {
                    return defaultValue;
                }
                let nextMatch = discriminable.indexOf(
                /*searchElement*/
                true, match + 1);
                while (nextMatch !== -1) {
                    if (!isTypeIdenticalTo(target.types[match], target.types[nextMatch])) {
                        return defaultValue;
                    }
                    nextMatch = discriminable.indexOf(
                    /*searchElement*/
                    true, nextMatch + 1);
                }
                return target.types[match];
            }
            function isWeakType(type) {
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    return resolved.callSignatures.length === 0 && resolved.constructSignatures.length === 0 && resolved.indexInfos.length === 0 && resolved.properties.length > 0 && every(resolved.properties, (p) => !!(p.flags & 16777216 /* Optional */));
                }
                if (type.flags & 2097152 /* Intersection */) {
                    return every(type.types, isWeakType);
                }
                return false;
            }
            function hasCommonProperties(source, target, isComparingJsxAttributes) {
                for (const prop of getPropertiesOfType(source)) {
                    if (isKnownProperty(target, prop.escapedName, isComparingJsxAttributes)) {
                        return true;
                    }
                }
                return false;
            }
            function getVariances(type) {
                return type === globalArrayType || type === globalReadonlyArrayType || type.objectFlags & 8 /* Tuple */ ? arrayVariances : getVariancesWorker(type.symbol, type.typeParameters);
            }
            function getAliasVariances(symbol) {
                return getVariancesWorker(symbol, getSymbolLinks(symbol).typeParameters);
            }
            function getVariancesWorker(symbol, typeParameters = emptyArray) {
                var _a2, _b;
                const links = getSymbolLinks(symbol);
                if (!links.variances) {
                    (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.CheckTypes, "getVariancesWorker", { arity: typeParameters.length, id: getTypeId(getDeclaredTypeOfSymbol(symbol)) });
                    links.variances = emptyArray;
                    const variances = [];
                    for (const tp of typeParameters) {
                        const modifiers = getTypeParameterModifiers(tp);
                        let variance = modifiers & 65536 /* Out */ ? modifiers & 32768 /* In */ ? 0 /* Invariant */ : 1 /* Covariant */ : modifiers & 32768 /* In */ ? 2 /* Contravariant */ : void 0;
                        if (variance === void 0) {
                            let unmeasurable = false;
                            let unreliable = false;
                            const oldHandler = outofbandVarianceMarkerHandler;
                            outofbandVarianceMarkerHandler = (onlyUnreliable) => onlyUnreliable ? unreliable = true : unmeasurable = true;
                            const typeWithSuper = createMarkerType(symbol, tp, markerSuperType);
                            const typeWithSub = createMarkerType(symbol, tp, markerSubType);
                            variance = (isTypeAssignableTo(typeWithSub, typeWithSuper) ? 1 /* Covariant */ : 0) | (isTypeAssignableTo(typeWithSuper, typeWithSub) ? 2 /* Contravariant */ : 0);
                            if (variance === 3 /* Bivariant */ && isTypeAssignableTo(createMarkerType(symbol, tp, markerOtherType), typeWithSuper)) {
                                variance = 4 /* Independent */;
                            }
                            outofbandVarianceMarkerHandler = oldHandler;
                            if (unmeasurable || unreliable) {
                                if (unmeasurable) {
                                    variance |= 8 /* Unmeasurable */;
                                }
                                if (unreliable) {
                                    variance |= 16 /* Unreliable */;
                                }
                            }
                        }
                        variances.push(variance);
                    }
                    links.variances = variances;
                    (_b = tracing) == null ? void 0 : _b.pop({ variances: variances.map(Debug.formatVariance) });
                }
                return links.variances;
            }
            function createMarkerType(symbol, source, target) {
                const mapper = makeUnaryTypeMapper(source, target);
                const type = getDeclaredTypeOfSymbol(symbol);
                if (isErrorType(type)) {
                    return type;
                }
                const result = symbol.flags & 524288 /* TypeAlias */ ? getTypeAliasInstantiation(symbol, instantiateTypes(getSymbolLinks(symbol).typeParameters, mapper)) : createTypeReference(type, instantiateTypes(type.typeParameters, mapper));
                markerTypes.add(getTypeId(result));
                return result;
            }
            function isMarkerType(type) {
                return markerTypes.has(getTypeId(type));
            }
            function getTypeParameterModifiers(tp) {
                var _a2;
                return reduceLeft((_a2 = tp.symbol) == null ? void 0 : _a2.declarations, (modifiers, d) => modifiers | getEffectiveModifierFlags(d), 0 /* None */) & (32768 /* In */ | 65536 /* Out */ | 2048 /* Const */);
            }
            function hasCovariantVoidArgument(typeArguments, variances) {
                for (let i = 0; i < variances.length; i++) {
                    if ((variances[i] & 7 /* VarianceMask */) === 1 /* Covariant */ && typeArguments[i].flags & 16384 /* Void */) {
                        return true;
                    }
                }
                return false;
            }
            function isUnconstrainedTypeParameter(type) {
                return type.flags & 262144 /* TypeParameter */ && !getConstraintOfTypeParameter(type);
            }
            function isNonDeferredTypeReference(type) {
                return !!(getObjectFlags(type) & 4 /* Reference */) && !type.node;
            }
            function isTypeReferenceWithGenericArguments(type) {
                return isNonDeferredTypeReference(type) && some(getTypeArguments(type), (t) => !!(t.flags & 262144 /* TypeParameter */) || isTypeReferenceWithGenericArguments(t));
            }
            function getGenericTypeReferenceRelationKey(source, target, postFix, ignoreConstraints) {
                const typeParameters = [];
                let constraintMarker = "";
                const sourceId = getTypeReferenceId(source, 0);
                const targetId = getTypeReferenceId(target, 0);
                return `${constraintMarker}${sourceId},${targetId}${postFix}`;
                function getTypeReferenceId(type, depth = 0) {
                    let result = "" + type.target.id;
                    for (const t of getTypeArguments(type)) {
                        if (t.flags & 262144 /* TypeParameter */) {
                            if (ignoreConstraints || isUnconstrainedTypeParameter(t)) {
                                let index = typeParameters.indexOf(t);
                                if (index < 0) {
                                    index = typeParameters.length;
                                    typeParameters.push(t);
                                }
                                result += "=" + index;
                                continue;
                            }
                            constraintMarker = "*";
                        }
                        else if (depth < 4 && isTypeReferenceWithGenericArguments(t)) {
                            result += "<" + getTypeReferenceId(t, depth + 1) + ">";
                            continue;
                        }
                        result += "-" + t.id;
                    }
                    return result;
                }
            }
            function getRelationKey(source, target, intersectionState, relation, ignoreConstraints) {
                if (relation === identityRelation && source.id > target.id) {
                    const temp = source;
                    source = target;
                    target = temp;
                }
                const postFix = intersectionState ? ":" + intersectionState : "";
                return isTypeReferenceWithGenericArguments(source) && isTypeReferenceWithGenericArguments(target) ? getGenericTypeReferenceRelationKey(source, target, postFix, ignoreConstraints) : `${source.id},${target.id}${postFix}`;
            }
            function forEachProperty2(prop, callback) {
                if (getCheckFlags(prop) & 6 /* Synthetic */) {
                    for (const t of prop.links.containingType.types) {
                        const p = getPropertyOfType(t, prop.escapedName);
                        const result = p && forEachProperty2(p, callback);
                        if (result) {
                            return result;
                        }
                    }
                    return void 0;
                }
                return callback(prop);
            }
            function getDeclaringClass(prop) {
                return prop.parent && prop.parent.flags & 32 /* Class */ ? getDeclaredTypeOfSymbol(getParentOfSymbol(prop)) : void 0;
            }
            function getTypeOfPropertyInBaseClass(property) {
                const classType = getDeclaringClass(property);
                const baseClassType = classType && getBaseTypes(classType)[0];
                return baseClassType && getTypeOfPropertyOfType(baseClassType, property.escapedName);
            }
            function isPropertyInClassDerivedFrom(prop, baseClass) {
                return forEachProperty2(prop, (sp) => {
                    const sourceClass = getDeclaringClass(sp);
                    return sourceClass ? hasBaseType(sourceClass, baseClass) : false;
                });
            }
            function isValidOverrideOf(sourceProp, targetProp) {
                return !forEachProperty2(targetProp, (tp) => getDeclarationModifierFlagsFromSymbol(tp) & 16 /* Protected */ ? !isPropertyInClassDerivedFrom(sourceProp, getDeclaringClass(tp)) : false);
            }
            function isClassDerivedFromDeclaringClasses(checkClass, prop, writing) {
                return forEachProperty2(prop, (p) => getDeclarationModifierFlagsFromSymbol(p, writing) & 16 /* Protected */ ? !hasBaseType(checkClass, getDeclaringClass(p)) : false) ? void 0 : checkClass;
            }
            function isDeeplyNestedType(type, stack, depth, maxDepth = 3) {
                if (depth >= maxDepth) {
                    if (type.flags & 2097152 /* Intersection */) {
                        return some(type.types, (t) => isDeeplyNestedType(t, stack, depth, maxDepth));
                    }
                    const identity2 = getRecursionIdentity(type);
                    let count = 0;
                    let lastTypeId = 0;
                    for (let i = 0; i < depth; i++) {
                        const t = stack[i];
                        if (t.flags & 2097152 /* Intersection */ ? some(t.types, (u) => getRecursionIdentity(u) === identity2) : getRecursionIdentity(t) === identity2) {
                            if (t.id >= lastTypeId) {
                                count++;
                                if (count >= maxDepth) {
                                    return true;
                                }
                            }
                            lastTypeId = t.id;
                        }
                    }
                }
                return false;
            }
            function getRecursionIdentity(type) {
                if (type.flags & 524288 /* Object */ && !isObjectOrArrayLiteralType(type)) {
                    if (getObjectFlags(type) && 4 /* Reference */ && type.node) {
                        return type.node;
                    }
                    if (type.symbol && !(getObjectFlags(type) & 16 /* Anonymous */ && type.symbol.flags & 32 /* Class */)) {
                        return type.symbol;
                    }
                    if (isTupleType(type)) {
                        return type.target;
                    }
                }
                if (type.flags & 262144 /* TypeParameter */) {
                    return type.symbol;
                }
                if (type.flags & 8388608 /* IndexedAccess */) {
                    do {
                        type = type.objectType;
                    } while (type.flags & 8388608 /* IndexedAccess */);
                    return type;
                }
                if (type.flags & 16777216 /* Conditional */) {
                    return type.root;
                }
                return type;
            }
            function isPropertyIdenticalTo(sourceProp, targetProp) {
                return compareProperties2(sourceProp, targetProp, compareTypesIdentical) !== 0 /* False */;
            }
            function compareProperties2(sourceProp, targetProp, compareTypes) {
                if (sourceProp === targetProp) {
                    return -1 /* True */;
                }
                const sourcePropAccessibility = getDeclarationModifierFlagsFromSymbol(sourceProp) & 24 /* NonPublicAccessibilityModifier */;
                const targetPropAccessibility = getDeclarationModifierFlagsFromSymbol(targetProp) & 24 /* NonPublicAccessibilityModifier */;
                if (sourcePropAccessibility !== targetPropAccessibility) {
                    return 0 /* False */;
                }
                if (sourcePropAccessibility) {
                    if (getTargetSymbol(sourceProp) !== getTargetSymbol(targetProp)) {
                        return 0 /* False */;
                    }
                }
                else {
                    if ((sourceProp.flags & 16777216 /* Optional */) !== (targetProp.flags & 16777216 /* Optional */)) {
                        return 0 /* False */;
                    }
                }
                if (isReadonlySymbol(sourceProp) !== isReadonlySymbol(targetProp)) {
                    return 0 /* False */;
                }
                return compareTypes(getTypeOfSymbol(sourceProp), getTypeOfSymbol(targetProp));
            }
            function isMatchingSignature(source, target, partialMatch) {
                const sourceParameterCount = getParameterCount(source);
                const targetParameterCount = getParameterCount(target);
                const sourceMinArgumentCount = getMinArgumentCount(source);
                const targetMinArgumentCount = getMinArgumentCount(target);
                const sourceHasRestParameter = hasEffectiveRestParameter(source);
                const targetHasRestParameter = hasEffectiveRestParameter(target);
                if (sourceParameterCount === targetParameterCount && sourceMinArgumentCount === targetMinArgumentCount && sourceHasRestParameter === targetHasRestParameter) {
                    return true;
                }
                if (partialMatch && sourceMinArgumentCount <= targetMinArgumentCount) {
                    return true;
                }
                return false;
            }
            function compareSignaturesIdentical(source, target, partialMatch, ignoreThisTypes, ignoreReturnTypes, compareTypes) {
                if (source === target) {
                    return -1 /* True */;
                }
                if (!isMatchingSignature(source, target, partialMatch)) {
                    return 0 /* False */;
                }
                if (length(source.typeParameters) !== length(target.typeParameters)) {
                    return 0 /* False */;
                }
                if (target.typeParameters) {
                    const mapper = createTypeMapper(source.typeParameters, target.typeParameters);
                    for (let i = 0; i < target.typeParameters.length; i++) {
                        const s = source.typeParameters[i];
                        const t = target.typeParameters[i];
                        if (!(s === t || compareTypes(instantiateType(getConstraintFromTypeParameter(s), mapper) || unknownType, getConstraintFromTypeParameter(t) || unknownType) && compareTypes(instantiateType(getDefaultFromTypeParameter(s), mapper) || unknownType, getDefaultFromTypeParameter(t) || unknownType))) {
                            return 0 /* False */;
                        }
                    }
                    source = instantiateSignature(source, mapper, 
                    /*eraseTypeParameters*/
                    true);
                }
                let result = -1 /* True */;
                if (!ignoreThisTypes) {
                    const sourceThisType = getThisTypeOfSignature(source);
                    if (sourceThisType) {
                        const targetThisType = getThisTypeOfSignature(target);
                        if (targetThisType) {
                            const related = compareTypes(sourceThisType, targetThisType);
                            if (!related) {
                                return 0 /* False */;
                            }
                            result &= related;
                        }
                    }
                }
                const targetLen = getParameterCount(target);
                for (let i = 0; i < targetLen; i++) {
                    const s = getTypeAtPosition(source, i);
                    const t = getTypeAtPosition(target, i);
                    const related = compareTypes(t, s);
                    if (!related) {
                        return 0 /* False */;
                    }
                    result &= related;
                }
                if (!ignoreReturnTypes) {
                    const sourceTypePredicate = getTypePredicateOfSignature(source);
                    const targetTypePredicate = getTypePredicateOfSignature(target);
                    result &= sourceTypePredicate || targetTypePredicate ? compareTypePredicatesIdentical(sourceTypePredicate, targetTypePredicate, compareTypes) : compareTypes(getReturnTypeOfSignature(source), getReturnTypeOfSignature(target));
                }
                return result;
            }
            function compareTypePredicatesIdentical(source, target, compareTypes) {
                return !(source && target && typePredicateKindsMatch(source, target)) ? 0 /* False */ : source.type === target.type ? -1 /* True */ : source.type && target.type ? compareTypes(source.type, target.type) : 0 /* False */;
            }
            function literalTypesWithSameBaseType(types) {
                let commonBaseType;
                for (const t of types) {
                    if (!(t.flags & 131072 /* Never */)) {
                        const baseType = getBaseTypeOfLiteralType(t);
                        commonBaseType != null ? commonBaseType : commonBaseType = baseType;
                        if (baseType === t || baseType !== commonBaseType) {
                            return false;
                        }
                    }
                }
                return true;
            }
            function getCombinedTypeFlags(types) {
                return reduceLeft(types, (flags, t) => flags | (t.flags & 1048576 /* Union */ ? getCombinedTypeFlags(t.types) : t.flags), 0);
            }
            function getCommonSupertype(types) {
                if (types.length === 1) {
                    return types[0];
                }
                const primaryTypes = strictNullChecks ? sameMap(types, (t) => filterType(t, (u) => !(u.flags & 98304 /* Nullable */))) : types;
                const superTypeOrUnion = literalTypesWithSameBaseType(primaryTypes) ? getUnionType(primaryTypes) : reduceLeft(primaryTypes, (s, t) => isTypeSubtypeOf(s, t) ? t : s);
                return primaryTypes === types ? superTypeOrUnion : getNullableType(superTypeOrUnion, getCombinedTypeFlags(types) & 98304 /* Nullable */);
            }
            function getCommonSubtype(types) {
                return reduceLeft(types, (s, t) => isTypeSubtypeOf(t, s) ? t : s);
            }
            function isArrayType(type) {
                return !!(getObjectFlags(type) & 4 /* Reference */) && (type.target === globalArrayType || type.target === globalReadonlyArrayType);
            }
            function isReadonlyArrayType(type) {
                return !!(getObjectFlags(type) & 4 /* Reference */) && type.target === globalReadonlyArrayType;
            }
            function isArrayOrTupleType(type) {
                return isArrayType(type) || isTupleType(type);
            }
            function isMutableArrayOrTuple(type) {
                return isArrayType(type) && !isReadonlyArrayType(type) || isTupleType(type) && !type.target.readonly;
            }
            function getElementTypeOfArrayType(type) {
                return isArrayType(type) ? getTypeArguments(type)[0] : void 0;
            }
            function isArrayLikeType(type) {
                return isArrayType(type) || !(type.flags & 98304 /* Nullable */) && isTypeAssignableTo(type, anyReadonlyArrayType);
            }
            function getSingleBaseForNonAugmentingSubtype(type) {
                if (!(getObjectFlags(type) & 4 /* Reference */) || !(getObjectFlags(type.target) & 3 /* ClassOrInterface */)) {
                    return void 0;
                }
                if (getObjectFlags(type) & 33554432 /* IdenticalBaseTypeCalculated */) {
                    return getObjectFlags(type) & 67108864 /* IdenticalBaseTypeExists */ ? type.cachedEquivalentBaseType : void 0;
                }
                type.objectFlags |= 33554432 /* IdenticalBaseTypeCalculated */;
                const target = type.target;
                if (getObjectFlags(target) & 1 /* Class */) {
                    const baseTypeNode = getBaseTypeNodeOfClass(target);
                    if (baseTypeNode && baseTypeNode.expression.kind !== 79 /* Identifier */ && baseTypeNode.expression.kind !== 208 /* PropertyAccessExpression */) {
                        return void 0;
                    }
                }
                const bases = getBaseTypes(target);
                if (bases.length !== 1) {
                    return void 0;
                }
                if (getMembersOfSymbol(type.symbol).size) {
                    return void 0;
                }
                let instantiatedBase = !length(target.typeParameters) ? bases[0] : instantiateType(bases[0], createTypeMapper(target.typeParameters, getTypeArguments(type).slice(0, target.typeParameters.length)));
                if (length(getTypeArguments(type)) > length(target.typeParameters)) {
                    instantiatedBase = getTypeWithThisArgument(instantiatedBase, last(getTypeArguments(type)));
                }
                type.objectFlags |= 67108864 /* IdenticalBaseTypeExists */;
                return type.cachedEquivalentBaseType = instantiatedBase;
            }
            function isEmptyLiteralType(type) {
                return strictNullChecks ? type === implicitNeverType : type === undefinedWideningType;
            }
            function isEmptyArrayLiteralType(type) {
                const elementType = getElementTypeOfArrayType(type);
                return !!elementType && isEmptyLiteralType(elementType);
            }
            function isTupleLikeType(type) {
                return isTupleType(type) || !!getPropertyOfType(type, "0");
            }
            function isArrayOrTupleLikeType(type) {
                return isArrayLikeType(type) || isTupleLikeType(type);
            }
            function getTupleElementType(type, index) {
                const propType = getTypeOfPropertyOfType(type, "" + index);
                if (propType) {
                    return propType;
                }
                if (everyType(type, isTupleType)) {
                    return mapType(type, (t) => {
                        const tupleType = t;
                        const restType = getRestTypeOfTupleType(tupleType);
                        if (!restType) {
                            return undefinedType;
                        }
                        if (compilerOptions.noUncheckedIndexedAccess && index >= tupleType.target.fixedLength + getEndElementCount(tupleType.target, 3 /* Fixed */)) {
                            return getUnionType([restType, undefinedType]);
                        }
                        return restType;
                    });
                }
                return void 0;
            }
            function isNeitherUnitTypeNorNever(type) {
                return !(type.flags & (109472 /* Unit */ | 131072 /* Never */));
            }
            function isUnitType(type) {
                return !!(type.flags & 109472 /* Unit */);
            }
            function isUnitLikeType(type) {
                const t = getBaseConstraintOrType(type);
                return t.flags & 2097152 /* Intersection */ ? some(t.types, isUnitType) : isUnitType(t);
            }
            function extractUnitType(type) {
                return type.flags & 2097152 /* Intersection */ ? find(type.types, isUnitType) || type : type;
            }
            function isLiteralType(type) {
                return type.flags & 16 /* Boolean */ ? true : type.flags & 1048576 /* Union */ ? type.flags & 1024 /* EnumLiteral */ ? true : every(type.types, isUnitType) : isUnitType(type);
            }
            function getBaseTypeOfLiteralType(type) {
                return type.flags & 1056 /* EnumLike */ ? getBaseTypeOfEnumLikeType(type) : type.flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) ? stringType : type.flags & 256 /* NumberLiteral */ ? numberType : type.flags & 2048 /* BigIntLiteral */ ? bigintType : type.flags & 512 /* BooleanLiteral */ ? booleanType : type.flags & 1048576 /* Union */ ? getBaseTypeOfLiteralTypeUnion(type) : type;
            }
            function getBaseTypeOfLiteralTypeUnion(type) {
                var _a2;
                const key = `B${getTypeId(type)}`;
                return (_a2 = getCachedType(key)) != null ? _a2 : setCachedType(key, mapType(type, getBaseTypeOfLiteralType));
            }
            function getBaseTypeOfLiteralTypeForComparison(type) {
                return type.flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) ? stringType : type.flags & (256 /* NumberLiteral */ | 32 /* Enum */) ? numberType : type.flags & 2048 /* BigIntLiteral */ ? bigintType : type.flags & 512 /* BooleanLiteral */ ? booleanType : type.flags & 1048576 /* Union */ ? mapType(type, getBaseTypeOfLiteralTypeForComparison) : type;
            }
            function getWidenedLiteralType(type) {
                return type.flags & 1056 /* EnumLike */ && isFreshLiteralType(type) ? getBaseTypeOfEnumLikeType(type) : type.flags & 128 /* StringLiteral */ && isFreshLiteralType(type) ? stringType : type.flags & 256 /* NumberLiteral */ && isFreshLiteralType(type) ? numberType : type.flags & 2048 /* BigIntLiteral */ && isFreshLiteralType(type) ? bigintType : type.flags & 512 /* BooleanLiteral */ && isFreshLiteralType(type) ? booleanType : type.flags & 1048576 /* Union */ ? mapType(type, getWidenedLiteralType) : type;
            }
            function getWidenedUniqueESSymbolType(type) {
                return type.flags & 8192 /* UniqueESSymbol */ ? esSymbolType : type.flags & 1048576 /* Union */ ? mapType(type, getWidenedUniqueESSymbolType) : type;
            }
            function getWidenedLiteralLikeTypeForContextualType(type, contextualType) {
                if (!isLiteralOfContextualType(type, contextualType)) {
                    type = getWidenedUniqueESSymbolType(getWidenedLiteralType(type));
                }
                return getRegularTypeOfLiteralType(type);
            }
            function getWidenedLiteralLikeTypeForContextualReturnTypeIfNeeded(type, contextualSignatureReturnType, isAsync) {
                if (type && isUnitType(type)) {
                    const contextualType = !contextualSignatureReturnType ? void 0 : isAsync ? getPromisedTypeOfPromise(contextualSignatureReturnType) : contextualSignatureReturnType;
                    type = getWidenedLiteralLikeTypeForContextualType(type, contextualType);
                }
                return type;
            }
            function getWidenedLiteralLikeTypeForContextualIterationTypeIfNeeded(type, contextualSignatureReturnType, kind, isAsyncGenerator) {
                if (type && isUnitType(type)) {
                    const contextualType = !contextualSignatureReturnType ? void 0 : getIterationTypeOfGeneratorFunctionReturnType(kind, contextualSignatureReturnType, isAsyncGenerator);
                    type = getWidenedLiteralLikeTypeForContextualType(type, contextualType);
                }
                return type;
            }
            function isTupleType(type) {
                return !!(getObjectFlags(type) & 4 /* Reference */ && type.target.objectFlags & 8 /* Tuple */);
            }
            function isGenericTupleType(type) {
                return isTupleType(type) && !!(type.target.combinedFlags & 8 /* Variadic */);
            }
            function isSingleElementGenericTupleType(type) {
                return isGenericTupleType(type) && type.target.elementFlags.length === 1;
            }
            function getRestTypeOfTupleType(type) {
                return getElementTypeOfSliceOfTupleType(type, type.target.fixedLength);
            }
            function getRestArrayTypeOfTupleType(type) {
                const restType = getRestTypeOfTupleType(type);
                return restType && createArrayType(restType);
            }
            function getElementTypeOfSliceOfTupleType(type, index, endSkipCount = 0, writing = false, noReductions = false) {
                const length2 = getTypeReferenceArity(type) - endSkipCount;
                if (index < length2) {
                    const typeArguments = getTypeArguments(type);
                    const elementTypes = [];
                    for (let i = index; i < length2; i++) {
                        const t = typeArguments[i];
                        elementTypes.push(type.target.elementFlags[i] & 8 /* Variadic */ ? getIndexedAccessType(t, numberType) : t);
                    }
                    return writing ? getIntersectionType(elementTypes) : getUnionType(elementTypes, noReductions ? 0 /* None */ : 1 /* Literal */);
                }
                return void 0;
            }
            function isTupleTypeStructureMatching(t1, t2) {
                return getTypeReferenceArity(t1) === getTypeReferenceArity(t2) && every(t1.target.elementFlags, (f, i) => (f & 12 /* Variable */) === (t2.target.elementFlags[i] & 12 /* Variable */));
            }
            function isZeroBigInt({ value }) {
                return value.base10Value === "0";
            }
            function removeDefinitelyFalsyTypes(type) {
                return filterType(type, (t) => !!(getTypeFacts(t) & 4194304 /* Truthy */));
            }
            function extractDefinitelyFalsyTypes(type) {
                return mapType(type, getDefinitelyFalsyPartOfType);
            }
            function getDefinitelyFalsyPartOfType(type) {
                return type.flags & 4 /* String */ ? emptyStringType : type.flags & 8 /* Number */ ? zeroType : type.flags & 64 /* BigInt */ ? zeroBigIntType : type === regularFalseType || type === falseType || type.flags & (16384 /* Void */ | 32768 /* Undefined */ | 65536 /* Null */ | 3 /* AnyOrUnknown */) || type.flags & 128 /* StringLiteral */ && type.value === "" || type.flags & 256 /* NumberLiteral */ && type.value === 0 || type.flags & 2048 /* BigIntLiteral */ && isZeroBigInt(type) ? type : neverType;
            }
            function getNullableType(type, flags) {
                const missing = flags & ~type.flags & (32768 /* Undefined */ | 65536 /* Null */);
                return missing === 0 ? type : missing === 32768 /* Undefined */ ? getUnionType([type, undefinedType]) : missing === 65536 /* Null */ ? getUnionType([type, nullType]) : getUnionType([type, undefinedType, nullType]);
            }
            function getOptionalType(type, isProperty = false) {
                Debug.assert(strictNullChecks);
                const missingOrUndefined = isProperty ? undefinedOrMissingType : undefinedType;
                return type === missingOrUndefined || type.flags & 1048576 /* Union */ && type.types[0] === missingOrUndefined ? type : getUnionType([type, missingOrUndefined]);
            }
            function getGlobalNonNullableTypeInstantiation(type) {
                if (!deferredGlobalNonNullableTypeAlias) {
                    deferredGlobalNonNullableTypeAlias = getGlobalSymbol("NonNullable", 524288 /* TypeAlias */, 
                    /*diagnostic*/
                    void 0) || unknownSymbol;
                }
                return deferredGlobalNonNullableTypeAlias !== unknownSymbol ? getTypeAliasInstantiation(deferredGlobalNonNullableTypeAlias, [type]) : getIntersectionType([type, emptyObjectType]);
            }
            function getNonNullableType(type) {
                return strictNullChecks ? getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */) : type;
            }
            function addOptionalTypeMarker(type) {
                return strictNullChecks ? getUnionType([type, optionalType]) : type;
            }
            function removeOptionalTypeMarker(type) {
                return strictNullChecks ? removeType(type, optionalType) : type;
            }
            function propagateOptionalTypeMarker(type, node, wasOptional) {
                return wasOptional ? isOutermostOptionalChain(node) ? getOptionalType(type) : addOptionalTypeMarker(type) : type;
            }
            function getOptionalExpressionType(exprType, expression) {
                return isExpressionOfOptionalChainRoot(expression) ? getNonNullableType(exprType) : isOptionalChain(expression) ? removeOptionalTypeMarker(exprType) : exprType;
            }
            function removeMissingType(type, isOptional) {
                return exactOptionalPropertyTypes && isOptional ? removeType(type, missingType) : type;
            }
            function containsMissingType(type) {
                return type === missingType || !!(type.flags & 1048576 /* Union */) && type.types[0] === missingType;
            }
            function removeMissingOrUndefinedType(type) {
                return exactOptionalPropertyTypes ? removeType(type, missingType) : getTypeWithFacts(type, 524288 /* NEUndefined */);
            }
            function isCoercibleUnderDoubleEquals(source, target) {
                return (source.flags & (8 /* Number */ | 4 /* String */ | 512 /* BooleanLiteral */)) !== 0 && (target.flags & (8 /* Number */ | 4 /* String */ | 16 /* Boolean */)) !== 0;
            }
            function isObjectTypeWithInferableIndex(type) {
                const objectFlags = getObjectFlags(type);
                return type.flags & 2097152 /* Intersection */ ? every(type.types, isObjectTypeWithInferableIndex) : !!(type.symbol && (type.symbol.flags & (4096 /* ObjectLiteral */ | 2048 /* TypeLiteral */ | 384 /* Enum */ | 512 /* ValueModule */)) !== 0 && !(type.symbol.flags & 32 /* Class */) && !typeHasCallOrConstructSignatures(type)) || !!(objectFlags & 4194304 /* ObjectRestType */) || !!(objectFlags & 1024 /* ReverseMapped */ && isObjectTypeWithInferableIndex(type.source));
            }
            function createSymbolWithType(source, type) {
                const symbol = createSymbol(source.flags, source.escapedName, getCheckFlags(source) & 8 /* Readonly */);
                symbol.declarations = source.declarations;
                symbol.parent = source.parent;
                symbol.links.type = type;
                symbol.links.target = source;
                if (source.valueDeclaration) {
                    symbol.valueDeclaration = source.valueDeclaration;
                }
                const nameType = getSymbolLinks(source).nameType;
                if (nameType) {
                    symbol.links.nameType = nameType;
                }
                return symbol;
            }
            function transformTypeOfMembers(type, f) {
                const members = createSymbolTable();
                for (const property of getPropertiesOfObjectType(type)) {
                    const original = getTypeOfSymbol(property);
                    const updated = f(original);
                    members.set(property.escapedName, updated === original ? property : createSymbolWithType(property, updated));
                }
                return members;
            }
            function getRegularTypeOfObjectLiteral(type) {
                if (!(isObjectLiteralType2(type) && getObjectFlags(type) & 8192 /* FreshLiteral */)) {
                    return type;
                }
                const regularType = type.regularType;
                if (regularType) {
                    return regularType;
                }
                const resolved = type;
                const members = transformTypeOfMembers(type, getRegularTypeOfObjectLiteral);
                const regularNew = createAnonymousType(resolved.symbol, members, resolved.callSignatures, resolved.constructSignatures, resolved.indexInfos);
                regularNew.flags = resolved.flags;
                regularNew.objectFlags |= resolved.objectFlags & ~8192 /* FreshLiteral */;
                type.regularType = regularNew;
                return regularNew;
            }
            function createWideningContext(parent2, propertyName, siblings) {
                return { parent: parent2, propertyName, siblings, resolvedProperties: void 0 };
            }
            function getSiblingsOfContext(context) {
                if (!context.siblings) {
                    const siblings = [];
                    for (const type of getSiblingsOfContext(context.parent)) {
                        if (isObjectLiteralType2(type)) {
                            const prop = getPropertyOfObjectType(type, context.propertyName);
                            if (prop) {
                                forEachType(getTypeOfSymbol(prop), (t) => {
                                    siblings.push(t);
                                });
                            }
                        }
                    }
                    context.siblings = siblings;
                }
                return context.siblings;
            }
            function getPropertiesOfContext(context) {
                if (!context.resolvedProperties) {
                    const names = /* @__PURE__ */ new Map();
                    for (const t of getSiblingsOfContext(context)) {
                        if (isObjectLiteralType2(t) && !(getObjectFlags(t) & 2097152 /* ContainsSpread */)) {
                            for (const prop of getPropertiesOfType(t)) {
                                names.set(prop.escapedName, prop);
                            }
                        }
                    }
                    context.resolvedProperties = arrayFrom(names.values());
                }
                return context.resolvedProperties;
            }
            function getWidenedProperty(prop, context) {
                if (!(prop.flags & 4 /* Property */)) {
                    return prop;
                }
                const original = getTypeOfSymbol(prop);
                const propContext = context && createWideningContext(context, prop.escapedName, 
                /*siblings*/
                void 0);
                const widened = getWidenedTypeWithContext(original, propContext);
                return widened === original ? prop : createSymbolWithType(prop, widened);
            }
            function getUndefinedProperty(prop) {
                const cached = undefinedProperties.get(prop.escapedName);
                if (cached) {
                    return cached;
                }
                const result = createSymbolWithType(prop, undefinedOrMissingType);
                result.flags |= 16777216 /* Optional */;
                undefinedProperties.set(prop.escapedName, result);
                return result;
            }
            function getWidenedTypeOfObjectLiteral(type, context) {
                const members = createSymbolTable();
                for (const prop of getPropertiesOfObjectType(type)) {
                    members.set(prop.escapedName, getWidenedProperty(prop, context));
                }
                if (context) {
                    for (const prop of getPropertiesOfContext(context)) {
                        if (!members.has(prop.escapedName)) {
                            members.set(prop.escapedName, getUndefinedProperty(prop));
                        }
                    }
                }
                const result = createAnonymousType(type.symbol, members, emptyArray, emptyArray, sameMap(getIndexInfosOfType(type), (info) => createIndexInfo(info.keyType, getWidenedType(info.type), info.isReadonly)));
                result.objectFlags |= getObjectFlags(type) & (4096 /* JSLiteral */ | 262144 /* NonInferrableType */);
                return result;
            }
            function getWidenedType(type) {
                return getWidenedTypeWithContext(type, 
                /*context*/
                void 0);
            }
            function getWidenedTypeWithContext(type, context) {
                if (getObjectFlags(type) & 196608 /* RequiresWidening */) {
                    if (context === void 0 && type.widened) {
                        return type.widened;
                    }
                    let result;
                    if (type.flags & (1 /* Any */ | 98304 /* Nullable */)) {
                        result = anyType;
                    }
                    else if (isObjectLiteralType2(type)) {
                        result = getWidenedTypeOfObjectLiteral(type, context);
                    }
                    else if (type.flags & 1048576 /* Union */) {
                        const unionContext = context || createWideningContext(
                        /*parent*/
                        void 0, 
                        /*propertyName*/
                        void 0, type.types);
                        const widenedTypes = sameMap(type.types, (t) => t.flags & 98304 /* Nullable */ ? t : getWidenedTypeWithContext(t, unionContext));
                        result = getUnionType(widenedTypes, some(widenedTypes, isEmptyObjectType) ? 2 /* Subtype */ : 1 /* Literal */);
                    }
                    else if (type.flags & 2097152 /* Intersection */) {
                        result = getIntersectionType(sameMap(type.types, getWidenedType));
                    }
                    else if (isArrayOrTupleType(type)) {
                        result = createTypeReference(type.target, sameMap(getTypeArguments(type), getWidenedType));
                    }
                    if (result && context === void 0) {
                        type.widened = result;
                    }
                    return result || type;
                }
                return type;
            }
            function reportWideningErrorsInType(type) {
                let errorReported = false;
                if (getObjectFlags(type) & 65536 /* ContainsWideningType */) {
                    if (type.flags & 1048576 /* Union */) {
                        if (some(type.types, isEmptyObjectType)) {
                            errorReported = true;
                        }
                        else {
                            for (const t of type.types) {
                                if (reportWideningErrorsInType(t)) {
                                    errorReported = true;
                                }
                            }
                        }
                    }
                    if (isArrayOrTupleType(type)) {
                        for (const t of getTypeArguments(type)) {
                            if (reportWideningErrorsInType(t)) {
                                errorReported = true;
                            }
                        }
                    }
                    if (isObjectLiteralType2(type)) {
                        for (const p of getPropertiesOfObjectType(type)) {
                            const t = getTypeOfSymbol(p);
                            if (getObjectFlags(t) & 65536 /* ContainsWideningType */) {
                                if (!reportWideningErrorsInType(t)) {
                                    error(p.valueDeclaration, Diagnostics.Object_literal_s_property_0_implicitly_has_an_1_type, symbolToString(p), typeToString(getWidenedType(t)));
                                }
                                errorReported = true;
                            }
                        }
                    }
                }
                return errorReported;
            }
            function reportImplicitAny(declaration, type, wideningKind) {
                const typeAsString = typeToString(getWidenedType(type));
                if (isInJSFile(declaration) && !isCheckJsEnabledForFile(getSourceFileOfNode(declaration), compilerOptions)) {
                    return;
                }
                let diagnostic;
                switch (declaration.kind) {
                    case 223 /* BinaryExpression */:
                    case 169 /* PropertyDeclaration */:
                    case 168 /* PropertySignature */:
                        diagnostic = noImplicitAny ? Diagnostics.Member_0_implicitly_has_an_1_type : Diagnostics.Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage;
                        break;
                    case 166 /* Parameter */:
                        const param = declaration;
                        if (isIdentifier(param.name)) {
                            const originalKeywordKind = identifierToKeywordKind(param.name);
                            if ((isCallSignatureDeclaration(param.parent) || isMethodSignature(param.parent) || isFunctionTypeNode(param.parent)) && param.parent.parameters.indexOf(param) > -1 && (resolveName(param, param.name.escapedText, 788968 /* Type */, void 0, param.name.escapedText, 
                            /*isUse*/
                            true) || originalKeywordKind && isTypeNodeKind(originalKeywordKind))) {
                                const newName = "arg" + param.parent.parameters.indexOf(param);
                                const typeName = declarationNameToString(param.name) + (param.dotDotDotToken ? "[]" : "");
                                errorOrSuggestion(noImplicitAny, declaration, Diagnostics.Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1, newName, typeName);
                                return;
                            }
                        }
                        diagnostic = declaration.dotDotDotToken ? noImplicitAny ? Diagnostics.Rest_parameter_0_implicitly_has_an_any_type : Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage : noImplicitAny ? Diagnostics.Parameter_0_implicitly_has_an_1_type : Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage;
                        break;
                    case 205 /* BindingElement */:
                        diagnostic = Diagnostics.Binding_element_0_implicitly_has_an_1_type;
                        if (!noImplicitAny) {
                            return;
                        }
                        break;
                    case 320 /* JSDocFunctionType */:
                        error(declaration, Diagnostics.Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type, typeAsString);
                        return;
                    case 326 /* JSDocSignature */:
                        if (noImplicitAny && isJSDocOverloadTag(declaration.parent)) {
                            error(declaration.parent.tagName, Diagnostics.This_overload_implicitly_returns_the_type_0_because_it_lacks_a_return_type_annotation, typeAsString);
                        }
                        return;
                    case 259 /* FunctionDeclaration */:
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                        if (noImplicitAny && !declaration.name) {
                            if (wideningKind === 3 /* GeneratorYield */) {
                                error(declaration, Diagnostics.Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_type_annotation, typeAsString);
                            }
                            else {
                                error(declaration, Diagnostics.Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type, typeAsString);
                            }
                            return;
                        }
                        diagnostic = !noImplicitAny ? Diagnostics._0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage : wideningKind === 3 /* GeneratorYield */ ? Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type : Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type;
                        break;
                    case 197 /* MappedType */:
                        if (noImplicitAny) {
                            error(declaration, Diagnostics.Mapped_object_type_implicitly_has_an_any_template_type);
                        }
                        return;
                    default:
                        diagnostic = noImplicitAny ? Diagnostics.Variable_0_implicitly_has_an_1_type : Diagnostics.Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage;
                }
                errorOrSuggestion(noImplicitAny, declaration, diagnostic, declarationNameToString(getNameOfDeclaration(declaration)), typeAsString);
            }
            function reportErrorsFromWidening(declaration, type, wideningKind) {
                addLazyDiagnostic(() => {
                    if (noImplicitAny && getObjectFlags(type) & 65536 /* ContainsWideningType */ && (!wideningKind || !getContextualSignatureForFunctionLikeDeclaration(declaration))) {
                        if (!reportWideningErrorsInType(type)) {
                            reportImplicitAny(declaration, type, wideningKind);
                        }
                    }
                });
            }
            function applyToParameterTypes(source, target, callback) {
                const sourceCount = getParameterCount(source);
                const targetCount = getParameterCount(target);
                const sourceRestType = getEffectiveRestType(source);
                const targetRestType = getEffectiveRestType(target);
                const targetNonRestCount = targetRestType ? targetCount - 1 : targetCount;
                const paramCount = sourceRestType ? targetNonRestCount : Math.min(sourceCount, targetNonRestCount);
                const sourceThisType = getThisTypeOfSignature(source);
                if (sourceThisType) {
                    const targetThisType = getThisTypeOfSignature(target);
                    if (targetThisType) {
                        callback(sourceThisType, targetThisType);
                    }
                }
                for (let i = 0; i < paramCount; i++) {
                    callback(getTypeAtPosition(source, i), getTypeAtPosition(target, i));
                }
                if (targetRestType) {
                    callback(getRestTypeAtPosition(source, paramCount), targetRestType);
                }
            }
            function applyToReturnTypes(source, target, callback) {
                const sourceTypePredicate = getTypePredicateOfSignature(source);
                const targetTypePredicate = getTypePredicateOfSignature(target);
                if (sourceTypePredicate && targetTypePredicate && typePredicateKindsMatch(sourceTypePredicate, targetTypePredicate) && sourceTypePredicate.type && targetTypePredicate.type) {
                    callback(sourceTypePredicate.type, targetTypePredicate.type);
                }
                else {
                    callback(getReturnTypeOfSignature(source), getReturnTypeOfSignature(target));
                }
            }
            function createInferenceContext(typeParameters, signature, flags, compareTypes) {
                return createInferenceContextWorker(typeParameters.map(createInferenceInfo), signature, flags, compareTypes || compareTypesAssignable);
            }
            function cloneInferenceContext(context, extraFlags = 0) {
                return context && createInferenceContextWorker(map(context.inferences, cloneInferenceInfo), context.signature, context.flags | extraFlags, context.compareTypes);
            }
            function createInferenceContextWorker(inferences, signature, flags, compareTypes) {
                const context = {
                    inferences,
                    signature,
                    flags,
                    compareTypes,
                    mapper: reportUnmeasurableMapper,
                    // initialize to a noop mapper so the context object is available, but the underlying object shape is right upon construction
                    nonFixingMapper: reportUnmeasurableMapper
                };
                context.mapper = makeFixingMapperForContext(context);
                context.nonFixingMapper = makeNonFixingMapperForContext(context);
                return context;
            }
            function makeFixingMapperForContext(context) {
                return makeDeferredTypeMapper(map(context.inferences, (i) => i.typeParameter), map(context.inferences, (inference, i) => () => {
                    if (!inference.isFixed) {
                        inferFromIntraExpressionSites(context);
                        clearCachedInferences(context.inferences);
                        inference.isFixed = true;
                    }
                    return getInferredType(context, i);
                }));
            }
            function makeNonFixingMapperForContext(context) {
                return makeDeferredTypeMapper(map(context.inferences, (i) => i.typeParameter), map(context.inferences, (_, i) => () => {
                    return getInferredType(context, i);
                }));
            }
            function clearCachedInferences(inferences) {
                for (const inference of inferences) {
                    if (!inference.isFixed) {
                        inference.inferredType = void 0;
                    }
                }
            }
            function addIntraExpressionInferenceSite(context, node, type) {
                var _a2;
                ((_a2 = context.intraExpressionInferenceSites) != null ? _a2 : context.intraExpressionInferenceSites = []).push({ node, type });
            }
            function inferFromIntraExpressionSites(context) {
                if (context.intraExpressionInferenceSites) {
                    for (const { node, type } of context.intraExpressionInferenceSites) {
                        const contextualType = node.kind === 171 /* MethodDeclaration */ ? getContextualTypeForObjectLiteralMethod(node, 2 /* NoConstraints */) : getContextualType2(node, 2 /* NoConstraints */);
                        if (contextualType) {
                            inferTypes(context.inferences, type, contextualType);
                        }
                    }
                    context.intraExpressionInferenceSites = void 0;
                }
            }
            function createInferenceInfo(typeParameter) {
                return {
                    typeParameter,
                    candidates: void 0,
                    contraCandidates: void 0,
                    inferredType: void 0,
                    priority: void 0,
                    topLevel: true,
                    isFixed: false,
                    impliedArity: void 0
                };
            }
            function cloneInferenceInfo(inference) {
                return {
                    typeParameter: inference.typeParameter,
                    candidates: inference.candidates && inference.candidates.slice(),
                    contraCandidates: inference.contraCandidates && inference.contraCandidates.slice(),
                    inferredType: inference.inferredType,
                    priority: inference.priority,
                    topLevel: inference.topLevel,
                    isFixed: inference.isFixed,
                    impliedArity: inference.impliedArity
                };
            }
            function cloneInferredPartOfContext(context) {
                const inferences = filter(context.inferences, hasInferenceCandidates);
                return inferences.length ? createInferenceContextWorker(map(inferences, cloneInferenceInfo), context.signature, context.flags, context.compareTypes) : void 0;
            }
            function getMapperFromContext(context) {
                return context && context.mapper;
            }
            function couldContainTypeVariables(type) {
                const objectFlags = getObjectFlags(type);
                if (objectFlags & 524288 /* CouldContainTypeVariablesComputed */) {
                    return !!(objectFlags & 1048576 /* CouldContainTypeVariables */);
                }
                const result = !!(type.flags & 465829888 /* Instantiable */ || type.flags & 524288 /* Object */ && !isNonGenericTopLevelType(type) && (objectFlags & 4 /* Reference */ && (type.node || forEach(getTypeArguments(type), couldContainTypeVariables)) || objectFlags & 16 /* Anonymous */ && type.symbol && type.symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 2048 /* TypeLiteral */ | 4096 /* ObjectLiteral */) && type.symbol.declarations || objectFlags & (32 /* Mapped */ | 1024 /* ReverseMapped */ | 4194304 /* ObjectRestType */ | 8388608 /* InstantiationExpressionType */)) || type.flags & 3145728 /* UnionOrIntersection */ && !(type.flags & 1024 /* EnumLiteral */) && !isNonGenericTopLevelType(type) && some(type.types, couldContainTypeVariables));
                if (type.flags & 3899393 /* ObjectFlagsType */) {
                    type.objectFlags |= 524288 /* CouldContainTypeVariablesComputed */ | (result ? 1048576 /* CouldContainTypeVariables */ : 0);
                }
                return result;
            }
            function isNonGenericTopLevelType(type) {
                if (type.aliasSymbol && !type.aliasTypeArguments) {
                    const declaration = getDeclarationOfKind(type.aliasSymbol, 262 /* TypeAliasDeclaration */);
                    return !!(declaration && findAncestor(declaration.parent, (n) => n.kind === 308 /* SourceFile */ ? true : n.kind === 264 /* ModuleDeclaration */ ? false : "quit"));
                }
                return false;
            }
            function isTypeParameterAtTopLevel(type, tp, depth = 0) {
                return !!(type === tp || type.flags & 3145728 /* UnionOrIntersection */ && some(type.types, (t) => isTypeParameterAtTopLevel(t, tp, depth)) || depth < 3 && type.flags & 16777216 /* Conditional */ && (isTypeParameterAtTopLevel(getTrueTypeFromConditionalType(type), tp, depth + 1) || isTypeParameterAtTopLevel(getFalseTypeFromConditionalType(type), tp, depth + 1)));
            }
            function isTypeParameterAtTopLevelInReturnType(signature, typeParameter) {
                const typePredicate = getTypePredicateOfSignature(signature);
                return typePredicate ? !!typePredicate.type && isTypeParameterAtTopLevel(typePredicate.type, typeParameter) : isTypeParameterAtTopLevel(getReturnTypeOfSignature(signature), typeParameter);
            }
            function createEmptyObjectTypeFromStringLiteral(type) {
                const members = createSymbolTable();
                forEachType(type, (t) => {
                    if (!(t.flags & 128 /* StringLiteral */)) {
                        return;
                    }
                    const name = escapeLeadingUnderscores(t.value);
                    const literalProp = createSymbol(4 /* Property */, name);
                    literalProp.links.type = anyType;
                    if (t.symbol) {
                        literalProp.declarations = t.symbol.declarations;
                        literalProp.valueDeclaration = t.symbol.valueDeclaration;
                    }
                    members.set(name, literalProp);
                });
                const indexInfos = type.flags & 4 /* String */ ? [createIndexInfo(stringType, emptyObjectType, 
                    /*isReadonly*/
                    false)] : emptyArray;
                return createAnonymousType(void 0, members, emptyArray, emptyArray, indexInfos);
            }
            function inferTypeForHomomorphicMappedType(source, target, constraint) {
                if (inInferTypeForHomomorphicMappedType) {
                    return void 0;
                }
                const key = source.id + "," + target.id + "," + constraint.id;
                if (reverseMappedCache.has(key)) {
                    return reverseMappedCache.get(key);
                }
                inInferTypeForHomomorphicMappedType = true;
                const type = createReverseMappedType(source, target, constraint);
                inInferTypeForHomomorphicMappedType = false;
                reverseMappedCache.set(key, type);
                return type;
            }
            function isPartiallyInferableType(type) {
                return !(getObjectFlags(type) & 262144 /* NonInferrableType */) || isObjectLiteralType2(type) && some(getPropertiesOfType(type), (prop) => isPartiallyInferableType(getTypeOfSymbol(prop))) || isTupleType(type) && some(getTypeArguments(type), isPartiallyInferableType);
            }
            function createReverseMappedType(source, target, constraint) {
                if (!(getIndexInfoOfType(source, stringType) || getPropertiesOfType(source).length !== 0 && isPartiallyInferableType(source))) {
                    return void 0;
                }
                if (isArrayType(source)) {
                    return createArrayType(inferReverseMappedType(getTypeArguments(source)[0], target, constraint), isReadonlyArrayType(source));
                }
                if (isTupleType(source)) {
                    const elementTypes = map(getTypeArguments(source), (t) => inferReverseMappedType(t, target, constraint));
                    const elementFlags = getMappedTypeModifiers(target) & 4 /* IncludeOptional */ ? sameMap(source.target.elementFlags, (f) => f & 2 /* Optional */ ? 1 /* Required */ : f) : source.target.elementFlags;
                    return createTupleType(elementTypes, elementFlags, source.target.readonly, source.target.labeledElementDeclarations);
                }
                const reversed = createObjectType(1024 /* ReverseMapped */ | 16 /* Anonymous */, 
                /*symbol*/
                void 0);
                reversed.source = source;
                reversed.mappedType = target;
                reversed.constraintType = constraint;
                return reversed;
            }
            function getTypeOfReverseMappedSymbol(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    links.type = inferReverseMappedType(symbol.links.propertyType, symbol.links.mappedType, symbol.links.constraintType);
                }
                return links.type;
            }
            function inferReverseMappedType(sourceType, target, constraint) {
                const typeParameter = getIndexedAccessType(constraint.type, getTypeParameterFromMappedType(target));
                const templateType = getTemplateTypeFromMappedType(target);
                const inference = createInferenceInfo(typeParameter);
                inferTypes([inference], sourceType, templateType);
                return getTypeFromInference(inference) || unknownType;
            }
            function* getUnmatchedProperties(source, target, requireOptionalProperties, matchDiscriminantProperties) {
                const properties = getPropertiesOfType(target);
                for (const targetProp of properties) {
                    if (isStaticPrivateIdentifierProperty(targetProp)) {
                        continue;
                    }
                    if (requireOptionalProperties || !(targetProp.flags & 16777216 /* Optional */ || getCheckFlags(targetProp) & 48 /* Partial */)) {
                        const sourceProp = getPropertyOfType(source, targetProp.escapedName);
                        if (!sourceProp) {
                            yield targetProp;
                        }
                        else if (matchDiscriminantProperties) {
                            const targetType = getTypeOfSymbol(targetProp);
                            if (targetType.flags & 109472 /* Unit */) {
                                const sourceType = getTypeOfSymbol(sourceProp);
                                if (!(sourceType.flags & 1 /* Any */ || getRegularTypeOfLiteralType(sourceType) === getRegularTypeOfLiteralType(targetType))) {
                                    yield targetProp;
                                }
                            }
                        }
                    }
                }
            }
            function getUnmatchedProperty(source, target, requireOptionalProperties, matchDiscriminantProperties) {
                return firstOrUndefinedIterator(getUnmatchedProperties(source, target, requireOptionalProperties, matchDiscriminantProperties));
            }
            function tupleTypesDefinitelyUnrelated(source, target) {
                return !(target.target.combinedFlags & 8 /* Variadic */) && target.target.minLength > source.target.minLength || !target.target.hasRestElement && (source.target.hasRestElement || target.target.fixedLength < source.target.fixedLength);
            }
            function typesDefinitelyUnrelated(source, target) {
                return isTupleType(source) && isTupleType(target) ? tupleTypesDefinitelyUnrelated(source, target) : !!getUnmatchedProperty(source, target, 
                /*requireOptionalProperties*/
                false, 
                /*matchDiscriminantProperties*/
                true) && !!getUnmatchedProperty(target, source, 
                /*requireOptionalProperties*/
                false, 
                /*matchDiscriminantProperties*/
                false);
            }
            function getTypeFromInference(inference) {
                return inference.candidates ? getUnionType(inference.candidates, 2 /* Subtype */) : inference.contraCandidates ? getIntersectionType(inference.contraCandidates) : void 0;
            }
            function hasSkipDirectInferenceFlag(node) {
                return !!getNodeLinks(node).skipDirectInference;
            }
            function isFromInferenceBlockedSource(type) {
                return !!(type.symbol && some(type.symbol.declarations, hasSkipDirectInferenceFlag));
            }
            function templateLiteralTypesDefinitelyUnrelated(source, target) {
                const sourceStart = source.texts[0];
                const targetStart = target.texts[0];
                const sourceEnd = source.texts[source.texts.length - 1];
                const targetEnd = target.texts[target.texts.length - 1];
                const startLen = Math.min(sourceStart.length, targetStart.length);
                const endLen = Math.min(sourceEnd.length, targetEnd.length);
                return sourceStart.slice(0, startLen) !== targetStart.slice(0, startLen) || sourceEnd.slice(sourceEnd.length - endLen) !== targetEnd.slice(targetEnd.length - endLen);
            }
            function isValidNumberString(s, roundTripOnly) {
                if (s === "")
                    return false;
                const n = +s;
                return isFinite(n) && (!roundTripOnly || "" + n === s);
            }
            function parseBigIntLiteralType(text) {
                return getBigIntLiteralType(parseValidBigInt(text));
            }
            function isMemberOfStringMapping(source, target) {
                if (target.flags & 1 /* Any */) {
                    return true;
                }
                if (target.flags & (4 /* String */ | 134217728 /* TemplateLiteral */)) {
                    return isTypeAssignableTo(source, target);
                }
                if (target.flags & 268435456 /* StringMapping */) {
                    const mappingStack = [];
                    while (target.flags & 268435456 /* StringMapping */) {
                        mappingStack.unshift(target.symbol);
                        target = target.type;
                    }
                    const mappedSource = reduceLeft(mappingStack, (memo, value) => getStringMappingType(value, memo), source);
                    return mappedSource === source && isMemberOfStringMapping(source, target);
                }
                return false;
            }
            function isValidTypeForTemplateLiteralPlaceholder(source, target) {
                if (source === target || target.flags & (1 /* Any */ | 4 /* String */)) {
                    return true;
                }
                if (source.flags & 128 /* StringLiteral */) {
                    const value = source.value;
                    return !!(target.flags & 8 /* Number */ && isValidNumberString(value, 
                    /*roundTripOnly*/
                    false) || target.flags & 64 /* BigInt */ && isValidBigIntString(value, 
                    /*roundTripOnly*/
                    false) || target.flags & (512 /* BooleanLiteral */ | 98304 /* Nullable */) && value === target.intrinsicName || target.flags & 268435456 /* StringMapping */ && isMemberOfStringMapping(getStringLiteralType(value), target));
                }
                if (source.flags & 134217728 /* TemplateLiteral */) {
                    const texts = source.texts;
                    return texts.length === 2 && texts[0] === "" && texts[1] === "" && isTypeAssignableTo(source.types[0], target);
                }
                return isTypeAssignableTo(source, target);
            }
            function inferTypesFromTemplateLiteralType(source, target) {
                return source.flags & 128 /* StringLiteral */ ? inferFromLiteralPartsToTemplateLiteral([source.value], emptyArray, target) : source.flags & 134217728 /* TemplateLiteral */ ? arraysEqual(source.texts, target.texts) ? map(source.types, getStringLikeTypeForType) : inferFromLiteralPartsToTemplateLiteral(source.texts, source.types, target) : void 0;
            }
            function isTypeMatchedByTemplateLiteralType(source, target) {
                const inferences = inferTypesFromTemplateLiteralType(source, target);
                return !!inferences && every(inferences, (r, i) => isValidTypeForTemplateLiteralPlaceholder(r, target.types[i]));
            }
            function getStringLikeTypeForType(type) {
                return type.flags & (1 /* Any */ | 402653316 /* StringLike */) ? type : getTemplateLiteralType(["", ""], [type]);
            }
            function inferFromLiteralPartsToTemplateLiteral(sourceTexts, sourceTypes, target) {
                const lastSourceIndex = sourceTexts.length - 1;
                const sourceStartText = sourceTexts[0];
                const sourceEndText = sourceTexts[lastSourceIndex];
                const targetTexts = target.texts;
                const lastTargetIndex = targetTexts.length - 1;
                const targetStartText = targetTexts[0];
                const targetEndText = targetTexts[lastTargetIndex];
                if (lastSourceIndex === 0 && sourceStartText.length < targetStartText.length + targetEndText.length || !sourceStartText.startsWith(targetStartText) || !sourceEndText.endsWith(targetEndText))
                    return void 0;
                const remainingEndText = sourceEndText.slice(0, sourceEndText.length - targetEndText.length);
                const matches = [];
                let seg = 0;
                let pos = targetStartText.length;
                for (let i = 1; i < lastTargetIndex; i++) {
                    const delim = targetTexts[i];
                    if (delim.length > 0) {
                        let s = seg;
                        let p = pos;
                        while (true) {
                            p = getSourceText(s).indexOf(delim, p);
                            if (p >= 0)
                                break;
                            s++;
                            if (s === sourceTexts.length)
                                return void 0;
                            p = 0;
                        }
                        addMatch(s, p);
                        pos += delim.length;
                    }
                    else if (pos < getSourceText(seg).length) {
                        addMatch(seg, pos + 1);
                    }
                    else if (seg < lastSourceIndex) {
                        addMatch(seg + 1, 0);
                    }
                    else {
                        return void 0;
                    }
                }
                addMatch(lastSourceIndex, getSourceText(lastSourceIndex).length);
                return matches;
                function getSourceText(index) {
                    return index < lastSourceIndex ? sourceTexts[index] : remainingEndText;
                }
                function addMatch(s, p) {
                    const matchType = s === seg ? getStringLiteralType(getSourceText(s).slice(pos, p)) : getTemplateLiteralType([sourceTexts[seg].slice(pos), ...sourceTexts.slice(seg + 1, s), getSourceText(s).slice(0, p)], sourceTypes.slice(seg, s));
                    matches.push(matchType);
                    seg = s;
                    pos = p;
                }
            }
            function inferTypes(inferences, originalSource, originalTarget, priority = 0 /* None */, contravariant = false) {
                let bivariant = false;
                let propagationType;
                let inferencePriority = 2048 /* MaxValue */;
                let allowComplexConstraintInference = true;
                let visited;
                let sourceStack;
                let targetStack;
                let expandingFlags = 0 /* None */;
                inferFromTypes(originalSource, originalTarget);
                function inferFromTypes(source, target) {
                    if (!couldContainTypeVariables(target)) {
                        return;
                    }
                    if (source === wildcardType) {
                        const savePropagationType = propagationType;
                        propagationType = source;
                        inferFromTypes(target, target);
                        propagationType = savePropagationType;
                        return;
                    }
                    if (source.aliasSymbol && source.aliasSymbol === target.aliasSymbol) {
                        if (source.aliasTypeArguments) {
                            const params = getSymbolLinks(source.aliasSymbol).typeParameters;
                            const minParams = getMinTypeArgumentCount(params);
                            const sourceTypes = fillMissingTypeArguments(source.aliasTypeArguments, params, minParams, isInJSFile(source.aliasSymbol.valueDeclaration));
                            const targetTypes = fillMissingTypeArguments(target.aliasTypeArguments, params, minParams, isInJSFile(source.aliasSymbol.valueDeclaration));
                            inferFromTypeArguments(sourceTypes, targetTypes, getAliasVariances(source.aliasSymbol));
                        }
                        return;
                    }
                    if (source === target && source.flags & 3145728 /* UnionOrIntersection */) {
                        for (const t of source.types) {
                            inferFromTypes(t, t);
                        }
                        return;
                    }
                    if (target.flags & 1048576 /* Union */) {
                        const [tempSources, tempTargets] = inferFromMatchingTypes(source.flags & 1048576 /* Union */ ? source.types : [source], target.types, isTypeOrBaseIdenticalTo);
                        const [sources, targets] = inferFromMatchingTypes(tempSources, tempTargets, isTypeCloselyMatchedBy);
                        if (targets.length === 0) {
                            return;
                        }
                        target = getUnionType(targets);
                        if (sources.length === 0) {
                            inferWithPriority(source, target, 1 /* NakedTypeVariable */);
                            return;
                        }
                        source = getUnionType(sources);
                    }
                    else if (target.flags & 2097152 /* Intersection */ && !every(target.types, isNonGenericObjectType)) {
                        if (!(source.flags & 1048576 /* Union */)) {
                            const [sources, targets] = inferFromMatchingTypes(source.flags & 2097152 /* Intersection */ ? source.types : [source], target.types, isTypeIdenticalTo);
                            if (sources.length === 0 || targets.length === 0) {
                                return;
                            }
                            source = getIntersectionType(sources);
                            target = getIntersectionType(targets);
                        }
                    }
                    else if (target.flags & (8388608 /* IndexedAccess */ | 33554432 /* Substitution */)) {
                        target = getActualTypeVariable(target);
                    }
                    if (target.flags & 8650752 /* TypeVariable */) {
                        if (isFromInferenceBlockedSource(source)) {
                            return;
                        }
                        const inference = getInferenceInfoForType(target);
                        if (inference) {
                            if (getObjectFlags(source) & 262144 /* NonInferrableType */ || source === nonInferrableAnyType) {
                                return;
                            }
                            if (!inference.isFixed) {
                                if (inference.priority === void 0 || priority < inference.priority) {
                                    inference.candidates = void 0;
                                    inference.contraCandidates = void 0;
                                    inference.topLevel = true;
                                    inference.priority = priority;
                                }
                                if (priority === inference.priority) {
                                    const candidate = propagationType || source;
                                    if (contravariant && !bivariant) {
                                        if (!contains(inference.contraCandidates, candidate)) {
                                            inference.contraCandidates = append(inference.contraCandidates, candidate);
                                            clearCachedInferences(inferences);
                                        }
                                    }
                                    else if (!contains(inference.candidates, candidate)) {
                                        inference.candidates = append(inference.candidates, candidate);
                                        clearCachedInferences(inferences);
                                    }
                                }
                                if (!(priority & 128 /* ReturnType */) && target.flags & 262144 /* TypeParameter */ && inference.topLevel && !isTypeParameterAtTopLevel(originalTarget, target)) {
                                    inference.topLevel = false;
                                    clearCachedInferences(inferences);
                                }
                            }
                            inferencePriority = Math.min(inferencePriority, priority);
                            return;
                        }
                        const simplified = getSimplifiedType(target, 
                        /*writing*/
                        false);
                        if (simplified !== target) {
                            inferFromTypes(source, simplified);
                        }
                        else if (target.flags & 8388608 /* IndexedAccess */) {
                            const indexType = getSimplifiedType(target.indexType, 
                            /*writing*/
                            false);
                            if (indexType.flags & 465829888 /* Instantiable */) {
                                const simplified2 = distributeIndexOverObjectType(getSimplifiedType(target.objectType, 
                                /*writing*/
                                false), indexType, 
                                /*writing*/
                                false);
                                if (simplified2 && simplified2 !== target) {
                                    inferFromTypes(source, simplified2);
                                }
                            }
                        }
                    }
                    if (getObjectFlags(source) & 4 /* Reference */ && getObjectFlags(target) & 4 /* Reference */ && (source.target === target.target || isArrayType(source) && isArrayType(target)) && !(source.node && target.node)) {
                        inferFromTypeArguments(getTypeArguments(source), getTypeArguments(target), getVariances(source.target));
                    }
                    else if (source.flags & 4194304 /* Index */ && target.flags & 4194304 /* Index */) {
                        inferFromContravariantTypes(source.type, target.type);
                    }
                    else if ((isLiteralType(source) || source.flags & 4 /* String */) && target.flags & 4194304 /* Index */) {
                        const empty = createEmptyObjectTypeFromStringLiteral(source);
                        inferFromContravariantTypesWithPriority(empty, target.type, 256 /* LiteralKeyof */);
                    }
                    else if (source.flags & 8388608 /* IndexedAccess */ && target.flags & 8388608 /* IndexedAccess */) {
                        inferFromTypes(source.objectType, target.objectType);
                        inferFromTypes(source.indexType, target.indexType);
                    }
                    else if (source.flags & 268435456 /* StringMapping */ && target.flags & 268435456 /* StringMapping */) {
                        if (source.symbol === target.symbol) {
                            inferFromTypes(source.type, target.type);
                        }
                    }
                    else if (source.flags & 33554432 /* Substitution */) {
                        inferFromTypes(source.baseType, target);
                        inferWithPriority(getSubstitutionIntersection(source), target, 4 /* SubstituteSource */);
                    }
                    else if (target.flags & 16777216 /* Conditional */) {
                        invokeOnce(source, target, inferToConditionalType);
                    }
                    else if (target.flags & 3145728 /* UnionOrIntersection */) {
                        inferToMultipleTypes(source, target.types, target.flags);
                    }
                    else if (source.flags & 1048576 /* Union */) {
                        const sourceTypes = source.types;
                        for (const sourceType of sourceTypes) {
                            inferFromTypes(sourceType, target);
                        }
                    }
                    else if (target.flags & 134217728 /* TemplateLiteral */) {
                        inferToTemplateLiteralType(source, target);
                    }
                    else {
                        source = getReducedType(source);
                        if (!(priority & 512 /* NoConstraints */ && source.flags & (2097152 /* Intersection */ | 465829888 /* Instantiable */))) {
                            const apparentSource = getApparentType(source);
                            if (apparentSource !== source && allowComplexConstraintInference && !(apparentSource.flags & (524288 /* Object */ | 2097152 /* Intersection */))) {
                                allowComplexConstraintInference = false;
                                return inferFromTypes(apparentSource, target);
                            }
                            source = apparentSource;
                        }
                        if (source.flags & (524288 /* Object */ | 2097152 /* Intersection */)) {
                            invokeOnce(source, target, inferFromObjectTypes);
                        }
                    }
                }
                function inferWithPriority(source, target, newPriority) {
                    const savePriority = priority;
                    priority |= newPriority;
                    inferFromTypes(source, target);
                    priority = savePriority;
                }
                function inferFromContravariantTypesWithPriority(source, target, newPriority) {
                    const savePriority = priority;
                    priority |= newPriority;
                    inferFromContravariantTypes(source, target);
                    priority = savePriority;
                }
                function inferToMultipleTypesWithPriority(source, targets, targetFlags, newPriority) {
                    const savePriority = priority;
                    priority |= newPriority;
                    inferToMultipleTypes(source, targets, targetFlags);
                    priority = savePriority;
                }
                function invokeOnce(source, target, action) {
                    const key = source.id + "," + target.id;
                    const status = visited && visited.get(key);
                    if (status !== void 0) {
                        inferencePriority = Math.min(inferencePriority, status);
                        return;
                    }
                    (visited || (visited = /* @__PURE__ */ new Map())).set(key, -1 /* Circularity */);
                    const saveInferencePriority = inferencePriority;
                    inferencePriority = 2048 /* MaxValue */;
                    const saveExpandingFlags = expandingFlags;
                    const sourceIdentity = getRecursionIdentity(source);
                    const targetIdentity = getRecursionIdentity(target);
                    if (contains(sourceStack, sourceIdentity))
                        expandingFlags |= 1 /* Source */;
                    if (contains(targetStack, targetIdentity))
                        expandingFlags |= 2 /* Target */;
                    if (expandingFlags !== 3 /* Both */) {
                        (sourceStack || (sourceStack = [])).push(sourceIdentity);
                        (targetStack || (targetStack = [])).push(targetIdentity);
                        action(source, target);
                        targetStack.pop();
                        sourceStack.pop();
                    }
                    else {
                        inferencePriority = -1 /* Circularity */;
                    }
                    expandingFlags = saveExpandingFlags;
                    visited.set(key, inferencePriority);
                    inferencePriority = Math.min(inferencePriority, saveInferencePriority);
                }
                function inferFromMatchingTypes(sources, targets, matches) {
                    let matchedSources;
                    let matchedTargets;
                    for (const t of targets) {
                        for (const s of sources) {
                            if (matches(s, t)) {
                                inferFromTypes(s, t);
                                matchedSources = appendIfUnique(matchedSources, s);
                                matchedTargets = appendIfUnique(matchedTargets, t);
                            }
                        }
                    }
                    return [
                        matchedSources ? filter(sources, (t) => !contains(matchedSources, t)) : sources,
                        matchedTargets ? filter(targets, (t) => !contains(matchedTargets, t)) : targets
                    ];
                }
                function inferFromTypeArguments(sourceTypes, targetTypes, variances) {
                    const count = sourceTypes.length < targetTypes.length ? sourceTypes.length : targetTypes.length;
                    for (let i = 0; i < count; i++) {
                        if (i < variances.length && (variances[i] & 7 /* VarianceMask */) === 2 /* Contravariant */) {
                            inferFromContravariantTypes(sourceTypes[i], targetTypes[i]);
                        }
                        else {
                            inferFromTypes(sourceTypes[i], targetTypes[i]);
                        }
                    }
                }
                function inferFromContravariantTypes(source, target) {
                    contravariant = !contravariant;
                    inferFromTypes(source, target);
                    contravariant = !contravariant;
                }
                function inferFromContravariantTypesIfStrictFunctionTypes(source, target) {
                    if (strictFunctionTypes || priority & 1024 /* AlwaysStrict */) {
                        inferFromContravariantTypes(source, target);
                    }
                    else {
                        inferFromTypes(source, target);
                    }
                }
                function getInferenceInfoForType(type) {
                    if (type.flags & 8650752 /* TypeVariable */) {
                        for (const inference of inferences) {
                            if (type === inference.typeParameter) {
                                return inference;
                            }
                        }
                    }
                    return void 0;
                }
                function getSingleTypeVariableFromIntersectionTypes(types) {
                    let typeVariable;
                    for (const type of types) {
                        const t = type.flags & 2097152 /* Intersection */ && find(type.types, (t2) => !!getInferenceInfoForType(t2));
                        if (!t || typeVariable && t !== typeVariable) {
                            return void 0;
                        }
                        typeVariable = t;
                    }
                    return typeVariable;
                }
                function inferToMultipleTypes(source, targets, targetFlags) {
                    let typeVariableCount = 0;
                    if (targetFlags & 1048576 /* Union */) {
                        let nakedTypeVariable;
                        const sources = source.flags & 1048576 /* Union */ ? source.types : [source];
                        const matched = new Array(sources.length);
                        let inferenceCircularity = false;
                        for (const t of targets) {
                            if (getInferenceInfoForType(t)) {
                                nakedTypeVariable = t;
                                typeVariableCount++;
                            }
                            else {
                                for (let i = 0; i < sources.length; i++) {
                                    const saveInferencePriority = inferencePriority;
                                    inferencePriority = 2048 /* MaxValue */;
                                    inferFromTypes(sources[i], t);
                                    if (inferencePriority === priority)
                                        matched[i] = true;
                                    inferenceCircularity = inferenceCircularity || inferencePriority === -1 /* Circularity */;
                                    inferencePriority = Math.min(inferencePriority, saveInferencePriority);
                                }
                            }
                        }
                        if (typeVariableCount === 0) {
                            const intersectionTypeVariable = getSingleTypeVariableFromIntersectionTypes(targets);
                            if (intersectionTypeVariable) {
                                inferWithPriority(source, intersectionTypeVariable, 1 /* NakedTypeVariable */);
                            }
                            return;
                        }
                        if (typeVariableCount === 1 && !inferenceCircularity) {
                            const unmatched = flatMap(sources, (s, i) => matched[i] ? void 0 : s);
                            if (unmatched.length) {
                                inferFromTypes(getUnionType(unmatched), nakedTypeVariable);
                                return;
                            }
                        }
                    }
                    else {
                        for (const t of targets) {
                            if (getInferenceInfoForType(t)) {
                                typeVariableCount++;
                            }
                            else {
                                inferFromTypes(source, t);
                            }
                        }
                    }
                    if (targetFlags & 2097152 /* Intersection */ ? typeVariableCount === 1 : typeVariableCount > 0) {
                        for (const t of targets) {
                            if (getInferenceInfoForType(t)) {
                                inferWithPriority(source, t, 1 /* NakedTypeVariable */);
                            }
                        }
                    }
                }
                function inferToMappedType(source, target, constraintType) {
                    if (constraintType.flags & 1048576 /* Union */) {
                        let result = false;
                        for (const type of constraintType.types) {
                            result = inferToMappedType(source, target, type) || result;
                        }
                        return result;
                    }
                    if (constraintType.flags & 4194304 /* Index */) {
                        const inference = getInferenceInfoForType(constraintType.type);
                        if (inference && !inference.isFixed && !isFromInferenceBlockedSource(source)) {
                            const inferredType = inferTypeForHomomorphicMappedType(source, target, constraintType);
                            if (inferredType) {
                                inferWithPriority(inferredType, inference.typeParameter, getObjectFlags(source) & 262144 /* NonInferrableType */ ? 16 /* PartialHomomorphicMappedType */ : 8 /* HomomorphicMappedType */);
                            }
                        }
                        return true;
                    }
                    if (constraintType.flags & 262144 /* TypeParameter */) {
                        inferWithPriority(getIndexType(source), constraintType, 32 /* MappedTypeConstraint */);
                        const extendedConstraint = getConstraintOfType(constraintType);
                        if (extendedConstraint && inferToMappedType(source, target, extendedConstraint)) {
                            return true;
                        }
                        const propTypes = map(getPropertiesOfType(source), getTypeOfSymbol);
                        const indexTypes = map(getIndexInfosOfType(source), (info) => info !== enumNumberIndexInfo ? info.type : neverType);
                        inferFromTypes(getUnionType(concatenate(propTypes, indexTypes)), getTemplateTypeFromMappedType(target));
                        return true;
                    }
                    return false;
                }
                function inferToConditionalType(source, target) {
                    if (source.flags & 16777216 /* Conditional */) {
                        inferFromTypes(source.checkType, target.checkType);
                        inferFromTypes(source.extendsType, target.extendsType);
                        inferFromTypes(getTrueTypeFromConditionalType(source), getTrueTypeFromConditionalType(target));
                        inferFromTypes(getFalseTypeFromConditionalType(source), getFalseTypeFromConditionalType(target));
                    }
                    else {
                        const targetTypes = [getTrueTypeFromConditionalType(target), getFalseTypeFromConditionalType(target)];
                        inferToMultipleTypesWithPriority(source, targetTypes, target.flags, contravariant ? 64 /* ContravariantConditional */ : 0);
                    }
                }
                function inferToTemplateLiteralType(source, target) {
                    const matches = inferTypesFromTemplateLiteralType(source, target);
                    const types = target.types;
                    if (matches || every(target.texts, (s) => s.length === 0)) {
                        for (let i = 0; i < types.length; i++) {
                            const source2 = matches ? matches[i] : neverType;
                            const target2 = types[i];
                            if (source2.flags & 128 /* StringLiteral */ && target2.flags & 8650752 /* TypeVariable */) {
                                const inferenceContext = getInferenceInfoForType(target2);
                                const constraint = inferenceContext ? getBaseConstraintOfType(inferenceContext.typeParameter) : void 0;
                                if (constraint && !isTypeAny(constraint)) {
                                    const constraintTypes = constraint.flags & 1048576 /* Union */ ? constraint.types : [constraint];
                                    let allTypeFlags = reduceLeft(constraintTypes, (flags, t) => flags | t.flags, 0);
                                    if (!(allTypeFlags & 4 /* String */)) {
                                        const str = source2.value;
                                        if (allTypeFlags & 296 /* NumberLike */ && !isValidNumberString(str, 
                                        /*roundTripOnly*/
                                        true)) {
                                            allTypeFlags &= ~296 /* NumberLike */;
                                        }
                                        if (allTypeFlags & 2112 /* BigIntLike */ && !isValidBigIntString(str, 
                                        /*roundTripOnly*/
                                        true)) {
                                            allTypeFlags &= ~2112 /* BigIntLike */;
                                        }
                                        const matchingType = reduceLeft(constraintTypes, (left, right) => !(right.flags & allTypeFlags) ? left : left.flags & 4 /* String */ ? left : right.flags & 4 /* String */ ? source2 : left.flags & 134217728 /* TemplateLiteral */ ? left : right.flags & 134217728 /* TemplateLiteral */ && isTypeMatchedByTemplateLiteralType(source2, right) ? source2 : left.flags & 268435456 /* StringMapping */ ? left : right.flags & 268435456 /* StringMapping */ && str === applyStringMapping(right.symbol, str) ? source2 : left.flags & 128 /* StringLiteral */ ? left : right.flags & 128 /* StringLiteral */ && right.value === str ? right : left.flags & 8 /* Number */ ? left : right.flags & 8 /* Number */ ? getNumberLiteralType(+str) : left.flags & 32 /* Enum */ ? left : right.flags & 32 /* Enum */ ? getNumberLiteralType(+str) : left.flags & 256 /* NumberLiteral */ ? left : right.flags & 256 /* NumberLiteral */ && right.value === +str ? right : left.flags & 64 /* BigInt */ ? left : right.flags & 64 /* BigInt */ ? parseBigIntLiteralType(str) : left.flags & 2048 /* BigIntLiteral */ ? left : right.flags & 2048 /* BigIntLiteral */ && pseudoBigIntToString(right.value) === str ? right : left.flags & 16 /* Boolean */ ? left : right.flags & 16 /* Boolean */ ? str === "true" ? trueType : str === "false" ? falseType : booleanType : left.flags & 512 /* BooleanLiteral */ ? left : right.flags & 512 /* BooleanLiteral */ && right.intrinsicName === str ? right : left.flags & 32768 /* Undefined */ ? left : right.flags & 32768 /* Undefined */ && right.intrinsicName === str ? right : left.flags & 65536 /* Null */ ? left : right.flags & 65536 /* Null */ && right.intrinsicName === str ? right : left, neverType);
                                        if (!(matchingType.flags & 131072 /* Never */)) {
                                            inferFromTypes(matchingType, target2);
                                            continue;
                                        }
                                    }
                                }
                            }
                            inferFromTypes(source2, target2);
                        }
                    }
                }
                function inferFromObjectTypes(source, target) {
                    var _a2, _b;
                    if (getObjectFlags(source) & 4 /* Reference */ && getObjectFlags(target) & 4 /* Reference */ && (source.target === target.target || isArrayType(source) && isArrayType(target))) {
                        inferFromTypeArguments(getTypeArguments(source), getTypeArguments(target), getVariances(source.target));
                        return;
                    }
                    if (isGenericMappedType(source) && isGenericMappedType(target)) {
                        inferFromTypes(getConstraintTypeFromMappedType(source), getConstraintTypeFromMappedType(target));
                        inferFromTypes(getTemplateTypeFromMappedType(source), getTemplateTypeFromMappedType(target));
                        const sourceNameType = getNameTypeFromMappedType(source);
                        const targetNameType = getNameTypeFromMappedType(target);
                        if (sourceNameType && targetNameType)
                            inferFromTypes(sourceNameType, targetNameType);
                    }
                    if (getObjectFlags(target) & 32 /* Mapped */ && !target.declaration.nameType) {
                        const constraintType = getConstraintTypeFromMappedType(target);
                        if (inferToMappedType(source, target, constraintType)) {
                            return;
                        }
                    }
                    if (!typesDefinitelyUnrelated(source, target)) {
                        if (isArrayOrTupleType(source)) {
                            if (isTupleType(target)) {
                                const sourceArity = getTypeReferenceArity(source);
                                const targetArity = getTypeReferenceArity(target);
                                const elementTypes = getTypeArguments(target);
                                const elementFlags = target.target.elementFlags;
                                if (isTupleType(source) && isTupleTypeStructureMatching(source, target)) {
                                    for (let i = 0; i < targetArity; i++) {
                                        inferFromTypes(getTypeArguments(source)[i], elementTypes[i]);
                                    }
                                    return;
                                }
                                const startLength = isTupleType(source) ? Math.min(source.target.fixedLength, target.target.fixedLength) : 0;
                                const endLength = Math.min(isTupleType(source) ? getEndElementCount(source.target, 3 /* Fixed */) : 0, target.target.hasRestElement ? getEndElementCount(target.target, 3 /* Fixed */) : 0);
                                for (let i = 0; i < startLength; i++) {
                                    inferFromTypes(getTypeArguments(source)[i], elementTypes[i]);
                                }
                                if (!isTupleType(source) || sourceArity - startLength - endLength === 1 && source.target.elementFlags[startLength] & 4 /* Rest */) {
                                    const restType = getTypeArguments(source)[startLength];
                                    for (let i = startLength; i < targetArity - endLength; i++) {
                                        inferFromTypes(elementFlags[i] & 8 /* Variadic */ ? createArrayType(restType) : restType, elementTypes[i]);
                                    }
                                }
                                else {
                                    const middleLength = targetArity - startLength - endLength;
                                    if (middleLength === 2) {
                                        if (elementFlags[startLength] & elementFlags[startLength + 1] & 8 /* Variadic */) {
                                            const targetInfo = getInferenceInfoForType(elementTypes[startLength]);
                                            if (targetInfo && targetInfo.impliedArity !== void 0) {
                                                inferFromTypes(sliceTupleType(source, startLength, endLength + sourceArity - targetInfo.impliedArity), elementTypes[startLength]);
                                                inferFromTypes(sliceTupleType(source, startLength + targetInfo.impliedArity, endLength), elementTypes[startLength + 1]);
                                            }
                                        }
                                        else if (elementFlags[startLength] & 8 /* Variadic */ && elementFlags[startLength + 1] & 4 /* Rest */) {
                                            const param = (_a2 = getInferenceInfoForType(elementTypes[startLength])) == null ? void 0 : _a2.typeParameter;
                                            const constraint = param && getBaseConstraintOfType(param);
                                            if (constraint && isTupleType(constraint) && !constraint.target.hasRestElement) {
                                                const impliedArity = constraint.target.fixedLength;
                                                inferFromTypes(sliceTupleType(source, startLength, sourceArity - (startLength + impliedArity)), elementTypes[startLength]);
                                                inferFromTypes(getElementTypeOfSliceOfTupleType(source, startLength + impliedArity, endLength), elementTypes[startLength + 1]);
                                            }
                                        }
                                        else if (elementFlags[startLength] & 4 /* Rest */ && elementFlags[startLength + 1] & 8 /* Variadic */) {
                                            const param = (_b = getInferenceInfoForType(elementTypes[startLength + 1])) == null ? void 0 : _b.typeParameter;
                                            const constraint = param && getBaseConstraintOfType(param);
                                            if (constraint && isTupleType(constraint) && !constraint.target.hasRestElement) {
                                                const impliedArity = constraint.target.fixedLength;
                                                const endIndex = sourceArity - getEndElementCount(target.target, 3 /* Fixed */);
                                                const startIndex = endIndex - impliedArity;
                                                const trailingSlice = createTupleType(getTypeArguments(source).slice(startIndex, endIndex), source.target.elementFlags.slice(startIndex, endIndex), 
                                                /*readonly*/
                                                false, source.target.labeledElementDeclarations && source.target.labeledElementDeclarations.slice(startIndex, endIndex));
                                                inferFromTypes(getElementTypeOfSliceOfTupleType(source, startLength, endLength + impliedArity), elementTypes[startLength]);
                                                inferFromTypes(trailingSlice, elementTypes[startLength + 1]);
                                            }
                                        }
                                    }
                                    else if (middleLength === 1 && elementFlags[startLength] & 8 /* Variadic */) {
                                        const endsInOptional = target.target.elementFlags[targetArity - 1] & 2 /* Optional */;
                                        const sourceSlice = sliceTupleType(source, startLength, endLength);
                                        inferWithPriority(sourceSlice, elementTypes[startLength], endsInOptional ? 2 /* SpeculativeTuple */ : 0);
                                    }
                                    else if (middleLength === 1 && elementFlags[startLength] & 4 /* Rest */) {
                                        const restType = getElementTypeOfSliceOfTupleType(source, startLength, endLength);
                                        if (restType) {
                                            inferFromTypes(restType, elementTypes[startLength]);
                                        }
                                    }
                                }
                                for (let i = 0; i < endLength; i++) {
                                    inferFromTypes(getTypeArguments(source)[sourceArity - i - 1], elementTypes[targetArity - i - 1]);
                                }
                                return;
                            }
                            if (isArrayType(target)) {
                                inferFromIndexTypes(source, target);
                                return;
                            }
                        }
                        inferFromProperties(source, target);
                        inferFromSignatures(source, target, 0 /* Call */);
                        inferFromSignatures(source, target, 1 /* Construct */);
                        inferFromIndexTypes(source, target);
                    }
                }
                function inferFromProperties(source, target) {
                    const properties = getPropertiesOfObjectType(target);
                    for (const targetProp of properties) {
                        const sourceProp = getPropertyOfType(source, targetProp.escapedName);
                        if (sourceProp && !some(sourceProp.declarations, hasSkipDirectInferenceFlag)) {
                            inferFromTypes(getTypeOfSymbol(sourceProp), getTypeOfSymbol(targetProp));
                        }
                    }
                }
                function inferFromSignatures(source, target, kind) {
                    const sourceSignatures = getSignaturesOfType(source, kind);
                    const targetSignatures = getSignaturesOfType(target, kind);
                    const sourceLen = sourceSignatures.length;
                    const targetLen = targetSignatures.length;
                    const len = sourceLen < targetLen ? sourceLen : targetLen;
                    for (let i = 0; i < len; i++) {
                        inferFromSignature(getBaseSignature(sourceSignatures[sourceLen - len + i]), getErasedSignature(targetSignatures[targetLen - len + i]));
                    }
                }
                function inferFromSignature(source, target) {
                    const saveBivariant = bivariant;
                    const kind = target.declaration ? target.declaration.kind : 0 /* Unknown */;
                    bivariant = bivariant || kind === 171 /* MethodDeclaration */ || kind === 170 /* MethodSignature */ || kind === 173 /* Constructor */;
                    applyToParameterTypes(source, target, inferFromContravariantTypesIfStrictFunctionTypes);
                    bivariant = saveBivariant;
                    applyToReturnTypes(source, target, inferFromTypes);
                }
                function inferFromIndexTypes(source, target) {
                    const priority2 = getObjectFlags(source) & getObjectFlags(target) & 32 /* Mapped */ ? 8 /* HomomorphicMappedType */ : 0;
                    const indexInfos = getIndexInfosOfType(target);
                    if (isObjectTypeWithInferableIndex(source)) {
                        for (const targetInfo of indexInfos) {
                            const propTypes = [];
                            for (const prop of getPropertiesOfType(source)) {
                                if (isApplicableIndexType(getLiteralTypeFromProperty(prop, 8576 /* StringOrNumberLiteralOrUnique */), targetInfo.keyType)) {
                                    const propType = getTypeOfSymbol(prop);
                                    propTypes.push(prop.flags & 16777216 /* Optional */ ? removeMissingOrUndefinedType(propType) : propType);
                                }
                            }
                            for (const info of getIndexInfosOfType(source)) {
                                if (isApplicableIndexType(info.keyType, targetInfo.keyType)) {
                                    propTypes.push(info.type);
                                }
                            }
                            if (propTypes.length) {
                                inferWithPriority(getUnionType(propTypes), targetInfo.type, priority2);
                            }
                        }
                    }
                    for (const targetInfo of indexInfos) {
                        const sourceInfo = getApplicableIndexInfo(source, targetInfo.keyType);
                        if (sourceInfo) {
                            inferWithPriority(sourceInfo.type, targetInfo.type, priority2);
                        }
                    }
                }
            }
            function isTypeOrBaseIdenticalTo(s, t) {
                return t === missingType ? s === t : isTypeIdenticalTo(s, t) || !!(t.flags & 4 /* String */ && s.flags & 128 /* StringLiteral */ || t.flags & 8 /* Number */ && s.flags & 256 /* NumberLiteral */);
            }
            function isTypeCloselyMatchedBy(s, t) {
                return !!(s.flags & 524288 /* Object */ && t.flags & 524288 /* Object */ && s.symbol && s.symbol === t.symbol || s.aliasSymbol && s.aliasTypeArguments && s.aliasSymbol === t.aliasSymbol);
            }
            function hasPrimitiveConstraint(type) {
                const constraint = getConstraintOfTypeParameter(type);
                return !!constraint && maybeTypeOfKind(constraint.flags & 16777216 /* Conditional */ ? getDefaultConstraintOfConditionalType(constraint) : constraint, 134348796 /* Primitive */ | 4194304 /* Index */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */);
            }
            function isObjectLiteralType2(type) {
                return !!(getObjectFlags(type) & 128 /* ObjectLiteral */);
            }
            function isObjectOrArrayLiteralType(type) {
                return !!(getObjectFlags(type) & (128 /* ObjectLiteral */ | 16384 /* ArrayLiteral */));
            }
            function unionObjectAndArrayLiteralCandidates(candidates) {
                if (candidates.length > 1) {
                    const objectLiterals = filter(candidates, isObjectOrArrayLiteralType);
                    if (objectLiterals.length) {
                        const literalsType = getUnionType(objectLiterals, 2 /* Subtype */);
                        return concatenate(filter(candidates, (t) => !isObjectOrArrayLiteralType(t)), [literalsType]);
                    }
                }
                return candidates;
            }
            function getContravariantInference(inference) {
                return inference.priority & 416 /* PriorityImpliesCombination */ ? getIntersectionType(inference.contraCandidates) : getCommonSubtype(inference.contraCandidates);
            }
            function getCovariantInference(inference, signature) {
                const candidates = unionObjectAndArrayLiteralCandidates(inference.candidates);
                const primitiveConstraint = hasPrimitiveConstraint(inference.typeParameter) || isConstTypeVariable(inference.typeParameter);
                const widenLiteralTypes = !primitiveConstraint && inference.topLevel && (inference.isFixed || !isTypeParameterAtTopLevelInReturnType(signature, inference.typeParameter));
                const baseCandidates = primitiveConstraint ? sameMap(candidates, getRegularTypeOfLiteralType) : widenLiteralTypes ? sameMap(candidates, getWidenedLiteralType) : candidates;
                const unwidenedType = inference.priority & 416 /* PriorityImpliesCombination */ ? getUnionType(baseCandidates, 2 /* Subtype */) : getCommonSupertype(baseCandidates);
                return getWidenedType(unwidenedType);
            }
            function getInferredType(context, index) {
                const inference = context.inferences[index];
                if (!inference.inferredType) {
                    let inferredType;
                    const signature = context.signature;
                    if (signature) {
                        const inferredCovariantType = inference.candidates ? getCovariantInference(inference, signature) : void 0;
                        if (inference.contraCandidates) {
                            const useCovariantType = inferredCovariantType && !(inferredCovariantType.flags & 131072 /* Never */) && some(inference.contraCandidates, (t) => isTypeSubtypeOf(inferredCovariantType, t)) && every(context.inferences, (other) => other !== inference && getConstraintOfTypeParameter(other.typeParameter) !== inference.typeParameter || every(other.candidates, (t) => isTypeSubtypeOf(t, inferredCovariantType)));
                            inferredType = useCovariantType ? inferredCovariantType : getContravariantInference(inference);
                        }
                        else if (inferredCovariantType) {
                            inferredType = inferredCovariantType;
                        }
                        else if (context.flags & 1 /* NoDefault */) {
                            inferredType = silentNeverType;
                        }
                        else {
                            const defaultType = getDefaultFromTypeParameter(inference.typeParameter);
                            if (defaultType) {
                                inferredType = instantiateType(defaultType, mergeTypeMappers(createBackreferenceMapper(context, index), context.nonFixingMapper));
                            }
                        }
                    }
                    else {
                        inferredType = getTypeFromInference(inference);
                    }
                    inference.inferredType = inferredType || getDefaultTypeArgumentType(!!(context.flags & 2 /* AnyDefault */));
                    const constraint = getConstraintOfTypeParameter(inference.typeParameter);
                    if (constraint) {
                        const instantiatedConstraint = instantiateType(constraint, context.nonFixingMapper);
                        if (!inferredType || !context.compareTypes(inferredType, getTypeWithThisArgument(instantiatedConstraint, inferredType))) {
                            inference.inferredType = inferredType = instantiatedConstraint;
                        }
                    }
                }
                return inference.inferredType;
            }
            function getDefaultTypeArgumentType(isInJavaScriptFile) {
                return isInJavaScriptFile ? anyType : unknownType;
            }
            function getInferredTypes(context) {
                const result = [];
                for (let i = 0; i < context.inferences.length; i++) {
                    result.push(getInferredType(context, i));
                }
                return result;
            }
            function getCannotFindNameDiagnosticForName(node) {
                switch (node.escapedText) {
                    case "document":
                    case "console":
                        return Diagnostics.Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_include_dom;
                    case "$":
                        return compilerOptions.types ? Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery_and_then_add_jquery_to_the_types_field_in_your_tsconfig : Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery;
                    case "describe":
                    case "suite":
                    case "it":
                    case "test":
                        return compilerOptions.types ? Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha_and_then_add_jest_or_mocha_to_the_types_field_in_your_tsconfig : Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha;
                    case "process":
                    case "require":
                    case "Buffer":
                    case "module":
                        return compilerOptions.types ? Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode_and_then_add_node_to_the_types_field_in_your_tsconfig : Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode;
                    case "Map":
                    case "Set":
                    case "Promise":
                    case "Symbol":
                    case "WeakMap":
                    case "WeakSet":
                    case "Iterator":
                    case "AsyncIterator":
                    case "SharedArrayBuffer":
                    case "Atomics":
                    case "AsyncIterable":
                    case "AsyncIterableIterator":
                    case "AsyncGenerator":
                    case "AsyncGeneratorFunction":
                    case "BigInt":
                    case "Reflect":
                    case "BigInt64Array":
                    case "BigUint64Array":
                        return Diagnostics.Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_1_or_later;
                    case "await":
                        if (isCallExpression(node.parent)) {
                            return Diagnostics.Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function;
                        }
                    default:
                        if (node.parent.kind === 300 /* ShorthandPropertyAssignment */) {
                            return Diagnostics.No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer;
                        }
                        else {
                            return Diagnostics.Cannot_find_name_0;
                        }
                }
            }
            function getResolvedSymbol(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedSymbol) {
                    links.resolvedSymbol = !nodeIsMissing(node) && resolveName(node, node.escapedText, 111551 /* Value */ | 1048576 /* ExportValue */, getCannotFindNameDiagnosticForName(node), node, !isWriteOnlyAccess(node), 
                    /*excludeGlobals*/
                    false) || unknownSymbol;
                }
                return links.resolvedSymbol;
            }
            function isInTypeQuery(node) {
                return !!findAncestor(node, (n) => n.kind === 183 /* TypeQuery */ ? true : n.kind === 79 /* Identifier */ || n.kind === 163 /* QualifiedName */ ? false : "quit");
            }
            function isInAmbientOrTypeNode(node) {
                return !!(node.flags & 16777216 /* Ambient */ || findAncestor(node, (n) => isInterfaceDeclaration(n) || isTypeLiteralNode(n)));
            }
            function getFlowCacheKey(node, declaredType, initialType, flowContainer) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        if (!isThisInTypeQuery(node)) {
                            const symbol = getResolvedSymbol(node);
                            return symbol !== unknownSymbol ? `${flowContainer ? getNodeId(flowContainer) : "-1"}|${getTypeId(declaredType)}|${getTypeId(initialType)}|${getSymbolId(symbol)}` : void 0;
                        }
                    case 108 /* ThisKeyword */:
                        return `0|${flowContainer ? getNodeId(flowContainer) : "-1"}|${getTypeId(declaredType)}|${getTypeId(initialType)}`;
                    case 232 /* NonNullExpression */:
                    case 214 /* ParenthesizedExpression */:
                        return getFlowCacheKey(node.expression, declaredType, initialType, flowContainer);
                    case 163 /* QualifiedName */:
                        const left = getFlowCacheKey(node.left, declaredType, initialType, flowContainer);
                        return left && left + "." + node.right.escapedText;
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        const propName = getAccessedPropertyName(node);
                        if (propName !== void 0) {
                            const key = getFlowCacheKey(node.expression, declaredType, initialType, flowContainer);
                            return key && key + "." + propName;
                        }
                        break;
                    case 203 /* ObjectBindingPattern */:
                    case 204 /* ArrayBindingPattern */:
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                    case 171 /* MethodDeclaration */:
                        return `${getNodeId(node)}#${getTypeId(declaredType)}`;
                }
                return void 0;
            }
            function isMatchingReference(source, target) {
                switch (target.kind) {
                    case 214 /* ParenthesizedExpression */:
                    case 232 /* NonNullExpression */:
                        return isMatchingReference(source, target.expression);
                    case 223 /* BinaryExpression */:
                        return isAssignmentExpression(target) && isMatchingReference(source, target.left) || isBinaryExpression(target) && target.operatorToken.kind === 27 /* CommaToken */ && isMatchingReference(source, target.right);
                }
                switch (source.kind) {
                    case 233 /* MetaProperty */:
                        return target.kind === 233 /* MetaProperty */ && source.keywordToken === target.keywordToken && source.name.escapedText === target.name.escapedText;
                    case 79 /* Identifier */:
                    case 80 /* PrivateIdentifier */:
                        return isThisInTypeQuery(source) ? target.kind === 108 /* ThisKeyword */ : target.kind === 79 /* Identifier */ && getResolvedSymbol(source) === getResolvedSymbol(target) || (isVariableDeclaration(target) || isBindingElement(target)) && getExportSymbolOfValueSymbolIfExported(getResolvedSymbol(source)) === getSymbolOfDeclaration(target);
                    case 108 /* ThisKeyword */:
                        return target.kind === 108 /* ThisKeyword */;
                    case 106 /* SuperKeyword */:
                        return target.kind === 106 /* SuperKeyword */;
                    case 232 /* NonNullExpression */:
                    case 214 /* ParenthesizedExpression */:
                        return isMatchingReference(source.expression, target);
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        const sourcePropertyName = getAccessedPropertyName(source);
                        const targetPropertyName = isAccessExpression(target) ? getAccessedPropertyName(target) : void 0;
                        return sourcePropertyName !== void 0 && targetPropertyName !== void 0 && targetPropertyName === sourcePropertyName && isMatchingReference(source.expression, target.expression);
                    case 163 /* QualifiedName */:
                        return isAccessExpression(target) && source.right.escapedText === getAccessedPropertyName(target) && isMatchingReference(source.left, target.expression);
                    case 223 /* BinaryExpression */:
                        return isBinaryExpression(source) && source.operatorToken.kind === 27 /* CommaToken */ && isMatchingReference(source.right, target);
                }
                return false;
            }
            function getAccessedPropertyName(access) {
                if (isPropertyAccessExpression(access)) {
                    return access.name.escapedText;
                }
                if (isElementAccessExpression(access)) {
                    return tryGetElementAccessExpressionName(access);
                }
                if (isBindingElement(access)) {
                    const name = getDestructuringPropertyName(access);
                    return name ? escapeLeadingUnderscores(name) : void 0;
                }
                if (isParameter(access)) {
                    return "" + access.parent.parameters.indexOf(access);
                }
                return void 0;
            }
            function tryGetNameFromType(type) {
                return type.flags & 8192 /* UniqueESSymbol */ ? type.escapedName : type.flags & 384 /* StringOrNumberLiteral */ ? escapeLeadingUnderscores("" + type.value) : void 0;
            }
            function tryGetElementAccessExpressionName(node) {
                if (isStringOrNumericLiteralLike(node.argumentExpression)) {
                    return escapeLeadingUnderscores(node.argumentExpression.text);
                }
                if (isEntityNameExpression(node.argumentExpression)) {
                    const symbol = resolveEntityName(node.argumentExpression, 111551 /* Value */, 
                    /*ignoreErrors*/
                    true);
                    if (!symbol || !(isConstVariable(symbol) || symbol.flags & 8 /* EnumMember */))
                        return void 0;
                    const declaration = symbol.valueDeclaration;
                    if (declaration === void 0)
                        return void 0;
                    const type = tryGetTypeFromEffectiveTypeNode(declaration);
                    if (type) {
                        const name = tryGetNameFromType(type);
                        if (name !== void 0) {
                            return name;
                        }
                    }
                    if (hasOnlyExpressionInitializer(declaration) && isBlockScopedNameDeclaredBeforeUse(declaration, node.argumentExpression)) {
                        const initializer = getEffectiveInitializer(declaration);
                        if (initializer) {
                            return tryGetNameFromType(getTypeOfExpression(initializer));
                        }
                        if (isEnumMember(declaration)) {
                            return getTextOfPropertyName(declaration.name);
                        }
                    }
                }
                return void 0;
            }
            function containsMatchingReference(source, target) {
                while (isAccessExpression(source)) {
                    source = source.expression;
                    if (isMatchingReference(source, target)) {
                        return true;
                    }
                }
                return false;
            }
            function optionalChainContainsReference(source, target) {
                while (isOptionalChain(source)) {
                    source = source.expression;
                    if (isMatchingReference(source, target)) {
                        return true;
                    }
                }
                return false;
            }
            function isDiscriminantProperty(type, name) {
                if (type && type.flags & 1048576 /* Union */) {
                    const prop = getUnionOrIntersectionProperty(type, name);
                    if (prop && getCheckFlags(prop) & 2 /* SyntheticProperty */) {
                        if (prop.links.isDiscriminantProperty === void 0) {
                            prop.links.isDiscriminantProperty = (prop.links.checkFlags & 192 /* Discriminant */) === 192 /* Discriminant */ && !isGenericType(getTypeOfSymbol(prop));
                        }
                        return !!prop.links.isDiscriminantProperty;
                    }
                }
                return false;
            }
            function findDiscriminantProperties(sourceProperties, target) {
                let result;
                for (const sourceProperty of sourceProperties) {
                    if (isDiscriminantProperty(target, sourceProperty.escapedName)) {
                        if (result) {
                            result.push(sourceProperty);
                            continue;
                        }
                        result = [sourceProperty];
                    }
                }
                return result;
            }
            function mapTypesByKeyProperty(types, name) {
                const map2 = /* @__PURE__ */ new Map();
                let count = 0;
                for (const type of types) {
                    if (type.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 58982400 /* InstantiableNonPrimitive */)) {
                        const discriminant = getTypeOfPropertyOfType(type, name);
                        if (discriminant) {
                            if (!isLiteralType(discriminant)) {
                                return void 0;
                            }
                            let duplicate = false;
                            forEachType(discriminant, (t) => {
                                const id = getTypeId(getRegularTypeOfLiteralType(t));
                                const existing = map2.get(id);
                                if (!existing) {
                                    map2.set(id, type);
                                }
                                else if (existing !== unknownType) {
                                    map2.set(id, unknownType);
                                    duplicate = true;
                                }
                            });
                            if (!duplicate)
                                count++;
                        }
                    }
                }
                return count >= 10 && count * 2 >= types.length ? map2 : void 0;
            }
            function getKeyPropertyName(unionType) {
                const types = unionType.types;
                if (types.length < 10 || getObjectFlags(unionType) & 32768 /* PrimitiveUnion */ || countWhere(types, (t) => !!(t.flags & (524288 /* Object */ | 58982400 /* InstantiableNonPrimitive */))) < 10) {
                    return void 0;
                }
                if (unionType.keyPropertyName === void 0) {
                    const keyPropertyName = forEach(types, (t) => t.flags & (524288 /* Object */ | 58982400 /* InstantiableNonPrimitive */) ? forEach(getPropertiesOfType(t), (p) => isUnitType(getTypeOfSymbol(p)) ? p.escapedName : void 0) : void 0);
                    const mapByKeyProperty = keyPropertyName && mapTypesByKeyProperty(types, keyPropertyName);
                    unionType.keyPropertyName = mapByKeyProperty ? keyPropertyName : "";
                    unionType.constituentMap = mapByKeyProperty;
                }
                return unionType.keyPropertyName.length ? unionType.keyPropertyName : void 0;
            }
            function getConstituentTypeForKeyType(unionType, keyType) {
                var _a2;
                const result = (_a2 = unionType.constituentMap) == null ? void 0 : _a2.get(getTypeId(getRegularTypeOfLiteralType(keyType)));
                return result !== unknownType ? result : void 0;
            }
            function getMatchingUnionConstituentForType(unionType, type) {
                const keyPropertyName = getKeyPropertyName(unionType);
                const propType = keyPropertyName && getTypeOfPropertyOfType(type, keyPropertyName);
                return propType && getConstituentTypeForKeyType(unionType, propType);
            }
            function getMatchingUnionConstituentForObjectLiteral(unionType, node) {
                const keyPropertyName = getKeyPropertyName(unionType);
                const propNode = keyPropertyName && find(node.properties, (p) => p.symbol && p.kind === 299 /* PropertyAssignment */ && p.symbol.escapedName === keyPropertyName && isPossiblyDiscriminantValue(p.initializer));
                const propType = propNode && getContextFreeTypeOfExpression(propNode.initializer);
                return propType && getConstituentTypeForKeyType(unionType, propType);
            }
            function isOrContainsMatchingReference(source, target) {
                return isMatchingReference(source, target) || containsMatchingReference(source, target);
            }
            function hasMatchingArgument(expression, reference) {
                if (expression.arguments) {
                    for (const argument of expression.arguments) {
                        if (isOrContainsMatchingReference(reference, argument)) {
                            return true;
                        }
                    }
                }
                if (expression.expression.kind === 208 /* PropertyAccessExpression */ && isOrContainsMatchingReference(reference, expression.expression.expression)) {
                    return true;
                }
                return false;
            }
            function getFlowNodeId(flow) {
                if (!flow.id || flow.id < 0) {
                    flow.id = nextFlowId;
                    nextFlowId++;
                }
                return flow.id;
            }
            function typeMaybeAssignableTo(source, target) {
                if (!(source.flags & 1048576 /* Union */)) {
                    return isTypeAssignableTo(source, target);
                }
                for (const t of source.types) {
                    if (isTypeAssignableTo(t, target)) {
                        return true;
                    }
                }
                return false;
            }
            function getAssignmentReducedType(declaredType, assignedType) {
                var _a2;
                if (declaredType === assignedType) {
                    return declaredType;
                }
                if (assignedType.flags & 131072 /* Never */) {
                    return assignedType;
                }
                const key = `A${getTypeId(declaredType)},${getTypeId(assignedType)}`;
                return (_a2 = getCachedType(key)) != null ? _a2 : setCachedType(key, getAssignmentReducedTypeWorker(declaredType, assignedType));
            }
            function getAssignmentReducedTypeWorker(declaredType, assignedType) {
                const filteredType = filterType(declaredType, (t) => typeMaybeAssignableTo(assignedType, t));
                const reducedType = assignedType.flags & 512 /* BooleanLiteral */ && isFreshLiteralType(assignedType) ? mapType(filteredType, getFreshTypeOfLiteralType) : filteredType;
                return isTypeAssignableTo(assignedType, reducedType) ? reducedType : declaredType;
            }
            function isFunctionObjectType(type) {
                const resolved = resolveStructuredTypeMembers(type);
                return !!(resolved.callSignatures.length || resolved.constructSignatures.length || resolved.members.get("bind") && isTypeSubtypeOf(type, globalFunctionType));
            }
            function getTypeFacts(type) {
                if (type.flags & (2097152 /* Intersection */ | 465829888 /* Instantiable */)) {
                    type = getBaseConstraintOfType(type) || unknownType;
                }
                const flags = type.flags;
                if (flags & (4 /* String */ | 268435456 /* StringMapping */)) {
                    return strictNullChecks ? 16317953 /* StringStrictFacts */ : 16776705 /* StringFacts */;
                }
                if (flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */)) {
                    const isEmpty = flags & 128 /* StringLiteral */ && type.value === "";
                    return strictNullChecks ? isEmpty ? 12123649 /* EmptyStringStrictFacts */ : 7929345 /* NonEmptyStringStrictFacts */ : isEmpty ? 12582401 /* EmptyStringFacts */ : 16776705 /* NonEmptyStringFacts */;
                }
                if (flags & (8 /* Number */ | 32 /* Enum */)) {
                    return strictNullChecks ? 16317698 /* NumberStrictFacts */ : 16776450 /* NumberFacts */;
                }
                if (flags & 256 /* NumberLiteral */) {
                    const isZero = type.value === 0;
                    return strictNullChecks ? isZero ? 12123394 /* ZeroNumberStrictFacts */ : 7929090 /* NonZeroNumberStrictFacts */ : isZero ? 12582146 /* ZeroNumberFacts */ : 16776450 /* NonZeroNumberFacts */;
                }
                if (flags & 64 /* BigInt */) {
                    return strictNullChecks ? 16317188 /* BigIntStrictFacts */ : 16775940 /* BigIntFacts */;
                }
                if (flags & 2048 /* BigIntLiteral */) {
                    const isZero = isZeroBigInt(type);
                    return strictNullChecks ? isZero ? 12122884 /* ZeroBigIntStrictFacts */ : 7928580 /* NonZeroBigIntStrictFacts */ : isZero ? 12581636 /* ZeroBigIntFacts */ : 16775940 /* NonZeroBigIntFacts */;
                }
                if (flags & 16 /* Boolean */) {
                    return strictNullChecks ? 16316168 /* BooleanStrictFacts */ : 16774920 /* BooleanFacts */;
                }
                if (flags & 528 /* BooleanLike */) {
                    return strictNullChecks ? type === falseType || type === regularFalseType ? 12121864 /* FalseStrictFacts */ : 7927560 /* TrueStrictFacts */ : type === falseType || type === regularFalseType ? 12580616 /* FalseFacts */ : 16774920 /* TrueFacts */;
                }
                if (flags & 524288 /* Object */) {
                    return getObjectFlags(type) & 16 /* Anonymous */ && isEmptyObjectType(type) ? strictNullChecks ? 83427327 /* EmptyObjectStrictFacts */ : 83886079 /* EmptyObjectFacts */ : isFunctionObjectType(type) ? strictNullChecks ? 7880640 /* FunctionStrictFacts */ : 16728e3 /* FunctionFacts */ : strictNullChecks ? 7888800 /* ObjectStrictFacts */ : 16736160 /* ObjectFacts */;
                }
                if (flags & 16384 /* Void */) {
                    return 9830144 /* VoidFacts */;
                }
                if (flags & 32768 /* Undefined */) {
                    return 26607360 /* UndefinedFacts */;
                }
                if (flags & 65536 /* Null */) {
                    return 42917664 /* NullFacts */;
                }
                if (flags & 12288 /* ESSymbolLike */) {
                    return strictNullChecks ? 7925520 /* SymbolStrictFacts */ : 16772880 /* SymbolFacts */;
                }
                if (flags & 67108864 /* NonPrimitive */) {
                    return strictNullChecks ? 7888800 /* ObjectStrictFacts */ : 16736160 /* ObjectFacts */;
                }
                if (flags & 131072 /* Never */) {
                    return 0 /* None */;
                }
                if (flags & 1048576 /* Union */) {
                    return reduceLeft(type.types, (facts, t) => facts | getTypeFacts(t), 0 /* None */);
                }
                if (flags & 2097152 /* Intersection */) {
                    return getIntersectionTypeFacts(type);
                }
                return 83886079 /* UnknownFacts */;
            }
            function getIntersectionTypeFacts(type) {
                const ignoreObjects = maybeTypeOfKind(type, 134348796 /* Primitive */);
                let oredFacts = 0 /* None */;
                let andedFacts = 134217727 /* All */;
                for (const t of type.types) {
                    if (!(ignoreObjects && t.flags & 524288 /* Object */)) {
                        const f = getTypeFacts(t);
                        oredFacts |= f;
                        andedFacts &= f;
                    }
                }
                return oredFacts & 8256 /* OrFactsMask */ | andedFacts & 134209471 /* AndFactsMask */;
            }
            function getTypeWithFacts(type, include) {
                return filterType(type, (t) => (getTypeFacts(t) & include) !== 0);
            }
            function getAdjustedTypeWithFacts(type, facts) {
                const reduced = recombineUnknownType(getTypeWithFacts(strictNullChecks && type.flags & 2 /* Unknown */ ? unknownUnionType : type, facts));
                if (strictNullChecks) {
                    switch (facts) {
                        case 524288 /* NEUndefined */:
                            return mapType(reduced, (t) => getTypeFacts(t) & 65536 /* EQUndefined */ ? getIntersectionType([t, getTypeFacts(t) & 131072 /* EQNull */ && !maybeTypeOfKind(reduced, 65536 /* Null */) ? getUnionType([emptyObjectType, nullType]) : emptyObjectType]) : t);
                        case 1048576 /* NENull */:
                            return mapType(reduced, (t) => getTypeFacts(t) & 131072 /* EQNull */ ? getIntersectionType([t, getTypeFacts(t) & 65536 /* EQUndefined */ && !maybeTypeOfKind(reduced, 32768 /* Undefined */) ? getUnionType([emptyObjectType, undefinedType]) : emptyObjectType]) : t);
                        case 2097152 /* NEUndefinedOrNull */:
                        case 4194304 /* Truthy */:
                            return mapType(reduced, (t) => getTypeFacts(t) & 262144 /* EQUndefinedOrNull */ ? getGlobalNonNullableTypeInstantiation(t) : t);
                    }
                }
                return reduced;
            }
            function recombineUnknownType(type) {
                return type === unknownUnionType ? unknownType : type;
            }
            function getTypeWithDefault(type, defaultExpression) {
                return defaultExpression ? getUnionType([getNonUndefinedType(type), getTypeOfExpression(defaultExpression)]) : type;
            }
            function getTypeOfDestructuredProperty(type, name) {
                var _a2;
                const nameType = getLiteralTypeFromPropertyName(name);
                if (!isTypeUsableAsPropertyName(nameType))
                    return errorType;
                const text = getPropertyNameFromType(nameType);
                return getTypeOfPropertyOfType(type, text) || includeUndefinedInIndexSignature((_a2 = getApplicableIndexInfoForName(type, text)) == null ? void 0 : _a2.type) || errorType;
            }
            function getTypeOfDestructuredArrayElement(type, index) {
                return everyType(type, isTupleLikeType) && getTupleElementType(type, index) || includeUndefinedInIndexSignature(checkIteratedTypeOrElementType(65 /* Destructuring */, type, undefinedType, 
                /*errorNode*/
                void 0)) || errorType;
            }
            function includeUndefinedInIndexSignature(type) {
                if (!type)
                    return type;
                return compilerOptions.noUncheckedIndexedAccess ? getUnionType([type, missingType]) : type;
            }
            function getTypeOfDestructuredSpreadExpression(type) {
                return createArrayType(checkIteratedTypeOrElementType(65 /* Destructuring */, type, undefinedType, 
                /*errorNode*/
                void 0) || errorType);
            }
            function getAssignedTypeOfBinaryExpression(node) {
                const isDestructuringDefaultAssignment = node.parent.kind === 206 /* ArrayLiteralExpression */ && isDestructuringAssignmentTarget(node.parent) || node.parent.kind === 299 /* PropertyAssignment */ && isDestructuringAssignmentTarget(node.parent.parent);
                return isDestructuringDefaultAssignment ? getTypeWithDefault(getAssignedType(node), node.right) : getTypeOfExpression(node.right);
            }
            function isDestructuringAssignmentTarget(parent2) {
                return parent2.parent.kind === 223 /* BinaryExpression */ && parent2.parent.left === parent2 || parent2.parent.kind === 247 /* ForOfStatement */ && parent2.parent.initializer === parent2;
            }
            function getAssignedTypeOfArrayLiteralElement(node, element) {
                return getTypeOfDestructuredArrayElement(getAssignedType(node), node.elements.indexOf(element));
            }
            function getAssignedTypeOfSpreadExpression(node) {
                return getTypeOfDestructuredSpreadExpression(getAssignedType(node.parent));
            }
            function getAssignedTypeOfPropertyAssignment(node) {
                return getTypeOfDestructuredProperty(getAssignedType(node.parent), node.name);
            }
            function getAssignedTypeOfShorthandPropertyAssignment(node) {
                return getTypeWithDefault(getAssignedTypeOfPropertyAssignment(node), node.objectAssignmentInitializer);
            }
            function getAssignedType(node) {
                const { parent: parent2 } = node;
                switch (parent2.kind) {
                    case 246 /* ForInStatement */:
                        return stringType;
                    case 247 /* ForOfStatement */:
                        return checkRightHandSideOfForOf(parent2) || errorType;
                    case 223 /* BinaryExpression */:
                        return getAssignedTypeOfBinaryExpression(parent2);
                    case 217 /* DeleteExpression */:
                        return undefinedType;
                    case 206 /* ArrayLiteralExpression */:
                        return getAssignedTypeOfArrayLiteralElement(parent2, node);
                    case 227 /* SpreadElement */:
                        return getAssignedTypeOfSpreadExpression(parent2);
                    case 299 /* PropertyAssignment */:
                        return getAssignedTypeOfPropertyAssignment(parent2);
                    case 300 /* ShorthandPropertyAssignment */:
                        return getAssignedTypeOfShorthandPropertyAssignment(parent2);
                }
                return errorType;
            }
            function getInitialTypeOfBindingElement(node) {
                const pattern = node.parent;
                const parentType = getInitialType(pattern.parent);
                const type = pattern.kind === 203 /* ObjectBindingPattern */ ? getTypeOfDestructuredProperty(parentType, node.propertyName || node.name) : !node.dotDotDotToken ? getTypeOfDestructuredArrayElement(parentType, pattern.elements.indexOf(node)) : getTypeOfDestructuredSpreadExpression(parentType);
                return getTypeWithDefault(type, node.initializer);
            }
            function getTypeOfInitializer(node) {
                const links = getNodeLinks(node);
                return links.resolvedType || getTypeOfExpression(node);
            }
            function getInitialTypeOfVariableDeclaration(node) {
                if (node.initializer) {
                    return getTypeOfInitializer(node.initializer);
                }
                if (node.parent.parent.kind === 246 /* ForInStatement */) {
                    return stringType;
                }
                if (node.parent.parent.kind === 247 /* ForOfStatement */) {
                    return checkRightHandSideOfForOf(node.parent.parent) || errorType;
                }
                return errorType;
            }
            function getInitialType(node) {
                return node.kind === 257 /* VariableDeclaration */ ? getInitialTypeOfVariableDeclaration(node) : getInitialTypeOfBindingElement(node);
            }
            function isEmptyArrayAssignment(node) {
                return node.kind === 257 /* VariableDeclaration */ && node.initializer && isEmptyArrayLiteral2(node.initializer) || node.kind !== 205 /* BindingElement */ && node.parent.kind === 223 /* BinaryExpression */ && isEmptyArrayLiteral2(node.parent.right);
            }
            function getReferenceCandidate(node) {
                switch (node.kind) {
                    case 214 /* ParenthesizedExpression */:
                        return getReferenceCandidate(node.expression);
                    case 223 /* BinaryExpression */:
                        switch (node.operatorToken.kind) {
                            case 63 /* EqualsToken */:
                            case 75 /* BarBarEqualsToken */:
                            case 76 /* AmpersandAmpersandEqualsToken */:
                            case 77 /* QuestionQuestionEqualsToken */:
                                return getReferenceCandidate(node.left);
                            case 27 /* CommaToken */:
                                return getReferenceCandidate(node.right);
                        }
                }
                return node;
            }
            function getReferenceRoot(node) {
                const { parent: parent2 } = node;
                return parent2.kind === 214 /* ParenthesizedExpression */ || parent2.kind === 223 /* BinaryExpression */ && parent2.operatorToken.kind === 63 /* EqualsToken */ && parent2.left === node || parent2.kind === 223 /* BinaryExpression */ && parent2.operatorToken.kind === 27 /* CommaToken */ && parent2.right === node ? getReferenceRoot(parent2) : node;
            }
            function getTypeOfSwitchClause(clause) {
                if (clause.kind === 292 /* CaseClause */) {
                    return getRegularTypeOfLiteralType(getTypeOfExpression(clause.expression));
                }
                return neverType;
            }
            function getSwitchClauseTypes(switchStatement) {
                const links = getNodeLinks(switchStatement);
                if (!links.switchTypes) {
                    links.switchTypes = [];
                    for (const clause of switchStatement.caseBlock.clauses) {
                        links.switchTypes.push(getTypeOfSwitchClause(clause));
                    }
                }
                return links.switchTypes;
            }
            function getSwitchClauseTypeOfWitnesses(switchStatement) {
                if (some(switchStatement.caseBlock.clauses, (clause) => clause.kind === 292 /* CaseClause */ && !isStringLiteralLike(clause.expression))) {
                    return void 0;
                }
                const witnesses = [];
                for (const clause of switchStatement.caseBlock.clauses) {
                    const text = clause.kind === 292 /* CaseClause */ ? clause.expression.text : void 0;
                    witnesses.push(text && !contains(witnesses, text) ? text : void 0);
                }
                return witnesses;
            }
            function eachTypeContainedIn(source, types) {
                return source.flags & 1048576 /* Union */ ? !forEach(source.types, (t) => !contains(types, t)) : contains(types, source);
            }
            function isTypeSubsetOf(source, target) {
                return source === target || target.flags & 1048576 /* Union */ && isTypeSubsetOfUnion(source, target);
            }
            function isTypeSubsetOfUnion(source, target) {
                if (source.flags & 1048576 /* Union */) {
                    for (const t of source.types) {
                        if (!containsType(target.types, t)) {
                            return false;
                        }
                    }
                    return true;
                }
                if (source.flags & 1056 /* EnumLike */ && getBaseTypeOfEnumLikeType(source) === target) {
                    return true;
                }
                return containsType(target.types, source);
            }
            function forEachType(type, f) {
                return type.flags & 1048576 /* Union */ ? forEach(type.types, f) : f(type);
            }
            function someType(type, f) {
                return type.flags & 1048576 /* Union */ ? some(type.types, f) : f(type);
            }
            function everyType(type, f) {
                return type.flags & 1048576 /* Union */ ? every(type.types, f) : f(type);
            }
            function everyContainedType(type, f) {
                return type.flags & 3145728 /* UnionOrIntersection */ ? every(type.types, f) : f(type);
            }
            function filterType(type, f) {
                if (type.flags & 1048576 /* Union */) {
                    const types = type.types;
                    const filtered = filter(types, f);
                    if (filtered === types) {
                        return type;
                    }
                    const origin = type.origin;
                    let newOrigin;
                    if (origin && origin.flags & 1048576 /* Union */) {
                        const originTypes = origin.types;
                        const originFiltered = filter(originTypes, (t) => !!(t.flags & 1048576 /* Union */) || f(t));
                        if (originTypes.length - originFiltered.length === types.length - filtered.length) {
                            if (originFiltered.length === 1) {
                                return originFiltered[0];
                            }
                            newOrigin = createOriginUnionOrIntersectionType(1048576 /* Union */, originFiltered);
                        }
                    }
                    return getUnionTypeFromSortedList(filtered, type.objectFlags & (32768 /* PrimitiveUnion */ | 16777216 /* ContainsIntersections */), 
                    /*aliasSymbol*/
                    void 0, 
                    /*aliasTypeArguments*/
                    void 0, newOrigin);
                }
                return type.flags & 131072 /* Never */ || f(type) ? type : neverType;
            }
            function removeType(type, targetType) {
                return filterType(type, (t) => t !== targetType);
            }
            function countTypes(type) {
                return type.flags & 1048576 /* Union */ ? type.types.length : 1;
            }
            function mapType(type, mapper, noReductions) {
                if (type.flags & 131072 /* Never */) {
                    return type;
                }
                if (!(type.flags & 1048576 /* Union */)) {
                    return mapper(type);
                }
                const origin = type.origin;
                const types = origin && origin.flags & 1048576 /* Union */ ? origin.types : type.types;
                let mappedTypes;
                let changed = false;
                for (const t of types) {
                    const mapped = t.flags & 1048576 /* Union */ ? mapType(t, mapper, noReductions) : mapper(t);
                    changed || (changed = t !== mapped);
                    if (mapped) {
                        if (!mappedTypes) {
                            mappedTypes = [mapped];
                        }
                        else {
                            mappedTypes.push(mapped);
                        }
                    }
                }
                return changed ? mappedTypes && getUnionType(mappedTypes, noReductions ? 0 /* None */ : 1 /* Literal */) : type;
            }
            function mapTypeWithAlias(type, mapper, aliasSymbol, aliasTypeArguments) {
                return type.flags & 1048576 /* Union */ && aliasSymbol ? getUnionType(map(type.types, mapper), 1 /* Literal */, aliasSymbol, aliasTypeArguments) : mapType(type, mapper);
            }
            function extractTypesOfKind(type, kind) {
                return filterType(type, (t) => (t.flags & kind) !== 0);
            }
            function replacePrimitivesWithLiterals(typeWithPrimitives, typeWithLiterals) {
                if (maybeTypeOfKind(typeWithPrimitives, 4 /* String */ | 134217728 /* TemplateLiteral */ | 8 /* Number */ | 64 /* BigInt */) && maybeTypeOfKind(typeWithLiterals, 128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */ | 256 /* NumberLiteral */ | 2048 /* BigIntLiteral */)) {
                    return mapType(typeWithPrimitives, (t) => t.flags & 4 /* String */ ? extractTypesOfKind(typeWithLiterals, 4 /* String */ | 128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) : isPatternLiteralType(t) && !maybeTypeOfKind(typeWithLiterals, 4 /* String */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) ? extractTypesOfKind(typeWithLiterals, 128 /* StringLiteral */) : t.flags & 8 /* Number */ ? extractTypesOfKind(typeWithLiterals, 8 /* Number */ | 256 /* NumberLiteral */) : t.flags & 64 /* BigInt */ ? extractTypesOfKind(typeWithLiterals, 64 /* BigInt */ | 2048 /* BigIntLiteral */) : t);
                }
                return typeWithPrimitives;
            }
            function isIncomplete(flowType) {
                return flowType.flags === 0;
            }
            function getTypeFromFlowType(flowType) {
                return flowType.flags === 0 ? flowType.type : flowType;
            }
            function createFlowType(type, incomplete) {
                return incomplete ? { flags: 0, type: type.flags & 131072 /* Never */ ? silentNeverType : type } : type;
            }
            function createEvolvingArrayType(elementType) {
                const result = createObjectType(256 /* EvolvingArray */);
                result.elementType = elementType;
                return result;
            }
            function getEvolvingArrayType(elementType) {
                return evolvingArrayTypes[elementType.id] || (evolvingArrayTypes[elementType.id] = createEvolvingArrayType(elementType));
            }
            function addEvolvingArrayElementType(evolvingArrayType, node) {
                const elementType = getRegularTypeOfObjectLiteral(getBaseTypeOfLiteralType(getContextFreeTypeOfExpression(node)));
                return isTypeSubsetOf(elementType, evolvingArrayType.elementType) ? evolvingArrayType : getEvolvingArrayType(getUnionType([evolvingArrayType.elementType, elementType]));
            }
            function createFinalArrayType(elementType) {
                return elementType.flags & 131072 /* Never */ ? autoArrayType : createArrayType(elementType.flags & 1048576 /* Union */ ? getUnionType(elementType.types, 2 /* Subtype */) : elementType);
            }
            function getFinalArrayType(evolvingArrayType) {
                return evolvingArrayType.finalArrayType || (evolvingArrayType.finalArrayType = createFinalArrayType(evolvingArrayType.elementType));
            }
            function finalizeEvolvingArrayType(type) {
                return getObjectFlags(type) & 256 /* EvolvingArray */ ? getFinalArrayType(type) : type;
            }
            function getElementTypeOfEvolvingArrayType(type) {
                return getObjectFlags(type) & 256 /* EvolvingArray */ ? type.elementType : neverType;
            }
            function isEvolvingArrayTypeList(types) {
                let hasEvolvingArrayType = false;
                for (const t of types) {
                    if (!(t.flags & 131072 /* Never */)) {
                        if (!(getObjectFlags(t) & 256 /* EvolvingArray */)) {
                            return false;
                        }
                        hasEvolvingArrayType = true;
                    }
                }
                return hasEvolvingArrayType;
            }
            function isEvolvingArrayOperationTarget(node) {
                const root = getReferenceRoot(node);
                const parent2 = root.parent;
                const isLengthPushOrUnshift = isPropertyAccessExpression(parent2) && (parent2.name.escapedText === "length" || parent2.parent.kind === 210 /* CallExpression */ && isIdentifier(parent2.name) && isPushOrUnshiftIdentifier(parent2.name));
                const isElementAssignment = parent2.kind === 209 /* ElementAccessExpression */ && parent2.expression === root && parent2.parent.kind === 223 /* BinaryExpression */ && parent2.parent.operatorToken.kind === 63 /* EqualsToken */ && parent2.parent.left === parent2 && !isAssignmentTarget(parent2.parent) && isTypeAssignableToKind(getTypeOfExpression(parent2.argumentExpression), 296 /* NumberLike */);
                return isLengthPushOrUnshift || isElementAssignment;
            }
            function isDeclarationWithExplicitTypeAnnotation(node) {
                return (isVariableDeclaration(node) || isPropertyDeclaration(node) || isPropertySignature(node) || isParameter(node)) && !!(getEffectiveTypeAnnotationNode(node) || isInJSFile(node) && hasInitializer(node) && node.initializer && isFunctionExpressionOrArrowFunction(node.initializer) && getEffectiveReturnTypeNode(node.initializer));
            }
            function getExplicitTypeOfSymbol(symbol, diagnostic) {
                symbol = resolveSymbol(symbol);
                if (symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 512 /* ValueModule */)) {
                    return getTypeOfSymbol(symbol);
                }
                if (symbol.flags & (3 /* Variable */ | 4 /* Property */)) {
                    if (getCheckFlags(symbol) & 262144 /* Mapped */) {
                        const origin = symbol.links.syntheticOrigin;
                        if (origin && getExplicitTypeOfSymbol(origin)) {
                            return getTypeOfSymbol(symbol);
                        }
                    }
                    const declaration = symbol.valueDeclaration;
                    if (declaration) {
                        if (isDeclarationWithExplicitTypeAnnotation(declaration)) {
                            return getTypeOfSymbol(symbol);
                        }
                        if (isVariableDeclaration(declaration) && declaration.parent.parent.kind === 247 /* ForOfStatement */) {
                            const statement = declaration.parent.parent;
                            const expressionType = getTypeOfDottedName(statement.expression, 
                            /*diagnostic*/
                            void 0);
                            if (expressionType) {
                                const use = statement.awaitModifier ? 15 /* ForAwaitOf */ : 13 /* ForOf */;
                                return checkIteratedTypeOrElementType(use, expressionType, undefinedType, 
                                /*errorNode*/
                                void 0);
                            }
                        }
                        if (diagnostic) {
                            addRelatedInfo(diagnostic, createDiagnosticForNode(declaration, Diagnostics._0_needs_an_explicit_type_annotation, symbolToString(symbol)));
                        }
                    }
                }
            }
            function getTypeOfDottedName(node, diagnostic) {
                if (!(node.flags & 33554432 /* InWithStatement */)) {
                    switch (node.kind) {
                        case 79 /* Identifier */:
                            const symbol = getExportSymbolOfValueSymbolIfExported(getResolvedSymbol(node));
                            return getExplicitTypeOfSymbol(symbol, diagnostic);
                        case 108 /* ThisKeyword */:
                            return getExplicitThisType(node);
                        case 106 /* SuperKeyword */:
                            return checkSuperExpression(node);
                        case 208 /* PropertyAccessExpression */: {
                            const type = getTypeOfDottedName(node.expression, diagnostic);
                            if (type) {
                                const name = node.name;
                                let prop;
                                if (isPrivateIdentifier(name)) {
                                    if (!type.symbol) {
                                        return void 0;
                                    }
                                    prop = getPropertyOfType(type, getSymbolNameForPrivateIdentifier(type.symbol, name.escapedText));
                                }
                                else {
                                    prop = getPropertyOfType(type, name.escapedText);
                                }
                                return prop && getExplicitTypeOfSymbol(prop, diagnostic);
                            }
                            return void 0;
                        }
                        case 214 /* ParenthesizedExpression */:
                            return getTypeOfDottedName(node.expression, diagnostic);
                    }
                }
            }
            function getEffectsSignature(node) {
                const links = getNodeLinks(node);
                let signature = links.effectsSignature;
                if (signature === void 0) {
                    let funcType;
                    if (node.parent.kind === 241 /* ExpressionStatement */) {
                        funcType = getTypeOfDottedName(node.expression, 
                        /*diagnostic*/
                        void 0);
                    }
                    else if (node.expression.kind !== 106 /* SuperKeyword */) {
                        if (isOptionalChain(node)) {
                            funcType = checkNonNullType(getOptionalExpressionType(checkExpression(node.expression), node.expression), node.expression);
                        }
                        else {
                            funcType = checkNonNullExpression(node.expression);
                        }
                    }
                    const signatures = getSignaturesOfType(funcType && getApparentType(funcType) || unknownType, 0 /* Call */);
                    const candidate = signatures.length === 1 && !signatures[0].typeParameters ? signatures[0] : some(signatures, hasTypePredicateOrNeverReturnType) ? getResolvedSignature(node) : void 0;
                    signature = links.effectsSignature = candidate && hasTypePredicateOrNeverReturnType(candidate) ? candidate : unknownSignature;
                }
                return signature === unknownSignature ? void 0 : signature;
            }
            function hasTypePredicateOrNeverReturnType(signature) {
                return !!(getTypePredicateOfSignature(signature) || signature.declaration && (getReturnTypeFromAnnotation(signature.declaration) || unknownType).flags & 131072 /* Never */);
            }
            function getTypePredicateArgument(predicate, callExpression) {
                if (predicate.kind === 1 /* Identifier */ || predicate.kind === 3 /* AssertsIdentifier */) {
                    return callExpression.arguments[predicate.parameterIndex];
                }
                const invokedExpression = skipParentheses(callExpression.expression);
                return isAccessExpression(invokedExpression) ? skipParentheses(invokedExpression.expression) : void 0;
            }
            function reportFlowControlError(node) {
                const block = findAncestor(node, isFunctionOrModuleBlock);
                const sourceFile = getSourceFileOfNode(node);
                const span = getSpanOfTokenAtPosition(sourceFile, block.statements.pos);
                diagnostics.add(createFileDiagnostic(sourceFile, span.start, span.length, Diagnostics.The_containing_function_or_module_body_is_too_large_for_control_flow_analysis));
            }
            function isReachableFlowNode(flow) {
                const result = isReachableFlowNodeWorker(flow, 
                /*noCacheCheck*/
                false);
                lastFlowNode = flow;
                lastFlowNodeReachable = result;
                return result;
            }
            function isFalseExpression(expr) {
                const node = skipParentheses(expr, 
                /*excludeJSDocTypeAssertions*/
                true);
                return node.kind === 95 /* FalseKeyword */ || node.kind === 223 /* BinaryExpression */ && (node.operatorToken.kind === 55 /* AmpersandAmpersandToken */ && (isFalseExpression(node.left) || isFalseExpression(node.right)) || node.operatorToken.kind === 56 /* BarBarToken */ && isFalseExpression(node.left) && isFalseExpression(node.right));
            }
            function isReachableFlowNodeWorker(flow, noCacheCheck) {
                while (true) {
                    if (flow === lastFlowNode) {
                        return lastFlowNodeReachable;
                    }
                    const flags = flow.flags;
                    if (flags & 4096 /* Shared */) {
                        if (!noCacheCheck) {
                            const id = getFlowNodeId(flow);
                            const reachable = flowNodeReachable[id];
                            return reachable !== void 0 ? reachable : flowNodeReachable[id] = isReachableFlowNodeWorker(flow, 
                            /*noCacheCheck*/
                            true);
                        }
                        noCacheCheck = false;
                    }
                    if (flags & (16 /* Assignment */ | 96 /* Condition */ | 256 /* ArrayMutation */)) {
                        flow = flow.antecedent;
                    }
                    else if (flags & 512 /* Call */) {
                        const signature = getEffectsSignature(flow.node);
                        if (signature) {
                            const predicate = getTypePredicateOfSignature(signature);
                            if (predicate && predicate.kind === 3 /* AssertsIdentifier */ && !predicate.type) {
                                const predicateArgument = flow.node.arguments[predicate.parameterIndex];
                                if (predicateArgument && isFalseExpression(predicateArgument)) {
                                    return false;
                                }
                            }
                            if (getReturnTypeOfSignature(signature).flags & 131072 /* Never */) {
                                return false;
                            }
                        }
                        flow = flow.antecedent;
                    }
                    else if (flags & 4 /* BranchLabel */) {
                        return some(flow.antecedents, (f) => isReachableFlowNodeWorker(f, 
                        /*noCacheCheck*/
                        false));
                    }
                    else if (flags & 8 /* LoopLabel */) {
                        const antecedents = flow.antecedents;
                        if (antecedents === void 0 || antecedents.length === 0) {
                            return false;
                        }
                        flow = antecedents[0];
                    }
                    else if (flags & 128 /* SwitchClause */) {
                        if (flow.clauseStart === flow.clauseEnd && isExhaustiveSwitchStatement(flow.switchStatement)) {
                            return false;
                        }
                        flow = flow.antecedent;
                    }
                    else if (flags & 1024 /* ReduceLabel */) {
                        lastFlowNode = void 0;
                        const target = flow.target;
                        const saveAntecedents = target.antecedents;
                        target.antecedents = flow.antecedents;
                        const result = isReachableFlowNodeWorker(flow.antecedent, 
                        /*noCacheCheck*/
                        false);
                        target.antecedents = saveAntecedents;
                        return result;
                    }
                    else {
                        return !(flags & 1 /* Unreachable */);
                    }
                }
            }
            function isPostSuperFlowNode(flow, noCacheCheck) {
                while (true) {
                    const flags = flow.flags;
                    if (flags & 4096 /* Shared */) {
                        if (!noCacheCheck) {
                            const id = getFlowNodeId(flow);
                            const postSuper = flowNodePostSuper[id];
                            return postSuper !== void 0 ? postSuper : flowNodePostSuper[id] = isPostSuperFlowNode(flow, 
                            /*noCacheCheck*/
                            true);
                        }
                        noCacheCheck = false;
                    }
                    if (flags & (16 /* Assignment */ | 96 /* Condition */ | 256 /* ArrayMutation */ | 128 /* SwitchClause */)) {
                        flow = flow.antecedent;
                    }
                    else if (flags & 512 /* Call */) {
                        if (flow.node.expression.kind === 106 /* SuperKeyword */) {
                            return true;
                        }
                        flow = flow.antecedent;
                    }
                    else if (flags & 4 /* BranchLabel */) {
                        return every(flow.antecedents, (f) => isPostSuperFlowNode(f, 
                        /*noCacheCheck*/
                        false));
                    }
                    else if (flags & 8 /* LoopLabel */) {
                        flow = flow.antecedents[0];
                    }
                    else if (flags & 1024 /* ReduceLabel */) {
                        const target = flow.target;
                        const saveAntecedents = target.antecedents;
                        target.antecedents = flow.antecedents;
                        const result = isPostSuperFlowNode(flow.antecedent, 
                        /*noCacheCheck*/
                        false);
                        target.antecedents = saveAntecedents;
                        return result;
                    }
                    else {
                        return !!(flags & 1 /* Unreachable */);
                    }
                }
            }
            function isConstantReference(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        if (!isThisInTypeQuery(node)) {
                            const symbol = getResolvedSymbol(node);
                            return isConstVariable(symbol) || isParameterOrCatchClauseVariable(symbol) && !isSymbolAssigned(symbol);
                        }
                        break;
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        return isConstantReference(node.expression) && isReadonlySymbol(getNodeLinks(node).resolvedSymbol || unknownSymbol);
                }
                return false;
            }
            function getFlowTypeOfReference(reference, declaredType, initialType = declaredType, flowContainer, flowNode = ((_a2) => (_a2 = tryCast(reference, canHaveFlowNode)) == null ? void 0 : _a2.flowNode)()) {
                let key;
                let isKeySet = false;
                let flowDepth = 0;
                if (flowAnalysisDisabled) {
                    return errorType;
                }
                if (!flowNode) {
                    return declaredType;
                }
                flowInvocationCount++;
                const sharedFlowStart = sharedFlowCount;
                const evolvedType = getTypeFromFlowType(getTypeAtFlowNode(flowNode));
                sharedFlowCount = sharedFlowStart;
                const resultType = getObjectFlags(evolvedType) & 256 /* EvolvingArray */ && isEvolvingArrayOperationTarget(reference) ? autoArrayType : finalizeEvolvingArrayType(evolvedType);
                if (resultType === unreachableNeverType || reference.parent && reference.parent.kind === 232 /* NonNullExpression */ && !(resultType.flags & 131072 /* Never */) && getTypeWithFacts(resultType, 2097152 /* NEUndefinedOrNull */).flags & 131072 /* Never */) {
                    return declaredType;
                }
                return resultType === nonNullUnknownType ? unknownType : resultType;
                function getOrSetCacheKey() {
                    if (isKeySet) {
                        return key;
                    }
                    isKeySet = true;
                    return key = getFlowCacheKey(reference, declaredType, initialType, flowContainer);
                }
                function getTypeAtFlowNode(flow) {
                    var _a3;
                    if (flowDepth === 2e3) {
                        (_a3 = tracing) == null ? void 0 : _a3.instant(tracing.Phase.CheckTypes, "getTypeAtFlowNode_DepthLimit", { flowId: flow.id });
                        flowAnalysisDisabled = true;
                        reportFlowControlError(reference);
                        return errorType;
                    }
                    flowDepth++;
                    let sharedFlow;
                    while (true) {
                        const flags = flow.flags;
                        if (flags & 4096 /* Shared */) {
                            for (let i = sharedFlowStart; i < sharedFlowCount; i++) {
                                if (sharedFlowNodes[i] === flow) {
                                    flowDepth--;
                                    return sharedFlowTypes[i];
                                }
                            }
                            sharedFlow = flow;
                        }
                        let type;
                        if (flags & 16 /* Assignment */) {
                            type = getTypeAtFlowAssignment(flow);
                            if (!type) {
                                flow = flow.antecedent;
                                continue;
                            }
                        }
                        else if (flags & 512 /* Call */) {
                            type = getTypeAtFlowCall(flow);
                            if (!type) {
                                flow = flow.antecedent;
                                continue;
                            }
                        }
                        else if (flags & 96 /* Condition */) {
                            type = getTypeAtFlowCondition(flow);
                        }
                        else if (flags & 128 /* SwitchClause */) {
                            type = getTypeAtSwitchClause(flow);
                        }
                        else if (flags & 12 /* Label */) {
                            if (flow.antecedents.length === 1) {
                                flow = flow.antecedents[0];
                                continue;
                            }
                            type = flags & 4 /* BranchLabel */ ? getTypeAtFlowBranchLabel(flow) : getTypeAtFlowLoopLabel(flow);
                        }
                        else if (flags & 256 /* ArrayMutation */) {
                            type = getTypeAtFlowArrayMutation(flow);
                            if (!type) {
                                flow = flow.antecedent;
                                continue;
                            }
                        }
                        else if (flags & 1024 /* ReduceLabel */) {
                            const target = flow.target;
                            const saveAntecedents = target.antecedents;
                            target.antecedents = flow.antecedents;
                            type = getTypeAtFlowNode(flow.antecedent);
                            target.antecedents = saveAntecedents;
                        }
                        else if (flags & 2 /* Start */) {
                            const container = flow.node;
                            if (container && container !== flowContainer && reference.kind !== 208 /* PropertyAccessExpression */ && reference.kind !== 209 /* ElementAccessExpression */ && reference.kind !== 108 /* ThisKeyword */) {
                                flow = container.flowNode;
                                continue;
                            }
                            type = initialType;
                        }
                        else {
                            type = convertAutoToAny(declaredType);
                        }
                        if (sharedFlow) {
                            sharedFlowNodes[sharedFlowCount] = sharedFlow;
                            sharedFlowTypes[sharedFlowCount] = type;
                            sharedFlowCount++;
                        }
                        flowDepth--;
                        return type;
                    }
                }
                function getInitialOrAssignedType(flow) {
                    const node = flow.node;
                    return getNarrowableTypeForReference(node.kind === 257 /* VariableDeclaration */ || node.kind === 205 /* BindingElement */ ? getInitialType(node) : getAssignedType(node), reference);
                }
                function getTypeAtFlowAssignment(flow) {
                    const node = flow.node;
                    if (isMatchingReference(reference, node)) {
                        if (!isReachableFlowNode(flow)) {
                            return unreachableNeverType;
                        }
                        if (getAssignmentTargetKind(node) === 2 /* Compound */) {
                            const flowType = getTypeAtFlowNode(flow.antecedent);
                            return createFlowType(getBaseTypeOfLiteralType(getTypeFromFlowType(flowType)), isIncomplete(flowType));
                        }
                        if (declaredType === autoType || declaredType === autoArrayType) {
                            if (isEmptyArrayAssignment(node)) {
                                return getEvolvingArrayType(neverType);
                            }
                            const assignedType = getWidenedLiteralType(getInitialOrAssignedType(flow));
                            return isTypeAssignableTo(assignedType, declaredType) ? assignedType : anyArrayType;
                        }
                        if (declaredType.flags & 1048576 /* Union */) {
                            return getAssignmentReducedType(declaredType, getInitialOrAssignedType(flow));
                        }
                        return declaredType;
                    }
                    if (containsMatchingReference(reference, node)) {
                        if (!isReachableFlowNode(flow)) {
                            return unreachableNeverType;
                        }
                        if (isVariableDeclaration(node) && (isInJSFile(node) || isVarConst(node))) {
                            const init = getDeclaredExpandoInitializer(node);
                            if (init && (init.kind === 215 /* FunctionExpression */ || init.kind === 216 /* ArrowFunction */)) {
                                return getTypeAtFlowNode(flow.antecedent);
                            }
                        }
                        return declaredType;
                    }
                    if (isVariableDeclaration(node) && node.parent.parent.kind === 246 /* ForInStatement */ && (isMatchingReference(reference, node.parent.parent.expression) || optionalChainContainsReference(node.parent.parent.expression, reference))) {
                        return getNonNullableTypeIfNeeded(finalizeEvolvingArrayType(getTypeFromFlowType(getTypeAtFlowNode(flow.antecedent))));
                    }
                    return void 0;
                }
                function narrowTypeByAssertion(type, expr) {
                    const node = skipParentheses(expr, 
                    /*excludeJSDocTypeAssertions*/
                    true);
                    if (node.kind === 95 /* FalseKeyword */) {
                        return unreachableNeverType;
                    }
                    if (node.kind === 223 /* BinaryExpression */) {
                        if (node.operatorToken.kind === 55 /* AmpersandAmpersandToken */) {
                            return narrowTypeByAssertion(narrowTypeByAssertion(type, node.left), node.right);
                        }
                        if (node.operatorToken.kind === 56 /* BarBarToken */) {
                            return getUnionType([narrowTypeByAssertion(type, node.left), narrowTypeByAssertion(type, node.right)]);
                        }
                    }
                    return narrowType(type, node, 
                    /*assumeTrue*/
                    true);
                }
                function getTypeAtFlowCall(flow) {
                    const signature = getEffectsSignature(flow.node);
                    if (signature) {
                        const predicate = getTypePredicateOfSignature(signature);
                        if (predicate && (predicate.kind === 2 /* AssertsThis */ || predicate.kind === 3 /* AssertsIdentifier */)) {
                            const flowType = getTypeAtFlowNode(flow.antecedent);
                            const type = finalizeEvolvingArrayType(getTypeFromFlowType(flowType));
                            const narrowedType = predicate.type ? narrowTypeByTypePredicate(type, predicate, flow.node, 
                            /*assumeTrue*/
                            true) : predicate.kind === 3 /* AssertsIdentifier */ && predicate.parameterIndex >= 0 && predicate.parameterIndex < flow.node.arguments.length ? narrowTypeByAssertion(type, flow.node.arguments[predicate.parameterIndex]) : type;
                            return narrowedType === type ? flowType : createFlowType(narrowedType, isIncomplete(flowType));
                        }
                        if (getReturnTypeOfSignature(signature).flags & 131072 /* Never */) {
                            return unreachableNeverType;
                        }
                    }
                    return void 0;
                }
                function getTypeAtFlowArrayMutation(flow) {
                    if (declaredType === autoType || declaredType === autoArrayType) {
                        const node = flow.node;
                        const expr = node.kind === 210 /* CallExpression */ ? node.expression.expression : node.left.expression;
                        if (isMatchingReference(reference, getReferenceCandidate(expr))) {
                            const flowType = getTypeAtFlowNode(flow.antecedent);
                            const type = getTypeFromFlowType(flowType);
                            if (getObjectFlags(type) & 256 /* EvolvingArray */) {
                                let evolvedType2 = type;
                                if (node.kind === 210 /* CallExpression */) {
                                    for (const arg of node.arguments) {
                                        evolvedType2 = addEvolvingArrayElementType(evolvedType2, arg);
                                    }
                                }
                                else {
                                    const indexType = getContextFreeTypeOfExpression(node.left.argumentExpression);
                                    if (isTypeAssignableToKind(indexType, 296 /* NumberLike */)) {
                                        evolvedType2 = addEvolvingArrayElementType(evolvedType2, node.right);
                                    }
                                }
                                return evolvedType2 === type ? flowType : createFlowType(evolvedType2, isIncomplete(flowType));
                            }
                            return flowType;
                        }
                    }
                    return void 0;
                }
                function getTypeAtFlowCondition(flow) {
                    const flowType = getTypeAtFlowNode(flow.antecedent);
                    const type = getTypeFromFlowType(flowType);
                    if (type.flags & 131072 /* Never */) {
                        return flowType;
                    }
                    const assumeTrue = (flow.flags & 32 /* TrueCondition */) !== 0;
                    const nonEvolvingType = finalizeEvolvingArrayType(type);
                    const narrowedType = narrowType(nonEvolvingType, flow.node, assumeTrue);
                    if (narrowedType === nonEvolvingType) {
                        return flowType;
                    }
                    return createFlowType(narrowedType, isIncomplete(flowType));
                }
                function getTypeAtSwitchClause(flow) {
                    const expr = flow.switchStatement.expression;
                    const flowType = getTypeAtFlowNode(flow.antecedent);
                    let type = getTypeFromFlowType(flowType);
                    if (isMatchingReference(reference, expr)) {
                        type = narrowTypeBySwitchOnDiscriminant(type, flow.switchStatement, flow.clauseStart, flow.clauseEnd);
                    }
                    else if (expr.kind === 218 /* TypeOfExpression */ && isMatchingReference(reference, expr.expression)) {
                        type = narrowTypeBySwitchOnTypeOf(type, flow.switchStatement, flow.clauseStart, flow.clauseEnd);
                    }
                    else {
                        if (strictNullChecks) {
                            if (optionalChainContainsReference(expr, reference)) {
                                type = narrowTypeBySwitchOptionalChainContainment(type, flow.switchStatement, flow.clauseStart, flow.clauseEnd, (t) => !(t.flags & (32768 /* Undefined */ | 131072 /* Never */)));
                            }
                            else if (expr.kind === 218 /* TypeOfExpression */ && optionalChainContainsReference(expr.expression, reference)) {
                                type = narrowTypeBySwitchOptionalChainContainment(type, flow.switchStatement, flow.clauseStart, flow.clauseEnd, (t) => !(t.flags & 131072 /* Never */ || t.flags & 128 /* StringLiteral */ && t.value === "undefined"));
                            }
                        }
                        const access = getDiscriminantPropertyAccess(expr, type);
                        if (access) {
                            type = narrowTypeBySwitchOnDiscriminantProperty(type, access, flow.switchStatement, flow.clauseStart, flow.clauseEnd);
                        }
                    }
                    return createFlowType(type, isIncomplete(flowType));
                }
                function getTypeAtFlowBranchLabel(flow) {
                    const antecedentTypes = [];
                    let subtypeReduction = false;
                    let seenIncomplete = false;
                    let bypassFlow;
                    for (const antecedent of flow.antecedents) {
                        if (!bypassFlow && antecedent.flags & 128 /* SwitchClause */ && antecedent.clauseStart === antecedent.clauseEnd) {
                            bypassFlow = antecedent;
                            continue;
                        }
                        const flowType = getTypeAtFlowNode(antecedent);
                        const type = getTypeFromFlowType(flowType);
                        if (type === declaredType && declaredType === initialType) {
                            return type;
                        }
                        pushIfUnique(antecedentTypes, type);
                        if (!isTypeSubsetOf(type, declaredType)) {
                            subtypeReduction = true;
                        }
                        if (isIncomplete(flowType)) {
                            seenIncomplete = true;
                        }
                    }
                    if (bypassFlow) {
                        const flowType = getTypeAtFlowNode(bypassFlow);
                        const type = getTypeFromFlowType(flowType);
                        if (!(type.flags & 131072 /* Never */) && !contains(antecedentTypes, type) && !isExhaustiveSwitchStatement(bypassFlow.switchStatement)) {
                            if (type === declaredType && declaredType === initialType) {
                                return type;
                            }
                            antecedentTypes.push(type);
                            if (!isTypeSubsetOf(type, declaredType)) {
                                subtypeReduction = true;
                            }
                            if (isIncomplete(flowType)) {
                                seenIncomplete = true;
                            }
                        }
                    }
                    return createFlowType(getUnionOrEvolvingArrayType(antecedentTypes, subtypeReduction ? 2 /* Subtype */ : 1 /* Literal */), seenIncomplete);
                }
                function getTypeAtFlowLoopLabel(flow) {
                    const id = getFlowNodeId(flow);
                    const cache = flowLoopCaches[id] || (flowLoopCaches[id] = /* @__PURE__ */ new Map());
                    const key2 = getOrSetCacheKey();
                    if (!key2) {
                        return declaredType;
                    }
                    const cached = cache.get(key2);
                    if (cached) {
                        return cached;
                    }
                    for (let i = flowLoopStart; i < flowLoopCount; i++) {
                        if (flowLoopNodes[i] === flow && flowLoopKeys[i] === key2 && flowLoopTypes[i].length) {
                            return createFlowType(getUnionOrEvolvingArrayType(flowLoopTypes[i], 1 /* Literal */), 
                            /*incomplete*/
                            true);
                        }
                    }
                    const antecedentTypes = [];
                    let subtypeReduction = false;
                    let firstAntecedentType;
                    for (const antecedent of flow.antecedents) {
                        let flowType;
                        if (!firstAntecedentType) {
                            flowType = firstAntecedentType = getTypeAtFlowNode(antecedent);
                        }
                        else {
                            flowLoopNodes[flowLoopCount] = flow;
                            flowLoopKeys[flowLoopCount] = key2;
                            flowLoopTypes[flowLoopCount] = antecedentTypes;
                            flowLoopCount++;
                            const saveFlowTypeCache = flowTypeCache;
                            flowTypeCache = void 0;
                            flowType = getTypeAtFlowNode(antecedent);
                            flowTypeCache = saveFlowTypeCache;
                            flowLoopCount--;
                            const cached2 = cache.get(key2);
                            if (cached2) {
                                return cached2;
                            }
                        }
                        const type = getTypeFromFlowType(flowType);
                        pushIfUnique(antecedentTypes, type);
                        if (!isTypeSubsetOf(type, declaredType)) {
                            subtypeReduction = true;
                        }
                        if (type === declaredType) {
                            break;
                        }
                    }
                    const result = getUnionOrEvolvingArrayType(antecedentTypes, subtypeReduction ? 2 /* Subtype */ : 1 /* Literal */);
                    if (isIncomplete(firstAntecedentType)) {
                        return createFlowType(result, 
                        /*incomplete*/
                        true);
                    }
                    cache.set(key2, result);
                    return result;
                }
                function getUnionOrEvolvingArrayType(types, subtypeReduction) {
                    if (isEvolvingArrayTypeList(types)) {
                        return getEvolvingArrayType(getUnionType(map(types, getElementTypeOfEvolvingArrayType)));
                    }
                    const result = recombineUnknownType(getUnionType(sameMap(types, finalizeEvolvingArrayType), subtypeReduction));
                    if (result !== declaredType && result.flags & declaredType.flags & 1048576 /* Union */ && arraysEqual(result.types, declaredType.types)) {
                        return declaredType;
                    }
                    return result;
                }
                function getCandidateDiscriminantPropertyAccess(expr) {
                    if (isBindingPattern(reference) || isFunctionExpressionOrArrowFunction(reference) || isObjectLiteralMethod(reference)) {
                        if (isIdentifier(expr)) {
                            const symbol = getResolvedSymbol(expr);
                            const declaration = symbol.valueDeclaration;
                            if (declaration && (isBindingElement(declaration) || isParameter(declaration)) && reference === declaration.parent && !declaration.initializer && !declaration.dotDotDotToken) {
                                return declaration;
                            }
                        }
                    }
                    else if (isAccessExpression(expr)) {
                        if (isMatchingReference(reference, expr.expression)) {
                            return expr;
                        }
                    }
                    else if (isIdentifier(expr)) {
                        const symbol = getResolvedSymbol(expr);
                        if (isConstVariable(symbol)) {
                            const declaration = symbol.valueDeclaration;
                            if (isVariableDeclaration(declaration) && !declaration.type && declaration.initializer && isAccessExpression(declaration.initializer) && isMatchingReference(reference, declaration.initializer.expression)) {
                                return declaration.initializer;
                            }
                            if (isBindingElement(declaration) && !declaration.initializer) {
                                const parent2 = declaration.parent.parent;
                                if (isVariableDeclaration(parent2) && !parent2.type && parent2.initializer && (isIdentifier(parent2.initializer) || isAccessExpression(parent2.initializer)) && isMatchingReference(reference, parent2.initializer)) {
                                    return declaration;
                                }
                            }
                        }
                    }
                    return void 0;
                }
                function getDiscriminantPropertyAccess(expr, computedType) {
                    const type = declaredType.flags & 1048576 /* Union */ ? declaredType : computedType;
                    if (type.flags & 1048576 /* Union */) {
                        const access = getCandidateDiscriminantPropertyAccess(expr);
                        if (access) {
                            const name = getAccessedPropertyName(access);
                            if (name && isDiscriminantProperty(type, name)) {
                                return access;
                            }
                        }
                    }
                    return void 0;
                }
                function narrowTypeByDiscriminant(type, access, narrowType2) {
                    const propName = getAccessedPropertyName(access);
                    if (propName === void 0) {
                        return type;
                    }
                    const optionalChain = isOptionalChain(access);
                    const removeNullable = strictNullChecks && (optionalChain || isNonNullAccess(access)) && maybeTypeOfKind(type, 98304 /* Nullable */);
                    let propType = getTypeOfPropertyOfType(removeNullable ? getTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */) : type, propName);
                    if (!propType) {
                        return type;
                    }
                    propType = removeNullable && optionalChain ? getOptionalType(propType) : propType;
                    const narrowedPropType = narrowType2(propType);
                    return filterType(type, (t) => {
                        const discriminantType = getTypeOfPropertyOrIndexSignature(t, propName);
                        return !(discriminantType.flags & 131072 /* Never */) && !(narrowedPropType.flags & 131072 /* Never */) && areTypesComparable(narrowedPropType, discriminantType);
                    });
                }
                function narrowTypeByDiscriminantProperty(type, access, operator, value, assumeTrue) {
                    if ((operator === 36 /* EqualsEqualsEqualsToken */ || operator === 37 /* ExclamationEqualsEqualsToken */) && type.flags & 1048576 /* Union */) {
                        const keyPropertyName = getKeyPropertyName(type);
                        if (keyPropertyName && keyPropertyName === getAccessedPropertyName(access)) {
                            const candidate = getConstituentTypeForKeyType(type, getTypeOfExpression(value));
                            if (candidate) {
                                return operator === (assumeTrue ? 36 /* EqualsEqualsEqualsToken */ : 37 /* ExclamationEqualsEqualsToken */) ? candidate : isUnitType(getTypeOfPropertyOfType(candidate, keyPropertyName) || unknownType) ? removeType(type, candidate) : type;
                            }
                        }
                    }
                    return narrowTypeByDiscriminant(type, access, (t) => narrowTypeByEquality(t, operator, value, assumeTrue));
                }
                function narrowTypeBySwitchOnDiscriminantProperty(type, access, switchStatement, clauseStart, clauseEnd) {
                    if (clauseStart < clauseEnd && type.flags & 1048576 /* Union */ && getKeyPropertyName(type) === getAccessedPropertyName(access)) {
                        const clauseTypes = getSwitchClauseTypes(switchStatement).slice(clauseStart, clauseEnd);
                        const candidate = getUnionType(map(clauseTypes, (t) => getConstituentTypeForKeyType(type, t) || unknownType));
                        if (candidate !== unknownType) {
                            return candidate;
                        }
                    }
                    return narrowTypeByDiscriminant(type, access, (t) => narrowTypeBySwitchOnDiscriminant(t, switchStatement, clauseStart, clauseEnd));
                }
                function narrowTypeByTruthiness(type, expr, assumeTrue) {
                    if (isMatchingReference(reference, expr)) {
                        return getAdjustedTypeWithFacts(type, assumeTrue ? 4194304 /* Truthy */ : 8388608 /* Falsy */);
                    }
                    if (strictNullChecks && assumeTrue && optionalChainContainsReference(expr, reference)) {
                        type = getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */);
                    }
                    const access = getDiscriminantPropertyAccess(expr, type);
                    if (access) {
                        return narrowTypeByDiscriminant(type, access, (t) => getTypeWithFacts(t, assumeTrue ? 4194304 /* Truthy */ : 8388608 /* Falsy */));
                    }
                    return type;
                }
                function isTypePresencePossible(type, propName, assumeTrue) {
                    const prop = getPropertyOfType(type, propName);
                    return prop ? !!(prop.flags & 16777216 /* Optional */) || assumeTrue : !!getApplicableIndexInfoForName(type, propName) || !assumeTrue;
                }
                function narrowTypeByInKeyword(type, nameType, assumeTrue) {
                    const name = getPropertyNameFromType(nameType);
                    const isKnownProperty2 = someType(type, (t) => isTypePresencePossible(t, name, 
                    /*assumeTrue*/
                    true));
                    if (isKnownProperty2) {
                        return filterType(type, (t) => isTypePresencePossible(t, name, assumeTrue));
                    }
                    if (assumeTrue) {
                        const recordSymbol = getGlobalRecordSymbol();
                        if (recordSymbol) {
                            return getIntersectionType([type, getTypeAliasInstantiation(recordSymbol, [nameType, unknownType])]);
                        }
                    }
                    return type;
                }
                function narrowTypeByBinaryExpression(type, expr, assumeTrue) {
                    switch (expr.operatorToken.kind) {
                        case 63 /* EqualsToken */:
                        case 75 /* BarBarEqualsToken */:
                        case 76 /* AmpersandAmpersandEqualsToken */:
                        case 77 /* QuestionQuestionEqualsToken */:
                            return narrowTypeByTruthiness(narrowType(type, expr.right, assumeTrue), expr.left, assumeTrue);
                        case 34 /* EqualsEqualsToken */:
                        case 35 /* ExclamationEqualsToken */:
                        case 36 /* EqualsEqualsEqualsToken */:
                        case 37 /* ExclamationEqualsEqualsToken */:
                            const operator = expr.operatorToken.kind;
                            const left = getReferenceCandidate(expr.left);
                            const right = getReferenceCandidate(expr.right);
                            if (left.kind === 218 /* TypeOfExpression */ && isStringLiteralLike(right)) {
                                return narrowTypeByTypeof(type, left, operator, right, assumeTrue);
                            }
                            if (right.kind === 218 /* TypeOfExpression */ && isStringLiteralLike(left)) {
                                return narrowTypeByTypeof(type, right, operator, left, assumeTrue);
                            }
                            if (isMatchingReference(reference, left)) {
                                return narrowTypeByEquality(type, operator, right, assumeTrue);
                            }
                            if (isMatchingReference(reference, right)) {
                                return narrowTypeByEquality(type, operator, left, assumeTrue);
                            }
                            if (strictNullChecks) {
                                if (optionalChainContainsReference(left, reference)) {
                                    type = narrowTypeByOptionalChainContainment(type, operator, right, assumeTrue);
                                }
                                else if (optionalChainContainsReference(right, reference)) {
                                    type = narrowTypeByOptionalChainContainment(type, operator, left, assumeTrue);
                                }
                            }
                            const leftAccess = getDiscriminantPropertyAccess(left, type);
                            if (leftAccess) {
                                return narrowTypeByDiscriminantProperty(type, leftAccess, operator, right, assumeTrue);
                            }
                            const rightAccess = getDiscriminantPropertyAccess(right, type);
                            if (rightAccess) {
                                return narrowTypeByDiscriminantProperty(type, rightAccess, operator, left, assumeTrue);
                            }
                            if (isMatchingConstructorReference(left)) {
                                return narrowTypeByConstructor(type, operator, right, assumeTrue);
                            }
                            if (isMatchingConstructorReference(right)) {
                                return narrowTypeByConstructor(type, operator, left, assumeTrue);
                            }
                            break;
                        case 102 /* InstanceOfKeyword */:
                            return narrowTypeByInstanceof(type, expr, assumeTrue);
                        case 101 /* InKeyword */:
                            if (isPrivateIdentifier(expr.left)) {
                                return narrowTypeByPrivateIdentifierInInExpression(type, expr, assumeTrue);
                            }
                            const target = getReferenceCandidate(expr.right);
                            const leftType = getTypeOfExpression(expr.left);
                            if (leftType.flags & 8576 /* StringOrNumberLiteralOrUnique */) {
                                if (containsMissingType(type) && isAccessExpression(reference) && isMatchingReference(reference.expression, target) && getAccessedPropertyName(reference) === getPropertyNameFromType(leftType)) {
                                    return getTypeWithFacts(type, assumeTrue ? 524288 /* NEUndefined */ : 65536 /* EQUndefined */);
                                }
                                if (isMatchingReference(reference, target)) {
                                    return narrowTypeByInKeyword(type, leftType, assumeTrue);
                                }
                            }
                            break;
                        case 27 /* CommaToken */:
                            return narrowType(type, expr.right, assumeTrue);
                        case 55 /* AmpersandAmpersandToken */:
                            return assumeTrue ? narrowType(narrowType(type, expr.left, 
                            /*assumeTrue*/
                            true), expr.right, 
                            /*assumeTrue*/
                            true) : getUnionType([narrowType(type, expr.left, 
                                /*assumeTrue*/
                                false), narrowType(type, expr.right, 
                                /*assumeTrue*/
                                false)]);
                        case 56 /* BarBarToken */:
                            return assumeTrue ? getUnionType([narrowType(type, expr.left, 
                                /*assumeTrue*/
                                true), narrowType(type, expr.right, 
                                /*assumeTrue*/
                                true)]) : narrowType(narrowType(type, expr.left, 
                            /*assumeTrue*/
                            false), expr.right, 
                            /*assumeTrue*/
                            false);
                    }
                    return type;
                }
                function narrowTypeByPrivateIdentifierInInExpression(type, expr, assumeTrue) {
                    const target = getReferenceCandidate(expr.right);
                    if (!isMatchingReference(reference, target)) {
                        return type;
                    }
                    Debug.assertNode(expr.left, isPrivateIdentifier);
                    const symbol = getSymbolForPrivateIdentifierExpression(expr.left);
                    if (symbol === void 0) {
                        return type;
                    }
                    const classSymbol = symbol.parent;
                    const targetType = hasStaticModifier(Debug.checkDefined(symbol.valueDeclaration, "should always have a declaration")) ? getTypeOfSymbol(classSymbol) : getDeclaredTypeOfSymbol(classSymbol);
                    return getNarrowedType(type, targetType, assumeTrue, 
                    /*checkDerived*/
                    true);
                }
                function narrowTypeByOptionalChainContainment(type, operator, value, assumeTrue) {
                    const equalsOperator = operator === 34 /* EqualsEqualsToken */ || operator === 36 /* EqualsEqualsEqualsToken */;
                    const nullableFlags = operator === 34 /* EqualsEqualsToken */ || operator === 35 /* ExclamationEqualsToken */ ? 98304 /* Nullable */ : 32768 /* Undefined */;
                    const valueType = getTypeOfExpression(value);
                    const removeNullable = equalsOperator !== assumeTrue && everyType(valueType, (t) => !!(t.flags & nullableFlags)) || equalsOperator === assumeTrue && everyType(valueType, (t) => !(t.flags & (3 /* AnyOrUnknown */ | nullableFlags)));
                    return removeNullable ? getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */) : type;
                }
                function narrowTypeByEquality(type, operator, value, assumeTrue) {
                    if (type.flags & 1 /* Any */) {
                        return type;
                    }
                    if (operator === 35 /* ExclamationEqualsToken */ || operator === 37 /* ExclamationEqualsEqualsToken */) {
                        assumeTrue = !assumeTrue;
                    }
                    const valueType = getTypeOfExpression(value);
                    const doubleEquals = operator === 34 /* EqualsEqualsToken */ || operator === 35 /* ExclamationEqualsToken */;
                    if (valueType.flags & 98304 /* Nullable */) {
                        if (!strictNullChecks) {
                            return type;
                        }
                        const facts = doubleEquals ? assumeTrue ? 262144 /* EQUndefinedOrNull */ : 2097152 /* NEUndefinedOrNull */ : valueType.flags & 65536 /* Null */ ? assumeTrue ? 131072 /* EQNull */ : 1048576 /* NENull */ : assumeTrue ? 65536 /* EQUndefined */ : 524288 /* NEUndefined */;
                        return getAdjustedTypeWithFacts(type, facts);
                    }
                    if (assumeTrue) {
                        if (!doubleEquals && (type.flags & 2 /* Unknown */ || someType(type, isEmptyAnonymousObjectType))) {
                            if (valueType.flags & (134348796 /* Primitive */ | 67108864 /* NonPrimitive */) || isEmptyAnonymousObjectType(valueType)) {
                                return valueType;
                            }
                            if (valueType.flags & 524288 /* Object */) {
                                return nonPrimitiveType;
                            }
                        }
                        const filteredType = filterType(type, (t) => areTypesComparable(t, valueType) || doubleEquals && isCoercibleUnderDoubleEquals(t, valueType));
                        return replacePrimitivesWithLiterals(filteredType, valueType);
                    }
                    if (isUnitType(valueType)) {
                        return filterType(type, (t) => !(isUnitLikeType(t) && areTypesComparable(t, valueType)));
                    }
                    return type;
                }
                function narrowTypeByTypeof(type, typeOfExpr, operator, literal, assumeTrue) {
                    if (operator === 35 /* ExclamationEqualsToken */ || operator === 37 /* ExclamationEqualsEqualsToken */) {
                        assumeTrue = !assumeTrue;
                    }
                    const target = getReferenceCandidate(typeOfExpr.expression);
                    if (!isMatchingReference(reference, target)) {
                        if (strictNullChecks && optionalChainContainsReference(target, reference) && assumeTrue === (literal.text !== "undefined")) {
                            type = getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */);
                        }
                        const propertyAccess = getDiscriminantPropertyAccess(target, type);
                        if (propertyAccess) {
                            return narrowTypeByDiscriminant(type, propertyAccess, (t) => narrowTypeByLiteralExpression(t, literal, assumeTrue));
                        }
                        return type;
                    }
                    return narrowTypeByLiteralExpression(type, literal, assumeTrue);
                }
                function narrowTypeByLiteralExpression(type, literal, assumeTrue) {
                    return assumeTrue ? narrowTypeByTypeName(type, literal.text) : getAdjustedTypeWithFacts(type, typeofNEFacts.get(literal.text) || 32768 /* TypeofNEHostObject */);
                }
                function narrowTypeBySwitchOptionalChainContainment(type, switchStatement, clauseStart, clauseEnd, clauseCheck) {
                    const everyClauseChecks = clauseStart !== clauseEnd && every(getSwitchClauseTypes(switchStatement).slice(clauseStart, clauseEnd), clauseCheck);
                    return everyClauseChecks ? getTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */) : type;
                }
                function narrowTypeBySwitchOnDiscriminant(type, switchStatement, clauseStart, clauseEnd) {
                    const switchTypes = getSwitchClauseTypes(switchStatement);
                    if (!switchTypes.length) {
                        return type;
                    }
                    const clauseTypes = switchTypes.slice(clauseStart, clauseEnd);
                    const hasDefaultClause = clauseStart === clauseEnd || contains(clauseTypes, neverType);
                    if (type.flags & 2 /* Unknown */ && !hasDefaultClause) {
                        let groundClauseTypes;
                        for (let i = 0; i < clauseTypes.length; i += 1) {
                            const t = clauseTypes[i];
                            if (t.flags & (134348796 /* Primitive */ | 67108864 /* NonPrimitive */)) {
                                if (groundClauseTypes !== void 0) {
                                    groundClauseTypes.push(t);
                                }
                            }
                            else if (t.flags & 524288 /* Object */) {
                                if (groundClauseTypes === void 0) {
                                    groundClauseTypes = clauseTypes.slice(0, i);
                                }
                                groundClauseTypes.push(nonPrimitiveType);
                            }
                            else {
                                return type;
                            }
                        }
                        return getUnionType(groundClauseTypes === void 0 ? clauseTypes : groundClauseTypes);
                    }
                    const discriminantType = getUnionType(clauseTypes);
                    const caseType = discriminantType.flags & 131072 /* Never */ ? neverType : replacePrimitivesWithLiterals(filterType(type, (t) => areTypesComparable(discriminantType, t)), discriminantType);
                    if (!hasDefaultClause) {
                        return caseType;
                    }
                    const defaultType = filterType(type, (t) => !(isUnitLikeType(t) && contains(switchTypes, getRegularTypeOfLiteralType(extractUnitType(t)))));
                    return caseType.flags & 131072 /* Never */ ? defaultType : getUnionType([caseType, defaultType]);
                }
                function narrowTypeByTypeName(type, typeName) {
                    switch (typeName) {
                        case "string":
                            return narrowTypeByTypeFacts(type, stringType, 1 /* TypeofEQString */);
                        case "number":
                            return narrowTypeByTypeFacts(type, numberType, 2 /* TypeofEQNumber */);
                        case "bigint":
                            return narrowTypeByTypeFacts(type, bigintType, 4 /* TypeofEQBigInt */);
                        case "boolean":
                            return narrowTypeByTypeFacts(type, booleanType, 8 /* TypeofEQBoolean */);
                        case "symbol":
                            return narrowTypeByTypeFacts(type, esSymbolType, 16 /* TypeofEQSymbol */);
                        case "object":
                            return type.flags & 1 /* Any */ ? type : getUnionType([narrowTypeByTypeFacts(type, nonPrimitiveType, 32 /* TypeofEQObject */), narrowTypeByTypeFacts(type, nullType, 131072 /* EQNull */)]);
                        case "function":
                            return type.flags & 1 /* Any */ ? type : narrowTypeByTypeFacts(type, globalFunctionType, 64 /* TypeofEQFunction */);
                        case "undefined":
                            return narrowTypeByTypeFacts(type, undefinedType, 65536 /* EQUndefined */);
                    }
                    return narrowTypeByTypeFacts(type, nonPrimitiveType, 128 /* TypeofEQHostObject */);
                }
                function narrowTypeByTypeFacts(type, impliedType, facts) {
                    return mapType(type, (t) => (
                    // We first check if a constituent is a subtype of the implied type. If so, we either keep or eliminate
                    // the constituent based on its type facts. We use the strict subtype relation because it treats `object`
                    // as a subtype of `{}`, and we need the type facts check because function types are subtypes of `object`,
                    // but are classified as "function" according to `typeof`.
                    isTypeRelatedTo(t, impliedType, strictSubtypeRelation) ? getTypeFacts(t) & facts ? t : neverType : (
                    // We next check if the consituent is a supertype of the implied type. If so, we substitute the implied
                    // type. This handles top types like `unknown` and `{}`, and supertypes like `{ toString(): string }`.
                    isTypeSubtypeOf(impliedType, t) ? impliedType : (
                    // Neither the constituent nor the implied type is a subtype of the other, however their domains may still
                    // overlap. For example, an unconstrained type parameter and type `string`. If the type facts indicate
                    // possible overlap, we form an intersection. Otherwise, we eliminate the constituent.
                    getTypeFacts(t) & facts ? getIntersectionType([t, impliedType]) : neverType))));
                }
                function narrowTypeBySwitchOnTypeOf(type, switchStatement, clauseStart, clauseEnd) {
                    const witnesses = getSwitchClauseTypeOfWitnesses(switchStatement);
                    if (!witnesses) {
                        return type;
                    }
                    const defaultIndex = findIndex(switchStatement.caseBlock.clauses, (clause) => clause.kind === 293 /* DefaultClause */);
                    const hasDefaultClause = clauseStart === clauseEnd || defaultIndex >= clauseStart && defaultIndex < clauseEnd;
                    if (hasDefaultClause) {
                        const notEqualFacts = getNotEqualFactsFromTypeofSwitch(clauseStart, clauseEnd, witnesses);
                        return filterType(type, (t) => (getTypeFacts(t) & notEqualFacts) === notEqualFacts);
                    }
                    const clauseWitnesses = witnesses.slice(clauseStart, clauseEnd);
                    return getUnionType(map(clauseWitnesses, (text) => text ? narrowTypeByTypeName(type, text) : neverType));
                }
                function isMatchingConstructorReference(expr) {
                    return (isPropertyAccessExpression(expr) && idText(expr.name) === "constructor" || isElementAccessExpression(expr) && isStringLiteralLike(expr.argumentExpression) && expr.argumentExpression.text === "constructor") && isMatchingReference(reference, expr.expression);
                }
                function narrowTypeByConstructor(type, operator, identifier, assumeTrue) {
                    if (assumeTrue ? operator !== 34 /* EqualsEqualsToken */ && operator !== 36 /* EqualsEqualsEqualsToken */ : operator !== 35 /* ExclamationEqualsToken */ && operator !== 37 /* ExclamationEqualsEqualsToken */) {
                        return type;
                    }
                    const identifierType = getTypeOfExpression(identifier);
                    if (!isFunctionType(identifierType) && !isConstructorType(identifierType)) {
                        return type;
                    }
                    const prototypeProperty = getPropertyOfType(identifierType, "prototype");
                    if (!prototypeProperty) {
                        return type;
                    }
                    const prototypeType = getTypeOfSymbol(prototypeProperty);
                    const candidate = !isTypeAny(prototypeType) ? prototypeType : void 0;
                    if (!candidate || candidate === globalObjectType || candidate === globalFunctionType) {
                        return type;
                    }
                    if (isTypeAny(type)) {
                        return candidate;
                    }
                    return filterType(type, (t) => isConstructedBy(t, candidate));
                    function isConstructedBy(source, target) {
                        if (source.flags & 524288 /* Object */ && getObjectFlags(source) & 1 /* Class */ || target.flags & 524288 /* Object */ && getObjectFlags(target) & 1 /* Class */) {
                            return source.symbol === target.symbol;
                        }
                        return isTypeSubtypeOf(source, target);
                    }
                }
                function narrowTypeByInstanceof(type, expr, assumeTrue) {
                    const left = getReferenceCandidate(expr.left);
                    if (!isMatchingReference(reference, left)) {
                        if (assumeTrue && strictNullChecks && optionalChainContainsReference(left, reference)) {
                            return getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */);
                        }
                        return type;
                    }
                    const rightType = getTypeOfExpression(expr.right);
                    if (!isTypeDerivedFrom(rightType, globalFunctionType)) {
                        return type;
                    }
                    const instanceType = mapType(rightType, getInstanceType);
                    if (isTypeAny(type) && (instanceType === globalObjectType || instanceType === globalFunctionType) || !assumeTrue && !(instanceType.flags & 524288 /* Object */ && !isEmptyAnonymousObjectType(instanceType))) {
                        return type;
                    }
                    return getNarrowedType(type, instanceType, assumeTrue, 
                    /*checkDerived*/
                    true);
                }
                function getInstanceType(constructorType) {
                    const prototypePropertyType = getTypeOfPropertyOfType(constructorType, "prototype");
                    if (prototypePropertyType && !isTypeAny(prototypePropertyType)) {
                        return prototypePropertyType;
                    }
                    const constructSignatures = getSignaturesOfType(constructorType, 1 /* Construct */);
                    if (constructSignatures.length) {
                        return getUnionType(map(constructSignatures, (signature) => getReturnTypeOfSignature(getErasedSignature(signature))));
                    }
                    return emptyObjectType;
                }
                function getNarrowedType(type, candidate, assumeTrue, checkDerived) {
                    var _a3;
                    const key2 = type.flags & 1048576 /* Union */ ? `N${getTypeId(type)},${getTypeId(candidate)},${(assumeTrue ? 1 : 0) | (checkDerived ? 2 : 0)}` : void 0;
                    return (_a3 = getCachedType(key2)) != null ? _a3 : setCachedType(key2, getNarrowedTypeWorker(type, candidate, assumeTrue, checkDerived));
                }
                function getNarrowedTypeWorker(type, candidate, assumeTrue, checkDerived) {
                    if (!assumeTrue) {
                        if (checkDerived) {
                            return filterType(type, (t) => !isTypeDerivedFrom(t, candidate));
                        }
                        const trueType2 = getNarrowedType(type, candidate, 
                        /*assumeTrue*/
                        true, 
                        /*checkDerived*/
                        false);
                        return filterType(type, (t) => !isTypeSubsetOf(t, trueType2));
                    }
                    if (type.flags & 3 /* AnyOrUnknown */) {
                        return candidate;
                    }
                    const isRelated = checkDerived ? isTypeDerivedFrom : isTypeSubtypeOf;
                    const keyPropertyName = type.flags & 1048576 /* Union */ ? getKeyPropertyName(type) : void 0;
                    const narrowedType = mapType(candidate, (c) => {
                        const discriminant = keyPropertyName && getTypeOfPropertyOfType(c, keyPropertyName);
                        const matching = discriminant && getConstituentTypeForKeyType(type, discriminant);
                        const directlyRelated = mapType(matching || type, checkDerived ? (t) => isTypeDerivedFrom(t, c) ? t : isTypeDerivedFrom(c, t) ? c : neverType : (t) => isTypeStrictSubtypeOf(t, c) ? t : isTypeStrictSubtypeOf(c, t) ? c : isTypeSubtypeOf(t, c) ? t : isTypeSubtypeOf(c, t) ? c : neverType);
                        return directlyRelated.flags & 131072 /* Never */ ? mapType(type, (t) => maybeTypeOfKind(t, 465829888 /* Instantiable */) && isRelated(c, getBaseConstraintOfType(t) || unknownType) ? getIntersectionType([t, c]) : neverType) : directlyRelated;
                    });
                    return !(narrowedType.flags & 131072 /* Never */) ? narrowedType : isTypeSubtypeOf(candidate, type) ? candidate : isTypeAssignableTo(type, candidate) ? type : isTypeAssignableTo(candidate, type) ? candidate : getIntersectionType([type, candidate]);
                }
                function narrowTypeByCallExpression(type, callExpression, assumeTrue) {
                    if (hasMatchingArgument(callExpression, reference)) {
                        const signature = assumeTrue || !isCallChain(callExpression) ? getEffectsSignature(callExpression) : void 0;
                        const predicate = signature && getTypePredicateOfSignature(signature);
                        if (predicate && (predicate.kind === 0 /* This */ || predicate.kind === 1 /* Identifier */)) {
                            return narrowTypeByTypePredicate(type, predicate, callExpression, assumeTrue);
                        }
                    }
                    if (containsMissingType(type) && isAccessExpression(reference) && isPropertyAccessExpression(callExpression.expression)) {
                        const callAccess = callExpression.expression;
                        if (isMatchingReference(reference.expression, getReferenceCandidate(callAccess.expression)) && isIdentifier(callAccess.name) && callAccess.name.escapedText === "hasOwnProperty" && callExpression.arguments.length === 1) {
                            const argument = callExpression.arguments[0];
                            if (isStringLiteralLike(argument) && getAccessedPropertyName(reference) === escapeLeadingUnderscores(argument.text)) {
                                return getTypeWithFacts(type, assumeTrue ? 524288 /* NEUndefined */ : 65536 /* EQUndefined */);
                            }
                        }
                    }
                    return type;
                }
                function narrowTypeByTypePredicate(type, predicate, callExpression, assumeTrue) {
                    if (predicate.type && !(isTypeAny(type) && (predicate.type === globalObjectType || predicate.type === globalFunctionType))) {
                        const predicateArgument = getTypePredicateArgument(predicate, callExpression);
                        if (predicateArgument) {
                            if (isMatchingReference(reference, predicateArgument)) {
                                return getNarrowedType(type, predicate.type, assumeTrue, 
                                /*checkDerived*/
                                false);
                            }
                            if (strictNullChecks && assumeTrue && optionalChainContainsReference(predicateArgument, reference) && !(getTypeFacts(predicate.type) & 65536 /* EQUndefined */)) {
                                type = getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */);
                            }
                            const access = getDiscriminantPropertyAccess(predicateArgument, type);
                            if (access) {
                                return narrowTypeByDiscriminant(type, access, (t) => getNarrowedType(t, predicate.type, assumeTrue, 
                                /*checkDerived*/
                                false));
                            }
                        }
                    }
                    return type;
                }
                function narrowType(type, expr, assumeTrue) {
                    if (isExpressionOfOptionalChainRoot(expr) || isBinaryExpression(expr.parent) && (expr.parent.operatorToken.kind === 60 /* QuestionQuestionToken */ || expr.parent.operatorToken.kind === 77 /* QuestionQuestionEqualsToken */) && expr.parent.left === expr) {
                        return narrowTypeByOptionality(type, expr, assumeTrue);
                    }
                    switch (expr.kind) {
                        case 79 /* Identifier */:
                            if (!isMatchingReference(reference, expr) && inlineLevel < 5) {
                                const symbol = getResolvedSymbol(expr);
                                if (isConstVariable(symbol)) {
                                    const declaration = symbol.valueDeclaration;
                                    if (declaration && isVariableDeclaration(declaration) && !declaration.type && declaration.initializer && isConstantReference(reference)) {
                                        inlineLevel++;
                                        const result = narrowType(type, declaration.initializer, assumeTrue);
                                        inlineLevel--;
                                        return result;
                                    }
                                }
                            }
                        case 108 /* ThisKeyword */:
                        case 106 /* SuperKeyword */:
                        case 208 /* PropertyAccessExpression */:
                        case 209 /* ElementAccessExpression */:
                            return narrowTypeByTruthiness(type, expr, assumeTrue);
                        case 210 /* CallExpression */:
                            return narrowTypeByCallExpression(type, expr, assumeTrue);
                        case 214 /* ParenthesizedExpression */:
                        case 232 /* NonNullExpression */:
                            return narrowType(type, expr.expression, assumeTrue);
                        case 223 /* BinaryExpression */:
                            return narrowTypeByBinaryExpression(type, expr, assumeTrue);
                        case 221 /* PrefixUnaryExpression */:
                            if (expr.operator === 53 /* ExclamationToken */) {
                                return narrowType(type, expr.operand, !assumeTrue);
                            }
                            break;
                    }
                    return type;
                }
                function narrowTypeByOptionality(type, expr, assumePresent) {
                    if (isMatchingReference(reference, expr)) {
                        return getAdjustedTypeWithFacts(type, assumePresent ? 2097152 /* NEUndefinedOrNull */ : 262144 /* EQUndefinedOrNull */);
                    }
                    const access = getDiscriminantPropertyAccess(expr, type);
                    if (access) {
                        return narrowTypeByDiscriminant(type, access, (t) => getTypeWithFacts(t, assumePresent ? 2097152 /* NEUndefinedOrNull */ : 262144 /* EQUndefinedOrNull */));
                    }
                    return type;
                }
            }
            function getTypeOfSymbolAtLocation(symbol, location) {
                symbol = getExportSymbolOfValueSymbolIfExported(symbol);
                if (location.kind === 79 /* Identifier */ || location.kind === 80 /* PrivateIdentifier */) {
                    if (isRightSideOfQualifiedNameOrPropertyAccess(location)) {
                        location = location.parent;
                    }
                    if (isExpressionNode(location) && (!isAssignmentTarget(location) || isWriteAccess(location))) {
                        const type = getTypeOfExpression(location);
                        if (getExportSymbolOfValueSymbolIfExported(getNodeLinks(location).resolvedSymbol) === symbol) {
                            return type;
                        }
                    }
                }
                if (isDeclarationName(location) && isSetAccessor(location.parent) && getAnnotatedAccessorTypeNode(location.parent)) {
                    return getWriteTypeOfAccessors(location.parent.symbol);
                }
                return getNonMissingTypeOfSymbol(symbol);
            }
            function getControlFlowContainer(node) {
                return findAncestor(node.parent, (node2) => isFunctionLike(node2) && !getImmediatelyInvokedFunctionExpression(node2) || node2.kind === 265 /* ModuleBlock */ || node2.kind === 308 /* SourceFile */ || node2.kind === 169 /* PropertyDeclaration */);
            }
            function isSymbolAssigned(symbol) {
                if (!symbol.valueDeclaration) {
                    return false;
                }
                const parent2 = getRootDeclaration(symbol.valueDeclaration).parent;
                const links = getNodeLinks(parent2);
                if (!(links.flags & 524288 /* AssignmentsMarked */)) {
                    links.flags |= 524288 /* AssignmentsMarked */;
                    if (!hasParentWithAssignmentsMarked(parent2)) {
                        markNodeAssignments(parent2);
                    }
                }
                return symbol.isAssigned || false;
            }
            function hasParentWithAssignmentsMarked(node) {
                return !!findAncestor(node.parent, (node2) => (isFunctionLike(node2) || isCatchClause(node2)) && !!(getNodeLinks(node2).flags & 524288 /* AssignmentsMarked */));
            }
            function markNodeAssignments(node) {
                if (node.kind === 79 /* Identifier */) {
                    if (isAssignmentTarget(node)) {
                        const symbol = getResolvedSymbol(node);
                        if (isParameterOrCatchClauseVariable(symbol)) {
                            symbol.isAssigned = true;
                        }
                    }
                }
                else {
                    forEachChild(node, markNodeAssignments);
                }
            }
            function isConstVariable(symbol) {
                return symbol.flags & 3 /* Variable */ && (getDeclarationNodeFlagsFromSymbol(symbol) & 2 /* Const */) !== 0;
            }
            function parameterInitializerContainsUndefined(declaration) {
                const links = getNodeLinks(declaration);
                if (links.parameterInitializerContainsUndefined === void 0) {
                    if (!pushTypeResolution(declaration, 9 /* ParameterInitializerContainsUndefined */)) {
                        reportCircularityError(declaration.symbol);
                        return true;
                    }
                    const containsUndefined = !!(getTypeFacts(checkDeclarationInitializer(declaration, 0 /* Normal */)) & 16777216 /* IsUndefined */);
                    if (!popTypeResolution()) {
                        reportCircularityError(declaration.symbol);
                        return true;
                    }
                    links.parameterInitializerContainsUndefined = containsUndefined;
                }
                return links.parameterInitializerContainsUndefined;
            }
            function removeOptionalityFromDeclaredType(declaredType, declaration) {
                const removeUndefined = strictNullChecks && declaration.kind === 166 /* Parameter */ && declaration.initializer && getTypeFacts(declaredType) & 16777216 /* IsUndefined */ && !parameterInitializerContainsUndefined(declaration);
                return removeUndefined ? getTypeWithFacts(declaredType, 524288 /* NEUndefined */) : declaredType;
            }
            function isConstraintPosition(type, node) {
                const parent2 = node.parent;
                return parent2.kind === 208 /* PropertyAccessExpression */ || parent2.kind === 163 /* QualifiedName */ || parent2.kind === 210 /* CallExpression */ && parent2.expression === node || parent2.kind === 209 /* ElementAccessExpression */ && parent2.expression === node && !(someType(type, isGenericTypeWithoutNullableConstraint) && isGenericIndexType(getTypeOfExpression(parent2.argumentExpression)));
            }
            function isGenericTypeWithUnionConstraint(type) {
                return type.flags & 2097152 /* Intersection */ ? some(type.types, isGenericTypeWithUnionConstraint) : !!(type.flags & 465829888 /* Instantiable */ && getBaseConstraintOrType(type).flags & (98304 /* Nullable */ | 1048576 /* Union */));
            }
            function isGenericTypeWithoutNullableConstraint(type) {
                return type.flags & 2097152 /* Intersection */ ? some(type.types, isGenericTypeWithoutNullableConstraint) : !!(type.flags & 465829888 /* Instantiable */ && !maybeTypeOfKind(getBaseConstraintOrType(type), 98304 /* Nullable */));
            }
            function hasContextualTypeWithNoGenericTypes(node, checkMode) {
                const contextualType = (isIdentifier(node) || isPropertyAccessExpression(node) || isElementAccessExpression(node)) && !((isJsxOpeningElement(node.parent) || isJsxSelfClosingElement(node.parent)) && node.parent.tagName === node) && (checkMode && checkMode & 64 /* RestBindingElement */ ? getContextualType2(node, 8 /* SkipBindingPatterns */) : getContextualType2(node, 
                /*contextFlags*/
                void 0));
                return contextualType && !isGenericType(contextualType);
            }
            function getNarrowableTypeForReference(type, reference, checkMode) {
                const substituteConstraints = !(checkMode && checkMode & 2 /* Inferential */) && someType(type, isGenericTypeWithUnionConstraint) && (isConstraintPosition(type, reference) || hasContextualTypeWithNoGenericTypes(reference, checkMode));
                return substituteConstraints ? mapType(type, getBaseConstraintOrType) : type;
            }
            function isExportOrExportExpression(location) {
                return !!findAncestor(location, (n) => {
                    const parent2 = n.parent;
                    if (parent2 === void 0) {
                        return "quit";
                    }
                    if (isExportAssignment(parent2)) {
                        return parent2.expression === n && isEntityNameExpression(n);
                    }
                    if (isExportSpecifier(parent2)) {
                        return parent2.name === n || parent2.propertyName === n;
                    }
                    return false;
                });
            }
            function markAliasReferenced(symbol, location) {
                if (compilerOptions.verbatimModuleSyntax) {
                    return;
                }
                if (isNonLocalAlias(symbol, 
                /*excludes*/
                111551 /* Value */) && !isInTypeQuery(location) && !getTypeOnlyAliasDeclaration(symbol, 111551 /* Value */)) {
                    const target = resolveAlias(symbol);
                    if (getAllSymbolFlags(target) & (111551 /* Value */ | 1048576 /* ExportValue */)) {
                        if (getIsolatedModules(compilerOptions) || shouldPreserveConstEnums(compilerOptions) && isExportOrExportExpression(location) || !isConstEnumOrConstEnumOnlyModule(getExportSymbolOfValueSymbolIfExported(target))) {
                            markAliasSymbolAsReferenced(symbol);
                        }
                        else {
                            markConstEnumAliasAsReferenced(symbol);
                        }
                    }
                }
            }
            function getNarrowedTypeOfSymbol(symbol, location) {
                var _a2;
                const type = getTypeOfSymbol(symbol);
                const declaration = symbol.valueDeclaration;
                if (declaration) {
                    if (isBindingElement(declaration) && !declaration.initializer && !declaration.dotDotDotToken && declaration.parent.elements.length >= 2) {
                        const parent2 = declaration.parent.parent;
                        if (parent2.kind === 257 /* VariableDeclaration */ && getCombinedNodeFlags(declaration) & 2 /* Const */ || parent2.kind === 166 /* Parameter */) {
                            const links = getNodeLinks(parent2);
                            if (!(links.flags & 16777216 /* InCheckIdentifier */)) {
                                links.flags |= 16777216 /* InCheckIdentifier */;
                                const parentType = getTypeForBindingElementParent(parent2, 0 /* Normal */);
                                const parentTypeConstraint = parentType && mapType(parentType, getBaseConstraintOrType);
                                links.flags &= ~16777216 /* InCheckIdentifier */;
                                if (parentTypeConstraint && parentTypeConstraint.flags & 1048576 /* Union */ && !(parent2.kind === 166 /* Parameter */ && isSymbolAssigned(symbol))) {
                                    const pattern = declaration.parent;
                                    const narrowedType = getFlowTypeOfReference(pattern, parentTypeConstraint, parentTypeConstraint, 
                                    /*flowContainer*/
                                    void 0, location.flowNode);
                                    if (narrowedType.flags & 131072 /* Never */) {
                                        return neverType;
                                    }
                                    return getBindingElementTypeFromParentType(declaration, narrowedType);
                                }
                            }
                        }
                    }
                    if (isParameter(declaration) && !declaration.type && !declaration.initializer && !declaration.dotDotDotToken) {
                        const func = declaration.parent;
                        if (func.parameters.length >= 2 && isContextSensitiveFunctionOrObjectLiteralMethod(func)) {
                            const contextualSignature = getContextualSignature(func);
                            if (contextualSignature && contextualSignature.parameters.length === 1 && signatureHasRestParameter(contextualSignature)) {
                                const restType = getReducedApparentType(instantiateType(getTypeOfSymbol(contextualSignature.parameters[0]), (_a2 = getInferenceContext(func)) == null ? void 0 : _a2.nonFixingMapper));
                                if (restType.flags & 1048576 /* Union */ && everyType(restType, isTupleType) && !isSymbolAssigned(symbol)) {
                                    const narrowedType = getFlowTypeOfReference(func, restType, restType, 
                                    /*flowContainer*/
                                    void 0, location.flowNode);
                                    const index = func.parameters.indexOf(declaration) - (getThisParameter(func) ? 1 : 0);
                                    return getIndexedAccessType(narrowedType, getNumberLiteralType(index));
                                }
                            }
                        }
                    }
                }
                return type;
            }
            function checkIdentifier(node, checkMode) {
                if (isThisInTypeQuery(node)) {
                    return checkThisExpression(node);
                }
                const symbol = getResolvedSymbol(node);
                if (symbol === unknownSymbol) {
                    return errorType;
                }
                if (symbol === argumentsSymbol) {
                    if (isInPropertyInitializerOrClassStaticBlock(node)) {
                        error(node, Diagnostics.arguments_cannot_be_referenced_in_property_initializers);
                        return errorType;
                    }
                    const container = getContainingFunction(node);
                    if (languageVersion < 2 /* ES2015 */) {
                        if (container.kind === 216 /* ArrowFunction */) {
                            error(node, Diagnostics.The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_standard_function_expression);
                        }
                        else if (hasSyntacticModifier(container, 512 /* Async */)) {
                            error(node, Diagnostics.The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_using_a_standard_function_or_method);
                        }
                    }
                    getNodeLinks(container).flags |= 512 /* CaptureArguments */;
                    return getTypeOfSymbol(symbol);
                }
                if (shouldMarkIdentifierAliasReferenced(node)) {
                    markAliasReferenced(symbol, node);
                }
                const localOrExportSymbol = getExportSymbolOfValueSymbolIfExported(symbol);
                const targetSymbol = checkDeprecatedAliasedSymbol(localOrExportSymbol, node);
                if (isDeprecatedSymbol(targetSymbol) && isUncalledFunctionReference(node, targetSymbol) && targetSymbol.declarations) {
                    addDeprecatedSuggestion(node, targetSymbol.declarations, node.escapedText);
                }
                let declaration = localOrExportSymbol.valueDeclaration;
                if (declaration && localOrExportSymbol.flags & 32 /* Class */) {
                    if (declaration.kind === 260 /* ClassDeclaration */ && nodeIsDecorated(legacyDecorators, declaration)) {
                        let container = getContainingClass(node);
                        while (container !== void 0) {
                            if (container === declaration && container.name !== node) {
                                getNodeLinks(declaration).flags |= 1048576 /* ClassWithConstructorReference */;
                                getNodeLinks(node).flags |= 2097152 /* ConstructorReferenceInClass */;
                                break;
                            }
                            container = getContainingClass(container);
                        }
                    }
                    else if (declaration.kind === 228 /* ClassExpression */) {
                        let container = getThisContainer(node, 
                        /*includeArrowFunctions*/
                        false, 
                        /*includeClassComputedPropertyName*/
                        false);
                        while (container.kind !== 308 /* SourceFile */) {
                            if (container.parent === declaration) {
                                if (isPropertyDeclaration(container) && isStatic(container) || isClassStaticBlockDeclaration(container)) {
                                    getNodeLinks(declaration).flags |= 1048576 /* ClassWithConstructorReference */;
                                    getNodeLinks(node).flags |= 2097152 /* ConstructorReferenceInClass */;
                                }
                                break;
                            }
                            container = getThisContainer(container, 
                            /*includeArrowFunctions*/
                            false, 
                            /*includeClassComputedPropertyName*/
                            false);
                        }
                    }
                }
                checkNestedBlockScopedBinding(node, symbol);
                let type = getNarrowedTypeOfSymbol(localOrExportSymbol, node);
                const assignmentKind = getAssignmentTargetKind(node);
                if (assignmentKind) {
                    if (!(localOrExportSymbol.flags & 3 /* Variable */) && !(isInJSFile(node) && localOrExportSymbol.flags & 512 /* ValueModule */)) {
                        const assignmentError = localOrExportSymbol.flags & 384 /* Enum */ ? Diagnostics.Cannot_assign_to_0_because_it_is_an_enum : localOrExportSymbol.flags & 32 /* Class */ ? Diagnostics.Cannot_assign_to_0_because_it_is_a_class : localOrExportSymbol.flags & 1536 /* Module */ ? Diagnostics.Cannot_assign_to_0_because_it_is_a_namespace : localOrExportSymbol.flags & 16 /* Function */ ? Diagnostics.Cannot_assign_to_0_because_it_is_a_function : localOrExportSymbol.flags & 2097152 /* Alias */ ? Diagnostics.Cannot_assign_to_0_because_it_is_an_import : Diagnostics.Cannot_assign_to_0_because_it_is_not_a_variable;
                        error(node, assignmentError, symbolToString(symbol));
                        return errorType;
                    }
                    if (isReadonlySymbol(localOrExportSymbol)) {
                        if (localOrExportSymbol.flags & 3 /* Variable */) {
                            error(node, Diagnostics.Cannot_assign_to_0_because_it_is_a_constant, symbolToString(symbol));
                        }
                        else {
                            error(node, Diagnostics.Cannot_assign_to_0_because_it_is_a_read_only_property, symbolToString(symbol));
                        }
                        return errorType;
                    }
                }
                const isAlias = localOrExportSymbol.flags & 2097152 /* Alias */;
                if (localOrExportSymbol.flags & 3 /* Variable */) {
                    if (assignmentKind === 1 /* Definite */) {
                        return type;
                    }
                }
                else if (isAlias) {
                    declaration = getDeclarationOfAliasSymbol(symbol);
                }
                else {
                    return type;
                }
                if (!declaration) {
                    return type;
                }
                type = getNarrowableTypeForReference(type, node, checkMode);
                const isParameter2 = getRootDeclaration(declaration).kind === 166 /* Parameter */;
                const declarationContainer = getControlFlowContainer(declaration);
                let flowContainer = getControlFlowContainer(node);
                const isOuterVariable = flowContainer !== declarationContainer;
                const isSpreadDestructuringAssignmentTarget = node.parent && node.parent.parent && isSpreadAssignment(node.parent) && isDestructuringAssignmentTarget(node.parent.parent);
                const isModuleExports = symbol.flags & 134217728 /* ModuleExports */;
                while (flowContainer !== declarationContainer && (flowContainer.kind === 215 /* FunctionExpression */ || flowContainer.kind === 216 /* ArrowFunction */ || isObjectLiteralOrClassExpressionMethodOrAccessor(flowContainer)) && (isConstVariable(localOrExportSymbol) && type !== autoArrayType || isParameter2 && !isSymbolAssigned(localOrExportSymbol))) {
                    flowContainer = getControlFlowContainer(flowContainer);
                }
                const assumeInitialized = isParameter2 || isAlias || isOuterVariable || isSpreadDestructuringAssignmentTarget || isModuleExports || isSameScopedBindingElement(node, declaration) || type !== autoType && type !== autoArrayType && (!strictNullChecks || (type.flags & (3 /* AnyOrUnknown */ | 16384 /* Void */)) !== 0 || isInTypeQuery(node) || isInAmbientOrTypeNode(node) || node.parent.kind === 278 /* ExportSpecifier */) || node.parent.kind === 232 /* NonNullExpression */ || declaration.kind === 257 /* VariableDeclaration */ && declaration.exclamationToken || declaration.flags & 16777216 /* Ambient */;
                const initialType = assumeInitialized ? isParameter2 ? removeOptionalityFromDeclaredType(type, declaration) : type : type === autoType || type === autoArrayType ? undefinedType : getOptionalType(type);
                const flowType = getFlowTypeOfReference(node, type, initialType, flowContainer);
                if (!isEvolvingArrayOperationTarget(node) && (type === autoType || type === autoArrayType)) {
                    if (flowType === autoType || flowType === autoArrayType) {
                        if (noImplicitAny) {
                            error(getNameOfDeclaration(declaration), Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined, symbolToString(symbol), typeToString(flowType));
                            error(node, Diagnostics.Variable_0_implicitly_has_an_1_type, symbolToString(symbol), typeToString(flowType));
                        }
                        return convertAutoToAny(flowType);
                    }
                }
                else if (!assumeInitialized && !containsUndefinedType(type) && containsUndefinedType(flowType)) {
                    error(node, Diagnostics.Variable_0_is_used_before_being_assigned, symbolToString(symbol));
                    return type;
                }
                return assignmentKind ? getBaseTypeOfLiteralType(flowType) : flowType;
            }
            function isSameScopedBindingElement(node, declaration) {
                if (isBindingElement(declaration)) {
                    const bindingElement = findAncestor(node, isBindingElement);
                    return bindingElement && getRootDeclaration(bindingElement) === getRootDeclaration(declaration);
                }
            }
            function shouldMarkIdentifierAliasReferenced(node) {
                var _a2;
                const parent2 = node.parent;
                if (parent2) {
                    if (isPropertyAccessExpression(parent2) && parent2.expression === node) {
                        return false;
                    }
                    if (isExportSpecifier(parent2) && parent2.isTypeOnly) {
                        return false;
                    }
                    const greatGrandparent = (_a2 = parent2.parent) == null ? void 0 : _a2.parent;
                    if (greatGrandparent && isExportDeclaration(greatGrandparent) && greatGrandparent.isTypeOnly) {
                        return false;
                    }
                }
                return true;
            }
            function isInsideFunctionOrInstancePropertyInitializer(node, threshold) {
                return !!findAncestor(node, (n) => n === threshold ? "quit" : isFunctionLike(n) || n.parent && isPropertyDeclaration(n.parent) && !hasStaticModifier(n.parent) && n.parent.initializer === n);
            }
            function getPartOfForStatementContainingNode(node, container) {
                return findAncestor(node, (n) => n === container ? "quit" : n === container.initializer || n === container.condition || n === container.incrementor || n === container.statement);
            }
            function getEnclosingIterationStatement(node) {
                return findAncestor(node, (n) => !n || nodeStartsNewLexicalEnvironment(n) ? "quit" : isIterationStatement(n, 
                /*lookInLabeledStatements*/
                false));
            }
            function checkNestedBlockScopedBinding(node, symbol) {
                if (languageVersion >= 2 /* ES2015 */ || (symbol.flags & (2 /* BlockScopedVariable */ | 32 /* Class */)) === 0 || !symbol.valueDeclaration || isSourceFile(symbol.valueDeclaration) || symbol.valueDeclaration.parent.kind === 295 /* CatchClause */) {
                    return;
                }
                const container = getEnclosingBlockScopeContainer(symbol.valueDeclaration);
                const isCaptured = isInsideFunctionOrInstancePropertyInitializer(node, container);
                const enclosingIterationStatement = getEnclosingIterationStatement(container);
                if (enclosingIterationStatement) {
                    if (isCaptured) {
                        let capturesBlockScopeBindingInLoopBody = true;
                        if (isForStatement(container)) {
                            const varDeclList = getAncestor(symbol.valueDeclaration, 258 /* VariableDeclarationList */);
                            if (varDeclList && varDeclList.parent === container) {
                                const part = getPartOfForStatementContainingNode(node.parent, container);
                                if (part) {
                                    const links = getNodeLinks(part);
                                    links.flags |= 8192 /* ContainsCapturedBlockScopeBinding */;
                                    const capturedBindings = links.capturedBlockScopeBindings || (links.capturedBlockScopeBindings = []);
                                    pushIfUnique(capturedBindings, symbol);
                                    if (part === container.initializer) {
                                        capturesBlockScopeBindingInLoopBody = false;
                                    }
                                }
                            }
                        }
                        if (capturesBlockScopeBindingInLoopBody) {
                            getNodeLinks(enclosingIterationStatement).flags |= 4096 /* LoopWithCapturedBlockScopedBinding */;
                        }
                    }
                    if (isForStatement(container)) {
                        const varDeclList = getAncestor(symbol.valueDeclaration, 258 /* VariableDeclarationList */);
                        if (varDeclList && varDeclList.parent === container && isAssignedInBodyOfForStatement(node, container)) {
                            getNodeLinks(symbol.valueDeclaration).flags |= 262144 /* NeedsLoopOutParameter */;
                        }
                    }
                    getNodeLinks(symbol.valueDeclaration).flags |= 32768 /* BlockScopedBindingInLoop */;
                }
                if (isCaptured) {
                    getNodeLinks(symbol.valueDeclaration).flags |= 16384 /* CapturedBlockScopedBinding */;
                }
            }
            function isBindingCapturedByNode(node, decl) {
                const links = getNodeLinks(node);
                return !!links && contains(links.capturedBlockScopeBindings, getSymbolOfDeclaration(decl));
            }
            function isAssignedInBodyOfForStatement(node, container) {
                let current = node;
                while (current.parent.kind === 214 /* ParenthesizedExpression */) {
                    current = current.parent;
                }
                let isAssigned = false;
                if (isAssignmentTarget(current)) {
                    isAssigned = true;
                }
                else if (current.parent.kind === 221 /* PrefixUnaryExpression */ || current.parent.kind === 222 /* PostfixUnaryExpression */) {
                    const expr = current.parent;
                    isAssigned = expr.operator === 45 /* PlusPlusToken */ || expr.operator === 46 /* MinusMinusToken */;
                }
                if (!isAssigned) {
                    return false;
                }
                return !!findAncestor(current, (n) => n === container ? "quit" : n === container.statement);
            }
            function captureLexicalThis(node, container) {
                getNodeLinks(node).flags |= 2 /* LexicalThis */;
                if (container.kind === 169 /* PropertyDeclaration */ || container.kind === 173 /* Constructor */) {
                    const classNode = container.parent;
                    getNodeLinks(classNode).flags |= 4 /* CaptureThis */;
                }
                else {
                    getNodeLinks(container).flags |= 4 /* CaptureThis */;
                }
            }
            function findFirstSuperCall(node) {
                return isSuperCall(node) ? node : isFunctionLike(node) ? void 0 : forEachChild(node, findFirstSuperCall);
            }
            function classDeclarationExtendsNull(classDecl) {
                const classSymbol = getSymbolOfDeclaration(classDecl);
                const classInstanceType = getDeclaredTypeOfSymbol(classSymbol);
                const baseConstructorType = getBaseConstructorTypeOfClass(classInstanceType);
                return baseConstructorType === nullWideningType;
            }
            function checkThisBeforeSuper(node, container, diagnosticMessage) {
                const containingClassDecl = container.parent;
                const baseTypeNode = getClassExtendsHeritageElement(containingClassDecl);
                if (baseTypeNode && !classDeclarationExtendsNull(containingClassDecl)) {
                    if (canHaveFlowNode(node) && node.flowNode && !isPostSuperFlowNode(node.flowNode, 
                    /*noCacheCheck*/
                    false)) {
                        error(node, diagnosticMessage);
                    }
                }
            }
            function checkThisInStaticClassFieldInitializerInDecoratedClass(thisExpression, container) {
                if (isPropertyDeclaration(container) && hasStaticModifier(container) && legacyDecorators && container.initializer && textRangeContainsPositionInclusive(container.initializer, thisExpression.pos) && hasDecorators(container.parent)) {
                    error(thisExpression, Diagnostics.Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class);
                }
            }
            function checkThisExpression(node) {
                const isNodeInTypeQuery = isInTypeQuery(node);
                let container = getThisContainer(node, 
                /* includeArrowFunctions */
                true, 
                /*includeClassComputedPropertyName*/
                true);
                let capturedByArrowFunction = false;
                let thisInComputedPropertyName = false;
                if (container.kind === 173 /* Constructor */) {
                    checkThisBeforeSuper(node, container, Diagnostics.super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class);
                }
                while (true) {
                    if (container.kind === 216 /* ArrowFunction */) {
                        container = getThisContainer(container, 
                        /* includeArrowFunctions */
                        false, !thisInComputedPropertyName);
                        capturedByArrowFunction = true;
                    }
                    if (container.kind === 164 /* ComputedPropertyName */) {
                        container = getThisContainer(container, !capturedByArrowFunction, 
                        /*includeClassComputedPropertyName*/
                        false);
                        thisInComputedPropertyName = true;
                        continue;
                    }
                    break;
                }
                checkThisInStaticClassFieldInitializerInDecoratedClass(node, container);
                if (thisInComputedPropertyName) {
                    error(node, Diagnostics.this_cannot_be_referenced_in_a_computed_property_name);
                }
                else {
                    switch (container.kind) {
                        case 264 /* ModuleDeclaration */:
                            error(node, Diagnostics.this_cannot_be_referenced_in_a_module_or_namespace_body);
                            break;
                        case 263 /* EnumDeclaration */:
                            error(node, Diagnostics.this_cannot_be_referenced_in_current_location);
                            break;
                        case 173 /* Constructor */:
                            if (isInConstructorArgumentInitializer(node, container)) {
                                error(node, Diagnostics.this_cannot_be_referenced_in_constructor_arguments);
                            }
                            break;
                    }
                }
                if (!isNodeInTypeQuery && capturedByArrowFunction && languageVersion < 2 /* ES2015 */) {
                    captureLexicalThis(node, container);
                }
                const type = tryGetThisTypeAt(node, 
                /*includeGlobalThis*/
                true, container);
                if (noImplicitThis) {
                    const globalThisType2 = getTypeOfSymbol(globalThisSymbol);
                    if (type === globalThisType2 && capturedByArrowFunction) {
                        error(node, Diagnostics.The_containing_arrow_function_captures_the_global_value_of_this);
                    }
                    else if (!type) {
                        const diag2 = error(node, Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation);
                        if (!isSourceFile(container)) {
                            const outsideThis = tryGetThisTypeAt(container);
                            if (outsideThis && outsideThis !== globalThisType2) {
                                addRelatedInfo(diag2, createDiagnosticForNode(container, Diagnostics.An_outer_value_of_this_is_shadowed_by_this_container));
                            }
                        }
                    }
                }
                return type || anyType;
            }
            function tryGetThisTypeAt(node, includeGlobalThis = true, container = getThisContainer(node, 
            /*includeArrowFunctions*/
            false, 
            /*includeClassComputedPropertyName*/
            false)) {
                const isInJS = isInJSFile(node);
                if (isFunctionLike(container) && (!isInParameterInitializerBeforeContainingFunction(node) || getThisParameter(container))) {
                    let thisType = getThisTypeOfDeclaration(container) || isInJS && getTypeForThisExpressionFromJSDoc(container);
                    if (!thisType) {
                        const className = getClassNameFromPrototypeMethod(container);
                        if (isInJS && className) {
                            const classSymbol = checkExpression(className).symbol;
                            if (classSymbol && classSymbol.members && classSymbol.flags & 16 /* Function */) {
                                thisType = getDeclaredTypeOfSymbol(classSymbol).thisType;
                            }
                        }
                        else if (isJSConstructor(container)) {
                            thisType = getDeclaredTypeOfSymbol(getMergedSymbol(container.symbol)).thisType;
                        }
                        thisType || (thisType = getContextualThisParameterType(container));
                    }
                    if (thisType) {
                        return getFlowTypeOfReference(node, thisType);
                    }
                }
                if (isClassLike(container.parent)) {
                    const symbol = getSymbolOfDeclaration(container.parent);
                    const type = isStatic(container) ? getTypeOfSymbol(symbol) : getDeclaredTypeOfSymbol(symbol).thisType;
                    return getFlowTypeOfReference(node, type);
                }
                if (isSourceFile(container)) {
                    if (container.commonJsModuleIndicator) {
                        const fileSymbol = getSymbolOfDeclaration(container);
                        return fileSymbol && getTypeOfSymbol(fileSymbol);
                    }
                    else if (container.externalModuleIndicator) {
                        return undefinedType;
                    }
                    else if (includeGlobalThis) {
                        return getTypeOfSymbol(globalThisSymbol);
                    }
                }
            }
            function getExplicitThisType(node) {
                const container = getThisContainer(node, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                if (isFunctionLike(container)) {
                    const signature = getSignatureFromDeclaration(container);
                    if (signature.thisParameter) {
                        return getExplicitTypeOfSymbol(signature.thisParameter);
                    }
                }
                if (isClassLike(container.parent)) {
                    const symbol = getSymbolOfDeclaration(container.parent);
                    return isStatic(container) ? getTypeOfSymbol(symbol) : getDeclaredTypeOfSymbol(symbol).thisType;
                }
            }
            function getClassNameFromPrototypeMethod(container) {
                if (container.kind === 215 /* FunctionExpression */ && isBinaryExpression(container.parent) && getAssignmentDeclarationKind(container.parent) === 3 /* PrototypeProperty */) {
                    return container.parent.left.expression.expression;
                }
                else if (container.kind === 171 /* MethodDeclaration */ && container.parent.kind === 207 /* ObjectLiteralExpression */ && isBinaryExpression(container.parent.parent) && getAssignmentDeclarationKind(container.parent.parent) === 6 /* Prototype */) {
                    return container.parent.parent.left.expression;
                }
                else if (container.kind === 215 /* FunctionExpression */ && container.parent.kind === 299 /* PropertyAssignment */ && container.parent.parent.kind === 207 /* ObjectLiteralExpression */ && isBinaryExpression(container.parent.parent.parent) && getAssignmentDeclarationKind(container.parent.parent.parent) === 6 /* Prototype */) {
                    return container.parent.parent.parent.left.expression;
                }
                else if (container.kind === 215 /* FunctionExpression */ && isPropertyAssignment(container.parent) && isIdentifier(container.parent.name) && (container.parent.name.escapedText === "value" || container.parent.name.escapedText === "get" || container.parent.name.escapedText === "set") && isObjectLiteralExpression(container.parent.parent) && isCallExpression(container.parent.parent.parent) && container.parent.parent.parent.arguments[2] === container.parent.parent && getAssignmentDeclarationKind(container.parent.parent.parent) === 9 /* ObjectDefinePrototypeProperty */) {
                    return container.parent.parent.parent.arguments[0].expression;
                }
                else if (isMethodDeclaration(container) && isIdentifier(container.name) && (container.name.escapedText === "value" || container.name.escapedText === "get" || container.name.escapedText === "set") && isObjectLiteralExpression(container.parent) && isCallExpression(container.parent.parent) && container.parent.parent.arguments[2] === container.parent && getAssignmentDeclarationKind(container.parent.parent) === 9 /* ObjectDefinePrototypeProperty */) {
                    return container.parent.parent.arguments[0].expression;
                }
            }
            function getTypeForThisExpressionFromJSDoc(node) {
                const jsdocType = getJSDocType(node);
                if (jsdocType && jsdocType.kind === 320 /* JSDocFunctionType */) {
                    const jsDocFunctionType = jsdocType;
                    if (jsDocFunctionType.parameters.length > 0 && jsDocFunctionType.parameters[0].name && jsDocFunctionType.parameters[0].name.escapedText === "this" /* This */) {
                        return getTypeFromTypeNode(jsDocFunctionType.parameters[0].type);
                    }
                }
                const thisTag = getJSDocThisTag(node);
                if (thisTag && thisTag.typeExpression) {
                    return getTypeFromTypeNode(thisTag.typeExpression);
                }
            }
            function isInConstructorArgumentInitializer(node, constructorDecl) {
                return !!findAncestor(node, (n) => isFunctionLikeDeclaration(n) ? "quit" : n.kind === 166 /* Parameter */ && n.parent === constructorDecl);
            }
            function checkSuperExpression(node) {
                const isCallExpression2 = node.parent.kind === 210 /* CallExpression */ && node.parent.expression === node;
                const immediateContainer = getSuperContainer(node, 
                /*stopOnFunctions*/
                true);
                let container = immediateContainer;
                let needToCaptureLexicalThis = false;
                let inAsyncFunction = false;
                if (!isCallExpression2) {
                    while (container && container.kind === 216 /* ArrowFunction */) {
                        if (hasSyntacticModifier(container, 512 /* Async */))
                            inAsyncFunction = true;
                        container = getSuperContainer(container, 
                        /*stopOnFunctions*/
                        true);
                        needToCaptureLexicalThis = languageVersion < 2 /* ES2015 */;
                    }
                    if (container && hasSyntacticModifier(container, 512 /* Async */))
                        inAsyncFunction = true;
                }
                let nodeCheckFlag = 0;
                if (!container || !isLegalUsageOfSuperExpression(container)) {
                    const current = findAncestor(node, (n) => n === container ? "quit" : n.kind === 164 /* ComputedPropertyName */);
                    if (current && current.kind === 164 /* ComputedPropertyName */) {
                        error(node, Diagnostics.super_cannot_be_referenced_in_a_computed_property_name);
                    }
                    else if (isCallExpression2) {
                        error(node, Diagnostics.Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors);
                    }
                    else if (!container || !container.parent || !(isClassLike(container.parent) || container.parent.kind === 207 /* ObjectLiteralExpression */)) {
                        error(node, Diagnostics.super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions);
                    }
                    else {
                        error(node, Diagnostics.super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class);
                    }
                    return errorType;
                }
                if (!isCallExpression2 && immediateContainer.kind === 173 /* Constructor */) {
                    checkThisBeforeSuper(node, container, Diagnostics.super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class);
                }
                if (isStatic(container) || isCallExpression2) {
                    nodeCheckFlag = 32 /* SuperStatic */;
                    if (!isCallExpression2 && languageVersion >= 2 /* ES2015 */ && languageVersion <= 8 /* ES2021 */ && (isPropertyDeclaration(container) || isClassStaticBlockDeclaration(container))) {
                        forEachEnclosingBlockScopeContainer(node.parent, (current) => {
                            if (!isSourceFile(current) || isExternalOrCommonJsModule(current)) {
                                getNodeLinks(current).flags |= 8388608 /* ContainsSuperPropertyInStaticInitializer */;
                            }
                        });
                    }
                }
                else {
                    nodeCheckFlag = 16 /* SuperInstance */;
                }
                getNodeLinks(node).flags |= nodeCheckFlag;
                if (container.kind === 171 /* MethodDeclaration */ && inAsyncFunction) {
                    if (isSuperProperty(node.parent) && isAssignmentTarget(node.parent)) {
                        getNodeLinks(container).flags |= 256 /* MethodWithSuperPropertyAssignmentInAsync */;
                    }
                    else {
                        getNodeLinks(container).flags |= 128 /* MethodWithSuperPropertyAccessInAsync */;
                    }
                }
                if (needToCaptureLexicalThis) {
                    captureLexicalThis(node.parent, container);
                }
                if (container.parent.kind === 207 /* ObjectLiteralExpression */) {
                    if (languageVersion < 2 /* ES2015 */) {
                        error(node, Diagnostics.super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher);
                        return errorType;
                    }
                    else {
                        return anyType;
                    }
                }
                const classLikeDeclaration = container.parent;
                if (!getClassExtendsHeritageElement(classLikeDeclaration)) {
                    error(node, Diagnostics.super_can_only_be_referenced_in_a_derived_class);
                    return errorType;
                }
                const classType = getDeclaredTypeOfSymbol(getSymbolOfDeclaration(classLikeDeclaration));
                const baseClassType = classType && getBaseTypes(classType)[0];
                if (!baseClassType) {
                    return errorType;
                }
                if (container.kind === 173 /* Constructor */ && isInConstructorArgumentInitializer(node, container)) {
                    error(node, Diagnostics.super_cannot_be_referenced_in_constructor_arguments);
                    return errorType;
                }
                return nodeCheckFlag === 32 /* SuperStatic */ ? getBaseConstructorTypeOfClass(classType) : getTypeWithThisArgument(baseClassType, classType.thisType);
                function isLegalUsageOfSuperExpression(container2) {
                    if (isCallExpression2) {
                        return container2.kind === 173 /* Constructor */;
                    }
                    else {
                        if (isClassLike(container2.parent) || container2.parent.kind === 207 /* ObjectLiteralExpression */) {
                            if (isStatic(container2)) {
                                return container2.kind === 171 /* MethodDeclaration */ || container2.kind === 170 /* MethodSignature */ || container2.kind === 174 /* GetAccessor */ || container2.kind === 175 /* SetAccessor */ || container2.kind === 169 /* PropertyDeclaration */ || container2.kind === 172 /* ClassStaticBlockDeclaration */;
                            }
                            else {
                                return container2.kind === 171 /* MethodDeclaration */ || container2.kind === 170 /* MethodSignature */ || container2.kind === 174 /* GetAccessor */ || container2.kind === 175 /* SetAccessor */ || container2.kind === 169 /* PropertyDeclaration */ || container2.kind === 168 /* PropertySignature */ || container2.kind === 173 /* Constructor */;
                            }
                        }
                    }
                    return false;
                }
            }
            function getContainingObjectLiteral(func) {
                return (func.kind === 171 /* MethodDeclaration */ || func.kind === 174 /* GetAccessor */ || func.kind === 175 /* SetAccessor */) && func.parent.kind === 207 /* ObjectLiteralExpression */ ? func.parent : func.kind === 215 /* FunctionExpression */ && func.parent.kind === 299 /* PropertyAssignment */ ? func.parent.parent : void 0;
            }
            function getThisTypeArgument(type) {
                return getObjectFlags(type) & 4 /* Reference */ && type.target === globalThisType ? getTypeArguments(type)[0] : void 0;
            }
            function getThisTypeFromContextualType(type) {
                return mapType(type, (t) => {
                    return t.flags & 2097152 /* Intersection */ ? forEach(t.types, getThisTypeArgument) : getThisTypeArgument(t);
                });
            }
            function getContextualThisParameterType(func) {
                if (func.kind === 216 /* ArrowFunction */) {
                    return void 0;
                }
                if (isContextSensitiveFunctionOrObjectLiteralMethod(func)) {
                    const contextualSignature = getContextualSignature(func);
                    if (contextualSignature) {
                        const thisParameter = contextualSignature.thisParameter;
                        if (thisParameter) {
                            return getTypeOfSymbol(thisParameter);
                        }
                    }
                }
                const inJs = isInJSFile(func);
                if (noImplicitThis || inJs) {
                    const containingLiteral = getContainingObjectLiteral(func);
                    if (containingLiteral) {
                        const contextualType = getApparentTypeOfContextualType(containingLiteral, 
                        /*contextFlags*/
                        void 0);
                        let literal = containingLiteral;
                        let type = contextualType;
                        while (type) {
                            const thisType = getThisTypeFromContextualType(type);
                            if (thisType) {
                                return instantiateType(thisType, getMapperFromContext(getInferenceContext(containingLiteral)));
                            }
                            if (literal.parent.kind !== 299 /* PropertyAssignment */) {
                                break;
                            }
                            literal = literal.parent.parent;
                            type = getApparentTypeOfContextualType(literal, 
                            /*contextFlags*/
                            void 0);
                        }
                        return getWidenedType(contextualType ? getNonNullableType(contextualType) : checkExpressionCached(containingLiteral));
                    }
                    const parent2 = walkUpParenthesizedExpressions(func.parent);
                    if (parent2.kind === 223 /* BinaryExpression */ && parent2.operatorToken.kind === 63 /* EqualsToken */) {
                        const target = parent2.left;
                        if (isAccessExpression(target)) {
                            const { expression } = target;
                            if (inJs && isIdentifier(expression)) {
                                const sourceFile = getSourceFileOfNode(parent2);
                                if (sourceFile.commonJsModuleIndicator && getResolvedSymbol(expression) === sourceFile.symbol) {
                                    return void 0;
                                }
                            }
                            return getWidenedType(checkExpressionCached(expression));
                        }
                    }
                }
                return void 0;
            }
            function getContextuallyTypedParameterType(parameter) {
                const func = parameter.parent;
                if (!isContextSensitiveFunctionOrObjectLiteralMethod(func)) {
                    return void 0;
                }
                const iife = getImmediatelyInvokedFunctionExpression(func);
                if (iife && iife.arguments) {
                    const args = getEffectiveCallArguments(iife);
                    const indexOfParameter = func.parameters.indexOf(parameter);
                    if (parameter.dotDotDotToken) {
                        return getSpreadArgumentType(args, indexOfParameter, args.length, anyType, 
                        /*context*/
                        void 0, 0 /* Normal */);
                    }
                    const links = getNodeLinks(iife);
                    const cached = links.resolvedSignature;
                    links.resolvedSignature = anySignature;
                    const type = indexOfParameter < args.length ? getWidenedLiteralType(checkExpression(args[indexOfParameter])) : parameter.initializer ? void 0 : undefinedWideningType;
                    links.resolvedSignature = cached;
                    return type;
                }
                const contextualSignature = getContextualSignature(func);
                if (contextualSignature) {
                    const index = func.parameters.indexOf(parameter) - (getThisParameter(func) ? 1 : 0);
                    return parameter.dotDotDotToken && lastOrUndefined(func.parameters) === parameter ? getRestTypeAtPosition(contextualSignature, index) : tryGetTypeAtPosition(contextualSignature, index);
                }
            }
            function getContextualTypeForVariableLikeDeclaration(declaration, contextFlags) {
                const typeNode = getEffectiveTypeAnnotationNode(declaration) || (isInJSFile(declaration) ? tryGetJSDocSatisfiesTypeNode(declaration) : void 0);
                if (typeNode) {
                    return getTypeFromTypeNode(typeNode);
                }
                switch (declaration.kind) {
                    case 166 /* Parameter */:
                        return getContextuallyTypedParameterType(declaration);
                    case 205 /* BindingElement */:
                        return getContextualTypeForBindingElement(declaration, contextFlags);
                    case 169 /* PropertyDeclaration */:
                        if (isStatic(declaration)) {
                            return getContextualTypeForStaticPropertyDeclaration(declaration, contextFlags);
                        }
                }
            }
            function getContextualTypeForBindingElement(declaration, contextFlags) {
                const parent2 = declaration.parent.parent;
                const name = declaration.propertyName || declaration.name;
                const parentType = getContextualTypeForVariableLikeDeclaration(parent2, contextFlags) || parent2.kind !== 205 /* BindingElement */ && parent2.initializer && checkDeclarationInitializer(parent2, declaration.dotDotDotToken ? 64 /* RestBindingElement */ : 0 /* Normal */);
                if (!parentType || isBindingPattern(name) || isComputedNonLiteralName(name))
                    return void 0;
                if (parent2.name.kind === 204 /* ArrayBindingPattern */) {
                    const index = indexOfNode(declaration.parent.elements, declaration);
                    if (index < 0)
                        return void 0;
                    return getContextualTypeForElementExpression(parentType, index);
                }
                const nameType = getLiteralTypeFromPropertyName(name);
                if (isTypeUsableAsPropertyName(nameType)) {
                    const text = getPropertyNameFromType(nameType);
                    return getTypeOfPropertyOfType(parentType, text);
                }
            }
            function getContextualTypeForStaticPropertyDeclaration(declaration, contextFlags) {
                const parentType = isExpression(declaration.parent) && getContextualType2(declaration.parent, contextFlags);
                if (!parentType)
                    return void 0;
                return getTypeOfPropertyOfContextualType(parentType, getSymbolOfDeclaration(declaration).escapedName);
            }
            function getContextualTypeForInitializerExpression(node, contextFlags) {
                const declaration = node.parent;
                if (hasInitializer(declaration) && node === declaration.initializer) {
                    const result = getContextualTypeForVariableLikeDeclaration(declaration, contextFlags);
                    if (result) {
                        return result;
                    }
                    if (!(contextFlags & 8 /* SkipBindingPatterns */) && isBindingPattern(declaration.name) && declaration.name.elements.length > 0) {
                        return getTypeFromBindingPattern(declaration.name, 
                        /*includePatternInType*/
                        true, 
                        /*reportErrors*/
                        false);
                    }
                }
                return void 0;
            }
            function getContextualTypeForReturnExpression(node, contextFlags) {
                const func = getContainingFunction(node);
                if (func) {
                    let contextualReturnType = getContextualReturnType(func, contextFlags);
                    if (contextualReturnType) {
                        const functionFlags = getFunctionFlags(func);
                        if (functionFlags & 1 /* Generator */) {
                            const isAsyncGenerator = (functionFlags & 2 /* Async */) !== 0;
                            if (contextualReturnType.flags & 1048576 /* Union */) {
                                contextualReturnType = filterType(contextualReturnType, (type) => !!getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, type, isAsyncGenerator));
                            }
                            const iterationReturnType = getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, contextualReturnType, (functionFlags & 2 /* Async */) !== 0);
                            if (!iterationReturnType) {
                                return void 0;
                            }
                            contextualReturnType = iterationReturnType;
                        }
                        if (functionFlags & 2 /* Async */) {
                            const contextualAwaitedType = mapType(contextualReturnType, getAwaitedTypeNoAlias);
                            return contextualAwaitedType && getUnionType([contextualAwaitedType, createPromiseLikeType(contextualAwaitedType)]);
                        }
                        return contextualReturnType;
                    }
                }
                return void 0;
            }
            function getContextualTypeForAwaitOperand(node, contextFlags) {
                const contextualType = getContextualType2(node, contextFlags);
                if (contextualType) {
                    const contextualAwaitedType = getAwaitedTypeNoAlias(contextualType);
                    return contextualAwaitedType && getUnionType([contextualAwaitedType, createPromiseLikeType(contextualAwaitedType)]);
                }
                return void 0;
            }
            function getContextualTypeForYieldOperand(node, contextFlags) {
                const func = getContainingFunction(node);
                if (func) {
                    const functionFlags = getFunctionFlags(func);
                    let contextualReturnType = getContextualReturnType(func, contextFlags);
                    if (contextualReturnType) {
                        const isAsyncGenerator = (functionFlags & 2 /* Async */) !== 0;
                        if (!node.asteriskToken && contextualReturnType.flags & 1048576 /* Union */) {
                            contextualReturnType = filterType(contextualReturnType, (type) => !!getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, type, isAsyncGenerator));
                        }
                        return node.asteriskToken ? contextualReturnType : getIterationTypeOfGeneratorFunctionReturnType(0 /* Yield */, contextualReturnType, isAsyncGenerator);
                    }
                }
                return void 0;
            }
            function isInParameterInitializerBeforeContainingFunction(node) {
                let inBindingInitializer = false;
                while (node.parent && !isFunctionLike(node.parent)) {
                    if (isParameter(node.parent) && (inBindingInitializer || node.parent.initializer === node)) {
                        return true;
                    }
                    if (isBindingElement(node.parent) && node.parent.initializer === node) {
                        inBindingInitializer = true;
                    }
                    node = node.parent;
                }
                return false;
            }
            function getContextualIterationType(kind, functionDecl) {
                const isAsync = !!(getFunctionFlags(functionDecl) & 2 /* Async */);
                const contextualReturnType = getContextualReturnType(functionDecl, 
                /*contextFlags*/
                void 0);
                if (contextualReturnType) {
                    return getIterationTypeOfGeneratorFunctionReturnType(kind, contextualReturnType, isAsync) || void 0;
                }
                return void 0;
            }
            function getContextualReturnType(functionDecl, contextFlags) {
                const returnType = getReturnTypeFromAnnotation(functionDecl);
                if (returnType) {
                    return returnType;
                }
                const signature = getContextualSignatureForFunctionLikeDeclaration(functionDecl);
                if (signature && !isResolvingReturnTypeOfSignature(signature)) {
                    return getReturnTypeOfSignature(signature);
                }
                const iife = getImmediatelyInvokedFunctionExpression(functionDecl);
                if (iife) {
                    return getContextualType2(iife, contextFlags);
                }
                return void 0;
            }
            function getContextualTypeForArgument(callTarget, arg) {
                const args = getEffectiveCallArguments(callTarget);
                const argIndex = args.indexOf(arg);
                return argIndex === -1 ? void 0 : getContextualTypeForArgumentAtIndex(callTarget, argIndex);
            }
            function getContextualTypeForArgumentAtIndex(callTarget, argIndex) {
                if (isImportCall(callTarget)) {
                    return argIndex === 0 ? stringType : argIndex === 1 ? getGlobalImportCallOptionsType(
                    /*reportErrors*/
                    false) : anyType;
                }
                const signature = getNodeLinks(callTarget).resolvedSignature === resolvingSignature ? resolvingSignature : getResolvedSignature(callTarget);
                if (isJsxOpeningLikeElement(callTarget) && argIndex === 0) {
                    return getEffectiveFirstArgumentForJsxSignature(signature, callTarget);
                }
                const restIndex = signature.parameters.length - 1;
                return signatureHasRestParameter(signature) && argIndex >= restIndex ? getIndexedAccessType(getTypeOfSymbol(signature.parameters[restIndex]), getNumberLiteralType(argIndex - restIndex), 256 /* Contextual */) : getTypeAtPosition(signature, argIndex);
            }
            function getContextualTypeForDecorator(decorator) {
                const signature = getDecoratorCallSignature(decorator);
                return signature ? getOrCreateTypeFromSignature(signature) : void 0;
            }
            function getContextualTypeForSubstitutionExpression(template, substitutionExpression) {
                if (template.parent.kind === 212 /* TaggedTemplateExpression */) {
                    return getContextualTypeForArgument(template.parent, substitutionExpression);
                }
                return void 0;
            }
            function getContextualTypeForBinaryOperand(node, contextFlags) {
                const binaryExpression = node.parent;
                const { left, operatorToken, right } = binaryExpression;
                switch (operatorToken.kind) {
                    case 63 /* EqualsToken */:
                    case 76 /* AmpersandAmpersandEqualsToken */:
                    case 75 /* BarBarEqualsToken */:
                    case 77 /* QuestionQuestionEqualsToken */:
                        return node === right ? getContextualTypeForAssignmentDeclaration(binaryExpression) : void 0;
                    case 56 /* BarBarToken */:
                    case 60 /* QuestionQuestionToken */:
                        const type = getContextualType2(binaryExpression, contextFlags);
                        return node === right && (type && type.pattern || !type && !isDefaultedExpandoInitializer(binaryExpression)) ? getTypeOfExpression(left) : type;
                    case 55 /* AmpersandAmpersandToken */:
                    case 27 /* CommaToken */:
                        return node === right ? getContextualType2(binaryExpression, contextFlags) : void 0;
                    default:
                        return void 0;
                }
            }
            function getSymbolForExpression(e) {
                if (canHaveSymbol(e) && e.symbol) {
                    return e.symbol;
                }
                if (isIdentifier(e)) {
                    return getResolvedSymbol(e);
                }
                if (isPropertyAccessExpression(e)) {
                    const lhsType = getTypeOfExpression(e.expression);
                    return isPrivateIdentifier(e.name) ? tryGetPrivateIdentifierPropertyOfType(lhsType, e.name) : getPropertyOfType(lhsType, e.name.escapedText);
                }
                if (isElementAccessExpression(e)) {
                    const propType = checkExpressionCached(e.argumentExpression);
                    if (!isTypeUsableAsPropertyName(propType)) {
                        return void 0;
                    }
                    const lhsType = getTypeOfExpression(e.expression);
                    return getPropertyOfType(lhsType, getPropertyNameFromType(propType));
                }
                return void 0;
                function tryGetPrivateIdentifierPropertyOfType(type, id) {
                    const lexicallyScopedSymbol = lookupSymbolForPrivateIdentifierDeclaration(id.escapedText, id);
                    return lexicallyScopedSymbol && getPrivateIdentifierPropertyOfType(type, lexicallyScopedSymbol);
                }
            }
            function getContextualTypeForAssignmentDeclaration(binaryExpression) {
                var _a2, _b;
                const kind = getAssignmentDeclarationKind(binaryExpression);
                switch (kind) {
                    case 0 /* None */:
                    case 4 /* ThisProperty */:
                        const lhsSymbol = getSymbolForExpression(binaryExpression.left);
                        const decl = lhsSymbol && lhsSymbol.valueDeclaration;
                        if (decl && (isPropertyDeclaration(decl) || isPropertySignature(decl))) {
                            const overallAnnotation = getEffectiveTypeAnnotationNode(decl);
                            return overallAnnotation && instantiateType(getTypeFromTypeNode(overallAnnotation), getSymbolLinks(lhsSymbol).mapper) || (isPropertyDeclaration(decl) ? decl.initializer && getTypeOfExpression(binaryExpression.left) : void 0);
                        }
                        if (kind === 0 /* None */) {
                            return getTypeOfExpression(binaryExpression.left);
                        }
                        return getContextualTypeForThisPropertyAssignment(binaryExpression);
                    case 5 /* Property */:
                        if (isPossiblyAliasedThisProperty(binaryExpression, kind)) {
                            return getContextualTypeForThisPropertyAssignment(binaryExpression);
                        }
                        else if (!canHaveSymbol(binaryExpression.left) || !binaryExpression.left.symbol) {
                            return getTypeOfExpression(binaryExpression.left);
                        }
                        else {
                            const decl2 = binaryExpression.left.symbol.valueDeclaration;
                            if (!decl2) {
                                return void 0;
                            }
                            const lhs = cast(binaryExpression.left, isAccessExpression);
                            const overallAnnotation = getEffectiveTypeAnnotationNode(decl2);
                            if (overallAnnotation) {
                                return getTypeFromTypeNode(overallAnnotation);
                            }
                            else if (isIdentifier(lhs.expression)) {
                                const id = lhs.expression;
                                const parentSymbol = resolveName(id, id.escapedText, 111551 /* Value */, void 0, id.escapedText, 
                                /*isUse*/
                                true);
                                if (parentSymbol) {
                                    const annotated2 = parentSymbol.valueDeclaration && getEffectiveTypeAnnotationNode(parentSymbol.valueDeclaration);
                                    if (annotated2) {
                                        const nameStr = getElementOrPropertyAccessName(lhs);
                                        if (nameStr !== void 0) {
                                            return getTypeOfPropertyOfContextualType(getTypeFromTypeNode(annotated2), nameStr);
                                        }
                                    }
                                    return void 0;
                                }
                            }
                            return isInJSFile(decl2) ? void 0 : getTypeOfExpression(binaryExpression.left);
                        }
                    case 1 /* ExportsProperty */:
                    case 6 /* Prototype */:
                    case 3 /* PrototypeProperty */:
                    case 2 /* ModuleExports */:
                        let valueDeclaration;
                        if (kind !== 2 /* ModuleExports */) {
                            valueDeclaration = canHaveSymbol(binaryExpression.left) ? (_a2 = binaryExpression.left.symbol) == null ? void 0 : _a2.valueDeclaration : void 0;
                        }
                        valueDeclaration || (valueDeclaration = (_b = binaryExpression.symbol) == null ? void 0 : _b.valueDeclaration);
                        const annotated = valueDeclaration && getEffectiveTypeAnnotationNode(valueDeclaration);
                        return annotated ? getTypeFromTypeNode(annotated) : void 0;
                    case 7 /* ObjectDefinePropertyValue */:
                    case 8 /* ObjectDefinePropertyExports */:
                    case 9 /* ObjectDefinePrototypeProperty */:
                        return Debug.fail("Does not apply");
                    default:
                        return Debug.assertNever(kind);
                }
            }
            function isPossiblyAliasedThisProperty(declaration, kind = getAssignmentDeclarationKind(declaration)) {
                if (kind === 4 /* ThisProperty */) {
                    return true;
                }
                if (!isInJSFile(declaration) || kind !== 5 /* Property */ || !isIdentifier(declaration.left.expression)) {
                    return false;
                }
                const name = declaration.left.expression.escapedText;
                const symbol = resolveName(declaration.left, name, 111551 /* Value */, void 0, void 0, 
                /*isUse*/
                true, 
                /*excludeGlobals*/
                true);
                return isThisInitializedDeclaration(symbol == null ? void 0 : symbol.valueDeclaration);
            }
            function getContextualTypeForThisPropertyAssignment(binaryExpression) {
                if (!binaryExpression.symbol)
                    return getTypeOfExpression(binaryExpression.left);
                if (binaryExpression.symbol.valueDeclaration) {
                    const annotated = getEffectiveTypeAnnotationNode(binaryExpression.symbol.valueDeclaration);
                    if (annotated) {
                        const type = getTypeFromTypeNode(annotated);
                        if (type) {
                            return type;
                        }
                    }
                }
                const thisAccess = cast(binaryExpression.left, isAccessExpression);
                if (!isObjectLiteralMethod(getThisContainer(thisAccess.expression, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false))) {
                    return void 0;
                }
                const thisType = checkThisExpression(thisAccess.expression);
                const nameStr = getElementOrPropertyAccessName(thisAccess);
                return nameStr !== void 0 && getTypeOfPropertyOfContextualType(thisType, nameStr) || void 0;
            }
            function isCircularMappedProperty(symbol) {
                return !!(getCheckFlags(symbol) & 262144 /* Mapped */ && !symbol.links.type && findResolutionCycleStartIndex(symbol, 0 /* Type */) >= 0);
            }
            function getTypeOfPropertyOfContextualType(type, name, nameType) {
                return mapType(type, (t) => {
                    var _a2;
                    if (isGenericMappedType(t) && !t.declaration.nameType) {
                        const constraint = getConstraintTypeFromMappedType(t);
                        const constraintOfConstraint = getBaseConstraintOfType(constraint) || constraint;
                        const propertyNameType = nameType || getStringLiteralType(unescapeLeadingUnderscores(name));
                        if (isTypeAssignableTo(propertyNameType, constraintOfConstraint)) {
                            return substituteIndexedMappedType(t, propertyNameType);
                        }
                    }
                    else if (t.flags & 3670016 /* StructuredType */) {
                        const prop = getPropertyOfType(t, name);
                        if (prop) {
                            return isCircularMappedProperty(prop) ? void 0 : getTypeOfSymbol(prop);
                        }
                        if (isTupleType(t) && isNumericLiteralName(name) && +name >= 0) {
                            const restType = getElementTypeOfSliceOfTupleType(t, t.target.fixedLength, 
                            /*endSkipCount*/
                            0, 
                            /*writing*/
                            false, 
                            /*noReductions*/
                            true);
                            if (restType) {
                                return restType;
                            }
                        }
                        return (_a2 = findApplicableIndexInfo(getIndexInfosOfStructuredType(t), nameType || getStringLiteralType(unescapeLeadingUnderscores(name)))) == null ? void 0 : _a2.type;
                    }
                    return void 0;
                }, 
                /*noReductions*/
                true);
            }
            function getContextualTypeForObjectLiteralMethod(node, contextFlags) {
                Debug.assert(isObjectLiteralMethod(node));
                if (node.flags & 33554432 /* InWithStatement */) {
                    return void 0;
                }
                return getContextualTypeForObjectLiteralElement(node, contextFlags);
            }
            function getContextualTypeForObjectLiteralElement(element, contextFlags) {
                const objectLiteral = element.parent;
                const propertyAssignmentType = isPropertyAssignment(element) && getContextualTypeForVariableLikeDeclaration(element, contextFlags);
                if (propertyAssignmentType) {
                    return propertyAssignmentType;
                }
                const type = getApparentTypeOfContextualType(objectLiteral, contextFlags);
                if (type) {
                    if (hasBindableName(element)) {
                        const symbol = getSymbolOfDeclaration(element);
                        return getTypeOfPropertyOfContextualType(type, symbol.escapedName, getSymbolLinks(symbol).nameType);
                    }
                    if (element.name) {
                        const nameType = getLiteralTypeFromPropertyName(element.name);
                        return mapType(type, (t) => {
                            var _a2;
                            return (_a2 = findApplicableIndexInfo(getIndexInfosOfStructuredType(t), nameType)) == null ? void 0 : _a2.type;
                        }, 
                        /*noReductions*/
                        true);
                    }
                }
                return void 0;
            }
            function getContextualTypeForElementExpression(arrayContextualType, index) {
                return arrayContextualType && (index >= 0 && getTypeOfPropertyOfContextualType(arrayContextualType, "" + index) || mapType(arrayContextualType, (t) => isTupleType(t) ? getElementTypeOfSliceOfTupleType(t, 0, 
                /*endSkipCount*/
                0, 
                /*writing*/
                false, 
                /*noReductions*/
                true) : getIteratedTypeOrElementType(1 /* Element */, t, undefinedType, 
                /*errorNode*/
                void 0, 
                /*checkAssignability*/
                false), 
                /*noReductions*/
                true));
            }
            function getContextualTypeForConditionalOperand(node, contextFlags) {
                const conditional = node.parent;
                return node === conditional.whenTrue || node === conditional.whenFalse ? getContextualType2(conditional, contextFlags) : void 0;
            }
            function getContextualTypeForChildJsxExpression(node, child, contextFlags) {
                const attributesType = getApparentTypeOfContextualType(node.openingElement.tagName, contextFlags);
                const jsxChildrenPropertyName = getJsxElementChildrenPropertyName(getJsxNamespaceAt(node));
                if (!(attributesType && !isTypeAny(attributesType) && jsxChildrenPropertyName && jsxChildrenPropertyName !== "")) {
                    return void 0;
                }
                const realChildren = getSemanticJsxChildren(node.children);
                const childIndex = realChildren.indexOf(child);
                const childFieldType = getTypeOfPropertyOfContextualType(attributesType, jsxChildrenPropertyName);
                return childFieldType && (realChildren.length === 1 ? childFieldType : mapType(childFieldType, (t) => {
                    if (isArrayLikeType(t)) {
                        return getIndexedAccessType(t, getNumberLiteralType(childIndex));
                    }
                    else {
                        return t;
                    }
                }, 
                /*noReductions*/
                true));
            }
            function getContextualTypeForJsxExpression(node, contextFlags) {
                const exprParent = node.parent;
                return isJsxAttributeLike(exprParent) ? getContextualType2(node, contextFlags) : isJsxElement(exprParent) ? getContextualTypeForChildJsxExpression(exprParent, node, contextFlags) : void 0;
            }
            function getContextualTypeForJsxAttribute(attribute, contextFlags) {
                if (isJsxAttribute(attribute)) {
                    const attributesType = getApparentTypeOfContextualType(attribute.parent, contextFlags);
                    if (!attributesType || isTypeAny(attributesType)) {
                        return void 0;
                    }
                    return getTypeOfPropertyOfContextualType(attributesType, attribute.name.escapedText);
                }
                else {
                    return getContextualType2(attribute.parent, contextFlags);
                }
            }
            function isPossiblyDiscriminantValue(node) {
                switch (node.kind) {
                    case 10 /* StringLiteral */:
                    case 8 /* NumericLiteral */:
                    case 9 /* BigIntLiteral */:
                    case 14 /* NoSubstitutionTemplateLiteral */:
                    case 110 /* TrueKeyword */:
                    case 95 /* FalseKeyword */:
                    case 104 /* NullKeyword */:
                    case 79 /* Identifier */:
                    case 155 /* UndefinedKeyword */:
                        return true;
                    case 208 /* PropertyAccessExpression */:
                    case 214 /* ParenthesizedExpression */:
                        return isPossiblyDiscriminantValue(node.expression);
                    case 291 /* JsxExpression */:
                        return !node.expression || isPossiblyDiscriminantValue(node.expression);
                }
                return false;
            }
            function discriminateContextualTypeByObjectMembers(node, contextualType) {
                return getMatchingUnionConstituentForObjectLiteral(contextualType, node) || discriminateTypeByDiscriminableItems(contextualType, concatenate(map(filter(node.properties, (p) => !!p.symbol && p.kind === 299 /* PropertyAssignment */ && isPossiblyDiscriminantValue(p.initializer) && isDiscriminantProperty(contextualType, p.symbol.escapedName)), (prop) => [() => getContextFreeTypeOfExpression(prop.initializer), prop.symbol.escapedName]), map(filter(getPropertiesOfType(contextualType), (s) => {
                    var _a2;
                    return !!(s.flags & 16777216 /* Optional */) && !!((_a2 = node == null ? void 0 : node.symbol) == null ? void 0 : _a2.members) && !node.symbol.members.has(s.escapedName) && isDiscriminantProperty(contextualType, s.escapedName);
                }), (s) => [() => undefinedType, s.escapedName])), isTypeAssignableTo, contextualType);
            }
            function discriminateContextualTypeByJSXAttributes(node, contextualType) {
                return discriminateTypeByDiscriminableItems(contextualType, concatenate(map(filter(node.properties, (p) => !!p.symbol && p.kind === 288 /* JsxAttribute */ && isDiscriminantProperty(contextualType, p.symbol.escapedName) && (!p.initializer || isPossiblyDiscriminantValue(p.initializer))), (prop) => [!prop.initializer ? () => trueType : () => getContextFreeTypeOfExpression(prop.initializer), prop.symbol.escapedName]), map(filter(getPropertiesOfType(contextualType), (s) => {
                    var _a2;
                    return !!(s.flags & 16777216 /* Optional */) && !!((_a2 = node == null ? void 0 : node.symbol) == null ? void 0 : _a2.members) && !node.symbol.members.has(s.escapedName) && isDiscriminantProperty(contextualType, s.escapedName);
                }), (s) => [() => undefinedType, s.escapedName])), isTypeAssignableTo, contextualType);
            }
            function getApparentTypeOfContextualType(node, contextFlags) {
                const contextualType = isObjectLiteralMethod(node) ? getContextualTypeForObjectLiteralMethod(node, contextFlags) : getContextualType2(node, contextFlags);
                const instantiatedType = instantiateContextualType(contextualType, node, contextFlags);
                if (instantiatedType && !(contextFlags && contextFlags & 2 /* NoConstraints */ && instantiatedType.flags & 8650752 /* TypeVariable */)) {
                    const apparentType = mapType(instantiatedType, getApparentType, 
                    /*noReductions*/
                    true);
                    return apparentType.flags & 1048576 /* Union */ && isObjectLiteralExpression(node) ? discriminateContextualTypeByObjectMembers(node, apparentType) : apparentType.flags & 1048576 /* Union */ && isJsxAttributes(node) ? discriminateContextualTypeByJSXAttributes(node, apparentType) : apparentType;
                }
            }
            function instantiateContextualType(contextualType, node, contextFlags) {
                if (contextualType && maybeTypeOfKind(contextualType, 465829888 /* Instantiable */)) {
                    const inferenceContext = getInferenceContext(node);
                    if (inferenceContext && contextFlags & 1 /* Signature */ && some(inferenceContext.inferences, hasInferenceCandidatesOrDefault)) {
                        return instantiateInstantiableTypes(contextualType, inferenceContext.nonFixingMapper);
                    }
                    if (inferenceContext == null ? void 0 : inferenceContext.returnMapper) {
                        const type = instantiateInstantiableTypes(contextualType, inferenceContext.returnMapper);
                        return type.flags & 1048576 /* Union */ && containsType(type.types, regularFalseType) && containsType(type.types, regularTrueType) ? filterType(type, (t) => t !== regularFalseType && t !== regularTrueType) : type;
                    }
                }
                return contextualType;
            }
            function instantiateInstantiableTypes(type, mapper) {
                if (type.flags & 465829888 /* Instantiable */) {
                    return instantiateType(type, mapper);
                }
                if (type.flags & 1048576 /* Union */) {
                    return getUnionType(map(type.types, (t) => instantiateInstantiableTypes(t, mapper)), 0 /* None */);
                }
                if (type.flags & 2097152 /* Intersection */) {
                    return getIntersectionType(map(type.types, (t) => instantiateInstantiableTypes(t, mapper)));
                }
                return type;
            }
            function getContextualType2(node, contextFlags) {
                var _a2, _b;
                if (node.flags & 33554432 /* InWithStatement */) {
                    return void 0;
                }
                const index = findContextualNode(node, 
                /*includeCaches*/
                !contextFlags);
                if (index >= 0) {
                    return contextualTypes[index];
                }
                const { parent: parent2 } = node;
                switch (parent2.kind) {
                    case 257 /* VariableDeclaration */:
                    case 166 /* Parameter */:
                    case 169 /* PropertyDeclaration */:
                    case 168 /* PropertySignature */:
                    case 205 /* BindingElement */:
                        return getContextualTypeForInitializerExpression(node, contextFlags);
                    case 216 /* ArrowFunction */:
                    case 250 /* ReturnStatement */:
                        return getContextualTypeForReturnExpression(node, contextFlags);
                    case 226 /* YieldExpression */:
                        return getContextualTypeForYieldOperand(parent2, contextFlags);
                    case 220 /* AwaitExpression */:
                        return getContextualTypeForAwaitOperand(parent2, contextFlags);
                    case 210 /* CallExpression */:
                    case 211 /* NewExpression */:
                        return getContextualTypeForArgument(parent2, node);
                    case 167 /* Decorator */:
                        return getContextualTypeForDecorator(parent2);
                    case 213 /* TypeAssertionExpression */:
                    case 231 /* AsExpression */:
                        return isConstTypeReference(parent2.type) ? getContextualType2(parent2, contextFlags) : getTypeFromTypeNode(parent2.type);
                    case 223 /* BinaryExpression */:
                        return getContextualTypeForBinaryOperand(node, contextFlags);
                    case 299 /* PropertyAssignment */:
                    case 300 /* ShorthandPropertyAssignment */:
                        return getContextualTypeForObjectLiteralElement(parent2, contextFlags);
                    case 301 /* SpreadAssignment */:
                        return getContextualType2(parent2.parent, contextFlags);
                    case 206 /* ArrayLiteralExpression */: {
                        const arrayLiteral = parent2;
                        const type = getApparentTypeOfContextualType(arrayLiteral, contextFlags);
                        const spreadIndex = (_b = (_a2 = getNodeLinks(arrayLiteral)).firstSpreadIndex) != null ? _b : _a2.firstSpreadIndex = findIndex(arrayLiteral.elements, isSpreadElement);
                        const elementIndex = indexOfNode(arrayLiteral.elements, node);
                        return getContextualTypeForElementExpression(type, spreadIndex < 0 || elementIndex < spreadIndex ? elementIndex : -1);
                    }
                    case 224 /* ConditionalExpression */:
                        return getContextualTypeForConditionalOperand(node, contextFlags);
                    case 236 /* TemplateSpan */:
                        Debug.assert(parent2.parent.kind === 225 /* TemplateExpression */);
                        return getContextualTypeForSubstitutionExpression(parent2.parent, node);
                    case 214 /* ParenthesizedExpression */: {
                        if (isInJSFile(parent2)) {
                            if (isJSDocSatisfiesExpression(parent2)) {
                                return getTypeFromTypeNode(getJSDocSatisfiesExpressionType(parent2));
                            }
                            const typeTag = getJSDocTypeTag(parent2);
                            if (typeTag && !isConstTypeReference(typeTag.typeExpression.type)) {
                                return getTypeFromTypeNode(typeTag.typeExpression.type);
                            }
                        }
                        return getContextualType2(parent2, contextFlags);
                    }
                    case 232 /* NonNullExpression */:
                        return getContextualType2(parent2, contextFlags);
                    case 235 /* SatisfiesExpression */:
                        return getTypeFromTypeNode(parent2.type);
                    case 274 /* ExportAssignment */:
                        return tryGetTypeFromEffectiveTypeNode(parent2);
                    case 291 /* JsxExpression */:
                        return getContextualTypeForJsxExpression(parent2, contextFlags);
                    case 288 /* JsxAttribute */:
                    case 290 /* JsxSpreadAttribute */:
                        return getContextualTypeForJsxAttribute(parent2, contextFlags);
                    case 283 /* JsxOpeningElement */:
                    case 282 /* JsxSelfClosingElement */:
                        return getContextualJsxElementAttributesType(parent2, contextFlags);
                }
                return void 0;
            }
            function pushCachedContextualType(node) {
                pushContextualType(node, getContextualType2(node, 
                /*contextFlags*/
                void 0), 
                /*isCache*/
                true);
            }
            function pushContextualType(node, type, isCache) {
                contextualTypeNodes[contextualTypeCount] = node;
                contextualTypes[contextualTypeCount] = type;
                contextualIsCache[contextualTypeCount] = isCache;
                contextualTypeCount++;
            }
            function popContextualType() {
                contextualTypeCount--;
            }
            function findContextualNode(node, includeCaches) {
                for (let i = contextualTypeCount - 1; i >= 0; i--) {
                    if (node === contextualTypeNodes[i] && (includeCaches || !contextualIsCache[i])) {
                        return i;
                    }
                }
                return -1;
            }
            function pushInferenceContext(node, inferenceContext) {
                inferenceContextNodes[inferenceContextCount] = node;
                inferenceContexts[inferenceContextCount] = inferenceContext;
                inferenceContextCount++;
            }
            function popInferenceContext() {
                inferenceContextCount--;
            }
            function getInferenceContext(node) {
                for (let i = inferenceContextCount - 1; i >= 0; i--) {
                    if (isNodeDescendantOf(node, inferenceContextNodes[i])) {
                        return inferenceContexts[i];
                    }
                }
            }
            function getContextualJsxElementAttributesType(node, contextFlags) {
                if (isJsxOpeningElement(node) && contextFlags !== 4 /* Completions */) {
                    const index = findContextualNode(node.parent, 
                    /*includeCaches*/
                    !contextFlags);
                    if (index >= 0) {
                        return contextualTypes[index];
                    }
                }
                return getContextualTypeForArgumentAtIndex(node, 0);
            }
            function getEffectiveFirstArgumentForJsxSignature(signature, node) {
                return getJsxReferenceKind(node) !== 0 /* Component */ ? getJsxPropsTypeFromCallSignature(signature, node) : getJsxPropsTypeFromClassType(signature, node);
            }
            function getJsxPropsTypeFromCallSignature(sig, context) {
                let propsType = getTypeOfFirstParameterOfSignatureWithFallback(sig, unknownType);
                propsType = getJsxManagedAttributesFromLocatedAttributes(context, getJsxNamespaceAt(context), propsType);
                const intrinsicAttribs = getJsxType(JsxNames.IntrinsicAttributes, context);
                if (!isErrorType(intrinsicAttribs)) {
                    propsType = intersectTypes(intrinsicAttribs, propsType);
                }
                return propsType;
            }
            function getJsxPropsTypeForSignatureFromMember(sig, forcedLookupLocation) {
                if (sig.compositeSignatures) {
                    const results = [];
                    for (const signature of sig.compositeSignatures) {
                        const instance = getReturnTypeOfSignature(signature);
                        if (isTypeAny(instance)) {
                            return instance;
                        }
                        const propType = getTypeOfPropertyOfType(instance, forcedLookupLocation);
                        if (!propType) {
                            return;
                        }
                        results.push(propType);
                    }
                    return getIntersectionType(results);
                }
                const instanceType = getReturnTypeOfSignature(sig);
                return isTypeAny(instanceType) ? instanceType : getTypeOfPropertyOfType(instanceType, forcedLookupLocation);
            }
            function getStaticTypeOfReferencedJsxConstructor(context) {
                if (isJsxIntrinsicIdentifier(context.tagName)) {
                    const result = getIntrinsicAttributesTypeFromJsxOpeningLikeElement(context);
                    const fakeSignature = createSignatureForJSXIntrinsic(context, result);
                    return getOrCreateTypeFromSignature(fakeSignature);
                }
                const tagType = checkExpressionCached(context.tagName);
                if (tagType.flags & 128 /* StringLiteral */) {
                    const result = getIntrinsicAttributesTypeFromStringLiteralType(tagType, context);
                    if (!result) {
                        return errorType;
                    }
                    const fakeSignature = createSignatureForJSXIntrinsic(context, result);
                    return getOrCreateTypeFromSignature(fakeSignature);
                }
                return tagType;
            }
            function getJsxManagedAttributesFromLocatedAttributes(context, ns, attributesType) {
                const managedSym = getJsxLibraryManagedAttributes(ns);
                if (managedSym) {
                    const declaredManagedType = getDeclaredTypeOfSymbol(managedSym);
                    const ctorType = getStaticTypeOfReferencedJsxConstructor(context);
                    if (managedSym.flags & 524288 /* TypeAlias */) {
                        const params = getSymbolLinks(managedSym).typeParameters;
                        if (length(params) >= 2) {
                            const args = fillMissingTypeArguments([ctorType, attributesType], params, 2, isInJSFile(context));
                            return getTypeAliasInstantiation(managedSym, args);
                        }
                    }
                    if (length(declaredManagedType.typeParameters) >= 2) {
                        const args = fillMissingTypeArguments([ctorType, attributesType], declaredManagedType.typeParameters, 2, isInJSFile(context));
                        return createTypeReference(declaredManagedType, args);
                    }
                }
                return attributesType;
            }
            function getJsxPropsTypeFromClassType(sig, context) {
                const ns = getJsxNamespaceAt(context);
                const forcedLookupLocation = getJsxElementPropertiesName(ns);
                let attributesType = forcedLookupLocation === void 0 ? getTypeOfFirstParameterOfSignatureWithFallback(sig, unknownType) : forcedLookupLocation === "" ? getReturnTypeOfSignature(sig) : getJsxPropsTypeForSignatureFromMember(sig, forcedLookupLocation);
                if (!attributesType) {
                    if (!!forcedLookupLocation && !!length(context.attributes.properties)) {
                        error(context, Diagnostics.JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property, unescapeLeadingUnderscores(forcedLookupLocation));
                    }
                    return unknownType;
                }
                attributesType = getJsxManagedAttributesFromLocatedAttributes(context, ns, attributesType);
                if (isTypeAny(attributesType)) {
                    return attributesType;
                }
                else {
                    let apparentAttributesType = attributesType;
                    const intrinsicClassAttribs = getJsxType(JsxNames.IntrinsicClassAttributes, context);
                    if (!isErrorType(intrinsicClassAttribs)) {
                        const typeParams = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(intrinsicClassAttribs.symbol);
                        const hostClassType = getReturnTypeOfSignature(sig);
                        let libraryManagedAttributeType;
                        if (typeParams) {
                            const inferredArgs = fillMissingTypeArguments([hostClassType], typeParams, getMinTypeArgumentCount(typeParams), isInJSFile(context));
                            libraryManagedAttributeType = instantiateType(intrinsicClassAttribs, createTypeMapper(typeParams, inferredArgs));
                        }
                        else
                            libraryManagedAttributeType = intrinsicClassAttribs;
                        apparentAttributesType = intersectTypes(libraryManagedAttributeType, apparentAttributesType);
                    }
                    const intrinsicAttribs = getJsxType(JsxNames.IntrinsicAttributes, context);
                    if (!isErrorType(intrinsicAttribs)) {
                        apparentAttributesType = intersectTypes(intrinsicAttribs, apparentAttributesType);
                    }
                    return apparentAttributesType;
                }
            }
            function getIntersectedSignatures(signatures) {
                return getStrictOptionValue(compilerOptions, "noImplicitAny") ? reduceLeft(signatures, (left, right) => left === right || !left ? left : compareTypeParametersIdentical(left.typeParameters, right.typeParameters) ? combineSignaturesOfIntersectionMembers(left, right) : void 0) : void 0;
            }
            function combineIntersectionThisParam(left, right, mapper) {
                if (!left || !right) {
                    return left || right;
                }
                const thisType = getUnionType([getTypeOfSymbol(left), instantiateType(getTypeOfSymbol(right), mapper)]);
                return createSymbolWithType(left, thisType);
            }
            function combineIntersectionParameters(left, right, mapper) {
                const leftCount = getParameterCount(left);
                const rightCount = getParameterCount(right);
                const longest = leftCount >= rightCount ? left : right;
                const shorter = longest === left ? right : left;
                const longestCount = longest === left ? leftCount : rightCount;
                const eitherHasEffectiveRest = hasEffectiveRestParameter(left) || hasEffectiveRestParameter(right);
                const needsExtraRestElement = eitherHasEffectiveRest && !hasEffectiveRestParameter(longest);
                const params = new Array(longestCount + (needsExtraRestElement ? 1 : 0));
                for (let i = 0; i < longestCount; i++) {
                    let longestParamType = tryGetTypeAtPosition(longest, i);
                    if (longest === right) {
                        longestParamType = instantiateType(longestParamType, mapper);
                    }
                    let shorterParamType = tryGetTypeAtPosition(shorter, i) || unknownType;
                    if (shorter === right) {
                        shorterParamType = instantiateType(shorterParamType, mapper);
                    }
                    const unionParamType = getUnionType([longestParamType, shorterParamType]);
                    const isRestParam = eitherHasEffectiveRest && !needsExtraRestElement && i === longestCount - 1;
                    const isOptional = i >= getMinArgumentCount(longest) && i >= getMinArgumentCount(shorter);
                    const leftName = i >= leftCount ? void 0 : getParameterNameAtPosition(left, i);
                    const rightName = i >= rightCount ? void 0 : getParameterNameAtPosition(right, i);
                    const paramName = leftName === rightName ? leftName : !leftName ? rightName : !rightName ? leftName : void 0;
                    const paramSymbol = createSymbol(1 /* FunctionScopedVariable */ | (isOptional && !isRestParam ? 16777216 /* Optional */ : 0), paramName || `arg${i}`);
                    paramSymbol.links.type = isRestParam ? createArrayType(unionParamType) : unionParamType;
                    params[i] = paramSymbol;
                }
                if (needsExtraRestElement) {
                    const restParamSymbol = createSymbol(1 /* FunctionScopedVariable */, "args");
                    restParamSymbol.links.type = createArrayType(getTypeAtPosition(shorter, longestCount));
                    if (shorter === right) {
                        restParamSymbol.links.type = instantiateType(restParamSymbol.links.type, mapper);
                    }
                    params[longestCount] = restParamSymbol;
                }
                return params;
            }
            function combineSignaturesOfIntersectionMembers(left, right) {
                const typeParams = left.typeParameters || right.typeParameters;
                let paramMapper;
                if (left.typeParameters && right.typeParameters) {
                    paramMapper = createTypeMapper(right.typeParameters, left.typeParameters);
                }
                const declaration = left.declaration;
                const params = combineIntersectionParameters(left, right, paramMapper);
                const thisParam = combineIntersectionThisParam(left.thisParameter, right.thisParameter, paramMapper);
                const minArgCount = Math.max(left.minArgumentCount, right.minArgumentCount);
                const result = createSignature(declaration, typeParams, thisParam, params, 
                /*resolvedReturnType*/
                void 0, 
                /*resolvedTypePredicate*/
                void 0, minArgCount, (left.flags | right.flags) & 39 /* PropagatingFlags */);
                result.compositeKind = 2097152 /* Intersection */;
                result.compositeSignatures = concatenate(left.compositeKind === 2097152 /* Intersection */ && left.compositeSignatures || [left], [right]);
                if (paramMapper) {
                    result.mapper = left.compositeKind === 2097152 /* Intersection */ && left.mapper && left.compositeSignatures ? combineTypeMappers(left.mapper, paramMapper) : paramMapper;
                }
                return result;
            }
            function getContextualCallSignature(type, node) {
                const signatures = getSignaturesOfType(type, 0 /* Call */);
                const applicableByArity = filter(signatures, (s) => !isAritySmaller(s, node));
                return applicableByArity.length === 1 ? applicableByArity[0] : getIntersectedSignatures(applicableByArity);
            }
            function isAritySmaller(signature, target) {
                let targetParameterCount = 0;
                for (; targetParameterCount < target.parameters.length; targetParameterCount++) {
                    const param = target.parameters[targetParameterCount];
                    if (param.initializer || param.questionToken || param.dotDotDotToken || isJSDocOptionalParameter(param)) {
                        break;
                    }
                }
                if (target.parameters.length && parameterIsThisKeyword(target.parameters[0])) {
                    targetParameterCount--;
                }
                return !hasEffectiveRestParameter(signature) && getParameterCount(signature) < targetParameterCount;
            }
            function getContextualSignatureForFunctionLikeDeclaration(node) {
                return isFunctionExpressionOrArrowFunction(node) || isObjectLiteralMethod(node) ? getContextualSignature(node) : void 0;
            }
            function getContextualSignature(node) {
                Debug.assert(node.kind !== 171 /* MethodDeclaration */ || isObjectLiteralMethod(node));
                const typeTagSignature = getSignatureOfTypeTag(node);
                if (typeTagSignature) {
                    return typeTagSignature;
                }
                const type = getApparentTypeOfContextualType(node, 1 /* Signature */);
                if (!type) {
                    return void 0;
                }
                if (!(type.flags & 1048576 /* Union */)) {
                    return getContextualCallSignature(type, node);
                }
                let signatureList;
                const types = type.types;
                for (const current of types) {
                    const signature = getContextualCallSignature(current, node);
                    if (signature) {
                        if (!signatureList) {
                            signatureList = [signature];
                        }
                        else if (!compareSignaturesIdentical(signatureList[0], signature, 
                        /*partialMatch*/
                        false, 
                        /*ignoreThisTypes*/
                        true, 
                        /*ignoreReturnTypes*/
                        true, compareTypesIdentical)) {
                            return void 0;
                        }
                        else {
                            signatureList.push(signature);
                        }
                    }
                }
                if (signatureList) {
                    return signatureList.length === 1 ? signatureList[0] : createUnionSignature(signatureList[0], signatureList);
                }
            }
            function checkSpreadExpression(node, checkMode) {
                if (languageVersion < 2 /* ES2015 */) {
                    checkExternalEmitHelpers(node, compilerOptions.downlevelIteration ? 1536 /* SpreadIncludes */ : 1024 /* SpreadArray */);
                }
                const arrayOrIterableType = checkExpression(node.expression, checkMode);
                return checkIteratedTypeOrElementType(33 /* Spread */, arrayOrIterableType, undefinedType, node.expression);
            }
            function checkSyntheticExpression(node) {
                return node.isSpread ? getIndexedAccessType(node.type, numberType) : node.type;
            }
            function hasDefaultValue(node) {
                return node.kind === 205 /* BindingElement */ && !!node.initializer || node.kind === 223 /* BinaryExpression */ && node.operatorToken.kind === 63 /* EqualsToken */;
            }
            function checkArrayLiteral(node, checkMode, forceTuple) {
                const elements = node.elements;
                const elementCount = elements.length;
                const elementTypes = [];
                const elementFlags = [];
                pushCachedContextualType(node);
                const inDestructuringPattern = isAssignmentTarget(node);
                const inConstContext = isConstContext(node);
                const contextualType = getApparentTypeOfContextualType(node, 
                /*contextFlags*/
                void 0);
                const inTupleContext = !!contextualType && someType(contextualType, isTupleLikeType);
                let hasOmittedExpression = false;
                for (let i = 0; i < elementCount; i++) {
                    const e = elements[i];
                    if (e.kind === 227 /* SpreadElement */) {
                        if (languageVersion < 2 /* ES2015 */) {
                            checkExternalEmitHelpers(e, compilerOptions.downlevelIteration ? 1536 /* SpreadIncludes */ : 1024 /* SpreadArray */);
                        }
                        const spreadType = checkExpression(e.expression, checkMode, forceTuple);
                        if (isArrayLikeType(spreadType)) {
                            elementTypes.push(spreadType);
                            elementFlags.push(8 /* Variadic */);
                        }
                        else if (inDestructuringPattern) {
                            const restElementType = getIndexTypeOfType(spreadType, numberType) || getIteratedTypeOrElementType(65 /* Destructuring */, spreadType, undefinedType, 
                            /*errorNode*/
                            void 0, 
                            /*checkAssignability*/
                            false) || unknownType;
                            elementTypes.push(restElementType);
                            elementFlags.push(4 /* Rest */);
                        }
                        else {
                            elementTypes.push(checkIteratedTypeOrElementType(33 /* Spread */, spreadType, undefinedType, e.expression));
                            elementFlags.push(4 /* Rest */);
                        }
                    }
                    else if (exactOptionalPropertyTypes && e.kind === 229 /* OmittedExpression */) {
                        hasOmittedExpression = true;
                        elementTypes.push(undefinedOrMissingType);
                        elementFlags.push(2 /* Optional */);
                    }
                    else {
                        const type = checkExpressionForMutableLocation(e, checkMode, forceTuple);
                        elementTypes.push(addOptionality(type, 
                        /*isProperty*/
                        true, hasOmittedExpression));
                        elementFlags.push(hasOmittedExpression ? 2 /* Optional */ : 1 /* Required */);
                        if (inTupleContext && checkMode && checkMode & 2 /* Inferential */ && !(checkMode & 4 /* SkipContextSensitive */) && isContextSensitive(e)) {
                            const inferenceContext = getInferenceContext(node);
                            Debug.assert(inferenceContext);
                            addIntraExpressionInferenceSite(inferenceContext, e, type);
                        }
                    }
                }
                popContextualType();
                if (inDestructuringPattern) {
                    return createTupleType(elementTypes, elementFlags);
                }
                if (forceTuple || inConstContext || inTupleContext) {
                    return createArrayLiteralType(createTupleType(elementTypes, elementFlags, 
                    /*readonly*/
                    inConstContext));
                }
                return createArrayLiteralType(createArrayType(elementTypes.length ? getUnionType(sameMap(elementTypes, (t, i) => elementFlags[i] & 8 /* Variadic */ ? getIndexedAccessTypeOrUndefined(t, numberType) || anyType : t), 2 /* Subtype */) : strictNullChecks ? implicitNeverType : undefinedWideningType, inConstContext));
            }
            function createArrayLiteralType(type) {
                if (!(getObjectFlags(type) & 4 /* Reference */)) {
                    return type;
                }
                let literalType = type.literalType;
                if (!literalType) {
                    literalType = type.literalType = cloneTypeReference(type);
                    literalType.objectFlags |= 16384 /* ArrayLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                }
                return literalType;
            }
            function isNumericName(name) {
                switch (name.kind) {
                    case 164 /* ComputedPropertyName */:
                        return isNumericComputedName(name);
                    case 79 /* Identifier */:
                        return isNumericLiteralName(name.escapedText);
                    case 8 /* NumericLiteral */:
                    case 10 /* StringLiteral */:
                        return isNumericLiteralName(name.text);
                    default:
                        return false;
                }
            }
            function isNumericComputedName(name) {
                return isTypeAssignableToKind(checkComputedPropertyName(name), 296 /* NumberLike */);
            }
            function checkComputedPropertyName(node) {
                const links = getNodeLinks(node.expression);
                if (!links.resolvedType) {
                    if ((isTypeLiteralNode(node.parent.parent) || isClassLike(node.parent.parent) || isInterfaceDeclaration(node.parent.parent)) && isBinaryExpression(node.expression) && node.expression.operatorToken.kind === 101 /* InKeyword */ && node.parent.kind !== 174 /* GetAccessor */ && node.parent.kind !== 175 /* SetAccessor */) {
                        return links.resolvedType = errorType;
                    }
                    links.resolvedType = checkExpression(node.expression);
                    if (isPropertyDeclaration(node.parent) && !hasStaticModifier(node.parent) && isClassExpression(node.parent.parent)) {
                        const container = getEnclosingBlockScopeContainer(node.parent.parent);
                        const enclosingIterationStatement = getEnclosingIterationStatement(container);
                        if (enclosingIterationStatement) {
                            getNodeLinks(enclosingIterationStatement).flags |= 4096 /* LoopWithCapturedBlockScopedBinding */;
                            getNodeLinks(node).flags |= 32768 /* BlockScopedBindingInLoop */;
                            getNodeLinks(node.parent.parent).flags |= 32768 /* BlockScopedBindingInLoop */;
                        }
                    }
                    if (links.resolvedType.flags & 98304 /* Nullable */ || !isTypeAssignableToKind(links.resolvedType, 402653316 /* StringLike */ | 296 /* NumberLike */ | 12288 /* ESSymbolLike */) && !isTypeAssignableTo(links.resolvedType, stringNumberSymbolType)) {
                        error(node, Diagnostics.A_computed_property_name_must_be_of_type_string_number_symbol_or_any);
                    }
                }
                return links.resolvedType;
            }
            function isSymbolWithNumericName(symbol) {
                var _a2;
                const firstDecl = (_a2 = symbol.declarations) == null ? void 0 : _a2[0];
                return isNumericLiteralName(symbol.escapedName) || firstDecl && isNamedDeclaration(firstDecl) && isNumericName(firstDecl.name);
            }
            function isSymbolWithSymbolName(symbol) {
                var _a2;
                const firstDecl = (_a2 = symbol.declarations) == null ? void 0 : _a2[0];
                return isKnownSymbol(symbol) || firstDecl && isNamedDeclaration(firstDecl) && isComputedPropertyName(firstDecl.name) && isTypeAssignableToKind(checkComputedPropertyName(firstDecl.name), 4096 /* ESSymbol */);
            }
            function getObjectLiteralIndexInfo(node, offset, properties, keyType) {
                const propTypes = [];
                for (let i = offset; i < properties.length; i++) {
                    const prop = properties[i];
                    if (keyType === stringType && !isSymbolWithSymbolName(prop) || keyType === numberType && isSymbolWithNumericName(prop) || keyType === esSymbolType && isSymbolWithSymbolName(prop)) {
                        propTypes.push(getTypeOfSymbol(properties[i]));
                    }
                }
                const unionType = propTypes.length ? getUnionType(propTypes, 2 /* Subtype */) : undefinedType;
                return createIndexInfo(keyType, unionType, isConstContext(node));
            }
            function getImmediateAliasedSymbol(symbol) {
                Debug.assert((symbol.flags & 2097152 /* Alias */) !== 0, "Should only get Alias here.");
                const links = getSymbolLinks(symbol);
                if (!links.immediateTarget) {
                    const node = getDeclarationOfAliasSymbol(symbol);
                    if (!node)
                        return Debug.fail();
                    links.immediateTarget = getTargetOfAliasDeclaration(node, 
                    /*dontRecursivelyResolve*/
                    true);
                }
                return links.immediateTarget;
            }
            function checkObjectLiteral(node, checkMode) {
                var _a2;
                const inDestructuringPattern = isAssignmentTarget(node);
                checkGrammarObjectLiteralExpression(node, inDestructuringPattern);
                const allPropertiesTable = strictNullChecks ? createSymbolTable() : void 0;
                let propertiesTable = createSymbolTable();
                let propertiesArray = [];
                let spread = emptyObjectType;
                pushCachedContextualType(node);
                const contextualType = getApparentTypeOfContextualType(node, 
                /*contextFlags*/
                void 0);
                const contextualTypeHasPattern = contextualType && contextualType.pattern && (contextualType.pattern.kind === 203 /* ObjectBindingPattern */ || contextualType.pattern.kind === 207 /* ObjectLiteralExpression */);
                const inConstContext = isConstContext(node);
                const checkFlags = inConstContext ? 8 /* Readonly */ : 0;
                const isInJavascript = isInJSFile(node) && !isInJsonFile(node);
                const enumTag = getJSDocEnumTag(node);
                const isJSObjectLiteral = !contextualType && isInJavascript && !enumTag;
                let objectFlags = freshObjectLiteralFlag;
                let patternWithComputedProperties = false;
                let hasComputedStringProperty = false;
                let hasComputedNumberProperty = false;
                let hasComputedSymbolProperty = false;
                for (const elem of node.properties) {
                    if (elem.name && isComputedPropertyName(elem.name)) {
                        checkComputedPropertyName(elem.name);
                    }
                }
                let offset = 0;
                for (const memberDecl of node.properties) {
                    let member = getSymbolOfDeclaration(memberDecl);
                    const computedNameType = memberDecl.name && memberDecl.name.kind === 164 /* ComputedPropertyName */ ? checkComputedPropertyName(memberDecl.name) : void 0;
                    if (memberDecl.kind === 299 /* PropertyAssignment */ || memberDecl.kind === 300 /* ShorthandPropertyAssignment */ || isObjectLiteralMethod(memberDecl)) {
                        let type = memberDecl.kind === 299 /* PropertyAssignment */ ? checkPropertyAssignment(memberDecl, checkMode) : (
                        // avoid resolving the left side of the ShorthandPropertyAssignment outside of the destructuring
                        // for error recovery purposes. For example, if a user wrote `{ a = 100 }` instead of `{ a: 100 }`.
                        // we don't want to say "could not find 'a'".
                        memberDecl.kind === 300 /* ShorthandPropertyAssignment */ ? checkExpressionForMutableLocation(!inDestructuringPattern && memberDecl.objectAssignmentInitializer ? memberDecl.objectAssignmentInitializer : memberDecl.name, checkMode) : checkObjectLiteralMethod(memberDecl, checkMode));
                        if (isInJavascript) {
                            const jsDocType = getTypeForDeclarationFromJSDocComment(memberDecl);
                            if (jsDocType) {
                                checkTypeAssignableTo(type, jsDocType, memberDecl);
                                type = jsDocType;
                            }
                            else if (enumTag && enumTag.typeExpression) {
                                checkTypeAssignableTo(type, getTypeFromTypeNode(enumTag.typeExpression), memberDecl);
                            }
                        }
                        objectFlags |= getObjectFlags(type) & 458752 /* PropagatingFlags */;
                        const nameType = computedNameType && isTypeUsableAsPropertyName(computedNameType) ? computedNameType : void 0;
                        const prop = nameType ? createSymbol(4 /* Property */ | member.flags, getPropertyNameFromType(nameType), checkFlags | 4096 /* Late */) : createSymbol(4 /* Property */ | member.flags, member.escapedName, checkFlags);
                        if (nameType) {
                            prop.links.nameType = nameType;
                        }
                        if (inDestructuringPattern) {
                            const isOptional = memberDecl.kind === 299 /* PropertyAssignment */ && hasDefaultValue(memberDecl.initializer) || memberDecl.kind === 300 /* ShorthandPropertyAssignment */ && memberDecl.objectAssignmentInitializer;
                            if (isOptional) {
                                prop.flags |= 16777216 /* Optional */;
                            }
                        }
                        else if (contextualTypeHasPattern && !(getObjectFlags(contextualType) & 512 /* ObjectLiteralPatternWithComputedProperties */)) {
                            const impliedProp = getPropertyOfType(contextualType, member.escapedName);
                            if (impliedProp) {
                                prop.flags |= impliedProp.flags & 16777216 /* Optional */;
                            }
                            else if (!compilerOptions.suppressExcessPropertyErrors && !getIndexInfoOfType(contextualType, stringType)) {
                                error(memberDecl.name, Diagnostics.Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1, symbolToString(member), typeToString(contextualType));
                            }
                        }
                        prop.declarations = member.declarations;
                        prop.parent = member.parent;
                        if (member.valueDeclaration) {
                            prop.valueDeclaration = member.valueDeclaration;
                        }
                        prop.links.type = type;
                        prop.links.target = member;
                        member = prop;
                        allPropertiesTable == null ? void 0 : allPropertiesTable.set(prop.escapedName, prop);
                        if (contextualType && checkMode && checkMode & 2 /* Inferential */ && !(checkMode & 4 /* SkipContextSensitive */) && (memberDecl.kind === 299 /* PropertyAssignment */ || memberDecl.kind === 171 /* MethodDeclaration */) && isContextSensitive(memberDecl)) {
                            const inferenceContext = getInferenceContext(node);
                            Debug.assert(inferenceContext);
                            const inferenceNode = memberDecl.kind === 299 /* PropertyAssignment */ ? memberDecl.initializer : memberDecl;
                            addIntraExpressionInferenceSite(inferenceContext, inferenceNode, type);
                        }
                    }
                    else if (memberDecl.kind === 301 /* SpreadAssignment */) {
                        if (languageVersion < 2 /* ES2015 */) {
                            checkExternalEmitHelpers(memberDecl, 2 /* Assign */);
                        }
                        if (propertiesArray.length > 0) {
                            spread = getSpreadType(spread, createObjectLiteralType(), node.symbol, objectFlags, inConstContext);
                            propertiesArray = [];
                            propertiesTable = createSymbolTable();
                            hasComputedStringProperty = false;
                            hasComputedNumberProperty = false;
                            hasComputedSymbolProperty = false;
                        }
                        const type = getReducedType(checkExpression(memberDecl.expression));
                        if (isValidSpreadType(type)) {
                            const mergedType = tryMergeUnionOfObjectTypeAndEmptyObject(type, inConstContext);
                            if (allPropertiesTable) {
                                checkSpreadPropOverrides(mergedType, allPropertiesTable, memberDecl);
                            }
                            offset = propertiesArray.length;
                            if (isErrorType(spread)) {
                                continue;
                            }
                            spread = getSpreadType(spread, mergedType, node.symbol, objectFlags, inConstContext);
                        }
                        else {
                            error(memberDecl, Diagnostics.Spread_types_may_only_be_created_from_object_types);
                            spread = errorType;
                        }
                        continue;
                    }
                    else {
                        Debug.assert(memberDecl.kind === 174 /* GetAccessor */ || memberDecl.kind === 175 /* SetAccessor */);
                        checkNodeDeferred(memberDecl);
                    }
                    if (computedNameType && !(computedNameType.flags & 8576 /* StringOrNumberLiteralOrUnique */)) {
                        if (isTypeAssignableTo(computedNameType, stringNumberSymbolType)) {
                            if (isTypeAssignableTo(computedNameType, numberType)) {
                                hasComputedNumberProperty = true;
                            }
                            else if (isTypeAssignableTo(computedNameType, esSymbolType)) {
                                hasComputedSymbolProperty = true;
                            }
                            else {
                                hasComputedStringProperty = true;
                            }
                            if (inDestructuringPattern) {
                                patternWithComputedProperties = true;
                            }
                        }
                    }
                    else {
                        propertiesTable.set(member.escapedName, member);
                    }
                    propertiesArray.push(member);
                }
                popContextualType();
                if (contextualTypeHasPattern) {
                    const rootPatternParent = findAncestor(contextualType.pattern.parent, (n) => n.kind === 257 /* VariableDeclaration */ || n.kind === 223 /* BinaryExpression */ || n.kind === 166 /* Parameter */);
                    const spreadOrOutsideRootObject = findAncestor(node, (n) => n === rootPatternParent || n.kind === 301 /* SpreadAssignment */);
                    if (spreadOrOutsideRootObject.kind !== 301 /* SpreadAssignment */) {
                        for (const prop of getPropertiesOfType(contextualType)) {
                            if (!propertiesTable.get(prop.escapedName) && !getPropertyOfType(spread, prop.escapedName)) {
                                if (!(prop.flags & 16777216 /* Optional */)) {
                                    error(prop.valueDeclaration || ((_a2 = tryCast(prop, isTransientSymbol)) == null ? void 0 : _a2.links.bindingElement), Diagnostics.Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value);
                                }
                                propertiesTable.set(prop.escapedName, prop);
                                propertiesArray.push(prop);
                            }
                        }
                    }
                }
                if (isErrorType(spread)) {
                    return errorType;
                }
                if (spread !== emptyObjectType) {
                    if (propertiesArray.length > 0) {
                        spread = getSpreadType(spread, createObjectLiteralType(), node.symbol, objectFlags, inConstContext);
                        propertiesArray = [];
                        propertiesTable = createSymbolTable();
                        hasComputedStringProperty = false;
                        hasComputedNumberProperty = false;
                    }
                    return mapType(spread, (t) => t === emptyObjectType ? createObjectLiteralType() : t);
                }
                return createObjectLiteralType();
                function createObjectLiteralType() {
                    const indexInfos = [];
                    if (hasComputedStringProperty)
                        indexInfos.push(getObjectLiteralIndexInfo(node, offset, propertiesArray, stringType));
                    if (hasComputedNumberProperty)
                        indexInfos.push(getObjectLiteralIndexInfo(node, offset, propertiesArray, numberType));
                    if (hasComputedSymbolProperty)
                        indexInfos.push(getObjectLiteralIndexInfo(node, offset, propertiesArray, esSymbolType));
                    const result = createAnonymousType(node.symbol, propertiesTable, emptyArray, emptyArray, indexInfos);
                    result.objectFlags |= objectFlags | 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                    if (isJSObjectLiteral) {
                        result.objectFlags |= 4096 /* JSLiteral */;
                    }
                    if (patternWithComputedProperties) {
                        result.objectFlags |= 512 /* ObjectLiteralPatternWithComputedProperties */;
                    }
                    if (inDestructuringPattern) {
                        result.pattern = node;
                    }
                    return result;
                }
            }
            function isValidSpreadType(type) {
                const t = removeDefinitelyFalsyTypes(mapType(type, getBaseConstraintOrType));
                return !!(t.flags & (1 /* Any */ | 67108864 /* NonPrimitive */ | 524288 /* Object */ | 58982400 /* InstantiableNonPrimitive */) || t.flags & 3145728 /* UnionOrIntersection */ && every(t.types, isValidSpreadType));
            }
            function checkJsxSelfClosingElementDeferred(node) {
                checkJsxOpeningLikeElementOrOpeningFragment(node);
            }
            function checkJsxSelfClosingElement(node, _checkMode) {
                checkNodeDeferred(node);
                return getJsxElementTypeAt(node) || anyType;
            }
            function checkJsxElementDeferred(node) {
                checkJsxOpeningLikeElementOrOpeningFragment(node.openingElement);
                if (isJsxIntrinsicIdentifier(node.closingElement.tagName)) {
                    getIntrinsicTagSymbol(node.closingElement);
                }
                else {
                    checkExpression(node.closingElement.tagName);
                }
                checkJsxChildren(node);
            }
            function checkJsxElement(node, _checkMode) {
                checkNodeDeferred(node);
                return getJsxElementTypeAt(node) || anyType;
            }
            function checkJsxFragment(node) {
                checkJsxOpeningLikeElementOrOpeningFragment(node.openingFragment);
                const nodeSourceFile = getSourceFileOfNode(node);
                if (getJSXTransformEnabled(compilerOptions) && (compilerOptions.jsxFactory || nodeSourceFile.pragmas.has("jsx")) && !compilerOptions.jsxFragmentFactory && !nodeSourceFile.pragmas.has("jsxfrag")) {
                    error(node, compilerOptions.jsxFactory ? Diagnostics.The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_compiler_option : Diagnostics.An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments);
                }
                checkJsxChildren(node);
                return getJsxElementTypeAt(node) || anyType;
            }
            function isHyphenatedJsxName(name) {
                return stringContains(name, "-");
            }
            function isJsxIntrinsicIdentifier(tagName) {
                return tagName.kind === 79 /* Identifier */ && isIntrinsicJsxName(tagName.escapedText);
            }
            function checkJsxAttribute(node, checkMode) {
                return node.initializer ? checkExpressionForMutableLocation(node.initializer, checkMode) : trueType;
            }
            function createJsxAttributesTypeFromAttributesProperty(openingLikeElement, checkMode) {
                const attributes = openingLikeElement.attributes;
                const attributesType = getContextualType2(attributes, 0 /* None */);
                const allAttributesTable = strictNullChecks ? createSymbolTable() : void 0;
                let attributesTable = createSymbolTable();
                let spread = emptyJsxObjectType;
                let hasSpreadAnyType = false;
                let typeToIntersect;
                let explicitlySpecifyChildrenAttribute = false;
                let objectFlags = 2048 /* JsxAttributes */;
                const jsxChildrenPropertyName = getJsxElementChildrenPropertyName(getJsxNamespaceAt(openingLikeElement));
                for (const attributeDecl of attributes.properties) {
                    const member = attributeDecl.symbol;
                    if (isJsxAttribute(attributeDecl)) {
                        const exprType = checkJsxAttribute(attributeDecl, checkMode);
                        objectFlags |= getObjectFlags(exprType) & 458752 /* PropagatingFlags */;
                        const attributeSymbol = createSymbol(4 /* Property */ | member.flags, member.escapedName);
                        attributeSymbol.declarations = member.declarations;
                        attributeSymbol.parent = member.parent;
                        if (member.valueDeclaration) {
                            attributeSymbol.valueDeclaration = member.valueDeclaration;
                        }
                        attributeSymbol.links.type = exprType;
                        attributeSymbol.links.target = member;
                        attributesTable.set(attributeSymbol.escapedName, attributeSymbol);
                        allAttributesTable == null ? void 0 : allAttributesTable.set(attributeSymbol.escapedName, attributeSymbol);
                        if (attributeDecl.name.escapedText === jsxChildrenPropertyName) {
                            explicitlySpecifyChildrenAttribute = true;
                        }
                        if (attributesType) {
                            const prop = getPropertyOfType(attributesType, member.escapedName);
                            if (prop && prop.declarations && isDeprecatedSymbol(prop)) {
                                addDeprecatedSuggestion(attributeDecl.name, prop.declarations, attributeDecl.name.escapedText);
                            }
                        }
                    }
                    else {
                        Debug.assert(attributeDecl.kind === 290 /* JsxSpreadAttribute */);
                        if (attributesTable.size > 0) {
                            spread = getSpreadType(spread, createJsxAttributesType(), attributes.symbol, objectFlags, 
                            /*readonly*/
                            false);
                            attributesTable = createSymbolTable();
                        }
                        const exprType = getReducedType(checkExpressionCached(attributeDecl.expression, checkMode));
                        if (isTypeAny(exprType)) {
                            hasSpreadAnyType = true;
                        }
                        if (isValidSpreadType(exprType)) {
                            spread = getSpreadType(spread, exprType, attributes.symbol, objectFlags, 
                            /*readonly*/
                            false);
                            if (allAttributesTable) {
                                checkSpreadPropOverrides(exprType, allAttributesTable, attributeDecl);
                            }
                        }
                        else {
                            error(attributeDecl.expression, Diagnostics.Spread_types_may_only_be_created_from_object_types);
                            typeToIntersect = typeToIntersect ? getIntersectionType([typeToIntersect, exprType]) : exprType;
                        }
                    }
                }
                if (!hasSpreadAnyType) {
                    if (attributesTable.size > 0) {
                        spread = getSpreadType(spread, createJsxAttributesType(), attributes.symbol, objectFlags, 
                        /*readonly*/
                        false);
                    }
                }
                const parent2 = openingLikeElement.parent.kind === 281 /* JsxElement */ ? openingLikeElement.parent : void 0;
                if (parent2 && parent2.openingElement === openingLikeElement && parent2.children.length > 0) {
                    const childrenTypes = checkJsxChildren(parent2, checkMode);
                    if (!hasSpreadAnyType && jsxChildrenPropertyName && jsxChildrenPropertyName !== "") {
                        if (explicitlySpecifyChildrenAttribute) {
                            error(attributes, Diagnostics._0_are_specified_twice_The_attribute_named_0_will_be_overwritten, unescapeLeadingUnderscores(jsxChildrenPropertyName));
                        }
                        const contextualType = getApparentTypeOfContextualType(openingLikeElement.attributes, 
                        /*contextFlags*/
                        void 0);
                        const childrenContextualType = contextualType && getTypeOfPropertyOfContextualType(contextualType, jsxChildrenPropertyName);
                        const childrenPropSymbol = createSymbol(4 /* Property */, jsxChildrenPropertyName);
                        childrenPropSymbol.links.type = childrenTypes.length === 1 ? childrenTypes[0] : childrenContextualType && someType(childrenContextualType, isTupleLikeType) ? createTupleType(childrenTypes) : createArrayType(getUnionType(childrenTypes));
                        childrenPropSymbol.valueDeclaration = factory.createPropertySignature(
                        /*modifiers*/
                        void 0, unescapeLeadingUnderscores(jsxChildrenPropertyName), 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0);
                        setParent(childrenPropSymbol.valueDeclaration, attributes);
                        childrenPropSymbol.valueDeclaration.symbol = childrenPropSymbol;
                        const childPropMap = createSymbolTable();
                        childPropMap.set(jsxChildrenPropertyName, childrenPropSymbol);
                        spread = getSpreadType(spread, createAnonymousType(attributes.symbol, childPropMap, emptyArray, emptyArray, emptyArray), attributes.symbol, objectFlags, 
                        /*readonly*/
                        false);
                    }
                }
                if (hasSpreadAnyType) {
                    return anyType;
                }
                if (typeToIntersect && spread !== emptyJsxObjectType) {
                    return getIntersectionType([typeToIntersect, spread]);
                }
                return typeToIntersect || (spread === emptyJsxObjectType ? createJsxAttributesType() : spread);
                function createJsxAttributesType() {
                    objectFlags |= freshObjectLiteralFlag;
                    const result = createAnonymousType(attributes.symbol, attributesTable, emptyArray, emptyArray, emptyArray);
                    result.objectFlags |= objectFlags | 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                    return result;
                }
            }
            function checkJsxChildren(node, checkMode) {
                const childrenTypes = [];
                for (const child of node.children) {
                    if (child.kind === 11 /* JsxText */) {
                        if (!child.containsOnlyTriviaWhiteSpaces) {
                            childrenTypes.push(stringType);
                        }
                    }
                    else if (child.kind === 291 /* JsxExpression */ && !child.expression) {
                        continue;
                    }
                    else {
                        childrenTypes.push(checkExpressionForMutableLocation(child, checkMode));
                    }
                }
                return childrenTypes;
            }
            function checkSpreadPropOverrides(type, props, spread) {
                for (const right of getPropertiesOfType(type)) {
                    if (!(right.flags & 16777216 /* Optional */)) {
                        const left = props.get(right.escapedName);
                        if (left) {
                            const diagnostic = error(left.valueDeclaration, Diagnostics._0_is_specified_more_than_once_so_this_usage_will_be_overwritten, unescapeLeadingUnderscores(left.escapedName));
                            addRelatedInfo(diagnostic, createDiagnosticForNode(spread, Diagnostics.This_spread_always_overwrites_this_property));
                        }
                    }
                }
            }
            function checkJsxAttributes(node, checkMode) {
                return createJsxAttributesTypeFromAttributesProperty(node.parent, checkMode);
            }
            function getJsxType(name, location) {
                const namespace = getJsxNamespaceAt(location);
                const exports = namespace && getExportsOfSymbol(namespace);
                const typeSymbol = exports && getSymbol2(exports, name, 788968 /* Type */);
                return typeSymbol ? getDeclaredTypeOfSymbol(typeSymbol) : errorType;
            }
            function getIntrinsicTagSymbol(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedSymbol) {
                    const intrinsicElementsType = getJsxType(JsxNames.IntrinsicElements, node);
                    if (!isErrorType(intrinsicElementsType)) {
                        if (!isIdentifier(node.tagName))
                            return Debug.fail();
                        const intrinsicProp = getPropertyOfType(intrinsicElementsType, node.tagName.escapedText);
                        if (intrinsicProp) {
                            links.jsxFlags |= 1 /* IntrinsicNamedElement */;
                            return links.resolvedSymbol = intrinsicProp;
                        }
                        const indexSignatureType = getIndexTypeOfType(intrinsicElementsType, stringType);
                        if (indexSignatureType) {
                            links.jsxFlags |= 2 /* IntrinsicIndexedElement */;
                            return links.resolvedSymbol = intrinsicElementsType.symbol;
                        }
                        error(node, Diagnostics.Property_0_does_not_exist_on_type_1, idText(node.tagName), "JSX." + JsxNames.IntrinsicElements);
                        return links.resolvedSymbol = unknownSymbol;
                    }
                    else {
                        if (noImplicitAny) {
                            error(node, Diagnostics.JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists, unescapeLeadingUnderscores(JsxNames.IntrinsicElements));
                        }
                        return links.resolvedSymbol = unknownSymbol;
                    }
                }
                return links.resolvedSymbol;
            }
            function getJsxNamespaceContainerForImplicitImport(location) {
                const file = location && getSourceFileOfNode(location);
                const links = file && getNodeLinks(file);
                if (links && links.jsxImplicitImportContainer === false) {
                    return void 0;
                }
                if (links && links.jsxImplicitImportContainer) {
                    return links.jsxImplicitImportContainer;
                }
                const runtimeImportSpecifier = getJSXRuntimeImport(getJSXImplicitImportBase(compilerOptions, file), compilerOptions);
                if (!runtimeImportSpecifier) {
                    return void 0;
                }
                const isClassic = getEmitModuleResolutionKind(compilerOptions) === 1 /* Classic */;
                const errorMessage = isClassic ? Diagnostics.Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_to_the_paths_option : Diagnostics.Cannot_find_module_0_or_its_corresponding_type_declarations;
                const mod = resolveExternalModule(location, runtimeImportSpecifier, errorMessage, location);
                const result = mod && mod !== unknownSymbol ? getMergedSymbol(resolveSymbol(mod)) : void 0;
                if (links) {
                    links.jsxImplicitImportContainer = result || false;
                }
                return result;
            }
            function getJsxNamespaceAt(location) {
                const links = location && getNodeLinks(location);
                if (links && links.jsxNamespace) {
                    return links.jsxNamespace;
                }
                if (!links || links.jsxNamespace !== false) {
                    let resolvedNamespace = getJsxNamespaceContainerForImplicitImport(location);
                    if (!resolvedNamespace || resolvedNamespace === unknownSymbol) {
                        const namespaceName = getJsxNamespace(location);
                        resolvedNamespace = resolveName(location, namespaceName, 1920 /* Namespace */, 
                        /*diagnosticMessage*/
                        void 0, namespaceName, 
                        /*isUse*/
                        false);
                    }
                    if (resolvedNamespace) {
                        const candidate = resolveSymbol(getSymbol2(getExportsOfSymbol(resolveSymbol(resolvedNamespace)), JsxNames.JSX, 1920 /* Namespace */));
                        if (candidate && candidate !== unknownSymbol) {
                            if (links) {
                                links.jsxNamespace = candidate;
                            }
                            return candidate;
                        }
                    }
                    if (links) {
                        links.jsxNamespace = false;
                    }
                }
                const s = resolveSymbol(getGlobalSymbol(JsxNames.JSX, 1920 /* Namespace */, 
                /*diagnosticMessage*/
                void 0));
                if (s === unknownSymbol) {
                    return void 0;
                }
                return s;
            }
            function getNameFromJsxElementAttributesContainer(nameOfAttribPropContainer, jsxNamespace) {
                const jsxElementAttribPropInterfaceSym = jsxNamespace && getSymbol2(jsxNamespace.exports, nameOfAttribPropContainer, 788968 /* Type */);
                const jsxElementAttribPropInterfaceType = jsxElementAttribPropInterfaceSym && getDeclaredTypeOfSymbol(jsxElementAttribPropInterfaceSym);
                const propertiesOfJsxElementAttribPropInterface = jsxElementAttribPropInterfaceType && getPropertiesOfType(jsxElementAttribPropInterfaceType);
                if (propertiesOfJsxElementAttribPropInterface) {
                    if (propertiesOfJsxElementAttribPropInterface.length === 0) {
                        return "";
                    }
                    else if (propertiesOfJsxElementAttribPropInterface.length === 1) {
                        return propertiesOfJsxElementAttribPropInterface[0].escapedName;
                    }
                    else if (propertiesOfJsxElementAttribPropInterface.length > 1 && jsxElementAttribPropInterfaceSym.declarations) {
                        error(jsxElementAttribPropInterfaceSym.declarations[0], Diagnostics.The_global_type_JSX_0_may_not_have_more_than_one_property, unescapeLeadingUnderscores(nameOfAttribPropContainer));
                    }
                }
                return void 0;
            }
            function getJsxLibraryManagedAttributes(jsxNamespace) {
                return jsxNamespace && getSymbol2(jsxNamespace.exports, JsxNames.LibraryManagedAttributes, 788968 /* Type */);
            }
            function getJsxElementPropertiesName(jsxNamespace) {
                return getNameFromJsxElementAttributesContainer(JsxNames.ElementAttributesPropertyNameContainer, jsxNamespace);
            }
            function getJsxElementChildrenPropertyName(jsxNamespace) {
                return getNameFromJsxElementAttributesContainer(JsxNames.ElementChildrenAttributeNameContainer, jsxNamespace);
            }
            function getUninstantiatedJsxSignaturesOfType(elementType, caller) {
                if (elementType.flags & 4 /* String */) {
                    return [anySignature];
                }
                else if (elementType.flags & 128 /* StringLiteral */) {
                    const intrinsicType = getIntrinsicAttributesTypeFromStringLiteralType(elementType, caller);
                    if (!intrinsicType) {
                        error(caller, Diagnostics.Property_0_does_not_exist_on_type_1, elementType.value, "JSX." + JsxNames.IntrinsicElements);
                        return emptyArray;
                    }
                    else {
                        const fakeSignature = createSignatureForJSXIntrinsic(caller, intrinsicType);
                        return [fakeSignature];
                    }
                }
                const apparentElemType = getApparentType(elementType);
                let signatures = getSignaturesOfType(apparentElemType, 1 /* Construct */);
                if (signatures.length === 0) {
                    signatures = getSignaturesOfType(apparentElemType, 0 /* Call */);
                }
                if (signatures.length === 0 && apparentElemType.flags & 1048576 /* Union */) {
                    signatures = getUnionSignatures(map(apparentElemType.types, (t) => getUninstantiatedJsxSignaturesOfType(t, caller)));
                }
                return signatures;
            }
            function getIntrinsicAttributesTypeFromStringLiteralType(type, location) {
                const intrinsicElementsType = getJsxType(JsxNames.IntrinsicElements, location);
                if (!isErrorType(intrinsicElementsType)) {
                    const stringLiteralTypeName = type.value;
                    const intrinsicProp = getPropertyOfType(intrinsicElementsType, escapeLeadingUnderscores(stringLiteralTypeName));
                    if (intrinsicProp) {
                        return getTypeOfSymbol(intrinsicProp);
                    }
                    const indexSignatureType = getIndexTypeOfType(intrinsicElementsType, stringType);
                    if (indexSignatureType) {
                        return indexSignatureType;
                    }
                    return void 0;
                }
                return anyType;
            }
            function checkJsxReturnAssignableToAppropriateBound(refKind, elemInstanceType, openingLikeElement) {
                if (refKind === 1 /* Function */) {
                    const sfcReturnConstraint = getJsxStatelessElementTypeAt(openingLikeElement);
                    if (sfcReturnConstraint) {
                        checkTypeRelatedTo(elemInstanceType, sfcReturnConstraint, assignableRelation, openingLikeElement.tagName, Diagnostics.Its_return_type_0_is_not_a_valid_JSX_element, generateInitialErrorChain);
                    }
                }
                else if (refKind === 0 /* Component */) {
                    const classConstraint = getJsxElementClassTypeAt(openingLikeElement);
                    if (classConstraint) {
                        checkTypeRelatedTo(elemInstanceType, classConstraint, assignableRelation, openingLikeElement.tagName, Diagnostics.Its_instance_type_0_is_not_a_valid_JSX_element, generateInitialErrorChain);
                    }
                }
                else {
                    const sfcReturnConstraint = getJsxStatelessElementTypeAt(openingLikeElement);
                    const classConstraint = getJsxElementClassTypeAt(openingLikeElement);
                    if (!sfcReturnConstraint || !classConstraint) {
                        return;
                    }
                    const combined = getUnionType([sfcReturnConstraint, classConstraint]);
                    checkTypeRelatedTo(elemInstanceType, combined, assignableRelation, openingLikeElement.tagName, Diagnostics.Its_element_type_0_is_not_a_valid_JSX_element, generateInitialErrorChain);
                }
                function generateInitialErrorChain() {
                    const componentName = getTextOfNode(openingLikeElement.tagName);
                    return chainDiagnosticMessages(
                    /* details */
                    void 0, Diagnostics._0_cannot_be_used_as_a_JSX_component, componentName);
                }
            }
            function getIntrinsicAttributesTypeFromJsxOpeningLikeElement(node) {
                Debug.assert(isJsxIntrinsicIdentifier(node.tagName));
                const links = getNodeLinks(node);
                if (!links.resolvedJsxElementAttributesType) {
                    const symbol = getIntrinsicTagSymbol(node);
                    if (links.jsxFlags & 1 /* IntrinsicNamedElement */) {
                        return links.resolvedJsxElementAttributesType = getTypeOfSymbol(symbol) || errorType;
                    }
                    else if (links.jsxFlags & 2 /* IntrinsicIndexedElement */) {
                        return links.resolvedJsxElementAttributesType = getIndexTypeOfType(getJsxType(JsxNames.IntrinsicElements, node), stringType) || errorType;
                    }
                    else {
                        return links.resolvedJsxElementAttributesType = errorType;
                    }
                }
                return links.resolvedJsxElementAttributesType;
            }
            function getJsxElementClassTypeAt(location) {
                const type = getJsxType(JsxNames.ElementClass, location);
                if (isErrorType(type))
                    return void 0;
                return type;
            }
            function getJsxElementTypeAt(location) {
                return getJsxType(JsxNames.Element, location);
            }
            function getJsxStatelessElementTypeAt(location) {
                const jsxElementType = getJsxElementTypeAt(location);
                if (jsxElementType) {
                    return getUnionType([jsxElementType, nullType]);
                }
            }
            function getJsxIntrinsicTagNamesAt(location) {
                const intrinsics = getJsxType(JsxNames.IntrinsicElements, location);
                return intrinsics ? getPropertiesOfType(intrinsics) : emptyArray;
            }
            function checkJsxPreconditions(errorNode) {
                if ((compilerOptions.jsx || 0 /* None */) === 0 /* None */) {
                    error(errorNode, Diagnostics.Cannot_use_JSX_unless_the_jsx_flag_is_provided);
                }
                if (getJsxElementTypeAt(errorNode) === void 0) {
                    if (noImplicitAny) {
                        error(errorNode, Diagnostics.JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist);
                    }
                }
            }
            function checkJsxOpeningLikeElementOrOpeningFragment(node) {
                const isNodeOpeningLikeElement = isJsxOpeningLikeElement(node);
                if (isNodeOpeningLikeElement) {
                    checkGrammarJsxElement(node);
                }
                checkJsxPreconditions(node);
                if (!getJsxNamespaceContainerForImplicitImport(node)) {
                    const jsxFactoryRefErr = diagnostics && compilerOptions.jsx === 2 /* React */ ? Diagnostics.Cannot_find_name_0 : void 0;
                    const jsxFactoryNamespace = getJsxNamespace(node);
                    const jsxFactoryLocation = isNodeOpeningLikeElement ? node.tagName : node;
                    let jsxFactorySym;
                    if (!(isJsxOpeningFragment(node) && jsxFactoryNamespace === "null")) {
                        jsxFactorySym = resolveName(jsxFactoryLocation, jsxFactoryNamespace, 111551 /* Value */, jsxFactoryRefErr, jsxFactoryNamespace, 
                        /*isUse*/
                        true);
                    }
                    if (jsxFactorySym) {
                        jsxFactorySym.isReferenced = 67108863 /* All */;
                        if (!compilerOptions.verbatimModuleSyntax && jsxFactorySym.flags & 2097152 /* Alias */ && !getTypeOnlyAliasDeclaration(jsxFactorySym)) {
                            markAliasSymbolAsReferenced(jsxFactorySym);
                        }
                    }
                    if (isJsxOpeningFragment(node)) {
                        const file = getSourceFileOfNode(node);
                        const localJsxNamespace = getLocalJsxNamespace(file);
                        if (localJsxNamespace) {
                            resolveName(jsxFactoryLocation, localJsxNamespace, 111551 /* Value */, jsxFactoryRefErr, localJsxNamespace, 
                            /*isUse*/
                            true);
                        }
                    }
                }
                if (isNodeOpeningLikeElement) {
                    const jsxOpeningLikeNode = node;
                    const sig = getResolvedSignature(jsxOpeningLikeNode);
                    checkDeprecatedSignature(sig, node);
                    checkJsxReturnAssignableToAppropriateBound(getJsxReferenceKind(jsxOpeningLikeNode), getReturnTypeOfSignature(sig), jsxOpeningLikeNode);
                }
            }
            function isKnownProperty(targetType, name, isComparingJsxAttributes) {
                if (targetType.flags & 524288 /* Object */) {
                    if (getPropertyOfObjectType(targetType, name) || getApplicableIndexInfoForName(targetType, name) || isLateBoundName(name) && getIndexInfoOfType(targetType, stringType) || isComparingJsxAttributes && isHyphenatedJsxName(name)) {
                        return true;
                    }
                }
                else if (targetType.flags & 3145728 /* UnionOrIntersection */ && isExcessPropertyCheckTarget(targetType)) {
                    for (const t of targetType.types) {
                        if (isKnownProperty(t, name, isComparingJsxAttributes)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function isExcessPropertyCheckTarget(type) {
                return !!(type.flags & 524288 /* Object */ && !(getObjectFlags(type) & 512 /* ObjectLiteralPatternWithComputedProperties */) || type.flags & 67108864 /* NonPrimitive */ || type.flags & 1048576 /* Union */ && some(type.types, isExcessPropertyCheckTarget) || type.flags & 2097152 /* Intersection */ && every(type.types, isExcessPropertyCheckTarget));
            }
            function checkJsxExpression(node, checkMode) {
                checkGrammarJsxExpression(node);
                if (node.expression) {
                    const type = checkExpression(node.expression, checkMode);
                    if (node.dotDotDotToken && type !== anyType && !isArrayType(type)) {
                        error(node, Diagnostics.JSX_spread_child_must_be_an_array_type);
                    }
                    return type;
                }
                else {
                    return errorType;
                }
            }
            function getDeclarationNodeFlagsFromSymbol(s) {
                return s.valueDeclaration ? getCombinedNodeFlags(s.valueDeclaration) : 0;
            }
            function isPrototypeProperty(symbol) {
                if (symbol.flags & 8192 /* Method */ || getCheckFlags(symbol) & 4 /* SyntheticMethod */) {
                    return true;
                }
                if (isInJSFile(symbol.valueDeclaration)) {
                    const parent2 = symbol.valueDeclaration.parent;
                    return parent2 && isBinaryExpression(parent2) && getAssignmentDeclarationKind(parent2) === 3 /* PrototypeProperty */;
                }
            }
            function checkPropertyAccessibility(node, isSuper, writing, type, prop, reportError = true) {
                const errorNode = !reportError ? void 0 : node.kind === 163 /* QualifiedName */ ? node.right : node.kind === 202 /* ImportType */ ? node : node.kind === 205 /* BindingElement */ && node.propertyName ? node.propertyName : node.name;
                return checkPropertyAccessibilityAtLocation(node, isSuper, writing, type, prop, errorNode);
            }
            function checkPropertyAccessibilityAtLocation(location, isSuper, writing, containingType, prop, errorNode) {
                const flags = getDeclarationModifierFlagsFromSymbol(prop, writing);
                if (isSuper) {
                    if (languageVersion < 2 /* ES2015 */) {
                        if (symbolHasNonMethodDeclaration(prop)) {
                            if (errorNode) {
                                error(errorNode, Diagnostics.Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword);
                            }
                            return false;
                        }
                    }
                    if (flags & 256 /* Abstract */) {
                        if (errorNode) {
                            error(errorNode, Diagnostics.Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression, symbolToString(prop), typeToString(getDeclaringClass(prop)));
                        }
                        return false;
                    }
                }
                if (flags & 256 /* Abstract */ && symbolHasNonMethodDeclaration(prop) && (isThisProperty(location) || isThisInitializedObjectBindingExpression(location) || isObjectBindingPattern(location.parent) && isThisInitializedDeclaration(location.parent.parent))) {
                    const declaringClassDeclaration = getClassLikeDeclarationOfSymbol(getParentOfSymbol(prop));
                    if (declaringClassDeclaration && isNodeUsedDuringClassInitialization(location)) {
                        if (errorNode) {
                            error(errorNode, Diagnostics.Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor, symbolToString(prop), getTextOfIdentifierOrLiteral(declaringClassDeclaration.name));
                        }
                        return false;
                    }
                }
                if (!(flags & 24 /* NonPublicAccessibilityModifier */)) {
                    return true;
                }
                if (flags & 8 /* Private */) {
                    const declaringClassDeclaration = getClassLikeDeclarationOfSymbol(getParentOfSymbol(prop));
                    if (!isNodeWithinClass(location, declaringClassDeclaration)) {
                        if (errorNode) {
                            error(errorNode, Diagnostics.Property_0_is_private_and_only_accessible_within_class_1, symbolToString(prop), typeToString(getDeclaringClass(prop)));
                        }
                        return false;
                    }
                    return true;
                }
                if (isSuper) {
                    return true;
                }
                let enclosingClass = forEachEnclosingClass(location, (enclosingDeclaration) => {
                    const enclosingClass2 = getDeclaredTypeOfSymbol(getSymbolOfDeclaration(enclosingDeclaration));
                    return isClassDerivedFromDeclaringClasses(enclosingClass2, prop, writing);
                });
                if (!enclosingClass) {
                    enclosingClass = getEnclosingClassFromThisParameter(location);
                    enclosingClass = enclosingClass && isClassDerivedFromDeclaringClasses(enclosingClass, prop, writing);
                    if (flags & 32 /* Static */ || !enclosingClass) {
                        if (errorNode) {
                            error(errorNode, Diagnostics.Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses, symbolToString(prop), typeToString(getDeclaringClass(prop) || containingType));
                        }
                        return false;
                    }
                }
                if (flags & 32 /* Static */) {
                    return true;
                }
                if (containingType.flags & 262144 /* TypeParameter */) {
                    containingType = containingType.isThisType ? getConstraintOfTypeParameter(containingType) : getBaseConstraintOfType(containingType);
                }
                if (!containingType || !hasBaseType(containingType, enclosingClass)) {
                    if (errorNode) {
                        error(errorNode, Diagnostics.Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_class_2, symbolToString(prop), typeToString(enclosingClass), typeToString(containingType));
                    }
                    return false;
                }
                return true;
            }
            function getEnclosingClassFromThisParameter(node) {
                const thisParameter = getThisParameterFromNodeContext(node);
                let thisType = (thisParameter == null ? void 0 : thisParameter.type) && getTypeFromTypeNode(thisParameter.type);
                if (thisType && thisType.flags & 262144 /* TypeParameter */) {
                    thisType = getConstraintOfTypeParameter(thisType);
                }
                if (thisType && getObjectFlags(thisType) & (3 /* ClassOrInterface */ | 4 /* Reference */)) {
                    return getTargetType(thisType);
                }
                return void 0;
            }
            function getThisParameterFromNodeContext(node) {
                const thisContainer = getThisContainer(node, 
                /* includeArrowFunctions */
                false, 
                /*includeClassComputedPropertyName*/
                false);
                return thisContainer && isFunctionLike(thisContainer) ? getThisParameter(thisContainer) : void 0;
            }
            function symbolHasNonMethodDeclaration(symbol) {
                return !!forEachProperty2(symbol, (prop) => !(prop.flags & 8192 /* Method */));
            }
            function checkNonNullExpression(node) {
                return checkNonNullType(checkExpression(node), node);
            }
            function isNullableType(type) {
                return !!(getTypeFacts(type) & 50331648 /* IsUndefinedOrNull */);
            }
            function getNonNullableTypeIfNeeded(type) {
                return isNullableType(type) ? getNonNullableType(type) : type;
            }
            function reportObjectPossiblyNullOrUndefinedError(node, facts) {
                const nodeText2 = isEntityNameExpression(node) ? entityNameToString(node) : void 0;
                if (node.kind === 104 /* NullKeyword */) {
                    error(node, Diagnostics.The_value_0_cannot_be_used_here, "null");
                    return;
                }
                if (nodeText2 !== void 0 && nodeText2.length < 100) {
                    if (isIdentifier(node) && nodeText2 === "undefined") {
                        error(node, Diagnostics.The_value_0_cannot_be_used_here, "undefined");
                        return;
                    }
                    error(node, facts & 16777216 /* IsUndefined */ ? facts & 33554432 /* IsNull */ ? Diagnostics._0_is_possibly_null_or_undefined : Diagnostics._0_is_possibly_undefined : Diagnostics._0_is_possibly_null, nodeText2);
                }
                else {
                    error(node, facts & 16777216 /* IsUndefined */ ? facts & 33554432 /* IsNull */ ? Diagnostics.Object_is_possibly_null_or_undefined : Diagnostics.Object_is_possibly_undefined : Diagnostics.Object_is_possibly_null);
                }
            }
            function reportCannotInvokePossiblyNullOrUndefinedError(node, facts) {
                error(node, facts & 16777216 /* IsUndefined */ ? facts & 33554432 /* IsNull */ ? Diagnostics.Cannot_invoke_an_object_which_is_possibly_null_or_undefined : Diagnostics.Cannot_invoke_an_object_which_is_possibly_undefined : Diagnostics.Cannot_invoke_an_object_which_is_possibly_null);
            }
            function checkNonNullTypeWithReporter(type, node, reportError) {
                if (strictNullChecks && type.flags & 2 /* Unknown */) {
                    if (isEntityNameExpression(node)) {
                        const nodeText2 = entityNameToString(node);
                        if (nodeText2.length < 100) {
                            error(node, Diagnostics._0_is_of_type_unknown, nodeText2);
                            return errorType;
                        }
                    }
                    error(node, Diagnostics.Object_is_of_type_unknown);
                    return errorType;
                }
                const facts = getTypeFacts(type);
                if (facts & 50331648 /* IsUndefinedOrNull */) {
                    reportError(node, facts);
                    const t = getNonNullableType(type);
                    return t.flags & (98304 /* Nullable */ | 131072 /* Never */) ? errorType : t;
                }
                return type;
            }
            function checkNonNullType(type, node) {
                return checkNonNullTypeWithReporter(type, node, reportObjectPossiblyNullOrUndefinedError);
            }
            function checkNonNullNonVoidType(type, node) {
                const nonNullType = checkNonNullType(type, node);
                if (nonNullType.flags & 16384 /* Void */) {
                    if (isEntityNameExpression(node)) {
                        const nodeText2 = entityNameToString(node);
                        if (isIdentifier(node) && nodeText2 === "undefined") {
                            error(node, Diagnostics.The_value_0_cannot_be_used_here, nodeText2);
                            return nonNullType;
                        }
                        if (nodeText2.length < 100) {
                            error(node, Diagnostics._0_is_possibly_undefined, nodeText2);
                            return nonNullType;
                        }
                    }
                    error(node, Diagnostics.Object_is_possibly_undefined);
                }
                return nonNullType;
            }
            function checkPropertyAccessExpression(node, checkMode) {
                return node.flags & 32 /* OptionalChain */ ? checkPropertyAccessChain(node, checkMode) : checkPropertyAccessExpressionOrQualifiedName(node, node.expression, checkNonNullExpression(node.expression), node.name, checkMode);
            }
            function checkPropertyAccessChain(node, checkMode) {
                const leftType = checkExpression(node.expression);
                const nonOptionalType = getOptionalExpressionType(leftType, node.expression);
                return propagateOptionalTypeMarker(checkPropertyAccessExpressionOrQualifiedName(node, node.expression, checkNonNullType(nonOptionalType, node.expression), node.name, checkMode), node, nonOptionalType !== leftType);
            }
            function checkQualifiedName(node, checkMode) {
                const leftType = isPartOfTypeQuery(node) && isThisIdentifier(node.left) ? checkNonNullType(checkThisExpression(node.left), node.left) : checkNonNullExpression(node.left);
                return checkPropertyAccessExpressionOrQualifiedName(node, node.left, leftType, node.right, checkMode);
            }
            function isMethodAccessForCall(node) {
                while (node.parent.kind === 214 /* ParenthesizedExpression */) {
                    node = node.parent;
                }
                return isCallOrNewExpression(node.parent) && node.parent.expression === node;
            }
            function lookupSymbolForPrivateIdentifierDeclaration(propName, location) {
                for (let containingClass = getContainingClass(location); !!containingClass; containingClass = getContainingClass(containingClass)) {
                    const { symbol } = containingClass;
                    const name = getSymbolNameForPrivateIdentifier(symbol, propName);
                    const prop = symbol.members && symbol.members.get(name) || symbol.exports && symbol.exports.get(name);
                    if (prop) {
                        return prop;
                    }
                }
            }
            function checkGrammarPrivateIdentifierExpression(privId) {
                if (!getContainingClass(privId)) {
                    return grammarErrorOnNode(privId, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                }
                if (!isForInStatement(privId.parent)) {
                    if (!isExpressionNode(privId)) {
                        return grammarErrorOnNode(privId, Diagnostics.Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression);
                    }
                    const isInOperation = isBinaryExpression(privId.parent) && privId.parent.operatorToken.kind === 101 /* InKeyword */;
                    if (!getSymbolForPrivateIdentifierExpression(privId) && !isInOperation) {
                        return grammarErrorOnNode(privId, Diagnostics.Cannot_find_name_0, idText(privId));
                    }
                }
                return false;
            }
            function checkPrivateIdentifierExpression(privId) {
                checkGrammarPrivateIdentifierExpression(privId);
                const symbol = getSymbolForPrivateIdentifierExpression(privId);
                if (symbol) {
                    markPropertyAsReferenced(symbol, 
                    /* nodeForCheckWriteOnly: */
                    void 0, 
                    /* isThisAccess: */
                    false);
                }
                return anyType;
            }
            function getSymbolForPrivateIdentifierExpression(privId) {
                if (!isExpressionNode(privId)) {
                    return void 0;
                }
                const links = getNodeLinks(privId);
                if (links.resolvedSymbol === void 0) {
                    links.resolvedSymbol = lookupSymbolForPrivateIdentifierDeclaration(privId.escapedText, privId);
                }
                return links.resolvedSymbol;
            }
            function getPrivateIdentifierPropertyOfType(leftType, lexicallyScopedIdentifier) {
                return getPropertyOfType(leftType, lexicallyScopedIdentifier.escapedName);
            }
            function checkPrivateIdentifierPropertyAccess(leftType, right, lexicallyScopedIdentifier) {
                let propertyOnType;
                const properties = getPropertiesOfType(leftType);
                if (properties) {
                    forEach(properties, (symbol) => {
                        const decl = symbol.valueDeclaration;
                        if (decl && isNamedDeclaration(decl) && isPrivateIdentifier(decl.name) && decl.name.escapedText === right.escapedText) {
                            propertyOnType = symbol;
                            return true;
                        }
                    });
                }
                const diagName = diagnosticName(right);
                if (propertyOnType) {
                    const typeValueDecl = Debug.checkDefined(propertyOnType.valueDeclaration);
                    const typeClass = Debug.checkDefined(getContainingClass(typeValueDecl));
                    if (lexicallyScopedIdentifier == null ? void 0 : lexicallyScopedIdentifier.valueDeclaration) {
                        const lexicalValueDecl = lexicallyScopedIdentifier.valueDeclaration;
                        const lexicalClass = getContainingClass(lexicalValueDecl);
                        Debug.assert(!!lexicalClass);
                        if (findAncestor(lexicalClass, (n) => typeClass === n)) {
                            const diagnostic = error(right, Diagnostics.The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_private_identifier_with_the_same_spelling, diagName, typeToString(leftType));
                            addRelatedInfo(diagnostic, createDiagnosticForNode(lexicalValueDecl, Diagnostics.The_shadowing_declaration_of_0_is_defined_here, diagName), createDiagnosticForNode(typeValueDecl, Diagnostics.The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here, diagName));
                            return true;
                        }
                    }
                    error(right, Diagnostics.Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier, diagName, diagnosticName(typeClass.name || anon));
                    return true;
                }
                return false;
            }
            function isThisPropertyAccessInConstructor(node, prop) {
                return (isConstructorDeclaredProperty(prop) || isThisProperty(node) && isAutoTypedProperty(prop)) && getThisContainer(node, 
                /*includeArrowFunctions*/
                true, 
                /*includeClassComputedPropertyName*/
                false) === getDeclaringConstructor(prop);
            }
            function checkPropertyAccessExpressionOrQualifiedName(node, left, leftType, right, checkMode) {
                const parentSymbol = getNodeLinks(left).resolvedSymbol;
                const assignmentKind = getAssignmentTargetKind(node);
                const apparentType = getApparentType(assignmentKind !== 0 /* None */ || isMethodAccessForCall(node) ? getWidenedType(leftType) : leftType);
                const isAnyLike = isTypeAny(apparentType) || apparentType === silentNeverType;
                let prop;
                if (isPrivateIdentifier(right)) {
                    if (languageVersion < 99 /* ESNext */) {
                        if (assignmentKind !== 0 /* None */) {
                            checkExternalEmitHelpers(node, 1048576 /* ClassPrivateFieldSet */);
                        }
                        if (assignmentKind !== 1 /* Definite */) {
                            checkExternalEmitHelpers(node, 524288 /* ClassPrivateFieldGet */);
                        }
                    }
                    const lexicallyScopedSymbol = lookupSymbolForPrivateIdentifierDeclaration(right.escapedText, right);
                    if (assignmentKind && lexicallyScopedSymbol && lexicallyScopedSymbol.valueDeclaration && isMethodDeclaration(lexicallyScopedSymbol.valueDeclaration)) {
                        grammarErrorOnNode(right, Diagnostics.Cannot_assign_to_private_method_0_Private_methods_are_not_writable, idText(right));
                    }
                    if (isAnyLike) {
                        if (lexicallyScopedSymbol) {
                            return isErrorType(apparentType) ? errorType : apparentType;
                        }
                        if (!getContainingClass(right)) {
                            grammarErrorOnNode(right, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                            return anyType;
                        }
                    }
                    prop = lexicallyScopedSymbol ? getPrivateIdentifierPropertyOfType(leftType, lexicallyScopedSymbol) : void 0;
                    if (!prop && checkPrivateIdentifierPropertyAccess(leftType, right, lexicallyScopedSymbol)) {
                        return errorType;
                    }
                    else {
                        const isSetonlyAccessor = prop && prop.flags & 65536 /* SetAccessor */ && !(prop.flags & 32768 /* GetAccessor */);
                        if (isSetonlyAccessor && assignmentKind !== 1 /* Definite */) {
                            error(node, Diagnostics.Private_accessor_was_defined_without_a_getter);
                        }
                    }
                }
                else {
                    if (isAnyLike) {
                        if (isIdentifier(left) && parentSymbol) {
                            markAliasReferenced(parentSymbol, node);
                        }
                        return isErrorType(apparentType) ? errorType : apparentType;
                    }
                    prop = getPropertyOfType(apparentType, right.escapedText, 
                    /*skipObjectFunctionPropertyAugment*/
                    false, 
                    /*includeTypeOnlyMembers*/
                    node.kind === 163 /* QualifiedName */);
                }
                if (isIdentifier(left) && parentSymbol && (getIsolatedModules(compilerOptions) || !(prop && (isConstEnumOrConstEnumOnlyModule(prop) || prop.flags & 8 /* EnumMember */ && node.parent.kind === 302 /* EnumMember */)) || shouldPreserveConstEnums(compilerOptions) && isExportOrExportExpression(node))) {
                    markAliasReferenced(parentSymbol, node);
                }
                let propType;
                if (!prop) {
                    const indexInfo = !isPrivateIdentifier(right) && (assignmentKind === 0 /* None */ || !isGenericObjectType(leftType) || isThisTypeParameter(leftType)) ? getApplicableIndexInfoForName(apparentType, right.escapedText) : void 0;
                    if (!(indexInfo && indexInfo.type)) {
                        const isUncheckedJS = isUncheckedJSSuggestion(node, leftType.symbol, 
                        /*excludeClasses*/
                        true);
                        if (!isUncheckedJS && isJSLiteralType(leftType)) {
                            return anyType;
                        }
                        if (leftType.symbol === globalThisSymbol) {
                            if (globalThisSymbol.exports.has(right.escapedText) && globalThisSymbol.exports.get(right.escapedText).flags & 418 /* BlockScoped */) {
                                error(right, Diagnostics.Property_0_does_not_exist_on_type_1, unescapeLeadingUnderscores(right.escapedText), typeToString(leftType));
                            }
                            else if (noImplicitAny) {
                                error(right, Diagnostics.Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature, typeToString(leftType));
                            }
                            return anyType;
                        }
                        if (right.escapedText && !checkAndReportErrorForExtendingInterface(node)) {
                            reportNonexistentProperty(right, isThisTypeParameter(leftType) ? apparentType : leftType, isUncheckedJS);
                        }
                        return errorType;
                    }
                    if (indexInfo.isReadonly && (isAssignmentTarget(node) || isDeleteTarget(node))) {
                        error(node, Diagnostics.Index_signature_in_type_0_only_permits_reading, typeToString(apparentType));
                    }
                    propType = compilerOptions.noUncheckedIndexedAccess && !isAssignmentTarget(node) ? getUnionType([indexInfo.type, missingType]) : indexInfo.type;
                    if (compilerOptions.noPropertyAccessFromIndexSignature && isPropertyAccessExpression(node)) {
                        error(right, Diagnostics.Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0, unescapeLeadingUnderscores(right.escapedText));
                    }
                    if (indexInfo.declaration && getCombinedNodeFlags(indexInfo.declaration) & 268435456 /* Deprecated */) {
                        addDeprecatedSuggestion(right, [indexInfo.declaration], right.escapedText);
                    }
                }
                else {
                    if (isDeprecatedSymbol(prop) && isUncalledFunctionReference(node, prop) && prop.declarations) {
                        addDeprecatedSuggestion(right, prop.declarations, right.escapedText);
                    }
                    checkPropertyNotUsedBeforeDeclaration(prop, node, right);
                    markPropertyAsReferenced(prop, node, isSelfTypeAccess(left, parentSymbol));
                    getNodeLinks(node).resolvedSymbol = prop;
                    const writing = isWriteAccess(node);
                    checkPropertyAccessibility(node, left.kind === 106 /* SuperKeyword */, writing, apparentType, prop);
                    if (isAssignmentToReadonlyEntity(node, prop, assignmentKind)) {
                        error(right, Diagnostics.Cannot_assign_to_0_because_it_is_a_read_only_property, idText(right));
                        return errorType;
                    }
                    propType = isThisPropertyAccessInConstructor(node, prop) ? autoType : writing ? getWriteTypeOfSymbol(prop) : getTypeOfSymbol(prop);
                }
                return getFlowTypeOfAccessExpression(node, prop, propType, right, checkMode);
            }
            function isUncheckedJSSuggestion(node, suggestion, excludeClasses) {
                const file = getSourceFileOfNode(node);
                if (file) {
                    if (compilerOptions.checkJs === void 0 && file.checkJsDirective === void 0 && (file.scriptKind === 1 /* JS */ || file.scriptKind === 2 /* JSX */)) {
                        const declarationFile = forEach(suggestion == null ? void 0 : suggestion.declarations, getSourceFileOfNode);
                        return !(file !== declarationFile && !!declarationFile && isGlobalSourceFile(declarationFile)) && !(excludeClasses && suggestion && suggestion.flags & 32 /* Class */) && !(!!node && excludeClasses && isPropertyAccessExpression(node) && node.expression.kind === 108 /* ThisKeyword */);
                    }
                }
                return false;
            }
            function getFlowTypeOfAccessExpression(node, prop, propType, errorNode, checkMode) {
                const assignmentKind = getAssignmentTargetKind(node);
                if (assignmentKind === 1 /* Definite */) {
                    return removeMissingType(propType, !!(prop && prop.flags & 16777216 /* Optional */));
                }
                if (prop && !(prop.flags & (3 /* Variable */ | 4 /* Property */ | 98304 /* Accessor */)) && !(prop.flags & 8192 /* Method */ && propType.flags & 1048576 /* Union */) && !isDuplicatedCommonJSExport(prop.declarations)) {
                    return propType;
                }
                if (propType === autoType) {
                    return getFlowTypeOfProperty(node, prop);
                }
                propType = getNarrowableTypeForReference(propType, node, checkMode);
                let assumeUninitialized = false;
                if (strictNullChecks && strictPropertyInitialization && isAccessExpression(node) && node.expression.kind === 108 /* ThisKeyword */) {
                    const declaration = prop && prop.valueDeclaration;
                    if (declaration && isPropertyWithoutInitializer(declaration)) {
                        if (!isStatic(declaration)) {
                            const flowContainer = getControlFlowContainer(node);
                            if (flowContainer.kind === 173 /* Constructor */ && flowContainer.parent === declaration.parent && !(declaration.flags & 16777216 /* Ambient */)) {
                                assumeUninitialized = true;
                            }
                        }
                    }
                }
                else if (strictNullChecks && prop && prop.valueDeclaration && isPropertyAccessExpression(prop.valueDeclaration) && getAssignmentDeclarationPropertyAccessKind(prop.valueDeclaration) && getControlFlowContainer(node) === getControlFlowContainer(prop.valueDeclaration)) {
                    assumeUninitialized = true;
                }
                const flowType = getFlowTypeOfReference(node, propType, assumeUninitialized ? getOptionalType(propType) : propType);
                if (assumeUninitialized && !containsUndefinedType(propType) && containsUndefinedType(flowType)) {
                    error(errorNode, Diagnostics.Property_0_is_used_before_being_assigned, symbolToString(prop));
                    return propType;
                }
                return assignmentKind ? getBaseTypeOfLiteralType(flowType) : flowType;
            }
            function checkPropertyNotUsedBeforeDeclaration(prop, node, right) {
                const { valueDeclaration } = prop;
                if (!valueDeclaration || getSourceFileOfNode(node).isDeclarationFile) {
                    return;
                }
                let diagnosticMessage;
                const declarationName = idText(right);
                if (isInPropertyInitializerOrClassStaticBlock(node) && !isOptionalPropertyDeclaration(valueDeclaration) && !(isAccessExpression(node) && isAccessExpression(node.expression)) && !isBlockScopedNameDeclaredBeforeUse(valueDeclaration, right) && !(isMethodDeclaration(valueDeclaration) && getCombinedModifierFlags(valueDeclaration) & 32 /* Static */) && (compilerOptions.useDefineForClassFields || !isPropertyDeclaredInAncestorClass(prop))) {
                    diagnosticMessage = error(right, Diagnostics.Property_0_is_used_before_its_initialization, declarationName);
                }
                else if (valueDeclaration.kind === 260 /* ClassDeclaration */ && node.parent.kind !== 180 /* TypeReference */ && !(valueDeclaration.flags & 16777216 /* Ambient */) && !isBlockScopedNameDeclaredBeforeUse(valueDeclaration, right)) {
                    diagnosticMessage = error(right, Diagnostics.Class_0_used_before_its_declaration, declarationName);
                }
                if (diagnosticMessage) {
                    addRelatedInfo(diagnosticMessage, createDiagnosticForNode(valueDeclaration, Diagnostics._0_is_declared_here, declarationName));
                }
            }
            function isInPropertyInitializerOrClassStaticBlock(node) {
                return !!findAncestor(node, (node2) => {
                    switch (node2.kind) {
                        case 169 /* PropertyDeclaration */:
                            return true;
                        case 299 /* PropertyAssignment */:
                        case 171 /* MethodDeclaration */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                        case 301 /* SpreadAssignment */:
                        case 164 /* ComputedPropertyName */:
                        case 236 /* TemplateSpan */:
                        case 291 /* JsxExpression */:
                        case 288 /* JsxAttribute */:
                        case 289 /* JsxAttributes */:
                        case 290 /* JsxSpreadAttribute */:
                        case 283 /* JsxOpeningElement */:
                        case 230 /* ExpressionWithTypeArguments */:
                        case 294 /* HeritageClause */:
                            return false;
                        case 216 /* ArrowFunction */:
                        case 241 /* ExpressionStatement */:
                            return isBlock(node2.parent) && isClassStaticBlockDeclaration(node2.parent.parent) ? true : "quit";
                        default:
                            return isExpressionNode(node2) ? false : "quit";
                    }
                });
            }
            function isPropertyDeclaredInAncestorClass(prop) {
                if (!(prop.parent.flags & 32 /* Class */)) {
                    return false;
                }
                let classType = getTypeOfSymbol(prop.parent);
                while (true) {
                    classType = classType.symbol && getSuperClass(classType);
                    if (!classType) {
                        return false;
                    }
                    const superProperty = getPropertyOfType(classType, prop.escapedName);
                    if (superProperty && superProperty.valueDeclaration) {
                        return true;
                    }
                }
            }
            function getSuperClass(classType) {
                const x = getBaseTypes(classType);
                if (x.length === 0) {
                    return void 0;
                }
                return getIntersectionType(x);
            }
            function reportNonexistentProperty(propNode, containingType, isUncheckedJS) {
                let errorInfo;
                let relatedInfo;
                if (!isPrivateIdentifier(propNode) && containingType.flags & 1048576 /* Union */ && !(containingType.flags & 134348796 /* Primitive */)) {
                    for (const subtype of containingType.types) {
                        if (!getPropertyOfType(subtype, propNode.escapedText) && !getApplicableIndexInfoForName(subtype, propNode.escapedText)) {
                            errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Property_0_does_not_exist_on_type_1, declarationNameToString(propNode), typeToString(subtype));
                            break;
                        }
                    }
                }
                if (typeHasStaticProperty(propNode.escapedText, containingType)) {
                    const propName = declarationNameToString(propNode);
                    const typeName = typeToString(containingType);
                    errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead, propName, typeName, typeName + "." + propName);
                }
                else {
                    const promisedType = getPromisedTypeOfPromise(containingType);
                    if (promisedType && getPropertyOfType(promisedType, propNode.escapedText)) {
                        errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Property_0_does_not_exist_on_type_1, declarationNameToString(propNode), typeToString(containingType));
                        relatedInfo = createDiagnosticForNode(propNode, Diagnostics.Did_you_forget_to_use_await);
                    }
                    else {
                        const missingProperty = declarationNameToString(propNode);
                        const container = typeToString(containingType);
                        const libSuggestion = getSuggestedLibForNonExistentProperty(missingProperty, containingType);
                        if (libSuggestion !== void 0) {
                            errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2_or_later, missingProperty, container, libSuggestion);
                        }
                        else {
                            const suggestion = getSuggestedSymbolForNonexistentProperty(propNode, containingType);
                            if (suggestion !== void 0) {
                                const suggestedName = symbolName(suggestion);
                                const message = isUncheckedJS ? Diagnostics.Property_0_may_not_exist_on_type_1_Did_you_mean_2 : Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2;
                                errorInfo = chainDiagnosticMessages(errorInfo, message, missingProperty, container, suggestedName);
                                relatedInfo = suggestion.valueDeclaration && createDiagnosticForNode(suggestion.valueDeclaration, Diagnostics._0_is_declared_here, suggestedName);
                            }
                            else {
                                const diagnostic = containerSeemsToBeEmptyDomElement(containingType) ? Diagnostics.Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom : Diagnostics.Property_0_does_not_exist_on_type_1;
                                errorInfo = chainDiagnosticMessages(elaborateNeverIntersection(errorInfo, containingType), diagnostic, missingProperty, container);
                            }
                        }
                    }
                }
                const resultDiagnostic = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(propNode), propNode, errorInfo);
                if (relatedInfo) {
                    addRelatedInfo(resultDiagnostic, relatedInfo);
                }
                addErrorOrSuggestion(!isUncheckedJS || errorInfo.code !== Diagnostics.Property_0_may_not_exist_on_type_1_Did_you_mean_2.code, resultDiagnostic);
            }
            function containerSeemsToBeEmptyDomElement(containingType) {
                return compilerOptions.lib && !compilerOptions.lib.includes("dom") && everyContainedType(containingType, (type) => type.symbol && /^(EventTarget|Node|((HTML[a-zA-Z]*)?Element))$/.test(unescapeLeadingUnderscores(type.symbol.escapedName))) && isEmptyObjectType(containingType);
            }
            function typeHasStaticProperty(propName, containingType) {
                const prop = containingType.symbol && getPropertyOfType(getTypeOfSymbol(containingType.symbol), propName);
                return prop !== void 0 && !!prop.valueDeclaration && isStatic(prop.valueDeclaration);
            }
            function getSuggestedLibForNonExistentName(name) {
                const missingName = diagnosticName(name);
                const allFeatures = getScriptTargetFeatures();
                const typeFeatures = allFeatures.get(missingName);
                return typeFeatures && firstIterator(typeFeatures.keys());
            }
            function getSuggestedLibForNonExistentProperty(missingProperty, containingType) {
                const container = getApparentType(containingType).symbol;
                if (!container) {
                    return void 0;
                }
                const containingTypeName = symbolName(container);
                const allFeatures = getScriptTargetFeatures();
                const typeFeatures = allFeatures.get(containingTypeName);
                if (typeFeatures) {
                    for (const [libTarget, featuresOfType] of typeFeatures) {
                        if (contains(featuresOfType, missingProperty)) {
                            return libTarget;
                        }
                    }
                }
            }
            function getSuggestedSymbolForNonexistentClassMember(name, baseType) {
                return getSpellingSuggestionForName(name, getPropertiesOfType(baseType), 106500 /* ClassMember */);
            }
            function getSuggestedSymbolForNonexistentProperty(name, containingType) {
                let props = getPropertiesOfType(containingType);
                if (typeof name !== "string") {
                    const parent2 = name.parent;
                    if (isPropertyAccessExpression(parent2)) {
                        props = filter(props, (prop) => isValidPropertyAccessForCompletions(parent2, containingType, prop));
                    }
                    name = idText(name);
                }
                return getSpellingSuggestionForName(name, props, 111551 /* Value */);
            }
            function getSuggestedSymbolForNonexistentJSXAttribute(name, containingType) {
                const strName = isString(name) ? name : idText(name);
                const properties = getPropertiesOfType(containingType);
                const jsxSpecific = strName === "for" ? find(properties, (x) => symbolName(x) === "htmlFor") : strName === "class" ? find(properties, (x) => symbolName(x) === "className") : void 0;
                return jsxSpecific != null ? jsxSpecific : getSpellingSuggestionForName(strName, properties, 111551 /* Value */);
            }
            function getSuggestionForNonexistentProperty(name, containingType) {
                const suggestion = getSuggestedSymbolForNonexistentProperty(name, containingType);
                return suggestion && symbolName(suggestion);
            }
            function getSuggestedSymbolForNonexistentSymbol(location, outerName, meaning) {
                Debug.assert(outerName !== void 0, "outername should always be defined");
                const result = resolveNameHelper(location, outerName, meaning, 
                /*nameNotFoundMessage*/
                void 0, outerName, 
                /*isUse*/
                false, 
                /*excludeGlobals*/
                false, 
                /*getSpellingSuggestions*/
                true, (symbols, name, meaning2) => {
                    Debug.assertEqual(outerName, name, "name should equal outerName");
                    const symbol = getSymbol2(symbols, name, meaning2);
                    if (symbol)
                        return symbol;
                    let candidates;
                    if (symbols === globals) {
                        const primitives = mapDefined(["string", "number", "boolean", "object", "bigint", "symbol"], (s) => symbols.has(s.charAt(0).toUpperCase() + s.slice(1)) ? createSymbol(524288 /* TypeAlias */, s) : void 0);
                        candidates = primitives.concat(arrayFrom(symbols.values()));
                    }
                    else {
                        candidates = arrayFrom(symbols.values());
                    }
                    return getSpellingSuggestionForName(unescapeLeadingUnderscores(name), candidates, meaning2);
                });
                return result;
            }
            function getSuggestionForNonexistentSymbol(location, outerName, meaning) {
                const symbolResult = getSuggestedSymbolForNonexistentSymbol(location, outerName, meaning);
                return symbolResult && symbolName(symbolResult);
            }
            function getSuggestedSymbolForNonexistentModule(name, targetModule) {
                return targetModule.exports && getSpellingSuggestionForName(idText(name), getExportsOfModuleAsArray(targetModule), 2623475 /* ModuleMember */);
            }
            function getSuggestionForNonexistentExport(name, targetModule) {
                const suggestion = getSuggestedSymbolForNonexistentModule(name, targetModule);
                return suggestion && symbolName(suggestion);
            }
            function getSuggestionForNonexistentIndexSignature(objectType, expr, keyedType) {
                function hasProp(name) {
                    const prop = getPropertyOfObjectType(objectType, name);
                    if (prop) {
                        const s = getSingleCallSignature(getTypeOfSymbol(prop));
                        return !!s && getMinArgumentCount(s) >= 1 && isTypeAssignableTo(keyedType, getTypeAtPosition(s, 0));
                    }
                    return false;
                }
                const suggestedMethod = isAssignmentTarget(expr) ? "set" : "get";
                if (!hasProp(suggestedMethod)) {
                    return void 0;
                }
                let suggestion = tryGetPropertyAccessOrIdentifierToString(expr.expression);
                if (suggestion === void 0) {
                    suggestion = suggestedMethod;
                }
                else {
                    suggestion += "." + suggestedMethod;
                }
                return suggestion;
            }
            function getSuggestedTypeForNonexistentStringLiteralType(source, target) {
                const candidates = target.types.filter((type) => !!(type.flags & 128 /* StringLiteral */));
                return getSpellingSuggestion(source.value, candidates, (type) => type.value);
            }
            function getSpellingSuggestionForName(name, symbols, meaning) {
                return getSpellingSuggestion(name, symbols, getCandidateName);
                function getCandidateName(candidate) {
                    const candidateName = symbolName(candidate);
                    if (startsWith(candidateName, '"')) {
                        return void 0;
                    }
                    if (candidate.flags & meaning) {
                        return candidateName;
                    }
                    if (candidate.flags & 2097152 /* Alias */) {
                        const alias = tryResolveAlias(candidate);
                        if (alias && alias.flags & meaning) {
                            return candidateName;
                        }
                    }
                    return void 0;
                }
            }
            function markPropertyAsReferenced(prop, nodeForCheckWriteOnly, isSelfTypeAccess2) {
                const valueDeclaration = prop && prop.flags & 106500 /* ClassMember */ && prop.valueDeclaration;
                if (!valueDeclaration) {
                    return;
                }
                const hasPrivateModifier = hasEffectiveModifier(valueDeclaration, 8 /* Private */);
                const hasPrivateIdentifier = prop.valueDeclaration && isNamedDeclaration(prop.valueDeclaration) && isPrivateIdentifier(prop.valueDeclaration.name);
                if (!hasPrivateModifier && !hasPrivateIdentifier) {
                    return;
                }
                if (nodeForCheckWriteOnly && isWriteOnlyAccess(nodeForCheckWriteOnly) && !(prop.flags & 65536 /* SetAccessor */)) {
                    return;
                }
                if (isSelfTypeAccess2) {
                    const containingMethod = findAncestor(nodeForCheckWriteOnly, isFunctionLikeDeclaration);
                    if (containingMethod && containingMethod.symbol === prop) {
                        return;
                    }
                }
                (getCheckFlags(prop) & 1 /* Instantiated */ ? getSymbolLinks(prop).target : prop).isReferenced = 67108863 /* All */;
            }
            function isSelfTypeAccess(name, parent2) {
                return name.kind === 108 /* ThisKeyword */ || !!parent2 && isEntityNameExpression(name) && parent2 === getResolvedSymbol(getFirstIdentifier(name));
            }
            function isValidPropertyAccess(node, propertyName) {
                switch (node.kind) {
                    case 208 /* PropertyAccessExpression */:
                        return isValidPropertyAccessWithType(node, node.expression.kind === 106 /* SuperKeyword */, propertyName, getWidenedType(checkExpression(node.expression)));
                    case 163 /* QualifiedName */:
                        return isValidPropertyAccessWithType(node, 
                        /*isSuper*/
                        false, propertyName, getWidenedType(checkExpression(node.left)));
                    case 202 /* ImportType */:
                        return isValidPropertyAccessWithType(node, 
                        /*isSuper*/
                        false, propertyName, getTypeFromTypeNode(node));
                }
            }
            function isValidPropertyAccessForCompletions(node, type, property) {
                return isPropertyAccessible(node, node.kind === 208 /* PropertyAccessExpression */ && node.expression.kind === 106 /* SuperKeyword */, 
                /* isWrite */
                false, type, property);
            }
            function isValidPropertyAccessWithType(node, isSuper, propertyName, type) {
                if (isTypeAny(type)) {
                    return true;
                }
                const prop = getPropertyOfType(type, propertyName);
                return !!prop && isPropertyAccessible(node, isSuper, 
                /* isWrite */
                false, type, prop);
            }
            function isPropertyAccessible(node, isSuper, isWrite, containingType, property) {
                if (isTypeAny(containingType)) {
                    return true;
                }
                if (property.valueDeclaration && isPrivateIdentifierClassElementDeclaration(property.valueDeclaration)) {
                    const declClass = getContainingClass(property.valueDeclaration);
                    return !isOptionalChain(node) && !!findAncestor(node, (parent2) => parent2 === declClass);
                }
                return checkPropertyAccessibilityAtLocation(node, isSuper, isWrite, containingType, property);
            }
            function getForInVariableSymbol(node) {
                const initializer = node.initializer;
                if (initializer.kind === 258 /* VariableDeclarationList */) {
                    const variable = initializer.declarations[0];
                    if (variable && !isBindingPattern(variable.name)) {
                        return getSymbolOfDeclaration(variable);
                    }
                }
                else if (initializer.kind === 79 /* Identifier */) {
                    return getResolvedSymbol(initializer);
                }
                return void 0;
            }
            function hasNumericPropertyNames(type) {
                return getIndexInfosOfType(type).length === 1 && !!getIndexInfoOfType(type, numberType);
            }
            function isForInVariableForNumericPropertyNames(expr) {
                const e = skipParentheses(expr);
                if (e.kind === 79 /* Identifier */) {
                    const symbol = getResolvedSymbol(e);
                    if (symbol.flags & 3 /* Variable */) {
                        let child = expr;
                        let node = expr.parent;
                        while (node) {
                            if (node.kind === 246 /* ForInStatement */ && child === node.statement && getForInVariableSymbol(node) === symbol && hasNumericPropertyNames(getTypeOfExpression(node.expression))) {
                                return true;
                            }
                            child = node;
                            node = node.parent;
                        }
                    }
                }
                return false;
            }
            function checkIndexedAccess(node, checkMode) {
                return node.flags & 32 /* OptionalChain */ ? checkElementAccessChain(node, checkMode) : checkElementAccessExpression(node, checkNonNullExpression(node.expression), checkMode);
            }
            function checkElementAccessChain(node, checkMode) {
                const exprType = checkExpression(node.expression);
                const nonOptionalType = getOptionalExpressionType(exprType, node.expression);
                return propagateOptionalTypeMarker(checkElementAccessExpression(node, checkNonNullType(nonOptionalType, node.expression), checkMode), node, nonOptionalType !== exprType);
            }
            function checkElementAccessExpression(node, exprType, checkMode) {
                const objectType = getAssignmentTargetKind(node) !== 0 /* None */ || isMethodAccessForCall(node) ? getWidenedType(exprType) : exprType;
                const indexExpression = node.argumentExpression;
                const indexType = checkExpression(indexExpression);
                if (isErrorType(objectType) || objectType === silentNeverType) {
                    return objectType;
                }
                if (isConstEnumObjectType(objectType) && !isStringLiteralLike(indexExpression)) {
                    error(indexExpression, Diagnostics.A_const_enum_member_can_only_be_accessed_using_a_string_literal);
                    return errorType;
                }
                const effectiveIndexType = isForInVariableForNumericPropertyNames(indexExpression) ? numberType : indexType;
                const accessFlags = isAssignmentTarget(node) ? 4 /* Writing */ | (isGenericObjectType(objectType) && !isThisTypeParameter(objectType) ? 2 /* NoIndexSignatures */ : 0) : 32 /* ExpressionPosition */;
                const indexedAccessType = getIndexedAccessTypeOrUndefined(objectType, effectiveIndexType, accessFlags, node) || errorType;
                return checkIndexedAccessIndexType(getFlowTypeOfAccessExpression(node, getNodeLinks(node).resolvedSymbol, indexedAccessType, indexExpression, checkMode), node);
            }
            function callLikeExpressionMayHaveTypeArguments(node) {
                return isCallOrNewExpression(node) || isTaggedTemplateExpression(node) || isJsxOpeningLikeElement(node);
            }
            function resolveUntypedCall(node) {
                if (callLikeExpressionMayHaveTypeArguments(node)) {
                    forEach(node.typeArguments, checkSourceElement);
                }
                if (node.kind === 212 /* TaggedTemplateExpression */) {
                    checkExpression(node.template);
                }
                else if (isJsxOpeningLikeElement(node)) {
                    checkExpression(node.attributes);
                }
                else if (node.kind !== 167 /* Decorator */) {
                    forEach(node.arguments, (argument) => {
                        checkExpression(argument);
                    });
                }
                return anySignature;
            }
            function resolveErrorCall(node) {
                resolveUntypedCall(node);
                return unknownSignature;
            }
            function reorderCandidates(signatures, result, callChainFlags) {
                let lastParent;
                let lastSymbol;
                let cutoffIndex = 0;
                let index;
                let specializedIndex = -1;
                let spliceIndex;
                Debug.assert(!result.length);
                for (const signature of signatures) {
                    const symbol = signature.declaration && getSymbolOfDeclaration(signature.declaration);
                    const parent2 = signature.declaration && signature.declaration.parent;
                    if (!lastSymbol || symbol === lastSymbol) {
                        if (lastParent && parent2 === lastParent) {
                            index = index + 1;
                        }
                        else {
                            lastParent = parent2;
                            index = cutoffIndex;
                        }
                    }
                    else {
                        index = cutoffIndex = result.length;
                        lastParent = parent2;
                    }
                    lastSymbol = symbol;
                    if (signatureHasLiteralTypes(signature)) {
                        specializedIndex++;
                        spliceIndex = specializedIndex;
                        cutoffIndex++;
                    }
                    else {
                        spliceIndex = index;
                    }
                    result.splice(spliceIndex, 0, callChainFlags ? getOptionalCallSignature(signature, callChainFlags) : signature);
                }
            }
            function isSpreadArgument(arg) {
                return !!arg && (arg.kind === 227 /* SpreadElement */ || arg.kind === 234 /* SyntheticExpression */ && arg.isSpread);
            }
            function getSpreadArgumentIndex(args) {
                return findIndex(args, isSpreadArgument);
            }
            function acceptsVoid(t) {
                return !!(t.flags & 16384 /* Void */);
            }
            function acceptsVoidUndefinedUnknownOrAny(t) {
                return !!(t.flags & (16384 /* Void */ | 32768 /* Undefined */ | 2 /* Unknown */ | 1 /* Any */));
            }
            function hasCorrectArity(node, args, signature, signatureHelpTrailingComma = false) {
                let argCount;
                let callIsIncomplete = false;
                let effectiveParameterCount = getParameterCount(signature);
                let effectiveMinimumArguments = getMinArgumentCount(signature);
                if (node.kind === 212 /* TaggedTemplateExpression */) {
                    argCount = args.length;
                    if (node.template.kind === 225 /* TemplateExpression */) {
                        const lastSpan = last(node.template.templateSpans);
                        callIsIncomplete = nodeIsMissing(lastSpan.literal) || !!lastSpan.literal.isUnterminated;
                    }
                    else {
                        const templateLiteral = node.template;
                        Debug.assert(templateLiteral.kind === 14 /* NoSubstitutionTemplateLiteral */);
                        callIsIncomplete = !!templateLiteral.isUnterminated;
                    }
                }
                else if (node.kind === 167 /* Decorator */) {
                    argCount = getDecoratorArgumentCount(node, signature);
                }
                else if (isJsxOpeningLikeElement(node)) {
                    callIsIncomplete = node.attributes.end === node.end;
                    if (callIsIncomplete) {
                        return true;
                    }
                    argCount = effectiveMinimumArguments === 0 ? args.length : 1;
                    effectiveParameterCount = args.length === 0 ? effectiveParameterCount : 1;
                    effectiveMinimumArguments = Math.min(effectiveMinimumArguments, 1);
                }
                else if (!node.arguments) {
                    Debug.assert(node.kind === 211 /* NewExpression */);
                    return getMinArgumentCount(signature) === 0;
                }
                else {
                    argCount = signatureHelpTrailingComma ? args.length + 1 : args.length;
                    callIsIncomplete = node.arguments.end === node.end;
                    const spreadArgIndex = getSpreadArgumentIndex(args);
                    if (spreadArgIndex >= 0) {
                        return spreadArgIndex >= getMinArgumentCount(signature) && (hasEffectiveRestParameter(signature) || spreadArgIndex < getParameterCount(signature));
                    }
                }
                if (!hasEffectiveRestParameter(signature) && argCount > effectiveParameterCount) {
                    return false;
                }
                if (callIsIncomplete || argCount >= effectiveMinimumArguments) {
                    return true;
                }
                for (let i = argCount; i < effectiveMinimumArguments; i++) {
                    const type = getTypeAtPosition(signature, i);
                    if (filterType(type, isInJSFile(node) && !strictNullChecks ? acceptsVoidUndefinedUnknownOrAny : acceptsVoid).flags & 131072 /* Never */) {
                        return false;
                    }
                }
                return true;
            }
            function hasCorrectTypeArgumentArity(signature, typeArguments) {
                const numTypeParameters = length(signature.typeParameters);
                const minTypeArgumentCount = getMinTypeArgumentCount(signature.typeParameters);
                return !some(typeArguments) || typeArguments.length >= minTypeArgumentCount && typeArguments.length <= numTypeParameters;
            }
            function getSingleCallSignature(type) {
                return getSingleSignature(type, 0 /* Call */, 
                /*allowMembers*/
                false);
            }
            function getSingleCallOrConstructSignature(type) {
                return getSingleSignature(type, 0 /* Call */, 
                /*allowMembers*/
                false) || getSingleSignature(type, 1 /* Construct */, 
                /*allowMembers*/
                false);
            }
            function getSingleSignature(type, kind, allowMembers) {
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    if (allowMembers || resolved.properties.length === 0 && resolved.indexInfos.length === 0) {
                        if (kind === 0 /* Call */ && resolved.callSignatures.length === 1 && resolved.constructSignatures.length === 0) {
                            return resolved.callSignatures[0];
                        }
                        if (kind === 1 /* Construct */ && resolved.constructSignatures.length === 1 && resolved.callSignatures.length === 0) {
                            return resolved.constructSignatures[0];
                        }
                    }
                }
                return void 0;
            }
            function instantiateSignatureInContextOf(signature, contextualSignature, inferenceContext, compareTypes) {
                const context = createInferenceContext(signature.typeParameters, signature, 0 /* None */, compareTypes);
                const restType = getEffectiveRestType(contextualSignature);
                const mapper = inferenceContext && (restType && restType.flags & 262144 /* TypeParameter */ ? inferenceContext.nonFixingMapper : inferenceContext.mapper);
                const sourceSignature = mapper ? instantiateSignature(contextualSignature, mapper) : contextualSignature;
                applyToParameterTypes(sourceSignature, signature, (source, target) => {
                    inferTypes(context.inferences, source, target);
                });
                if (!inferenceContext) {
                    applyToReturnTypes(contextualSignature, signature, (source, target) => {
                        inferTypes(context.inferences, source, target, 128 /* ReturnType */);
                    });
                }
                return getSignatureInstantiation(signature, getInferredTypes(context), isInJSFile(contextualSignature.declaration));
            }
            function inferJsxTypeArguments(node, signature, checkMode, context) {
                const paramType = getEffectiveFirstArgumentForJsxSignature(signature, node);
                const checkAttrType = checkExpressionWithContextualType(node.attributes, paramType, context, checkMode);
                inferTypes(context.inferences, checkAttrType, paramType);
                return getInferredTypes(context);
            }
            function getThisArgumentType(thisArgumentNode) {
                if (!thisArgumentNode) {
                    return voidType;
                }
                const thisArgumentType = checkExpression(thisArgumentNode);
                return isOptionalChainRoot(thisArgumentNode.parent) ? getNonNullableType(thisArgumentType) : isOptionalChain(thisArgumentNode.parent) ? removeOptionalTypeMarker(thisArgumentType) : thisArgumentType;
            }
            function inferTypeArguments(node, signature, args, checkMode, context) {
                if (isJsxOpeningLikeElement(node)) {
                    return inferJsxTypeArguments(node, signature, checkMode, context);
                }
                if (node.kind !== 167 /* Decorator */) {
                    const skipBindingPatterns = every(signature.typeParameters, (p) => !!getDefaultFromTypeParameter(p));
                    const contextualType = getContextualType2(node, skipBindingPatterns ? 8 /* SkipBindingPatterns */ : 0 /* None */);
                    if (contextualType) {
                        const inferenceTargetType = getReturnTypeOfSignature(signature);
                        if (couldContainTypeVariables(inferenceTargetType)) {
                            const outerContext = getInferenceContext(node);
                            const isFromBindingPattern = !skipBindingPatterns && getContextualType2(node, 8 /* SkipBindingPatterns */) !== contextualType;
                            if (!isFromBindingPattern) {
                                const outerMapper = getMapperFromContext(cloneInferenceContext(outerContext, 1 /* NoDefault */));
                                const instantiatedType = instantiateType(contextualType, outerMapper);
                                const contextualSignature = getSingleCallSignature(instantiatedType);
                                const inferenceSourceType = contextualSignature && contextualSignature.typeParameters ? getOrCreateTypeFromSignature(getSignatureInstantiationWithoutFillingInTypeArguments(contextualSignature, contextualSignature.typeParameters)) : instantiatedType;
                                inferTypes(context.inferences, inferenceSourceType, inferenceTargetType, 128 /* ReturnType */);
                            }
                            const returnContext = createInferenceContext(signature.typeParameters, signature, context.flags);
                            const returnSourceType = instantiateType(contextualType, outerContext && outerContext.returnMapper);
                            inferTypes(returnContext.inferences, returnSourceType, inferenceTargetType);
                            context.returnMapper = some(returnContext.inferences, hasInferenceCandidates) ? getMapperFromContext(cloneInferredPartOfContext(returnContext)) : void 0;
                        }
                    }
                }
                const restType = getNonArrayRestType(signature);
                const argCount = restType ? Math.min(getParameterCount(signature) - 1, args.length) : args.length;
                if (restType && restType.flags & 262144 /* TypeParameter */) {
                    const info = find(context.inferences, (info2) => info2.typeParameter === restType);
                    if (info) {
                        info.impliedArity = findIndex(args, isSpreadArgument, argCount) < 0 ? args.length - argCount : void 0;
                    }
                }
                const thisType = getThisTypeOfSignature(signature);
                if (thisType && couldContainTypeVariables(thisType)) {
                    const thisArgumentNode = getThisArgumentOfCall(node);
                    inferTypes(context.inferences, getThisArgumentType(thisArgumentNode), thisType);
                }
                for (let i = 0; i < argCount; i++) {
                    const arg = args[i];
                    if (arg.kind !== 229 /* OmittedExpression */ && !(checkMode & 32 /* IsForStringLiteralArgumentCompletions */ && hasSkipDirectInferenceFlag(arg))) {
                        const paramType = getTypeAtPosition(signature, i);
                        if (couldContainTypeVariables(paramType)) {
                            const argType = checkExpressionWithContextualType(arg, paramType, context, checkMode);
                            inferTypes(context.inferences, argType, paramType);
                        }
                    }
                }
                if (restType && couldContainTypeVariables(restType)) {
                    const spreadType = getSpreadArgumentType(args, argCount, args.length, restType, context, checkMode);
                    inferTypes(context.inferences, spreadType, restType);
                }
                return getInferredTypes(context);
            }
            function getMutableArrayOrTupleType(type) {
                return type.flags & 1048576 /* Union */ ? mapType(type, getMutableArrayOrTupleType) : type.flags & 1 /* Any */ || isMutableArrayOrTuple(getBaseConstraintOfType(type) || type) ? type : isTupleType(type) ? createTupleType(getTypeArguments(type), type.target.elementFlags, 
                /*readonly*/
                false, type.target.labeledElementDeclarations) : createTupleType([type], [8 /* Variadic */]);
            }
            function getSpreadArgumentType(args, index, argCount, restType, context, checkMode) {
                if (index >= argCount - 1) {
                    const arg = args[argCount - 1];
                    if (isSpreadArgument(arg)) {
                        return getMutableArrayOrTupleType(arg.kind === 234 /* SyntheticExpression */ ? arg.type : checkExpressionWithContextualType(arg.expression, restType, context, checkMode));
                    }
                }
                const types = [];
                const flags = [];
                const names = [];
                const inConstContext = isConstTypeVariable(restType);
                for (let i = index; i < argCount; i++) {
                    const arg = args[i];
                    if (isSpreadArgument(arg)) {
                        const spreadType = arg.kind === 234 /* SyntheticExpression */ ? arg.type : checkExpression(arg.expression);
                        if (isArrayLikeType(spreadType)) {
                            types.push(spreadType);
                            flags.push(8 /* Variadic */);
                        }
                        else {
                            types.push(checkIteratedTypeOrElementType(33 /* Spread */, spreadType, undefinedType, arg.kind === 227 /* SpreadElement */ ? arg.expression : arg));
                            flags.push(4 /* Rest */);
                        }
                    }
                    else {
                        const contextualType = getIndexedAccessType(restType, getNumberLiteralType(i - index), 256 /* Contextual */);
                        const argType = checkExpressionWithContextualType(arg, contextualType, context, checkMode);
                        const hasPrimitiveContextualType = inConstContext || maybeTypeOfKind(contextualType, 134348796 /* Primitive */ | 4194304 /* Index */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */);
                        types.push(hasPrimitiveContextualType ? getRegularTypeOfLiteralType(argType) : getWidenedLiteralType(argType));
                        flags.push(1 /* Required */);
                    }
                    if (arg.kind === 234 /* SyntheticExpression */ && arg.tupleNameSource) {
                        names.push(arg.tupleNameSource);
                    }
                }
                return createTupleType(types, flags, inConstContext, length(names) === length(types) ? names : void 0);
            }
            function checkTypeArguments(signature, typeArgumentNodes, reportErrors2, headMessage) {
                const isJavascript = isInJSFile(signature.declaration);
                const typeParameters = signature.typeParameters;
                const typeArgumentTypes = fillMissingTypeArguments(map(typeArgumentNodes, getTypeFromTypeNode), typeParameters, getMinTypeArgumentCount(typeParameters), isJavascript);
                let mapper;
                for (let i = 0; i < typeArgumentNodes.length; i++) {
                    Debug.assert(typeParameters[i] !== void 0, "Should not call checkTypeArguments with too many type arguments");
                    const constraint = getConstraintOfTypeParameter(typeParameters[i]);
                    if (constraint) {
                        const errorInfo = reportErrors2 && headMessage ? () => chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Type_0_does_not_satisfy_the_constraint_1) : void 0;
                        const typeArgumentHeadMessage = headMessage || Diagnostics.Type_0_does_not_satisfy_the_constraint_1;
                        if (!mapper) {
                            mapper = createTypeMapper(typeParameters, typeArgumentTypes);
                        }
                        const typeArgument = typeArgumentTypes[i];
                        if (!checkTypeAssignableTo(typeArgument, getTypeWithThisArgument(instantiateType(constraint, mapper), typeArgument), reportErrors2 ? typeArgumentNodes[i] : void 0, typeArgumentHeadMessage, errorInfo)) {
                            return void 0;
                        }
                    }
                }
                return typeArgumentTypes;
            }
            function getJsxReferenceKind(node) {
                if (isJsxIntrinsicIdentifier(node.tagName)) {
                    return 2 /* Mixed */;
                }
                const tagType = getApparentType(checkExpression(node.tagName));
                if (length(getSignaturesOfType(tagType, 1 /* Construct */))) {
                    return 0 /* Component */;
                }
                if (length(getSignaturesOfType(tagType, 0 /* Call */))) {
                    return 1 /* Function */;
                }
                return 2 /* Mixed */;
            }
            function checkApplicableSignatureForJsxOpeningLikeElement(node, signature, relation, checkMode, reportErrors2, containingMessageChain, errorOutputContainer) {
                const paramType = getEffectiveFirstArgumentForJsxSignature(signature, node);
                const attributesType = checkExpressionWithContextualType(node.attributes, paramType, 
                /*inferenceContext*/
                void 0, checkMode);
                return checkTagNameDoesNotExpectTooManyArguments() && checkTypeRelatedToAndOptionallyElaborate(attributesType, paramType, relation, reportErrors2 ? node.tagName : void 0, node.attributes, 
                /*headMessage*/
                void 0, containingMessageChain, errorOutputContainer);
                function checkTagNameDoesNotExpectTooManyArguments() {
                    var _a2;
                    if (getJsxNamespaceContainerForImplicitImport(node)) {
                        return true;
                    }
                    const tagType = isJsxOpeningElement(node) || isJsxSelfClosingElement(node) && !isJsxIntrinsicIdentifier(node.tagName) ? checkExpression(node.tagName) : void 0;
                    if (!tagType) {
                        return true;
                    }
                    const tagCallSignatures = getSignaturesOfType(tagType, 0 /* Call */);
                    if (!length(tagCallSignatures)) {
                        return true;
                    }
                    const factory2 = getJsxFactoryEntity(node);
                    if (!factory2) {
                        return true;
                    }
                    const factorySymbol = resolveEntityName(factory2, 111551 /* Value */, 
                    /*ignoreErrors*/
                    true, 
                    /*dontResolveAlias*/
                    false, node);
                    if (!factorySymbol) {
                        return true;
                    }
                    const factoryType = getTypeOfSymbol(factorySymbol);
                    const callSignatures = getSignaturesOfType(factoryType, 0 /* Call */);
                    if (!length(callSignatures)) {
                        return true;
                    }
                    let hasFirstParamSignatures = false;
                    let maxParamCount = 0;
                    for (const sig of callSignatures) {
                        const firstparam = getTypeAtPosition(sig, 0);
                        const signaturesOfParam = getSignaturesOfType(firstparam, 0 /* Call */);
                        if (!length(signaturesOfParam))
                            continue;
                        for (const paramSig of signaturesOfParam) {
                            hasFirstParamSignatures = true;
                            if (hasEffectiveRestParameter(paramSig)) {
                                return true;
                            }
                            const paramCount = getParameterCount(paramSig);
                            if (paramCount > maxParamCount) {
                                maxParamCount = paramCount;
                            }
                        }
                    }
                    if (!hasFirstParamSignatures) {
                        return true;
                    }
                    let absoluteMinArgCount = Infinity;
                    for (const tagSig of tagCallSignatures) {
                        const tagRequiredArgCount = getMinArgumentCount(tagSig);
                        if (tagRequiredArgCount < absoluteMinArgCount) {
                            absoluteMinArgCount = tagRequiredArgCount;
                        }
                    }
                    if (absoluteMinArgCount <= maxParamCount) {
                        return true;
                    }
                    if (reportErrors2) {
                        const diag2 = createDiagnosticForNode(node.tagName, Diagnostics.Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3, entityNameToString(node.tagName), absoluteMinArgCount, entityNameToString(factory2), maxParamCount);
                        const tagNameDeclaration = (_a2 = getSymbolAtLocation(node.tagName)) == null ? void 0 : _a2.valueDeclaration;
                        if (tagNameDeclaration) {
                            addRelatedInfo(diag2, createDiagnosticForNode(tagNameDeclaration, Diagnostics._0_is_declared_here, entityNameToString(node.tagName)));
                        }
                        if (errorOutputContainer && errorOutputContainer.skipLogging) {
                            (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                        }
                        if (!errorOutputContainer.skipLogging) {
                            diagnostics.add(diag2);
                        }
                    }
                    return false;
                }
            }
            function getSignatureApplicabilityError(node, args, signature, relation, checkMode, reportErrors2, containingMessageChain) {
                const errorOutputContainer = { errors: void 0, skipLogging: true };
                if (isJsxOpeningLikeElement(node)) {
                    if (!checkApplicableSignatureForJsxOpeningLikeElement(node, signature, relation, checkMode, reportErrors2, containingMessageChain, errorOutputContainer)) {
                        Debug.assert(!reportErrors2 || !!errorOutputContainer.errors, "jsx should have errors when reporting errors");
                        return errorOutputContainer.errors || emptyArray;
                    }
                    return void 0;
                }
                const thisType = getThisTypeOfSignature(signature);
                if (thisType && thisType !== voidType && !(isNewExpression(node) || isCallExpression(node) && isSuperProperty(node.expression))) {
                    const thisArgumentNode = getThisArgumentOfCall(node);
                    const thisArgumentType = getThisArgumentType(thisArgumentNode);
                    const errorNode = reportErrors2 ? thisArgumentNode || node : void 0;
                    const headMessage2 = Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1;
                    if (!checkTypeRelatedTo(thisArgumentType, thisType, relation, errorNode, headMessage2, containingMessageChain, errorOutputContainer)) {
                        Debug.assert(!reportErrors2 || !!errorOutputContainer.errors, "this parameter should have errors when reporting errors");
                        return errorOutputContainer.errors || emptyArray;
                    }
                }
                const headMessage = Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1;
                const restType = getNonArrayRestType(signature);
                const argCount = restType ? Math.min(getParameterCount(signature) - 1, args.length) : args.length;
                for (let i = 0; i < argCount; i++) {
                    const arg = args[i];
                    if (arg.kind !== 229 /* OmittedExpression */) {
                        const paramType = getTypeAtPosition(signature, i);
                        const argType = checkExpressionWithContextualType(arg, paramType, 
                        /*inferenceContext*/
                        void 0, checkMode);
                        const checkArgType = checkMode & 4 /* SkipContextSensitive */ ? getRegularTypeOfObjectLiteral(argType) : argType;
                        if (!checkTypeRelatedToAndOptionallyElaborate(checkArgType, paramType, relation, reportErrors2 ? arg : void 0, arg, headMessage, containingMessageChain, errorOutputContainer)) {
                            Debug.assert(!reportErrors2 || !!errorOutputContainer.errors, "parameter should have errors when reporting errors");
                            maybeAddMissingAwaitInfo(arg, checkArgType, paramType);
                            return errorOutputContainer.errors || emptyArray;
                        }
                    }
                }
                if (restType) {
                    const spreadType = getSpreadArgumentType(args, argCount, args.length, restType, 
                    /*context*/
                    void 0, checkMode);
                    const restArgCount = args.length - argCount;
                    const errorNode = !reportErrors2 ? void 0 : restArgCount === 0 ? node : restArgCount === 1 ? args[argCount] : setTextRangePosEnd(createSyntheticExpression(node, spreadType), args[argCount].pos, args[args.length - 1].end);
                    if (!checkTypeRelatedTo(spreadType, restType, relation, errorNode, headMessage, 
                    /*containingMessageChain*/
                    void 0, errorOutputContainer)) {
                        Debug.assert(!reportErrors2 || !!errorOutputContainer.errors, "rest parameter should have errors when reporting errors");
                        maybeAddMissingAwaitInfo(errorNode, spreadType, restType);
                        return errorOutputContainer.errors || emptyArray;
                    }
                }
                return void 0;
                function maybeAddMissingAwaitInfo(errorNode, source, target) {
                    if (errorNode && reportErrors2 && errorOutputContainer.errors && errorOutputContainer.errors.length) {
                        if (getAwaitedTypeOfPromise(target)) {
                            return;
                        }
                        const awaitedTypeOfSource = getAwaitedTypeOfPromise(source);
                        if (awaitedTypeOfSource && isTypeRelatedTo(awaitedTypeOfSource, target, relation)) {
                            addRelatedInfo(errorOutputContainer.errors[0], createDiagnosticForNode(errorNode, Diagnostics.Did_you_forget_to_use_await));
                        }
                    }
                }
            }
            function getThisArgumentOfCall(node) {
                const expression = node.kind === 210 /* CallExpression */ ? node.expression : node.kind === 212 /* TaggedTemplateExpression */ ? node.tag : void 0;
                if (expression) {
                    const callee = skipOuterExpressions(expression);
                    if (isAccessExpression(callee)) {
                        return callee.expression;
                    }
                }
            }
            function createSyntheticExpression(parent2, type, isSpread, tupleNameSource) {
                const result = parseNodeFactory.createSyntheticExpression(type, isSpread, tupleNameSource);
                setTextRange(result, parent2);
                setParent(result, parent2);
                return result;
            }
            function getEffectiveCallArguments(node) {
                if (node.kind === 212 /* TaggedTemplateExpression */) {
                    const template = node.template;
                    const args2 = [createSyntheticExpression(template, getGlobalTemplateStringsArrayType())];
                    if (template.kind === 225 /* TemplateExpression */) {
                        forEach(template.templateSpans, (span) => {
                            args2.push(span.expression);
                        });
                    }
                    return args2;
                }
                if (node.kind === 167 /* Decorator */) {
                    return getEffectiveDecoratorArguments(node);
                }
                if (isJsxOpeningLikeElement(node)) {
                    return node.attributes.properties.length > 0 || isJsxOpeningElement(node) && node.parent.children.length > 0 ? [node.attributes] : emptyArray;
                }
                const args = node.arguments || emptyArray;
                const spreadIndex = getSpreadArgumentIndex(args);
                if (spreadIndex >= 0) {
                    const effectiveArgs = args.slice(0, spreadIndex);
                    for (let i = spreadIndex; i < args.length; i++) {
                        const arg = args[i];
                        const spreadType = arg.kind === 227 /* SpreadElement */ && (flowLoopCount ? checkExpression(arg.expression) : checkExpressionCached(arg.expression));
                        if (spreadType && isTupleType(spreadType)) {
                            forEach(getTypeArguments(spreadType), (t, i2) => {
                                var _a2;
                                const flags = spreadType.target.elementFlags[i2];
                                const syntheticArg = createSyntheticExpression(arg, flags & 4 /* Rest */ ? createArrayType(t) : t, !!(flags & 12 /* Variable */), (_a2 = spreadType.target.labeledElementDeclarations) == null ? void 0 : _a2[i2]);
                                effectiveArgs.push(syntheticArg);
                            });
                        }
                        else {
                            effectiveArgs.push(arg);
                        }
                    }
                    return effectiveArgs;
                }
                return args;
            }
            function getEffectiveDecoratorArguments(node) {
                const expr = node.expression;
                const signature = getDecoratorCallSignature(node);
                if (signature) {
                    const args = [];
                    for (const param of signature.parameters) {
                        const type = getTypeOfSymbol(param);
                        args.push(createSyntheticExpression(expr, type));
                    }
                    return args;
                }
                return Debug.fail();
            }
            function getDecoratorArgumentCount(node, signature) {
                return compilerOptions.experimentalDecorators ? getLegacyDecoratorArgumentCount(node, signature) : 2;
            }
            function getLegacyDecoratorArgumentCount(node, signature) {
                switch (node.parent.kind) {
                    case 260 /* ClassDeclaration */:
                    case 228 /* ClassExpression */:
                        return 1;
                    case 169 /* PropertyDeclaration */:
                        return hasAccessorModifier(node.parent) ? 3 : 2;
                    case 171 /* MethodDeclaration */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        return languageVersion === 0 /* ES3 */ || signature.parameters.length <= 2 ? 2 : 3;
                    case 166 /* Parameter */:
                        return 3;
                    default:
                        return Debug.fail();
                }
            }
            function getDiagnosticSpanForCallNode(node, doNotIncludeArguments) {
                let start;
                let length2;
                const sourceFile = getSourceFileOfNode(node);
                if (isPropertyAccessExpression(node.expression)) {
                    const nameSpan = getErrorSpanForNode(sourceFile, node.expression.name);
                    start = nameSpan.start;
                    length2 = doNotIncludeArguments ? nameSpan.length : node.end - start;
                }
                else {
                    const expressionSpan = getErrorSpanForNode(sourceFile, node.expression);
                    start = expressionSpan.start;
                    length2 = doNotIncludeArguments ? expressionSpan.length : node.end - start;
                }
                return { start, length: length2, sourceFile };
            }
            function getDiagnosticForCallNode(node, message, arg0, arg1, arg2, arg3) {
                if (isCallExpression(node)) {
                    const { sourceFile, start, length: length2 } = getDiagnosticSpanForCallNode(node);
                    if ("message" in message) {
                        return createFileDiagnostic(sourceFile, start, length2, message, arg0, arg1, arg2, arg3);
                    }
                    return createDiagnosticForFileFromMessageChain(sourceFile, message);
                }
                else {
                    if ("message" in message) {
                        return createDiagnosticForNode(node, message, arg0, arg1, arg2, arg3);
                    }
                    return createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(node), node, message);
                }
            }
            function isPromiseResolveArityError(node) {
                if (!isCallExpression(node) || !isIdentifier(node.expression))
                    return false;
                const symbol = resolveName(node.expression, node.expression.escapedText, 111551 /* Value */, void 0, void 0, false);
                const decl = symbol == null ? void 0 : symbol.valueDeclaration;
                if (!decl || !isParameter(decl) || !isFunctionExpressionOrArrowFunction(decl.parent) || !isNewExpression(decl.parent.parent) || !isIdentifier(decl.parent.parent.expression)) {
                    return false;
                }
                const globalPromiseSymbol = getGlobalPromiseConstructorSymbol(
                /*reportErrors*/
                false);
                if (!globalPromiseSymbol)
                    return false;
                const constructorSymbol = getSymbolAtLocation(decl.parent.parent.expression, 
                /*ignoreErrors*/
                true);
                return constructorSymbol === globalPromiseSymbol;
            }
            function getArgumentArityError(node, signatures, args, headMessage) {
                var _a2;
                const spreadIndex = getSpreadArgumentIndex(args);
                if (spreadIndex > -1) {
                    return createDiagnosticForNode(args[spreadIndex], Diagnostics.A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter);
                }
                let min2 = Number.POSITIVE_INFINITY;
                let max = Number.NEGATIVE_INFINITY;
                let maxBelow = Number.NEGATIVE_INFINITY;
                let minAbove = Number.POSITIVE_INFINITY;
                let closestSignature;
                for (const sig of signatures) {
                    const minParameter = getMinArgumentCount(sig);
                    const maxParameter = getParameterCount(sig);
                    if (minParameter < min2) {
                        min2 = minParameter;
                        closestSignature = sig;
                    }
                    max = Math.max(max, maxParameter);
                    if (minParameter < args.length && minParameter > maxBelow)
                        maxBelow = minParameter;
                    if (args.length < maxParameter && maxParameter < minAbove)
                        minAbove = maxParameter;
                }
                const hasRestParameter2 = some(signatures, hasEffectiveRestParameter);
                const parameterRange = hasRestParameter2 ? min2 : min2 < max ? min2 + "-" + max : min2;
                const isVoidPromiseError = !hasRestParameter2 && parameterRange === 1 && args.length === 0 && isPromiseResolveArityError(node);
                if (isVoidPromiseError && isInJSFile(node)) {
                    return getDiagnosticForCallNode(node, Diagnostics.Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_without_arguments);
                }
                const error2 = isDecorator(node) ? hasRestParameter2 ? Diagnostics.The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_at_least_0 : Diagnostics.The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_0 : hasRestParameter2 ? Diagnostics.Expected_at_least_0_arguments_but_got_1 : isVoidPromiseError ? Diagnostics.Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise : Diagnostics.Expected_0_arguments_but_got_1;
                if (min2 < args.length && args.length < max) {
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments, args.length, maxBelow, minAbove);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        return getDiagnosticForCallNode(node, chain);
                    }
                    return getDiagnosticForCallNode(node, Diagnostics.No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments, args.length, maxBelow, minAbove);
                }
                else if (args.length < min2) {
                    let diagnostic;
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, error2, parameterRange, args.length);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        diagnostic = getDiagnosticForCallNode(node, chain);
                    }
                    else {
                        diagnostic = getDiagnosticForCallNode(node, error2, parameterRange, args.length);
                    }
                    const parameter = (_a2 = closestSignature == null ? void 0 : closestSignature.declaration) == null ? void 0 : _a2.parameters[closestSignature.thisParameter ? args.length + 1 : args.length];
                    if (parameter) {
                        const parameterError = createDiagnosticForNode(parameter, isBindingPattern(parameter.name) ? Diagnostics.An_argument_matching_this_binding_pattern_was_not_provided : isRestParameter(parameter) ? Diagnostics.Arguments_for_the_rest_parameter_0_were_not_provided : Diagnostics.An_argument_for_0_was_not_provided, !parameter.name ? args.length : !isBindingPattern(parameter.name) ? idText(getFirstIdentifier(parameter.name)) : void 0);
                        return addRelatedInfo(diagnostic, parameterError);
                    }
                    return diagnostic;
                }
                else {
                    const errorSpan = factory.createNodeArray(args.slice(max));
                    const pos = first(errorSpan).pos;
                    let end = last(errorSpan).end;
                    if (end === pos) {
                        end++;
                    }
                    setTextRangePosEnd(errorSpan, pos, end);
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, error2, parameterRange, args.length);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        return createDiagnosticForNodeArrayFromMessageChain(getSourceFileOfNode(node), errorSpan, chain);
                    }
                    return createDiagnosticForNodeArray(getSourceFileOfNode(node), errorSpan, error2, parameterRange, args.length);
                }
            }
            function getTypeArgumentArityError(node, signatures, typeArguments, headMessage) {
                const argCount = typeArguments.length;
                if (signatures.length === 1) {
                    const sig = signatures[0];
                    const min2 = getMinTypeArgumentCount(sig.typeParameters);
                    const max = length(sig.typeParameters);
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Expected_0_type_arguments_but_got_1, min2 < max ? min2 + "-" + max : min2, argCount);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        return createDiagnosticForNodeArrayFromMessageChain(getSourceFileOfNode(node), typeArguments, chain);
                    }
                    return createDiagnosticForNodeArray(getSourceFileOfNode(node), typeArguments, Diagnostics.Expected_0_type_arguments_but_got_1, min2 < max ? min2 + "-" + max : min2, argCount);
                }
                let belowArgCount = -Infinity;
                let aboveArgCount = Infinity;
                for (const sig of signatures) {
                    const min2 = getMinTypeArgumentCount(sig.typeParameters);
                    const max = length(sig.typeParameters);
                    if (min2 > argCount) {
                        aboveArgCount = Math.min(aboveArgCount, min2);
                    }
                    else if (max < argCount) {
                        belowArgCount = Math.max(belowArgCount, max);
                    }
                }
                if (belowArgCount !== -Infinity && aboveArgCount !== Infinity) {
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments, argCount, belowArgCount, aboveArgCount);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        return createDiagnosticForNodeArrayFromMessageChain(getSourceFileOfNode(node), typeArguments, chain);
                    }
                    return createDiagnosticForNodeArray(getSourceFileOfNode(node), typeArguments, Diagnostics.No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments, argCount, belowArgCount, aboveArgCount);
                }
                if (headMessage) {
                    let chain = chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics.Expected_0_type_arguments_but_got_1, belowArgCount === -Infinity ? aboveArgCount : belowArgCount, argCount);
                    chain = chainDiagnosticMessages(chain, headMessage);
                    return createDiagnosticForNodeArrayFromMessageChain(getSourceFileOfNode(node), typeArguments, chain);
                }
                return createDiagnosticForNodeArray(getSourceFileOfNode(node), typeArguments, Diagnostics.Expected_0_type_arguments_but_got_1, belowArgCount === -Infinity ? aboveArgCount : belowArgCount, argCount);
            }
            function resolveCall(node, signatures, candidatesOutArray, checkMode, callChainFlags, headMessage) {
                const isTaggedTemplate = node.kind === 212 /* TaggedTemplateExpression */;
                const isDecorator2 = node.kind === 167 /* Decorator */;
                const isJsxOpeningOrSelfClosingElement = isJsxOpeningLikeElement(node);
                const reportErrors2 = !isInferencePartiallyBlocked && !candidatesOutArray;
                let typeArguments;
                if (!isDecorator2 && !isSuperCall(node)) {
                    typeArguments = node.typeArguments;
                    if (isTaggedTemplate || isJsxOpeningOrSelfClosingElement || node.expression.kind !== 106 /* SuperKeyword */) {
                        forEach(typeArguments, checkSourceElement);
                    }
                }
                const candidates = candidatesOutArray || [];
                reorderCandidates(signatures, candidates, callChainFlags);
                if (!candidates.length) {
                    if (reportErrors2) {
                        diagnostics.add(getDiagnosticForCallNode(node, Diagnostics.Call_target_does_not_contain_any_signatures));
                    }
                    return resolveErrorCall(node);
                }
                const args = getEffectiveCallArguments(node);
                const isSingleNonGenericCandidate = candidates.length === 1 && !candidates[0].typeParameters;
                let argCheckMode = !isDecorator2 && !isSingleNonGenericCandidate && some(args, isContextSensitive) ? 4 /* SkipContextSensitive */ : 0 /* Normal */;
                argCheckMode |= checkMode & 32 /* IsForStringLiteralArgumentCompletions */;
                let candidatesForArgumentError;
                let candidateForArgumentArityError;
                let candidateForTypeArgumentError;
                let result;
                const signatureHelpTrailingComma = !!(checkMode & 16 /* IsForSignatureHelp */) && node.kind === 210 /* CallExpression */ && node.arguments.hasTrailingComma;
                if (candidates.length > 1) {
                    result = chooseOverload(candidates, subtypeRelation, isSingleNonGenericCandidate, signatureHelpTrailingComma);
                }
                if (!result) {
                    result = chooseOverload(candidates, assignableRelation, isSingleNonGenericCandidate, signatureHelpTrailingComma);
                }
                if (result) {
                    return result;
                }
                result = getCandidateForOverloadFailure(node, candidates, args, !!candidatesOutArray, checkMode);
                getNodeLinks(node).resolvedSignature = result;
                if (reportErrors2) {
                    if (candidatesForArgumentError) {
                        if (candidatesForArgumentError.length === 1 || candidatesForArgumentError.length > 3) {
                            const last2 = candidatesForArgumentError[candidatesForArgumentError.length - 1];
                            let chain;
                            if (candidatesForArgumentError.length > 3) {
                                chain = chainDiagnosticMessages(chain, Diagnostics.The_last_overload_gave_the_following_error);
                                chain = chainDiagnosticMessages(chain, Diagnostics.No_overload_matches_this_call);
                            }
                            if (headMessage) {
                                chain = chainDiagnosticMessages(chain, headMessage);
                            }
                            const diags = getSignatureApplicabilityError(node, args, last2, assignableRelation, 0 /* Normal */, 
                            /*reportErrors*/
                            true, () => chain);
                            if (diags) {
                                for (const d of diags) {
                                    if (last2.declaration && candidatesForArgumentError.length > 3) {
                                        addRelatedInfo(d, createDiagnosticForNode(last2.declaration, Diagnostics.The_last_overload_is_declared_here));
                                    }
                                    addImplementationSuccessElaboration(last2, d);
                                    diagnostics.add(d);
                                }
                            }
                            else {
                                Debug.fail("No error for last overload signature");
                            }
                        }
                        else {
                            const allDiagnostics = [];
                            let max = 0;
                            let min2 = Number.MAX_VALUE;
                            let minIndex = 0;
                            let i = 0;
                            for (const c of candidatesForArgumentError) {
                                const chain2 = () => chainDiagnosticMessages(
                                /*details*/
                                void 0, Diagnostics.Overload_0_of_1_2_gave_the_following_error, i + 1, candidates.length, signatureToString(c));
                                const diags2 = getSignatureApplicabilityError(node, args, c, assignableRelation, 0 /* Normal */, 
                                /*reportErrors*/
                                true, chain2);
                                if (diags2) {
                                    if (diags2.length <= min2) {
                                        min2 = diags2.length;
                                        minIndex = i;
                                    }
                                    max = Math.max(max, diags2.length);
                                    allDiagnostics.push(diags2);
                                }
                                else {
                                    Debug.fail("No error for 3 or fewer overload signatures");
                                }
                                i++;
                            }
                            const diags = max > 1 ? allDiagnostics[minIndex] : flatten(allDiagnostics);
                            Debug.assert(diags.length > 0, "No errors reported for 3 or fewer overload signatures");
                            let chain = chainDiagnosticMessages(map(diags, createDiagnosticMessageChainFromDiagnostic), Diagnostics.No_overload_matches_this_call);
                            if (headMessage) {
                                chain = chainDiagnosticMessages(chain, headMessage);
                            }
                            const related = [...flatMap(diags, (d) => d.relatedInformation)];
                            let diag2;
                            if (every(diags, (d) => d.start === diags[0].start && d.length === diags[0].length && d.file === diags[0].file)) {
                                const { file, start, length: length2 } = diags[0];
                                diag2 = { file, start, length: length2, code: chain.code, category: chain.category, messageText: chain, relatedInformation: related };
                            }
                            else {
                                diag2 = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(node), node, chain, related);
                            }
                            addImplementationSuccessElaboration(candidatesForArgumentError[0], diag2);
                            diagnostics.add(diag2);
                        }
                    }
                    else if (candidateForArgumentArityError) {
                        diagnostics.add(getArgumentArityError(node, [candidateForArgumentArityError], args, headMessage));
                    }
                    else if (candidateForTypeArgumentError) {
                        checkTypeArguments(candidateForTypeArgumentError, node.typeArguments, 
                        /*reportErrors*/
                        true, headMessage);
                    }
                    else {
                        const signaturesWithCorrectTypeArgumentArity = filter(signatures, (s) => hasCorrectTypeArgumentArity(s, typeArguments));
                        if (signaturesWithCorrectTypeArgumentArity.length === 0) {
                            diagnostics.add(getTypeArgumentArityError(node, signatures, typeArguments, headMessage));
                        }
                        else {
                            diagnostics.add(getArgumentArityError(node, signaturesWithCorrectTypeArgumentArity, args, headMessage));
                        }
                    }
                }
                return result;
                function addImplementationSuccessElaboration(failed, diagnostic) {
                    var _a2, _b;
                    const oldCandidatesForArgumentError = candidatesForArgumentError;
                    const oldCandidateForArgumentArityError = candidateForArgumentArityError;
                    const oldCandidateForTypeArgumentError = candidateForTypeArgumentError;
                    const failedSignatureDeclarations = ((_b = (_a2 = failed.declaration) == null ? void 0 : _a2.symbol) == null ? void 0 : _b.declarations) || emptyArray;
                    const isOverload = failedSignatureDeclarations.length > 1;
                    const implDecl = isOverload ? find(failedSignatureDeclarations, (d) => isFunctionLikeDeclaration(d) && nodeIsPresent(d.body)) : void 0;
                    if (implDecl) {
                        const candidate = getSignatureFromDeclaration(implDecl);
                        const isSingleNonGenericCandidate2 = !candidate.typeParameters;
                        if (chooseOverload([candidate], assignableRelation, isSingleNonGenericCandidate2)) {
                            addRelatedInfo(diagnostic, createDiagnosticForNode(implDecl, Diagnostics.The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_are_not_externally_visible));
                        }
                    }
                    candidatesForArgumentError = oldCandidatesForArgumentError;
                    candidateForArgumentArityError = oldCandidateForArgumentArityError;
                    candidateForTypeArgumentError = oldCandidateForTypeArgumentError;
                }
                function chooseOverload(candidates2, relation, isSingleNonGenericCandidate2, signatureHelpTrailingComma2 = false) {
                    candidatesForArgumentError = void 0;
                    candidateForArgumentArityError = void 0;
                    candidateForTypeArgumentError = void 0;
                    if (isSingleNonGenericCandidate2) {
                        const candidate = candidates2[0];
                        if (some(typeArguments) || !hasCorrectArity(node, args, candidate, signatureHelpTrailingComma2)) {
                            return void 0;
                        }
                        if (getSignatureApplicabilityError(node, args, candidate, relation, 0 /* Normal */, 
                        /*reportErrors*/
                        false, 
                        /*containingMessageChain*/
                        void 0)) {
                            candidatesForArgumentError = [candidate];
                            return void 0;
                        }
                        return candidate;
                    }
                    for (let candidateIndex = 0; candidateIndex < candidates2.length; candidateIndex++) {
                        const candidate = candidates2[candidateIndex];
                        if (!hasCorrectTypeArgumentArity(candidate, typeArguments) || !hasCorrectArity(node, args, candidate, signatureHelpTrailingComma2)) {
                            continue;
                        }
                        let checkCandidate;
                        let inferenceContext;
                        if (candidate.typeParameters) {
                            let typeArgumentTypes;
                            if (some(typeArguments)) {
                                typeArgumentTypes = checkTypeArguments(candidate, typeArguments, 
                                /*reportErrors*/
                                false);
                                if (!typeArgumentTypes) {
                                    candidateForTypeArgumentError = candidate;
                                    continue;
                                }
                            }
                            else {
                                inferenceContext = createInferenceContext(candidate.typeParameters, candidate, 
                                /*flags*/
                                isInJSFile(node) ? 2 /* AnyDefault */ : 0 /* None */);
                                typeArgumentTypes = inferTypeArguments(node, candidate, args, argCheckMode | 8 /* SkipGenericFunctions */, inferenceContext);
                                argCheckMode |= inferenceContext.flags & 4 /* SkippedGenericFunction */ ? 8 /* SkipGenericFunctions */ : 0 /* Normal */;
                            }
                            checkCandidate = getSignatureInstantiation(candidate, typeArgumentTypes, isInJSFile(candidate.declaration), inferenceContext && inferenceContext.inferredTypeParameters);
                            if (getNonArrayRestType(candidate) && !hasCorrectArity(node, args, checkCandidate, signatureHelpTrailingComma2)) {
                                candidateForArgumentArityError = checkCandidate;
                                continue;
                            }
                        }
                        else {
                            checkCandidate = candidate;
                        }
                        if (getSignatureApplicabilityError(node, args, checkCandidate, relation, argCheckMode, 
                        /*reportErrors*/
                        false, 
                        /*containingMessageChain*/
                        void 0)) {
                            (candidatesForArgumentError || (candidatesForArgumentError = [])).push(checkCandidate);
                            continue;
                        }
                        if (argCheckMode) {
                            argCheckMode = checkMode & 32 /* IsForStringLiteralArgumentCompletions */;
                            if (inferenceContext) {
                                const typeArgumentTypes = inferTypeArguments(node, candidate, args, argCheckMode, inferenceContext);
                                checkCandidate = getSignatureInstantiation(candidate, typeArgumentTypes, isInJSFile(candidate.declaration), inferenceContext.inferredTypeParameters);
                                if (getNonArrayRestType(candidate) && !hasCorrectArity(node, args, checkCandidate, signatureHelpTrailingComma2)) {
                                    candidateForArgumentArityError = checkCandidate;
                                    continue;
                                }
                            }
                            if (getSignatureApplicabilityError(node, args, checkCandidate, relation, argCheckMode, 
                            /*reportErrors*/
                            false, 
                            /*containingMessageChain*/
                            void 0)) {
                                (candidatesForArgumentError || (candidatesForArgumentError = [])).push(checkCandidate);
                                continue;
                            }
                        }
                        candidates2[candidateIndex] = checkCandidate;
                        return checkCandidate;
                    }
                    return void 0;
                }
            }
            function getCandidateForOverloadFailure(node, candidates, args, hasCandidatesOutArray, checkMode) {
                Debug.assert(candidates.length > 0);
                checkNodeDeferred(node);
                return hasCandidatesOutArray || candidates.length === 1 || candidates.some((c) => !!c.typeParameters) ? pickLongestCandidateSignature(node, candidates, args, checkMode) : createUnionOfSignaturesForOverloadFailure(candidates);
            }
            function createUnionOfSignaturesForOverloadFailure(candidates) {
                const thisParameters = mapDefined(candidates, (c) => c.thisParameter);
                let thisParameter;
                if (thisParameters.length) {
                    thisParameter = createCombinedSymbolFromTypes(thisParameters, thisParameters.map(getTypeOfParameter));
                }
                const { min: minArgumentCount, max: maxNonRestParam } = minAndMax(candidates, getNumNonRestParameters);
                const parameters = [];
                for (let i = 0; i < maxNonRestParam; i++) {
                    const symbols = mapDefined(candidates, (s) => signatureHasRestParameter(s) ? i < s.parameters.length - 1 ? s.parameters[i] : last(s.parameters) : i < s.parameters.length ? s.parameters[i] : void 0);
                    Debug.assert(symbols.length !== 0);
                    parameters.push(createCombinedSymbolFromTypes(symbols, mapDefined(candidates, (candidate) => tryGetTypeAtPosition(candidate, i))));
                }
                const restParameterSymbols = mapDefined(candidates, (c) => signatureHasRestParameter(c) ? last(c.parameters) : void 0);
                let flags = 0 /* None */;
                if (restParameterSymbols.length !== 0) {
                    const type = createArrayType(getUnionType(mapDefined(candidates, tryGetRestTypeOfSignature), 2 /* Subtype */));
                    parameters.push(createCombinedSymbolForOverloadFailure(restParameterSymbols, type));
                    flags |= 1 /* HasRestParameter */;
                }
                if (candidates.some(signatureHasLiteralTypes)) {
                    flags |= 2 /* HasLiteralTypes */;
                }
                return createSignature(candidates[0].declaration, 
                /*typeParameters*/
                void 0, 
                // Before calling this we tested for `!candidates.some(c => !!c.typeParameters)`.
                thisParameter, parameters, 
                /*resolvedReturnType*/
                getIntersectionType(candidates.map(getReturnTypeOfSignature)), 
                /*typePredicate*/
                void 0, minArgumentCount, flags);
            }
            function getNumNonRestParameters(signature) {
                const numParams = signature.parameters.length;
                return signatureHasRestParameter(signature) ? numParams - 1 : numParams;
            }
            function createCombinedSymbolFromTypes(sources, types) {
                return createCombinedSymbolForOverloadFailure(sources, getUnionType(types, 2 /* Subtype */));
            }
            function createCombinedSymbolForOverloadFailure(sources, type) {
                return createSymbolWithType(first(sources), type);
            }
            function pickLongestCandidateSignature(node, candidates, args, checkMode) {
                const bestIndex = getLongestCandidateIndex(candidates, apparentArgumentCount === void 0 ? args.length : apparentArgumentCount);
                const candidate = candidates[bestIndex];
                const { typeParameters } = candidate;
                if (!typeParameters) {
                    return candidate;
                }
                const typeArgumentNodes = callLikeExpressionMayHaveTypeArguments(node) ? node.typeArguments : void 0;
                const instantiated = typeArgumentNodes ? createSignatureInstantiation(candidate, getTypeArgumentsFromNodes(typeArgumentNodes, typeParameters, isInJSFile(node))) : inferSignatureInstantiationForOverloadFailure(node, typeParameters, candidate, args, checkMode);
                candidates[bestIndex] = instantiated;
                return instantiated;
            }
            function getTypeArgumentsFromNodes(typeArgumentNodes, typeParameters, isJs) {
                const typeArguments = typeArgumentNodes.map(getTypeOfNode);
                while (typeArguments.length > typeParameters.length) {
                    typeArguments.pop();
                }
                while (typeArguments.length < typeParameters.length) {
                    typeArguments.push(getDefaultFromTypeParameter(typeParameters[typeArguments.length]) || getConstraintOfTypeParameter(typeParameters[typeArguments.length]) || getDefaultTypeArgumentType(isJs));
                }
                return typeArguments;
            }
            function inferSignatureInstantiationForOverloadFailure(node, typeParameters, candidate, args, checkMode) {
                const inferenceContext = createInferenceContext(typeParameters, candidate, 
                /*flags*/
                isInJSFile(node) ? 2 /* AnyDefault */ : 0 /* None */);
                const typeArgumentTypes = inferTypeArguments(node, candidate, args, checkMode | 4 /* SkipContextSensitive */ | 8 /* SkipGenericFunctions */, inferenceContext);
                return createSignatureInstantiation(candidate, typeArgumentTypes);
            }
            function getLongestCandidateIndex(candidates, argsCount) {
                let maxParamsIndex = -1;
                let maxParams = -1;
                for (let i = 0; i < candidates.length; i++) {
                    const candidate = candidates[i];
                    const paramCount = getParameterCount(candidate);
                    if (hasEffectiveRestParameter(candidate) || paramCount >= argsCount) {
                        return i;
                    }
                    if (paramCount > maxParams) {
                        maxParams = paramCount;
                        maxParamsIndex = i;
                    }
                }
                return maxParamsIndex;
            }
            function resolveCallExpression(node, candidatesOutArray, checkMode) {
                if (node.expression.kind === 106 /* SuperKeyword */) {
                    const superType = checkSuperExpression(node.expression);
                    if (isTypeAny(superType)) {
                        for (const arg of node.arguments) {
                            checkExpression(arg);
                        }
                        return anySignature;
                    }
                    if (!isErrorType(superType)) {
                        const baseTypeNode = getEffectiveBaseTypeNode(getContainingClass(node));
                        if (baseTypeNode) {
                            const baseConstructors = getInstantiatedConstructorsForTypeArguments(superType, baseTypeNode.typeArguments, baseTypeNode);
                            return resolveCall(node, baseConstructors, candidatesOutArray, checkMode, 0 /* None */);
                        }
                    }
                    return resolveUntypedCall(node);
                }
                let callChainFlags;
                let funcType = checkExpression(node.expression);
                if (isCallChain(node)) {
                    const nonOptionalType = getOptionalExpressionType(funcType, node.expression);
                    callChainFlags = nonOptionalType === funcType ? 0 /* None */ : isOutermostOptionalChain(node) ? 16 /* IsOuterCallChain */ : 8 /* IsInnerCallChain */;
                    funcType = nonOptionalType;
                }
                else {
                    callChainFlags = 0 /* None */;
                }
                funcType = checkNonNullTypeWithReporter(funcType, node.expression, reportCannotInvokePossiblyNullOrUndefinedError);
                if (funcType === silentNeverType) {
                    return silentNeverSignature;
                }
                const apparentType = getApparentType(funcType);
                if (isErrorType(apparentType)) {
                    return resolveErrorCall(node);
                }
                const callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
                const numConstructSignatures = getSignaturesOfType(apparentType, 1 /* Construct */).length;
                if (isUntypedFunctionCall(funcType, apparentType, callSignatures.length, numConstructSignatures)) {
                    if (!isErrorType(funcType) && node.typeArguments) {
                        error(node, Diagnostics.Untyped_function_calls_may_not_accept_type_arguments);
                    }
                    return resolveUntypedCall(node);
                }
                if (!callSignatures.length) {
                    if (numConstructSignatures) {
                        error(node, Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new, typeToString(funcType));
                    }
                    else {
                        let relatedInformation;
                        if (node.arguments.length === 1) {
                            const text = getSourceFileOfNode(node).text;
                            if (isLineBreak(text.charCodeAt(skipTrivia(text, node.expression.end, 
                            /* stopAfterLineBreak */
                            true) - 1))) {
                                relatedInformation = createDiagnosticForNode(node.expression, Diagnostics.Are_you_missing_a_semicolon);
                            }
                        }
                        invocationError(node.expression, apparentType, 0 /* Call */, relatedInformation);
                    }
                    return resolveErrorCall(node);
                }
                if (checkMode & 8 /* SkipGenericFunctions */ && !node.typeArguments && callSignatures.some(isGenericFunctionReturningFunction)) {
                    skippedGenericFunction(node, checkMode);
                    return resolvingSignature;
                }
                if (callSignatures.some((sig) => isInJSFile(sig.declaration) && !!getJSDocClassTag(sig.declaration))) {
                    error(node, Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new, typeToString(funcType));
                    return resolveErrorCall(node);
                }
                return resolveCall(node, callSignatures, candidatesOutArray, checkMode, callChainFlags);
            }
            function isGenericFunctionReturningFunction(signature) {
                return !!(signature.typeParameters && isFunctionType(getReturnTypeOfSignature(signature)));
            }
            function isUntypedFunctionCall(funcType, apparentFuncType, numCallSignatures, numConstructSignatures) {
                return isTypeAny(funcType) || isTypeAny(apparentFuncType) && !!(funcType.flags & 262144 /* TypeParameter */) || !numCallSignatures && !numConstructSignatures && !(apparentFuncType.flags & 1048576 /* Union */) && !(getReducedType(apparentFuncType).flags & 131072 /* Never */) && isTypeAssignableTo(funcType, globalFunctionType);
            }
            function resolveNewExpression(node, candidatesOutArray, checkMode) {
                if (node.arguments && languageVersion < 1 /* ES5 */) {
                    const spreadIndex = getSpreadArgumentIndex(node.arguments);
                    if (spreadIndex >= 0) {
                        error(node.arguments[spreadIndex], Diagnostics.Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher);
                    }
                }
                let expressionType = checkNonNullExpression(node.expression);
                if (expressionType === silentNeverType) {
                    return silentNeverSignature;
                }
                expressionType = getApparentType(expressionType);
                if (isErrorType(expressionType)) {
                    return resolveErrorCall(node);
                }
                if (isTypeAny(expressionType)) {
                    if (node.typeArguments) {
                        error(node, Diagnostics.Untyped_function_calls_may_not_accept_type_arguments);
                    }
                    return resolveUntypedCall(node);
                }
                const constructSignatures = getSignaturesOfType(expressionType, 1 /* Construct */);
                if (constructSignatures.length) {
                    if (!isConstructorAccessible(node, constructSignatures[0])) {
                        return resolveErrorCall(node);
                    }
                    if (someSignature(constructSignatures, (signature) => !!(signature.flags & 4 /* Abstract */))) {
                        error(node, Diagnostics.Cannot_create_an_instance_of_an_abstract_class);
                        return resolveErrorCall(node);
                    }
                    const valueDecl = expressionType.symbol && getClassLikeDeclarationOfSymbol(expressionType.symbol);
                    if (valueDecl && hasSyntacticModifier(valueDecl, 256 /* Abstract */)) {
                        error(node, Diagnostics.Cannot_create_an_instance_of_an_abstract_class);
                        return resolveErrorCall(node);
                    }
                    return resolveCall(node, constructSignatures, candidatesOutArray, checkMode, 0 /* None */);
                }
                const callSignatures = getSignaturesOfType(expressionType, 0 /* Call */);
                if (callSignatures.length) {
                    const signature = resolveCall(node, callSignatures, candidatesOutArray, checkMode, 0 /* None */);
                    if (!noImplicitAny) {
                        if (signature.declaration && !isJSConstructor(signature.declaration) && getReturnTypeOfSignature(signature) !== voidType) {
                            error(node, Diagnostics.Only_a_void_function_can_be_called_with_the_new_keyword);
                        }
                        if (getThisTypeOfSignature(signature) === voidType) {
                            error(node, Diagnostics.A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void);
                        }
                    }
                    return signature;
                }
                invocationError(node.expression, expressionType, 1 /* Construct */);
                return resolveErrorCall(node);
            }
            function someSignature(signatures, f) {
                if (isArray(signatures)) {
                    return some(signatures, (signature) => someSignature(signature, f));
                }
                return signatures.compositeKind === 1048576 /* Union */ ? some(signatures.compositeSignatures, f) : f(signatures);
            }
            function typeHasProtectedAccessibleBase(target, type) {
                const baseTypes = getBaseTypes(type);
                if (!length(baseTypes)) {
                    return false;
                }
                const firstBase = baseTypes[0];
                if (firstBase.flags & 2097152 /* Intersection */) {
                    const types = firstBase.types;
                    const mixinFlags = findMixins(types);
                    let i = 0;
                    for (const intersectionMember of firstBase.types) {
                        if (!mixinFlags[i]) {
                            if (getObjectFlags(intersectionMember) & (1 /* Class */ | 2 /* Interface */)) {
                                if (intersectionMember.symbol === target) {
                                    return true;
                                }
                                if (typeHasProtectedAccessibleBase(target, intersectionMember)) {
                                    return true;
                                }
                            }
                        }
                        i++;
                    }
                    return false;
                }
                if (firstBase.symbol === target) {
                    return true;
                }
                return typeHasProtectedAccessibleBase(target, firstBase);
            }
            function isConstructorAccessible(node, signature) {
                if (!signature || !signature.declaration) {
                    return true;
                }
                const declaration = signature.declaration;
                const modifiers = getSelectedEffectiveModifierFlags(declaration, 24 /* NonPublicAccessibilityModifier */);
                if (!modifiers || declaration.kind !== 173 /* Constructor */) {
                    return true;
                }
                const declaringClassDeclaration = getClassLikeDeclarationOfSymbol(declaration.parent.symbol);
                const declaringClass = getDeclaredTypeOfSymbol(declaration.parent.symbol);
                if (!isNodeWithinClass(node, declaringClassDeclaration)) {
                    const containingClass = getContainingClass(node);
                    if (containingClass && modifiers & 16 /* Protected */) {
                        const containingType = getTypeOfNode(containingClass);
                        if (typeHasProtectedAccessibleBase(declaration.parent.symbol, containingType)) {
                            return true;
                        }
                    }
                    if (modifiers & 8 /* Private */) {
                        error(node, Diagnostics.Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration, typeToString(declaringClass));
                    }
                    if (modifiers & 16 /* Protected */) {
                        error(node, Diagnostics.Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration, typeToString(declaringClass));
                    }
                    return false;
                }
                return true;
            }
            function invocationErrorDetails(errorTarget, apparentType, kind) {
                let errorInfo;
                const isCall = kind === 0 /* Call */;
                const awaitedType = getAwaitedType(apparentType);
                const maybeMissingAwait = awaitedType && getSignaturesOfType(awaitedType, kind).length > 0;
                if (apparentType.flags & 1048576 /* Union */) {
                    const types = apparentType.types;
                    let hasSignatures = false;
                    for (const constituent of types) {
                        const signatures = getSignaturesOfType(constituent, kind);
                        if (signatures.length !== 0) {
                            hasSignatures = true;
                            if (errorInfo) {
                                break;
                            }
                        }
                        else {
                            if (!errorInfo) {
                                errorInfo = chainDiagnosticMessages(errorInfo, isCall ? Diagnostics.Type_0_has_no_call_signatures : Diagnostics.Type_0_has_no_construct_signatures, typeToString(constituent));
                                errorInfo = chainDiagnosticMessages(errorInfo, isCall ? Diagnostics.Not_all_constituents_of_type_0_are_callable : Diagnostics.Not_all_constituents_of_type_0_are_constructable, typeToString(apparentType));
                            }
                            if (hasSignatures) {
                                break;
                            }
                        }
                    }
                    if (!hasSignatures) {
                        errorInfo = chainDiagnosticMessages(
                        /* detials */
                        void 0, isCall ? Diagnostics.No_constituent_of_type_0_is_callable : Diagnostics.No_constituent_of_type_0_is_constructable, typeToString(apparentType));
                    }
                    if (!errorInfo) {
                        errorInfo = chainDiagnosticMessages(errorInfo, isCall ? Diagnostics.Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_other : Diagnostics.Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_with_each_other, typeToString(apparentType));
                    }
                }
                else {
                    errorInfo = chainDiagnosticMessages(errorInfo, isCall ? Diagnostics.Type_0_has_no_call_signatures : Diagnostics.Type_0_has_no_construct_signatures, typeToString(apparentType));
                }
                let headMessage = isCall ? Diagnostics.This_expression_is_not_callable : Diagnostics.This_expression_is_not_constructable;
                if (isCallExpression(errorTarget.parent) && errorTarget.parent.arguments.length === 0) {
                    const { resolvedSymbol } = getNodeLinks(errorTarget);
                    if (resolvedSymbol && resolvedSymbol.flags & 32768 /* GetAccessor */) {
                        headMessage = Diagnostics.This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without;
                    }
                }
                return {
                    messageChain: chainDiagnosticMessages(errorInfo, headMessage),
                    relatedMessage: maybeMissingAwait ? Diagnostics.Did_you_forget_to_use_await : void 0
                };
            }
            function invocationError(errorTarget, apparentType, kind, relatedInformation) {
                const { messageChain, relatedMessage: relatedInfo } = invocationErrorDetails(errorTarget, apparentType, kind);
                const diagnostic = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(errorTarget), errorTarget, messageChain);
                if (relatedInfo) {
                    addRelatedInfo(diagnostic, createDiagnosticForNode(errorTarget, relatedInfo));
                }
                if (isCallExpression(errorTarget.parent)) {
                    const { start, length: length2 } = getDiagnosticSpanForCallNode(errorTarget.parent, 
                    /* doNotIncludeArguments */
                    true);
                    diagnostic.start = start;
                    diagnostic.length = length2;
                }
                diagnostics.add(diagnostic);
                invocationErrorRecovery(apparentType, kind, relatedInformation ? addRelatedInfo(diagnostic, relatedInformation) : diagnostic);
            }
            function invocationErrorRecovery(apparentType, kind, diagnostic) {
                if (!apparentType.symbol) {
                    return;
                }
                const importNode = getSymbolLinks(apparentType.symbol).originatingImport;
                if (importNode && !isImportCall(importNode)) {
                    const sigs = getSignaturesOfType(getTypeOfSymbol(getSymbolLinks(apparentType.symbol).target), kind);
                    if (!sigs || !sigs.length)
                        return;
                    addRelatedInfo(diagnostic, createDiagnosticForNode(importNode, Diagnostics.Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead));
                }
            }
            function resolveTaggedTemplateExpression(node, candidatesOutArray, checkMode) {
                const tagType = checkExpression(node.tag);
                const apparentType = getApparentType(tagType);
                if (isErrorType(apparentType)) {
                    return resolveErrorCall(node);
                }
                const callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
                const numConstructSignatures = getSignaturesOfType(apparentType, 1 /* Construct */).length;
                if (isUntypedFunctionCall(tagType, apparentType, callSignatures.length, numConstructSignatures)) {
                    return resolveUntypedCall(node);
                }
                if (!callSignatures.length) {
                    if (isArrayLiteralExpression(node.parent)) {
                        const diagnostic = createDiagnosticForNode(node.tag, Diagnostics.It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tagged_template_expression_which_cannot_be_invoked);
                        diagnostics.add(diagnostic);
                        return resolveErrorCall(node);
                    }
                    invocationError(node.tag, apparentType, 0 /* Call */);
                    return resolveErrorCall(node);
                }
                return resolveCall(node, callSignatures, candidatesOutArray, checkMode, 0 /* None */);
            }
            function getDiagnosticHeadMessageForDecoratorResolution(node) {
                switch (node.parent.kind) {
                    case 260 /* ClassDeclaration */:
                    case 228 /* ClassExpression */:
                        return Diagnostics.Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression;
                    case 166 /* Parameter */:
                        return Diagnostics.Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression;
                    case 169 /* PropertyDeclaration */:
                        return Diagnostics.Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression;
                    case 171 /* MethodDeclaration */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        return Diagnostics.Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression;
                    default:
                        return Debug.fail();
                }
            }
            function resolveDecorator(node, candidatesOutArray, checkMode) {
                const funcType = checkExpression(node.expression);
                const apparentType = getApparentType(funcType);
                if (isErrorType(apparentType)) {
                    return resolveErrorCall(node);
                }
                const callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
                const numConstructSignatures = getSignaturesOfType(apparentType, 1 /* Construct */).length;
                if (isUntypedFunctionCall(funcType, apparentType, callSignatures.length, numConstructSignatures)) {
                    return resolveUntypedCall(node);
                }
                if (isPotentiallyUncalledDecorator(node, callSignatures) && !isParenthesizedExpression(node.expression)) {
                    const nodeStr = getTextOfNode(node.expression, 
                    /*includeTrivia*/
                    false);
                    error(node, Diagnostics._0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0, nodeStr);
                    return resolveErrorCall(node);
                }
                const headMessage = getDiagnosticHeadMessageForDecoratorResolution(node);
                if (!callSignatures.length) {
                    const errorDetails = invocationErrorDetails(node.expression, apparentType, 0 /* Call */);
                    const messageChain = chainDiagnosticMessages(errorDetails.messageChain, headMessage);
                    const diag2 = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(node.expression), node.expression, messageChain);
                    if (errorDetails.relatedMessage) {
                        addRelatedInfo(diag2, createDiagnosticForNode(node.expression, errorDetails.relatedMessage));
                    }
                    diagnostics.add(diag2);
                    invocationErrorRecovery(apparentType, 0 /* Call */, diag2);
                    return resolveErrorCall(node);
                }
                return resolveCall(node, callSignatures, candidatesOutArray, checkMode, 0 /* None */, headMessage);
            }
            function createSignatureForJSXIntrinsic(node, result) {
                const namespace = getJsxNamespaceAt(node);
                const exports = namespace && getExportsOfSymbol(namespace);
                const typeSymbol = exports && getSymbol2(exports, JsxNames.Element, 788968 /* Type */);
                const returnNode = typeSymbol && nodeBuilder.symbolToEntityName(typeSymbol, 788968 /* Type */, node);
                const declaration = factory.createFunctionTypeNode(
                /*typeParameters*/
                void 0, [factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotdotdot*/
                    void 0, "props", 
                    /*questionMark*/
                    void 0, nodeBuilder.typeToTypeNode(result, node))], returnNode ? factory.createTypeReferenceNode(returnNode, 
                /*typeArguments*/
                void 0) : factory.createKeywordTypeNode(131 /* AnyKeyword */));
                const parameterSymbol = createSymbol(1 /* FunctionScopedVariable */, "props");
                parameterSymbol.links.type = result;
                return createSignature(declaration, 
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, [parameterSymbol], typeSymbol ? getDeclaredTypeOfSymbol(typeSymbol) : errorType, 
                /*returnTypePredicate*/
                void 0, 1, 0 /* None */);
            }
            function resolveJsxOpeningLikeElement(node, candidatesOutArray, checkMode) {
                if (isJsxIntrinsicIdentifier(node.tagName)) {
                    const result = getIntrinsicAttributesTypeFromJsxOpeningLikeElement(node);
                    const fakeSignature = createSignatureForJSXIntrinsic(node, result);
                    checkTypeAssignableToAndOptionallyElaborate(checkExpressionWithContextualType(node.attributes, getEffectiveFirstArgumentForJsxSignature(fakeSignature, node), 
                    /*inferenceContext*/
                    void 0, 0 /* Normal */), result, node.tagName, node.attributes);
                    if (length(node.typeArguments)) {
                        forEach(node.typeArguments, checkSourceElement);
                        diagnostics.add(createDiagnosticForNodeArray(getSourceFileOfNode(node), node.typeArguments, Diagnostics.Expected_0_type_arguments_but_got_1, 0, length(node.typeArguments)));
                    }
                    return fakeSignature;
                }
                const exprTypes = checkExpression(node.tagName);
                const apparentType = getApparentType(exprTypes);
                if (isErrorType(apparentType)) {
                    return resolveErrorCall(node);
                }
                const signatures = getUninstantiatedJsxSignaturesOfType(exprTypes, node);
                if (isUntypedFunctionCall(exprTypes, apparentType, signatures.length, 
                /*constructSignatures*/
                0)) {
                    return resolveUntypedCall(node);
                }
                if (signatures.length === 0) {
                    error(node.tagName, Diagnostics.JSX_element_type_0_does_not_have_any_construct_or_call_signatures, getTextOfNode(node.tagName));
                    return resolveErrorCall(node);
                }
                return resolveCall(node, signatures, candidatesOutArray, checkMode, 0 /* None */);
            }
            function isPotentiallyUncalledDecorator(decorator, signatures) {
                return signatures.length && every(signatures, (signature) => signature.minArgumentCount === 0 && !signatureHasRestParameter(signature) && signature.parameters.length < getDecoratorArgumentCount(decorator, signature));
            }
            function resolveSignature(node, candidatesOutArray, checkMode) {
                switch (node.kind) {
                    case 210 /* CallExpression */:
                        return resolveCallExpression(node, candidatesOutArray, checkMode);
                    case 211 /* NewExpression */:
                        return resolveNewExpression(node, candidatesOutArray, checkMode);
                    case 212 /* TaggedTemplateExpression */:
                        return resolveTaggedTemplateExpression(node, candidatesOutArray, checkMode);
                    case 167 /* Decorator */:
                        return resolveDecorator(node, candidatesOutArray, checkMode);
                    case 283 /* JsxOpeningElement */:
                    case 282 /* JsxSelfClosingElement */:
                        return resolveJsxOpeningLikeElement(node, candidatesOutArray, checkMode);
                }
                throw Debug.assertNever(node, "Branch in 'resolveSignature' should be unreachable.");
            }
            function getResolvedSignature(node, candidatesOutArray, checkMode) {
                const links = getNodeLinks(node);
                const cached = links.resolvedSignature;
                if (cached && cached !== resolvingSignature && !candidatesOutArray) {
                    return cached;
                }
                links.resolvedSignature = resolvingSignature;
                const result = resolveSignature(node, candidatesOutArray, checkMode || 0 /* Normal */);
                if (result !== resolvingSignature) {
                    links.resolvedSignature = flowLoopStart === flowLoopCount ? result : cached;
                }
                return result;
            }
            function isJSConstructor(node) {
                var _a2;
                if (!node || !isInJSFile(node)) {
                    return false;
                }
                const func = isFunctionDeclaration(node) || isFunctionExpression(node) ? node : (isVariableDeclaration(node) || isPropertyAssignment(node)) && node.initializer && isFunctionExpression(node.initializer) ? node.initializer : void 0;
                if (func) {
                    if (getJSDocClassTag(node))
                        return true;
                    if (isPropertyAssignment(walkUpParenthesizedExpressions(func.parent)))
                        return false;
                    const symbol = getSymbolOfDeclaration(func);
                    return !!((_a2 = symbol == null ? void 0 : symbol.members) == null ? void 0 : _a2.size);
                }
                return false;
            }
            function mergeJSSymbols(target, source) {
                var _a2, _b;
                if (source) {
                    const links = getSymbolLinks(source);
                    if (!links.inferredClassSymbol || !links.inferredClassSymbol.has(getSymbolId(target))) {
                        const inferred = isTransientSymbol(target) ? target : cloneSymbol(target);
                        inferred.exports = inferred.exports || createSymbolTable();
                        inferred.members = inferred.members || createSymbolTable();
                        inferred.flags |= source.flags & 32 /* Class */;
                        if ((_a2 = source.exports) == null ? void 0 : _a2.size) {
                            mergeSymbolTable(inferred.exports, source.exports);
                        }
                        if ((_b = source.members) == null ? void 0 : _b.size) {
                            mergeSymbolTable(inferred.members, source.members);
                        }
                        (links.inferredClassSymbol || (links.inferredClassSymbol = /* @__PURE__ */ new Map())).set(getSymbolId(inferred), inferred);
                        return inferred;
                    }
                    return links.inferredClassSymbol.get(getSymbolId(target));
                }
            }
            function getAssignedClassSymbol(decl) {
                var _a2;
                const assignmentSymbol = decl && getSymbolOfExpando(decl, 
                /*allowDeclaration*/
                true);
                const prototype = (_a2 = assignmentSymbol == null ? void 0 : assignmentSymbol.exports) == null ? void 0 : _a2.get("prototype");
                const init = (prototype == null ? void 0 : prototype.valueDeclaration) && getAssignedJSPrototype(prototype.valueDeclaration);
                return init ? getSymbolOfDeclaration(init) : void 0;
            }
            function getSymbolOfExpando(node, allowDeclaration) {
                if (!node.parent) {
                    return void 0;
                }
                let name;
                let decl;
                if (isVariableDeclaration(node.parent) && node.parent.initializer === node) {
                    if (!isInJSFile(node) && !(isVarConst(node.parent) && isFunctionLikeDeclaration(node))) {
                        return void 0;
                    }
                    name = node.parent.name;
                    decl = node.parent;
                }
                else if (isBinaryExpression(node.parent)) {
                    const parentNode = node.parent;
                    const parentNodeOperator = node.parent.operatorToken.kind;
                    if (parentNodeOperator === 63 /* EqualsToken */ && (allowDeclaration || parentNode.right === node)) {
                        name = parentNode.left;
                        decl = name;
                    }
                    else if (parentNodeOperator === 56 /* BarBarToken */ || parentNodeOperator === 60 /* QuestionQuestionToken */) {
                        if (isVariableDeclaration(parentNode.parent) && parentNode.parent.initializer === parentNode) {
                            name = parentNode.parent.name;
                            decl = parentNode.parent;
                        }
                        else if (isBinaryExpression(parentNode.parent) && parentNode.parent.operatorToken.kind === 63 /* EqualsToken */ && (allowDeclaration || parentNode.parent.right === parentNode)) {
                            name = parentNode.parent.left;
                            decl = name;
                        }
                        if (!name || !isBindableStaticNameExpression(name) || !isSameEntityName(name, parentNode.left)) {
                            return void 0;
                        }
                    }
                }
                else if (allowDeclaration && isFunctionDeclaration(node)) {
                    name = node.name;
                    decl = node;
                }
                if (!decl || !name || !allowDeclaration && !getExpandoInitializer(node, isPrototypeAccess(name))) {
                    return void 0;
                }
                return getSymbolOfNode(decl);
            }
            function getAssignedJSPrototype(node) {
                if (!node.parent) {
                    return false;
                }
                let parent2 = node.parent;
                while (parent2 && parent2.kind === 208 /* PropertyAccessExpression */) {
                    parent2 = parent2.parent;
                }
                if (parent2 && isBinaryExpression(parent2) && isPrototypeAccess(parent2.left) && parent2.operatorToken.kind === 63 /* EqualsToken */) {
                    const right = getInitializerOfBinaryExpression(parent2);
                    return isObjectLiteralExpression(right) && right;
                }
            }
            function checkCallExpression(node, checkMode) {
                var _a2, _b, _c;
                checkGrammarTypeArguments(node, node.typeArguments);
                const signature = getResolvedSignature(node, 
                /*candidatesOutArray*/
                void 0, checkMode);
                if (signature === resolvingSignature) {
                    return silentNeverType;
                }
                checkDeprecatedSignature(signature, node);
                if (node.expression.kind === 106 /* SuperKeyword */) {
                    return voidType;
                }
                if (node.kind === 211 /* NewExpression */) {
                    const declaration = signature.declaration;
                    if (declaration && declaration.kind !== 173 /* Constructor */ && declaration.kind !== 177 /* ConstructSignature */ && declaration.kind !== 182 /* ConstructorType */ && !(isJSDocSignature(declaration) && ((_b = (_a2 = getJSDocRoot(declaration)) == null ? void 0 : _a2.parent) == null ? void 0 : _b.kind) === 173 /* Constructor */) && !isJSDocConstructSignature(declaration) && !isJSConstructor(declaration)) {
                        if (noImplicitAny) {
                            error(node, Diagnostics.new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type);
                        }
                        return anyType;
                    }
                }
                if (isInJSFile(node) && shouldResolveJsRequire(compilerOptions) && isCommonJsRequire(node)) {
                    return resolveExternalModuleTypeByLiteral(node.arguments[0]);
                }
                const returnType = getReturnTypeOfSignature(signature);
                if (returnType.flags & 12288 /* ESSymbolLike */ && isSymbolOrSymbolForCall(node)) {
                    return getESSymbolLikeTypeForNode(walkUpParenthesizedExpressions(node.parent));
                }
                if (node.kind === 210 /* CallExpression */ && !node.questionDotToken && node.parent.kind === 241 /* ExpressionStatement */ && returnType.flags & 16384 /* Void */ && getTypePredicateOfSignature(signature)) {
                    if (!isDottedName(node.expression)) {
                        error(node.expression, Diagnostics.Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name);
                    }
                    else if (!getEffectsSignature(node)) {
                        const diagnostic = error(node.expression, Diagnostics.Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation);
                        getTypeOfDottedName(node.expression, diagnostic);
                    }
                }
                if (isInJSFile(node)) {
                    const jsSymbol = getSymbolOfExpando(node, 
                    /*allowDeclaration*/
                    false);
                    if ((_c = jsSymbol == null ? void 0 : jsSymbol.exports) == null ? void 0 : _c.size) {
                        const jsAssignmentType = createAnonymousType(jsSymbol, jsSymbol.exports, emptyArray, emptyArray, emptyArray);
                        jsAssignmentType.objectFlags |= 4096 /* JSLiteral */;
                        return getIntersectionType([returnType, jsAssignmentType]);
                    }
                }
                return returnType;
            }
            function checkDeprecatedSignature(signature, node) {
                if (signature.declaration && signature.declaration.flags & 268435456 /* Deprecated */) {
                    const suggestionNode = getDeprecatedSuggestionNode(node);
                    const name = tryGetPropertyAccessOrIdentifierToString(getInvokedExpression(node));
                    addDeprecatedSuggestionWithSignature(suggestionNode, signature.declaration, name, signatureToString(signature));
                }
            }
            function getDeprecatedSuggestionNode(node) {
                node = skipParentheses(node);
                switch (node.kind) {
                    case 210 /* CallExpression */:
                    case 167 /* Decorator */:
                    case 211 /* NewExpression */:
                        return getDeprecatedSuggestionNode(node.expression);
                    case 212 /* TaggedTemplateExpression */:
                        return getDeprecatedSuggestionNode(node.tag);
                    case 283 /* JsxOpeningElement */:
                    case 282 /* JsxSelfClosingElement */:
                        return getDeprecatedSuggestionNode(node.tagName);
                    case 209 /* ElementAccessExpression */:
                        return node.argumentExpression;
                    case 208 /* PropertyAccessExpression */:
                        return node.name;
                    case 180 /* TypeReference */:
                        const typeReference = node;
                        return isQualifiedName(typeReference.typeName) ? typeReference.typeName.right : typeReference;
                    default:
                        return node;
                }
            }
            function isSymbolOrSymbolForCall(node) {
                if (!isCallExpression(node))
                    return false;
                let left = node.expression;
                if (isPropertyAccessExpression(left) && left.name.escapedText === "for") {
                    left = left.expression;
                }
                if (!isIdentifier(left) || left.escapedText !== "Symbol") {
                    return false;
                }
                const globalESSymbol = getGlobalESSymbolConstructorSymbol(
                /*reportErrors*/
                false);
                if (!globalESSymbol) {
                    return false;
                }
                return globalESSymbol === resolveName(left, "Symbol", 111551 /* Value */, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                false);
            }
            function checkImportCallExpression(node) {
                checkGrammarImportCallExpression(node);
                if (node.arguments.length === 0) {
                    return createPromiseReturnType(node, anyType);
                }
                const specifier = node.arguments[0];
                const specifierType = checkExpressionCached(specifier);
                const optionsType = node.arguments.length > 1 ? checkExpressionCached(node.arguments[1]) : void 0;
                for (let i = 2; i < node.arguments.length; ++i) {
                    checkExpressionCached(node.arguments[i]);
                }
                if (specifierType.flags & 32768 /* Undefined */ || specifierType.flags & 65536 /* Null */ || !isTypeAssignableTo(specifierType, stringType)) {
                    error(specifier, Diagnostics.Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0, typeToString(specifierType));
                }
                if (optionsType) {
                    const importCallOptionsType = getGlobalImportCallOptionsType(
                    /*reportErrors*/
                    true);
                    if (importCallOptionsType !== emptyObjectType) {
                        checkTypeAssignableTo(optionsType, getNullableType(importCallOptionsType, 32768 /* Undefined */), node.arguments[1]);
                    }
                }
                const moduleSymbol = resolveExternalModuleName(node, specifier);
                if (moduleSymbol) {
                    const esModuleSymbol = resolveESModuleSymbol(moduleSymbol, specifier, 
                    /*dontRecursivelyResolve*/
                    true, 
                    /*suppressUsageError*/
                    false);
                    if (esModuleSymbol) {
                        return createPromiseReturnType(node, getTypeWithSyntheticDefaultOnly(getTypeOfSymbol(esModuleSymbol), esModuleSymbol, moduleSymbol, specifier) || getTypeWithSyntheticDefaultImportType(getTypeOfSymbol(esModuleSymbol), esModuleSymbol, moduleSymbol, specifier));
                    }
                }
                return createPromiseReturnType(node, anyType);
            }
            function createDefaultPropertyWrapperForModule(symbol, originalSymbol, anonymousSymbol) {
                const memberTable = createSymbolTable();
                const newSymbol = createSymbol(2097152 /* Alias */, "default" /* Default */);
                newSymbol.parent = originalSymbol;
                newSymbol.links.nameType = getStringLiteralType("default");
                newSymbol.links.aliasTarget = resolveSymbol(symbol);
                memberTable.set("default" /* Default */, newSymbol);
                return createAnonymousType(anonymousSymbol, memberTable, emptyArray, emptyArray, emptyArray);
            }
            function getTypeWithSyntheticDefaultOnly(type, symbol, originalSymbol, moduleSpecifier) {
                const hasDefaultOnly = isOnlyImportedAsDefault(moduleSpecifier);
                if (hasDefaultOnly && type && !isErrorType(type)) {
                    const synthType = type;
                    if (!synthType.defaultOnlyType) {
                        const type2 = createDefaultPropertyWrapperForModule(symbol, originalSymbol);
                        synthType.defaultOnlyType = type2;
                    }
                    return synthType.defaultOnlyType;
                }
                return void 0;
            }
            function getTypeWithSyntheticDefaultImportType(type, symbol, originalSymbol, moduleSpecifier) {
                var _a2;
                if (allowSyntheticDefaultImports && type && !isErrorType(type)) {
                    const synthType = type;
                    if (!synthType.syntheticType) {
                        const file = (_a2 = originalSymbol.declarations) == null ? void 0 : _a2.find(isSourceFile);
                        const hasSyntheticDefault = canHaveSyntheticDefault(file, originalSymbol, 
                        /*dontResolveAlias*/
                        false, moduleSpecifier);
                        if (hasSyntheticDefault) {
                            const anonymousSymbol = createSymbol(2048 /* TypeLiteral */, "__type" /* Type */);
                            const defaultContainingObject = createDefaultPropertyWrapperForModule(symbol, originalSymbol, anonymousSymbol);
                            anonymousSymbol.links.type = defaultContainingObject;
                            synthType.syntheticType = isValidSpreadType(type) ? getSpreadType(type, defaultContainingObject, anonymousSymbol, 
                            /*objectFlags*/
                            0, 
                            /*readonly*/
                            false) : defaultContainingObject;
                        }
                        else {
                            synthType.syntheticType = type;
                        }
                    }
                    return synthType.syntheticType;
                }
                return type;
            }
            function isCommonJsRequire(node) {
                if (!isRequireCall(node, 
                /*checkArgumentIsStringLiteralLike*/
                true)) {
                    return false;
                }
                if (!isIdentifier(node.expression))
                    return Debug.fail();
                const resolvedRequire = resolveName(node.expression, node.expression.escapedText, 111551 /* Value */, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                true);
                if (resolvedRequire === requireSymbol) {
                    return true;
                }
                if (resolvedRequire.flags & 2097152 /* Alias */) {
                    return false;
                }
                const targetDeclarationKind = resolvedRequire.flags & 16 /* Function */ ? 259 /* FunctionDeclaration */ : resolvedRequire.flags & 3 /* Variable */ ? 257 /* VariableDeclaration */ : 0 /* Unknown */;
                if (targetDeclarationKind !== 0 /* Unknown */) {
                    const decl = getDeclarationOfKind(resolvedRequire, targetDeclarationKind);
                    return !!decl && !!(decl.flags & 16777216 /* Ambient */);
                }
                return false;
            }
            function checkTaggedTemplateExpression(node) {
                if (!checkGrammarTaggedTemplateChain(node))
                    checkGrammarTypeArguments(node, node.typeArguments);
                if (languageVersion < 2 /* ES2015 */) {
                    checkExternalEmitHelpers(node, 262144 /* MakeTemplateObject */);
                }
                const signature = getResolvedSignature(node);
                checkDeprecatedSignature(signature, node);
                return getReturnTypeOfSignature(signature);
            }
            function checkAssertion(node) {
                if (node.kind === 213 /* TypeAssertionExpression */) {
                    const file = getSourceFileOfNode(node);
                    if (file && fileExtensionIsOneOf(file.fileName, [".cts" /* Cts */, ".mts" /* Mts */])) {
                        grammarErrorOnNode(node, Diagnostics.This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead);
                    }
                }
                return checkAssertionWorker(node, node.type, node.expression);
            }
            function isValidConstAssertionArgument(node) {
                switch (node.kind) {
                    case 10 /* StringLiteral */:
                    case 14 /* NoSubstitutionTemplateLiteral */:
                    case 8 /* NumericLiteral */:
                    case 9 /* BigIntLiteral */:
                    case 110 /* TrueKeyword */:
                    case 95 /* FalseKeyword */:
                    case 206 /* ArrayLiteralExpression */:
                    case 207 /* ObjectLiteralExpression */:
                    case 225 /* TemplateExpression */:
                        return true;
                    case 214 /* ParenthesizedExpression */:
                        return isValidConstAssertionArgument(node.expression);
                    case 221 /* PrefixUnaryExpression */:
                        const op = node.operator;
                        const arg = node.operand;
                        return op === 40 /* MinusToken */ && (arg.kind === 8 /* NumericLiteral */ || arg.kind === 9 /* BigIntLiteral */) || op === 39 /* PlusToken */ && arg.kind === 8 /* NumericLiteral */;
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        const expr = skipParentheses(node.expression);
                        const symbol = isEntityNameExpression(expr) ? resolveEntityName(expr, 111551 /* Value */, 
                        /*ignoreErrors*/
                        true) : void 0;
                        return !!(symbol && symbol.flags & 384 /* Enum */);
                }
                return false;
            }
            function checkAssertionWorker(errNode, type, expression, checkMode) {
                let exprType = checkExpression(expression, checkMode);
                if (isConstTypeReference(type)) {
                    if (!isValidConstAssertionArgument(expression)) {
                        error(expression, Diagnostics.A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array_or_object_literals);
                    }
                    return getRegularTypeOfLiteralType(exprType);
                }
                checkSourceElement(type);
                exprType = getRegularTypeOfObjectLiteral(getBaseTypeOfLiteralType(exprType));
                const targetType = getTypeFromTypeNode(type);
                if (!isErrorType(targetType)) {
                    addLazyDiagnostic(() => {
                        const widenedType = getWidenedType(exprType);
                        if (!isTypeComparableTo(targetType, widenedType)) {
                            checkTypeComparableTo(exprType, targetType, errNode, Diagnostics.Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first);
                        }
                    });
                }
                return targetType;
            }
            function checkNonNullChain(node) {
                const leftType = checkExpression(node.expression);
                const nonOptionalType = getOptionalExpressionType(leftType, node.expression);
                return propagateOptionalTypeMarker(getNonNullableType(nonOptionalType), node, nonOptionalType !== leftType);
            }
            function checkNonNullAssertion(node) {
                return node.flags & 32 /* OptionalChain */ ? checkNonNullChain(node) : getNonNullableType(checkExpression(node.expression));
            }
            function checkExpressionWithTypeArguments(node) {
                checkGrammarExpressionWithTypeArguments(node);
                forEach(node.typeArguments, checkSourceElement);
                const exprType = node.kind === 230 /* ExpressionWithTypeArguments */ ? checkExpression(node.expression) : isThisIdentifier(node.exprName) ? checkThisExpression(node.exprName) : checkExpression(node.exprName);
                return getInstantiationExpressionType(exprType, node);
            }
            function getInstantiationExpressionType(exprType, node) {
                const typeArguments = node.typeArguments;
                if (exprType === silentNeverType || isErrorType(exprType) || !some(typeArguments)) {
                    return exprType;
                }
                let hasSomeApplicableSignature = false;
                let nonApplicableType;
                const result = getInstantiatedType(exprType);
                const errorType2 = hasSomeApplicableSignature ? nonApplicableType : exprType;
                if (errorType2) {
                    diagnostics.add(createDiagnosticForNodeArray(getSourceFileOfNode(node), typeArguments, Diagnostics.Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable, typeToString(errorType2)));
                }
                return result;
                function getInstantiatedType(type) {
                    let hasSignatures = false;
                    let hasApplicableSignature = false;
                    const result2 = getInstantiatedTypePart(type);
                    hasSomeApplicableSignature || (hasSomeApplicableSignature = hasApplicableSignature);
                    if (hasSignatures && !hasApplicableSignature) {
                        nonApplicableType != null ? nonApplicableType : nonApplicableType = type;
                    }
                    return result2;
                    function getInstantiatedTypePart(type2) {
                        if (type2.flags & 524288 /* Object */) {
                            const resolved = resolveStructuredTypeMembers(type2);
                            const callSignatures = getInstantiatedSignatures(resolved.callSignatures);
                            const constructSignatures = getInstantiatedSignatures(resolved.constructSignatures);
                            hasSignatures || (hasSignatures = resolved.callSignatures.length !== 0 || resolved.constructSignatures.length !== 0);
                            hasApplicableSignature || (hasApplicableSignature = callSignatures.length !== 0 || constructSignatures.length !== 0);
                            if (callSignatures !== resolved.callSignatures || constructSignatures !== resolved.constructSignatures) {
                                const result3 = createAnonymousType(void 0, resolved.members, callSignatures, constructSignatures, resolved.indexInfos);
                                result3.objectFlags |= 8388608 /* InstantiationExpressionType */;
                                result3.node = node;
                                return result3;
                            }
                        }
                        else if (type2.flags & 58982400 /* InstantiableNonPrimitive */) {
                            const constraint = getBaseConstraintOfType(type2);
                            if (constraint) {
                                const instantiated = getInstantiatedTypePart(constraint);
                                if (instantiated !== constraint) {
                                    return instantiated;
                                }
                            }
                        }
                        else if (type2.flags & 1048576 /* Union */) {
                            return mapType(type2, getInstantiatedType);
                        }
                        else if (type2.flags & 2097152 /* Intersection */) {
                            return getIntersectionType(sameMap(type2.types, getInstantiatedTypePart));
                        }
                        return type2;
                    }
                }
                function getInstantiatedSignatures(signatures) {
                    const applicableSignatures = filter(signatures, (sig) => !!sig.typeParameters && hasCorrectTypeArgumentArity(sig, typeArguments));
                    return sameMap(applicableSignatures, (sig) => {
                        const typeArgumentTypes = checkTypeArguments(sig, typeArguments, 
                        /*reportErrors*/
                        true);
                        return typeArgumentTypes ? getSignatureInstantiation(sig, typeArgumentTypes, isInJSFile(sig.declaration)) : sig;
                    });
                }
            }
            function checkSatisfiesExpression(node) {
                checkSourceElement(node.type);
                return checkSatisfiesExpressionWorker(node.expression, node.type);
            }
            function checkSatisfiesExpressionWorker(expression, target, checkMode) {
                const exprType = checkExpression(expression, checkMode);
                const targetType = getTypeFromTypeNode(target);
                if (isErrorType(targetType)) {
                    return targetType;
                }
                checkTypeAssignableToAndOptionallyElaborate(exprType, targetType, target, expression, Diagnostics.Type_0_does_not_satisfy_the_expected_type_1);
                return exprType;
            }
            function checkMetaProperty(node) {
                checkGrammarMetaProperty(node);
                if (node.keywordToken === 103 /* NewKeyword */) {
                    return checkNewTargetMetaProperty(node);
                }
                if (node.keywordToken === 100 /* ImportKeyword */) {
                    return checkImportMetaProperty(node);
                }
                return Debug.assertNever(node.keywordToken);
            }
            function checkMetaPropertyKeyword(node) {
                switch (node.keywordToken) {
                    case 100 /* ImportKeyword */:
                        return getGlobalImportMetaExpressionType();
                    case 103 /* NewKeyword */:
                        const type = checkNewTargetMetaProperty(node);
                        return isErrorType(type) ? errorType : createNewTargetExpressionType(type);
                    default:
                        Debug.assertNever(node.keywordToken);
                }
            }
            function checkNewTargetMetaProperty(node) {
                const container = getNewTargetContainer(node);
                if (!container) {
                    error(node, Diagnostics.Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constructor, "new.target");
                    return errorType;
                }
                else if (container.kind === 173 /* Constructor */) {
                    const symbol = getSymbolOfDeclaration(container.parent);
                    return getTypeOfSymbol(symbol);
                }
                else {
                    const symbol = getSymbolOfDeclaration(container);
                    return getTypeOfSymbol(symbol);
                }
            }
            function checkImportMetaProperty(node) {
                if (moduleKind === 100 /* Node16 */ || moduleKind === 199 /* NodeNext */) {
                    if (getSourceFileOfNode(node).impliedNodeFormat !== 99 /* ESNext */) {
                        error(node, Diagnostics.The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output);
                    }
                }
                else if (moduleKind < 6 /* ES2020 */ && moduleKind !== 4 /* System */) {
                    error(node, Diagnostics.The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system_node16_or_nodenext);
                }
                const file = getSourceFileOfNode(node);
                Debug.assert(!!(file.flags & 4194304 /* PossiblyContainsImportMeta */), "Containing file is missing import meta node flag.");
                return node.name.escapedText === "meta" ? getGlobalImportMetaType() : errorType;
            }
            function getTypeOfParameter(symbol) {
                const type = getTypeOfSymbol(symbol);
                if (strictNullChecks) {
                    const declaration = symbol.valueDeclaration;
                    if (declaration && hasInitializer(declaration)) {
                        return getOptionalType(type);
                    }
                }
                return type;
            }
            function getTupleElementLabel(d) {
                Debug.assert(isIdentifier(d.name));
                return d.name.escapedText;
            }
            function getParameterNameAtPosition(signature, pos, overrideRestType) {
                const paramCount = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                if (pos < paramCount) {
                    return signature.parameters[pos].escapedName;
                }
                const restParameter = signature.parameters[paramCount] || unknownSymbol;
                const restType = overrideRestType || getTypeOfSymbol(restParameter);
                if (isTupleType(restType)) {
                    const associatedNames = restType.target.labeledElementDeclarations;
                    const index = pos - paramCount;
                    return associatedNames && getTupleElementLabel(associatedNames[index]) || restParameter.escapedName + "_" + index;
                }
                return restParameter.escapedName;
            }
            function getParameterIdentifierNameAtPosition(signature, pos) {
                var _a2;
                if (((_a2 = signature.declaration) == null ? void 0 : _a2.kind) === 320 /* JSDocFunctionType */) {
                    return void 0;
                }
                const paramCount = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                if (pos < paramCount) {
                    const param = signature.parameters[pos];
                    return isParameterDeclarationWithIdentifierName(param) ? [param.escapedName, false] : void 0;
                }
                const restParameter = signature.parameters[paramCount] || unknownSymbol;
                if (!isParameterDeclarationWithIdentifierName(restParameter)) {
                    return void 0;
                }
                const restType = getTypeOfSymbol(restParameter);
                if (isTupleType(restType)) {
                    const associatedNames = restType.target.labeledElementDeclarations;
                    const index = pos - paramCount;
                    const associatedName = associatedNames == null ? void 0 : associatedNames[index];
                    const isRestTupleElement = !!(associatedName == null ? void 0 : associatedName.dotDotDotToken);
                    return associatedName ? [
                        getTupleElementLabel(associatedName),
                        isRestTupleElement
                    ] : void 0;
                }
                if (pos === paramCount) {
                    return [restParameter.escapedName, true];
                }
                return void 0;
            }
            function isParameterDeclarationWithIdentifierName(symbol) {
                return symbol.valueDeclaration && isParameter(symbol.valueDeclaration) && isIdentifier(symbol.valueDeclaration.name);
            }
            function isValidDeclarationForTupleLabel(d) {
                return d.kind === 199 /* NamedTupleMember */ || isParameter(d) && d.name && isIdentifier(d.name);
            }
            function getNameableDeclarationAtPosition(signature, pos) {
                const paramCount = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                if (pos < paramCount) {
                    const decl = signature.parameters[pos].valueDeclaration;
                    return decl && isValidDeclarationForTupleLabel(decl) ? decl : void 0;
                }
                const restParameter = signature.parameters[paramCount] || unknownSymbol;
                const restType = getTypeOfSymbol(restParameter);
                if (isTupleType(restType)) {
                    const associatedNames = restType.target.labeledElementDeclarations;
                    const index = pos - paramCount;
                    return associatedNames && associatedNames[index];
                }
                return restParameter.valueDeclaration && isValidDeclarationForTupleLabel(restParameter.valueDeclaration) ? restParameter.valueDeclaration : void 0;
            }
            function getTypeAtPosition(signature, pos) {
                return tryGetTypeAtPosition(signature, pos) || anyType;
            }
            function tryGetTypeAtPosition(signature, pos) {
                const paramCount = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                if (pos < paramCount) {
                    return getTypeOfParameter(signature.parameters[pos]);
                }
                if (signatureHasRestParameter(signature)) {
                    const restType = getTypeOfSymbol(signature.parameters[paramCount]);
                    const index = pos - paramCount;
                    if (!isTupleType(restType) || restType.target.hasRestElement || index < restType.target.fixedLength) {
                        return getIndexedAccessType(restType, getNumberLiteralType(index));
                    }
                }
                return void 0;
            }
            function getRestTypeAtPosition(source, pos) {
                const parameterCount = getParameterCount(source);
                const minArgumentCount = getMinArgumentCount(source);
                const restType = getEffectiveRestType(source);
                if (restType && pos >= parameterCount - 1) {
                    return pos === parameterCount - 1 ? restType : createArrayType(getIndexedAccessType(restType, numberType));
                }
                const types = [];
                const flags = [];
                const names = [];
                for (let i = pos; i < parameterCount; i++) {
                    if (!restType || i < parameterCount - 1) {
                        types.push(getTypeAtPosition(source, i));
                        flags.push(i < minArgumentCount ? 1 /* Required */ : 2 /* Optional */);
                    }
                    else {
                        types.push(restType);
                        flags.push(8 /* Variadic */);
                    }
                    const name = getNameableDeclarationAtPosition(source, i);
                    if (name) {
                        names.push(name);
                    }
                }
                return createTupleType(types, flags, 
                /*readonly*/
                false, length(names) === length(types) ? names : void 0);
            }
            function getParameterCount(signature) {
                const length2 = signature.parameters.length;
                if (signatureHasRestParameter(signature)) {
                    const restType = getTypeOfSymbol(signature.parameters[length2 - 1]);
                    if (isTupleType(restType)) {
                        return length2 + restType.target.fixedLength - (restType.target.hasRestElement ? 0 : 1);
                    }
                }
                return length2;
            }
            function getMinArgumentCount(signature, flags) {
                const strongArityForUntypedJS = flags & 1 /* StrongArityForUntypedJS */;
                const voidIsNonOptional = flags & 2 /* VoidIsNonOptional */;
                if (voidIsNonOptional || signature.resolvedMinArgumentCount === void 0) {
                    let minArgumentCount;
                    if (signatureHasRestParameter(signature)) {
                        const restType = getTypeOfSymbol(signature.parameters[signature.parameters.length - 1]);
                        if (isTupleType(restType)) {
                            const firstOptionalIndex = findIndex(restType.target.elementFlags, (f) => !(f & 1 /* Required */));
                            const requiredCount = firstOptionalIndex < 0 ? restType.target.fixedLength : firstOptionalIndex;
                            if (requiredCount > 0) {
                                minArgumentCount = signature.parameters.length - 1 + requiredCount;
                            }
                        }
                    }
                    if (minArgumentCount === void 0) {
                        if (!strongArityForUntypedJS && signature.flags & 32 /* IsUntypedSignatureInJSFile */) {
                            return 0;
                        }
                        minArgumentCount = signature.minArgumentCount;
                    }
                    if (voidIsNonOptional) {
                        return minArgumentCount;
                    }
                    for (let i = minArgumentCount - 1; i >= 0; i--) {
                        const type = getTypeAtPosition(signature, i);
                        if (filterType(type, acceptsVoid).flags & 131072 /* Never */) {
                            break;
                        }
                        minArgumentCount = i;
                    }
                    signature.resolvedMinArgumentCount = minArgumentCount;
                }
                return signature.resolvedMinArgumentCount;
            }
            function hasEffectiveRestParameter(signature) {
                if (signatureHasRestParameter(signature)) {
                    const restType = getTypeOfSymbol(signature.parameters[signature.parameters.length - 1]);
                    return !isTupleType(restType) || restType.target.hasRestElement;
                }
                return false;
            }
            function getEffectiveRestType(signature) {
                if (signatureHasRestParameter(signature)) {
                    const restType = getTypeOfSymbol(signature.parameters[signature.parameters.length - 1]);
                    if (!isTupleType(restType)) {
                        return restType;
                    }
                    if (restType.target.hasRestElement) {
                        return sliceTupleType(restType, restType.target.fixedLength);
                    }
                }
                return void 0;
            }
            function getNonArrayRestType(signature) {
                const restType = getEffectiveRestType(signature);
                return restType && !isArrayType(restType) && !isTypeAny(restType) && (getReducedType(restType).flags & 131072 /* Never */) === 0 ? restType : void 0;
            }
            function getTypeOfFirstParameterOfSignature(signature) {
                return getTypeOfFirstParameterOfSignatureWithFallback(signature, neverType);
            }
            function getTypeOfFirstParameterOfSignatureWithFallback(signature, fallbackType) {
                return signature.parameters.length > 0 ? getTypeAtPosition(signature, 0) : fallbackType;
            }
            function inferFromAnnotatedParameters(signature, context, inferenceContext) {
                const len = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                for (let i = 0; i < len; i++) {
                    const declaration = signature.parameters[i].valueDeclaration;
                    if (declaration.type) {
                        const typeNode = getEffectiveTypeAnnotationNode(declaration);
                        if (typeNode) {
                            inferTypes(inferenceContext.inferences, getTypeFromTypeNode(typeNode), getTypeAtPosition(context, i));
                        }
                    }
                }
            }
            function assignContextualParameterTypes(signature, context) {
                if (context.typeParameters) {
                    if (!signature.typeParameters) {
                        signature.typeParameters = context.typeParameters;
                    }
                    else {
                        return;
                    }
                }
                if (context.thisParameter) {
                    const parameter = signature.thisParameter;
                    if (!parameter || parameter.valueDeclaration && !parameter.valueDeclaration.type) {
                        if (!parameter) {
                            signature.thisParameter = createSymbolWithType(context.thisParameter, 
                            /*type*/
                            void 0);
                        }
                        assignParameterType(signature.thisParameter, getTypeOfSymbol(context.thisParameter));
                    }
                }
                const len = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                for (let i = 0; i < len; i++) {
                    const parameter = signature.parameters[i];
                    if (!getEffectiveTypeAnnotationNode(parameter.valueDeclaration)) {
                        const contextualParameterType = tryGetTypeAtPosition(context, i);
                        assignParameterType(parameter, contextualParameterType);
                    }
                }
                if (signatureHasRestParameter(signature)) {
                    const parameter = last(signature.parameters);
                    if (parameter.valueDeclaration ? !getEffectiveTypeAnnotationNode(parameter.valueDeclaration) : !!(getCheckFlags(parameter) & 65536 /* DeferredType */)) {
                        const contextualParameterType = getRestTypeAtPosition(context, len);
                        assignParameterType(parameter, contextualParameterType);
                    }
                }
            }
            function assignNonContextualParameterTypes(signature) {
                if (signature.thisParameter) {
                    assignParameterType(signature.thisParameter);
                }
                for (const parameter of signature.parameters) {
                    assignParameterType(parameter);
                }
            }
            function assignParameterType(parameter, type) {
                const links = getSymbolLinks(parameter);
                if (!links.type) {
                    const declaration = parameter.valueDeclaration;
                    links.type = type || (declaration ? getWidenedTypeForVariableLikeDeclaration(declaration, 
                    /*reportErrors*/
                    true) : getTypeOfSymbol(parameter));
                    if (declaration && declaration.name.kind !== 79 /* Identifier */) {
                        if (links.type === unknownType) {
                            links.type = getTypeFromBindingPattern(declaration.name);
                        }
                        assignBindingElementTypes(declaration.name, links.type);
                    }
                }
                else if (type) {
                    Debug.assertEqual(links.type, type, "Parameter symbol already has a cached type which differs from newly assigned type");
                }
            }
            function assignBindingElementTypes(pattern, parentType) {
                for (const element of pattern.elements) {
                    if (!isOmittedExpression(element)) {
                        const type = getBindingElementTypeFromParentType(element, parentType);
                        if (element.name.kind === 79 /* Identifier */) {
                            getSymbolLinks(getSymbolOfDeclaration(element)).type = type;
                        }
                        else {
                            assignBindingElementTypes(element.name, type);
                        }
                    }
                }
            }
            function createClassDecoratorContextType(classType) {
                return tryCreateTypeReference(getGlobalClassDecoratorContextType(
                /*reportErrors*/
                true), [classType]);
            }
            function createClassMethodDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassMethodDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassGetterDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassGetterDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassSetterDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassSetterDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassAccessorDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassAccessorDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassFieldDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassFieldDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function getClassMemberDecoratorContextOverrideType(nameType, isPrivate, isStatic2) {
                const key = `${isPrivate ? "p" : "P"}${isStatic2 ? "s" : "S"}${nameType.id}`;
                let overrideType = decoratorContextOverrideTypeCache.get(key);
                if (!overrideType) {
                    const members = createSymbolTable();
                    members.set("name", createProperty("name", nameType));
                    members.set("private", createProperty("private", isPrivate ? trueType : falseType));
                    members.set("static", createProperty("static", isStatic2 ? trueType : falseType));
                    overrideType = createAnonymousType(
                    /*symbol*/
                    void 0, members, emptyArray, emptyArray, emptyArray);
                    decoratorContextOverrideTypeCache.set(key, overrideType);
                }
                return overrideType;
            }
            function createClassMemberDecoratorContextTypeForNode(node, thisType, valueType) {
                const isStatic2 = hasStaticModifier(node);
                const isPrivate = isPrivateIdentifier(node.name);
                const nameType = isPrivate ? getStringLiteralType(idText(node.name)) : getLiteralTypeFromPropertyName(node.name);
                const contextType = isMethodDeclaration(node) ? createClassMethodDecoratorContextType(thisType, valueType) : isGetAccessorDeclaration(node) ? createClassGetterDecoratorContextType(thisType, valueType) : isSetAccessorDeclaration(node) ? createClassSetterDecoratorContextType(thisType, valueType) : isAutoAccessorPropertyDeclaration(node) ? createClassAccessorDecoratorContextType(thisType, valueType) : isPropertyDeclaration(node) ? createClassFieldDecoratorContextType(thisType, valueType) : Debug.failBadSyntaxKind(node);
                const overrideType = getClassMemberDecoratorContextOverrideType(nameType, isPrivate, isStatic2);
                return getIntersectionType([contextType, overrideType]);
            }
            function createClassAccessorDecoratorTargetType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassAccessorDecoratorTargetType(
                /*reportError*/
                true), [thisType, valueType]);
            }
            function createClassAccessorDecoratorResultType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassAccessorDecoratorResultType(
                /*reportError*/
                true), [thisType, valueType]);
            }
            function createClassFieldDecoratorInitializerMutatorType(thisType, valueType) {
                const thisParam = createParameter("this", thisType);
                const valueParam = createParameter("value", valueType);
                return createFunctionType(
                /*typeParameters*/
                void 0, thisParam, [valueParam], valueType, 
                /*typePredicate*/
                void 0, 1);
            }
            function createESDecoratorCallSignature(targetType, contextType, nonOptionalReturnType) {
                const targetParam = createParameter("target", targetType);
                const contextParam = createParameter("context", contextType);
                const returnType = getUnionType([nonOptionalReturnType, voidType]);
                return createCallSignature(
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, [targetParam, contextParam], returnType);
            }
            function getESDecoratorCallSignature(decorator) {
                const { parent: parent2 } = decorator;
                const links = getNodeLinks(parent2);
                if (!links.decoratorSignature) {
                    links.decoratorSignature = anySignature;
                    switch (parent2.kind) {
                        case 260 /* ClassDeclaration */:
                        case 228 /* ClassExpression */: {
                            const node = parent2;
                            const targetType = getTypeOfSymbol(getSymbolOfDeclaration(node));
                            const contextType = createClassDecoratorContextType(targetType);
                            links.decoratorSignature = createESDecoratorCallSignature(targetType, contextType, targetType);
                            break;
                        }
                        case 171 /* MethodDeclaration */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */: {
                            const node = parent2;
                            if (!isClassLike(node.parent))
                                break;
                            const valueType = isMethodDeclaration(node) ? getOrCreateTypeFromSignature(getSignatureFromDeclaration(node)) : getTypeOfNode(node);
                            const thisType = hasStaticModifier(node) ? getTypeOfSymbol(getSymbolOfDeclaration(node.parent)) : getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(node.parent));
                            const targetType = isGetAccessorDeclaration(node) ? createGetterFunctionType(valueType) : isSetAccessorDeclaration(node) ? createSetterFunctionType(valueType) : valueType;
                            const contextType = createClassMemberDecoratorContextTypeForNode(node, thisType, valueType);
                            const returnType = isGetAccessorDeclaration(node) ? createGetterFunctionType(valueType) : isSetAccessorDeclaration(node) ? createSetterFunctionType(valueType) : valueType;
                            links.decoratorSignature = createESDecoratorCallSignature(targetType, contextType, returnType);
                            break;
                        }
                        case 169 /* PropertyDeclaration */: {
                            const node = parent2;
                            if (!isClassLike(node.parent))
                                break;
                            const valueType = getTypeOfNode(node);
                            const thisType = hasStaticModifier(node) ? getTypeOfSymbol(getSymbolOfDeclaration(node.parent)) : getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(node.parent));
                            const targetType = hasAccessorModifier(node) ? createClassAccessorDecoratorTargetType(thisType, valueType) : undefinedType;
                            const contextType = createClassMemberDecoratorContextTypeForNode(node, thisType, valueType);
                            const returnType = hasAccessorModifier(node) ? createClassAccessorDecoratorResultType(thisType, valueType) : createClassFieldDecoratorInitializerMutatorType(thisType, valueType);
                            links.decoratorSignature = createESDecoratorCallSignature(targetType, contextType, returnType);
                            break;
                        }
                    }
                }
                return links.decoratorSignature === anySignature ? void 0 : links.decoratorSignature;
            }
            function getLegacyDecoratorCallSignature(decorator) {
                const { parent: parent2 } = decorator;
                const links = getNodeLinks(parent2);
                if (!links.decoratorSignature) {
                    links.decoratorSignature = anySignature;
                    switch (parent2.kind) {
                        case 260 /* ClassDeclaration */:
                        case 228 /* ClassExpression */: {
                            const node = parent2;
                            const targetType = getTypeOfSymbol(getSymbolOfDeclaration(node));
                            const targetParam = createParameter("target", targetType);
                            links.decoratorSignature = createCallSignature(
                            /*typeParameters*/
                            void 0, 
                            /*thisParameter*/
                            void 0, [targetParam], getUnionType([targetType, voidType]));
                            break;
                        }
                        case 166 /* Parameter */: {
                            const node = parent2;
                            if (!isConstructorDeclaration(node.parent) && !(isMethodDeclaration(node.parent) || isSetAccessorDeclaration(node.parent) && isClassLike(node.parent.parent))) {
                                break;
                            }
                            if (getThisParameter(node.parent) === node) {
                                break;
                            }
                            const index = getThisParameter(node.parent) ? node.parent.parameters.indexOf(node) - 1 : node.parent.parameters.indexOf(node);
                            Debug.assert(index >= 0);
                            const targetType = isConstructorDeclaration(node.parent) ? getTypeOfSymbol(getSymbolOfDeclaration(node.parent.parent)) : getParentTypeOfClassElement(node.parent);
                            const keyType = isConstructorDeclaration(node.parent) ? undefinedType : getClassElementPropertyKeyType(node.parent);
                            const indexType = getNumberLiteralType(index);
                            const targetParam = createParameter("target", targetType);
                            const keyParam = createParameter("propertyKey", keyType);
                            const indexParam = createParameter("parameterIndex", indexType);
                            links.decoratorSignature = createCallSignature(
                            /*typeParameters*/
                            void 0, 
                            /*thisParameter*/
                            void 0, [targetParam, keyParam, indexParam], voidType);
                            break;
                        }
                        case 171 /* MethodDeclaration */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                        case 169 /* PropertyDeclaration */: {
                            const node = parent2;
                            if (!isClassLike(node.parent))
                                break;
                            const targetType = getParentTypeOfClassElement(node);
                            const targetParam = createParameter("target", targetType);
                            const keyType = getClassElementPropertyKeyType(node);
                            const keyParam = createParameter("propertyKey", keyType);
                            const returnType = isPropertyDeclaration(node) ? voidType : createTypedPropertyDescriptorType(getTypeOfNode(node));
                            const hasPropDesc = languageVersion !== 0 /* ES3 */ && (!isPropertyDeclaration(parent2) || hasAccessorModifier(parent2));
                            if (hasPropDesc) {
                                const descriptorType = createTypedPropertyDescriptorType(getTypeOfNode(node));
                                const descriptorParam = createParameter("descriptor", descriptorType);
                                links.decoratorSignature = createCallSignature(
                                /*typeParameters*/
                                void 0, 
                                /*thisParameter*/
                                void 0, [targetParam, keyParam, descriptorParam], getUnionType([returnType, voidType]));
                            }
                            else {
                                links.decoratorSignature = createCallSignature(
                                /*typeParameters*/
                                void 0, 
                                /*thisParameter*/
                                void 0, [targetParam, keyParam], getUnionType([returnType, voidType]));
                            }
                            break;
                        }
                    }
                }
                return links.decoratorSignature === anySignature ? void 0 : links.decoratorSignature;
            }
            function getDecoratorCallSignature(decorator) {
                return legacyDecorators ? getLegacyDecoratorCallSignature(decorator) : getESDecoratorCallSignature(decorator);
            }
            function createPromiseType(promisedType) {
                const globalPromiseType = getGlobalPromiseType(
                /*reportErrors*/
                true);
                if (globalPromiseType !== emptyGenericType) {
                    promisedType = getAwaitedTypeNoAlias(unwrapAwaitedType(promisedType)) || unknownType;
                    return createTypeReference(globalPromiseType, [promisedType]);
                }
                return unknownType;
            }
            function createPromiseLikeType(promisedType) {
                const globalPromiseLikeType = getGlobalPromiseLikeType(
                /*reportErrors*/
                true);
                if (globalPromiseLikeType !== emptyGenericType) {
                    promisedType = getAwaitedTypeNoAlias(unwrapAwaitedType(promisedType)) || unknownType;
                    return createTypeReference(globalPromiseLikeType, [promisedType]);
                }
                return unknownType;
            }
            function createPromiseReturnType(func, promisedType) {
                const promiseType = createPromiseType(promisedType);
                if (promiseType === unknownType) {
                    error(func, isImportCall(func) ? Diagnostics.A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option : Diagnostics.An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option);
                    return errorType;
                }
                else if (!getGlobalPromiseConstructorSymbol(
                /*reportErrors*/
                true)) {
                    error(func, isImportCall(func) ? Diagnostics.A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option : Diagnostics.An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option);
                }
                return promiseType;
            }
            function createNewTargetExpressionType(targetType) {
                const symbol = createSymbol(0 /* None */, "NewTargetExpression");
                const targetPropertySymbol = createSymbol(4 /* Property */, "target", 8 /* Readonly */);
                targetPropertySymbol.parent = symbol;
                targetPropertySymbol.links.type = targetType;
                const members = createSymbolTable([targetPropertySymbol]);
                symbol.members = members;
                return createAnonymousType(symbol, members, emptyArray, emptyArray, emptyArray);
            }
            function getReturnTypeFromBody(func, checkMode) {
                if (!func.body) {
                    return errorType;
                }
                const functionFlags = getFunctionFlags(func);
                const isAsync = (functionFlags & 2 /* Async */) !== 0;
                const isGenerator = (functionFlags & 1 /* Generator */) !== 0;
                let returnType;
                let yieldType;
                let nextType;
                let fallbackReturnType = voidType;
                if (func.body.kind !== 238 /* Block */) {
                    returnType = checkExpressionCached(func.body, checkMode && checkMode & ~8 /* SkipGenericFunctions */);
                    if (isAsync) {
                        returnType = unwrapAwaitedType(checkAwaitedType(returnType, 
                        /*withAlias*/
                        false, 
                        /*errorNode*/
                        func, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member));
                    }
                }
                else if (isGenerator) {
                    const returnTypes = checkAndAggregateReturnExpressionTypes(func, checkMode);
                    if (!returnTypes) {
                        fallbackReturnType = neverType;
                    }
                    else if (returnTypes.length > 0) {
                        returnType = getUnionType(returnTypes, 2 /* Subtype */);
                    }
                    const { yieldTypes, nextTypes } = checkAndAggregateYieldOperandTypes(func, checkMode);
                    yieldType = some(yieldTypes) ? getUnionType(yieldTypes, 2 /* Subtype */) : void 0;
                    nextType = some(nextTypes) ? getIntersectionType(nextTypes) : void 0;
                }
                else {
                    const types = checkAndAggregateReturnExpressionTypes(func, checkMode);
                    if (!types) {
                        return functionFlags & 2 /* Async */ ? createPromiseReturnType(func, neverType) : neverType;
                    }
                    if (types.length === 0) {
                        return functionFlags & 2 /* Async */ ? createPromiseReturnType(func, voidType) : voidType;
                    }
                    returnType = getUnionType(types, 2 /* Subtype */);
                }
                if (returnType || yieldType || nextType) {
                    if (yieldType)
                        reportErrorsFromWidening(func, yieldType, 3 /* GeneratorYield */);
                    if (returnType)
                        reportErrorsFromWidening(func, returnType, 1 /* FunctionReturn */);
                    if (nextType)
                        reportErrorsFromWidening(func, nextType, 2 /* GeneratorNext */);
                    if (returnType && isUnitType(returnType) || yieldType && isUnitType(yieldType) || nextType && isUnitType(nextType)) {
                        const contextualSignature = getContextualSignatureForFunctionLikeDeclaration(func);
                        const contextualType = !contextualSignature ? void 0 : contextualSignature === getSignatureFromDeclaration(func) ? isGenerator ? void 0 : returnType : instantiateContextualType(getReturnTypeOfSignature(contextualSignature), func, 
                        /*contextFlags*/
                        void 0);
                        if (isGenerator) {
                            yieldType = getWidenedLiteralLikeTypeForContextualIterationTypeIfNeeded(yieldType, contextualType, 0 /* Yield */, isAsync);
                            returnType = getWidenedLiteralLikeTypeForContextualIterationTypeIfNeeded(returnType, contextualType, 1 /* Return */, isAsync);
                            nextType = getWidenedLiteralLikeTypeForContextualIterationTypeIfNeeded(nextType, contextualType, 2 /* Next */, isAsync);
                        }
                        else {
                            returnType = getWidenedLiteralLikeTypeForContextualReturnTypeIfNeeded(returnType, contextualType, isAsync);
                        }
                    }
                    if (yieldType)
                        yieldType = getWidenedType(yieldType);
                    if (returnType)
                        returnType = getWidenedType(returnType);
                    if (nextType)
                        nextType = getWidenedType(nextType);
                }
                if (isGenerator) {
                    return createGeneratorReturnType(yieldType || neverType, returnType || fallbackReturnType, nextType || getContextualIterationType(2 /* Next */, func) || unknownType, isAsync);
                }
                else {
                    return isAsync ? createPromiseType(returnType || fallbackReturnType) : returnType || fallbackReturnType;
                }
            }
            function createGeneratorReturnType(yieldType, returnType, nextType, isAsyncGenerator) {
                const resolver = isAsyncGenerator ? asyncIterationTypesResolver : syncIterationTypesResolver;
                const globalGeneratorType = resolver.getGlobalGeneratorType(
                /*reportErrors*/
                false);
                yieldType = resolver.resolveIterationType(yieldType, 
                /*errorNode*/
                void 0) || unknownType;
                returnType = resolver.resolveIterationType(returnType, 
                /*errorNode*/
                void 0) || unknownType;
                nextType = resolver.resolveIterationType(nextType, 
                /*errorNode*/
                void 0) || unknownType;
                if (globalGeneratorType === emptyGenericType) {
                    const globalType = resolver.getGlobalIterableIteratorType(
                    /*reportErrors*/
                    false);
                    const iterationTypes = globalType !== emptyGenericType ? getIterationTypesOfGlobalIterableType(globalType, resolver) : void 0;
                    const iterableIteratorReturnType = iterationTypes ? iterationTypes.returnType : anyType;
                    const iterableIteratorNextType = iterationTypes ? iterationTypes.nextType : undefinedType;
                    if (isTypeAssignableTo(returnType, iterableIteratorReturnType) && isTypeAssignableTo(iterableIteratorNextType, nextType)) {
                        if (globalType !== emptyGenericType) {
                            return createTypeFromGenericGlobalType(globalType, [yieldType]);
                        }
                        resolver.getGlobalIterableIteratorType(
                        /*reportErrors*/
                        true);
                        return emptyObjectType;
                    }
                    resolver.getGlobalGeneratorType(
                    /*reportErrors*/
                    true);
                    return emptyObjectType;
                }
                return createTypeFromGenericGlobalType(globalGeneratorType, [yieldType, returnType, nextType]);
            }
            function checkAndAggregateYieldOperandTypes(func, checkMode) {
                const yieldTypes = [];
                const nextTypes = [];
                const isAsync = (getFunctionFlags(func) & 2 /* Async */) !== 0;
                forEachYieldExpression(func.body, (yieldExpression) => {
                    const yieldExpressionType = yieldExpression.expression ? checkExpression(yieldExpression.expression, checkMode) : undefinedWideningType;
                    pushIfUnique(yieldTypes, getYieldedTypeOfYieldExpression(yieldExpression, yieldExpressionType, anyType, isAsync));
                    let nextType;
                    if (yieldExpression.asteriskToken) {
                        const iterationTypes = getIterationTypesOfIterable(yieldExpressionType, isAsync ? 19 /* AsyncYieldStar */ : 17 /* YieldStar */, yieldExpression.expression);
                        nextType = iterationTypes && iterationTypes.nextType;
                    }
                    else {
                        nextType = getContextualType2(yieldExpression, 
                        /*contextFlags*/
                        void 0);
                    }
                    if (nextType)
                        pushIfUnique(nextTypes, nextType);
                });
                return { yieldTypes, nextTypes };
            }
            function getYieldedTypeOfYieldExpression(node, expressionType, sentType, isAsync) {
                const errorNode = node.expression || node;
                const yieldedType = node.asteriskToken ? checkIteratedTypeOrElementType(isAsync ? 19 /* AsyncYieldStar */ : 17 /* YieldStar */, expressionType, sentType, errorNode) : expressionType;
                return !isAsync ? yieldedType : getAwaitedType(yieldedType, errorNode, node.asteriskToken ? Diagnostics.Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member : Diagnostics.Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);
            }
            function getNotEqualFactsFromTypeofSwitch(start, end, witnesses) {
                let facts = 0 /* None */;
                for (let i = 0; i < witnesses.length; i++) {
                    const witness = i < start || i >= end ? witnesses[i] : void 0;
                    facts |= witness !== void 0 ? typeofNEFacts.get(witness) || 32768 /* TypeofNEHostObject */ : 0;
                }
                return facts;
            }
            function isExhaustiveSwitchStatement(node) {
                const links = getNodeLinks(node);
                if (links.isExhaustive === void 0) {
                    links.isExhaustive = 0;
                    const exhaustive = computeExhaustiveSwitchStatement(node);
                    if (links.isExhaustive === 0) {
                        links.isExhaustive = exhaustive;
                    }
                }
                else if (links.isExhaustive === 0) {
                    links.isExhaustive = false;
                }
                return links.isExhaustive;
            }
            function computeExhaustiveSwitchStatement(node) {
                if (node.expression.kind === 218 /* TypeOfExpression */) {
                    const witnesses = getSwitchClauseTypeOfWitnesses(node);
                    if (!witnesses) {
                        return false;
                    }
                    const operandConstraint = getBaseConstraintOrType(checkExpressionCached(node.expression.expression));
                    const notEqualFacts = getNotEqualFactsFromTypeofSwitch(0, 0, witnesses);
                    if (operandConstraint.flags & 3 /* AnyOrUnknown */) {
                        return (556800 /* AllTypeofNE */ & notEqualFacts) === 556800 /* AllTypeofNE */;
                    }
                    return !someType(operandConstraint, (t) => (getTypeFacts(t) & notEqualFacts) === notEqualFacts);
                }
                const type = checkExpressionCached(node.expression);
                if (!isLiteralType(type)) {
                    return false;
                }
                const switchTypes = getSwitchClauseTypes(node);
                if (!switchTypes.length || some(switchTypes, isNeitherUnitTypeNorNever)) {
                    return false;
                }
                return eachTypeContainedIn(mapType(type, getRegularTypeOfLiteralType), switchTypes);
            }
            function functionHasImplicitReturn(func) {
                return func.endFlowNode && isReachableFlowNode(func.endFlowNode);
            }
            function checkAndAggregateReturnExpressionTypes(func, checkMode) {
                const functionFlags = getFunctionFlags(func);
                const aggregatedTypes = [];
                let hasReturnWithNoExpression = functionHasImplicitReturn(func);
                let hasReturnOfTypeNever = false;
                forEachReturnStatement(func.body, (returnStatement) => {
                    const expr = returnStatement.expression;
                    if (expr) {
                        let type = checkExpressionCached(expr, checkMode && checkMode & ~8 /* SkipGenericFunctions */);
                        if (functionFlags & 2 /* Async */) {
                            type = unwrapAwaitedType(checkAwaitedType(type, 
                            /*withAlias*/
                            false, func, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member));
                        }
                        if (type.flags & 131072 /* Never */) {
                            hasReturnOfTypeNever = true;
                        }
                        pushIfUnique(aggregatedTypes, type);
                    }
                    else {
                        hasReturnWithNoExpression = true;
                    }
                });
                if (aggregatedTypes.length === 0 && !hasReturnWithNoExpression && (hasReturnOfTypeNever || mayReturnNever(func))) {
                    return void 0;
                }
                if (strictNullChecks && aggregatedTypes.length && hasReturnWithNoExpression && !(isJSConstructor(func) && aggregatedTypes.some((t) => t.symbol === func.symbol))) {
                    pushIfUnique(aggregatedTypes, undefinedType);
                }
                return aggregatedTypes;
            }
            function mayReturnNever(func) {
                switch (func.kind) {
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                        return true;
                    case 171 /* MethodDeclaration */:
                        return func.parent.kind === 207 /* ObjectLiteralExpression */;
                    default:
                        return false;
                }
            }
            function checkAllCodePathsInNonVoidFunctionReturnOrThrow(func, returnType) {
                addLazyDiagnostic(checkAllCodePathsInNonVoidFunctionReturnOrThrowDiagnostics);
                return;
                function checkAllCodePathsInNonVoidFunctionReturnOrThrowDiagnostics() {
                    const functionFlags = getFunctionFlags(func);
                    const type = returnType && unwrapReturnType(returnType, functionFlags);
                    if (type && maybeTypeOfKind(type, 1 /* Any */ | 16384 /* Void */)) {
                        return;
                    }
                    if (func.kind === 170 /* MethodSignature */ || nodeIsMissing(func.body) || func.body.kind !== 238 /* Block */ || !functionHasImplicitReturn(func)) {
                        return;
                    }
                    const hasExplicitReturn = func.flags & 512 /* HasExplicitReturn */;
                    const errorNode = getEffectiveReturnTypeNode(func) || func;
                    if (type && type.flags & 131072 /* Never */) {
                        error(errorNode, Diagnostics.A_function_returning_never_cannot_have_a_reachable_end_point);
                    }
                    else if (type && !hasExplicitReturn) {
                        error(errorNode, Diagnostics.A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value);
                    }
                    else if (type && strictNullChecks && !isTypeAssignableTo(undefinedType, type)) {
                        error(errorNode, Diagnostics.Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined);
                    }
                    else if (compilerOptions.noImplicitReturns) {
                        if (!type) {
                            if (!hasExplicitReturn) {
                                return;
                            }
                            const inferredReturnType = getReturnTypeOfSignature(getSignatureFromDeclaration(func));
                            if (isUnwrappedReturnTypeVoidOrAny(func, inferredReturnType)) {
                                return;
                            }
                        }
                        error(errorNode, Diagnostics.Not_all_code_paths_return_a_value);
                    }
                }
            }
            function checkFunctionExpressionOrObjectLiteralMethod(node, checkMode) {
                Debug.assert(node.kind !== 171 /* MethodDeclaration */ || isObjectLiteralMethod(node));
                checkNodeDeferred(node);
                if (isFunctionExpression(node)) {
                    checkCollisionsForDeclarationName(node, node.name);
                }
                if (checkMode && checkMode & 4 /* SkipContextSensitive */ && isContextSensitive(node)) {
                    if (!getEffectiveReturnTypeNode(node) && !hasContextSensitiveParameters(node)) {
                        const contextualSignature = getContextualSignature(node);
                        if (contextualSignature && couldContainTypeVariables(getReturnTypeOfSignature(contextualSignature))) {
                            const links = getNodeLinks(node);
                            if (links.contextFreeType) {
                                return links.contextFreeType;
                            }
                            const returnType = getReturnTypeFromBody(node, checkMode);
                            const returnOnlySignature = createSignature(void 0, void 0, void 0, emptyArray, returnType, 
                            /*resolvedTypePredicate*/
                            void 0, 0, 0 /* None */);
                            const returnOnlyType = createAnonymousType(node.symbol, emptySymbols, [returnOnlySignature], emptyArray, emptyArray);
                            returnOnlyType.objectFlags |= 262144 /* NonInferrableType */;
                            return links.contextFreeType = returnOnlyType;
                        }
                    }
                    return anyFunctionType;
                }
                const hasGrammarError = checkGrammarFunctionLikeDeclaration(node);
                if (!hasGrammarError && node.kind === 215 /* FunctionExpression */) {
                    checkGrammarForGenerator(node);
                }
                contextuallyCheckFunctionExpressionOrObjectLiteralMethod(node, checkMode);
                return getTypeOfSymbol(getSymbolOfDeclaration(node));
            }
            function contextuallyCheckFunctionExpressionOrObjectLiteralMethod(node, checkMode) {
                const links = getNodeLinks(node);
                if (!(links.flags & 64 /* ContextChecked */)) {
                    const contextualSignature = getContextualSignature(node);
                    if (!(links.flags & 64 /* ContextChecked */)) {
                        links.flags |= 64 /* ContextChecked */;
                        const signature = firstOrUndefined(getSignaturesOfType(getTypeOfSymbol(getSymbolOfDeclaration(node)), 0 /* Call */));
                        if (!signature) {
                            return;
                        }
                        if (isContextSensitive(node)) {
                            if (contextualSignature) {
                                const inferenceContext = getInferenceContext(node);
                                let instantiatedContextualSignature;
                                if (checkMode && checkMode & 2 /* Inferential */) {
                                    inferFromAnnotatedParameters(signature, contextualSignature, inferenceContext);
                                    const restType = getEffectiveRestType(contextualSignature);
                                    if (restType && restType.flags & 262144 /* TypeParameter */) {
                                        instantiatedContextualSignature = instantiateSignature(contextualSignature, inferenceContext.nonFixingMapper);
                                    }
                                }
                                instantiatedContextualSignature || (instantiatedContextualSignature = inferenceContext ? instantiateSignature(contextualSignature, inferenceContext.mapper) : contextualSignature);
                                assignContextualParameterTypes(signature, instantiatedContextualSignature);
                            }
                            else {
                                assignNonContextualParameterTypes(signature);
                            }
                        }
                        if (contextualSignature && !getReturnTypeFromAnnotation(node) && !signature.resolvedReturnType) {
                            const returnType = getReturnTypeFromBody(node, checkMode);
                            if (!signature.resolvedReturnType) {
                                signature.resolvedReturnType = returnType;
                            }
                        }
                        checkSignatureDeclaration(node);
                    }
                }
            }
            function checkFunctionExpressionOrObjectLiteralMethodDeferred(node) {
                Debug.assert(node.kind !== 171 /* MethodDeclaration */ || isObjectLiteralMethod(node));
                const functionFlags = getFunctionFlags(node);
                const returnType = getReturnTypeFromAnnotation(node);
                checkAllCodePathsInNonVoidFunctionReturnOrThrow(node, returnType);
                if (node.body) {
                    if (!getEffectiveReturnTypeNode(node)) {
                        getReturnTypeOfSignature(getSignatureFromDeclaration(node));
                    }
                    if (node.body.kind === 238 /* Block */) {
                        checkSourceElement(node.body);
                    }
                    else {
                        const exprType = checkExpression(node.body);
                        const returnOrPromisedType = returnType && unwrapReturnType(returnType, functionFlags);
                        if (returnOrPromisedType) {
                            if ((functionFlags & 3 /* AsyncGenerator */) === 2 /* Async */) {
                                const awaitedType = checkAwaitedType(exprType, 
                                /*withAlias*/
                                false, node.body, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);
                                checkTypeAssignableToAndOptionallyElaborate(awaitedType, returnOrPromisedType, node.body, node.body);
                            }
                            else {
                                checkTypeAssignableToAndOptionallyElaborate(exprType, returnOrPromisedType, node.body, node.body);
                            }
                        }
                    }
                }
            }
            function checkArithmeticOperandType(operand, type, diagnostic, isAwaitValid = false) {
                if (!isTypeAssignableTo(type, numberOrBigIntType)) {
                    const awaitedType = isAwaitValid && getAwaitedTypeOfPromise(type);
                    errorAndMaybeSuggestAwait(operand, !!awaitedType && isTypeAssignableTo(awaitedType, numberOrBigIntType), diagnostic);
                    return false;
                }
                return true;
            }
            function isReadonlyAssignmentDeclaration(d) {
                if (!isCallExpression(d)) {
                    return false;
                }
                if (!isBindableObjectDefinePropertyCall(d)) {
                    return false;
                }
                const objectLitType = checkExpressionCached(d.arguments[2]);
                const valueType = getTypeOfPropertyOfType(objectLitType, "value");
                if (valueType) {
                    const writableProp = getPropertyOfType(objectLitType, "writable");
                    const writableType = writableProp && getTypeOfSymbol(writableProp);
                    if (!writableType || writableType === falseType || writableType === regularFalseType) {
                        return true;
                    }
                    if (writableProp && writableProp.valueDeclaration && isPropertyAssignment(writableProp.valueDeclaration)) {
                        const initializer = writableProp.valueDeclaration.initializer;
                        const rawOriginalType = checkExpression(initializer);
                        if (rawOriginalType === falseType || rawOriginalType === regularFalseType) {
                            return true;
                        }
                    }
                    return false;
                }
                const setProp = getPropertyOfType(objectLitType, "set");
                return !setProp;
            }
            function isReadonlySymbol(symbol) {
                return !!(getCheckFlags(symbol) & 8 /* Readonly */ || symbol.flags & 4 /* Property */ && getDeclarationModifierFlagsFromSymbol(symbol) & 64 /* Readonly */ || symbol.flags & 3 /* Variable */ && getDeclarationNodeFlagsFromSymbol(symbol) & 2 /* Const */ || symbol.flags & 98304 /* Accessor */ && !(symbol.flags & 65536 /* SetAccessor */) || symbol.flags & 8 /* EnumMember */ || some(symbol.declarations, isReadonlyAssignmentDeclaration));
            }
            function isAssignmentToReadonlyEntity(expr, symbol, assignmentKind) {
                var _a2, _b;
                if (assignmentKind === 0 /* None */) {
                    return false;
                }
                if (isReadonlySymbol(symbol)) {
                    if (symbol.flags & 4 /* Property */ && isAccessExpression(expr) && expr.expression.kind === 108 /* ThisKeyword */) {
                        const ctor = getContainingFunction(expr);
                        if (!(ctor && (ctor.kind === 173 /* Constructor */ || isJSConstructor(ctor)))) {
                            return true;
                        }
                        if (symbol.valueDeclaration) {
                            const isAssignmentDeclaration2 = isBinaryExpression(symbol.valueDeclaration);
                            const isLocalPropertyDeclaration = ctor.parent === symbol.valueDeclaration.parent;
                            const isLocalParameterProperty = ctor === symbol.valueDeclaration.parent;
                            const isLocalThisPropertyAssignment = isAssignmentDeclaration2 && ((_a2 = symbol.parent) == null ? void 0 : _a2.valueDeclaration) === ctor.parent;
                            const isLocalThisPropertyAssignmentConstructorFunction = isAssignmentDeclaration2 && ((_b = symbol.parent) == null ? void 0 : _b.valueDeclaration) === ctor;
                            const isWriteableSymbol = isLocalPropertyDeclaration || isLocalParameterProperty || isLocalThisPropertyAssignment || isLocalThisPropertyAssignmentConstructorFunction;
                            return !isWriteableSymbol;
                        }
                    }
                    return true;
                }
                if (isAccessExpression(expr)) {
                    const node = skipParentheses(expr.expression);
                    if (node.kind === 79 /* Identifier */) {
                        const symbol2 = getNodeLinks(node).resolvedSymbol;
                        if (symbol2.flags & 2097152 /* Alias */) {
                            const declaration = getDeclarationOfAliasSymbol(symbol2);
                            return !!declaration && declaration.kind === 271 /* NamespaceImport */;
                        }
                    }
                }
                return false;
            }
            function checkReferenceExpression(expr, invalidReferenceMessage, invalidOptionalChainMessage) {
                const node = skipOuterExpressions(expr, 6 /* Assertions */ | 1 /* Parentheses */);
                if (node.kind !== 79 /* Identifier */ && !isAccessExpression(node)) {
                    error(expr, invalidReferenceMessage);
                    return false;
                }
                if (node.flags & 32 /* OptionalChain */) {
                    error(expr, invalidOptionalChainMessage);
                    return false;
                }
                return true;
            }
            function checkDeleteExpression(node) {
                checkExpression(node.expression);
                const expr = skipParentheses(node.expression);
                if (!isAccessExpression(expr)) {
                    error(expr, Diagnostics.The_operand_of_a_delete_operator_must_be_a_property_reference);
                    return booleanType;
                }
                if (isPropertyAccessExpression(expr) && isPrivateIdentifier(expr.name)) {
                    error(expr, Diagnostics.The_operand_of_a_delete_operator_cannot_be_a_private_identifier);
                }
                const links = getNodeLinks(expr);
                const symbol = getExportSymbolOfValueSymbolIfExported(links.resolvedSymbol);
                if (symbol) {
                    if (isReadonlySymbol(symbol)) {
                        error(expr, Diagnostics.The_operand_of_a_delete_operator_cannot_be_a_read_only_property);
                    }
                    checkDeleteExpressionMustBeOptional(expr, symbol);
                }
                return booleanType;
            }
            function checkDeleteExpressionMustBeOptional(expr, symbol) {
                const type = getTypeOfSymbol(symbol);
                if (strictNullChecks && !(type.flags & (3 /* AnyOrUnknown */ | 131072 /* Never */)) && !(exactOptionalPropertyTypes ? symbol.flags & 16777216 /* Optional */ : getTypeFacts(type) & 16777216 /* IsUndefined */)) {
                    error(expr, Diagnostics.The_operand_of_a_delete_operator_must_be_optional);
                }
            }
            function checkTypeOfExpression(node) {
                checkExpression(node.expression);
                return typeofType;
            }
            function checkVoidExpression(node) {
                checkExpression(node.expression);
                return undefinedWideningType;
            }
            function checkAwaitExpressionGrammar(node) {
                const container = getContainingFunctionOrClassStaticBlock(node);
                if (container && isClassStaticBlockDeclaration(container)) {
                    error(node, Diagnostics.Await_expression_cannot_be_used_inside_a_class_static_block);
                }
                else if (!(node.flags & 32768 /* AwaitContext */)) {
                    if (isInTopLevelContext(node)) {
                        const sourceFile = getSourceFileOfNode(node);
                        if (!hasParseDiagnostics(sourceFile)) {
                            let span;
                            if (!isEffectiveExternalModule(sourceFile, compilerOptions)) {
                                span != null ? span : span = getSpanOfTokenAtPosition(sourceFile, node.pos);
                                const diagnostic = createFileDiagnostic(sourceFile, span.start, span.length, Diagnostics.await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module);
                                diagnostics.add(diagnostic);
                            }
                            switch (moduleKind) {
                                case 100 /* Node16 */:
                                case 199 /* NodeNext */:
                                    if (sourceFile.impliedNodeFormat === 1 /* CommonJS */) {
                                        span != null ? span : span = getSpanOfTokenAtPosition(sourceFile, node.pos);
                                        diagnostics.add(createFileDiagnostic(sourceFile, span.start, span.length, Diagnostics.The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level));
                                        break;
                                    }
                                case 7 /* ES2022 */:
                                case 99 /* ESNext */:
                                case 4 /* System */:
                                    if (languageVersion >= 4 /* ES2017 */) {
                                        break;
                                    }
                                default:
                                    span != null ? span : span = getSpanOfTokenAtPosition(sourceFile, node.pos);
                                    diagnostics.add(createFileDiagnostic(sourceFile, span.start, span.length, Diagnostics.Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_or_nodenext_and_the_target_option_is_set_to_es2017_or_higher));
                                    break;
                            }
                        }
                    }
                    else {
                        const sourceFile = getSourceFileOfNode(node);
                        if (!hasParseDiagnostics(sourceFile)) {
                            const span = getSpanOfTokenAtPosition(sourceFile, node.pos);
                            const diagnostic = createFileDiagnostic(sourceFile, span.start, span.length, Diagnostics.await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules);
                            if (container && container.kind !== 173 /* Constructor */ && (getFunctionFlags(container) & 2 /* Async */) === 0) {
                                const relatedInfo = createDiagnosticForNode(container, Diagnostics.Did_you_mean_to_mark_this_function_as_async);
                                addRelatedInfo(diagnostic, relatedInfo);
                            }
                            diagnostics.add(diagnostic);
                        }
                    }
                }
                if (isInParameterInitializerBeforeContainingFunction(node)) {
                    error(node, Diagnostics.await_expressions_cannot_be_used_in_a_parameter_initializer);
                }
            }
            function checkAwaitExpression(node) {
                addLazyDiagnostic(() => checkAwaitExpressionGrammar(node));
                const operandType = checkExpression(node.expression);
                const awaitedType = checkAwaitedType(operandType, 
                /*withAlias*/
                true, node, Diagnostics.Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);
                if (awaitedType === operandType && !isErrorType(awaitedType) && !(operandType.flags & 3 /* AnyOrUnknown */)) {
                    addErrorOrSuggestion(
                    /*isError*/
                    false, createDiagnosticForNode(node, Diagnostics.await_has_no_effect_on_the_type_of_this_expression));
                }
                return awaitedType;
            }
            function checkPrefixUnaryExpression(node) {
                const operandType = checkExpression(node.operand);
                if (operandType === silentNeverType) {
                    return silentNeverType;
                }
                switch (node.operand.kind) {
                    case 8 /* NumericLiteral */:
                        switch (node.operator) {
                            case 40 /* MinusToken */:
                                return getFreshTypeOfLiteralType(getNumberLiteralType(-node.operand.text));
                            case 39 /* PlusToken */:
                                return getFreshTypeOfLiteralType(getNumberLiteralType(+node.operand.text));
                        }
                        break;
                    case 9 /* BigIntLiteral */:
                        if (node.operator === 40 /* MinusToken */) {
                            return getFreshTypeOfLiteralType(getBigIntLiteralType({
                                negative: true,
                                base10Value: parsePseudoBigInt(node.operand.text)
                            }));
                        }
                }
                switch (node.operator) {
                    case 39 /* PlusToken */:
                    case 40 /* MinusToken */:
                    case 54 /* TildeToken */:
                        checkNonNullType(operandType, node.operand);
                        if (maybeTypeOfKindConsideringBaseConstraint(operandType, 12288 /* ESSymbolLike */)) {
                            error(node.operand, Diagnostics.The_0_operator_cannot_be_applied_to_type_symbol, tokenToString(node.operator));
                        }
                        if (node.operator === 39 /* PlusToken */) {
                            if (maybeTypeOfKindConsideringBaseConstraint(operandType, 2112 /* BigIntLike */)) {
                                error(node.operand, Diagnostics.Operator_0_cannot_be_applied_to_type_1, tokenToString(node.operator), typeToString(getBaseTypeOfLiteralType(operandType)));
                            }
                            return numberType;
                        }
                        return getUnaryResultType(operandType);
                    case 53 /* ExclamationToken */:
                        checkTruthinessExpression(node.operand);
                        const facts = getTypeFacts(operandType) & (4194304 /* Truthy */ | 8388608 /* Falsy */);
                        return facts === 4194304 /* Truthy */ ? falseType : facts === 8388608 /* Falsy */ ? trueType : booleanType;
                    case 45 /* PlusPlusToken */:
                    case 46 /* MinusMinusToken */:
                        const ok = checkArithmeticOperandType(node.operand, checkNonNullType(operandType, node.operand), Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type);
                        if (ok) {
                            checkReferenceExpression(node.operand, Diagnostics.The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access, Diagnostics.The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access);
                        }
                        return getUnaryResultType(operandType);
                }
                return errorType;
            }
            function checkPostfixUnaryExpression(node) {
                const operandType = checkExpression(node.operand);
                if (operandType === silentNeverType) {
                    return silentNeverType;
                }
                const ok = checkArithmeticOperandType(node.operand, checkNonNullType(operandType, node.operand), Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type);
                if (ok) {
                    checkReferenceExpression(node.operand, Diagnostics.The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access, Diagnostics.The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access);
                }
                return getUnaryResultType(operandType);
            }
            function getUnaryResultType(operandType) {
                if (maybeTypeOfKind(operandType, 2112 /* BigIntLike */)) {
                    return isTypeAssignableToKind(operandType, 3 /* AnyOrUnknown */) || maybeTypeOfKind(operandType, 296 /* NumberLike */) ? numberOrBigIntType : bigintType;
                }
                return numberType;
            }
            function maybeTypeOfKindConsideringBaseConstraint(type, kind) {
                if (maybeTypeOfKind(type, kind)) {
                    return true;
                }
                const baseConstraint = getBaseConstraintOrType(type);
                return !!baseConstraint && maybeTypeOfKind(baseConstraint, kind);
            }
            function maybeTypeOfKind(type, kind) {
                if (type.flags & kind) {
                    return true;
                }
                if (type.flags & 3145728 /* UnionOrIntersection */) {
                    const types = type.types;
                    for (const t of types) {
                        if (maybeTypeOfKind(t, kind)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function isTypeAssignableToKind(source, kind, strict) {
                if (source.flags & kind) {
                    return true;
                }
                if (strict && source.flags & (3 /* AnyOrUnknown */ | 16384 /* Void */ | 32768 /* Undefined */ | 65536 /* Null */)) {
                    return false;
                }
                return !!(kind & 296 /* NumberLike */) && isTypeAssignableTo(source, numberType) || !!(kind & 2112 /* BigIntLike */) && isTypeAssignableTo(source, bigintType) || !!(kind & 402653316 /* StringLike */) && isTypeAssignableTo(source, stringType) || !!(kind & 528 /* BooleanLike */) && isTypeAssignableTo(source, booleanType) || !!(kind & 16384 /* Void */) && isTypeAssignableTo(source, voidType) || !!(kind & 131072 /* Never */) && isTypeAssignableTo(source, neverType) || !!(kind & 65536 /* Null */) && isTypeAssignableTo(source, nullType) || !!(kind & 32768 /* Undefined */) && isTypeAssignableTo(source, undefinedType) || !!(kind & 4096 /* ESSymbol */) && isTypeAssignableTo(source, esSymbolType) || !!(kind & 67108864 /* NonPrimitive */) && isTypeAssignableTo(source, nonPrimitiveType);
            }
            function allTypesAssignableToKind(source, kind, strict) {
                return source.flags & 1048576 /* Union */ ? every(source.types, (subType) => allTypesAssignableToKind(subType, kind, strict)) : isTypeAssignableToKind(source, kind, strict);
            }
            function isConstEnumObjectType(type) {
                return !!(getObjectFlags(type) & 16 /* Anonymous */) && !!type.symbol && isConstEnumSymbol(type.symbol);
            }
            function isConstEnumSymbol(symbol) {
                return (symbol.flags & 128 /* ConstEnum */) !== 0;
            }
            function checkInstanceOfExpression(left, right, leftType, rightType) {
                if (leftType === silentNeverType || rightType === silentNeverType) {
                    return silentNeverType;
                }
                if (!isTypeAny(leftType) && allTypesAssignableToKind(leftType, 134348796 /* Primitive */)) {
                    error(left, Diagnostics.The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter);
                }
                if (!(isTypeAny(rightType) || typeHasCallOrConstructSignatures(rightType) || isTypeSubtypeOf(rightType, globalFunctionType))) {
                    error(right, Diagnostics.The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_Function_interface_type);
                }
                return booleanType;
            }
            function hasEmptyObjectIntersection(type) {
                return someType(type, (t) => t === unknownEmptyObjectType || !!(t.flags & 2097152 /* Intersection */) && isEmptyAnonymousObjectType(getBaseConstraintOrType(t)));
            }
            function checkInExpression(left, right, leftType, rightType) {
                if (leftType === silentNeverType || rightType === silentNeverType) {
                    return silentNeverType;
                }
                if (isPrivateIdentifier(left)) {
                    if (languageVersion < 99 /* ESNext */) {
                        checkExternalEmitHelpers(left, 2097152 /* ClassPrivateFieldIn */);
                    }
                    if (!getNodeLinks(left).resolvedSymbol && getContainingClass(left)) {
                        const isUncheckedJS = isUncheckedJSSuggestion(left, rightType.symbol, 
                        /*excludeClasses*/
                        true);
                        reportNonexistentProperty(left, rightType, isUncheckedJS);
                    }
                }
                else {
                    checkTypeAssignableTo(checkNonNullType(leftType, left), stringNumberSymbolType, left);
                }
                if (checkTypeAssignableTo(checkNonNullType(rightType, right), nonPrimitiveType, right)) {
                    if (hasEmptyObjectIntersection(rightType)) {
                        error(right, Diagnostics.Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operator, typeToString(rightType));
                    }
                }
                return booleanType;
            }
            function checkObjectLiteralAssignment(node, sourceType, rightIsThis) {
                const properties = node.properties;
                if (strictNullChecks && properties.length === 0) {
                    return checkNonNullType(sourceType, node);
                }
                for (let i = 0; i < properties.length; i++) {
                    checkObjectLiteralDestructuringPropertyAssignment(node, sourceType, i, properties, rightIsThis);
                }
                return sourceType;
            }
            function checkObjectLiteralDestructuringPropertyAssignment(node, objectLiteralType, propertyIndex, allProperties, rightIsThis = false) {
                const properties = node.properties;
                const property = properties[propertyIndex];
                if (property.kind === 299 /* PropertyAssignment */ || property.kind === 300 /* ShorthandPropertyAssignment */) {
                    const name = property.name;
                    const exprType = getLiteralTypeFromPropertyName(name);
                    if (isTypeUsableAsPropertyName(exprType)) {
                        const text = getPropertyNameFromType(exprType);
                        const prop = getPropertyOfType(objectLiteralType, text);
                        if (prop) {
                            markPropertyAsReferenced(prop, property, rightIsThis);
                            checkPropertyAccessibility(property, 
                            /*isSuper*/
                            false, 
                            /*writing*/
                            true, objectLiteralType, prop);
                        }
                    }
                    const elementType = getIndexedAccessType(objectLiteralType, exprType, 32 /* ExpressionPosition */, name);
                    const type = getFlowTypeOfDestructuring(property, elementType);
                    return checkDestructuringAssignment(property.kind === 300 /* ShorthandPropertyAssignment */ ? property : property.initializer, type);
                }
                else if (property.kind === 301 /* SpreadAssignment */) {
                    if (propertyIndex < properties.length - 1) {
                        error(property, Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern);
                    }
                    else {
                        if (languageVersion < 99 /* ESNext */) {
                            checkExternalEmitHelpers(property, 4 /* Rest */);
                        }
                        const nonRestNames = [];
                        if (allProperties) {
                            for (const otherProperty of allProperties) {
                                if (!isSpreadAssignment(otherProperty)) {
                                    nonRestNames.push(otherProperty.name);
                                }
                            }
                        }
                        const type = getRestType(objectLiteralType, nonRestNames, objectLiteralType.symbol);
                        checkGrammarForDisallowedTrailingComma(allProperties, Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma);
                        return checkDestructuringAssignment(property.expression, type);
                    }
                }
                else {
                    error(property, Diagnostics.Property_assignment_expected);
                }
            }
            function checkArrayLiteralAssignment(node, sourceType, checkMode) {
                const elements = node.elements;
                if (languageVersion < 2 /* ES2015 */ && compilerOptions.downlevelIteration) {
                    checkExternalEmitHelpers(node, 512 /* Read */);
                }
                const possiblyOutOfBoundsType = checkIteratedTypeOrElementType(65 /* Destructuring */ | 128 /* PossiblyOutOfBounds */, sourceType, undefinedType, node) || errorType;
                let inBoundsType = compilerOptions.noUncheckedIndexedAccess ? void 0 : possiblyOutOfBoundsType;
                for (let i = 0; i < elements.length; i++) {
                    let type = possiblyOutOfBoundsType;
                    if (node.elements[i].kind === 227 /* SpreadElement */) {
                        type = inBoundsType = inBoundsType != null ? inBoundsType : checkIteratedTypeOrElementType(65 /* Destructuring */, sourceType, undefinedType, node) || errorType;
                    }
                    checkArrayLiteralDestructuringElementAssignment(node, sourceType, i, type, checkMode);
                }
                return sourceType;
            }
            function checkArrayLiteralDestructuringElementAssignment(node, sourceType, elementIndex, elementType, checkMode) {
                const elements = node.elements;
                const element = elements[elementIndex];
                if (element.kind !== 229 /* OmittedExpression */) {
                    if (element.kind !== 227 /* SpreadElement */) {
                        const indexType = getNumberLiteralType(elementIndex);
                        if (isArrayLikeType(sourceType)) {
                            const accessFlags = 32 /* ExpressionPosition */ | (hasDefaultValue(element) ? 16 /* NoTupleBoundsCheck */ : 0);
                            const elementType2 = getIndexedAccessTypeOrUndefined(sourceType, indexType, accessFlags, createSyntheticExpression(element, indexType)) || errorType;
                            const assignedType = hasDefaultValue(element) ? getTypeWithFacts(elementType2, 524288 /* NEUndefined */) : elementType2;
                            const type = getFlowTypeOfDestructuring(element, assignedType);
                            return checkDestructuringAssignment(element, type, checkMode);
                        }
                        return checkDestructuringAssignment(element, elementType, checkMode);
                    }
                    if (elementIndex < elements.length - 1) {
                        error(element, Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern);
                    }
                    else {
                        const restExpression = element.expression;
                        if (restExpression.kind === 223 /* BinaryExpression */ && restExpression.operatorToken.kind === 63 /* EqualsToken */) {
                            error(restExpression.operatorToken, Diagnostics.A_rest_element_cannot_have_an_initializer);
                        }
                        else {
                            checkGrammarForDisallowedTrailingComma(node.elements, Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma);
                            const type = everyType(sourceType, isTupleType) ? mapType(sourceType, (t) => sliceTupleType(t, elementIndex)) : createArrayType(elementType);
                            return checkDestructuringAssignment(restExpression, type, checkMode);
                        }
                    }
                }
                return void 0;
            }
            function checkDestructuringAssignment(exprOrAssignment, sourceType, checkMode, rightIsThis) {
                let target;
                if (exprOrAssignment.kind === 300 /* ShorthandPropertyAssignment */) {
                    const prop = exprOrAssignment;
                    if (prop.objectAssignmentInitializer) {
                        if (strictNullChecks && !(getTypeFacts(checkExpression(prop.objectAssignmentInitializer)) & 16777216 /* IsUndefined */)) {
                            sourceType = getTypeWithFacts(sourceType, 524288 /* NEUndefined */);
                        }
                        checkBinaryLikeExpression(prop.name, prop.equalsToken, prop.objectAssignmentInitializer, checkMode);
                    }
                    target = exprOrAssignment.name;
                }
                else {
                    target = exprOrAssignment;
                }
                if (target.kind === 223 /* BinaryExpression */ && target.operatorToken.kind === 63 /* EqualsToken */) {
                    checkBinaryExpression(target, checkMode);
                    target = target.left;
                    if (strictNullChecks) {
                        sourceType = getTypeWithFacts(sourceType, 524288 /* NEUndefined */);
                    }
                }
                if (target.kind === 207 /* ObjectLiteralExpression */) {
                    return checkObjectLiteralAssignment(target, sourceType, rightIsThis);
                }
                if (target.kind === 206 /* ArrayLiteralExpression */) {
                    return checkArrayLiteralAssignment(target, sourceType, checkMode);
                }
                return checkReferenceAssignment(target, sourceType, checkMode);
            }
            function checkReferenceAssignment(target, sourceType, checkMode) {
                const targetType = checkExpression(target, checkMode);
                const error2 = target.parent.kind === 301 /* SpreadAssignment */ ? Diagnostics.The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access : Diagnostics.The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access;
                const optionalError = target.parent.kind === 301 /* SpreadAssignment */ ? Diagnostics.The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access : Diagnostics.The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access;
                if (checkReferenceExpression(target, error2, optionalError)) {
                    checkTypeAssignableToAndOptionallyElaborate(sourceType, targetType, target, target);
                }
                if (isPrivateIdentifierPropertyAccessExpression(target)) {
                    checkExternalEmitHelpers(target.parent, 1048576 /* ClassPrivateFieldSet */);
                }
                return sourceType;
            }
            function isSideEffectFree(node) {
                node = skipParentheses(node);
                switch (node.kind) {
                    case 79 /* Identifier */:
                    case 10 /* StringLiteral */:
                    case 13 /* RegularExpressionLiteral */:
                    case 212 /* TaggedTemplateExpression */:
                    case 225 /* TemplateExpression */:
                    case 14 /* NoSubstitutionTemplateLiteral */:
                    case 8 /* NumericLiteral */:
                    case 9 /* BigIntLiteral */:
                    case 110 /* TrueKeyword */:
                    case 95 /* FalseKeyword */:
                    case 104 /* NullKeyword */:
                    case 155 /* UndefinedKeyword */:
                    case 215 /* FunctionExpression */:
                    case 228 /* ClassExpression */:
                    case 216 /* ArrowFunction */:
                    case 206 /* ArrayLiteralExpression */:
                    case 207 /* ObjectLiteralExpression */:
                    case 218 /* TypeOfExpression */:
                    case 232 /* NonNullExpression */:
                    case 282 /* JsxSelfClosingElement */:
                    case 281 /* JsxElement */:
                        return true;
                    case 224 /* ConditionalExpression */:
                        return isSideEffectFree(node.whenTrue) && isSideEffectFree(node.whenFalse);
                    case 223 /* BinaryExpression */:
                        if (isAssignmentOperator(node.operatorToken.kind)) {
                            return false;
                        }
                        return isSideEffectFree(node.left) && isSideEffectFree(node.right);
                    case 221 /* PrefixUnaryExpression */:
                    case 222 /* PostfixUnaryExpression */:
                        switch (node.operator) {
                            case 53 /* ExclamationToken */:
                            case 39 /* PlusToken */:
                            case 40 /* MinusToken */:
                            case 54 /* TildeToken */:
                                return true;
                        }
                        return false;
                    case 219 /* VoidExpression */:
                    case 213 /* TypeAssertionExpression */:
                    case 231 /* AsExpression */:
                    default:
                        return false;
                }
            }
            function isTypeEqualityComparableTo(source, target) {
                return (target.flags & 98304 /* Nullable */) !== 0 || isTypeComparableTo(source, target);
            }
            function createCheckBinaryExpression() {
                const trampoline = createBinaryExpressionTrampoline(onEnter, onLeft, onOperator, onRight, onExit, foldState);
                return (node, checkMode) => {
                    const result = trampoline(node, checkMode);
                    Debug.assertIsDefined(result);
                    return result;
                };
                function onEnter(node, state, checkMode) {
                    if (state) {
                        state.stackIndex++;
                        state.skip = false;
                        setLeftType(state, 
                        /*type*/
                        void 0);
                        setLastResult(state, 
                        /*type*/
                        void 0);
                    }
                    else {
                        state = {
                            checkMode,
                            skip: false,
                            stackIndex: 0,
                            typeStack: [void 0, void 0]
                        };
                    }
                    if (isInJSFile(node) && getAssignedExpandoInitializer(node)) {
                        state.skip = true;
                        setLastResult(state, checkExpression(node.right, checkMode));
                        return state;
                    }
                    checkGrammarNullishCoalesceWithLogicalExpression(node);
                    const operator = node.operatorToken.kind;
                    if (operator === 63 /* EqualsToken */ && (node.left.kind === 207 /* ObjectLiteralExpression */ || node.left.kind === 206 /* ArrayLiteralExpression */)) {
                        state.skip = true;
                        setLastResult(state, checkDestructuringAssignment(node.left, checkExpression(node.right, checkMode), checkMode, node.right.kind === 108 /* ThisKeyword */));
                        return state;
                    }
                    return state;
                }
                function onLeft(left, state, _node) {
                    if (!state.skip) {
                        return maybeCheckExpression(state, left);
                    }
                }
                function onOperator(operatorToken, state, node) {
                    if (!state.skip) {
                        const leftType = getLastResult(state);
                        Debug.assertIsDefined(leftType);
                        setLeftType(state, leftType);
                        setLastResult(state, 
                        /*type*/
                        void 0);
                        const operator = operatorToken.kind;
                        if (isLogicalOrCoalescingBinaryOperator(operator)) {
                            let parent2 = node.parent;
                            while (parent2.kind === 214 /* ParenthesizedExpression */ || isLogicalOrCoalescingBinaryExpression(parent2)) {
                                parent2 = parent2.parent;
                            }
                            if (operator === 55 /* AmpersandAmpersandToken */ || isIfStatement(parent2)) {
                                checkTestingKnownTruthyCallableOrAwaitableType(node.left, leftType, isIfStatement(parent2) ? parent2.thenStatement : void 0);
                            }
                            checkTruthinessOfType(leftType, node.left);
                        }
                    }
                }
                function onRight(right, state, _node) {
                    if (!state.skip) {
                        return maybeCheckExpression(state, right);
                    }
                }
                function onExit(node, state) {
                    let result;
                    if (state.skip) {
                        result = getLastResult(state);
                    }
                    else {
                        const leftType = getLeftType(state);
                        Debug.assertIsDefined(leftType);
                        const rightType = getLastResult(state);
                        Debug.assertIsDefined(rightType);
                        result = checkBinaryLikeExpressionWorker(node.left, node.operatorToken, node.right, leftType, rightType, node);
                    }
                    state.skip = false;
                    setLeftType(state, 
                    /*type*/
                    void 0);
                    setLastResult(state, 
                    /*type*/
                    void 0);
                    state.stackIndex--;
                    return result;
                }
                function foldState(state, result, _side) {
                    setLastResult(state, result);
                    return state;
                }
                function maybeCheckExpression(state, node) {
                    if (isBinaryExpression(node)) {
                        return node;
                    }
                    setLastResult(state, checkExpression(node, state.checkMode));
                }
                function getLeftType(state) {
                    return state.typeStack[state.stackIndex];
                }
                function setLeftType(state, type) {
                    state.typeStack[state.stackIndex] = type;
                }
                function getLastResult(state) {
                    return state.typeStack[state.stackIndex + 1];
                }
                function setLastResult(state, type) {
                    state.typeStack[state.stackIndex + 1] = type;
                }
            }
            function checkGrammarNullishCoalesceWithLogicalExpression(node) {
                const { left, operatorToken, right } = node;
                if (operatorToken.kind === 60 /* QuestionQuestionToken */) {
                    if (isBinaryExpression(left) && (left.operatorToken.kind === 56 /* BarBarToken */ || left.operatorToken.kind === 55 /* AmpersandAmpersandToken */)) {
                        grammarErrorOnNode(left, Diagnostics._0_and_1_operations_cannot_be_mixed_without_parentheses, tokenToString(left.operatorToken.kind), tokenToString(operatorToken.kind));
                    }
                    if (isBinaryExpression(right) && (right.operatorToken.kind === 56 /* BarBarToken */ || right.operatorToken.kind === 55 /* AmpersandAmpersandToken */)) {
                        grammarErrorOnNode(right, Diagnostics._0_and_1_operations_cannot_be_mixed_without_parentheses, tokenToString(right.operatorToken.kind), tokenToString(operatorToken.kind));
                    }
                }
            }
            function checkBinaryLikeExpression(left, operatorToken, right, checkMode, errorNode) {
                const operator = operatorToken.kind;
                if (operator === 63 /* EqualsToken */ && (left.kind === 207 /* ObjectLiteralExpression */ || left.kind === 206 /* ArrayLiteralExpression */)) {
                    return checkDestructuringAssignment(left, checkExpression(right, checkMode), checkMode, right.kind === 108 /* ThisKeyword */);
                }
                let leftType;
                if (isLogicalOrCoalescingBinaryOperator(operator)) {
                    leftType = checkTruthinessExpression(left, checkMode);
                }
                else {
                    leftType = checkExpression(left, checkMode);
                }
                const rightType = checkExpression(right, checkMode);
                return checkBinaryLikeExpressionWorker(left, operatorToken, right, leftType, rightType, errorNode);
            }
            function checkBinaryLikeExpressionWorker(left, operatorToken, right, leftType, rightType, errorNode) {
                const operator = operatorToken.kind;
                switch (operator) {
                    case 41 /* AsteriskToken */:
                    case 42 /* AsteriskAsteriskToken */:
                    case 66 /* AsteriskEqualsToken */:
                    case 67 /* AsteriskAsteriskEqualsToken */:
                    case 43 /* SlashToken */:
                    case 68 /* SlashEqualsToken */:
                    case 44 /* PercentToken */:
                    case 69 /* PercentEqualsToken */:
                    case 40 /* MinusToken */:
                    case 65 /* MinusEqualsToken */:
                    case 47 /* LessThanLessThanToken */:
                    case 70 /* LessThanLessThanEqualsToken */:
                    case 48 /* GreaterThanGreaterThanToken */:
                    case 71 /* GreaterThanGreaterThanEqualsToken */:
                    case 49 /* GreaterThanGreaterThanGreaterThanToken */:
                    case 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                    case 51 /* BarToken */:
                    case 74 /* BarEqualsToken */:
                    case 52 /* CaretToken */:
                    case 78 /* CaretEqualsToken */:
                    case 50 /* AmpersandToken */:
                    case 73 /* AmpersandEqualsToken */:
                        if (leftType === silentNeverType || rightType === silentNeverType) {
                            return silentNeverType;
                        }
                        leftType = checkNonNullType(leftType, left);
                        rightType = checkNonNullType(rightType, right);
                        let suggestedOperator;
                        if (leftType.flags & 528 /* BooleanLike */ && rightType.flags & 528 /* BooleanLike */ && (suggestedOperator = getSuggestedBooleanOperator(operatorToken.kind)) !== void 0) {
                            error(errorNode || operatorToken, Diagnostics.The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead, tokenToString(operatorToken.kind), tokenToString(suggestedOperator));
                            return numberType;
                        }
                        else {
                            const leftOk = checkArithmeticOperandType(left, leftType, Diagnostics.The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type, 
                            /*isAwaitValid*/
                            true);
                            const rightOk = checkArithmeticOperandType(right, rightType, Diagnostics.The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type, 
                            /*isAwaitValid*/
                            true);
                            let resultType2;
                            if (isTypeAssignableToKind(leftType, 3 /* AnyOrUnknown */) && isTypeAssignableToKind(rightType, 3 /* AnyOrUnknown */) || // Or, if neither could be bigint, implicit coercion results in a number result
                                !(maybeTypeOfKind(leftType, 2112 /* BigIntLike */) || maybeTypeOfKind(rightType, 2112 /* BigIntLike */))) {
                                resultType2 = numberType;
                            }
                            else if (bothAreBigIntLike(leftType, rightType)) {
                                switch (operator) {
                                    case 49 /* GreaterThanGreaterThanGreaterThanToken */:
                                    case 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                                        reportOperatorError();
                                        break;
                                    case 42 /* AsteriskAsteriskToken */:
                                    case 67 /* AsteriskAsteriskEqualsToken */:
                                        if (languageVersion < 3 /* ES2016 */) {
                                            error(errorNode, Diagnostics.Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_later);
                                        }
                                }
                                resultType2 = bigintType;
                            }
                            else {
                                reportOperatorError(bothAreBigIntLike);
                                resultType2 = errorType;
                            }
                            if (leftOk && rightOk) {
                                checkAssignmentOperator(resultType2);
                            }
                            return resultType2;
                        }
                    case 39 /* PlusToken */:
                    case 64 /* PlusEqualsToken */:
                        if (leftType === silentNeverType || rightType === silentNeverType) {
                            return silentNeverType;
                        }
                        if (!isTypeAssignableToKind(leftType, 402653316 /* StringLike */) && !isTypeAssignableToKind(rightType, 402653316 /* StringLike */)) {
                            leftType = checkNonNullType(leftType, left);
                            rightType = checkNonNullType(rightType, right);
                        }
                        let resultType;
                        if (isTypeAssignableToKind(leftType, 296 /* NumberLike */, 
                        /*strict*/
                        true) && isTypeAssignableToKind(rightType, 296 /* NumberLike */, 
                        /*strict*/
                        true)) {
                            resultType = numberType;
                        }
                        else if (isTypeAssignableToKind(leftType, 2112 /* BigIntLike */, 
                        /*strict*/
                        true) && isTypeAssignableToKind(rightType, 2112 /* BigIntLike */, 
                        /*strict*/
                        true)) {
                            resultType = bigintType;
                        }
                        else if (isTypeAssignableToKind(leftType, 402653316 /* StringLike */, 
                        /*strict*/
                        true) || isTypeAssignableToKind(rightType, 402653316 /* StringLike */, 
                        /*strict*/
                        true)) {
                            resultType = stringType;
                        }
                        else if (isTypeAny(leftType) || isTypeAny(rightType)) {
                            resultType = isErrorType(leftType) || isErrorType(rightType) ? errorType : anyType;
                        }
                        if (resultType && !checkForDisallowedESSymbolOperand(operator)) {
                            return resultType;
                        }
                        if (!resultType) {
                            const closeEnoughKind = 296 /* NumberLike */ | 2112 /* BigIntLike */ | 402653316 /* StringLike */ | 3 /* AnyOrUnknown */;
                            reportOperatorError((left2, right2) => isTypeAssignableToKind(left2, closeEnoughKind) && isTypeAssignableToKind(right2, closeEnoughKind));
                            return anyType;
                        }
                        if (operator === 64 /* PlusEqualsToken */) {
                            checkAssignmentOperator(resultType);
                        }
                        return resultType;
                    case 29 /* LessThanToken */:
                    case 31 /* GreaterThanToken */:
                    case 32 /* LessThanEqualsToken */:
                    case 33 /* GreaterThanEqualsToken */:
                        if (checkForDisallowedESSymbolOperand(operator)) {
                            leftType = getBaseTypeOfLiteralTypeForComparison(checkNonNullType(leftType, left));
                            rightType = getBaseTypeOfLiteralTypeForComparison(checkNonNullType(rightType, right));
                            reportOperatorErrorUnless((left2, right2) => {
                                if (isTypeAny(left2) || isTypeAny(right2)) {
                                    return true;
                                }
                                const leftAssignableToNumber = isTypeAssignableTo(left2, numberOrBigIntType);
                                const rightAssignableToNumber = isTypeAssignableTo(right2, numberOrBigIntType);
                                return leftAssignableToNumber && rightAssignableToNumber || !leftAssignableToNumber && !rightAssignableToNumber && areTypesComparable(left2, right2);
                            });
                        }
                        return booleanType;
                    case 34 /* EqualsEqualsToken */:
                    case 35 /* ExclamationEqualsToken */:
                    case 36 /* EqualsEqualsEqualsToken */:
                    case 37 /* ExclamationEqualsEqualsToken */:
                        if (isLiteralExpressionOfObject(left) || isLiteralExpressionOfObject(right)) {
                            const eqType = operator === 34 /* EqualsEqualsToken */ || operator === 36 /* EqualsEqualsEqualsToken */;
                            error(errorNode, Diagnostics.This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value, eqType ? "false" : "true");
                        }
                        checkNaNEquality(errorNode, operator, left, right);
                        reportOperatorErrorUnless((left2, right2) => isTypeEqualityComparableTo(left2, right2) || isTypeEqualityComparableTo(right2, left2));
                        return booleanType;
                    case 102 /* InstanceOfKeyword */:
                        return checkInstanceOfExpression(left, right, leftType, rightType);
                    case 101 /* InKeyword */:
                        return checkInExpression(left, right, leftType, rightType);
                    case 55 /* AmpersandAmpersandToken */:
                    case 76 /* AmpersandAmpersandEqualsToken */: {
                        const resultType2 = getTypeFacts(leftType) & 4194304 /* Truthy */ ? getUnionType([extractDefinitelyFalsyTypes(strictNullChecks ? leftType : getBaseTypeOfLiteralType(rightType)), rightType]) : leftType;
                        if (operator === 76 /* AmpersandAmpersandEqualsToken */) {
                            checkAssignmentOperator(rightType);
                        }
                        return resultType2;
                    }
                    case 56 /* BarBarToken */:
                    case 75 /* BarBarEqualsToken */: {
                        const resultType2 = getTypeFacts(leftType) & 8388608 /* Falsy */ ? getUnionType([getNonNullableType(removeDefinitelyFalsyTypes(leftType)), rightType], 2 /* Subtype */) : leftType;
                        if (operator === 75 /* BarBarEqualsToken */) {
                            checkAssignmentOperator(rightType);
                        }
                        return resultType2;
                    }
                    case 60 /* QuestionQuestionToken */:
                    case 77 /* QuestionQuestionEqualsToken */: {
                        const resultType2 = getTypeFacts(leftType) & 262144 /* EQUndefinedOrNull */ ? getUnionType([getNonNullableType(leftType), rightType], 2 /* Subtype */) : leftType;
                        if (operator === 77 /* QuestionQuestionEqualsToken */) {
                            checkAssignmentOperator(rightType);
                        }
                        return resultType2;
                    }
                    case 63 /* EqualsToken */:
                        const declKind = isBinaryExpression(left.parent) ? getAssignmentDeclarationKind(left.parent) : 0 /* None */;
                        checkAssignmentDeclaration(declKind, rightType);
                        if (isAssignmentDeclaration2(declKind)) {
                            if (!(rightType.flags & 524288 /* Object */) || declKind !== 2 /* ModuleExports */ && declKind !== 6 /* Prototype */ && !isEmptyObjectType(rightType) && !isFunctionObjectType(rightType) && !(getObjectFlags(rightType) & 1 /* Class */)) {
                                checkAssignmentOperator(rightType);
                            }
                            return leftType;
                        }
                        else {
                            checkAssignmentOperator(rightType);
                            return rightType;
                        }
                    case 27 /* CommaToken */:
                        if (!compilerOptions.allowUnreachableCode && isSideEffectFree(left) && !isIndirectCall(left.parent)) {
                            const sf = getSourceFileOfNode(left);
                            const sourceText = sf.text;
                            const start = skipTrivia(sourceText, left.pos);
                            const isInDiag2657 = sf.parseDiagnostics.some((diag2) => {
                                if (diag2.code !== Diagnostics.JSX_expressions_must_have_one_parent_element.code)
                                    return false;
                                return textSpanContainsPosition(diag2, start);
                            });
                            if (!isInDiag2657)
                                error(left, Diagnostics.Left_side_of_comma_operator_is_unused_and_has_no_side_effects);
                        }
                        return rightType;
                    default:
                        return Debug.fail();
                }
                function bothAreBigIntLike(left2, right2) {
                    return isTypeAssignableToKind(left2, 2112 /* BigIntLike */) && isTypeAssignableToKind(right2, 2112 /* BigIntLike */);
                }
                function checkAssignmentDeclaration(kind, rightType2) {
                    if (kind === 2 /* ModuleExports */) {
                        for (const prop of getPropertiesOfObjectType(rightType2)) {
                            const propType = getTypeOfSymbol(prop);
                            if (propType.symbol && propType.symbol.flags & 32 /* Class */) {
                                const name = prop.escapedName;
                                const symbol = resolveName(prop.valueDeclaration, name, 788968 /* Type */, void 0, name, 
                                /*isUse*/
                                false);
                                if ((symbol == null ? void 0 : symbol.declarations) && symbol.declarations.some(isJSDocTypedefTag)) {
                                    addDuplicateDeclarationErrorsForSymbols(symbol, Diagnostics.Duplicate_identifier_0, unescapeLeadingUnderscores(name), prop);
                                    addDuplicateDeclarationErrorsForSymbols(prop, Diagnostics.Duplicate_identifier_0, unescapeLeadingUnderscores(name), symbol);
                                }
                            }
                        }
                    }
                }
                function isIndirectCall(node) {
                    return node.parent.kind === 214 /* ParenthesizedExpression */ && isNumericLiteral(node.left) && node.left.text === "0" && (isCallExpression(node.parent.parent) && node.parent.parent.expression === node.parent || node.parent.parent.kind === 212 /* TaggedTemplateExpression */) && // special-case for "eval" because it's the only non-access case where an indirect call actually affects behavior.
                        (isAccessExpression(node.right) || isIdentifier(node.right) && node.right.escapedText === "eval");
                }
                function checkForDisallowedESSymbolOperand(operator2) {
                    const offendingSymbolOperand = maybeTypeOfKindConsideringBaseConstraint(leftType, 12288 /* ESSymbolLike */) ? left : maybeTypeOfKindConsideringBaseConstraint(rightType, 12288 /* ESSymbolLike */) ? right : void 0;
                    if (offendingSymbolOperand) {
                        error(offendingSymbolOperand, Diagnostics.The_0_operator_cannot_be_applied_to_type_symbol, tokenToString(operator2));
                        return false;
                    }
                    return true;
                }
                function getSuggestedBooleanOperator(operator2) {
                    switch (operator2) {
                        case 51 /* BarToken */:
                        case 74 /* BarEqualsToken */:
                            return 56 /* BarBarToken */;
                        case 52 /* CaretToken */:
                        case 78 /* CaretEqualsToken */:
                            return 37 /* ExclamationEqualsEqualsToken */;
                        case 50 /* AmpersandToken */:
                        case 73 /* AmpersandEqualsToken */:
                            return 55 /* AmpersandAmpersandToken */;
                        default:
                            return void 0;
                    }
                }
                function checkAssignmentOperator(valueType) {
                    if (isAssignmentOperator(operator)) {
                        addLazyDiagnostic(checkAssignmentOperatorWorker);
                    }
                    function checkAssignmentOperatorWorker() {
                        if (checkReferenceExpression(left, Diagnostics.The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access, Diagnostics.The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access)) {
                            let headMessage;
                            if (exactOptionalPropertyTypes && isPropertyAccessExpression(left) && maybeTypeOfKind(valueType, 32768 /* Undefined */)) {
                                const target = getTypeOfPropertyOfType(getTypeOfExpression(left.expression), left.name.escapedText);
                                if (isExactOptionalPropertyMismatch(valueType, target)) {
                                    headMessage = Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target;
                                }
                            }
                            checkTypeAssignableToAndOptionallyElaborate(valueType, leftType, left, right, headMessage);
                        }
                    }
                }
                function isAssignmentDeclaration2(kind) {
                    var _a2;
                    switch (kind) {
                        case 2 /* ModuleExports */:
                            return true;
                        case 1 /* ExportsProperty */:
                        case 5 /* Property */:
                        case 6 /* Prototype */:
                        case 3 /* PrototypeProperty */:
                        case 4 /* ThisProperty */:
                            const symbol = getSymbolOfNode(left);
                            const init = getAssignedExpandoInitializer(right);
                            return !!init && isObjectLiteralExpression(init) && !!((_a2 = symbol == null ? void 0 : symbol.exports) == null ? void 0 : _a2.size);
                        default:
                            return false;
                    }
                }
                function reportOperatorErrorUnless(typesAreCompatible) {
                    if (!typesAreCompatible(leftType, rightType)) {
                        reportOperatorError(typesAreCompatible);
                        return true;
                    }
                    return false;
                }
                function reportOperatorError(isRelated) {
                    let wouldWorkWithAwait = false;
                    const errNode = errorNode || operatorToken;
                    if (isRelated) {
                        const awaitedLeftType = getAwaitedTypeNoAlias(leftType);
                        const awaitedRightType = getAwaitedTypeNoAlias(rightType);
                        wouldWorkWithAwait = !(awaitedLeftType === leftType && awaitedRightType === rightType) && !!(awaitedLeftType && awaitedRightType) && isRelated(awaitedLeftType, awaitedRightType);
                    }
                    let effectiveLeft = leftType;
                    let effectiveRight = rightType;
                    if (!wouldWorkWithAwait && isRelated) {
                        [effectiveLeft, effectiveRight] = getBaseTypesIfUnrelated(leftType, rightType, isRelated);
                    }
                    const [leftStr, rightStr] = getTypeNamesForErrorDisplay(effectiveLeft, effectiveRight);
                    if (!tryGiveBetterPrimaryError(errNode, wouldWorkWithAwait, leftStr, rightStr)) {
                        errorAndMaybeSuggestAwait(errNode, wouldWorkWithAwait, Diagnostics.Operator_0_cannot_be_applied_to_types_1_and_2, tokenToString(operatorToken.kind), leftStr, rightStr);
                    }
                }
                function tryGiveBetterPrimaryError(errNode, maybeMissingAwait, leftStr, rightStr) {
                    switch (operatorToken.kind) {
                        case 36 /* EqualsEqualsEqualsToken */:
                        case 34 /* EqualsEqualsToken */:
                        case 37 /* ExclamationEqualsEqualsToken */:
                        case 35 /* ExclamationEqualsToken */:
                            return errorAndMaybeSuggestAwait(errNode, maybeMissingAwait, Diagnostics.This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap, leftStr, rightStr);
                        default:
                            return void 0;
                    }
                }
                function checkNaNEquality(errorNode2, operator2, left2, right2) {
                    const isLeftNaN = isGlobalNaN(skipParentheses(left2));
                    const isRightNaN = isGlobalNaN(skipParentheses(right2));
                    if (isLeftNaN || isRightNaN) {
                        const err = error(errorNode2, Diagnostics.This_condition_will_always_return_0, tokenToString(operator2 === 36 /* EqualsEqualsEqualsToken */ || operator2 === 34 /* EqualsEqualsToken */ ? 95 /* FalseKeyword */ : 110 /* TrueKeyword */));
                        if (isLeftNaN && isRightNaN)
                            return;
                        const operatorString = operator2 === 37 /* ExclamationEqualsEqualsToken */ || operator2 === 35 /* ExclamationEqualsToken */ ? tokenToString(53 /* ExclamationToken */) : "";
                        const location = isLeftNaN ? right2 : left2;
                        const expression = skipParentheses(location);
                        addRelatedInfo(err, createDiagnosticForNode(location, Diagnostics.Did_you_mean_0, `${operatorString}Number.isNaN(${isEntityNameExpression(expression) ? entityNameToString(expression) : "..."})`));
                    }
                }
                function isGlobalNaN(expr) {
                    if (isIdentifier(expr) && expr.escapedText === "NaN") {
                        const globalNaNSymbol = getGlobalNaNSymbol();
                        return !!globalNaNSymbol && globalNaNSymbol === getResolvedSymbol(expr);
                    }
                    return false;
                }
            }
            function getBaseTypesIfUnrelated(leftType, rightType, isRelated) {
                let effectiveLeft = leftType;
                let effectiveRight = rightType;
                const leftBase = getBaseTypeOfLiteralType(leftType);
                const rightBase = getBaseTypeOfLiteralType(rightType);
                if (!isRelated(leftBase, rightBase)) {
                    effectiveLeft = leftBase;
                    effectiveRight = rightBase;
                }
                return [effectiveLeft, effectiveRight];
            }
            function checkYieldExpression(node) {
                addLazyDiagnostic(checkYieldExpressionGrammar);
                const func = getContainingFunction(node);
                if (!func)
                    return anyType;
                const functionFlags = getFunctionFlags(func);
                if (!(functionFlags & 1 /* Generator */)) {
                    return anyType;
                }
                const isAsync = (functionFlags & 2 /* Async */) !== 0;
                if (node.asteriskToken) {
                    if (isAsync && languageVersion < 99 /* ESNext */) {
                        checkExternalEmitHelpers(node, 26624 /* AsyncDelegatorIncludes */);
                    }
                    if (!isAsync && languageVersion < 2 /* ES2015 */ && compilerOptions.downlevelIteration) {
                        checkExternalEmitHelpers(node, 256 /* Values */);
                    }
                }
                const returnType = getReturnTypeFromAnnotation(func);
                const iterationTypes = returnType && getIterationTypesOfGeneratorFunctionReturnType(returnType, isAsync);
                const signatureYieldType = iterationTypes && iterationTypes.yieldType || anyType;
                const signatureNextType = iterationTypes && iterationTypes.nextType || anyType;
                const resolvedSignatureNextType = isAsync ? getAwaitedType(signatureNextType) || anyType : signatureNextType;
                const yieldExpressionType = node.expression ? checkExpression(node.expression) : undefinedWideningType;
                const yieldedType = getYieldedTypeOfYieldExpression(node, yieldExpressionType, resolvedSignatureNextType, isAsync);
                if (returnType && yieldedType) {
                    checkTypeAssignableToAndOptionallyElaborate(yieldedType, signatureYieldType, node.expression || node, node.expression);
                }
                if (node.asteriskToken) {
                    const use = isAsync ? 19 /* AsyncYieldStar */ : 17 /* YieldStar */;
                    return getIterationTypeOfIterable(use, 1 /* Return */, yieldExpressionType, node.expression) || anyType;
                }
                else if (returnType) {
                    return getIterationTypeOfGeneratorFunctionReturnType(2 /* Next */, returnType, isAsync) || anyType;
                }
                let type = getContextualIterationType(2 /* Next */, func);
                if (!type) {
                    type = anyType;
                    addLazyDiagnostic(() => {
                        if (noImplicitAny && !expressionResultIsUnused(node)) {
                            const contextualType = getContextualType2(node, 
                            /*contextFlags*/
                            void 0);
                            if (!contextualType || isTypeAny(contextualType)) {
                                error(node, Diagnostics.yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_type_annotation);
                            }
                        }
                    });
                }
                return type;
                function checkYieldExpressionGrammar() {
                    if (!(node.flags & 8192 /* YieldContext */)) {
                        grammarErrorOnFirstToken(node, Diagnostics.A_yield_expression_is_only_allowed_in_a_generator_body);
                    }
                    if (isInParameterInitializerBeforeContainingFunction(node)) {
                        error(node, Diagnostics.yield_expressions_cannot_be_used_in_a_parameter_initializer);
                    }
                }
            }
            function checkConditionalExpression(node, checkMode) {
                const type = checkTruthinessExpression(node.condition);
                checkTestingKnownTruthyCallableOrAwaitableType(node.condition, type, node.whenTrue);
                const type1 = checkExpression(node.whenTrue, checkMode);
                const type2 = checkExpression(node.whenFalse, checkMode);
                return getUnionType([type1, type2], 2 /* Subtype */);
            }
            function isTemplateLiteralContext(node) {
                const parent2 = node.parent;
                return isParenthesizedExpression(parent2) && isTemplateLiteralContext(parent2) || isElementAccessExpression(parent2) && parent2.argumentExpression === node;
            }
            function checkTemplateExpression(node) {
                const texts = [node.head.text];
                const types = [];
                for (const span of node.templateSpans) {
                    const type = checkExpression(span.expression);
                    if (maybeTypeOfKindConsideringBaseConstraint(type, 12288 /* ESSymbolLike */)) {
                        error(span.expression, Diagnostics.Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_in_String);
                    }
                    texts.push(span.literal.text);
                    types.push(isTypeAssignableTo(type, templateConstraintType) ? type : stringType);
                }
                return isConstContext(node) || isTemplateLiteralContext(node) || someType(getContextualType2(node, 
                /*contextFlags*/
                void 0) || unknownType, isTemplateLiteralContextualType) ? getTemplateLiteralType(texts, types) : stringType;
            }
            function isTemplateLiteralContextualType(type) {
                return !!(type.flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */) || type.flags & 58982400 /* InstantiableNonPrimitive */ && maybeTypeOfKind(getBaseConstraintOfType(type) || unknownType, 402653316 /* StringLike */));
            }
            function getContextNode2(node) {
                if (isJsxAttributes(node) && !isJsxSelfClosingElement(node.parent)) {
                    return node.parent.parent;
                }
                return node;
            }
            function checkExpressionWithContextualType(node, contextualType, inferenceContext, checkMode) {
                const contextNode = getContextNode2(node);
                pushContextualType(contextNode, contextualType, 
                /*isCache*/
                false);
                pushInferenceContext(contextNode, inferenceContext);
                const type = checkExpression(node, checkMode | 1 /* Contextual */ | (inferenceContext ? 2 /* Inferential */ : 0));
                if (inferenceContext && inferenceContext.intraExpressionInferenceSites) {
                    inferenceContext.intraExpressionInferenceSites = void 0;
                }
                const result = maybeTypeOfKind(type, 2944 /* Literal */) && isLiteralOfContextualType(type, instantiateContextualType(contextualType, node, 
                /*contextFlags*/
                void 0)) ? getRegularTypeOfLiteralType(type) : type;
                popInferenceContext();
                popContextualType();
                return result;
            }
            function checkExpressionCached(node, checkMode) {
                if (checkMode) {
                    return checkExpression(node, checkMode);
                }
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const saveFlowLoopStart = flowLoopStart;
                    const saveFlowTypeCache = flowTypeCache;
                    flowLoopStart = flowLoopCount;
                    flowTypeCache = void 0;
                    links.resolvedType = checkExpression(node, checkMode);
                    flowTypeCache = saveFlowTypeCache;
                    flowLoopStart = saveFlowLoopStart;
                }
                return links.resolvedType;
            }
            function isTypeAssertion(node) {
                node = skipParentheses(node, 
                /*excludeJSDocTypeAssertions*/
                true);
                return node.kind === 213 /* TypeAssertionExpression */ || node.kind === 231 /* AsExpression */ || isJSDocTypeAssertion(node);
            }
            function checkDeclarationInitializer(declaration, checkMode, contextualType) {
                const initializer = getEffectiveInitializer(declaration);
                if (isInJSFile(declaration)) {
                    const typeNode = tryGetJSDocSatisfiesTypeNode(declaration);
                    if (typeNode) {
                        return checkSatisfiesExpressionWorker(initializer, typeNode, checkMode);
                    }
                }
                const type = getQuickTypeOfExpression(initializer) || (contextualType ? checkExpressionWithContextualType(initializer, contextualType, 
                /*inferenceContext*/
                void 0, checkMode || 0 /* Normal */) : checkExpressionCached(initializer, checkMode));
                return isParameter(declaration) && declaration.name.kind === 204 /* ArrayBindingPattern */ && isTupleType(type) && !type.target.hasRestElement && getTypeReferenceArity(type) < declaration.name.elements.length ? padTupleType(type, declaration.name) : type;
            }
            function padTupleType(type, pattern) {
                const patternElements = pattern.elements;
                const elementTypes = getTypeArguments(type).slice();
                const elementFlags = type.target.elementFlags.slice();
                for (let i = getTypeReferenceArity(type); i < patternElements.length; i++) {
                    const e = patternElements[i];
                    if (i < patternElements.length - 1 || !(e.kind === 205 /* BindingElement */ && e.dotDotDotToken)) {
                        elementTypes.push(!isOmittedExpression(e) && hasDefaultValue(e) ? getTypeFromBindingElement(e, 
                        /*includePatternInType*/
                        false, 
                        /*reportErrors*/
                        false) : anyType);
                        elementFlags.push(2 /* Optional */);
                        if (!isOmittedExpression(e) && !hasDefaultValue(e)) {
                            reportImplicitAny(e, anyType);
                        }
                    }
                }
                return createTupleType(elementTypes, elementFlags, type.target.readonly);
            }
            function widenTypeInferredFromInitializer(declaration, type) {
                const widened = getCombinedNodeFlags(declaration) & 2 /* Const */ || isDeclarationReadonly(declaration) ? type : getWidenedLiteralType(type);
                if (isInJSFile(declaration)) {
                    if (isEmptyLiteralType(widened)) {
                        reportImplicitAny(declaration, anyType);
                        return anyType;
                    }
                    else if (isEmptyArrayLiteralType(widened)) {
                        reportImplicitAny(declaration, anyArrayType);
                        return anyArrayType;
                    }
                }
                return widened;
            }
            function isLiteralOfContextualType(candidateType, contextualType) {
                if (contextualType) {
                    if (contextualType.flags & 3145728 /* UnionOrIntersection */) {
                        const types = contextualType.types;
                        return some(types, (t) => isLiteralOfContextualType(candidateType, t));
                    }
                    if (contextualType.flags & 58982400 /* InstantiableNonPrimitive */) {
                        const constraint = getBaseConstraintOfType(contextualType) || unknownType;
                        return maybeTypeOfKind(constraint, 4 /* String */) && maybeTypeOfKind(candidateType, 128 /* StringLiteral */) || maybeTypeOfKind(constraint, 8 /* Number */) && maybeTypeOfKind(candidateType, 256 /* NumberLiteral */) || maybeTypeOfKind(constraint, 64 /* BigInt */) && maybeTypeOfKind(candidateType, 2048 /* BigIntLiteral */) || maybeTypeOfKind(constraint, 4096 /* ESSymbol */) && maybeTypeOfKind(candidateType, 8192 /* UniqueESSymbol */) || isLiteralOfContextualType(candidateType, constraint);
                    }
                    return !!(contextualType.flags & (128 /* StringLiteral */ | 4194304 /* Index */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) && maybeTypeOfKind(candidateType, 128 /* StringLiteral */) || contextualType.flags & 256 /* NumberLiteral */ && maybeTypeOfKind(candidateType, 256 /* NumberLiteral */) || contextualType.flags & 2048 /* BigIntLiteral */ && maybeTypeOfKind(candidateType, 2048 /* BigIntLiteral */) || contextualType.flags & 512 /* BooleanLiteral */ && maybeTypeOfKind(candidateType, 512 /* BooleanLiteral */) || contextualType.flags & 8192 /* UniqueESSymbol */ && maybeTypeOfKind(candidateType, 8192 /* UniqueESSymbol */));
                }
                return false;
            }
            function isConstContext(node) {
                const parent2 = node.parent;
                return isAssertionExpression(parent2) && isConstTypeReference(parent2.type) || isJSDocTypeAssertion(parent2) && isConstTypeReference(getJSDocTypeAssertionType(parent2)) || isValidConstAssertionArgument(node) && isConstTypeParameterContext(node) || (isParenthesizedExpression(parent2) || isArrayLiteralExpression(parent2) || isSpreadElement(parent2)) && isConstContext(parent2) || (isPropertyAssignment(parent2) || isShorthandPropertyAssignment(parent2) || isTemplateSpan(parent2)) && isConstContext(parent2.parent);
            }
            function isConstTypeParameterContext(node) {
                const contextualType = getContextualType2(node, 0 /* None */);
                return !!contextualType && someType(contextualType, isConstTypeVariable);
            }
            function checkExpressionForMutableLocation(node, checkMode, forceTuple) {
                const type = checkExpression(node, checkMode, forceTuple);
                return isConstContext(node) || isCommonJsExportedExpression(node) ? getRegularTypeOfLiteralType(type) : isTypeAssertion(node) ? type : getWidenedLiteralLikeTypeForContextualType(type, instantiateContextualType(getContextualType2(node, 
                /*contextFlags*/
                void 0), node, 
                /*contextFlags*/
                void 0));
            }
            function checkPropertyAssignment(node, checkMode) {
                if (node.name.kind === 164 /* ComputedPropertyName */) {
                    checkComputedPropertyName(node.name);
                }
                return checkExpressionForMutableLocation(node.initializer, checkMode);
            }
            function checkObjectLiteralMethod(node, checkMode) {
                checkGrammarMethod(node);
                if (node.name.kind === 164 /* ComputedPropertyName */) {
                    checkComputedPropertyName(node.name);
                }
                const uninstantiatedType = checkFunctionExpressionOrObjectLiteralMethod(node, checkMode);
                return instantiateTypeWithSingleGenericCallSignature(node, uninstantiatedType, checkMode);
            }
            function instantiateTypeWithSingleGenericCallSignature(node, type, checkMode) {
                if (checkMode && checkMode & (2 /* Inferential */ | 8 /* SkipGenericFunctions */)) {
                    const callSignature = getSingleSignature(type, 0 /* Call */, 
                    /*allowMembers*/
                    true);
                    const constructSignature = getSingleSignature(type, 1 /* Construct */, 
                    /*allowMembers*/
                    true);
                    const signature = callSignature || constructSignature;
                    if (signature && signature.typeParameters) {
                        const contextualType = getApparentTypeOfContextualType(node, 2 /* NoConstraints */);
                        if (contextualType) {
                            const contextualSignature = getSingleSignature(getNonNullableType(contextualType), callSignature ? 0 /* Call */ : 1 /* Construct */, 
                            /*allowMembers*/
                            false);
                            if (contextualSignature && !contextualSignature.typeParameters) {
                                if (checkMode & 8 /* SkipGenericFunctions */) {
                                    skippedGenericFunction(node, checkMode);
                                    return anyFunctionType;
                                }
                                const context = getInferenceContext(node);
                                const returnType = context.signature && getReturnTypeOfSignature(context.signature);
                                const returnSignature = returnType && getSingleCallOrConstructSignature(returnType);
                                if (returnSignature && !returnSignature.typeParameters && !every(context.inferences, hasInferenceCandidates)) {
                                    const uniqueTypeParameters = getUniqueTypeParameters(context, signature.typeParameters);
                                    const instantiatedSignature = getSignatureInstantiationWithoutFillingInTypeArguments(signature, uniqueTypeParameters);
                                    const inferences = map(context.inferences, (info) => createInferenceInfo(info.typeParameter));
                                    applyToParameterTypes(instantiatedSignature, contextualSignature, (source, target) => {
                                        inferTypes(inferences, source, target, 
                                        /*priority*/
                                        0, 
                                        /*contravariant*/
                                        true);
                                    });
                                    if (some(inferences, hasInferenceCandidates)) {
                                        applyToReturnTypes(instantiatedSignature, contextualSignature, (source, target) => {
                                            inferTypes(inferences, source, target);
                                        });
                                        if (!hasOverlappingInferences(context.inferences, inferences)) {
                                            mergeInferences(context.inferences, inferences);
                                            context.inferredTypeParameters = concatenate(context.inferredTypeParameters, uniqueTypeParameters);
                                            return getOrCreateTypeFromSignature(instantiatedSignature);
                                        }
                                    }
                                }
                                return getOrCreateTypeFromSignature(instantiateSignatureInContextOf(signature, contextualSignature, context));
                            }
                        }
                    }
                }
                return type;
            }
            function skippedGenericFunction(node, checkMode) {
                if (checkMode & 2 /* Inferential */) {
                    const context = getInferenceContext(node);
                    context.flags |= 4 /* SkippedGenericFunction */;
                }
            }
            function hasInferenceCandidates(info) {
                return !!(info.candidates || info.contraCandidates);
            }
            function hasInferenceCandidatesOrDefault(info) {
                return !!(info.candidates || info.contraCandidates || hasTypeParameterDefault(info.typeParameter));
            }
            function hasOverlappingInferences(a, b) {
                for (let i = 0; i < a.length; i++) {
                    if (hasInferenceCandidates(a[i]) && hasInferenceCandidates(b[i])) {
                        return true;
                    }
                }
                return false;
            }
            function mergeInferences(target, source) {
                for (let i = 0; i < target.length; i++) {
                    if (!hasInferenceCandidates(target[i]) && hasInferenceCandidates(source[i])) {
                        target[i] = source[i];
                    }
                }
            }
            function getUniqueTypeParameters(context, typeParameters) {
                const result = [];
                let oldTypeParameters;
                let newTypeParameters;
                for (const tp of typeParameters) {
                    const name = tp.symbol.escapedName;
                    if (hasTypeParameterByName(context.inferredTypeParameters, name) || hasTypeParameterByName(result, name)) {
                        const newName = getUniqueTypeParameterName(concatenate(context.inferredTypeParameters, result), name);
                        const symbol = createSymbol(262144 /* TypeParameter */, newName);
                        const newTypeParameter = createTypeParameter(symbol);
                        newTypeParameter.target = tp;
                        oldTypeParameters = append(oldTypeParameters, tp);
                        newTypeParameters = append(newTypeParameters, newTypeParameter);
                        result.push(newTypeParameter);
                    }
                    else {
                        result.push(tp);
                    }
                }
                if (newTypeParameters) {
                    const mapper = createTypeMapper(oldTypeParameters, newTypeParameters);
                    for (const tp of newTypeParameters) {
                        tp.mapper = mapper;
                    }
                }
                return result;
            }
            function hasTypeParameterByName(typeParameters, name) {
                return some(typeParameters, (tp) => tp.symbol.escapedName === name);
            }
            function getUniqueTypeParameterName(typeParameters, baseName) {
                let len = baseName.length;
                while (len > 1 && baseName.charCodeAt(len - 1) >= 48 /* _0 */ && baseName.charCodeAt(len - 1) <= 57 /* _9 */)
                    len--;
                const s = baseName.slice(0, len);
                for (let index = 1; true; index++) {
                    const augmentedName = s + index;
                    if (!hasTypeParameterByName(typeParameters, augmentedName)) {
                        return augmentedName;
                    }
                }
            }
            function getReturnTypeOfSingleNonGenericCallSignature(funcType) {
                const signature = getSingleCallSignature(funcType);
                if (signature && !signature.typeParameters) {
                    return getReturnTypeOfSignature(signature);
                }
            }
            function getReturnTypeOfSingleNonGenericSignatureOfCallChain(expr) {
                const funcType = checkExpression(expr.expression);
                const nonOptionalType = getOptionalExpressionType(funcType, expr.expression);
                const returnType = getReturnTypeOfSingleNonGenericCallSignature(funcType);
                return returnType && propagateOptionalTypeMarker(returnType, expr, nonOptionalType !== funcType);
            }
            function getTypeOfExpression(node) {
                const quickType = getQuickTypeOfExpression(node);
                if (quickType) {
                    return quickType;
                }
                if (node.flags & 134217728 /* TypeCached */ && flowTypeCache) {
                    const cachedType = flowTypeCache[getNodeId(node)];
                    if (cachedType) {
                        return cachedType;
                    }
                }
                const startInvocationCount = flowInvocationCount;
                const type = checkExpression(node);
                if (flowInvocationCount !== startInvocationCount) {
                    const cache = flowTypeCache || (flowTypeCache = []);
                    cache[getNodeId(node)] = type;
                    setNodeFlags(node, node.flags | 134217728 /* TypeCached */);
                }
                return type;
            }
            function getQuickTypeOfExpression(node) {
                let expr = skipParentheses(node, 
                /*excludeJSDocTypeAssertions*/
                true);
                if (isJSDocTypeAssertion(expr)) {
                    const type = getJSDocTypeAssertionType(expr);
                    if (!isConstTypeReference(type)) {
                        return getTypeFromTypeNode(type);
                    }
                }
                expr = skipParentheses(node);
                if (isAwaitExpression(expr)) {
                    const type = getQuickTypeOfExpression(expr.expression);
                    return type ? getAwaitedType(type) : void 0;
                }
                if (isCallExpression(expr) && expr.expression.kind !== 106 /* SuperKeyword */ && !isRequireCall(expr, 
                /*checkArgumentIsStringLiteralLike*/
                true) && !isSymbolOrSymbolForCall(expr)) {
                    return isCallChain(expr) ? getReturnTypeOfSingleNonGenericSignatureOfCallChain(expr) : getReturnTypeOfSingleNonGenericCallSignature(checkNonNullExpression(expr.expression));
                }
                else if (isAssertionExpression(expr) && !isConstTypeReference(expr.type)) {
                    return getTypeFromTypeNode(expr.type);
                }
                else if (isLiteralExpression(node) || isBooleanLiteral(node)) {
                    return checkExpression(node);
                }
                return void 0;
            }
            function getContextFreeTypeOfExpression(node) {
                const links = getNodeLinks(node);
                if (links.contextFreeType) {
                    return links.contextFreeType;
                }
                pushContextualType(node, anyType, 
                /*isCache*/
                false);
                const type = links.contextFreeType = checkExpression(node, 4 /* SkipContextSensitive */);
                popContextualType();
                return type;
            }
            function checkExpression(node, checkMode, forceTuple) {
                var _a2, _b;
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Check, "checkExpression", { kind: node.kind, pos: node.pos, end: node.end, path: node.tracingPath });
                const saveCurrentNode = currentNode;
                currentNode = node;
                instantiationCount = 0;
                const uninstantiatedType = checkExpressionWorker(node, checkMode, forceTuple);
                const type = instantiateTypeWithSingleGenericCallSignature(node, uninstantiatedType, checkMode);
                if (isConstEnumObjectType(type)) {
                    checkConstEnumAccess(node, type);
                }
                currentNode = saveCurrentNode;
                (_b = tracing) == null ? void 0 : _b.pop();
                return type;
            }
            function checkConstEnumAccess(node, type) {
                const ok = node.parent.kind === 208 /* PropertyAccessExpression */ && node.parent.expression === node || node.parent.kind === 209 /* ElementAccessExpression */ && node.parent.expression === node || ((node.kind === 79 /* Identifier */ || node.kind === 163 /* QualifiedName */) && isInRightSideOfImportOrExportAssignment(node) || node.parent.kind === 183 /* TypeQuery */ && node.parent.exprName === node) || node.parent.kind === 278 /* ExportSpecifier */;
                if (!ok) {
                    error(node, Diagnostics.const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment_or_type_query);
                }
                if (getIsolatedModules(compilerOptions)) {
                    Debug.assert(!!(type.symbol.flags & 128 /* ConstEnum */));
                    const constEnumDeclaration = type.symbol.valueDeclaration;
                    if (constEnumDeclaration.flags & 16777216 /* Ambient */) {
                        error(node, Diagnostics.Cannot_access_ambient_const_enums_when_0_is_enabled, isolatedModulesLikeFlagName);
                    }
                }
            }
            function checkParenthesizedExpression(node, checkMode) {
                if (hasJSDocNodes(node)) {
                    if (isJSDocSatisfiesExpression(node)) {
                        return checkSatisfiesExpressionWorker(node.expression, getJSDocSatisfiesExpressionType(node), checkMode);
                    }
                    if (isJSDocTypeAssertion(node)) {
                        const type = getJSDocTypeAssertionType(node);
                        return checkAssertionWorker(type, type, node.expression, checkMode);
                    }
                }
                return checkExpression(node.expression, checkMode);
            }
            function checkExpressionWorker(node, checkMode, forceTuple) {
                const kind = node.kind;
                if (cancellationToken) {
                    switch (kind) {
                        case 228 /* ClassExpression */:
                        case 215 /* FunctionExpression */:
                        case 216 /* ArrowFunction */:
                            cancellationToken.throwIfCancellationRequested();
                    }
                }
                switch (kind) {
                    case 79 /* Identifier */:
                        return checkIdentifier(node, checkMode);
                    case 80 /* PrivateIdentifier */:
                        return checkPrivateIdentifierExpression(node);
                    case 108 /* ThisKeyword */:
                        return checkThisExpression(node);
                    case 106 /* SuperKeyword */:
                        return checkSuperExpression(node);
                    case 104 /* NullKeyword */:
                        return nullWideningType;
                    case 14 /* NoSubstitutionTemplateLiteral */:
                    case 10 /* StringLiteral */:
                        return getFreshTypeOfLiteralType(getStringLiteralType(node.text));
                    case 8 /* NumericLiteral */:
                        checkGrammarNumericLiteral(node);
                        return getFreshTypeOfLiteralType(getNumberLiteralType(+node.text));
                    case 9 /* BigIntLiteral */:
                        checkGrammarBigIntLiteral(node);
                        return getFreshTypeOfLiteralType(getBigIntLiteralType({
                            negative: false,
                            base10Value: parsePseudoBigInt(node.text)
                        }));
                    case 110 /* TrueKeyword */:
                        return trueType;
                    case 95 /* FalseKeyword */:
                        return falseType;
                    case 225 /* TemplateExpression */:
                        return checkTemplateExpression(node);
                    case 13 /* RegularExpressionLiteral */:
                        return globalRegExpType;
                    case 206 /* ArrayLiteralExpression */:
                        return checkArrayLiteral(node, checkMode, forceTuple);
                    case 207 /* ObjectLiteralExpression */:
                        return checkObjectLiteral(node, checkMode);
                    case 208 /* PropertyAccessExpression */:
                        return checkPropertyAccessExpression(node, checkMode);
                    case 163 /* QualifiedName */:
                        return checkQualifiedName(node, checkMode);
                    case 209 /* ElementAccessExpression */:
                        return checkIndexedAccess(node, checkMode);
                    case 210 /* CallExpression */:
                        if (node.expression.kind === 100 /* ImportKeyword */) {
                            return checkImportCallExpression(node);
                        }
                    case 211 /* NewExpression */:
                        return checkCallExpression(node, checkMode);
                    case 212 /* TaggedTemplateExpression */:
                        return checkTaggedTemplateExpression(node);
                    case 214 /* ParenthesizedExpression */:
                        return checkParenthesizedExpression(node, checkMode);
                    case 228 /* ClassExpression */:
                        return checkClassExpression(node);
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                        return checkFunctionExpressionOrObjectLiteralMethod(node, checkMode);
                    case 218 /* TypeOfExpression */:
                        return checkTypeOfExpression(node);
                    case 213 /* TypeAssertionExpression */:
                    case 231 /* AsExpression */:
                        return checkAssertion(node);
                    case 232 /* NonNullExpression */:
                        return checkNonNullAssertion(node);
                    case 230 /* ExpressionWithTypeArguments */:
                        return checkExpressionWithTypeArguments(node);
                    case 235 /* SatisfiesExpression */:
                        return checkSatisfiesExpression(node);
                    case 233 /* MetaProperty */:
                        return checkMetaProperty(node);
                    case 217 /* DeleteExpression */:
                        return checkDeleteExpression(node);
                    case 219 /* VoidExpression */:
                        return checkVoidExpression(node);
                    case 220 /* AwaitExpression */:
                        return checkAwaitExpression(node);
                    case 221 /* PrefixUnaryExpression */:
                        return checkPrefixUnaryExpression(node);
                    case 222 /* PostfixUnaryExpression */:
                        return checkPostfixUnaryExpression(node);
                    case 223 /* BinaryExpression */:
                        return checkBinaryExpression(node, checkMode);
                    case 224 /* ConditionalExpression */:
                        return checkConditionalExpression(node, checkMode);
                    case 227 /* SpreadElement */:
                        return checkSpreadExpression(node, checkMode);
                    case 229 /* OmittedExpression */:
                        return undefinedWideningType;
                    case 226 /* YieldExpression */:
                        return checkYieldExpression(node);
                    case 234 /* SyntheticExpression */:
                        return checkSyntheticExpression(node);
                    case 291 /* JsxExpression */:
                        return checkJsxExpression(node, checkMode);
                    case 281 /* JsxElement */:
                        return checkJsxElement(node, checkMode);
                    case 282 /* JsxSelfClosingElement */:
                        return checkJsxSelfClosingElement(node, checkMode);
                    case 285 /* JsxFragment */:
                        return checkJsxFragment(node);
                    case 289 /* JsxAttributes */:
                        return checkJsxAttributes(node, checkMode);
                    case 283 /* JsxOpeningElement */:
                        Debug.fail("Shouldn't ever directly check a JsxOpeningElement");
                }
                return errorType;
            }
            function checkTypeParameter(node) {
                checkGrammarModifiers(node);
                if (node.expression) {
                    grammarErrorOnFirstToken(node.expression, Diagnostics.Type_expected);
                }
                checkSourceElement(node.constraint);
                checkSourceElement(node.default);
                const typeParameter = getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(node));
                getBaseConstraintOfType(typeParameter);
                if (!hasNonCircularTypeParameterDefault(typeParameter)) {
                    error(node.default, Diagnostics.Type_parameter_0_has_a_circular_default, typeToString(typeParameter));
                }
                const constraintType = getConstraintOfTypeParameter(typeParameter);
                const defaultType = getDefaultFromTypeParameter(typeParameter);
                if (constraintType && defaultType) {
                    checkTypeAssignableTo(defaultType, getTypeWithThisArgument(instantiateType(constraintType, makeUnaryTypeMapper(typeParameter, defaultType)), defaultType), node.default, Diagnostics.Type_0_does_not_satisfy_the_constraint_1);
                }
                checkNodeDeferred(node);
                addLazyDiagnostic(() => checkTypeNameIsReserved(node.name, Diagnostics.Type_parameter_name_cannot_be_0));
            }
            function checkTypeParameterDeferred(node) {
                var _a2, _b;
                if (isInterfaceDeclaration(node.parent) || isClassLike(node.parent) || isTypeAliasDeclaration(node.parent)) {
                    const typeParameter = getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(node));
                    const modifiers = getTypeParameterModifiers(typeParameter) & (32768 /* In */ | 65536 /* Out */);
                    if (modifiers) {
                        const symbol = getSymbolOfDeclaration(node.parent);
                        if (isTypeAliasDeclaration(node.parent) && !(getObjectFlags(getDeclaredTypeOfSymbol(symbol)) & (16 /* Anonymous */ | 32 /* Mapped */))) {
                            error(node, Diagnostics.Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_types);
                        }
                        else if (modifiers === 32768 /* In */ || modifiers === 65536 /* Out */) {
                            (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.CheckTypes, "checkTypeParameterDeferred", { parent: getTypeId(getDeclaredTypeOfSymbol(symbol)), id: getTypeId(typeParameter) });
                            const source = createMarkerType(symbol, typeParameter, modifiers === 65536 /* Out */ ? markerSubTypeForCheck : markerSuperTypeForCheck);
                            const target = createMarkerType(symbol, typeParameter, modifiers === 65536 /* Out */ ? markerSuperTypeForCheck : markerSubTypeForCheck);
                            const saveVarianceTypeParameter = typeParameter;
                            varianceTypeParameter = typeParameter;
                            checkTypeAssignableTo(source, target, node, Diagnostics.Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation);
                            varianceTypeParameter = saveVarianceTypeParameter;
                            (_b = tracing) == null ? void 0 : _b.pop();
                        }
                    }
                }
            }
            function checkParameter(node) {
                checkGrammarModifiers(node);
                checkVariableLikeDeclaration(node);
                const func = getContainingFunction(node);
                if (hasSyntacticModifier(node, 16476 /* ParameterPropertyModifier */)) {
                    if (!(func.kind === 173 /* Constructor */ && nodeIsPresent(func.body))) {
                        error(node, Diagnostics.A_parameter_property_is_only_allowed_in_a_constructor_implementation);
                    }
                    if (func.kind === 173 /* Constructor */ && isIdentifier(node.name) && node.name.escapedText === "constructor") {
                        error(node.name, Diagnostics.constructor_cannot_be_used_as_a_parameter_property_name);
                    }
                }
                if (!node.initializer && isOptionalDeclaration(node) && isBindingPattern(node.name) && func.body) {
                    error(node, Diagnostics.A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature);
                }
                if (node.name && isIdentifier(node.name) && (node.name.escapedText === "this" || node.name.escapedText === "new")) {
                    if (func.parameters.indexOf(node) !== 0) {
                        error(node, Diagnostics.A_0_parameter_must_be_the_first_parameter, node.name.escapedText);
                    }
                    if (func.kind === 173 /* Constructor */ || func.kind === 177 /* ConstructSignature */ || func.kind === 182 /* ConstructorType */) {
                        error(node, Diagnostics.A_constructor_cannot_have_a_this_parameter);
                    }
                    if (func.kind === 216 /* ArrowFunction */) {
                        error(node, Diagnostics.An_arrow_function_cannot_have_a_this_parameter);
                    }
                    if (func.kind === 174 /* GetAccessor */ || func.kind === 175 /* SetAccessor */) {
                        error(node, Diagnostics.get_and_set_accessors_cannot_declare_this_parameters);
                    }
                }
                if (node.dotDotDotToken && !isBindingPattern(node.name) && !isTypeAssignableTo(getReducedType(getTypeOfSymbol(node.symbol)), anyReadonlyArrayType)) {
                    error(node, Diagnostics.A_rest_parameter_must_be_of_an_array_type);
                }
            }
            function checkTypePredicate(node) {
                const parent2 = getTypePredicateParent(node);
                if (!parent2) {
                    error(node, Diagnostics.A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods);
                    return;
                }
                const signature = getSignatureFromDeclaration(parent2);
                const typePredicate = getTypePredicateOfSignature(signature);
                if (!typePredicate) {
                    return;
                }
                checkSourceElement(node.type);
                const { parameterName } = node;
                if (typePredicate.kind === 0 /* This */ || typePredicate.kind === 2 /* AssertsThis */) {
                    getTypeFromThisTypeNode(parameterName);
                }
                else {
                    if (typePredicate.parameterIndex >= 0) {
                        if (signatureHasRestParameter(signature) && typePredicate.parameterIndex === signature.parameters.length - 1) {
                            error(parameterName, Diagnostics.A_type_predicate_cannot_reference_a_rest_parameter);
                        }
                        else {
                            if (typePredicate.type) {
                                const leadingError = () => chainDiagnosticMessages(
                                /*details*/
                                void 0, Diagnostics.A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type);
                                checkTypeAssignableTo(typePredicate.type, getTypeOfSymbol(signature.parameters[typePredicate.parameterIndex]), node.type, 
                                /*headMessage*/
                                void 0, leadingError);
                            }
                        }
                    }
                    else if (parameterName) {
                        let hasReportedError = false;
                        for (const { name } of parent2.parameters) {
                            if (isBindingPattern(name) && checkIfTypePredicateVariableIsDeclaredInBindingPattern(name, parameterName, typePredicate.parameterName)) {
                                hasReportedError = true;
                                break;
                            }
                        }
                        if (!hasReportedError) {
                            error(node.parameterName, Diagnostics.Cannot_find_parameter_0, typePredicate.parameterName);
                        }
                    }
                }
            }
            function getTypePredicateParent(node) {
                switch (node.parent.kind) {
                    case 216 /* ArrowFunction */:
                    case 176 /* CallSignature */:
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                    case 181 /* FunctionType */:
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                        const parent2 = node.parent;
                        if (node === parent2.type) {
                            return parent2;
                        }
                }
            }
            function checkIfTypePredicateVariableIsDeclaredInBindingPattern(pattern, predicateVariableNode, predicateVariableName) {
                for (const element of pattern.elements) {
                    if (isOmittedExpression(element)) {
                        continue;
                    }
                    const name = element.name;
                    if (name.kind === 79 /* Identifier */ && name.escapedText === predicateVariableName) {
                        error(predicateVariableNode, Diagnostics.A_type_predicate_cannot_reference_element_0_in_a_binding_pattern, predicateVariableName);
                        return true;
                    }
                    else if (name.kind === 204 /* ArrayBindingPattern */ || name.kind === 203 /* ObjectBindingPattern */) {
                        if (checkIfTypePredicateVariableIsDeclaredInBindingPattern(name, predicateVariableNode, predicateVariableName)) {
                            return true;
                        }
                    }
                }
            }
            function checkSignatureDeclaration(node) {
                if (node.kind === 178 /* IndexSignature */) {
                    checkGrammarIndexSignature(node);
                }
                else if (node.kind === 181 /* FunctionType */ || node.kind === 259 /* FunctionDeclaration */ || node.kind === 182 /* ConstructorType */ || node.kind === 176 /* CallSignature */ || node.kind === 173 /* Constructor */ || node.kind === 177 /* ConstructSignature */) {
                    checkGrammarFunctionLikeDeclaration(node);
                }
                const functionFlags = getFunctionFlags(node);
                if (!(functionFlags & 4 /* Invalid */)) {
                    if ((functionFlags & 3 /* AsyncGenerator */) === 3 /* AsyncGenerator */ && languageVersion < 99 /* ESNext */) {
                        checkExternalEmitHelpers(node, 6144 /* AsyncGeneratorIncludes */);
                    }
                    if ((functionFlags & 3 /* AsyncGenerator */) === 2 /* Async */ && languageVersion < 4 /* ES2017 */) {
                        checkExternalEmitHelpers(node, 64 /* Awaiter */);
                    }
                    if ((functionFlags & 3 /* AsyncGenerator */) !== 0 /* Normal */ && languageVersion < 2 /* ES2015 */) {
                        checkExternalEmitHelpers(node, 128 /* Generator */);
                    }
                }
                checkTypeParameters(getEffectiveTypeParameterDeclarations(node));
                checkUnmatchedJSDocParameters(node);
                forEach(node.parameters, checkParameter);
                if (node.type) {
                    checkSourceElement(node.type);
                }
                addLazyDiagnostic(checkSignatureDeclarationDiagnostics);
                function checkSignatureDeclarationDiagnostics() {
                    checkCollisionWithArgumentsInGeneratedCode(node);
                    const returnTypeNode = getEffectiveReturnTypeNode(node);
                    if (noImplicitAny && !returnTypeNode) {
                        switch (node.kind) {
                            case 177 /* ConstructSignature */:
                                error(node, Diagnostics.Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type);
                                break;
                            case 176 /* CallSignature */:
                                error(node, Diagnostics.Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type);
                                break;
                        }
                    }
                    if (returnTypeNode) {
                        const functionFlags2 = getFunctionFlags(node);
                        if ((functionFlags2 & (4 /* Invalid */ | 1 /* Generator */)) === 1 /* Generator */) {
                            const returnType = getTypeFromTypeNode(returnTypeNode);
                            if (returnType === voidType) {
                                error(returnTypeNode, Diagnostics.A_generator_cannot_have_a_void_type_annotation);
                            }
                            else {
                                const generatorYieldType = getIterationTypeOfGeneratorFunctionReturnType(0 /* Yield */, returnType, (functionFlags2 & 2 /* Async */) !== 0) || anyType;
                                const generatorReturnType = getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, returnType, (functionFlags2 & 2 /* Async */) !== 0) || generatorYieldType;
                                const generatorNextType = getIterationTypeOfGeneratorFunctionReturnType(2 /* Next */, returnType, (functionFlags2 & 2 /* Async */) !== 0) || unknownType;
                                const generatorInstantiation = createGeneratorReturnType(generatorYieldType, generatorReturnType, generatorNextType, !!(functionFlags2 & 2 /* Async */));
                                checkTypeAssignableTo(generatorInstantiation, returnType, returnTypeNode);
                            }
                        }
                        else if ((functionFlags2 & 3 /* AsyncGenerator */) === 2 /* Async */) {
                            checkAsyncFunctionReturnType(node, returnTypeNode);
                        }
                    }
                    if (node.kind !== 178 /* IndexSignature */ && node.kind !== 320 /* JSDocFunctionType */) {
                        registerForUnusedIdentifiersCheck(node);
                    }
                }
            }
            function checkClassForDuplicateDeclarations(node) {
                const instanceNames = /* @__PURE__ */ new Map();
                const staticNames = /* @__PURE__ */ new Map();
                const privateIdentifiers = /* @__PURE__ */ new Map();
                for (const member of node.members) {
                    if (member.kind === 173 /* Constructor */) {
                        for (const param of member.parameters) {
                            if (isParameterPropertyDeclaration(param, member) && !isBindingPattern(param.name)) {
                                addName(instanceNames, param.name, param.name.escapedText, 3 /* GetOrSetAccessor */);
                            }
                        }
                    }
                    else {
                        const isStaticMember = isStatic(member);
                        const name = member.name;
                        if (!name) {
                            continue;
                        }
                        const isPrivate = isPrivateIdentifier(name);
                        const privateStaticFlags = isPrivate && isStaticMember ? 16 /* PrivateStatic */ : 0;
                        const names = isPrivate ? privateIdentifiers : isStaticMember ? staticNames : instanceNames;
                        const memberName = name && getPropertyNameForPropertyNameNode(name);
                        if (memberName) {
                            switch (member.kind) {
                                case 174 /* GetAccessor */:
                                    addName(names, name, memberName, 1 /* GetAccessor */ | privateStaticFlags);
                                    break;
                                case 175 /* SetAccessor */:
                                    addName(names, name, memberName, 2 /* SetAccessor */ | privateStaticFlags);
                                    break;
                                case 169 /* PropertyDeclaration */:
                                    addName(names, name, memberName, 3 /* GetOrSetAccessor */ | privateStaticFlags);
                                    break;
                                case 171 /* MethodDeclaration */:
                                    addName(names, name, memberName, 8 /* Method */ | privateStaticFlags);
                                    break;
                            }
                        }
                    }
                }
                function addName(names, location, name, meaning) {
                    const prev = names.get(name);
                    if (prev) {
                        if ((prev & 16 /* PrivateStatic */) !== (meaning & 16 /* PrivateStatic */)) {
                            error(location, Diagnostics.Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name, getTextOfNode(location));
                        }
                        else {
                            const prevIsMethod = !!(prev & 8 /* Method */);
                            const isMethod = !!(meaning & 8 /* Method */);
                            if (prevIsMethod || isMethod) {
                                if (prevIsMethod !== isMethod) {
                                    error(location, Diagnostics.Duplicate_identifier_0, getTextOfNode(location));
                                }
                            }
                            else if (prev & meaning & ~16 /* PrivateStatic */) {
                                error(location, Diagnostics.Duplicate_identifier_0, getTextOfNode(location));
                            }
                            else {
                                names.set(name, prev | meaning);
                            }
                        }
                    }
                    else {
                        names.set(name, meaning);
                    }
                }
            }
            function checkClassForStaticPropertyNameConflicts(node) {
                for (const member of node.members) {
                    const memberNameNode = member.name;
                    const isStaticMember = isStatic(member);
                    if (isStaticMember && memberNameNode) {
                        const memberName = getPropertyNameForPropertyNameNode(memberNameNode);
                        switch (memberName) {
                            case "name":
                            case "length":
                            case "caller":
                            case "arguments":
                            case "prototype":
                                const message = Diagnostics.Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1;
                                const className = getNameOfSymbolAsWritten(getSymbolOfDeclaration(node));
                                error(memberNameNode, message, memberName, className);
                                break;
                        }
                    }
                }
            }
            function checkObjectTypeForDuplicateDeclarations(node) {
                const names = /* @__PURE__ */ new Map();
                for (const member of node.members) {
                    if (member.kind === 168 /* PropertySignature */) {
                        let memberName;
                        const name = member.name;
                        switch (name.kind) {
                            case 10 /* StringLiteral */:
                            case 8 /* NumericLiteral */:
                                memberName = name.text;
                                break;
                            case 79 /* Identifier */:
                                memberName = idText(name);
                                break;
                            default:
                                continue;
                        }
                        if (names.get(memberName)) {
                            error(getNameOfDeclaration(member.symbol.valueDeclaration), Diagnostics.Duplicate_identifier_0, memberName);
                            error(member.name, Diagnostics.Duplicate_identifier_0, memberName);
                        }
                        else {
                            names.set(memberName, true);
                        }
                    }
                }
            }
            function checkTypeForDuplicateIndexSignatures(node) {
                if (node.kind === 261 /* InterfaceDeclaration */) {
                    const nodeSymbol = getSymbolOfDeclaration(node);
                    if (nodeSymbol.declarations && nodeSymbol.declarations.length > 0 && nodeSymbol.declarations[0] !== node) {
                        return;
                    }
                }
                const indexSymbol = getIndexSymbol(getSymbolOfDeclaration(node));
                if (indexSymbol == null ? void 0 : indexSymbol.declarations) {
                    const indexSignatureMap = /* @__PURE__ */ new Map();
                    for (const declaration of indexSymbol.declarations) {
                        if (declaration.parameters.length === 1 && declaration.parameters[0].type) {
                            forEachType(getTypeFromTypeNode(declaration.parameters[0].type), (type) => {
                                const entry = indexSignatureMap.get(getTypeId(type));
                                if (entry) {
                                    entry.declarations.push(declaration);
                                }
                                else {
                                    indexSignatureMap.set(getTypeId(type), { type, declarations: [declaration] });
                                }
                            });
                        }
                    }
                    indexSignatureMap.forEach((entry) => {
                        if (entry.declarations.length > 1) {
                            for (const declaration of entry.declarations) {
                                error(declaration, Diagnostics.Duplicate_index_signature_for_type_0, typeToString(entry.type));
                            }
                        }
                    });
                }
            }
            function checkPropertyDeclaration(node) {
                if (!checkGrammarModifiers(node) && !checkGrammarProperty(node))
                    checkGrammarComputedPropertyName(node.name);
                checkVariableLikeDeclaration(node);
                setNodeLinksForPrivateIdentifierScope(node);
                if (hasSyntacticModifier(node, 256 /* Abstract */) && node.kind === 169 /* PropertyDeclaration */ && node.initializer) {
                    error(node, Diagnostics.Property_0_cannot_have_an_initializer_because_it_is_marked_abstract, declarationNameToString(node.name));
                }
            }
            function checkPropertySignature(node) {
                if (isPrivateIdentifier(node.name)) {
                    error(node, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                }
                return checkPropertyDeclaration(node);
            }
            function checkMethodDeclaration(node) {
                if (!checkGrammarMethod(node))
                    checkGrammarComputedPropertyName(node.name);
                if (isMethodDeclaration(node) && node.asteriskToken && isIdentifier(node.name) && idText(node.name) === "constructor") {
                    error(node.name, Diagnostics.Class_constructor_may_not_be_a_generator);
                }
                checkFunctionOrMethodDeclaration(node);
                if (hasSyntacticModifier(node, 256 /* Abstract */) && node.kind === 171 /* MethodDeclaration */ && node.body) {
                    error(node, Diagnostics.Method_0_cannot_have_an_implementation_because_it_is_marked_abstract, declarationNameToString(node.name));
                }
                if (isPrivateIdentifier(node.name) && !getContainingClass(node)) {
                    error(node, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                }
                setNodeLinksForPrivateIdentifierScope(node);
            }
            function setNodeLinksForPrivateIdentifierScope(node) {
                if (isPrivateIdentifier(node.name) && languageVersion < 99 /* ESNext */) {
                    for (let lexicalScope = getEnclosingBlockScopeContainer(node); !!lexicalScope; lexicalScope = getEnclosingBlockScopeContainer(lexicalScope)) {
                        getNodeLinks(lexicalScope).flags |= 4194304 /* ContainsClassWithPrivateIdentifiers */;
                    }
                    if (isClassExpression(node.parent)) {
                        const enclosingIterationStatement = getEnclosingIterationStatement(node.parent);
                        if (enclosingIterationStatement) {
                            getNodeLinks(node.name).flags |= 32768 /* BlockScopedBindingInLoop */;
                            getNodeLinks(enclosingIterationStatement).flags |= 4096 /* LoopWithCapturedBlockScopedBinding */;
                        }
                    }
                }
            }
            function checkClassStaticBlockDeclaration(node) {
                checkGrammarModifiers(node);
                forEachChild(node, checkSourceElement);
            }
            function checkConstructorDeclaration(node) {
                checkSignatureDeclaration(node);
                if (!checkGrammarConstructorTypeParameters(node))
                    checkGrammarConstructorTypeAnnotation(node);
                checkSourceElement(node.body);
                const symbol = getSymbolOfDeclaration(node);
                const firstDeclaration = getDeclarationOfKind(symbol, node.kind);
                if (node === firstDeclaration) {
                    checkFunctionOrConstructorSymbol(symbol);
                }
                if (nodeIsMissing(node.body)) {
                    return;
                }
                addLazyDiagnostic(checkConstructorDeclarationDiagnostics);
                return;
                function isInstancePropertyWithInitializerOrPrivateIdentifierProperty(n) {
                    if (isPrivateIdentifierClassElementDeclaration(n)) {
                        return true;
                    }
                    return n.kind === 169 /* PropertyDeclaration */ && !isStatic(n) && !!n.initializer;
                }
                function checkConstructorDeclarationDiagnostics() {
                    const containingClassDecl = node.parent;
                    if (getClassExtendsHeritageElement(containingClassDecl)) {
                        captureLexicalThis(node.parent, containingClassDecl);
                        const classExtendsNull = classDeclarationExtendsNull(containingClassDecl);
                        const superCall = findFirstSuperCall(node.body);
                        if (superCall) {
                            if (classExtendsNull) {
                                error(superCall, Diagnostics.A_constructor_cannot_contain_a_super_call_when_its_class_extends_null);
                            }
                            const superCallShouldBeRootLevel = (getEmitScriptTarget(compilerOptions) !== 99 /* ESNext */ || !useDefineForClassFields) && (some(node.parent.members, isInstancePropertyWithInitializerOrPrivateIdentifierProperty) || some(node.parameters, (p) => hasSyntacticModifier(p, 16476 /* ParameterPropertyModifier */)));
                            if (superCallShouldBeRootLevel) {
                                if (!superCallIsRootLevelInConstructor(superCall, node.body)) {
                                    error(superCall, Diagnostics.A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_initialized_properties_parameter_properties_or_private_identifiers);
                                }
                                else {
                                    let superCallStatement;
                                    for (const statement of node.body.statements) {
                                        if (isExpressionStatement(statement) && isSuperCall(skipOuterExpressions(statement.expression))) {
                                            superCallStatement = statement;
                                            break;
                                        }
                                        if (nodeImmediatelyReferencesSuperOrThis(statement)) {
                                            break;
                                        }
                                    }
                                    if (superCallStatement === void 0) {
                                        error(node, Diagnostics.A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_class_contains_initialized_properties_parameter_properties_or_private_identifiers);
                                    }
                                }
                            }
                        }
                        else if (!classExtendsNull) {
                            error(node, Diagnostics.Constructors_for_derived_classes_must_contain_a_super_call);
                        }
                    }
                }
            }
            function superCallIsRootLevelInConstructor(superCall, body) {
                const superCallParent = walkUpParenthesizedExpressions(superCall.parent);
                return isExpressionStatement(superCallParent) && superCallParent.parent === body;
            }
            function nodeImmediatelyReferencesSuperOrThis(node) {
                if (node.kind === 106 /* SuperKeyword */ || node.kind === 108 /* ThisKeyword */) {
                    return true;
                }
                if (isThisContainerOrFunctionBlock(node)) {
                    return false;
                }
                return !!forEachChild(node, nodeImmediatelyReferencesSuperOrThis);
            }
            function checkAccessorDeclaration(node) {
                if (isIdentifier(node.name) && idText(node.name) === "constructor") {
                    error(node.name, Diagnostics.Class_constructor_may_not_be_an_accessor);
                }
                addLazyDiagnostic(checkAccessorDeclarationDiagnostics);
                checkSourceElement(node.body);
                setNodeLinksForPrivateIdentifierScope(node);
                function checkAccessorDeclarationDiagnostics() {
                    if (!checkGrammarFunctionLikeDeclaration(node) && !checkGrammarAccessor(node))
                        checkGrammarComputedPropertyName(node.name);
                    checkDecorators(node);
                    checkSignatureDeclaration(node);
                    if (node.kind === 174 /* GetAccessor */) {
                        if (!(node.flags & 16777216 /* Ambient */) && nodeIsPresent(node.body) && node.flags & 256 /* HasImplicitReturn */) {
                            if (!(node.flags & 512 /* HasExplicitReturn */)) {
                                error(node.name, Diagnostics.A_get_accessor_must_return_a_value);
                            }
                        }
                    }
                    if (node.name.kind === 164 /* ComputedPropertyName */) {
                        checkComputedPropertyName(node.name);
                    }
                    if (hasBindableName(node)) {
                        const symbol = getSymbolOfDeclaration(node);
                        const getter = getDeclarationOfKind(symbol, 174 /* GetAccessor */);
                        const setter = getDeclarationOfKind(symbol, 175 /* SetAccessor */);
                        if (getter && setter && !(getNodeCheckFlags(getter) & 1 /* TypeChecked */)) {
                            getNodeLinks(getter).flags |= 1 /* TypeChecked */;
                            const getterFlags = getEffectiveModifierFlags(getter);
                            const setterFlags = getEffectiveModifierFlags(setter);
                            if ((getterFlags & 256 /* Abstract */) !== (setterFlags & 256 /* Abstract */)) {
                                error(getter.name, Diagnostics.Accessors_must_both_be_abstract_or_non_abstract);
                                error(setter.name, Diagnostics.Accessors_must_both_be_abstract_or_non_abstract);
                            }
                            if (getterFlags & 16 /* Protected */ && !(setterFlags & (16 /* Protected */ | 8 /* Private */)) || getterFlags & 8 /* Private */ && !(setterFlags & 8 /* Private */)) {
                                error(getter.name, Diagnostics.A_get_accessor_must_be_at_least_as_accessible_as_the_setter);
                                error(setter.name, Diagnostics.A_get_accessor_must_be_at_least_as_accessible_as_the_setter);
                            }
                            const getterType = getAnnotatedAccessorType(getter);
                            const setterType = getAnnotatedAccessorType(setter);
                            if (getterType && setterType) {
                                checkTypeAssignableTo(getterType, setterType, getter, Diagnostics.The_return_type_of_a_get_accessor_must_be_assignable_to_its_set_accessor_type);
                            }
                        }
                    }
                    const returnType = getTypeOfAccessors(getSymbolOfDeclaration(node));
                    if (node.kind === 174 /* GetAccessor */) {
                        checkAllCodePathsInNonVoidFunctionReturnOrThrow(node, returnType);
                    }
                }
            }
            function checkMissingDeclaration(node) {
                checkDecorators(node);
            }
            function getEffectiveTypeArgumentAtIndex(node, typeParameters, index) {
                if (node.typeArguments && index < node.typeArguments.length) {
                    return getTypeFromTypeNode(node.typeArguments[index]);
                }
                return getEffectiveTypeArguments2(node, typeParameters)[index];
            }
            function getEffectiveTypeArguments2(node, typeParameters) {
                return fillMissingTypeArguments(map(node.typeArguments, getTypeFromTypeNode), typeParameters, getMinTypeArgumentCount(typeParameters), isInJSFile(node));
            }
            function checkTypeArgumentConstraints(node, typeParameters) {
                let typeArguments;
                let mapper;
                let result = true;
                for (let i = 0; i < typeParameters.length; i++) {
                    const constraint = getConstraintOfTypeParameter(typeParameters[i]);
                    if (constraint) {
                        if (!typeArguments) {
                            typeArguments = getEffectiveTypeArguments2(node, typeParameters);
                            mapper = createTypeMapper(typeParameters, typeArguments);
                        }
                        result = result && checkTypeAssignableTo(typeArguments[i], instantiateType(constraint, mapper), node.typeArguments[i], Diagnostics.Type_0_does_not_satisfy_the_constraint_1);
                    }
                }
                return result;
            }
            function getTypeParametersForTypeAndSymbol(type, symbol) {
                if (!isErrorType(type)) {
                    return symbol.flags & 524288 /* TypeAlias */ && getSymbolLinks(symbol).typeParameters || (getObjectFlags(type) & 4 /* Reference */ ? type.target.localTypeParameters : void 0);
                }
                return void 0;
            }
            function getTypeParametersForTypeReferenceOrImport(node) {
                const type = getTypeFromTypeNode(node);
                if (!isErrorType(type)) {
                    const symbol = getNodeLinks(node).resolvedSymbol;
                    if (symbol) {
                        return getTypeParametersForTypeAndSymbol(type, symbol);
                    }
                }
                return void 0;
            }
            function checkTypeReferenceNode(node) {
                checkGrammarTypeArguments(node, node.typeArguments);
                if (node.kind === 180 /* TypeReference */ && !isInJSFile(node) && !isInJSDoc(node) && node.typeArguments && node.typeName.end !== node.typeArguments.pos) {
                    const sourceFile = getSourceFileOfNode(node);
                    if (scanTokenAtPosition(sourceFile, node.typeName.end) === 24 /* DotToken */) {
                        grammarErrorAtPos(node, skipTrivia(sourceFile.text, node.typeName.end), 1, Diagnostics.JSDoc_types_can_only_be_used_inside_documentation_comments);
                    }
                }
                forEach(node.typeArguments, checkSourceElement);
                checkTypeReferenceOrImport(node);
            }
            function checkTypeReferenceOrImport(node) {
                const type = getTypeFromTypeNode(node);
                if (!isErrorType(type)) {
                    if (node.typeArguments) {
                        addLazyDiagnostic(() => {
                            const typeParameters = getTypeParametersForTypeReferenceOrImport(node);
                            if (typeParameters) {
                                checkTypeArgumentConstraints(node, typeParameters);
                            }
                        });
                    }
                    const symbol = getNodeLinks(node).resolvedSymbol;
                    if (symbol) {
                        if (some(symbol.declarations, (d) => isTypeDeclaration(d) && !!(d.flags & 268435456 /* Deprecated */))) {
                            addDeprecatedSuggestion(getDeprecatedSuggestionNode(node), symbol.declarations, symbol.escapedName);
                        }
                    }
                }
            }
            function getTypeArgumentConstraint(node) {
                const typeReferenceNode = tryCast(node.parent, isTypeReferenceType);
                if (!typeReferenceNode)
                    return void 0;
                const typeParameters = getTypeParametersForTypeReferenceOrImport(typeReferenceNode);
                if (!typeParameters)
                    return void 0;
                const constraint = getConstraintOfTypeParameter(typeParameters[typeReferenceNode.typeArguments.indexOf(node)]);
                return constraint && instantiateType(constraint, createTypeMapper(typeParameters, getEffectiveTypeArguments2(typeReferenceNode, typeParameters)));
            }
            function checkTypeQuery(node) {
                getTypeFromTypeQueryNode(node);
            }
            function checkTypeLiteral(node) {
                forEach(node.members, checkSourceElement);
                addLazyDiagnostic(checkTypeLiteralDiagnostics);
                function checkTypeLiteralDiagnostics() {
                    const type = getTypeFromTypeLiteralOrFunctionOrConstructorTypeNode(node);
                    checkIndexConstraints(type, type.symbol);
                    checkTypeForDuplicateIndexSignatures(node);
                    checkObjectTypeForDuplicateDeclarations(node);
                }
            }
            function checkArrayType(node) {
                checkSourceElement(node.elementType);
            }
            function checkTupleType(node) {
                const elementTypes = node.elements;
                let seenOptionalElement = false;
                let seenRestElement = false;
                const hasNamedElement = some(elementTypes, isNamedTupleMember);
                for (const e of elementTypes) {
                    if (e.kind !== 199 /* NamedTupleMember */ && hasNamedElement) {
                        grammarErrorOnNode(e, Diagnostics.Tuple_members_must_all_have_names_or_all_not_have_names);
                        break;
                    }
                    const flags = getTupleElementFlags(e);
                    if (flags & 8 /* Variadic */) {
                        const type = getTypeFromTypeNode(e.type);
                        if (!isArrayLikeType(type)) {
                            error(e, Diagnostics.A_rest_element_type_must_be_an_array_type);
                            break;
                        }
                        if (isArrayType(type) || isTupleType(type) && type.target.combinedFlags & 4 /* Rest */) {
                            seenRestElement = true;
                        }
                    }
                    else if (flags & 4 /* Rest */) {
                        if (seenRestElement) {
                            grammarErrorOnNode(e, Diagnostics.A_rest_element_cannot_follow_another_rest_element);
                            break;
                        }
                        seenRestElement = true;
                    }
                    else if (flags & 2 /* Optional */) {
                        if (seenRestElement) {
                            grammarErrorOnNode(e, Diagnostics.An_optional_element_cannot_follow_a_rest_element);
                            break;
                        }
                        seenOptionalElement = true;
                    }
                    else if (seenOptionalElement) {
                        grammarErrorOnNode(e, Diagnostics.A_required_element_cannot_follow_an_optional_element);
                        break;
                    }
                }
                forEach(node.elements, checkSourceElement);
                getTypeFromTypeNode(node);
            }
            function checkUnionOrIntersectionType(node) {
                forEach(node.types, checkSourceElement);
                getTypeFromTypeNode(node);
            }
            function checkIndexedAccessIndexType(type, accessNode) {
                if (!(type.flags & 8388608 /* IndexedAccess */)) {
                    return type;
                }
                const objectType = type.objectType;
                const indexType = type.indexType;
                if (isTypeAssignableTo(indexType, getIndexType(objectType, 
                /*stringsOnly*/
                false))) {
                    if (accessNode.kind === 209 /* ElementAccessExpression */ && isAssignmentTarget(accessNode) && getObjectFlags(objectType) & 32 /* Mapped */ && getMappedTypeModifiers(objectType) & 1 /* IncludeReadonly */) {
                        error(accessNode, Diagnostics.Index_signature_in_type_0_only_permits_reading, typeToString(objectType));
                    }
                    return type;
                }
                const apparentObjectType = getApparentType(objectType);
                if (getIndexInfoOfType(apparentObjectType, numberType) && isTypeAssignableToKind(indexType, 296 /* NumberLike */)) {
                    return type;
                }
                if (isGenericObjectType(objectType)) {
                    const propertyName = getPropertyNameFromIndex(indexType, accessNode);
                    if (propertyName) {
                        const propertySymbol = forEachType(apparentObjectType, (t) => getPropertyOfType(t, propertyName));
                        if (propertySymbol && getDeclarationModifierFlagsFromSymbol(propertySymbol) & 24 /* NonPublicAccessibilityModifier */) {
                            error(accessNode, Diagnostics.Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter, unescapeLeadingUnderscores(propertyName));
                            return errorType;
                        }
                    }
                }
                error(accessNode, Diagnostics.Type_0_cannot_be_used_to_index_type_1, typeToString(indexType), typeToString(objectType));
                return errorType;
            }
            function checkIndexedAccessType(node) {
                checkSourceElement(node.objectType);
                checkSourceElement(node.indexType);
                checkIndexedAccessIndexType(getTypeFromIndexedAccessTypeNode(node), node);
            }
            function checkMappedType(node) {
                checkGrammarMappedType(node);
                checkSourceElement(node.typeParameter);
                checkSourceElement(node.nameType);
                checkSourceElement(node.type);
                if (!node.type) {
                    reportImplicitAny(node, anyType);
                }
                const type = getTypeFromMappedTypeNode(node);
                const nameType = getNameTypeFromMappedType(type);
                if (nameType) {
                    checkTypeAssignableTo(nameType, keyofConstraintType, node.nameType);
                }
                else {
                    const constraintType = getConstraintTypeFromMappedType(type);
                    checkTypeAssignableTo(constraintType, keyofConstraintType, getEffectiveConstraintOfTypeParameter(node.typeParameter));
                }
            }
            function checkGrammarMappedType(node) {
                var _a2;
                if ((_a2 = node.members) == null ? void 0 : _a2.length) {
                    return grammarErrorOnNode(node.members[0], Diagnostics.A_mapped_type_may_not_declare_properties_or_methods);
                }
            }
            function checkThisType(node) {
                getTypeFromThisTypeNode(node);
            }
            function checkTypeOperator(node) {
                checkGrammarTypeOperatorNode(node);
                checkSourceElement(node.type);
            }
            function checkConditionalType(node) {
                forEachChild(node, checkSourceElement);
            }
            function checkInferType(node) {
                if (!findAncestor(node, (n) => n.parent && n.parent.kind === 191 /* ConditionalType */ && n.parent.extendsType === n)) {
                    grammarErrorOnNode(node, Diagnostics.infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type);
                }
                checkSourceElement(node.typeParameter);
                const symbol = getSymbolOfDeclaration(node.typeParameter);
                if (symbol.declarations && symbol.declarations.length > 1) {
                    const links = getSymbolLinks(symbol);
                    if (!links.typeParametersChecked) {
                        links.typeParametersChecked = true;
                        const typeParameter = getDeclaredTypeOfTypeParameter(symbol);
                        const declarations = getDeclarationsOfKind(symbol, 165 /* TypeParameter */);
                        if (!areTypeParametersIdentical(declarations, [typeParameter], (decl) => [decl])) {
                            const name = symbolToString(symbol);
                            for (const declaration of declarations) {
                                error(declaration.name, Diagnostics.All_declarations_of_0_must_have_identical_constraints, name);
                            }
                        }
                    }
                }
                registerForUnusedIdentifiersCheck(node);
            }
            function checkTemplateLiteralType(node) {
                for (const span of node.templateSpans) {
                    checkSourceElement(span.type);
                    const type = getTypeFromTypeNode(span.type);
                    checkTypeAssignableTo(type, templateConstraintType, span.type);
                }
                getTypeFromTypeNode(node);
            }
            function checkImportType(node) {
                checkSourceElement(node.argument);
                if (node.assertions) {
                    const override = getResolutionModeOverrideForClause(node.assertions.assertClause, grammarErrorOnNode);
                    if (override) {
                        if (!isNightly()) {
                            grammarErrorOnNode(node.assertions.assertClause, Diagnostics.resolution_mode_assertions_are_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next);
                        }
                        if (getEmitModuleResolutionKind(compilerOptions) !== 3 /* Node16 */ && getEmitModuleResolutionKind(compilerOptions) !== 99 /* NodeNext */) {
                            grammarErrorOnNode(node.assertions.assertClause, Diagnostics.resolution_mode_assertions_are_only_supported_when_moduleResolution_is_node16_or_nodenext);
                        }
                    }
                }
                checkTypeReferenceOrImport(node);
            }
            function checkNamedTupleMember(node) {
                if (node.dotDotDotToken && node.questionToken) {
                    grammarErrorOnNode(node, Diagnostics.A_tuple_member_cannot_be_both_optional_and_rest);
                }
                if (node.type.kind === 187 /* OptionalType */) {
                    grammarErrorOnNode(node.type, Diagnostics.A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type);
                }
                if (node.type.kind === 188 /* RestType */) {
                    grammarErrorOnNode(node.type, Diagnostics.A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type);
                }
                checkSourceElement(node.type);
                getTypeFromTypeNode(node);
            }
            function isPrivateWithinAmbient(node) {
                return (hasEffectiveModifier(node, 8 /* Private */) || isPrivateIdentifierClassElementDeclaration(node)) && !!(node.flags & 16777216 /* Ambient */);
            }
            function getEffectiveDeclarationFlags(n, flagsToCheck) {
                let flags = getCombinedModifierFlags(n);
                if (n.parent.kind !== 261 /* InterfaceDeclaration */ && n.parent.kind !== 260 /* ClassDeclaration */ && n.parent.kind !== 228 /* ClassExpression */ && n.flags & 16777216 /* Ambient */) {
                    if (!(flags & 2 /* Ambient */) && !(isModuleBlock(n.parent) && isModuleDeclaration(n.parent.parent) && isGlobalScopeAugmentation(n.parent.parent))) {
                        flags |= 1 /* Export */;
                    }
                    flags |= 2 /* Ambient */;
                }
                return flags & flagsToCheck;
            }
            function checkFunctionOrConstructorSymbol(symbol) {
                addLazyDiagnostic(() => checkFunctionOrConstructorSymbolWorker(symbol));
            }
            function checkFunctionOrConstructorSymbolWorker(symbol) {
                function getCanonicalOverload(overloads, implementation) {
                    const implementationSharesContainerWithFirstOverload = implementation !== void 0 && implementation.parent === overloads[0].parent;
                    return implementationSharesContainerWithFirstOverload ? implementation : overloads[0];
                }
                function checkFlagAgreementBetweenOverloads(overloads, implementation, flagsToCheck2, someOverloadFlags, allOverloadFlags) {
                    const someButNotAllOverloadFlags = someOverloadFlags ^ allOverloadFlags;
                    if (someButNotAllOverloadFlags !== 0) {
                        const canonicalFlags = getEffectiveDeclarationFlags(getCanonicalOverload(overloads, implementation), flagsToCheck2);
                        forEach(overloads, (o) => {
                            const deviation = getEffectiveDeclarationFlags(o, flagsToCheck2) ^ canonicalFlags;
                            if (deviation & 1 /* Export */) {
                                error(getNameOfDeclaration(o), Diagnostics.Overload_signatures_must_all_be_exported_or_non_exported);
                            }
                            else if (deviation & 2 /* Ambient */) {
                                error(getNameOfDeclaration(o), Diagnostics.Overload_signatures_must_all_be_ambient_or_non_ambient);
                            }
                            else if (deviation & (8 /* Private */ | 16 /* Protected */)) {
                                error(getNameOfDeclaration(o) || o, Diagnostics.Overload_signatures_must_all_be_public_private_or_protected);
                            }
                            else if (deviation & 256 /* Abstract */) {
                                error(getNameOfDeclaration(o), Diagnostics.Overload_signatures_must_all_be_abstract_or_non_abstract);
                            }
                        });
                    }
                }
                function checkQuestionTokenAgreementBetweenOverloads(overloads, implementation, someHaveQuestionToken2, allHaveQuestionToken2) {
                    if (someHaveQuestionToken2 !== allHaveQuestionToken2) {
                        const canonicalHasQuestionToken = hasQuestionToken(getCanonicalOverload(overloads, implementation));
                        forEach(overloads, (o) => {
                            const deviation = hasQuestionToken(o) !== canonicalHasQuestionToken;
                            if (deviation) {
                                error(getNameOfDeclaration(o), Diagnostics.Overload_signatures_must_all_be_optional_or_required);
                            }
                        });
                    }
                }
                const flagsToCheck = 1 /* Export */ | 2 /* Ambient */ | 8 /* Private */ | 16 /* Protected */ | 256 /* Abstract */;
                let someNodeFlags = 0 /* None */;
                let allNodeFlags = flagsToCheck;
                let someHaveQuestionToken = false;
                let allHaveQuestionToken = true;
                let hasOverloads = false;
                let bodyDeclaration;
                let lastSeenNonAmbientDeclaration;
                let previousDeclaration;
                const declarations = symbol.declarations;
                const isConstructor = (symbol.flags & 16384 /* Constructor */) !== 0;
                function reportImplementationExpectedError(node) {
                    if (node.name && nodeIsMissing(node.name)) {
                        return;
                    }
                    let seen = false;
                    const subsequentNode = forEachChild(node.parent, (c) => {
                        if (seen) {
                            return c;
                        }
                        else {
                            seen = c === node;
                        }
                    });
                    if (subsequentNode && subsequentNode.pos === node.end) {
                        if (subsequentNode.kind === node.kind) {
                            const errorNode2 = subsequentNode.name || subsequentNode;
                            const subsequentName = subsequentNode.name;
                            if (node.name && subsequentName && // both are private identifiers
                                (isPrivateIdentifier(node.name) && isPrivateIdentifier(subsequentName) && node.name.escapedText === subsequentName.escapedText || // Both are computed property names
                                    // TODO: GH#17345: These are methods, so handle computed name case. (`Always allowing computed property names is *not* the correct behavior!)
                                    isComputedPropertyName(node.name) && isComputedPropertyName(subsequentName) || // Both are literal property names that are the same.
                                    isPropertyNameLiteral(node.name) && isPropertyNameLiteral(subsequentName) && getEscapedTextOfIdentifierOrLiteral(node.name) === getEscapedTextOfIdentifierOrLiteral(subsequentName))) {
                                const reportError = (node.kind === 171 /* MethodDeclaration */ || node.kind === 170 /* MethodSignature */) && isStatic(node) !== isStatic(subsequentNode);
                                if (reportError) {
                                    const diagnostic = isStatic(node) ? Diagnostics.Function_overload_must_be_static : Diagnostics.Function_overload_must_not_be_static;
                                    error(errorNode2, diagnostic);
                                }
                                return;
                            }
                            if (nodeIsPresent(subsequentNode.body)) {
                                error(errorNode2, Diagnostics.Function_implementation_name_must_be_0, declarationNameToString(node.name));
                                return;
                            }
                        }
                    }
                    const errorNode = node.name || node;
                    if (isConstructor) {
                        error(errorNode, Diagnostics.Constructor_implementation_is_missing);
                    }
                    else {
                        if (hasSyntacticModifier(node, 256 /* Abstract */)) {
                            error(errorNode, Diagnostics.All_declarations_of_an_abstract_method_must_be_consecutive);
                        }
                        else {
                            error(errorNode, Diagnostics.Function_implementation_is_missing_or_not_immediately_following_the_declaration);
                        }
                    }
                }
                let duplicateFunctionDeclaration = false;
                let multipleConstructorImplementation = false;
                let hasNonAmbientClass = false;
                const functionDeclarations = [];
                if (declarations) {
                    for (const current of declarations) {
                        const node = current;
                        const inAmbientContext = node.flags & 16777216 /* Ambient */;
                        const inAmbientContextOrInterface = node.parent && (node.parent.kind === 261 /* InterfaceDeclaration */ || node.parent.kind === 184 /* TypeLiteral */) || inAmbientContext;
                        if (inAmbientContextOrInterface) {
                            previousDeclaration = void 0;
                        }
                        if ((node.kind === 260 /* ClassDeclaration */ || node.kind === 228 /* ClassExpression */) && !inAmbientContext) {
                            hasNonAmbientClass = true;
                        }
                        if (node.kind === 259 /* FunctionDeclaration */ || node.kind === 171 /* MethodDeclaration */ || node.kind === 170 /* MethodSignature */ || node.kind === 173 /* Constructor */) {
                            functionDeclarations.push(node);
                            const currentNodeFlags = getEffectiveDeclarationFlags(node, flagsToCheck);
                            someNodeFlags |= currentNodeFlags;
                            allNodeFlags &= currentNodeFlags;
                            someHaveQuestionToken = someHaveQuestionToken || hasQuestionToken(node);
                            allHaveQuestionToken = allHaveQuestionToken && hasQuestionToken(node);
                            const bodyIsPresent = nodeIsPresent(node.body);
                            if (bodyIsPresent && bodyDeclaration) {
                                if (isConstructor) {
                                    multipleConstructorImplementation = true;
                                }
                                else {
                                    duplicateFunctionDeclaration = true;
                                }
                            }
                            else if ((previousDeclaration == null ? void 0 : previousDeclaration.parent) === node.parent && previousDeclaration.end !== node.pos) {
                                reportImplementationExpectedError(previousDeclaration);
                            }
                            if (bodyIsPresent) {
                                if (!bodyDeclaration) {
                                    bodyDeclaration = node;
                                }
                            }
                            else {
                                hasOverloads = true;
                            }
                            previousDeclaration = node;
                            if (!inAmbientContextOrInterface) {
                                lastSeenNonAmbientDeclaration = node;
                            }
                        }
                        if (isInJSFile(current) && isFunctionLike(current) && current.jsDoc) {
                            for (const node2 of current.jsDoc) {
                                if (node2.tags) {
                                    for (const tag of node2.tags) {
                                        if (isJSDocOverloadTag(tag)) {
                                            hasOverloads = true;
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
                if (multipleConstructorImplementation) {
                    forEach(functionDeclarations, (declaration) => {
                        error(declaration, Diagnostics.Multiple_constructor_implementations_are_not_allowed);
                    });
                }
                if (duplicateFunctionDeclaration) {
                    forEach(functionDeclarations, (declaration) => {
                        error(getNameOfDeclaration(declaration) || declaration, Diagnostics.Duplicate_function_implementation);
                    });
                }
                if (hasNonAmbientClass && !isConstructor && symbol.flags & 16 /* Function */ && declarations) {
                    const relatedDiagnostics = filter(declarations, (d) => d.kind === 260 /* ClassDeclaration */).map((d) => createDiagnosticForNode(d, Diagnostics.Consider_adding_a_declare_modifier_to_this_class));
                    forEach(declarations, (declaration) => {
                        const diagnostic = declaration.kind === 260 /* ClassDeclaration */ ? Diagnostics.Class_declaration_cannot_implement_overload_list_for_0 : declaration.kind === 259 /* FunctionDeclaration */ ? Diagnostics.Function_with_bodies_can_only_merge_with_classes_that_are_ambient : void 0;
                        if (diagnostic) {
                            addRelatedInfo(error(getNameOfDeclaration(declaration) || declaration, diagnostic, symbolName(symbol)), ...relatedDiagnostics);
                        }
                    });
                }
                if (lastSeenNonAmbientDeclaration && !lastSeenNonAmbientDeclaration.body && !hasSyntacticModifier(lastSeenNonAmbientDeclaration, 256 /* Abstract */) && !lastSeenNonAmbientDeclaration.questionToken) {
                    reportImplementationExpectedError(lastSeenNonAmbientDeclaration);
                }
                if (hasOverloads) {
                    if (declarations) {
                        checkFlagAgreementBetweenOverloads(declarations, bodyDeclaration, flagsToCheck, someNodeFlags, allNodeFlags);
                        checkQuestionTokenAgreementBetweenOverloads(declarations, bodyDeclaration, someHaveQuestionToken, allHaveQuestionToken);
                    }
                    if (bodyDeclaration) {
                        const signatures = getSignaturesOfSymbol(symbol);
                        const bodySignature = getSignatureFromDeclaration(bodyDeclaration);
                        for (const signature of signatures) {
                            if (!isImplementationCompatibleWithOverload(bodySignature, signature)) {
                                const errorNode = signature.declaration && isJSDocSignature(signature.declaration) ? signature.declaration.parent.tagName : signature.declaration;
                                addRelatedInfo(error(errorNode, Diagnostics.This_overload_signature_is_not_compatible_with_its_implementation_signature), createDiagnosticForNode(bodyDeclaration, Diagnostics.The_implementation_signature_is_declared_here));
                                break;
                            }
                        }
                    }
                }
            }
            function checkExportsOnMergedDeclarations(node) {
                addLazyDiagnostic(() => checkExportsOnMergedDeclarationsWorker(node));
            }
            function checkExportsOnMergedDeclarationsWorker(node) {
                let symbol = node.localSymbol;
                if (!symbol) {
                    symbol = getSymbolOfDeclaration(node);
                    if (!symbol.exportSymbol) {
                        return;
                    }
                }
                if (getDeclarationOfKind(symbol, node.kind) !== node) {
                    return;
                }
                let exportedDeclarationSpaces = 0 /* None */;
                let nonExportedDeclarationSpaces = 0 /* None */;
                let defaultExportedDeclarationSpaces = 0 /* None */;
                for (const d of symbol.declarations) {
                    const declarationSpaces = getDeclarationSpaces(d);
                    const effectiveDeclarationFlags = getEffectiveDeclarationFlags(d, 1 /* Export */ | 1024 /* Default */);
                    if (effectiveDeclarationFlags & 1 /* Export */) {
                        if (effectiveDeclarationFlags & 1024 /* Default */) {
                            defaultExportedDeclarationSpaces |= declarationSpaces;
                        }
                        else {
                            exportedDeclarationSpaces |= declarationSpaces;
                        }
                    }
                    else {
                        nonExportedDeclarationSpaces |= declarationSpaces;
                    }
                }
                const nonDefaultExportedDeclarationSpaces = exportedDeclarationSpaces | nonExportedDeclarationSpaces;
                const commonDeclarationSpacesForExportsAndLocals = exportedDeclarationSpaces & nonExportedDeclarationSpaces;
                const commonDeclarationSpacesForDefaultAndNonDefault = defaultExportedDeclarationSpaces & nonDefaultExportedDeclarationSpaces;
                if (commonDeclarationSpacesForExportsAndLocals || commonDeclarationSpacesForDefaultAndNonDefault) {
                    for (const d of symbol.declarations) {
                        const declarationSpaces = getDeclarationSpaces(d);
                        const name = getNameOfDeclaration(d);
                        if (declarationSpaces & commonDeclarationSpacesForDefaultAndNonDefault) {
                            error(name, Diagnostics.Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead, declarationNameToString(name));
                        }
                        else if (declarationSpaces & commonDeclarationSpacesForExportsAndLocals) {
                            error(name, Diagnostics.Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local, declarationNameToString(name));
                        }
                    }
                }
                function getDeclarationSpaces(decl) {
                    let d = decl;
                    switch (d.kind) {
                        case 261 /* InterfaceDeclaration */:
                        case 262 /* TypeAliasDeclaration */:
                        case 349 /* JSDocTypedefTag */:
                        case 341 /* JSDocCallbackTag */:
                        case 343 /* JSDocEnumTag */:
                            return 2 /* ExportType */;
                        case 264 /* ModuleDeclaration */:
                            return isAmbientModule(d) || getModuleInstanceState(d) !== 0 /* NonInstantiated */ ? 4 /* ExportNamespace */ | 1 /* ExportValue */ : 4 /* ExportNamespace */;
                        case 260 /* ClassDeclaration */:
                        case 263 /* EnumDeclaration */:
                        case 302 /* EnumMember */:
                            return 2 /* ExportType */ | 1 /* ExportValue */;
                        case 308 /* SourceFile */:
                            return 2 /* ExportType */ | 1 /* ExportValue */ | 4 /* ExportNamespace */;
                        case 274 /* ExportAssignment */:
                        case 223 /* BinaryExpression */:
                            const node2 = d;
                            const expression = isExportAssignment(node2) ? node2.expression : node2.right;
                            if (!isEntityNameExpression(expression)) {
                                return 1 /* ExportValue */;
                            }
                            d = expression;
                        case 268 /* ImportEqualsDeclaration */:
                        case 271 /* NamespaceImport */:
                        case 270 /* ImportClause */:
                            let result = 0 /* None */;
                            const target = resolveAlias(getSymbolOfDeclaration(d));
                            forEach(target.declarations, (d2) => {
                                result |= getDeclarationSpaces(d2);
                            });
                            return result;
                        case 257 /* VariableDeclaration */:
                        case 205 /* BindingElement */:
                        case 259 /* FunctionDeclaration */:
                        case 273 /* ImportSpecifier */:
                        case 79 /* Identifier */:
                            return 1 /* ExportValue */;
                        case 170 /* MethodSignature */:
                        case 168 /* PropertySignature */:
                            return 2 /* ExportType */;
                        default:
                            return Debug.failBadSyntaxKind(d);
                    }
                }
            }
            function getAwaitedTypeOfPromise(type, errorNode, diagnosticMessage, arg0) {
                const promisedType = getPromisedTypeOfPromise(type, errorNode);
                return promisedType && getAwaitedType(promisedType, errorNode, diagnosticMessage, arg0);
            }
            function getPromisedTypeOfPromise(type, errorNode, thisTypeForErrorOut) {
                if (isTypeAny(type)) {
                    return void 0;
                }
                const typeAsPromise = type;
                if (typeAsPromise.promisedTypeOfPromise) {
                    return typeAsPromise.promisedTypeOfPromise;
                }
                if (isReferenceToType2(type, getGlobalPromiseType(
                /*reportErrors*/
                false))) {
                    return typeAsPromise.promisedTypeOfPromise = getTypeArguments(type)[0];
                }
                if (allTypesAssignableToKind(getBaseConstraintOrType(type), 134348796 /* Primitive */ | 131072 /* Never */)) {
                    return void 0;
                }
                const thenFunction = getTypeOfPropertyOfType(type, "then");
                if (isTypeAny(thenFunction)) {
                    return void 0;
                }
                const thenSignatures = thenFunction ? getSignaturesOfType(thenFunction, 0 /* Call */) : emptyArray;
                if (thenSignatures.length === 0) {
                    if (errorNode) {
                        error(errorNode, Diagnostics.A_promise_must_have_a_then_method);
                    }
                    return void 0;
                }
                let thisTypeForError;
                let candidates;
                for (const thenSignature of thenSignatures) {
                    const thisType = getThisTypeOfSignature(thenSignature);
                    if (thisType && thisType !== voidType && !isTypeRelatedTo(type, thisType, subtypeRelation)) {
                        thisTypeForError = thisType;
                    }
                    else {
                        candidates = append(candidates, thenSignature);
                    }
                }
                if (!candidates) {
                    Debug.assertIsDefined(thisTypeForError);
                    if (thisTypeForErrorOut) {
                        thisTypeForErrorOut.value = thisTypeForError;
                    }
                    if (errorNode) {
                        error(errorNode, Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1, typeToString(type), typeToString(thisTypeForError));
                    }
                    return void 0;
                }
                const onfulfilledParameterType = getTypeWithFacts(getUnionType(map(candidates, getTypeOfFirstParameterOfSignature)), 2097152 /* NEUndefinedOrNull */);
                if (isTypeAny(onfulfilledParameterType)) {
                    return void 0;
                }
                const onfulfilledParameterSignatures = getSignaturesOfType(onfulfilledParameterType, 0 /* Call */);
                if (onfulfilledParameterSignatures.length === 0) {
                    if (errorNode) {
                        error(errorNode, Diagnostics.The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback);
                    }
                    return void 0;
                }
                return typeAsPromise.promisedTypeOfPromise = getUnionType(map(onfulfilledParameterSignatures, getTypeOfFirstParameterOfSignature), 2 /* Subtype */);
            }
            function checkAwaitedType(type, withAlias, errorNode, diagnosticMessage, arg0) {
                const awaitedType = withAlias ? getAwaitedType(type, errorNode, diagnosticMessage, arg0) : getAwaitedTypeNoAlias(type, errorNode, diagnosticMessage, arg0);
                return awaitedType || errorType;
            }
            function isThenableType(type) {
                if (allTypesAssignableToKind(getBaseConstraintOrType(type), 134348796 /* Primitive */ | 131072 /* Never */)) {
                    return false;
                }
                const thenFunction = getTypeOfPropertyOfType(type, "then");
                return !!thenFunction && getSignaturesOfType(getTypeWithFacts(thenFunction, 2097152 /* NEUndefinedOrNull */), 0 /* Call */).length > 0;
            }
            function isAwaitedTypeInstantiation(type) {
                var _a2;
                if (type.flags & 16777216 /* Conditional */) {
                    const awaitedSymbol = getGlobalAwaitedSymbol(
                    /*reportErrors*/
                    false);
                    return !!awaitedSymbol && type.aliasSymbol === awaitedSymbol && ((_a2 = type.aliasTypeArguments) == null ? void 0 : _a2.length) === 1;
                }
                return false;
            }
            function unwrapAwaitedType(type) {
                return type.flags & 1048576 /* Union */ ? mapType(type, unwrapAwaitedType) : isAwaitedTypeInstantiation(type) ? type.aliasTypeArguments[0] : type;
            }
            function isAwaitedTypeNeeded(type) {
                if (isTypeAny(type) || isAwaitedTypeInstantiation(type)) {
                    return false;
                }
                if (isGenericObjectType(type)) {
                    const baseConstraint = getBaseConstraintOfType(type);
                    if (baseConstraint ? baseConstraint.flags & 3 /* AnyOrUnknown */ || isEmptyObjectType(baseConstraint) || someType(baseConstraint, isThenableType) : maybeTypeOfKind(type, 8650752 /* TypeVariable */)) {
                        return true;
                    }
                }
                return false;
            }
            function tryCreateAwaitedType(type) {
                const awaitedSymbol = getGlobalAwaitedSymbol(
                /*reportErrors*/
                true);
                if (awaitedSymbol) {
                    return getTypeAliasInstantiation(awaitedSymbol, [unwrapAwaitedType(type)]);
                }
                return void 0;
            }
            function createAwaitedTypeIfNeeded(type) {
                if (isAwaitedTypeNeeded(type)) {
                    const awaitedType = tryCreateAwaitedType(type);
                    if (awaitedType) {
                        return awaitedType;
                    }
                }
                Debug.assert(isAwaitedTypeInstantiation(type) || getPromisedTypeOfPromise(type) === void 0, "type provided should not be a non-generic 'promise'-like.");
                return type;
            }
            function getAwaitedType(type, errorNode, diagnosticMessage, arg0) {
                const awaitedType = getAwaitedTypeNoAlias(type, errorNode, diagnosticMessage, arg0);
                return awaitedType && createAwaitedTypeIfNeeded(awaitedType);
            }
            function getAwaitedTypeNoAlias(type, errorNode, diagnosticMessage, arg0) {
                if (isTypeAny(type)) {
                    return type;
                }
                if (isAwaitedTypeInstantiation(type)) {
                    return type;
                }
                const typeAsAwaitable = type;
                if (typeAsAwaitable.awaitedTypeOfType) {
                    return typeAsAwaitable.awaitedTypeOfType;
                }
                if (type.flags & 1048576 /* Union */) {
                    if (awaitedTypeStack.lastIndexOf(type.id) >= 0) {
                        if (errorNode) {
                            error(errorNode, Diagnostics.Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method);
                        }
                        return void 0;
                    }
                    const mapper = errorNode ? (constituentType) => getAwaitedTypeNoAlias(constituentType, errorNode, diagnosticMessage, arg0) : getAwaitedTypeNoAlias;
                    awaitedTypeStack.push(type.id);
                    const mapped = mapType(type, mapper);
                    awaitedTypeStack.pop();
                    return typeAsAwaitable.awaitedTypeOfType = mapped;
                }
                if (isAwaitedTypeNeeded(type)) {
                    return typeAsAwaitable.awaitedTypeOfType = type;
                }
                const thisTypeForErrorOut = { value: void 0 };
                const promisedType = getPromisedTypeOfPromise(type, 
                /*errorNode*/
                void 0, thisTypeForErrorOut);
                if (promisedType) {
                    if (type.id === promisedType.id || awaitedTypeStack.lastIndexOf(promisedType.id) >= 0) {
                        if (errorNode) {
                            error(errorNode, Diagnostics.Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method);
                        }
                        return void 0;
                    }
                    awaitedTypeStack.push(type.id);
                    const awaitedType = getAwaitedTypeNoAlias(promisedType, errorNode, diagnosticMessage, arg0);
                    awaitedTypeStack.pop();
                    if (!awaitedType) {
                        return void 0;
                    }
                    return typeAsAwaitable.awaitedTypeOfType = awaitedType;
                }
                if (isThenableType(type)) {
                    if (errorNode) {
                        Debug.assertIsDefined(diagnosticMessage);
                        let chain;
                        if (thisTypeForErrorOut.value) {
                            chain = chainDiagnosticMessages(chain, Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1, typeToString(type), typeToString(thisTypeForErrorOut.value));
                        }
                        chain = chainDiagnosticMessages(chain, diagnosticMessage, arg0);
                        diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(errorNode), errorNode, chain));
                    }
                    return void 0;
                }
                return typeAsAwaitable.awaitedTypeOfType = type;
            }
            function checkAsyncFunctionReturnType(node, returnTypeNode) {
                const returnType = getTypeFromTypeNode(returnTypeNode);
                if (languageVersion >= 2 /* ES2015 */) {
                    if (isErrorType(returnType)) {
                        return;
                    }
                    const globalPromiseType = getGlobalPromiseType(
                    /*reportErrors*/
                    true);
                    if (globalPromiseType !== emptyGenericType && !isReferenceToType2(returnType, globalPromiseType)) {
                        error(returnTypeNode, Diagnostics.The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0, typeToString(getAwaitedTypeNoAlias(returnType) || voidType));
                        return;
                    }
                }
                else {
                    markTypeNodeAsReferenced(returnTypeNode);
                    if (isErrorType(returnType)) {
                        return;
                    }
                    const promiseConstructorName = getEntityNameFromTypeNode(returnTypeNode);
                    if (promiseConstructorName === void 0) {
                        error(returnTypeNode, Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value, typeToString(returnType));
                        return;
                    }
                    const promiseConstructorSymbol = resolveEntityName(promiseConstructorName, 111551 /* Value */, 
                    /*ignoreErrors*/
                    true);
                    const promiseConstructorType = promiseConstructorSymbol ? getTypeOfSymbol(promiseConstructorSymbol) : errorType;
                    if (isErrorType(promiseConstructorType)) {
                        if (promiseConstructorName.kind === 79 /* Identifier */ && promiseConstructorName.escapedText === "Promise" && getTargetType(returnType) === getGlobalPromiseType(
                        /*reportErrors*/
                        false)) {
                            error(returnTypeNode, Diagnostics.An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option);
                        }
                        else {
                            error(returnTypeNode, Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value, entityNameToString(promiseConstructorName));
                        }
                        return;
                    }
                    const globalPromiseConstructorLikeType = getGlobalPromiseConstructorLikeType(
                    /*reportErrors*/
                    true);
                    if (globalPromiseConstructorLikeType === emptyObjectType) {
                        error(returnTypeNode, Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value, entityNameToString(promiseConstructorName));
                        return;
                    }
                    if (!checkTypeAssignableTo(promiseConstructorType, globalPromiseConstructorLikeType, returnTypeNode, Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value)) {
                        return;
                    }
                    const rootName = promiseConstructorName && getFirstIdentifier(promiseConstructorName);
                    const collidingSymbol = getSymbol2(node.locals, rootName.escapedText, 111551 /* Value */);
                    if (collidingSymbol) {
                        error(collidingSymbol.valueDeclaration, Diagnostics.Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions, idText(rootName), entityNameToString(promiseConstructorName));
                        return;
                    }
                }
                checkAwaitedType(returnType, 
                /*withAlias*/
                false, node, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);
            }
            function checkDecorator(node) {
                const signature = getResolvedSignature(node);
                checkDeprecatedSignature(signature, node);
                const returnType = getReturnTypeOfSignature(signature);
                if (returnType.flags & 1 /* Any */) {
                    return;
                }
                const decoratorSignature = getDecoratorCallSignature(node);
                if (!(decoratorSignature == null ? void 0 : decoratorSignature.resolvedReturnType))
                    return;
                let headMessage;
                const expectedReturnType = decoratorSignature.resolvedReturnType;
                switch (node.parent.kind) {
                    case 260 /* ClassDeclaration */:
                    case 228 /* ClassExpression */:
                        headMessage = Diagnostics.Decorator_function_return_type_0_is_not_assignable_to_type_1;
                        break;
                    case 169 /* PropertyDeclaration */:
                        if (!legacyDecorators) {
                            headMessage = Diagnostics.Decorator_function_return_type_0_is_not_assignable_to_type_1;
                            break;
                        }
                    case 166 /* Parameter */:
                        headMessage = Diagnostics.Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any;
                        break;
                    case 171 /* MethodDeclaration */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        headMessage = Diagnostics.Decorator_function_return_type_0_is_not_assignable_to_type_1;
                        break;
                    default:
                        return Debug.failBadSyntaxKind(node.parent);
                }
                checkTypeAssignableTo(returnType, expectedReturnType, node.expression, headMessage);
            }
            function createCallSignature(typeParameters, thisParameter, parameters, returnType, typePredicate, minArgumentCount = parameters.length, flags = 0 /* None */) {
                const decl = factory.createFunctionTypeNode(
                /*typeParameters*/
                void 0, emptyArray, factory.createKeywordTypeNode(131 /* AnyKeyword */));
                return createSignature(decl, typeParameters, thisParameter, parameters, returnType, typePredicate, minArgumentCount, flags);
            }
            function createFunctionType(typeParameters, thisParameter, parameters, returnType, typePredicate, minArgumentCount, flags) {
                const signature = createCallSignature(typeParameters, thisParameter, parameters, returnType, typePredicate, minArgumentCount, flags);
                return getOrCreateTypeFromSignature(signature);
            }
            function createGetterFunctionType(type) {
                return createFunctionType(
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, emptyArray, type);
            }
            function createSetterFunctionType(type) {
                const valueParam = createParameter("value", type);
                return createFunctionType(
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, [valueParam], voidType);
            }
            function markTypeNodeAsReferenced(node) {
                markEntityNameOrEntityExpressionAsReference(node && getEntityNameFromTypeNode(node), 
                /*forDecoratorMetadata*/
                false);
            }
            function markEntityNameOrEntityExpressionAsReference(typeName, forDecoratorMetadata) {
                if (!typeName)
                    return;
                const rootName = getFirstIdentifier(typeName);
                const meaning = (typeName.kind === 79 /* Identifier */ ? 788968 /* Type */ : 1920 /* Namespace */) | 2097152 /* Alias */;
                const rootSymbol = resolveName(rootName, rootName.escapedText, meaning, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isReference*/
                true);
                if (rootSymbol && rootSymbol.flags & 2097152 /* Alias */) {
                    if (!compilerOptions.verbatimModuleSyntax && symbolIsValue(rootSymbol) && !isConstEnumOrConstEnumOnlyModule(resolveAlias(rootSymbol)) && !getTypeOnlyAliasDeclaration(rootSymbol)) {
                        markAliasSymbolAsReferenced(rootSymbol);
                    }
                    else if (forDecoratorMetadata && getIsolatedModules(compilerOptions) && getEmitModuleKind(compilerOptions) >= 5 /* ES2015 */ && !symbolIsValue(rootSymbol) && !some(rootSymbol.declarations, isTypeOnlyImportOrExportDeclaration)) {
                        const diag2 = error(typeName, Diagnostics.A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_when_isolatedModules_and_emitDecoratorMetadata_are_enabled);
                        const aliasDeclaration = find(rootSymbol.declarations || emptyArray, isAliasSymbolDeclaration2);
                        if (aliasDeclaration) {
                            addRelatedInfo(diag2, createDiagnosticForNode(aliasDeclaration, Diagnostics._0_was_imported_here, idText(rootName)));
                        }
                    }
                }
            }
            function markDecoratorMedataDataTypeNodeAsReferenced(node) {
                const entityName = getEntityNameForDecoratorMetadata(node);
                if (entityName && isEntityName(entityName)) {
                    markEntityNameOrEntityExpressionAsReference(entityName, 
                    /*forDecoratorMetadata*/
                    true);
                }
            }
            function getEntityNameForDecoratorMetadata(node) {
                if (node) {
                    switch (node.kind) {
                        case 190 /* IntersectionType */:
                        case 189 /* UnionType */:
                            return getEntityNameForDecoratorMetadataFromTypeList(node.types);
                        case 191 /* ConditionalType */:
                            return getEntityNameForDecoratorMetadataFromTypeList([node.trueType, node.falseType]);
                        case 193 /* ParenthesizedType */:
                        case 199 /* NamedTupleMember */:
                            return getEntityNameForDecoratorMetadata(node.type);
                        case 180 /* TypeReference */:
                            return node.typeName;
                    }
                }
            }
            function getEntityNameForDecoratorMetadataFromTypeList(types) {
                let commonEntityName;
                for (let typeNode of types) {
                    while (typeNode.kind === 193 /* ParenthesizedType */ || typeNode.kind === 199 /* NamedTupleMember */) {
                        typeNode = typeNode.type;
                    }
                    if (typeNode.kind === 144 /* NeverKeyword */) {
                        continue;
                    }
                    if (!strictNullChecks && (typeNode.kind === 198 /* LiteralType */ && typeNode.literal.kind === 104 /* NullKeyword */ || typeNode.kind === 155 /* UndefinedKeyword */)) {
                        continue;
                    }
                    const individualEntityName = getEntityNameForDecoratorMetadata(typeNode);
                    if (!individualEntityName) {
                        return void 0;
                    }
                    if (commonEntityName) {
                        if (!isIdentifier(commonEntityName) || !isIdentifier(individualEntityName) || commonEntityName.escapedText !== individualEntityName.escapedText) {
                            return void 0;
                        }
                    }
                    else {
                        commonEntityName = individualEntityName;
                    }
                }
                return commonEntityName;
            }
            function getParameterTypeNodeForDecoratorCheck(node) {
                const typeNode = getEffectiveTypeAnnotationNode(node);
                return isRestParameter(node) ? getRestParameterElementType(typeNode) : typeNode;
            }
            function checkDecorators(node) {
                if (!canHaveDecorators(node) || !hasDecorators(node) || !node.modifiers || !nodeCanBeDecorated(legacyDecorators, node, node.parent, node.parent.parent)) {
                    return;
                }
                const firstDecorator = find(node.modifiers, isDecorator);
                if (!firstDecorator) {
                    return;
                }
                if (legacyDecorators) {
                    checkExternalEmitHelpers(firstDecorator, 8 /* Decorate */);
                    if (node.kind === 166 /* Parameter */) {
                        checkExternalEmitHelpers(firstDecorator, 32 /* Param */);
                    }
                }
                else if (languageVersion < 99 /* ESNext */) {
                    checkExternalEmitHelpers(firstDecorator, 8 /* ESDecorateAndRunInitializers */);
                    if (isClassDeclaration(node)) {
                        if (!node.name) {
                            checkExternalEmitHelpers(firstDecorator, 8388608 /* SetFunctionName */);
                        }
                        else {
                            const member = getFirstTransformableStaticClassElement(node);
                            if (member) {
                                checkExternalEmitHelpers(firstDecorator, 8388608 /* SetFunctionName */);
                            }
                        }
                    }
                    else if (!isClassExpression(node)) {
                        if (isPrivateIdentifier(node.name) && (isMethodDeclaration(node) || isAccessor(node) || isAutoAccessorPropertyDeclaration(node))) {
                            checkExternalEmitHelpers(firstDecorator, 8388608 /* SetFunctionName */);
                        }
                        if (isComputedPropertyName(node.name)) {
                            checkExternalEmitHelpers(firstDecorator, 16777216 /* PropKey */);
                        }
                    }
                }
                if (compilerOptions.emitDecoratorMetadata) {
                    checkExternalEmitHelpers(firstDecorator, 16 /* Metadata */);
                    switch (node.kind) {
                        case 260 /* ClassDeclaration */:
                            const constructor = getFirstConstructorWithBody(node);
                            if (constructor) {
                                for (const parameter of constructor.parameters) {
                                    markDecoratorMedataDataTypeNodeAsReferenced(getParameterTypeNodeForDecoratorCheck(parameter));
                                }
                            }
                            break;
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            const otherKind = node.kind === 174 /* GetAccessor */ ? 175 /* SetAccessor */ : 174 /* GetAccessor */;
                            const otherAccessor = getDeclarationOfKind(getSymbolOfDeclaration(node), otherKind);
                            markDecoratorMedataDataTypeNodeAsReferenced(getAnnotatedAccessorTypeNode(node) || otherAccessor && getAnnotatedAccessorTypeNode(otherAccessor));
                            break;
                        case 171 /* MethodDeclaration */:
                            for (const parameter of node.parameters) {
                                markDecoratorMedataDataTypeNodeAsReferenced(getParameterTypeNodeForDecoratorCheck(parameter));
                            }
                            markDecoratorMedataDataTypeNodeAsReferenced(getEffectiveReturnTypeNode(node));
                            break;
                        case 169 /* PropertyDeclaration */:
                            markDecoratorMedataDataTypeNodeAsReferenced(getEffectiveTypeAnnotationNode(node));
                            break;
                        case 166 /* Parameter */:
                            markDecoratorMedataDataTypeNodeAsReferenced(getParameterTypeNodeForDecoratorCheck(node));
                            const containingSignature = node.parent;
                            for (const parameter of containingSignature.parameters) {
                                markDecoratorMedataDataTypeNodeAsReferenced(getParameterTypeNodeForDecoratorCheck(parameter));
                            }
                            break;
                    }
                }
                for (const modifier of node.modifiers) {
                    if (isDecorator(modifier)) {
                        checkDecorator(modifier);
                    }
                }
            }
            function checkFunctionDeclaration(node) {
                addLazyDiagnostic(checkFunctionDeclarationDiagnostics);
                function checkFunctionDeclarationDiagnostics() {
                    checkFunctionOrMethodDeclaration(node);
                    checkGrammarForGenerator(node);
                    checkCollisionsForDeclarationName(node, node.name);
                }
            }
            function checkJSDocTypeAliasTag(node) {
                if (!node.typeExpression) {
                    error(node.name, Diagnostics.JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags);
                }
                if (node.name) {
                    checkTypeNameIsReserved(node.name, Diagnostics.Type_alias_name_cannot_be_0);
                }
                checkSourceElement(node.typeExpression);
                checkTypeParameters(getEffectiveTypeParameterDeclarations(node));
            }
            function checkJSDocTemplateTag(node) {
                checkSourceElement(node.constraint);
                for (const tp of node.typeParameters) {
                    checkSourceElement(tp);
                }
            }
            function checkJSDocTypeTag(node) {
                checkSourceElement(node.typeExpression);
            }
            function checkJSDocSatisfiesTag(node) {
                checkSourceElement(node.typeExpression);
                const host2 = getEffectiveJSDocHost(node);
                if (host2) {
                    const tags = getAllJSDocTags(host2, isJSDocSatisfiesTag);
                    if (length(tags) > 1) {
                        for (let i = 1; i < length(tags); i++) {
                            const tagName = tags[i].tagName;
                            error(tagName, Diagnostics._0_tag_already_specified, idText(tagName));
                        }
                    }
                }
            }
            function checkJSDocLinkLikeTag(node) {
                if (node.name) {
                    resolveJSDocMemberName(node.name, 
                    /*ignoreErrors*/
                    true);
                }
            }
            function checkJSDocParameterTag(node) {
                checkSourceElement(node.typeExpression);
            }
            function checkJSDocPropertyTag(node) {
                checkSourceElement(node.typeExpression);
            }
            function checkJSDocFunctionType(node) {
                addLazyDiagnostic(checkJSDocFunctionTypeImplicitAny);
                checkSignatureDeclaration(node);
                function checkJSDocFunctionTypeImplicitAny() {
                    if (!node.type && !isJSDocConstructSignature(node)) {
                        reportImplicitAny(node, anyType);
                    }
                }
            }
            function checkJSDocImplementsTag(node) {
                const classLike = getEffectiveJSDocHost(node);
                if (!classLike || !isClassDeclaration(classLike) && !isClassExpression(classLike)) {
                    error(classLike, Diagnostics.JSDoc_0_is_not_attached_to_a_class, idText(node.tagName));
                }
            }
            function checkJSDocAugmentsTag(node) {
                const classLike = getEffectiveJSDocHost(node);
                if (!classLike || !isClassDeclaration(classLike) && !isClassExpression(classLike)) {
                    error(classLike, Diagnostics.JSDoc_0_is_not_attached_to_a_class, idText(node.tagName));
                    return;
                }
                const augmentsTags = getJSDocTags(classLike).filter(isJSDocAugmentsTag);
                Debug.assert(augmentsTags.length > 0);
                if (augmentsTags.length > 1) {
                    error(augmentsTags[1], Diagnostics.Class_declarations_cannot_have_more_than_one_augments_or_extends_tag);
                }
                const name = getIdentifierFromEntityNameExpression(node.class.expression);
                const extend2 = getClassExtendsHeritageElement(classLike);
                if (extend2) {
                    const className = getIdentifierFromEntityNameExpression(extend2.expression);
                    if (className && name.escapedText !== className.escapedText) {
                        error(name, Diagnostics.JSDoc_0_1_does_not_match_the_extends_2_clause, idText(node.tagName), idText(name), idText(className));
                    }
                }
            }
            function checkJSDocAccessibilityModifiers(node) {
                const host2 = getJSDocHost(node);
                if (host2 && isPrivateIdentifierClassElementDeclaration(host2)) {
                    error(node, Diagnostics.An_accessibility_modifier_cannot_be_used_with_a_private_identifier);
                }
            }
            function getIdentifierFromEntityNameExpression(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        return node;
                    case 208 /* PropertyAccessExpression */:
                        return node.name;
                    default:
                        return void 0;
                }
            }
            function checkFunctionOrMethodDeclaration(node) {
                var _a2;
                checkDecorators(node);
                checkSignatureDeclaration(node);
                const functionFlags = getFunctionFlags(node);
                if (node.name && node.name.kind === 164 /* ComputedPropertyName */) {
                    checkComputedPropertyName(node.name);
                }
                if (hasBindableName(node)) {
                    const symbol = getSymbolOfDeclaration(node);
                    const localSymbol = node.localSymbol || symbol;
                    const firstDeclaration = (_a2 = localSymbol.declarations) == null ? void 0 : _a2.find(
                    // Get first non javascript function declaration
                    (declaration) => declaration.kind === node.kind && !(declaration.flags & 262144 /* JavaScriptFile */));
                    if (node === firstDeclaration) {
                        checkFunctionOrConstructorSymbol(localSymbol);
                    }
                    if (symbol.parent) {
                        checkFunctionOrConstructorSymbol(symbol);
                    }
                }
                const body = node.kind === 170 /* MethodSignature */ ? void 0 : node.body;
                checkSourceElement(body);
                checkAllCodePathsInNonVoidFunctionReturnOrThrow(node, getReturnTypeFromAnnotation(node));
                addLazyDiagnostic(checkFunctionOrMethodDeclarationDiagnostics);
                if (isInJSFile(node)) {
                    const typeTag = getJSDocTypeTag(node);
                    if (typeTag && typeTag.typeExpression && !getContextualCallSignature(getTypeFromTypeNode(typeTag.typeExpression), node)) {
                        error(typeTag.typeExpression.type, Diagnostics.The_type_of_a_function_declaration_must_match_the_function_s_signature);
                    }
                }
                function checkFunctionOrMethodDeclarationDiagnostics() {
                    if (!getEffectiveReturnTypeNode(node)) {
                        if (nodeIsMissing(body) && !isPrivateWithinAmbient(node)) {
                            reportImplicitAny(node, anyType);
                        }
                        if (functionFlags & 1 /* Generator */ && nodeIsPresent(body)) {
                            getReturnTypeOfSignature(getSignatureFromDeclaration(node));
                        }
                    }
                }
            }
            function registerForUnusedIdentifiersCheck(node) {
                addLazyDiagnostic(registerForUnusedIdentifiersCheckDiagnostics);
                function registerForUnusedIdentifiersCheckDiagnostics() {
                    const sourceFile = getSourceFileOfNode(node);
                    let potentiallyUnusedIdentifiers = allPotentiallyUnusedIdentifiers.get(sourceFile.path);
                    if (!potentiallyUnusedIdentifiers) {
                        potentiallyUnusedIdentifiers = [];
                        allPotentiallyUnusedIdentifiers.set(sourceFile.path, potentiallyUnusedIdentifiers);
                    }
                    potentiallyUnusedIdentifiers.push(node);
                }
            }
            function checkUnusedIdentifiers(potentiallyUnusedIdentifiers, addDiagnostic) {
                for (const node of potentiallyUnusedIdentifiers) {
                    switch (node.kind) {
                        case 260 /* ClassDeclaration */:
                        case 228 /* ClassExpression */:
                            checkUnusedClassMembers(node, addDiagnostic);
                            checkUnusedTypeParameters(node, addDiagnostic);
                            break;
                        case 308 /* SourceFile */:
                        case 264 /* ModuleDeclaration */:
                        case 238 /* Block */:
                        case 266 /* CaseBlock */:
                        case 245 /* ForStatement */:
                        case 246 /* ForInStatement */:
                        case 247 /* ForOfStatement */:
                            checkUnusedLocalsAndParameters(node, addDiagnostic);
                            break;
                        case 173 /* Constructor */:
                        case 215 /* FunctionExpression */:
                        case 259 /* FunctionDeclaration */:
                        case 216 /* ArrowFunction */:
                        case 171 /* MethodDeclaration */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            if (node.body) {
                                checkUnusedLocalsAndParameters(node, addDiagnostic);
                            }
                            checkUnusedTypeParameters(node, addDiagnostic);
                            break;
                        case 170 /* MethodSignature */:
                        case 176 /* CallSignature */:
                        case 177 /* ConstructSignature */:
                        case 181 /* FunctionType */:
                        case 182 /* ConstructorType */:
                        case 262 /* TypeAliasDeclaration */:
                        case 261 /* InterfaceDeclaration */:
                            checkUnusedTypeParameters(node, addDiagnostic);
                            break;
                        case 192 /* InferType */:
                            checkUnusedInferTypeParameter(node, addDiagnostic);
                            break;
                        default:
                            Debug.assertNever(node, "Node should not have been registered for unused identifiers check");
                    }
                }
            }
            function errorUnusedLocal(declaration, name, addDiagnostic) {
                const node = getNameOfDeclaration(declaration) || declaration;
                const message = isTypeDeclaration(declaration) ? Diagnostics._0_is_declared_but_never_used : Diagnostics._0_is_declared_but_its_value_is_never_read;
                addDiagnostic(declaration, 0 /* Local */, createDiagnosticForNode(node, message, name));
            }
            function isIdentifierThatStartsWithUnderscore(node) {
                return isIdentifier(node) && idText(node).charCodeAt(0) === 95 /* _ */;
            }
            function checkUnusedClassMembers(node, addDiagnostic) {
                for (const member of node.members) {
                    switch (member.kind) {
                        case 171 /* MethodDeclaration */:
                        case 169 /* PropertyDeclaration */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            if (member.kind === 175 /* SetAccessor */ && member.symbol.flags & 32768 /* GetAccessor */) {
                                break;
                            }
                            const symbol = getSymbolOfDeclaration(member);
                            if (!symbol.isReferenced && (hasEffectiveModifier(member, 8 /* Private */) || isNamedDeclaration(member) && isPrivateIdentifier(member.name)) && !(member.flags & 16777216 /* Ambient */)) {
                                addDiagnostic(member, 0 /* Local */, createDiagnosticForNode(member.name, Diagnostics._0_is_declared_but_its_value_is_never_read, symbolToString(symbol)));
                            }
                            break;
                        case 173 /* Constructor */:
                            for (const parameter of member.parameters) {
                                if (!parameter.symbol.isReferenced && hasSyntacticModifier(parameter, 8 /* Private */)) {
                                    addDiagnostic(parameter, 0 /* Local */, createDiagnosticForNode(parameter.name, Diagnostics.Property_0_is_declared_but_its_value_is_never_read, symbolName(parameter.symbol)));
                                }
                            }
                            break;
                        case 178 /* IndexSignature */:
                        case 237 /* SemicolonClassElement */:
                        case 172 /* ClassStaticBlockDeclaration */:
                            break;
                        default:
                            Debug.fail("Unexpected class member");
                    }
                }
            }
            function checkUnusedInferTypeParameter(node, addDiagnostic) {
                const { typeParameter } = node;
                if (isTypeParameterUnused(typeParameter)) {
                    addDiagnostic(node, 1 /* Parameter */, createDiagnosticForNode(node, Diagnostics._0_is_declared_but_its_value_is_never_read, idText(typeParameter.name)));
                }
            }
            function checkUnusedTypeParameters(node, addDiagnostic) {
                const declarations = getSymbolOfDeclaration(node).declarations;
                if (!declarations || last(declarations) !== node)
                    return;
                const typeParameters = getEffectiveTypeParameterDeclarations(node);
                const seenParentsWithEveryUnused = /* @__PURE__ */ new Set();
                for (const typeParameter of typeParameters) {
                    if (!isTypeParameterUnused(typeParameter))
                        continue;
                    const name = idText(typeParameter.name);
                    const { parent: parent2 } = typeParameter;
                    if (parent2.kind !== 192 /* InferType */ && parent2.typeParameters.every(isTypeParameterUnused)) {
                        if (tryAddToSet(seenParentsWithEveryUnused, parent2)) {
                            const sourceFile = getSourceFileOfNode(parent2);
                            const range = isJSDocTemplateTag(parent2) ? rangeOfNode(parent2) : rangeOfTypeParameters(sourceFile, parent2.typeParameters);
                            const only = parent2.typeParameters.length === 1;
                            const message = only ? Diagnostics._0_is_declared_but_its_value_is_never_read : Diagnostics.All_type_parameters_are_unused;
                            const arg0 = only ? name : void 0;
                            addDiagnostic(typeParameter, 1 /* Parameter */, createFileDiagnostic(sourceFile, range.pos, range.end - range.pos, message, arg0));
                        }
                    }
                    else {
                        addDiagnostic(typeParameter, 1 /* Parameter */, createDiagnosticForNode(typeParameter, Diagnostics._0_is_declared_but_its_value_is_never_read, name));
                    }
                }
            }
            function isTypeParameterUnused(typeParameter) {
                return !(getMergedSymbol(typeParameter.symbol).isReferenced & 262144 /* TypeParameter */) && !isIdentifierThatStartsWithUnderscore(typeParameter.name);
            }
            function addToGroup(map2, key, value, getKey) {
                const keyString = String(getKey(key));
                const group2 = map2.get(keyString);
                if (group2) {
                    group2[1].push(value);
                }
                else {
                    map2.set(keyString, [key, [value]]);
                }
            }
            function tryGetRootParameterDeclaration(node) {
                return tryCast(getRootDeclaration(node), isParameter);
            }
            function isValidUnusedLocalDeclaration(declaration) {
                if (isBindingElement(declaration)) {
                    if (isObjectBindingPattern(declaration.parent)) {
                        return !!(declaration.propertyName && isIdentifierThatStartsWithUnderscore(declaration.name));
                    }
                    return isIdentifierThatStartsWithUnderscore(declaration.name);
                }
                return isAmbientModule(declaration) || (isVariableDeclaration(declaration) && isForInOrOfStatement(declaration.parent.parent) || isImportedDeclaration(declaration)) && isIdentifierThatStartsWithUnderscore(declaration.name);
            }
            function checkUnusedLocalsAndParameters(nodeWithLocals, addDiagnostic) {
                const unusedImports = /* @__PURE__ */ new Map();
                const unusedDestructures = /* @__PURE__ */ new Map();
                const unusedVariables = /* @__PURE__ */ new Map();
                nodeWithLocals.locals.forEach((local) => {
                    if (local.flags & 262144 /* TypeParameter */ ? !(local.flags & 3 /* Variable */ && !(local.isReferenced & 3 /* Variable */)) : local.isReferenced || local.exportSymbol) {
                        return;
                    }
                    if (local.declarations) {
                        for (const declaration of local.declarations) {
                            if (isValidUnusedLocalDeclaration(declaration)) {
                                continue;
                            }
                            if (isImportedDeclaration(declaration)) {
                                addToGroup(unusedImports, importClauseFromImported(declaration), declaration, getNodeId);
                            }
                            else if (isBindingElement(declaration) && isObjectBindingPattern(declaration.parent)) {
                                const lastElement = last(declaration.parent.elements);
                                if (declaration === lastElement || !last(declaration.parent.elements).dotDotDotToken) {
                                    addToGroup(unusedDestructures, declaration.parent, declaration, getNodeId);
                                }
                            }
                            else if (isVariableDeclaration(declaration)) {
                                addToGroup(unusedVariables, declaration.parent, declaration, getNodeId);
                            }
                            else {
                                const parameter = local.valueDeclaration && tryGetRootParameterDeclaration(local.valueDeclaration);
                                const name = local.valueDeclaration && getNameOfDeclaration(local.valueDeclaration);
                                if (parameter && name) {
                                    if (!isParameterPropertyDeclaration(parameter, parameter.parent) && !parameterIsThisKeyword(parameter) && !isIdentifierThatStartsWithUnderscore(name)) {
                                        if (isBindingElement(declaration) && isArrayBindingPattern(declaration.parent)) {
                                            addToGroup(unusedDestructures, declaration.parent, declaration, getNodeId);
                                        }
                                        else {
                                            addDiagnostic(parameter, 1 /* Parameter */, createDiagnosticForNode(name, Diagnostics._0_is_declared_but_its_value_is_never_read, symbolName(local)));
                                        }
                                    }
                                }
                                else {
                                    errorUnusedLocal(declaration, symbolName(local), addDiagnostic);
                                }
                            }
                        }
                    }
                });
                unusedImports.forEach(([importClause, unuseds]) => {
                    const importDecl = importClause.parent;
                    const nDeclarations = (importClause.name ? 1 : 0) + (importClause.namedBindings ? importClause.namedBindings.kind === 271 /* NamespaceImport */ ? 1 : importClause.namedBindings.elements.length : 0);
                    if (nDeclarations === unuseds.length) {
                        addDiagnostic(importDecl, 0 /* Local */, unuseds.length === 1 ? createDiagnosticForNode(importDecl, Diagnostics._0_is_declared_but_its_value_is_never_read, idText(first(unuseds).name)) : createDiagnosticForNode(importDecl, Diagnostics.All_imports_in_import_declaration_are_unused));
                    }
                    else {
                        for (const unused of unuseds)
                            errorUnusedLocal(unused, idText(unused.name), addDiagnostic);
                    }
                });
                unusedDestructures.forEach(([bindingPattern, bindingElements]) => {
                    const kind = tryGetRootParameterDeclaration(bindingPattern.parent) ? 1 /* Parameter */ : 0 /* Local */;
                    if (bindingPattern.elements.length === bindingElements.length) {
                        if (bindingElements.length === 1 && bindingPattern.parent.kind === 257 /* VariableDeclaration */ && bindingPattern.parent.parent.kind === 258 /* VariableDeclarationList */) {
                            addToGroup(unusedVariables, bindingPattern.parent.parent, bindingPattern.parent, getNodeId);
                        }
                        else {
                            addDiagnostic(bindingPattern, kind, bindingElements.length === 1 ? createDiagnosticForNode(bindingPattern, Diagnostics._0_is_declared_but_its_value_is_never_read, bindingNameText(first(bindingElements).name)) : createDiagnosticForNode(bindingPattern, Diagnostics.All_destructured_elements_are_unused));
                        }
                    }
                    else {
                        for (const e of bindingElements) {
                            addDiagnostic(e, kind, createDiagnosticForNode(e, Diagnostics._0_is_declared_but_its_value_is_never_read, bindingNameText(e.name)));
                        }
                    }
                });
                unusedVariables.forEach(([declarationList, declarations]) => {
                    if (declarationList.declarations.length === declarations.length) {
                        addDiagnostic(declarationList, 0 /* Local */, declarations.length === 1 ? createDiagnosticForNode(first(declarations).name, Diagnostics._0_is_declared_but_its_value_is_never_read, bindingNameText(first(declarations).name)) : createDiagnosticForNode(declarationList.parent.kind === 240 /* VariableStatement */ ? declarationList.parent : declarationList, Diagnostics.All_variables_are_unused));
                    }
                    else {
                        for (const decl of declarations) {
                            addDiagnostic(decl, 0 /* Local */, createDiagnosticForNode(decl, Diagnostics._0_is_declared_but_its_value_is_never_read, bindingNameText(decl.name)));
                        }
                    }
                });
            }
            function checkPotentialUncheckedRenamedBindingElementsInTypes() {
                var _a2;
                for (const node of potentialUnusedRenamedBindingElementsInTypes) {
                    if (!((_a2 = getSymbolOfDeclaration(node)) == null ? void 0 : _a2.isReferenced)) {
                        const wrappingDeclaration = walkUpBindingElementsAndPatterns(node);
                        Debug.assert(isParameterDeclaration(wrappingDeclaration), "Only parameter declaration should be checked here");
                        const diagnostic = createDiagnosticForNode(node.name, Diagnostics._0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation, declarationNameToString(node.name), declarationNameToString(node.propertyName));
                        if (!wrappingDeclaration.type) {
                            addRelatedInfo(diagnostic, createFileDiagnostic(getSourceFileOfNode(wrappingDeclaration), wrappingDeclaration.end, 1, Diagnostics.We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here, declarationNameToString(node.propertyName)));
                        }
                        diagnostics.add(diagnostic);
                    }
                }
            }
            function bindingNameText(name) {
                switch (name.kind) {
                    case 79 /* Identifier */:
                        return idText(name);
                    case 204 /* ArrayBindingPattern */:
                    case 203 /* ObjectBindingPattern */:
                        return bindingNameText(cast(first(name.elements), isBindingElement).name);
                    default:
                        return Debug.assertNever(name);
                }
            }
            function isImportedDeclaration(node) {
                return node.kind === 270 /* ImportClause */ || node.kind === 273 /* ImportSpecifier */ || node.kind === 271 /* NamespaceImport */;
            }
            function importClauseFromImported(decl) {
                return decl.kind === 270 /* ImportClause */ ? decl : decl.kind === 271 /* NamespaceImport */ ? decl.parent : decl.parent.parent;
            }
            function checkBlock(node) {
                if (node.kind === 238 /* Block */) {
                    checkGrammarStatementInAmbientContext(node);
                }
                if (isFunctionOrModuleBlock(node)) {
                    const saveFlowAnalysisDisabled = flowAnalysisDisabled;
                    forEach(node.statements, checkSourceElement);
                    flowAnalysisDisabled = saveFlowAnalysisDisabled;
                }
                else {
                    forEach(node.statements, checkSourceElement);
                }
                if (node.locals) {
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function checkCollisionWithArgumentsInGeneratedCode(node) {
                if (languageVersion >= 2 /* ES2015 */ || !hasRestParameter(node) || node.flags & 16777216 /* Ambient */ || nodeIsMissing(node.body)) {
                    return;
                }
                forEach(node.parameters, (p) => {
                    if (p.name && !isBindingPattern(p.name) && p.name.escapedText === argumentsSymbol.escapedName) {
                        errorSkippedOn("noEmit", p, Diagnostics.Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters);
                    }
                });
            }
            function needCollisionCheckForIdentifier(node, identifier, name) {
                if ((identifier == null ? void 0 : identifier.escapedText) !== name) {
                    return false;
                }
                if (node.kind === 169 /* PropertyDeclaration */ || node.kind === 168 /* PropertySignature */ || node.kind === 171 /* MethodDeclaration */ || node.kind === 170 /* MethodSignature */ || node.kind === 174 /* GetAccessor */ || node.kind === 175 /* SetAccessor */ || node.kind === 299 /* PropertyAssignment */) {
                    return false;
                }
                if (node.flags & 16777216 /* Ambient */) {
                    return false;
                }
                if (isImportClause(node) || isImportEqualsDeclaration(node) || isImportSpecifier(node)) {
                    if (isTypeOnlyImportOrExportDeclaration(node)) {
                        return false;
                    }
                }
                const root = getRootDeclaration(node);
                if (isParameter(root) && nodeIsMissing(root.parent.body)) {
                    return false;
                }
                return true;
            }
            function checkIfThisIsCapturedInEnclosingScope(node) {
                findAncestor(node, (current) => {
                    if (getNodeCheckFlags(current) & 4 /* CaptureThis */) {
                        const isDeclaration2 = node.kind !== 79 /* Identifier */;
                        if (isDeclaration2) {
                            error(getNameOfDeclaration(node), Diagnostics.Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference);
                        }
                        else {
                            error(node, Diagnostics.Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference);
                        }
                        return true;
                    }
                    return false;
                });
            }
            function checkIfNewTargetIsCapturedInEnclosingScope(node) {
                findAncestor(node, (current) => {
                    if (getNodeCheckFlags(current) & 8 /* CaptureNewTarget */) {
                        const isDeclaration2 = node.kind !== 79 /* Identifier */;
                        if (isDeclaration2) {
                            error(getNameOfDeclaration(node), Diagnostics.Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_meta_property_reference);
                        }
                        else {
                            error(node, Diagnostics.Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta_property_reference);
                        }
                        return true;
                    }
                    return false;
                });
            }
            function checkCollisionWithRequireExportsInGeneratedCode(node, name) {
                if (moduleKind >= 5 /* ES2015 */ && !(moduleKind >= 100 /* Node16 */ && getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                    return;
                }
                if (!name || !needCollisionCheckForIdentifier(node, name, "require") && !needCollisionCheckForIdentifier(node, name, "exports")) {
                    return;
                }
                if (isModuleDeclaration(node) && getModuleInstanceState(node) !== 1 /* Instantiated */) {
                    return;
                }
                const parent2 = getDeclarationContainer(node);
                if (parent2.kind === 308 /* SourceFile */ && isExternalOrCommonJsModule(parent2)) {
                    errorSkippedOn("noEmit", name, Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module, declarationNameToString(name), declarationNameToString(name));
                }
            }
            function checkCollisionWithGlobalPromiseInGeneratedCode(node, name) {
                if (!name || languageVersion >= 4 /* ES2017 */ || !needCollisionCheckForIdentifier(node, name, "Promise")) {
                    return;
                }
                if (isModuleDeclaration(node) && getModuleInstanceState(node) !== 1 /* Instantiated */) {
                    return;
                }
                const parent2 = getDeclarationContainer(node);
                if (parent2.kind === 308 /* SourceFile */ && isExternalOrCommonJsModule(parent2) && parent2.flags & 2048 /* HasAsyncFunctions */) {
                    errorSkippedOn("noEmit", name, Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions, declarationNameToString(name), declarationNameToString(name));
                }
            }
            function recordPotentialCollisionWithWeakMapSetInGeneratedCode(node, name) {
                if (languageVersion <= 8 /* ES2021 */ && (needCollisionCheckForIdentifier(node, name, "WeakMap") || needCollisionCheckForIdentifier(node, name, "WeakSet"))) {
                    potentialWeakMapSetCollisions.push(node);
                }
            }
            function checkWeakMapSetCollision(node) {
                const enclosingBlockScope = getEnclosingBlockScopeContainer(node);
                if (getNodeCheckFlags(enclosingBlockScope) & 4194304 /* ContainsClassWithPrivateIdentifiers */) {
                    Debug.assert(isNamedDeclaration(node) && isIdentifier(node.name) && typeof node.name.escapedText === "string", "The target of a WeakMap/WeakSet collision check should be an identifier");
                    errorSkippedOn("noEmit", node, Diagnostics.Compiler_reserves_name_0_when_emitting_private_identifier_downlevel, node.name.escapedText);
                }
            }
            function recordPotentialCollisionWithReflectInGeneratedCode(node, name) {
                if (name && languageVersion >= 2 /* ES2015 */ && languageVersion <= 8 /* ES2021 */ && needCollisionCheckForIdentifier(node, name, "Reflect")) {
                    potentialReflectCollisions.push(node);
                }
            }
            function checkReflectCollision(node) {
                let hasCollision = false;
                if (isClassExpression(node)) {
                    for (const member of node.members) {
                        if (getNodeCheckFlags(member) & 8388608 /* ContainsSuperPropertyInStaticInitializer */) {
                            hasCollision = true;
                            break;
                        }
                    }
                }
                else if (isFunctionExpression(node)) {
                    if (getNodeCheckFlags(node) & 8388608 /* ContainsSuperPropertyInStaticInitializer */) {
                        hasCollision = true;
                    }
                }
                else {
                    const container = getEnclosingBlockScopeContainer(node);
                    if (container && getNodeCheckFlags(container) & 8388608 /* ContainsSuperPropertyInStaticInitializer */) {
                        hasCollision = true;
                    }
                }
                if (hasCollision) {
                    Debug.assert(isNamedDeclaration(node) && isIdentifier(node.name), "The target of a Reflect collision check should be an identifier");
                    errorSkippedOn("noEmit", node, Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializers, declarationNameToString(node.name), "Reflect");
                }
            }
            function checkCollisionsForDeclarationName(node, name) {
                if (!name)
                    return;
                checkCollisionWithRequireExportsInGeneratedCode(node, name);
                checkCollisionWithGlobalPromiseInGeneratedCode(node, name);
                recordPotentialCollisionWithWeakMapSetInGeneratedCode(node, name);
                recordPotentialCollisionWithReflectInGeneratedCode(node, name);
                if (isClassLike(node)) {
                    checkTypeNameIsReserved(name, Diagnostics.Class_name_cannot_be_0);
                    if (!(node.flags & 16777216 /* Ambient */)) {
                        checkClassNameCollisionWithObject(name);
                    }
                }
                else if (isEnumDeclaration(node)) {
                    checkTypeNameIsReserved(name, Diagnostics.Enum_name_cannot_be_0);
                }
            }
            function checkVarDeclaredNamesNotShadowed(node) {
                if ((getCombinedNodeFlags(node) & 3 /* BlockScoped */) !== 0 || isParameterDeclaration(node)) {
                    return;
                }
                if (node.kind === 257 /* VariableDeclaration */ && !node.initializer) {
                    return;
                }
                const symbol = getSymbolOfDeclaration(node);
                if (symbol.flags & 1 /* FunctionScopedVariable */) {
                    if (!isIdentifier(node.name))
                        return Debug.fail();
                    const localDeclarationSymbol = resolveName(node, node.name.escapedText, 3 /* Variable */, 
                    /*nodeNotFoundErrorMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false);
                    if (localDeclarationSymbol && localDeclarationSymbol !== symbol && localDeclarationSymbol.flags & 2 /* BlockScopedVariable */) {
                        if (getDeclarationNodeFlagsFromSymbol(localDeclarationSymbol) & 3 /* BlockScoped */) {
                            const varDeclList = getAncestor(localDeclarationSymbol.valueDeclaration, 258 /* VariableDeclarationList */);
                            const container = varDeclList.parent.kind === 240 /* VariableStatement */ && varDeclList.parent.parent ? varDeclList.parent.parent : void 0;
                            const namesShareScope = container && (container.kind === 238 /* Block */ && isFunctionLike(container.parent) || container.kind === 265 /* ModuleBlock */ || container.kind === 264 /* ModuleDeclaration */ || container.kind === 308 /* SourceFile */);
                            if (!namesShareScope) {
                                const name = symbolToString(localDeclarationSymbol);
                                error(node, Diagnostics.Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1, name, name);
                            }
                        }
                    }
                }
            }
            function convertAutoToAny(type) {
                return type === autoType ? anyType : type === autoArrayType ? anyArrayType : type;
            }
            function checkVariableLikeDeclaration(node) {
                var _a2;
                checkDecorators(node);
                if (!isBindingElement(node)) {
                    checkSourceElement(node.type);
                }
                if (!node.name) {
                    return;
                }
                if (node.name.kind === 164 /* ComputedPropertyName */) {
                    checkComputedPropertyName(node.name);
                    if (hasOnlyExpressionInitializer(node) && node.initializer) {
                        checkExpressionCached(node.initializer);
                    }
                }
                if (isBindingElement(node)) {
                    if (node.propertyName && isIdentifier(node.name) && isParameterDeclaration(node) && nodeIsMissing(getContainingFunction(node).body)) {
                        potentialUnusedRenamedBindingElementsInTypes.push(node);
                        return;
                    }
                    if (isObjectBindingPattern(node.parent) && node.dotDotDotToken && languageVersion < 5 /* ES2018 */) {
                        checkExternalEmitHelpers(node, 4 /* Rest */);
                    }
                    if (node.propertyName && node.propertyName.kind === 164 /* ComputedPropertyName */) {
                        checkComputedPropertyName(node.propertyName);
                    }
                    const parent2 = node.parent.parent;
                    const parentCheckMode = node.dotDotDotToken ? 64 /* RestBindingElement */ : 0 /* Normal */;
                    const parentType = getTypeForBindingElementParent(parent2, parentCheckMode);
                    const name = node.propertyName || node.name;
                    if (parentType && !isBindingPattern(name)) {
                        const exprType = getLiteralTypeFromPropertyName(name);
                        if (isTypeUsableAsPropertyName(exprType)) {
                            const nameText = getPropertyNameFromType(exprType);
                            const property = getPropertyOfType(parentType, nameText);
                            if (property) {
                                markPropertyAsReferenced(property, 
                                /*nodeForCheckWriteOnly*/
                                void 0, 
                                /*isSelfTypeAccess*/
                                false);
                                checkPropertyAccessibility(node, !!parent2.initializer && parent2.initializer.kind === 106 /* SuperKeyword */, 
                                /*writing*/
                                false, parentType, property);
                            }
                        }
                    }
                }
                if (isBindingPattern(node.name)) {
                    if (node.name.kind === 204 /* ArrayBindingPattern */ && languageVersion < 2 /* ES2015 */ && compilerOptions.downlevelIteration) {
                        checkExternalEmitHelpers(node, 512 /* Read */);
                    }
                    forEach(node.name.elements, checkSourceElement);
                }
                if (isParameter(node) && node.initializer && nodeIsMissing(getContainingFunction(node).body)) {
                    error(node, Diagnostics.A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation);
                    return;
                }
                if (isBindingPattern(node.name)) {
                    const needCheckInitializer = hasOnlyExpressionInitializer(node) && node.initializer && node.parent.parent.kind !== 246 /* ForInStatement */;
                    const needCheckWidenedType = !some(node.name.elements, not(isOmittedExpression));
                    if (needCheckInitializer || needCheckWidenedType) {
                        const widenedType = getWidenedTypeForVariableLikeDeclaration(node);
                        if (needCheckInitializer) {
                            const initializerType = checkExpressionCached(node.initializer);
                            if (strictNullChecks && needCheckWidenedType) {
                                checkNonNullNonVoidType(initializerType, node);
                            }
                            else {
                                checkTypeAssignableToAndOptionallyElaborate(initializerType, getWidenedTypeForVariableLikeDeclaration(node), node, node.initializer);
                            }
                        }
                        if (needCheckWidenedType) {
                            if (isArrayBindingPattern(node.name)) {
                                checkIteratedTypeOrElementType(65 /* Destructuring */, widenedType, undefinedType, node);
                            }
                            else if (strictNullChecks) {
                                checkNonNullNonVoidType(widenedType, node);
                            }
                        }
                    }
                    return;
                }
                const symbol = getSymbolOfDeclaration(node);
                if (symbol.flags & 2097152 /* Alias */ && (isVariableDeclarationInitializedToBareOrAccessedRequire(node) || isBindingElementOfBareOrAccessedRequire(node))) {
                    checkAliasSymbol(node);
                    return;
                }
                const type = convertAutoToAny(getTypeOfSymbol(symbol));
                if (node === symbol.valueDeclaration) {
                    const initializer = hasOnlyExpressionInitializer(node) && getEffectiveInitializer(node);
                    if (initializer) {
                        const isJSObjectLiteralInitializer = isInJSFile(node) && isObjectLiteralExpression(initializer) && (initializer.properties.length === 0 || isPrototypeAccess(node.name)) && !!((_a2 = symbol.exports) == null ? void 0 : _a2.size);
                        if (!isJSObjectLiteralInitializer && node.parent.parent.kind !== 246 /* ForInStatement */) {
                            checkTypeAssignableToAndOptionallyElaborate(checkExpressionCached(initializer), type, node, initializer, 
                            /*headMessage*/
                            void 0);
                        }
                    }
                    if (symbol.declarations && symbol.declarations.length > 1) {
                        if (some(symbol.declarations, (d) => d !== node && isVariableLike(d) && !areDeclarationFlagsIdentical(d, node))) {
                            error(node.name, Diagnostics.All_declarations_of_0_must_have_identical_modifiers, declarationNameToString(node.name));
                        }
                    }
                }
                else {
                    const declarationType = convertAutoToAny(getWidenedTypeForVariableLikeDeclaration(node));
                    if (!isErrorType(type) && !isErrorType(declarationType) && !isTypeIdenticalTo(type, declarationType) && !(symbol.flags & 67108864 /* Assignment */)) {
                        errorNextVariableOrPropertyDeclarationMustHaveSameType(symbol.valueDeclaration, type, node, declarationType);
                    }
                    if (hasOnlyExpressionInitializer(node) && node.initializer) {
                        checkTypeAssignableToAndOptionallyElaborate(checkExpressionCached(node.initializer), declarationType, node, node.initializer, 
                        /*headMessage*/
                        void 0);
                    }
                    if (symbol.valueDeclaration && !areDeclarationFlagsIdentical(node, symbol.valueDeclaration)) {
                        error(node.name, Diagnostics.All_declarations_of_0_must_have_identical_modifiers, declarationNameToString(node.name));
                    }
                }
                if (node.kind !== 169 /* PropertyDeclaration */ && node.kind !== 168 /* PropertySignature */) {
                    checkExportsOnMergedDeclarations(node);
                    if (node.kind === 257 /* VariableDeclaration */ || node.kind === 205 /* BindingElement */) {
                        checkVarDeclaredNamesNotShadowed(node);
                    }
                    checkCollisionsForDeclarationName(node, node.name);
                }
            }
            function errorNextVariableOrPropertyDeclarationMustHaveSameType(firstDeclaration, firstType, nextDeclaration, nextType) {
                const nextDeclarationName = getNameOfDeclaration(nextDeclaration);
                const message = nextDeclaration.kind === 169 /* PropertyDeclaration */ || nextDeclaration.kind === 168 /* PropertySignature */ ? Diagnostics.Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_type_2 : Diagnostics.Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2;
                const declName = declarationNameToString(nextDeclarationName);
                const err = error(nextDeclarationName, message, declName, typeToString(firstType), typeToString(nextType));
                if (firstDeclaration) {
                    addRelatedInfo(err, createDiagnosticForNode(firstDeclaration, Diagnostics._0_was_also_declared_here, declName));
                }
            }
            function areDeclarationFlagsIdentical(left, right) {
                if (left.kind === 166 /* Parameter */ && right.kind === 257 /* VariableDeclaration */ || left.kind === 257 /* VariableDeclaration */ && right.kind === 166 /* Parameter */) {
                    return true;
                }
                if (hasQuestionToken(left) !== hasQuestionToken(right)) {
                    return false;
                }
                const interestingFlags = 8 /* Private */ | 16 /* Protected */ | 512 /* Async */ | 256 /* Abstract */ | 64 /* Readonly */ | 32 /* Static */;
                return getSelectedEffectiveModifierFlags(left, interestingFlags) === getSelectedEffectiveModifierFlags(right, interestingFlags);
            }
            function checkVariableDeclaration(node) {
                var _a2, _b;
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Check, "checkVariableDeclaration", { kind: node.kind, pos: node.pos, end: node.end, path: node.tracingPath });
                checkGrammarVariableDeclaration(node);
                checkVariableLikeDeclaration(node);
                (_b = tracing) == null ? void 0 : _b.pop();
            }
            function checkBindingElement(node) {
                checkGrammarBindingElement(node);
                return checkVariableLikeDeclaration(node);
            }
            function checkVariableStatement(node) {
                if (!checkGrammarModifiers(node) && !checkGrammarVariableDeclarationList(node.declarationList))
                    checkGrammarForDisallowedLetOrConstStatement(node);
                forEach(node.declarationList.declarations, checkSourceElement);
            }
            function checkExpressionStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                checkExpression(node.expression);
            }
            function checkIfStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                const type = checkTruthinessExpression(node.expression);
                checkTestingKnownTruthyCallableOrAwaitableType(node.expression, type, node.thenStatement);
                checkSourceElement(node.thenStatement);
                if (node.thenStatement.kind === 239 /* EmptyStatement */) {
                    error(node.thenStatement, Diagnostics.The_body_of_an_if_statement_cannot_be_the_empty_statement);
                }
                checkSourceElement(node.elseStatement);
            }
            function checkTestingKnownTruthyCallableOrAwaitableType(condExpr, condType, body) {
                if (!strictNullChecks)
                    return;
                bothHelper(condExpr, body);
                function bothHelper(condExpr2, body2) {
                    condExpr2 = skipParentheses(condExpr2);
                    helper(condExpr2, body2);
                    while (isBinaryExpression(condExpr2) && (condExpr2.operatorToken.kind === 56 /* BarBarToken */ || condExpr2.operatorToken.kind === 60 /* QuestionQuestionToken */)) {
                        condExpr2 = skipParentheses(condExpr2.left);
                        helper(condExpr2, body2);
                    }
                }
                function helper(condExpr2, body2) {
                    const location = isLogicalOrCoalescingBinaryExpression(condExpr2) ? skipParentheses(condExpr2.right) : condExpr2;
                    if (isModuleExportsAccessExpression(location)) {
                        return;
                    }
                    if (isLogicalOrCoalescingBinaryExpression(location)) {
                        bothHelper(location, body2);
                        return;
                    }
                    const type = location === condExpr2 ? condType : checkTruthinessExpression(location);
                    const isPropertyExpressionCast = isPropertyAccessExpression(location) && isTypeAssertion(location.expression);
                    if (!(getTypeFacts(type) & 4194304 /* Truthy */) || isPropertyExpressionCast)
                        return;
                    const callSignatures = getSignaturesOfType(type, 0 /* Call */);
                    const isPromise = !!getAwaitedTypeOfPromise(type);
                    if (callSignatures.length === 0 && !isPromise) {
                        return;
                    }
                    const testedNode = isIdentifier(location) ? location : isPropertyAccessExpression(location) ? location.name : void 0;
                    const testedSymbol = testedNode && getSymbolAtLocation(testedNode);
                    if (!testedSymbol && !isPromise) {
                        return;
                    }
                    const isUsed = testedSymbol && isBinaryExpression(condExpr2.parent) && isSymbolUsedInBinaryExpressionChain(condExpr2.parent, testedSymbol) || testedSymbol && body2 && isSymbolUsedInConditionBody(condExpr2, body2, testedNode, testedSymbol);
                    if (!isUsed) {
                        if (isPromise) {
                            errorAndMaybeSuggestAwait(location, 
                            /*maybeMissingAwait*/
                            true, Diagnostics.This_condition_will_always_return_true_since_this_0_is_always_defined, getTypeNameForErrorDisplay(type));
                        }
                        else {
                            error(location, Diagnostics.This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead);
                        }
                    }
                }
            }
            function isSymbolUsedInConditionBody(expr, body, testedNode, testedSymbol) {
                return !!forEachChild(body, function check(childNode) {
                    if (isIdentifier(childNode)) {
                        const childSymbol = getSymbolAtLocation(childNode);
                        if (childSymbol && childSymbol === testedSymbol) {
                            if (isIdentifier(expr) || isIdentifier(testedNode) && isBinaryExpression(testedNode.parent)) {
                                return true;
                            }
                            let testedExpression = testedNode.parent;
                            let childExpression = childNode.parent;
                            while (testedExpression && childExpression) {
                                if (isIdentifier(testedExpression) && isIdentifier(childExpression) || testedExpression.kind === 108 /* ThisKeyword */ && childExpression.kind === 108 /* ThisKeyword */) {
                                    return getSymbolAtLocation(testedExpression) === getSymbolAtLocation(childExpression);
                                }
                                else if (isPropertyAccessExpression(testedExpression) && isPropertyAccessExpression(childExpression)) {
                                    if (getSymbolAtLocation(testedExpression.name) !== getSymbolAtLocation(childExpression.name)) {
                                        return false;
                                    }
                                    childExpression = childExpression.expression;
                                    testedExpression = testedExpression.expression;
                                }
                                else if (isCallExpression(testedExpression) && isCallExpression(childExpression)) {
                                    childExpression = childExpression.expression;
                                    testedExpression = testedExpression.expression;
                                }
                                else {
                                    return false;
                                }
                            }
                        }
                    }
                    return forEachChild(childNode, check);
                });
            }
            function isSymbolUsedInBinaryExpressionChain(node, testedSymbol) {
                while (isBinaryExpression(node) && node.operatorToken.kind === 55 /* AmpersandAmpersandToken */) {
                    const isUsed = forEachChild(node.right, function visit(child) {
                        if (isIdentifier(child)) {
                            const symbol = getSymbolAtLocation(child);
                            if (symbol && symbol === testedSymbol) {
                                return true;
                            }
                        }
                        return forEachChild(child, visit);
                    });
                    if (isUsed) {
                        return true;
                    }
                    node = node.parent;
                }
                return false;
            }
            function checkDoStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                checkSourceElement(node.statement);
                checkTruthinessExpression(node.expression);
            }
            function checkWhileStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                checkTruthinessExpression(node.expression);
                checkSourceElement(node.statement);
            }
            function checkTruthinessOfType(type, node) {
                if (type.flags & 16384 /* Void */) {
                    error(node, Diagnostics.An_expression_of_type_void_cannot_be_tested_for_truthiness);
                }
                return type;
            }
            function checkTruthinessExpression(node, checkMode) {
                return checkTruthinessOfType(checkExpression(node, checkMode), node);
            }
            function checkForStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node)) {
                    if (node.initializer && node.initializer.kind === 258 /* VariableDeclarationList */) {
                        checkGrammarVariableDeclarationList(node.initializer);
                    }
                }
                if (node.initializer) {
                    if (node.initializer.kind === 258 /* VariableDeclarationList */) {
                        forEach(node.initializer.declarations, checkVariableDeclaration);
                    }
                    else {
                        checkExpression(node.initializer);
                    }
                }
                if (node.condition)
                    checkTruthinessExpression(node.condition);
                if (node.incrementor)
                    checkExpression(node.incrementor);
                checkSourceElement(node.statement);
                if (node.locals) {
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function checkForOfStatement(node) {
                checkGrammarForInOrForOfStatement(node);
                const container = getContainingFunctionOrClassStaticBlock(node);
                if (node.awaitModifier) {
                    if (container && isClassStaticBlockDeclaration(container)) {
                        grammarErrorOnNode(node.awaitModifier, Diagnostics.For_await_loops_cannot_be_used_inside_a_class_static_block);
                    }
                    else {
                        const functionFlags = getFunctionFlags(container);
                        if ((functionFlags & (4 /* Invalid */ | 2 /* Async */)) === 2 /* Async */ && languageVersion < 99 /* ESNext */) {
                            checkExternalEmitHelpers(node, 16384 /* ForAwaitOfIncludes */);
                        }
                    }
                }
                else if (compilerOptions.downlevelIteration && languageVersion < 2 /* ES2015 */) {
                    checkExternalEmitHelpers(node, 256 /* ForOfIncludes */);
                }
                if (node.initializer.kind === 258 /* VariableDeclarationList */) {
                    checkForInOrForOfVariableDeclaration(node);
                }
                else {
                    const varExpr = node.initializer;
                    const iteratedType = checkRightHandSideOfForOf(node);
                    if (varExpr.kind === 206 /* ArrayLiteralExpression */ || varExpr.kind === 207 /* ObjectLiteralExpression */) {
                        checkDestructuringAssignment(varExpr, iteratedType || errorType);
                    }
                    else {
                        const leftType = checkExpression(varExpr);
                        checkReferenceExpression(varExpr, Diagnostics.The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access, Diagnostics.The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access);
                        if (iteratedType) {
                            checkTypeAssignableToAndOptionallyElaborate(iteratedType, leftType, varExpr, node.expression);
                        }
                    }
                }
                checkSourceElement(node.statement);
                if (node.locals) {
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function checkForInStatement(node) {
                checkGrammarForInOrForOfStatement(node);
                const rightType = getNonNullableTypeIfNeeded(checkExpression(node.expression));
                if (node.initializer.kind === 258 /* VariableDeclarationList */) {
                    const variable = node.initializer.declarations[0];
                    if (variable && isBindingPattern(variable.name)) {
                        error(variable.name, Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern);
                    }
                    checkForInOrForOfVariableDeclaration(node);
                }
                else {
                    const varExpr = node.initializer;
                    const leftType = checkExpression(varExpr);
                    if (varExpr.kind === 206 /* ArrayLiteralExpression */ || varExpr.kind === 207 /* ObjectLiteralExpression */) {
                        error(varExpr, Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern);
                    }
                    else if (!isTypeAssignableTo(getIndexTypeOrString(rightType), leftType)) {
                        error(varExpr, Diagnostics.The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any);
                    }
                    else {
                        checkReferenceExpression(varExpr, Diagnostics.The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access, Diagnostics.The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access);
                    }
                }
                if (rightType === neverType || !isTypeAssignableToKind(rightType, 67108864 /* NonPrimitive */ | 58982400 /* InstantiableNonPrimitive */)) {
                    error(node.expression, Diagnostics.The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_here_has_type_0, typeToString(rightType));
                }
                checkSourceElement(node.statement);
                if (node.locals) {
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function checkForInOrForOfVariableDeclaration(iterationStatement) {
                const variableDeclarationList = iterationStatement.initializer;
                if (variableDeclarationList.declarations.length >= 1) {
                    const decl = variableDeclarationList.declarations[0];
                    checkVariableDeclaration(decl);
                }
            }
            function checkRightHandSideOfForOf(statement) {
                const use = statement.awaitModifier ? 15 /* ForAwaitOf */ : 13 /* ForOf */;
                return checkIteratedTypeOrElementType(use, checkNonNullExpression(statement.expression), undefinedType, statement.expression);
            }
            function checkIteratedTypeOrElementType(use, inputType, sentType, errorNode) {
                if (isTypeAny(inputType)) {
                    return inputType;
                }
                return getIteratedTypeOrElementType(use, inputType, sentType, errorNode, 
                /*checkAssignability*/
                true) || anyType;
            }
            function getIteratedTypeOrElementType(use, inputType, sentType, errorNode, checkAssignability) {
                const allowAsyncIterables = (use & 2 /* AllowsAsyncIterablesFlag */) !== 0;
                if (inputType === neverType) {
                    reportTypeNotIterableError(errorNode, inputType, allowAsyncIterables);
                    return void 0;
                }
                const uplevelIteration = languageVersion >= 2 /* ES2015 */;
                const downlevelIteration = !uplevelIteration && compilerOptions.downlevelIteration;
                const possibleOutOfBounds = compilerOptions.noUncheckedIndexedAccess && !!(use & 128 /* PossiblyOutOfBounds */);
                if (uplevelIteration || downlevelIteration || allowAsyncIterables) {
                    const iterationTypes = getIterationTypesOfIterable(inputType, use, uplevelIteration ? errorNode : void 0);
                    if (checkAssignability) {
                        if (iterationTypes) {
                            const diagnostic = use & 8 /* ForOfFlag */ ? Diagnostics.Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_send_0 : use & 32 /* SpreadFlag */ ? Diagnostics.Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_always_send_0 : use & 64 /* DestructuringFlag */ ? Diagnostics.Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring_will_always_send_0 : use & 16 /* YieldStarFlag */ ? Diagnostics.Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_containing_generator_will_always_send_0 : void 0;
                            if (diagnostic) {
                                checkTypeAssignableTo(sentType, iterationTypes.nextType, errorNode, diagnostic);
                            }
                        }
                    }
                    if (iterationTypes || uplevelIteration) {
                        return possibleOutOfBounds ? includeUndefinedInIndexSignature(iterationTypes && iterationTypes.yieldType) : iterationTypes && iterationTypes.yieldType;
                    }
                }
                let arrayType = inputType;
                let reportedError = false;
                let hasStringConstituent = false;
                if (use & 4 /* AllowsStringInputFlag */) {
                    if (arrayType.flags & 1048576 /* Union */) {
                        const arrayTypes = inputType.types;
                        const filteredTypes = filter(arrayTypes, (t) => !(t.flags & 402653316 /* StringLike */));
                        if (filteredTypes !== arrayTypes) {
                            arrayType = getUnionType(filteredTypes, 2 /* Subtype */);
                        }
                    }
                    else if (arrayType.flags & 402653316 /* StringLike */) {
                        arrayType = neverType;
                    }
                    hasStringConstituent = arrayType !== inputType;
                    if (hasStringConstituent) {
                        if (languageVersion < 1 /* ES5 */) {
                            if (errorNode) {
                                error(errorNode, Diagnostics.Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher);
                                reportedError = true;
                            }
                        }
                        if (arrayType.flags & 131072 /* Never */) {
                            return possibleOutOfBounds ? includeUndefinedInIndexSignature(stringType) : stringType;
                        }
                    }
                }
                if (!isArrayLikeType(arrayType)) {
                    if (errorNode && !reportedError) {
                        const allowsStrings = !!(use & 4 /* AllowsStringInputFlag */) && !hasStringConstituent;
                        const [defaultDiagnostic, maybeMissingAwait] = getIterationDiagnosticDetails(allowsStrings, downlevelIteration);
                        errorAndMaybeSuggestAwait(errorNode, maybeMissingAwait && !!getAwaitedTypeOfPromise(arrayType), defaultDiagnostic, typeToString(arrayType));
                    }
                    return hasStringConstituent ? possibleOutOfBounds ? includeUndefinedInIndexSignature(stringType) : stringType : void 0;
                }
                const arrayElementType = getIndexTypeOfType(arrayType, numberType);
                if (hasStringConstituent && arrayElementType) {
                    if (arrayElementType.flags & 402653316 /* StringLike */ && !compilerOptions.noUncheckedIndexedAccess) {
                        return stringType;
                    }
                    return getUnionType(possibleOutOfBounds ? [arrayElementType, stringType, undefinedType] : [arrayElementType, stringType], 2 /* Subtype */);
                }
                return use & 128 /* PossiblyOutOfBounds */ ? includeUndefinedInIndexSignature(arrayElementType) : arrayElementType;
                function getIterationDiagnosticDetails(allowsStrings, downlevelIteration2) {
                    var _a2;
                    if (downlevelIteration2) {
                        return allowsStrings ? [Diagnostics.Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator, true] : [Diagnostics.Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator, true];
                    }
                    const yieldType = getIterationTypeOfIterable(use, 0 /* Yield */, inputType, 
                    /*errorNode*/
                    void 0);
                    if (yieldType) {
                        return [Diagnostics.Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher, false];
                    }
                    if (isES2015OrLaterIterable((_a2 = inputType.symbol) == null ? void 0 : _a2.escapedName)) {
                        return [Diagnostics.Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher, true];
                    }
                    return allowsStrings ? [Diagnostics.Type_0_is_not_an_array_type_or_a_string_type, true] : [Diagnostics.Type_0_is_not_an_array_type, true];
                }
            }
            function isES2015OrLaterIterable(n) {
                switch (n) {
                    case "Float32Array":
                    case "Float64Array":
                    case "Int16Array":
                    case "Int32Array":
                    case "Int8Array":
                    case "NodeList":
                    case "Uint16Array":
                    case "Uint32Array":
                    case "Uint8Array":
                    case "Uint8ClampedArray":
                        return true;
                }
                return false;
            }
            function getIterationTypeOfIterable(use, typeKind, inputType, errorNode) {
                if (isTypeAny(inputType)) {
                    return void 0;
                }
                const iterationTypes = getIterationTypesOfIterable(inputType, use, errorNode);
                return iterationTypes && iterationTypes[getIterationTypesKeyFromIterationTypeKind(typeKind)];
            }
            function createIterationTypes(yieldType = neverType, returnType = neverType, nextType = unknownType) {
                if (yieldType.flags & 67359327 /* Intrinsic */ && returnType.flags & (1 /* Any */ | 131072 /* Never */ | 2 /* Unknown */ | 16384 /* Void */ | 32768 /* Undefined */) && nextType.flags & (1 /* Any */ | 131072 /* Never */ | 2 /* Unknown */ | 16384 /* Void */ | 32768 /* Undefined */)) {
                    const id = getTypeListId([yieldType, returnType, nextType]);
                    let iterationTypes = iterationTypesCache.get(id);
                    if (!iterationTypes) {
                        iterationTypes = { yieldType, returnType, nextType };
                        iterationTypesCache.set(id, iterationTypes);
                    }
                    return iterationTypes;
                }
                return { yieldType, returnType, nextType };
            }
            function combineIterationTypes(array) {
                let yieldTypes;
                let returnTypes;
                let nextTypes;
                for (const iterationTypes of array) {
                    if (iterationTypes === void 0 || iterationTypes === noIterationTypes) {
                        continue;
                    }
                    if (iterationTypes === anyIterationTypes) {
                        return anyIterationTypes;
                    }
                    yieldTypes = append(yieldTypes, iterationTypes.yieldType);
                    returnTypes = append(returnTypes, iterationTypes.returnType);
                    nextTypes = append(nextTypes, iterationTypes.nextType);
                }
                if (yieldTypes || returnTypes || nextTypes) {
                    return createIterationTypes(yieldTypes && getUnionType(yieldTypes), returnTypes && getUnionType(returnTypes), nextTypes && getIntersectionType(nextTypes));
                }
                return noIterationTypes;
            }
            function getCachedIterationTypes(type, cacheKey) {
                return type[cacheKey];
            }
            function setCachedIterationTypes(type, cacheKey, cachedTypes2) {
                return type[cacheKey] = cachedTypes2;
            }
            function getIterationTypesOfIterable(type, use, errorNode) {
                var _a2, _b;
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                if (!(type.flags & 1048576 /* Union */)) {
                    const errorOutputContainer = errorNode ? { errors: void 0 } : void 0;
                    const iterationTypes2 = getIterationTypesOfIterableWorker(type, use, errorNode, errorOutputContainer);
                    if (iterationTypes2 === noIterationTypes) {
                        if (errorNode) {
                            const rootDiag = reportTypeNotIterableError(errorNode, type, !!(use & 2 /* AllowsAsyncIterablesFlag */));
                            if (errorOutputContainer == null ? void 0 : errorOutputContainer.errors) {
                                addRelatedInfo(rootDiag, ...errorOutputContainer.errors);
                            }
                        }
                        return void 0;
                    }
                    else if ((_a2 = errorOutputContainer == null ? void 0 : errorOutputContainer.errors) == null ? void 0 : _a2.length) {
                        for (const diag2 of errorOutputContainer.errors) {
                            diagnostics.add(diag2);
                        }
                    }
                    return iterationTypes2;
                }
                const cacheKey = use & 2 /* AllowsAsyncIterablesFlag */ ? "iterationTypesOfAsyncIterable" : "iterationTypesOfIterable";
                const cachedTypes2 = getCachedIterationTypes(type, cacheKey);
                if (cachedTypes2)
                    return cachedTypes2 === noIterationTypes ? void 0 : cachedTypes2;
                let allIterationTypes;
                for (const constituent of type.types) {
                    const errorOutputContainer = errorNode ? { errors: void 0 } : void 0;
                    const iterationTypes2 = getIterationTypesOfIterableWorker(constituent, use, errorNode, errorOutputContainer);
                    if (iterationTypes2 === noIterationTypes) {
                        if (errorNode) {
                            const rootDiag = reportTypeNotIterableError(errorNode, type, !!(use & 2 /* AllowsAsyncIterablesFlag */));
                            if (errorOutputContainer == null ? void 0 : errorOutputContainer.errors) {
                                addRelatedInfo(rootDiag, ...errorOutputContainer.errors);
                            }
                        }
                        setCachedIterationTypes(type, cacheKey, noIterationTypes);
                        return void 0;
                    }
                    else if ((_b = errorOutputContainer == null ? void 0 : errorOutputContainer.errors) == null ? void 0 : _b.length) {
                        for (const diag2 of errorOutputContainer.errors) {
                            diagnostics.add(diag2);
                        }
                    }
                    allIterationTypes = append(allIterationTypes, iterationTypes2);
                }
                const iterationTypes = allIterationTypes ? combineIterationTypes(allIterationTypes) : noIterationTypes;
                setCachedIterationTypes(type, cacheKey, iterationTypes);
                return iterationTypes === noIterationTypes ? void 0 : iterationTypes;
            }
            function getAsyncFromSyncIterationTypes(iterationTypes, errorNode) {
                if (iterationTypes === noIterationTypes)
                    return noIterationTypes;
                if (iterationTypes === anyIterationTypes)
                    return anyIterationTypes;
                const { yieldType, returnType, nextType } = iterationTypes;
                if (errorNode) {
                    getGlobalAwaitedSymbol(
                    /*reportErrors*/
                    true);
                }
                return createIterationTypes(getAwaitedType(yieldType, errorNode) || anyType, getAwaitedType(returnType, errorNode) || anyType, nextType);
            }
            function getIterationTypesOfIterableWorker(type, use, errorNode, errorOutputContainer) {
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                let noCache = false;
                if (use & 2 /* AllowsAsyncIterablesFlag */) {
                    const iterationTypes = getIterationTypesOfIterableCached(type, asyncIterationTypesResolver) || getIterationTypesOfIterableFast(type, asyncIterationTypesResolver);
                    if (iterationTypes) {
                        if (iterationTypes === noIterationTypes && errorNode) {
                            noCache = true;
                        }
                        else {
                            return use & 8 /* ForOfFlag */ ? getAsyncFromSyncIterationTypes(iterationTypes, errorNode) : iterationTypes;
                        }
                    }
                }
                if (use & 1 /* AllowsSyncIterablesFlag */) {
                    let iterationTypes = getIterationTypesOfIterableCached(type, syncIterationTypesResolver) || getIterationTypesOfIterableFast(type, syncIterationTypesResolver);
                    if (iterationTypes) {
                        if (iterationTypes === noIterationTypes && errorNode) {
                            noCache = true;
                        }
                        else {
                            if (use & 2 /* AllowsAsyncIterablesFlag */) {
                                if (iterationTypes !== noIterationTypes) {
                                    iterationTypes = getAsyncFromSyncIterationTypes(iterationTypes, errorNode);
                                    return noCache ? iterationTypes : setCachedIterationTypes(type, "iterationTypesOfAsyncIterable", iterationTypes);
                                }
                            }
                            else {
                                return iterationTypes;
                            }
                        }
                    }
                }
                if (use & 2 /* AllowsAsyncIterablesFlag */) {
                    const iterationTypes = getIterationTypesOfIterableSlow(type, asyncIterationTypesResolver, errorNode, errorOutputContainer, noCache);
                    if (iterationTypes !== noIterationTypes) {
                        return iterationTypes;
                    }
                }
                if (use & 1 /* AllowsSyncIterablesFlag */) {
                    let iterationTypes = getIterationTypesOfIterableSlow(type, syncIterationTypesResolver, errorNode, errorOutputContainer, noCache);
                    if (iterationTypes !== noIterationTypes) {
                        if (use & 2 /* AllowsAsyncIterablesFlag */) {
                            iterationTypes = getAsyncFromSyncIterationTypes(iterationTypes, errorNode);
                            return noCache ? iterationTypes : setCachedIterationTypes(type, "iterationTypesOfAsyncIterable", iterationTypes);
                        }
                        else {
                            return iterationTypes;
                        }
                    }
                }
                return noIterationTypes;
            }
            function getIterationTypesOfIterableCached(type, resolver) {
                return getCachedIterationTypes(type, resolver.iterableCacheKey);
            }
            function getIterationTypesOfGlobalIterableType(globalType, resolver) {
                const globalIterationTypes = getIterationTypesOfIterableCached(globalType, resolver) || getIterationTypesOfIterableSlow(globalType, resolver, 
                /*errorNode*/
                void 0, 
                /*errorOutputContainer*/
                void 0, 
                /*noCache*/
                false);
                return globalIterationTypes === noIterationTypes ? defaultIterationTypes : globalIterationTypes;
            }
            function getIterationTypesOfIterableFast(type, resolver) {
                let globalType;
                if (isReferenceToType2(type, globalType = resolver.getGlobalIterableType(
                /*reportErrors*/
                false)) || isReferenceToType2(type, globalType = resolver.getGlobalIterableIteratorType(
                /*reportErrors*/
                false))) {
                    const [yieldType] = getTypeArguments(type);
                    const { returnType, nextType } = getIterationTypesOfGlobalIterableType(globalType, resolver);
                    return setCachedIterationTypes(type, resolver.iterableCacheKey, createIterationTypes(resolver.resolveIterationType(yieldType, 
                    /*errorNode*/
                    void 0) || yieldType, resolver.resolveIterationType(returnType, 
                    /*errorNode*/
                    void 0) || returnType, nextType));
                }
                if (isReferenceToType2(type, resolver.getGlobalGeneratorType(
                /*reportErrors*/
                false))) {
                    const [yieldType, returnType, nextType] = getTypeArguments(type);
                    return setCachedIterationTypes(type, resolver.iterableCacheKey, createIterationTypes(resolver.resolveIterationType(yieldType, 
                    /*errorNode*/
                    void 0) || yieldType, resolver.resolveIterationType(returnType, 
                    /*errorNode*/
                    void 0) || returnType, nextType));
                }
            }
            function getPropertyNameForKnownSymbolName(symbolName2) {
                const ctorType = getGlobalESSymbolConstructorSymbol(
                /*reportErrors*/
                false);
                const uniqueType = ctorType && getTypeOfPropertyOfType(getTypeOfSymbol(ctorType), escapeLeadingUnderscores(symbolName2));
                return uniqueType && isTypeUsableAsPropertyName(uniqueType) ? getPropertyNameFromType(uniqueType) : `__@${symbolName2}`;
            }
            function getIterationTypesOfIterableSlow(type, resolver, errorNode, errorOutputContainer, noCache) {
                var _a2;
                const method = getPropertyOfType(type, getPropertyNameForKnownSymbolName(resolver.iteratorSymbolName));
                const methodType = method && !(method.flags & 16777216 /* Optional */) ? getTypeOfSymbol(method) : void 0;
                if (isTypeAny(methodType)) {
                    return noCache ? anyIterationTypes : setCachedIterationTypes(type, resolver.iterableCacheKey, anyIterationTypes);
                }
                const signatures = methodType ? getSignaturesOfType(methodType, 0 /* Call */) : void 0;
                if (!some(signatures)) {
                    return noCache ? noIterationTypes : setCachedIterationTypes(type, resolver.iterableCacheKey, noIterationTypes);
                }
                const iteratorType = getIntersectionType(map(signatures, getReturnTypeOfSignature));
                const iterationTypes = (_a2 = getIterationTypesOfIteratorWorker(iteratorType, resolver, errorNode, errorOutputContainer, noCache)) != null ? _a2 : noIterationTypes;
                return noCache ? iterationTypes : setCachedIterationTypes(type, resolver.iterableCacheKey, iterationTypes);
            }
            function reportTypeNotIterableError(errorNode, type, allowAsyncIterables) {
                const message = allowAsyncIterables ? Diagnostics.Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator : Diagnostics.Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator;
                const suggestAwait = (
                // for (const x of Promise<...>) or [...Promise<...>]
                !!getAwaitedTypeOfPromise(type) || !allowAsyncIterables && isForOfStatement(errorNode.parent) && errorNode.parent.expression === errorNode && getGlobalAsyncIterableType(
                /** reportErrors */
                false) !== emptyGenericType && isTypeAssignableTo(type, getGlobalAsyncIterableType(
                /** reportErrors */
                false)));
                return errorAndMaybeSuggestAwait(errorNode, suggestAwait, message, typeToString(type));
            }
            function getIterationTypesOfIterator(type, resolver, errorNode, errorOutputContainer) {
                return getIterationTypesOfIteratorWorker(type, resolver, errorNode, errorOutputContainer, 
                /*noCache*/
                false);
            }
            function getIterationTypesOfIteratorWorker(type, resolver, errorNode, errorOutputContainer, noCache) {
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                let iterationTypes = getIterationTypesOfIteratorCached(type, resolver) || getIterationTypesOfIteratorFast(type, resolver);
                if (iterationTypes === noIterationTypes && errorNode) {
                    iterationTypes = void 0;
                    noCache = true;
                }
                iterationTypes != null ? iterationTypes : iterationTypes = getIterationTypesOfIteratorSlow(type, resolver, errorNode, errorOutputContainer, noCache);
                return iterationTypes === noIterationTypes ? void 0 : iterationTypes;
            }
            function getIterationTypesOfIteratorCached(type, resolver) {
                return getCachedIterationTypes(type, resolver.iteratorCacheKey);
            }
            function getIterationTypesOfIteratorFast(type, resolver) {
                const globalType = resolver.getGlobalIterableIteratorType(
                /*reportErrors*/
                false);
                if (isReferenceToType2(type, globalType)) {
                    const [yieldType] = getTypeArguments(type);
                    const globalIterationTypes = getIterationTypesOfIteratorCached(globalType, resolver) || getIterationTypesOfIteratorSlow(globalType, resolver, 
                    /*errorNode*/
                    void 0, 
                    /*errorOutputContainer*/
                    void 0, 
                    /*noCache*/
                    false);
                    const { returnType, nextType } = globalIterationTypes === noIterationTypes ? defaultIterationTypes : globalIterationTypes;
                    return setCachedIterationTypes(type, resolver.iteratorCacheKey, createIterationTypes(yieldType, returnType, nextType));
                }
                if (isReferenceToType2(type, resolver.getGlobalIteratorType(
                /*reportErrors*/
                false)) || isReferenceToType2(type, resolver.getGlobalGeneratorType(
                /*reportErrors*/
                false))) {
                    const [yieldType, returnType, nextType] = getTypeArguments(type);
                    return setCachedIterationTypes(type, resolver.iteratorCacheKey, createIterationTypes(yieldType, returnType, nextType));
                }
            }
            function isIteratorResult(type, kind) {
                const doneType = getTypeOfPropertyOfType(type, "done") || falseType;
                return isTypeAssignableTo(kind === 0 /* Yield */ ? falseType : trueType, doneType);
            }
            function isYieldIteratorResult(type) {
                return isIteratorResult(type, 0 /* Yield */);
            }
            function isReturnIteratorResult(type) {
                return isIteratorResult(type, 1 /* Return */);
            }
            function getIterationTypesOfIteratorResult(type) {
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                const cachedTypes2 = getCachedIterationTypes(type, "iterationTypesOfIteratorResult");
                if (cachedTypes2) {
                    return cachedTypes2;
                }
                if (isReferenceToType2(type, getGlobalIteratorYieldResultType(
                /*reportErrors*/
                false))) {
                    const yieldType2 = getTypeArguments(type)[0];
                    return setCachedIterationTypes(type, "iterationTypesOfIteratorResult", createIterationTypes(yieldType2, 
                    /*returnType*/
                    void 0, 
                    /*nextType*/
                    void 0));
                }
                if (isReferenceToType2(type, getGlobalIteratorReturnResultType(
                /*reportErrors*/
                false))) {
                    const returnType2 = getTypeArguments(type)[0];
                    return setCachedIterationTypes(type, "iterationTypesOfIteratorResult", createIterationTypes(
                    /*yieldType*/
                    void 0, returnType2, 
                    /*nextType*/
                    void 0));
                }
                const yieldIteratorResult = filterType(type, isYieldIteratorResult);
                const yieldType = yieldIteratorResult !== neverType ? getTypeOfPropertyOfType(yieldIteratorResult, "value") : void 0;
                const returnIteratorResult = filterType(type, isReturnIteratorResult);
                const returnType = returnIteratorResult !== neverType ? getTypeOfPropertyOfType(returnIteratorResult, "value") : void 0;
                if (!yieldType && !returnType) {
                    return setCachedIterationTypes(type, "iterationTypesOfIteratorResult", noIterationTypes);
                }
                return setCachedIterationTypes(type, "iterationTypesOfIteratorResult", createIterationTypes(yieldType, returnType || voidType, 
                /*nextType*/
                void 0));
            }
            function getIterationTypesOfMethod(type, resolver, methodName, errorNode, errorOutputContainer) {
                var _a2, _b, _c, _d, _e, _f;
                const method = getPropertyOfType(type, methodName);
                if (!method && methodName !== "next") {
                    return void 0;
                }
                const methodType = method && !(methodName === "next" && method.flags & 16777216 /* Optional */) ? methodName === "next" ? getTypeOfSymbol(method) : getTypeWithFacts(getTypeOfSymbol(method), 2097152 /* NEUndefinedOrNull */) : void 0;
                if (isTypeAny(methodType)) {
                    return methodName === "next" ? anyIterationTypes : anyIterationTypesExceptNext;
                }
                const methodSignatures = methodType ? getSignaturesOfType(methodType, 0 /* Call */) : emptyArray;
                if (methodSignatures.length === 0) {
                    if (errorNode) {
                        const diagnostic = methodName === "next" ? resolver.mustHaveANextMethodDiagnostic : resolver.mustBeAMethodDiagnostic;
                        if (errorOutputContainer) {
                            (_a2 = errorOutputContainer.errors) != null ? _a2 : errorOutputContainer.errors = [];
                            errorOutputContainer.errors.push(createDiagnosticForNode(errorNode, diagnostic, methodName));
                        }
                        else {
                            error(errorNode, diagnostic, methodName);
                        }
                    }
                    return methodName === "next" ? noIterationTypes : void 0;
                }
                if ((methodType == null ? void 0 : methodType.symbol) && methodSignatures.length === 1) {
                    const globalGeneratorType = resolver.getGlobalGeneratorType(
                    /*reportErrors*/
                    false);
                    const globalIteratorType = resolver.getGlobalIteratorType(
                    /*reportErrors*/
                    false);
                    const isGeneratorMethod = ((_c = (_b = globalGeneratorType.symbol) == null ? void 0 : _b.members) == null ? void 0 : _c.get(methodName)) === methodType.symbol;
                    const isIteratorMethod = !isGeneratorMethod && ((_e = (_d = globalIteratorType.symbol) == null ? void 0 : _d.members) == null ? void 0 : _e.get(methodName)) === methodType.symbol;
                    if (isGeneratorMethod || isIteratorMethod) {
                        const globalType = isGeneratorMethod ? globalGeneratorType : globalIteratorType;
                        const { mapper } = methodType;
                        return createIterationTypes(getMappedType(globalType.typeParameters[0], mapper), getMappedType(globalType.typeParameters[1], mapper), methodName === "next" ? getMappedType(globalType.typeParameters[2], mapper) : void 0);
                    }
                }
                let methodParameterTypes;
                let methodReturnTypes;
                for (const signature of methodSignatures) {
                    if (methodName !== "throw" && some(signature.parameters)) {
                        methodParameterTypes = append(methodParameterTypes, getTypeAtPosition(signature, 0));
                    }
                    methodReturnTypes = append(methodReturnTypes, getReturnTypeOfSignature(signature));
                }
                let returnTypes;
                let nextType;
                if (methodName !== "throw") {
                    const methodParameterType = methodParameterTypes ? getUnionType(methodParameterTypes) : unknownType;
                    if (methodName === "next") {
                        nextType = methodParameterType;
                    }
                    else if (methodName === "return") {
                        const resolvedMethodParameterType = resolver.resolveIterationType(methodParameterType, errorNode) || anyType;
                        returnTypes = append(returnTypes, resolvedMethodParameterType);
                    }
                }
                let yieldType;
                const methodReturnType = methodReturnTypes ? getIntersectionType(methodReturnTypes) : neverType;
                const resolvedMethodReturnType = resolver.resolveIterationType(methodReturnType, errorNode) || anyType;
                const iterationTypes = getIterationTypesOfIteratorResult(resolvedMethodReturnType);
                if (iterationTypes === noIterationTypes) {
                    if (errorNode) {
                        if (errorOutputContainer) {
                            (_f = errorOutputContainer.errors) != null ? _f : errorOutputContainer.errors = [];
                            errorOutputContainer.errors.push(createDiagnosticForNode(errorNode, resolver.mustHaveAValueDiagnostic, methodName));
                        }
                        else {
                            error(errorNode, resolver.mustHaveAValueDiagnostic, methodName);
                        }
                    }
                    yieldType = anyType;
                    returnTypes = append(returnTypes, anyType);
                }
                else {
                    yieldType = iterationTypes.yieldType;
                    returnTypes = append(returnTypes, iterationTypes.returnType);
                }
                return createIterationTypes(yieldType, getUnionType(returnTypes), nextType);
            }
            function getIterationTypesOfIteratorSlow(type, resolver, errorNode, errorOutputContainer, noCache) {
                const iterationTypes = combineIterationTypes([
                    getIterationTypesOfMethod(type, resolver, "next", errorNode, errorOutputContainer),
                    getIterationTypesOfMethod(type, resolver, "return", errorNode, errorOutputContainer),
                    getIterationTypesOfMethod(type, resolver, "throw", errorNode, errorOutputContainer)
                ]);
                return noCache ? iterationTypes : setCachedIterationTypes(type, resolver.iteratorCacheKey, iterationTypes);
            }
            function getIterationTypeOfGeneratorFunctionReturnType(kind, returnType, isAsyncGenerator) {
                if (isTypeAny(returnType)) {
                    return void 0;
                }
                const iterationTypes = getIterationTypesOfGeneratorFunctionReturnType(returnType, isAsyncGenerator);
                return iterationTypes && iterationTypes[getIterationTypesKeyFromIterationTypeKind(kind)];
            }
            function getIterationTypesOfGeneratorFunctionReturnType(type, isAsyncGenerator) {
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                const use = isAsyncGenerator ? 2 /* AsyncGeneratorReturnType */ : 1 /* GeneratorReturnType */;
                const resolver = isAsyncGenerator ? asyncIterationTypesResolver : syncIterationTypesResolver;
                return getIterationTypesOfIterable(type, use, 
                /*errorNode*/
                void 0) || getIterationTypesOfIterator(type, resolver, 
                /*errorNode*/
                void 0, 
                /*errorOutputContainer*/
                void 0);
            }
            function checkBreakOrContinueStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node))
                    checkGrammarBreakOrContinueStatement(node);
            }
            function unwrapReturnType(returnType, functionFlags) {
                const isGenerator = !!(functionFlags & 1 /* Generator */);
                const isAsync = !!(functionFlags & 2 /* Async */);
                if (isGenerator) {
                    const returnIterationType = getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, returnType, isAsync);
                    if (!returnIterationType) {
                        return errorType;
                    }
                    return isAsync ? getAwaitedTypeNoAlias(unwrapAwaitedType(returnIterationType)) : returnIterationType;
                }
                return isAsync ? getAwaitedTypeNoAlias(returnType) || errorType : returnType;
            }
            function isUnwrappedReturnTypeVoidOrAny(func, returnType) {
                const unwrappedReturnType = unwrapReturnType(returnType, getFunctionFlags(func));
                return !!unwrappedReturnType && maybeTypeOfKind(unwrappedReturnType, 16384 /* Void */ | 3 /* AnyOrUnknown */);
            }
            function checkReturnStatement(node) {
                var _a2;
                if (checkGrammarStatementInAmbientContext(node)) {
                    return;
                }
                const container = getContainingFunctionOrClassStaticBlock(node);
                if (container && isClassStaticBlockDeclaration(container)) {
                    grammarErrorOnFirstToken(node, Diagnostics.A_return_statement_cannot_be_used_inside_a_class_static_block);
                    return;
                }
                if (!container) {
                    grammarErrorOnFirstToken(node, Diagnostics.A_return_statement_can_only_be_used_within_a_function_body);
                    return;
                }
                const signature = getSignatureFromDeclaration(container);
                const returnType = getReturnTypeOfSignature(signature);
                const functionFlags = getFunctionFlags(container);
                if (strictNullChecks || node.expression || returnType.flags & 131072 /* Never */) {
                    const exprType = node.expression ? checkExpressionCached(node.expression) : undefinedType;
                    if (container.kind === 175 /* SetAccessor */) {
                        if (node.expression) {
                            error(node, Diagnostics.Setters_cannot_return_a_value);
                        }
                    }
                    else if (container.kind === 173 /* Constructor */) {
                        if (node.expression && !checkTypeAssignableToAndOptionallyElaborate(exprType, returnType, node, node.expression)) {
                            error(node, Diagnostics.Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class);
                        }
                    }
                    else if (getReturnTypeFromAnnotation(container)) {
                        const unwrappedReturnType = (_a2 = unwrapReturnType(returnType, functionFlags)) != null ? _a2 : returnType;
                        const unwrappedExprType = functionFlags & 2 /* Async */ ? checkAwaitedType(exprType, 
                        /*withAlias*/
                        false, node, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member) : exprType;
                        if (unwrappedReturnType) {
                            checkTypeAssignableToAndOptionallyElaborate(unwrappedExprType, unwrappedReturnType, node, node.expression);
                        }
                    }
                }
                else if (container.kind !== 173 /* Constructor */ && compilerOptions.noImplicitReturns && !isUnwrappedReturnTypeVoidOrAny(container, returnType)) {
                    error(node, Diagnostics.Not_all_code_paths_return_a_value);
                }
            }
            function checkWithStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node)) {
                    if (node.flags & 32768 /* AwaitContext */) {
                        grammarErrorOnFirstToken(node, Diagnostics.with_statements_are_not_allowed_in_an_async_function_block);
                    }
                }
                checkExpression(node.expression);
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    const start = getSpanOfTokenAtPosition(sourceFile, node.pos).start;
                    const end = node.statement.pos;
                    grammarErrorAtPos(sourceFile, start, end - start, Diagnostics.The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any);
                }
            }
            function checkSwitchStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                let firstDefaultClause;
                let hasDuplicateDefaultClause = false;
                const expressionType = checkExpression(node.expression);
                forEach(node.caseBlock.clauses, (clause) => {
                    if (clause.kind === 293 /* DefaultClause */ && !hasDuplicateDefaultClause) {
                        if (firstDefaultClause === void 0) {
                            firstDefaultClause = clause;
                        }
                        else {
                            grammarErrorOnNode(clause, Diagnostics.A_default_clause_cannot_appear_more_than_once_in_a_switch_statement);
                            hasDuplicateDefaultClause = true;
                        }
                    }
                    if (clause.kind === 292 /* CaseClause */) {
                        addLazyDiagnostic(createLazyCaseClauseDiagnostics(clause));
                    }
                    forEach(clause.statements, checkSourceElement);
                    if (compilerOptions.noFallthroughCasesInSwitch && clause.fallthroughFlowNode && isReachableFlowNode(clause.fallthroughFlowNode)) {
                        error(clause, Diagnostics.Fallthrough_case_in_switch);
                    }
                    function createLazyCaseClauseDiagnostics(clause2) {
                        return () => {
                            const caseType = checkExpression(clause2.expression);
                            if (!isTypeEqualityComparableTo(expressionType, caseType)) {
                                checkTypeComparableTo(caseType, expressionType, clause2.expression, 
                                /*headMessage*/
                                void 0);
                            }
                        };
                    }
                });
                if (node.caseBlock.locals) {
                    registerForUnusedIdentifiersCheck(node.caseBlock);
                }
            }
            function checkLabeledStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node)) {
                    findAncestor(node.parent, (current) => {
                        if (isFunctionLike(current)) {
                            return "quit";
                        }
                        if (current.kind === 253 /* LabeledStatement */ && current.label.escapedText === node.label.escapedText) {
                            grammarErrorOnNode(node.label, Diagnostics.Duplicate_label_0, getTextOfNode(node.label));
                            return true;
                        }
                        return false;
                    });
                }
                checkSourceElement(node.statement);
            }
            function checkThrowStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node)) {
                    if (isIdentifier(node.expression) && !node.expression.escapedText) {
                        grammarErrorAfterFirstToken(node, Diagnostics.Line_break_not_permitted_here);
                    }
                }
                if (node.expression) {
                    checkExpression(node.expression);
                }
            }
            function checkTryStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                checkBlock(node.tryBlock);
                const catchClause = node.catchClause;
                if (catchClause) {
                    if (catchClause.variableDeclaration) {
                        const declaration = catchClause.variableDeclaration;
                        checkVariableLikeDeclaration(declaration);
                        const typeNode = getEffectiveTypeAnnotationNode(declaration);
                        if (typeNode) {
                            const type = getTypeFromTypeNode(typeNode);
                            if (type && !(type.flags & 3 /* AnyOrUnknown */)) {
                                grammarErrorOnFirstToken(typeNode, Diagnostics.Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified);
                            }
                        }
                        else if (declaration.initializer) {
                            grammarErrorOnFirstToken(declaration.initializer, Diagnostics.Catch_clause_variable_cannot_have_an_initializer);
                        }
                        else {
                            const blockLocals = catchClause.block.locals;
                            if (blockLocals) {
                                forEachKey(catchClause.locals, (caughtName) => {
                                    const blockLocal = blockLocals.get(caughtName);
                                    if ((blockLocal == null ? void 0 : blockLocal.valueDeclaration) && (blockLocal.flags & 2 /* BlockScopedVariable */) !== 0) {
                                        grammarErrorOnNode(blockLocal.valueDeclaration, Diagnostics.Cannot_redeclare_identifier_0_in_catch_clause, caughtName);
                                    }
                                });
                            }
                        }
                    }
                    checkBlock(catchClause.block);
                }
                if (node.finallyBlock) {
                    checkBlock(node.finallyBlock);
                }
            }
            function checkIndexConstraints(type, symbol, isStaticIndex) {
                const indexInfos = getIndexInfosOfType(type);
                if (indexInfos.length === 0) {
                    return;
                }
                for (const prop of getPropertiesOfObjectType(type)) {
                    if (!(isStaticIndex && prop.flags & 4194304 /* Prototype */)) {
                        checkIndexConstraintForProperty(type, prop, getLiteralTypeFromProperty(prop, 8576 /* StringOrNumberLiteralOrUnique */, 
                        /*includeNonPublic*/
                        true), getNonMissingTypeOfSymbol(prop));
                    }
                }
                const typeDeclaration = symbol.valueDeclaration;
                if (typeDeclaration && isClassLike(typeDeclaration)) {
                    for (const member of typeDeclaration.members) {
                        if (!isStatic(member) && !hasBindableName(member)) {
                            const symbol2 = getSymbolOfDeclaration(member);
                            checkIndexConstraintForProperty(type, symbol2, getTypeOfExpression(member.name.expression), getNonMissingTypeOfSymbol(symbol2));
                        }
                    }
                }
                if (indexInfos.length > 1) {
                    for (const info of indexInfos) {
                        checkIndexConstraintForIndexSignature(type, info);
                    }
                }
            }
            function checkIndexConstraintForProperty(type, prop, propNameType, propType) {
                const declaration = prop.valueDeclaration;
                const name = getNameOfDeclaration(declaration);
                if (name && isPrivateIdentifier(name)) {
                    return;
                }
                const indexInfos = getApplicableIndexInfos(type, propNameType);
                const interfaceDeclaration = getObjectFlags(type) & 2 /* Interface */ ? getDeclarationOfKind(type.symbol, 261 /* InterfaceDeclaration */) : void 0;
                const propDeclaration = declaration && declaration.kind === 223 /* BinaryExpression */ || name && name.kind === 164 /* ComputedPropertyName */ ? declaration : void 0;
                const localPropDeclaration = getParentOfSymbol(prop) === type.symbol ? declaration : void 0;
                for (const info of indexInfos) {
                    const localIndexDeclaration = info.declaration && getParentOfSymbol(getSymbolOfDeclaration(info.declaration)) === type.symbol ? info.declaration : void 0;
                    const errorNode = localPropDeclaration || localIndexDeclaration || (interfaceDeclaration && !some(getBaseTypes(type), (base) => !!getPropertyOfObjectType(base, prop.escapedName) && !!getIndexTypeOfType(base, info.keyType)) ? interfaceDeclaration : void 0);
                    if (errorNode && !isTypeAssignableTo(propType, info.type)) {
                        const diagnostic = createError(errorNode, Diagnostics.Property_0_of_type_1_is_not_assignable_to_2_index_type_3, symbolToString(prop), typeToString(propType), typeToString(info.keyType), typeToString(info.type));
                        if (propDeclaration && errorNode !== propDeclaration) {
                            addRelatedInfo(diagnostic, createDiagnosticForNode(propDeclaration, Diagnostics._0_is_declared_here, symbolToString(prop)));
                        }
                        diagnostics.add(diagnostic);
                    }
                }
            }
            function checkIndexConstraintForIndexSignature(type, checkInfo) {
                const declaration = checkInfo.declaration;
                const indexInfos = getApplicableIndexInfos(type, checkInfo.keyType);
                const interfaceDeclaration = getObjectFlags(type) & 2 /* Interface */ ? getDeclarationOfKind(type.symbol, 261 /* InterfaceDeclaration */) : void 0;
                const localCheckDeclaration = declaration && getParentOfSymbol(getSymbolOfDeclaration(declaration)) === type.symbol ? declaration : void 0;
                for (const info of indexInfos) {
                    if (info === checkInfo)
                        continue;
                    const localIndexDeclaration = info.declaration && getParentOfSymbol(getSymbolOfDeclaration(info.declaration)) === type.symbol ? info.declaration : void 0;
                    const errorNode = localCheckDeclaration || localIndexDeclaration || (interfaceDeclaration && !some(getBaseTypes(type), (base) => !!getIndexInfoOfType(base, checkInfo.keyType) && !!getIndexTypeOfType(base, info.keyType)) ? interfaceDeclaration : void 0);
                    if (errorNode && !isTypeAssignableTo(checkInfo.type, info.type)) {
                        error(errorNode, Diagnostics._0_index_type_1_is_not_assignable_to_2_index_type_3, typeToString(checkInfo.keyType), typeToString(checkInfo.type), typeToString(info.keyType), typeToString(info.type));
                    }
                }
            }
            function checkTypeNameIsReserved(name, message) {
                switch (name.escapedText) {
                    case "any":
                    case "unknown":
                    case "never":
                    case "number":
                    case "bigint":
                    case "boolean":
                    case "string":
                    case "symbol":
                    case "void":
                    case "object":
                        error(name, message, name.escapedText);
                }
            }
            function checkClassNameCollisionWithObject(name) {
                if (languageVersion >= 1 /* ES5 */ && name.escapedText === "Object" && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(name).impliedNodeFormat === 1 /* CommonJS */)) {
                    error(name, Diagnostics.Class_name_cannot_be_Object_when_targeting_ES5_with_module_0, ModuleKind[moduleKind]);
                }
            }
            function checkUnmatchedJSDocParameters(node) {
                const jsdocParameters = filter(getJSDocTags(node), isJSDocParameterTag);
                if (!length(jsdocParameters))
                    return;
                const isJs = isInJSFile(node);
                const parameters = /* @__PURE__ */ new Set();
                const excludedParameters = /* @__PURE__ */ new Set();
                forEach(node.parameters, ({ name }, index) => {
                    if (isIdentifier(name)) {
                        parameters.add(name.escapedText);
                    }
                    if (isBindingPattern(name)) {
                        excludedParameters.add(index);
                    }
                });
                const containsArguments = containsArgumentsReference(node);
                if (containsArguments) {
                    const lastJSDocParamIndex = jsdocParameters.length - 1;
                    const lastJSDocParam = jsdocParameters[lastJSDocParamIndex];
                    if (isJs && lastJSDocParam && isIdentifier(lastJSDocParam.name) && lastJSDocParam.typeExpression && lastJSDocParam.typeExpression.type && !parameters.has(lastJSDocParam.name.escapedText) && !excludedParameters.has(lastJSDocParamIndex) && !isArrayType(getTypeFromTypeNode(lastJSDocParam.typeExpression.type))) {
                        error(lastJSDocParam.name, Diagnostics.JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_had_an_array_type, idText(lastJSDocParam.name));
                    }
                }
                else {
                    forEach(jsdocParameters, ({ name, isNameFirst }, index) => {
                        if (excludedParameters.has(index) || isIdentifier(name) && parameters.has(name.escapedText)) {
                            return;
                        }
                        if (isQualifiedName(name)) {
                            if (isJs) {
                                error(name, Diagnostics.Qualified_name_0_is_not_allowed_without_a_leading_param_object_1, entityNameToString(name), entityNameToString(name.left));
                            }
                        }
                        else {
                            if (!isNameFirst) {
                                errorOrSuggestion(isJs, name, Diagnostics.JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name, idText(name));
                            }
                        }
                    });
                }
            }
            function checkTypeParameters(typeParameterDeclarations) {
                let seenDefault = false;
                if (typeParameterDeclarations) {
                    for (let i = 0; i < typeParameterDeclarations.length; i++) {
                        const node = typeParameterDeclarations[i];
                        checkTypeParameter(node);
                        addLazyDiagnostic(createCheckTypeParameterDiagnostic(node, i));
                    }
                }
                function createCheckTypeParameterDiagnostic(node, i) {
                    return () => {
                        if (node.default) {
                            seenDefault = true;
                            checkTypeParametersNotReferenced(node.default, typeParameterDeclarations, i);
                        }
                        else if (seenDefault) {
                            error(node, Diagnostics.Required_type_parameters_may_not_follow_optional_type_parameters);
                        }
                        for (let j = 0; j < i; j++) {
                            if (typeParameterDeclarations[j].symbol === node.symbol) {
                                error(node.name, Diagnostics.Duplicate_identifier_0, declarationNameToString(node.name));
                            }
                        }
                    };
                }
            }
            function checkTypeParametersNotReferenced(root, typeParameters, index) {
                visit(root);
                function visit(node) {
                    if (node.kind === 180 /* TypeReference */) {
                        const type = getTypeFromTypeReference(node);
                        if (type.flags & 262144 /* TypeParameter */) {
                            for (let i = index; i < typeParameters.length; i++) {
                                if (type.symbol === getSymbolOfDeclaration(typeParameters[i])) {
                                    error(node, Diagnostics.Type_parameter_defaults_can_only_reference_previously_declared_type_parameters);
                                }
                            }
                        }
                    }
                    forEachChild(node, visit);
                }
            }
            function checkTypeParameterListsIdentical(symbol) {
                if (symbol.declarations && symbol.declarations.length === 1) {
                    return;
                }
                const links = getSymbolLinks(symbol);
                if (!links.typeParametersChecked) {
                    links.typeParametersChecked = true;
                    const declarations = getClassOrInterfaceDeclarationsOfSymbol(symbol);
                    if (!declarations || declarations.length <= 1) {
                        return;
                    }
                    const type = getDeclaredTypeOfSymbol(symbol);
                    if (!areTypeParametersIdentical(declarations, type.localTypeParameters, getEffectiveTypeParameterDeclarations)) {
                        const name = symbolToString(symbol);
                        for (const declaration of declarations) {
                            error(declaration.name, Diagnostics.All_declarations_of_0_must_have_identical_type_parameters, name);
                        }
                    }
                }
            }
            function areTypeParametersIdentical(declarations, targetParameters, getTypeParameterDeclarations) {
                const maxTypeArgumentCount = length(targetParameters);
                const minTypeArgumentCount = getMinTypeArgumentCount(targetParameters);
                for (const declaration of declarations) {
                    const sourceParameters = getTypeParameterDeclarations(declaration);
                    const numTypeParameters = sourceParameters.length;
                    if (numTypeParameters < minTypeArgumentCount || numTypeParameters > maxTypeArgumentCount) {
                        return false;
                    }
                    for (let i = 0; i < numTypeParameters; i++) {
                        const source = sourceParameters[i];
                        const target = targetParameters[i];
                        if (source.name.escapedText !== target.symbol.escapedName) {
                            return false;
                        }
                        const constraint = getEffectiveConstraintOfTypeParameter(source);
                        const sourceConstraint = constraint && getTypeFromTypeNode(constraint);
                        const targetConstraint = getConstraintOfTypeParameter(target);
                        if (sourceConstraint && targetConstraint && !isTypeIdenticalTo(sourceConstraint, targetConstraint)) {
                            return false;
                        }
                        const sourceDefault = source.default && getTypeFromTypeNode(source.default);
                        const targetDefault = getDefaultFromTypeParameter(target);
                        if (sourceDefault && targetDefault && !isTypeIdenticalTo(sourceDefault, targetDefault)) {
                            return false;
                        }
                    }
                }
                return true;
            }
            function getFirstTransformableStaticClassElement(node) {
                var _a2;
                const willTransformStaticElementsOfDecoratedClass = !legacyDecorators && languageVersion < 99 /* ESNext */ && classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                false, node);
                const willTransformPrivateElementsOrClassStaticBlocks = languageVersion <= 9 /* ES2022 */;
                const willTransformInitializers = !useDefineForClassFields || languageVersion < 9 /* ES2022 */;
                if (willTransformStaticElementsOfDecoratedClass || willTransformPrivateElementsOrClassStaticBlocks) {
                    for (const member of node.members) {
                        if (willTransformStaticElementsOfDecoratedClass && classElementOrClassElementParameterIsDecorated(
                        /*useLegacyDecorators*/
                        false, member, node)) {
                            return (_a2 = firstOrUndefined(getDecorators(node))) != null ? _a2 : node;
                        }
                        else if (willTransformPrivateElementsOrClassStaticBlocks) {
                            if (isClassStaticBlockDeclaration(member)) {
                                return member;
                            }
                            else if (isStatic(member)) {
                                if (isPrivateIdentifierClassElementDeclaration(member) || willTransformInitializers && isInitializedProperty(member)) {
                                    return member;
                                }
                            }
                        }
                    }
                }
            }
            function checkClassExpressionExternalHelpers(node) {
                var _a2;
                if (node.name)
                    return;
                const parent2 = walkUpOuterExpressions(node);
                if (!isNamedEvaluationSource(parent2))
                    return;
                const willTransformESDecorators = !legacyDecorators && languageVersion < 99 /* ESNext */;
                let location;
                if (willTransformESDecorators && classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                false, node)) {
                    location = (_a2 = firstOrUndefined(getDecorators(node))) != null ? _a2 : node;
                }
                else {
                    location = getFirstTransformableStaticClassElement(node);
                }
                if (location) {
                    checkExternalEmitHelpers(location, 8388608 /* SetFunctionName */);
                    if ((isPropertyAssignment(parent2) || isPropertyDeclaration(parent2) || isBindingElement(parent2)) && isComputedPropertyName(parent2.name)) {
                        checkExternalEmitHelpers(location, 16777216 /* PropKey */);
                    }
                }
            }
            function checkClassExpression(node) {
                checkClassLikeDeclaration(node);
                checkNodeDeferred(node);
                checkClassExpressionExternalHelpers(node);
                return getTypeOfSymbol(getSymbolOfDeclaration(node));
            }
            function checkClassExpressionDeferred(node) {
                forEach(node.members, checkSourceElement);
                registerForUnusedIdentifiersCheck(node);
            }
            function checkClassDeclaration(node) {
                const firstDecorator = find(node.modifiers, isDecorator);
                if (legacyDecorators && firstDecorator && some(node.members, (p) => hasStaticModifier(p) && isPrivateIdentifierClassElementDeclaration(p))) {
                    grammarErrorOnNode(firstDecorator, Diagnostics.Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator);
                }
                if (!node.name && !hasSyntacticModifier(node, 1024 /* Default */)) {
                    grammarErrorOnFirstToken(node, Diagnostics.A_class_declaration_without_the_default_modifier_must_have_a_name);
                }
                checkClassLikeDeclaration(node);
                forEach(node.members, checkSourceElement);
                registerForUnusedIdentifiersCheck(node);
            }
            function checkClassLikeDeclaration(node) {
                checkGrammarClassLikeDeclaration(node);
                checkDecorators(node);
                checkCollisionsForDeclarationName(node, node.name);
                checkTypeParameters(getEffectiveTypeParameterDeclarations(node));
                checkExportsOnMergedDeclarations(node);
                const symbol = getSymbolOfDeclaration(node);
                const type = getDeclaredTypeOfSymbol(symbol);
                const typeWithThis = getTypeWithThisArgument(type);
                const staticType = getTypeOfSymbol(symbol);
                checkTypeParameterListsIdentical(symbol);
                checkFunctionOrConstructorSymbol(symbol);
                checkClassForDuplicateDeclarations(node);
                const nodeInAmbientContext = !!(node.flags & 16777216 /* Ambient */);
                if (!nodeInAmbientContext) {
                    checkClassForStaticPropertyNameConflicts(node);
                }
                const baseTypeNode = getEffectiveBaseTypeNode(node);
                if (baseTypeNode) {
                    forEach(baseTypeNode.typeArguments, checkSourceElement);
                    if (languageVersion < 2 /* ES2015 */) {
                        checkExternalEmitHelpers(baseTypeNode.parent, 1 /* Extends */);
                    }
                    const extendsNode = getClassExtendsHeritageElement(node);
                    if (extendsNode && extendsNode !== baseTypeNode) {
                        checkExpression(extendsNode.expression);
                    }
                    const baseTypes = getBaseTypes(type);
                    if (baseTypes.length) {
                        addLazyDiagnostic(() => {
                            const baseType = baseTypes[0];
                            const baseConstructorType = getBaseConstructorTypeOfClass(type);
                            const staticBaseType = getApparentType(baseConstructorType);
                            checkBaseTypeAccessibility(staticBaseType, baseTypeNode);
                            checkSourceElement(baseTypeNode.expression);
                            if (some(baseTypeNode.typeArguments)) {
                                forEach(baseTypeNode.typeArguments, checkSourceElement);
                                for (const constructor of getConstructorsForTypeArguments(staticBaseType, baseTypeNode.typeArguments, baseTypeNode)) {
                                    if (!checkTypeArgumentConstraints(baseTypeNode, constructor.typeParameters)) {
                                        break;
                                    }
                                }
                            }
                            const baseWithThis = getTypeWithThisArgument(baseType, type.thisType);
                            if (!checkTypeAssignableTo(typeWithThis, baseWithThis, 
                            /*errorNode*/
                            void 0)) {
                                issueMemberSpecificError(node, typeWithThis, baseWithThis, Diagnostics.Class_0_incorrectly_extends_base_class_1);
                            }
                            else {
                                checkTypeAssignableTo(staticType, getTypeWithoutSignatures(staticBaseType), node.name || node, Diagnostics.Class_static_side_0_incorrectly_extends_base_class_static_side_1);
                            }
                            if (baseConstructorType.flags & 8650752 /* TypeVariable */) {
                                if (!isMixinConstructorType(staticType)) {
                                    error(node.name || node, Diagnostics.A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any);
                                }
                                else {
                                    const constructSignatures = getSignaturesOfType(baseConstructorType, 1 /* Construct */);
                                    if (constructSignatures.some((signature) => signature.flags & 4 /* Abstract */) && !hasSyntacticModifier(node, 256 /* Abstract */)) {
                                        error(node.name || node, Diagnostics.A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_be_declared_abstract);
                                    }
                                }
                            }
                            if (!(staticBaseType.symbol && staticBaseType.symbol.flags & 32 /* Class */) && !(baseConstructorType.flags & 8650752 /* TypeVariable */)) {
                                const constructors = getInstantiatedConstructorsForTypeArguments(staticBaseType, baseTypeNode.typeArguments, baseTypeNode);
                                if (forEach(constructors, (sig) => !isJSConstructor(sig.declaration) && !isTypeIdenticalTo(getReturnTypeOfSignature(sig), baseType))) {
                                    error(baseTypeNode.expression, Diagnostics.Base_constructors_must_all_have_the_same_return_type);
                                }
                            }
                            checkKindsOfPropertyMemberOverrides(type, baseType);
                        });
                    }
                }
                checkMembersForOverrideModifier(node, type, typeWithThis, staticType);
                const implementedTypeNodes = getEffectiveImplementsTypeNodes(node);
                if (implementedTypeNodes) {
                    for (const typeRefNode of implementedTypeNodes) {
                        if (!isEntityNameExpression(typeRefNode.expression) || isOptionalChain(typeRefNode.expression)) {
                            error(typeRefNode.expression, Diagnostics.A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments);
                        }
                        checkTypeReferenceNode(typeRefNode);
                        addLazyDiagnostic(createImplementsDiagnostics(typeRefNode));
                    }
                }
                addLazyDiagnostic(() => {
                    checkIndexConstraints(type, symbol);
                    checkIndexConstraints(staticType, symbol, 
                    /*isStaticIndex*/
                    true);
                    checkTypeForDuplicateIndexSignatures(node);
                    checkPropertyInitialization(node);
                });
                function createImplementsDiagnostics(typeRefNode) {
                    return () => {
                        const t = getReducedType(getTypeFromTypeNode(typeRefNode));
                        if (!isErrorType(t)) {
                            if (isValidBaseType(t)) {
                                const genericDiag = t.symbol && t.symbol.flags & 32 /* Class */ ? Diagnostics.Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass : Diagnostics.Class_0_incorrectly_implements_interface_1;
                                const baseWithThis = getTypeWithThisArgument(t, type.thisType);
                                if (!checkTypeAssignableTo(typeWithThis, baseWithThis, 
                                /*errorNode*/
                                void 0)) {
                                    issueMemberSpecificError(node, typeWithThis, baseWithThis, genericDiag);
                                }
                            }
                            else {
                                error(typeRefNode, Diagnostics.A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_members);
                            }
                        }
                    };
                }
            }
            function checkMembersForOverrideModifier(node, type, typeWithThis, staticType) {
                const baseTypeNode = getEffectiveBaseTypeNode(node);
                const baseTypes = baseTypeNode && getBaseTypes(type);
                const baseWithThis = (baseTypes == null ? void 0 : baseTypes.length) ? getTypeWithThisArgument(first(baseTypes), type.thisType) : void 0;
                const baseStaticType = getBaseConstructorTypeOfClass(type);
                for (const member of node.members) {
                    if (hasAmbientModifier(member)) {
                        continue;
                    }
                    if (isConstructorDeclaration(member)) {
                        forEach(member.parameters, (param) => {
                            if (isParameterPropertyDeclaration(param, member)) {
                                checkExistingMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, param, 
                                /* memberIsParameterProperty */
                                true);
                            }
                        });
                    }
                    checkExistingMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, member, 
                    /* memberIsParameterProperty */
                    false);
                }
            }
            function checkExistingMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, member, memberIsParameterProperty, reportErrors2 = true) {
                const declaredProp = member.name && getSymbolAtLocation(member.name) || getSymbolAtLocation(member);
                if (!declaredProp) {
                    return 0 /* Ok */;
                }
                return checkMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, hasOverrideModifier(member), hasAbstractModifier(member), isStatic(member), memberIsParameterProperty, symbolName(declaredProp), reportErrors2 ? member : void 0);
            }
            function checkMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, memberHasOverrideModifier, memberHasAbstractModifier, memberIsStatic, memberIsParameterProperty, memberName, errorNode) {
                const isJs = isInJSFile(node);
                const nodeInAmbientContext = !!(node.flags & 16777216 /* Ambient */);
                if (baseWithThis && (memberHasOverrideModifier || compilerOptions.noImplicitOverride)) {
                    const memberEscapedName = escapeLeadingUnderscores(memberName);
                    const thisType = memberIsStatic ? staticType : typeWithThis;
                    const baseType = memberIsStatic ? baseStaticType : baseWithThis;
                    const prop = getPropertyOfType(thisType, memberEscapedName);
                    const baseProp = getPropertyOfType(baseType, memberEscapedName);
                    const baseClassName = typeToString(baseWithThis);
                    if (prop && !baseProp && memberHasOverrideModifier) {
                        if (errorNode) {
                            const suggestion = getSuggestedSymbolForNonexistentClassMember(memberName, baseType);
                            suggestion ? error(errorNode, isJs ? Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1 : Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1, baseClassName, symbolToString(suggestion)) : error(errorNode, isJs ? Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0 : Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0, baseClassName);
                        }
                        return 2 /* HasInvalidOverride */;
                    }
                    else if (prop && (baseProp == null ? void 0 : baseProp.declarations) && compilerOptions.noImplicitOverride && !nodeInAmbientContext) {
                        const baseHasAbstract = some(baseProp.declarations, hasAbstractModifier);
                        if (memberHasOverrideModifier) {
                            return 0 /* Ok */;
                        }
                        if (!baseHasAbstract) {
                            if (errorNode) {
                                const diag2 = memberIsParameterProperty ? isJs ? Diagnostics.This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0 : Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0 : isJs ? Diagnostics.This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0 : Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0;
                                error(errorNode, diag2, baseClassName);
                            }
                            return 1 /* NeedsOverride */;
                        }
                        else if (memberHasAbstractModifier && baseHasAbstract) {
                            if (errorNode) {
                                error(errorNode, Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0, baseClassName);
                            }
                            return 1 /* NeedsOverride */;
                        }
                    }
                }
                else if (memberHasOverrideModifier) {
                    if (errorNode) {
                        const className = typeToString(type);
                        error(errorNode, isJs ? Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class : Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class, className);
                    }
                    return 2 /* HasInvalidOverride */;
                }
                return 0 /* Ok */;
            }
            function issueMemberSpecificError(node, typeWithThis, baseWithThis, broadDiag) {
                let issuedMemberError = false;
                for (const member of node.members) {
                    if (isStatic(member)) {
                        continue;
                    }
                    const declaredProp = member.name && getSymbolAtLocation(member.name) || getSymbolAtLocation(member);
                    if (declaredProp) {
                        const prop = getPropertyOfType(typeWithThis, declaredProp.escapedName);
                        const baseProp = getPropertyOfType(baseWithThis, declaredProp.escapedName);
                        if (prop && baseProp) {
                            const rootChain = () => chainDiagnosticMessages(
                            /*details*/
                            void 0, Diagnostics.Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2, symbolToString(declaredProp), typeToString(typeWithThis), typeToString(baseWithThis));
                            if (!checkTypeAssignableTo(getTypeOfSymbol(prop), getTypeOfSymbol(baseProp), member.name || member, 
                            /*message*/
                            void 0, rootChain)) {
                                issuedMemberError = true;
                            }
                        }
                    }
                }
                if (!issuedMemberError) {
                    checkTypeAssignableTo(typeWithThis, baseWithThis, node.name || node, broadDiag);
                }
            }
            function checkBaseTypeAccessibility(type, node) {
                const signatures = getSignaturesOfType(type, 1 /* Construct */);
                if (signatures.length) {
                    const declaration = signatures[0].declaration;
                    if (declaration && hasEffectiveModifier(declaration, 8 /* Private */)) {
                        const typeClassDeclaration = getClassLikeDeclarationOfSymbol(type.symbol);
                        if (!isNodeWithinClass(node, typeClassDeclaration)) {
                            error(node, Diagnostics.Cannot_extend_a_class_0_Class_constructor_is_marked_as_private, getFullyQualifiedName(type.symbol));
                        }
                    }
                }
            }
            function getMemberOverrideModifierStatus(node, member, memberSymbol) {
                if (!member.name) {
                    return 0 /* Ok */;
                }
                const classSymbol = getSymbolOfDeclaration(node);
                const type = getDeclaredTypeOfSymbol(classSymbol);
                const typeWithThis = getTypeWithThisArgument(type);
                const staticType = getTypeOfSymbol(classSymbol);
                const baseTypeNode = getEffectiveBaseTypeNode(node);
                const baseTypes = baseTypeNode && getBaseTypes(type);
                const baseWithThis = (baseTypes == null ? void 0 : baseTypes.length) ? getTypeWithThisArgument(first(baseTypes), type.thisType) : void 0;
                const baseStaticType = getBaseConstructorTypeOfClass(type);
                const memberHasOverrideModifier = member.parent ? hasOverrideModifier(member) : hasSyntacticModifier(member, 16384 /* Override */);
                return checkMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, memberHasOverrideModifier, hasAbstractModifier(member), isStatic(member), 
                /* memberIsParameterProperty */
                false, symbolName(memberSymbol));
            }
            function getTargetSymbol(s) {
                return getCheckFlags(s) & 1 /* Instantiated */ ? s.links.target : s;
            }
            function getClassOrInterfaceDeclarationsOfSymbol(symbol) {
                return filter(symbol.declarations, (d) => d.kind === 260 /* ClassDeclaration */ || d.kind === 261 /* InterfaceDeclaration */);
            }
            function checkKindsOfPropertyMemberOverrides(type, baseType) {
                var _a2, _b, _c, _d;
                const baseProperties = getPropertiesOfType(baseType);
                basePropertyCheck: for (const baseProperty of baseProperties) {
                    const base = getTargetSymbol(baseProperty);
                    if (base.flags & 4194304 /* Prototype */) {
                        continue;
                    }
                    const baseSymbol = getPropertyOfObjectType(type, base.escapedName);
                    if (!baseSymbol) {
                        continue;
                    }
                    const derived = getTargetSymbol(baseSymbol);
                    const baseDeclarationFlags = getDeclarationModifierFlagsFromSymbol(base);
                    Debug.assert(!!derived, "derived should point to something, even if it is the base class' declaration.");
                    if (derived === base) {
                        const derivedClassDecl = getClassLikeDeclarationOfSymbol(type.symbol);
                        if (baseDeclarationFlags & 256 /* Abstract */ && (!derivedClassDecl || !hasSyntacticModifier(derivedClassDecl, 256 /* Abstract */))) {
                            for (const otherBaseType of getBaseTypes(type)) {
                                if (otherBaseType === baseType)
                                    continue;
                                const baseSymbol2 = getPropertyOfObjectType(otherBaseType, base.escapedName);
                                const derivedElsewhere = baseSymbol2 && getTargetSymbol(baseSymbol2);
                                if (derivedElsewhere && derivedElsewhere !== base) {
                                    continue basePropertyCheck;
                                }
                            }
                            if (derivedClassDecl.kind === 228 /* ClassExpression */) {
                                error(derivedClassDecl, Diagnostics.Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1, symbolToString(baseProperty), typeToString(baseType));
                            }
                            else {
                                error(derivedClassDecl, Diagnostics.Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2, typeToString(type), symbolToString(baseProperty), typeToString(baseType));
                            }
                        }
                    }
                    else {
                        const derivedDeclarationFlags = getDeclarationModifierFlagsFromSymbol(derived);
                        if (baseDeclarationFlags & 8 /* Private */ || derivedDeclarationFlags & 8 /* Private */) {
                            continue;
                        }
                        let errorMessage;
                        const basePropertyFlags = base.flags & 98308 /* PropertyOrAccessor */;
                        const derivedPropertyFlags = derived.flags & 98308 /* PropertyOrAccessor */;
                        if (basePropertyFlags && derivedPropertyFlags) {
                            if ((getCheckFlags(base) & 6 /* Synthetic */ ? (_a2 = base.declarations) == null ? void 0 : _a2.some((d) => isPropertyAbstractOrInterface(d, baseDeclarationFlags)) : (_b = base.declarations) == null ? void 0 : _b.every((d) => isPropertyAbstractOrInterface(d, baseDeclarationFlags))) || getCheckFlags(base) & 262144 /* Mapped */ || derived.valueDeclaration && isBinaryExpression(derived.valueDeclaration)) {
                                continue;
                            }
                            const overriddenInstanceProperty = basePropertyFlags !== 4 /* Property */ && derivedPropertyFlags === 4 /* Property */;
                            const overriddenInstanceAccessor = basePropertyFlags === 4 /* Property */ && derivedPropertyFlags !== 4 /* Property */;
                            if (overriddenInstanceProperty || overriddenInstanceAccessor) {
                                const errorMessage2 = overriddenInstanceProperty ? Diagnostics._0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property : Diagnostics._0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor;
                                error(getNameOfDeclaration(derived.valueDeclaration) || derived.valueDeclaration, errorMessage2, symbolToString(base), typeToString(baseType), typeToString(type));
                            }
                            else if (useDefineForClassFields) {
                                const uninitialized = (_c = derived.declarations) == null ? void 0 : _c.find((d) => d.kind === 169 /* PropertyDeclaration */ && !d.initializer);
                                if (uninitialized && !(derived.flags & 33554432 /* Transient */) && !(baseDeclarationFlags & 256 /* Abstract */) && !(derivedDeclarationFlags & 256 /* Abstract */) && !((_d = derived.declarations) == null ? void 0 : _d.some((d) => !!(d.flags & 16777216 /* Ambient */)))) {
                                    const constructor = findConstructorDeclaration(getClassLikeDeclarationOfSymbol(type.symbol));
                                    const propName = uninitialized.name;
                                    if (uninitialized.exclamationToken || !constructor || !isIdentifier(propName) || !strictNullChecks || !isPropertyInitializedInConstructor(propName, type, constructor)) {
                                        const errorMessage2 = Diagnostics.Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration;
                                        error(getNameOfDeclaration(derived.valueDeclaration) || derived.valueDeclaration, errorMessage2, symbolToString(base), typeToString(baseType));
                                    }
                                }
                            }
                            continue;
                        }
                        else if (isPrototypeProperty(base)) {
                            if (isPrototypeProperty(derived) || derived.flags & 4 /* Property */) {
                                continue;
                            }
                            else {
                                Debug.assert(!!(derived.flags & 98304 /* Accessor */));
                                errorMessage = Diagnostics.Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor;
                            }
                        }
                        else if (base.flags & 98304 /* Accessor */) {
                            errorMessage = Diagnostics.Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function;
                        }
                        else {
                            errorMessage = Diagnostics.Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function;
                        }
                        error(getNameOfDeclaration(derived.valueDeclaration) || derived.valueDeclaration, errorMessage, typeToString(baseType), symbolToString(base), typeToString(type));
                    }
                }
            }
            function isPropertyAbstractOrInterface(declaration, baseDeclarationFlags) {
                return baseDeclarationFlags & 256 /* Abstract */ && (!isPropertyDeclaration(declaration) || !declaration.initializer) || isInterfaceDeclaration(declaration.parent);
            }
            function getNonInheritedProperties(type, baseTypes, properties) {
                if (!length(baseTypes)) {
                    return properties;
                }
                const seen = /* @__PURE__ */ new Map();
                forEach(properties, (p) => {
                    seen.set(p.escapedName, p);
                });
                for (const base of baseTypes) {
                    const properties2 = getPropertiesOfType(getTypeWithThisArgument(base, type.thisType));
                    for (const prop of properties2) {
                        const existing = seen.get(prop.escapedName);
                        if (existing && prop.parent === existing.parent) {
                            seen.delete(prop.escapedName);
                        }
                    }
                }
                return arrayFrom(seen.values());
            }
            function checkInheritedPropertiesAreIdentical(type, typeNode) {
                const baseTypes = getBaseTypes(type);
                if (baseTypes.length < 2) {
                    return true;
                }
                const seen = /* @__PURE__ */ new Map();
                forEach(resolveDeclaredMembers(type).declaredProperties, (p) => {
                    seen.set(p.escapedName, { prop: p, containingType: type });
                });
                let ok = true;
                for (const base of baseTypes) {
                    const properties = getPropertiesOfType(getTypeWithThisArgument(base, type.thisType));
                    for (const prop of properties) {
                        const existing = seen.get(prop.escapedName);
                        if (!existing) {
                            seen.set(prop.escapedName, { prop, containingType: base });
                        }
                        else {
                            const isInheritedProperty = existing.containingType !== type;
                            if (isInheritedProperty && !isPropertyIdenticalTo(existing.prop, prop)) {
                                ok = false;
                                const typeName1 = typeToString(existing.containingType);
                                const typeName2 = typeToString(base);
                                let errorInfo = chainDiagnosticMessages(
                                /*details*/
                                void 0, Diagnostics.Named_property_0_of_types_1_and_2_are_not_identical, symbolToString(prop), typeName1, typeName2);
                                errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Interface_0_cannot_simultaneously_extend_types_1_and_2, typeToString(type), typeName1, typeName2);
                                diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(typeNode), typeNode, errorInfo));
                            }
                        }
                    }
                }
                return ok;
            }
            function checkPropertyInitialization(node) {
                if (!strictNullChecks || !strictPropertyInitialization || node.flags & 16777216 /* Ambient */) {
                    return;
                }
                const constructor = findConstructorDeclaration(node);
                for (const member of node.members) {
                    if (getEffectiveModifierFlags(member) & 2 /* Ambient */) {
                        continue;
                    }
                    if (!isStatic(member) && isPropertyWithoutInitializer(member)) {
                        const propName = member.name;
                        if (isIdentifier(propName) || isPrivateIdentifier(propName) || isComputedPropertyName(propName)) {
                            const type = getTypeOfSymbol(getSymbolOfDeclaration(member));
                            if (!(type.flags & 3 /* AnyOrUnknown */ || containsUndefinedType(type))) {
                                if (!constructor || !isPropertyInitializedInConstructor(propName, type, constructor)) {
                                    error(member.name, Diagnostics.Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor, declarationNameToString(propName));
                                }
                            }
                        }
                    }
                }
            }
            function isPropertyWithoutInitializer(node) {
                return node.kind === 169 /* PropertyDeclaration */ && !hasAbstractModifier(node) && !node.exclamationToken && !node.initializer;
            }
            function isPropertyInitializedInStaticBlocks(propName, propType, staticBlocks, startPos, endPos) {
                for (const staticBlock of staticBlocks) {
                    if (staticBlock.pos >= startPos && staticBlock.pos <= endPos) {
                        const reference = factory.createPropertyAccessExpression(factory.createThis(), propName);
                        setParent(reference.expression, reference);
                        setParent(reference, staticBlock);
                        reference.flowNode = staticBlock.returnFlowNode;
                        const flowType = getFlowTypeOfReference(reference, propType, getOptionalType(propType));
                        if (!containsUndefinedType(flowType)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function isPropertyInitializedInConstructor(propName, propType, constructor) {
                const reference = isComputedPropertyName(propName) ? factory.createElementAccessExpression(factory.createThis(), propName.expression) : factory.createPropertyAccessExpression(factory.createThis(), propName);
                setParent(reference.expression, reference);
                setParent(reference, constructor);
                reference.flowNode = constructor.returnFlowNode;
                const flowType = getFlowTypeOfReference(reference, propType, getOptionalType(propType));
                return !containsUndefinedType(flowType);
            }
            function checkInterfaceDeclaration(node) {
                if (!checkGrammarModifiers(node))
                    checkGrammarInterfaceDeclaration(node);
                checkTypeParameters(node.typeParameters);
                addLazyDiagnostic(() => {
                    checkTypeNameIsReserved(node.name, Diagnostics.Interface_name_cannot_be_0);
                    checkExportsOnMergedDeclarations(node);
                    const symbol = getSymbolOfDeclaration(node);
                    checkTypeParameterListsIdentical(symbol);
                    const firstInterfaceDecl = getDeclarationOfKind(symbol, 261 /* InterfaceDeclaration */);
                    if (node === firstInterfaceDecl) {
                        const type = getDeclaredTypeOfSymbol(symbol);
                        const typeWithThis = getTypeWithThisArgument(type);
                        if (checkInheritedPropertiesAreIdentical(type, node.name)) {
                            for (const baseType of getBaseTypes(type)) {
                                checkTypeAssignableTo(typeWithThis, getTypeWithThisArgument(baseType, type.thisType), node.name, Diagnostics.Interface_0_incorrectly_extends_interface_1);
                            }
                            checkIndexConstraints(type, symbol);
                        }
                    }
                    checkObjectTypeForDuplicateDeclarations(node);
                });
                forEach(getInterfaceBaseTypeNodes(node), (heritageElement) => {
                    if (!isEntityNameExpression(heritageElement.expression) || isOptionalChain(heritageElement.expression)) {
                        error(heritageElement.expression, Diagnostics.An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments);
                    }
                    checkTypeReferenceNode(heritageElement);
                });
                forEach(node.members, checkSourceElement);
                addLazyDiagnostic(() => {
                    checkTypeForDuplicateIndexSignatures(node);
                    registerForUnusedIdentifiersCheck(node);
                });
            }
            function checkTypeAliasDeclaration(node) {
                checkGrammarModifiers(node);
                checkTypeNameIsReserved(node.name, Diagnostics.Type_alias_name_cannot_be_0);
                checkExportsOnMergedDeclarations(node);
                checkTypeParameters(node.typeParameters);
                if (node.type.kind === 139 /* IntrinsicKeyword */) {
                    if (!intrinsicTypeKinds.has(node.name.escapedText) || length(node.typeParameters) !== 1) {
                        error(node.type, Diagnostics.The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types);
                    }
                }
                else {
                    checkSourceElement(node.type);
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function computeEnumMemberValues(node) {
                const nodeLinks2 = getNodeLinks(node);
                if (!(nodeLinks2.flags & 1024 /* EnumValuesComputed */)) {
                    nodeLinks2.flags |= 1024 /* EnumValuesComputed */;
                    let autoValue = 0;
                    for (const member of node.members) {
                        const value = computeMemberValue(member, autoValue);
                        getNodeLinks(member).enumMemberValue = value;
                        autoValue = typeof value === "number" ? value + 1 : void 0;
                    }
                }
            }
            function computeMemberValue(member, autoValue) {
                if (isComputedNonLiteralName(member.name)) {
                    error(member.name, Diagnostics.Computed_property_names_are_not_allowed_in_enums);
                }
                else {
                    const text = getTextOfPropertyName(member.name);
                    if (isNumericLiteralName(text) && !isInfinityOrNaNString(text)) {
                        error(member.name, Diagnostics.An_enum_member_cannot_have_a_numeric_name);
                    }
                }
                if (member.initializer) {
                    return computeConstantValue(member);
                }
                if (member.parent.flags & 16777216 /* Ambient */ && !isEnumConst(member.parent)) {
                    return void 0;
                }
                if (autoValue !== void 0) {
                    return autoValue;
                }
                error(member.name, Diagnostics.Enum_member_must_have_initializer);
                return void 0;
            }
            function computeConstantValue(member) {
                const isConstEnum = isEnumConst(member.parent);
                const initializer = member.initializer;
                const value = evaluate(initializer, member);
                if (value !== void 0) {
                    if (isConstEnum && typeof value === "number" && !isFinite(value)) {
                        error(initializer, isNaN(value) ? Diagnostics.const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN : Diagnostics.const_enum_member_initializer_was_evaluated_to_a_non_finite_value);
                    }
                }
                else if (isConstEnum) {
                    error(initializer, Diagnostics.const_enum_member_initializers_must_be_constant_expressions);
                }
                else if (member.parent.flags & 16777216 /* Ambient */) {
                    error(initializer, Diagnostics.In_ambient_enum_declarations_member_initializer_must_be_constant_expression);
                }
                else {
                    checkTypeAssignableTo(checkExpression(initializer), numberType, initializer, Diagnostics.Type_0_is_not_assignable_to_type_1_as_required_for_computed_enum_member_values);
                }
                return value;
            }
            function evaluate(expr, location) {
                switch (expr.kind) {
                    case 221 /* PrefixUnaryExpression */:
                        const value = evaluate(expr.operand, location);
                        if (typeof value === "number") {
                            switch (expr.operator) {
                                case 39 /* PlusToken */:
                                    return value;
                                case 40 /* MinusToken */:
                                    return -value;
                                case 54 /* TildeToken */:
                                    return ~value;
                            }
                        }
                        break;
                    case 223 /* BinaryExpression */:
                        const left = evaluate(expr.left, location);
                        const right = evaluate(expr.right, location);
                        if (typeof left === "number" && typeof right === "number") {
                            switch (expr.operatorToken.kind) {
                                case 51 /* BarToken */:
                                    return left | right;
                                case 50 /* AmpersandToken */:
                                    return left & right;
                                case 48 /* GreaterThanGreaterThanToken */:
                                    return left >> right;
                                case 49 /* GreaterThanGreaterThanGreaterThanToken */:
                                    return left >>> right;
                                case 47 /* LessThanLessThanToken */:
                                    return left << right;
                                case 52 /* CaretToken */:
                                    return left ^ right;
                                case 41 /* AsteriskToken */:
                                    return left * right;
                                case 43 /* SlashToken */:
                                    return left / right;
                                case 39 /* PlusToken */:
                                    return left + right;
                                case 40 /* MinusToken */:
                                    return left - right;
                                case 44 /* PercentToken */:
                                    return left % right;
                                case 42 /* AsteriskAsteriskToken */:
                                    return left ** right;
                            }
                        }
                        else if ((typeof left === "string" || typeof left === "number") && (typeof right === "string" || typeof right === "number") && expr.operatorToken.kind === 39 /* PlusToken */) {
                            return "" + left + right;
                        }
                        break;
                    case 10 /* StringLiteral */:
                    case 14 /* NoSubstitutionTemplateLiteral */:
                        return expr.text;
                    case 225 /* TemplateExpression */:
                        return evaluateTemplateExpression(expr, location);
                    case 8 /* NumericLiteral */:
                        checkGrammarNumericLiteral(expr);
                        return +expr.text;
                    case 214 /* ParenthesizedExpression */:
                        return evaluate(expr.expression, location);
                    case 79 /* Identifier */:
                        if (isInfinityOrNaNString(expr.escapedText)) {
                            return +expr.escapedText;
                        }
                    case 208 /* PropertyAccessExpression */:
                        if (isEntityNameExpression(expr)) {
                            const symbol = resolveEntityName(expr, 111551 /* Value */, 
                            /*ignoreErrors*/
                            true);
                            if (symbol) {
                                if (symbol.flags & 8 /* EnumMember */) {
                                    return evaluateEnumMember(expr, symbol, location);
                                }
                                if (isConstVariable(symbol)) {
                                    const declaration = symbol.valueDeclaration;
                                    if (declaration && !declaration.type && declaration.initializer && declaration !== location && isBlockScopedNameDeclaredBeforeUse(declaration, location)) {
                                        return evaluate(declaration.initializer, declaration);
                                    }
                                }
                            }
                        }
                        break;
                    case 209 /* ElementAccessExpression */:
                        const root = expr.expression;
                        if (isEntityNameExpression(root) && isStringLiteralLike(expr.argumentExpression)) {
                            const rootSymbol = resolveEntityName(root, 111551 /* Value */, 
                            /*ignoreErrors*/
                            true);
                            if (rootSymbol && rootSymbol.flags & 384 /* Enum */) {
                                const name = escapeLeadingUnderscores(expr.argumentExpression.text);
                                const member = rootSymbol.exports.get(name);
                                if (member) {
                                    return evaluateEnumMember(expr, member, location);
                                }
                            }
                        }
                        break;
                }
                return void 0;
            }
            function evaluateEnumMember(expr, symbol, location) {
                const declaration = symbol.valueDeclaration;
                if (!declaration || declaration === location) {
                    error(expr, Diagnostics.Property_0_is_used_before_being_assigned, symbolToString(symbol));
                    return void 0;
                }
                if (!isBlockScopedNameDeclaredBeforeUse(declaration, location)) {
                    error(expr, Diagnostics.A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums);
                    return 0;
                }
                return getEnumMemberValue(declaration);
            }
            function evaluateTemplateExpression(expr, location) {
                let result = expr.head.text;
                for (const span of expr.templateSpans) {
                    const value = evaluate(span.expression, location);
                    if (value === void 0) {
                        return void 0;
                    }
                    result += value;
                    result += span.literal.text;
                }
                return result;
            }
            function checkEnumDeclaration(node) {
                addLazyDiagnostic(() => checkEnumDeclarationWorker(node));
            }
            function checkEnumDeclarationWorker(node) {
                checkGrammarModifiers(node);
                checkCollisionsForDeclarationName(node, node.name);
                checkExportsOnMergedDeclarations(node);
                node.members.forEach(checkEnumMember);
                computeEnumMemberValues(node);
                const enumSymbol = getSymbolOfDeclaration(node);
                const firstDeclaration = getDeclarationOfKind(enumSymbol, node.kind);
                if (node === firstDeclaration) {
                    if (enumSymbol.declarations && enumSymbol.declarations.length > 1) {
                        const enumIsConst = isEnumConst(node);
                        forEach(enumSymbol.declarations, (decl) => {
                            if (isEnumDeclaration(decl) && isEnumConst(decl) !== enumIsConst) {
                                error(getNameOfDeclaration(decl), Diagnostics.Enum_declarations_must_all_be_const_or_non_const);
                            }
                        });
                    }
                    let seenEnumMissingInitialInitializer = false;
                    forEach(enumSymbol.declarations, (declaration) => {
                        if (declaration.kind !== 263 /* EnumDeclaration */) {
                            return false;
                        }
                        const enumDeclaration = declaration;
                        if (!enumDeclaration.members.length) {
                            return false;
                        }
                        const firstEnumMember = enumDeclaration.members[0];
                        if (!firstEnumMember.initializer) {
                            if (seenEnumMissingInitialInitializer) {
                                error(firstEnumMember.name, Diagnostics.In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element);
                            }
                            else {
                                seenEnumMissingInitialInitializer = true;
                            }
                        }
                    });
                }
            }
            function checkEnumMember(node) {
                if (isPrivateIdentifier(node.name)) {
                    error(node, Diagnostics.An_enum_member_cannot_be_named_with_a_private_identifier);
                }
                if (node.initializer) {
                    checkExpression(node.initializer);
                }
            }
            function getFirstNonAmbientClassOrFunctionDeclaration(symbol) {
                const declarations = symbol.declarations;
                if (declarations) {
                    for (const declaration of declarations) {
                        if ((declaration.kind === 260 /* ClassDeclaration */ || declaration.kind === 259 /* FunctionDeclaration */ && nodeIsPresent(declaration.body)) && !(declaration.flags & 16777216 /* Ambient */)) {
                            return declaration;
                        }
                    }
                }
                return void 0;
            }
            function inSameLexicalScope(node1, node2) {
                const container1 = getEnclosingBlockScopeContainer(node1);
                const container2 = getEnclosingBlockScopeContainer(node2);
                if (isGlobalSourceFile(container1)) {
                    return isGlobalSourceFile(container2);
                }
                else if (isGlobalSourceFile(container2)) {
                    return false;
                }
                else {
                    return container1 === container2;
                }
            }
            function checkModuleDeclaration(node) {
                if (node.body) {
                    checkSourceElement(node.body);
                    if (!isGlobalScopeAugmentation(node)) {
                        registerForUnusedIdentifiersCheck(node);
                    }
                }
                addLazyDiagnostic(checkModuleDeclarationDiagnostics);
                function checkModuleDeclarationDiagnostics() {
                    var _a2, _b;
                    const isGlobalAugmentation = isGlobalScopeAugmentation(node);
                    const inAmbientContext = node.flags & 16777216 /* Ambient */;
                    if (isGlobalAugmentation && !inAmbientContext) {
                        error(node.name, Diagnostics.Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context);
                    }
                    const isAmbientExternalModule = isAmbientModule(node);
                    const contextErrorMessage = isAmbientExternalModule ? Diagnostics.An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file : Diagnostics.A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module;
                    if (checkGrammarModuleElementContext(node, contextErrorMessage)) {
                        return;
                    }
                    if (!checkGrammarModifiers(node)) {
                        if (!inAmbientContext && node.name.kind === 10 /* StringLiteral */) {
                            grammarErrorOnNode(node.name, Diagnostics.Only_ambient_modules_can_use_quoted_names);
                        }
                    }
                    if (isIdentifier(node.name)) {
                        checkCollisionsForDeclarationName(node, node.name);
                    }
                    checkExportsOnMergedDeclarations(node);
                    const symbol = getSymbolOfDeclaration(node);
                    if (symbol.flags & 512 /* ValueModule */ && !inAmbientContext && isInstantiatedModule(node, shouldPreserveConstEnums(compilerOptions))) {
                        if (getIsolatedModules(compilerOptions) && !getSourceFileOfNode(node).externalModuleIndicator) {
                            error(node.name, Diagnostics.Namespaces_are_not_allowed_in_global_script_files_when_0_is_enabled_If_this_file_is_not_intended_to_be_a_global_script_set_moduleDetection_to_force_or_add_an_empty_export_statement, isolatedModulesLikeFlagName);
                        }
                        if (((_a2 = symbol.declarations) == null ? void 0 : _a2.length) > 1) {
                            const firstNonAmbientClassOrFunc = getFirstNonAmbientClassOrFunctionDeclaration(symbol);
                            if (firstNonAmbientClassOrFunc) {
                                if (getSourceFileOfNode(node) !== getSourceFileOfNode(firstNonAmbientClassOrFunc)) {
                                    error(node.name, Diagnostics.A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged);
                                }
                                else if (node.pos < firstNonAmbientClassOrFunc.pos) {
                                    error(node.name, Diagnostics.A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged);
                                }
                            }
                            const mergedClass = getDeclarationOfKind(symbol, 260 /* ClassDeclaration */);
                            if (mergedClass && inSameLexicalScope(node, mergedClass)) {
                                getNodeLinks(node).flags |= 2048 /* LexicalModuleMergesWithClass */;
                            }
                        }
                        if (compilerOptions.verbatimModuleSyntax && node.parent.kind === 308 /* SourceFile */ && (moduleKind === 1 /* CommonJS */ || node.parent.impliedNodeFormat === 1 /* CommonJS */)) {
                            const exportModifier = (_b = node.modifiers) == null ? void 0 : _b.find((m) => m.kind === 93 /* ExportKeyword */);
                            if (exportModifier) {
                                error(exportModifier, Diagnostics.A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                            }
                        }
                    }
                    if (isAmbientExternalModule) {
                        if (isExternalModuleAugmentation(node)) {
                            const checkBody = isGlobalAugmentation || getSymbolOfDeclaration(node).flags & 33554432 /* Transient */;
                            if (checkBody && node.body) {
                                for (const statement of node.body.statements) {
                                    checkModuleAugmentationElement(statement, isGlobalAugmentation);
                                }
                            }
                        }
                        else if (isGlobalSourceFile(node.parent)) {
                            if (isGlobalAugmentation) {
                                error(node.name, Diagnostics.Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations);
                            }
                            else if (isExternalModuleNameRelative(getTextOfIdentifierOrLiteral(node.name))) {
                                error(node.name, Diagnostics.Ambient_module_declaration_cannot_specify_relative_module_name);
                            }
                        }
                        else {
                            if (isGlobalAugmentation) {
                                error(node.name, Diagnostics.Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations);
                            }
                            else {
                                error(node.name, Diagnostics.Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces);
                            }
                        }
                    }
                }
            }
            function checkModuleAugmentationElement(node, isGlobalAugmentation) {
                switch (node.kind) {
                    case 240 /* VariableStatement */:
                        for (const decl of node.declarationList.declarations) {
                            checkModuleAugmentationElement(decl, isGlobalAugmentation);
                        }
                        break;
                    case 274 /* ExportAssignment */:
                    case 275 /* ExportDeclaration */:
                        grammarErrorOnFirstToken(node, Diagnostics.Exports_and_export_assignments_are_not_permitted_in_module_augmentations);
                        break;
                    case 268 /* ImportEqualsDeclaration */:
                    case 269 /* ImportDeclaration */:
                        grammarErrorOnFirstToken(node, Diagnostics.Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module);
                        break;
                    case 205 /* BindingElement */:
                    case 257 /* VariableDeclaration */:
                        const name = node.name;
                        if (isBindingPattern(name)) {
                            for (const el of name.elements) {
                                checkModuleAugmentationElement(el, isGlobalAugmentation);
                            }
                            break;
                        }
                    case 260 /* ClassDeclaration */:
                    case 263 /* EnumDeclaration */:
                    case 259 /* FunctionDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                    case 264 /* ModuleDeclaration */:
                    case 262 /* TypeAliasDeclaration */:
                        if (isGlobalAugmentation) {
                            return;
                        }
                        break;
                }
            }
            function getFirstNonModuleExportsIdentifier(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        return node;
                    case 163 /* QualifiedName */:
                        do {
                            node = node.left;
                        } while (node.kind !== 79 /* Identifier */);
                        return node;
                    case 208 /* PropertyAccessExpression */:
                        do {
                            if (isModuleExportsAccessExpression(node.expression) && !isPrivateIdentifier(node.name)) {
                                return node.name;
                            }
                            node = node.expression;
                        } while (node.kind !== 79 /* Identifier */);
                        return node;
                }
            }
            function checkExternalImportOrExportDeclaration(node) {
                const moduleName = getExternalModuleName(node);
                if (!moduleName || nodeIsMissing(moduleName)) {
                    return false;
                }
                if (!isStringLiteral(moduleName)) {
                    error(moduleName, Diagnostics.String_literal_expected);
                    return false;
                }
                const inAmbientExternalModule = node.parent.kind === 265 /* ModuleBlock */ && isAmbientModule(node.parent.parent);
                if (node.parent.kind !== 308 /* SourceFile */ && !inAmbientExternalModule) {
                    error(moduleName, node.kind === 275 /* ExportDeclaration */ ? Diagnostics.Export_declarations_are_not_permitted_in_a_namespace : Diagnostics.Import_declarations_in_a_namespace_cannot_reference_a_module);
                    return false;
                }
                if (inAmbientExternalModule && isExternalModuleNameRelative(moduleName.text)) {
                    if (!isTopLevelInExternalModuleAugmentation(node)) {
                        error(node, Diagnostics.Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name);
                        return false;
                    }
                }
                if (!isImportEqualsDeclaration(node) && node.assertClause) {
                    let hasError = false;
                    for (const clause of node.assertClause.elements) {
                        if (!isStringLiteral(clause.value)) {
                            hasError = true;
                            error(clause.value, Diagnostics.Import_assertion_values_must_be_string_literal_expressions);
                        }
                    }
                    return !hasError;
                }
                return true;
            }
            function checkAliasSymbol(node) {
                var _a2, _b, _c, _d, _e;
                let symbol = getSymbolOfDeclaration(node);
                const target = resolveAlias(symbol);
                if (target !== unknownSymbol) {
                    symbol = getMergedSymbol(symbol.exportSymbol || symbol);
                    if (isInJSFile(node) && !(target.flags & 111551 /* Value */) && !isTypeOnlyImportOrExportDeclaration(node)) {
                        const errorNode = isImportOrExportSpecifier(node) ? node.propertyName || node.name : isNamedDeclaration(node) ? node.name : node;
                        Debug.assert(node.kind !== 277 /* NamespaceExport */);
                        if (node.kind === 278 /* ExportSpecifier */) {
                            const diag2 = error(errorNode, Diagnostics.Types_cannot_appear_in_export_declarations_in_JavaScript_files);
                            const alreadyExportedSymbol = (_b = (_a2 = getSourceFileOfNode(node).symbol) == null ? void 0 : _a2.exports) == null ? void 0 : _b.get((node.propertyName || node.name).escapedText);
                            if (alreadyExportedSymbol === target) {
                                const exportingDeclaration = (_c = alreadyExportedSymbol.declarations) == null ? void 0 : _c.find(isJSDocNode);
                                if (exportingDeclaration) {
                                    addRelatedInfo(diag2, createDiagnosticForNode(exportingDeclaration, Diagnostics._0_is_automatically_exported_here, unescapeLeadingUnderscores(alreadyExportedSymbol.escapedName)));
                                }
                            }
                        }
                        else {
                            Debug.assert(node.kind !== 257 /* VariableDeclaration */);
                            const importDeclaration = findAncestor(node, or(isImportDeclaration, isImportEqualsDeclaration));
                            const moduleSpecifier = (_e = importDeclaration && ((_d = tryGetModuleSpecifierFromDeclaration(importDeclaration)) == null ? void 0 : _d.text)) != null ? _e : "...";
                            const importedIdentifier = unescapeLeadingUnderscores(isIdentifier(errorNode) ? errorNode.escapedText : symbol.escapedName);
                            error(errorNode, Diagnostics._0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation, importedIdentifier, `import("${moduleSpecifier}").${importedIdentifier}`);
                        }
                        return;
                    }
                    const targetFlags = getAllSymbolFlags(target);
                    const excludedMeanings = (symbol.flags & (111551 /* Value */ | 1048576 /* ExportValue */) ? 111551 /* Value */ : 0) | (symbol.flags & 788968 /* Type */ ? 788968 /* Type */ : 0) | (symbol.flags & 1920 /* Namespace */ ? 1920 /* Namespace */ : 0);
                    if (targetFlags & excludedMeanings) {
                        const message = node.kind === 278 /* ExportSpecifier */ ? Diagnostics.Export_declaration_conflicts_with_exported_declaration_of_0 : Diagnostics.Import_declaration_conflicts_with_local_declaration_of_0;
                        error(node, message, symbolToString(symbol));
                    }
                    if (getIsolatedModules(compilerOptions) && !isTypeOnlyImportOrExportDeclaration(node) && !(node.flags & 16777216 /* Ambient */)) {
                        const typeOnlyAlias = getTypeOnlyAliasDeclaration(symbol);
                        const isType = !(targetFlags & 111551 /* Value */);
                        if (isType || typeOnlyAlias) {
                            switch (node.kind) {
                                case 270 /* ImportClause */:
                                case 273 /* ImportSpecifier */:
                                case 268 /* ImportEqualsDeclaration */: {
                                    if (compilerOptions.preserveValueImports || compilerOptions.verbatimModuleSyntax) {
                                        Debug.assertIsDefined(node.name, "An ImportClause with a symbol should have a name");
                                        const message = compilerOptions.verbatimModuleSyntax && isInternalModuleImportEqualsDeclaration(node) ? Diagnostics.An_import_alias_cannot_resolve_to_a_type_or_type_only_declaration_when_verbatimModuleSyntax_is_enabled : isType ? compilerOptions.verbatimModuleSyntax ? Diagnostics._0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled : Diagnostics._0_is_a_type_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled : compilerOptions.verbatimModuleSyntax ? Diagnostics._0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled : Diagnostics._0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled;
                                        const name = idText(node.kind === 273 /* ImportSpecifier */ ? node.propertyName || node.name : node.name);
                                        addTypeOnlyDeclarationRelatedInfo(error(node, message, name), isType ? void 0 : typeOnlyAlias, name);
                                    }
                                    if (isType && node.kind === 268 /* ImportEqualsDeclaration */ && hasEffectiveModifier(node, 1 /* Export */)) {
                                        error(node, Diagnostics.Cannot_use_export_import_on_a_type_or_type_only_namespace_when_0_is_enabled, isolatedModulesLikeFlagName);
                                    }
                                    break;
                                }
                                case 278 /* ExportSpecifier */: {
                                    if (compilerOptions.verbatimModuleSyntax || getSourceFileOfNode(typeOnlyAlias) !== getSourceFileOfNode(node)) {
                                        const name = idText(node.propertyName || node.name);
                                        const diagnostic = isType ? error(node, Diagnostics.Re_exporting_a_type_when_0_is_enabled_requires_using_export_type, isolatedModulesLikeFlagName) : error(node, Diagnostics._0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_1_is_enabled, name, isolatedModulesLikeFlagName);
                                        addTypeOnlyDeclarationRelatedInfo(diagnostic, isType ? void 0 : typeOnlyAlias, name);
                                        break;
                                    }
                                }
                            }
                        }
                        if (compilerOptions.verbatimModuleSyntax && node.kind !== 268 /* ImportEqualsDeclaration */ && !isInJSFile(node) && (moduleKind === 1 /* CommonJS */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                            error(node, Diagnostics.ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                        }
                    }
                    if (isImportSpecifier(node)) {
                        const targetSymbol = checkDeprecatedAliasedSymbol(symbol, node);
                        if (isDeprecatedAliasedSymbol(targetSymbol) && targetSymbol.declarations) {
                            addDeprecatedSuggestion(node, targetSymbol.declarations, targetSymbol.escapedName);
                        }
                    }
                }
            }
            function isDeprecatedAliasedSymbol(symbol) {
                return !!symbol.declarations && every(symbol.declarations, (d) => !!(getCombinedNodeFlags(d) & 268435456 /* Deprecated */));
            }
            function checkDeprecatedAliasedSymbol(symbol, location) {
                if (!(symbol.flags & 2097152 /* Alias */))
                    return symbol;
                const targetSymbol = resolveAlias(symbol);
                if (targetSymbol === unknownSymbol)
                    return targetSymbol;
                while (symbol.flags & 2097152 /* Alias */) {
                    const target = getImmediateAliasedSymbol(symbol);
                    if (target) {
                        if (target === targetSymbol)
                            break;
                        if (target.declarations && length(target.declarations)) {
                            if (isDeprecatedAliasedSymbol(target)) {
                                addDeprecatedSuggestion(location, target.declarations, target.escapedName);
                                break;
                            }
                            else {
                                if (symbol === targetSymbol)
                                    break;
                                symbol = target;
                            }
                        }
                    }
                    else {
                        break;
                    }
                }
                return targetSymbol;
            }
            function checkImportBinding(node) {
                checkCollisionsForDeclarationName(node, node.name);
                checkAliasSymbol(node);
                if (node.kind === 273 /* ImportSpecifier */ && idText(node.propertyName || node.name) === "default" && getESModuleInterop(compilerOptions) && moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                    checkExternalEmitHelpers(node, 131072 /* ImportDefault */);
                }
            }
            function checkAssertClause(declaration) {
                var _a2;
                if (declaration.assertClause) {
                    const validForTypeAssertions = isExclusivelyTypeOnlyImportOrExport(declaration);
                    const override = getResolutionModeOverrideForClause(declaration.assertClause, validForTypeAssertions ? grammarErrorOnNode : void 0);
                    if (validForTypeAssertions && override) {
                        if (!isNightly()) {
                            grammarErrorOnNode(declaration.assertClause, Diagnostics.resolution_mode_assertions_are_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next);
                        }
                        if (getEmitModuleResolutionKind(compilerOptions) !== 3 /* Node16 */ && getEmitModuleResolutionKind(compilerOptions) !== 99 /* NodeNext */) {
                            return grammarErrorOnNode(declaration.assertClause, Diagnostics.resolution_mode_assertions_are_only_supported_when_moduleResolution_is_node16_or_nodenext);
                        }
                        return;
                    }
                    const mode = moduleKind === 199 /* NodeNext */ && declaration.moduleSpecifier && getUsageModeForExpression(declaration.moduleSpecifier);
                    if (mode !== 99 /* ESNext */ && moduleKind !== 99 /* ESNext */) {
                        return grammarErrorOnNode(declaration.assertClause, moduleKind === 199 /* NodeNext */ ? Diagnostics.Import_assertions_are_not_allowed_on_statements_that_transpile_to_commonjs_require_calls : Diagnostics.Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_or_nodenext);
                    }
                    if (isImportDeclaration(declaration) ? (_a2 = declaration.importClause) == null ? void 0 : _a2.isTypeOnly : declaration.isTypeOnly) {
                        return grammarErrorOnNode(declaration.assertClause, Diagnostics.Import_assertions_cannot_be_used_with_type_only_imports_or_exports);
                    }
                    if (override) {
                        return grammarErrorOnNode(declaration.assertClause, Diagnostics.resolution_mode_can_only_be_set_for_type_only_imports);
                    }
                }
            }
            function checkImportDeclaration(node) {
                if (checkGrammarModuleElementContext(node, isInJSFile(node) ? Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_module : Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module)) {
                    return;
                }
                if (!checkGrammarModifiers(node) && hasEffectiveModifiers(node)) {
                    grammarErrorOnFirstToken(node, Diagnostics.An_import_declaration_cannot_have_modifiers);
                }
                if (checkExternalImportOrExportDeclaration(node)) {
                    const importClause = node.importClause;
                    if (importClause && !checkGrammarImportClause(importClause)) {
                        if (importClause.name) {
                            checkImportBinding(importClause);
                        }
                        if (importClause.namedBindings) {
                            if (importClause.namedBindings.kind === 271 /* NamespaceImport */) {
                                checkImportBinding(importClause.namedBindings);
                                if (moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */) && getESModuleInterop(compilerOptions)) {
                                    checkExternalEmitHelpers(node, 65536 /* ImportStar */);
                                }
                            }
                            else {
                                const moduleExisted = resolveExternalModuleName(node, node.moduleSpecifier);
                                if (moduleExisted) {
                                    forEach(importClause.namedBindings.elements, checkImportBinding);
                                }
                            }
                        }
                    }
                }
                checkAssertClause(node);
            }
            function checkImportEqualsDeclaration(node) {
                if (checkGrammarModuleElementContext(node, isInJSFile(node) ? Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_module : Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module)) {
                    return;
                }
                checkGrammarModifiers(node);
                if (isInternalModuleImportEqualsDeclaration(node) || checkExternalImportOrExportDeclaration(node)) {
                    checkImportBinding(node);
                    if (hasSyntacticModifier(node, 1 /* Export */)) {
                        markExportAsReferenced(node);
                    }
                    if (node.moduleReference.kind !== 280 /* ExternalModuleReference */) {
                        const target = resolveAlias(getSymbolOfDeclaration(node));
                        if (target !== unknownSymbol) {
                            const targetFlags = getAllSymbolFlags(target);
                            if (targetFlags & 111551 /* Value */) {
                                const moduleName = getFirstIdentifier(node.moduleReference);
                                if (!(resolveEntityName(moduleName, 111551 /* Value */ | 1920 /* Namespace */).flags & 1920 /* Namespace */)) {
                                    error(moduleName, Diagnostics.Module_0_is_hidden_by_a_local_declaration_with_the_same_name, declarationNameToString(moduleName));
                                }
                            }
                            if (targetFlags & 788968 /* Type */) {
                                checkTypeNameIsReserved(node.name, Diagnostics.Import_name_cannot_be_0);
                            }
                        }
                        if (node.isTypeOnly) {
                            grammarErrorOnNode(node, Diagnostics.An_import_alias_cannot_use_import_type);
                        }
                    }
                    else {
                        if (moduleKind >= 5 /* ES2015 */ && getSourceFileOfNode(node).impliedNodeFormat === void 0 && !node.isTypeOnly && !(node.flags & 16777216 /* Ambient */)) {
                            grammarErrorOnNode(node, Diagnostics.Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead);
                        }
                    }
                }
            }
            function checkExportDeclaration(node) {
                if (checkGrammarModuleElementContext(node, isInJSFile(node) ? Diagnostics.An_export_declaration_can_only_be_used_at_the_top_level_of_a_module : Diagnostics.An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module)) {
                    return;
                }
                if (!checkGrammarModifiers(node) && hasSyntacticModifiers(node)) {
                    grammarErrorOnFirstToken(node, Diagnostics.An_export_declaration_cannot_have_modifiers);
                }
                if (node.moduleSpecifier && node.exportClause && isNamedExports(node.exportClause) && length(node.exportClause.elements) && languageVersion === 0 /* ES3 */) {
                    checkExternalEmitHelpers(node, 4194304 /* CreateBinding */);
                }
                checkGrammarExportDeclaration(node);
                if (!node.moduleSpecifier || checkExternalImportOrExportDeclaration(node)) {
                    if (node.exportClause && !isNamespaceExport(node.exportClause)) {
                        forEach(node.exportClause.elements, checkExportSpecifier);
                        const inAmbientExternalModule = node.parent.kind === 265 /* ModuleBlock */ && isAmbientModule(node.parent.parent);
                        const inAmbientNamespaceDeclaration = !inAmbientExternalModule && node.parent.kind === 265 /* ModuleBlock */ && !node.moduleSpecifier && node.flags & 16777216 /* Ambient */;
                        if (node.parent.kind !== 308 /* SourceFile */ && !inAmbientExternalModule && !inAmbientNamespaceDeclaration) {
                            error(node, Diagnostics.Export_declarations_are_not_permitted_in_a_namespace);
                        }
                    }
                    else {
                        const moduleSymbol = resolveExternalModuleName(node, node.moduleSpecifier);
                        if (moduleSymbol && hasExportAssignmentSymbol(moduleSymbol)) {
                            error(node.moduleSpecifier, Diagnostics.Module_0_uses_export_and_cannot_be_used_with_export_Asterisk, symbolToString(moduleSymbol));
                        }
                        else if (node.exportClause) {
                            checkAliasSymbol(node.exportClause);
                        }
                        if (moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                            if (node.exportClause) {
                                if (getESModuleInterop(compilerOptions)) {
                                    checkExternalEmitHelpers(node, 65536 /* ImportStar */);
                                }
                            }
                            else {
                                checkExternalEmitHelpers(node, 32768 /* ExportStar */);
                            }
                        }
                    }
                }
                checkAssertClause(node);
            }
            function checkGrammarExportDeclaration(node) {
                var _a2;
                if (node.isTypeOnly && ((_a2 = node.exportClause) == null ? void 0 : _a2.kind) === 276 /* NamedExports */) {
                    return checkGrammarNamedImportsOrExports(node.exportClause);
                }
                return false;
            }
            function checkGrammarModuleElementContext(node, errorMessage) {
                const isInAppropriateContext = node.parent.kind === 308 /* SourceFile */ || node.parent.kind === 265 /* ModuleBlock */ || node.parent.kind === 264 /* ModuleDeclaration */;
                if (!isInAppropriateContext) {
                    grammarErrorOnFirstToken(node, errorMessage);
                }
                return !isInAppropriateContext;
            }
            function importClauseContainsReferencedImport(importClause) {
                return forEachImportClauseDeclaration(importClause, (declaration) => {
                    return !!getSymbolOfDeclaration(declaration).isReferenced;
                });
            }
            function importClauseContainsConstEnumUsedAsValue(importClause) {
                return forEachImportClauseDeclaration(importClause, (declaration) => {
                    return !!getSymbolLinks(getSymbolOfDeclaration(declaration)).constEnumReferenced;
                });
            }
            function canConvertImportDeclarationToTypeOnly(statement) {
                return isImportDeclaration(statement) && statement.importClause && !statement.importClause.isTypeOnly && importClauseContainsReferencedImport(statement.importClause) && !isReferencedAliasDeclaration(statement.importClause, 
                /*checkChildren*/
                true) && !importClauseContainsConstEnumUsedAsValue(statement.importClause);
            }
            function canConvertImportEqualsDeclarationToTypeOnly(statement) {
                return isImportEqualsDeclaration(statement) && isExternalModuleReference(statement.moduleReference) && !statement.isTypeOnly && getSymbolOfDeclaration(statement).isReferenced && !isReferencedAliasDeclaration(statement, 
                /*checkChildren*/
                false) && !getSymbolLinks(getSymbolOfDeclaration(statement)).constEnumReferenced;
            }
            function checkImportsForTypeOnlyConversion(sourceFile) {
                for (const statement of sourceFile.statements) {
                    if (canConvertImportDeclarationToTypeOnly(statement) || canConvertImportEqualsDeclarationToTypeOnly(statement)) {
                        error(statement, Diagnostics.This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error);
                    }
                }
            }
            function checkExportSpecifier(node) {
                checkAliasSymbol(node);
                if (getEmitDeclarations(compilerOptions)) {
                    collectLinkedAliases(node.propertyName || node.name, 
                    /*setVisibility*/
                    true);
                }
                if (!node.parent.parent.moduleSpecifier) {
                    const exportedName = node.propertyName || node.name;
                    const symbol = resolveName(exportedName, exportedName.escapedText, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    true);
                    if (symbol && (symbol === undefinedSymbol || symbol === globalThisSymbol || symbol.declarations && isGlobalSourceFile(getDeclarationContainer(symbol.declarations[0])))) {
                        error(exportedName, Diagnostics.Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module, idText(exportedName));
                    }
                    else {
                        if (!node.isTypeOnly && !node.parent.parent.isTypeOnly) {
                            markExportAsReferenced(node);
                        }
                        const target = symbol && (symbol.flags & 2097152 /* Alias */ ? resolveAlias(symbol) : symbol);
                        if (!target || getAllSymbolFlags(target) & 111551 /* Value */) {
                            checkExpressionCached(node.propertyName || node.name);
                        }
                    }
                }
                else {
                    if (getESModuleInterop(compilerOptions) && moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */) && idText(node.propertyName || node.name) === "default") {
                        checkExternalEmitHelpers(node, 131072 /* ImportDefault */);
                    }
                }
            }
            function checkExportAssignment(node) {
                const illegalContextMessage = node.isExportEquals ? Diagnostics.An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration : Diagnostics.A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration;
                if (checkGrammarModuleElementContext(node, illegalContextMessage)) {
                    return;
                }
                const container = node.parent.kind === 308 /* SourceFile */ ? node.parent : node.parent.parent;
                if (container.kind === 264 /* ModuleDeclaration */ && !isAmbientModule(container)) {
                    if (node.isExportEquals) {
                        error(node, Diagnostics.An_export_assignment_cannot_be_used_in_a_namespace);
                    }
                    else {
                        error(node, Diagnostics.A_default_export_can_only_be_used_in_an_ECMAScript_style_module);
                    }
                    return;
                }
                if (!checkGrammarModifiers(node) && hasEffectiveModifiers(node)) {
                    grammarErrorOnFirstToken(node, Diagnostics.An_export_assignment_cannot_have_modifiers);
                }
                const typeAnnotationNode = getEffectiveTypeAnnotationNode(node);
                if (typeAnnotationNode) {
                    checkTypeAssignableTo(checkExpressionCached(node.expression), getTypeFromTypeNode(typeAnnotationNode), node.expression);
                }
                const isIllegalExportDefaultInCJS = !node.isExportEquals && !(node.flags & 16777216 /* Ambient */) && compilerOptions.verbatimModuleSyntax && (moduleKind === 1 /* CommonJS */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */);
                if (node.expression.kind === 79 /* Identifier */) {
                    const id = node.expression;
                    const sym = getExportSymbolOfValueSymbolIfExported(resolveEntityName(id, 67108863 /* All */, 
                    /*ignoreErrors*/
                    true, 
                    /*dontResolveAlias*/
                    true, node));
                    if (sym) {
                        markAliasReferenced(sym, id);
                        if (getAllSymbolFlags(sym) & 111551 /* Value */) {
                            checkExpressionCached(id);
                            if (!isIllegalExportDefaultInCJS && !(node.flags & 16777216 /* Ambient */) && compilerOptions.verbatimModuleSyntax && getTypeOnlyAliasDeclaration(sym, 111551 /* Value */)) {
                                error(id, node.isExportEquals ? Diagnostics.An_export_declaration_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration : Diagnostics.An_export_default_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration, idText(id));
                            }
                        }
                        else if (!isIllegalExportDefaultInCJS && !(node.flags & 16777216 /* Ambient */) && compilerOptions.verbatimModuleSyntax) {
                            error(id, node.isExportEquals ? Diagnostics.An_export_declaration_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type : Diagnostics.An_export_default_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type, idText(id));
                        }
                    }
                    else {
                        checkExpressionCached(id);
                    }
                    if (getEmitDeclarations(compilerOptions)) {
                        collectLinkedAliases(id, 
                        /*setVisibility*/
                        true);
                    }
                }
                else {
                    checkExpressionCached(node.expression);
                }
                if (isIllegalExportDefaultInCJS) {
                    error(node, Diagnostics.ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                }
                checkExternalModuleExports(container);
                if (node.flags & 16777216 /* Ambient */ && !isEntityNameExpression(node.expression)) {
                    grammarErrorOnNode(node.expression, Diagnostics.The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context);
                }
                if (node.isExportEquals) {
                    if (moduleKind >= 5 /* ES2015 */ && (node.flags & 16777216 /* Ambient */ && getSourceFileOfNode(node).impliedNodeFormat === 99 /* ESNext */ || !(node.flags & 16777216 /* Ambient */) && getSourceFileOfNode(node).impliedNodeFormat !== 1 /* CommonJS */)) {
                        grammarErrorOnNode(node, Diagnostics.Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or_another_module_format_instead);
                    }
                    else if (moduleKind === 4 /* System */ && !(node.flags & 16777216 /* Ambient */)) {
                        grammarErrorOnNode(node, Diagnostics.Export_assignment_is_not_supported_when_module_flag_is_system);
                    }
                }
            }
            function hasExportedMembers(moduleSymbol) {
                return forEachEntry(moduleSymbol.exports, (_, id) => id !== "export=");
            }
            function checkExternalModuleExports(node) {
                const moduleSymbol = getSymbolOfDeclaration(node);
                const links = getSymbolLinks(moduleSymbol);
                if (!links.exportsChecked) {
                    const exportEqualsSymbol = moduleSymbol.exports.get("export=");
                    if (exportEqualsSymbol && hasExportedMembers(moduleSymbol)) {
                        const declaration = getDeclarationOfAliasSymbol(exportEqualsSymbol) || exportEqualsSymbol.valueDeclaration;
                        if (declaration && !isTopLevelInExternalModuleAugmentation(declaration) && !isInJSFile(declaration)) {
                            error(declaration, Diagnostics.An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements);
                        }
                    }
                    const exports = getExportsOfModule(moduleSymbol);
                    if (exports) {
                        exports.forEach(({ declarations, flags }, id) => {
                            if (id === "__export") {
                                return;
                            }
                            if (flags & (1920 /* Namespace */ | 384 /* Enum */)) {
                                return;
                            }
                            const exportedDeclarationsCount = countWhere(declarations, and(isNotOverloadAndNotAccessor, not(isInterfaceDeclaration)));
                            if (flags & 524288 /* TypeAlias */ && exportedDeclarationsCount <= 2) {
                                return;
                            }
                            if (exportedDeclarationsCount > 1) {
                                if (!isDuplicatedCommonJSExport(declarations)) {
                                    for (const declaration of declarations) {
                                        if (isNotOverload(declaration)) {
                                            diagnostics.add(createDiagnosticForNode(declaration, Diagnostics.Cannot_redeclare_exported_variable_0, unescapeLeadingUnderscores(id)));
                                        }
                                    }
                                }
                            }
                        });
                    }
                    links.exportsChecked = true;
                }
            }
            function isDuplicatedCommonJSExport(declarations) {
                return declarations && declarations.length > 1 && declarations.every((d) => isInJSFile(d) && isAccessExpression(d) && (isExportsIdentifier(d.expression) || isModuleExportsAccessExpression(d.expression)));
            }
            function checkSourceElement(node) {
                if (node) {
                    const saveCurrentNode = currentNode;
                    currentNode = node;
                    instantiationCount = 0;
                    checkSourceElementWorker(node);
                    currentNode = saveCurrentNode;
                }
            }
            function checkSourceElementWorker(node) {
                if (canHaveJSDoc(node)) {
                    forEach(node.jsDoc, ({ comment, tags }) => {
                        checkJSDocCommentWorker(comment);
                        forEach(tags, (tag) => {
                            checkJSDocCommentWorker(tag.comment);
                            if (isInJSFile(node)) {
                                checkSourceElement(tag);
                            }
                        });
                    });
                }
                const kind = node.kind;
                if (cancellationToken) {
                    switch (kind) {
                        case 264 /* ModuleDeclaration */:
                        case 260 /* ClassDeclaration */:
                        case 261 /* InterfaceDeclaration */:
                        case 259 /* FunctionDeclaration */:
                            cancellationToken.throwIfCancellationRequested();
                    }
                }
                if (kind >= 240 /* FirstStatement */ && kind <= 256 /* LastStatement */ && canHaveFlowNode(node) && node.flowNode && !isReachableFlowNode(node.flowNode)) {
                    errorOrSuggestion(compilerOptions.allowUnreachableCode === false, node, Diagnostics.Unreachable_code_detected);
                }
                switch (kind) {
                    case 165 /* TypeParameter */:
                        return checkTypeParameter(node);
                    case 166 /* Parameter */:
                        return checkParameter(node);
                    case 169 /* PropertyDeclaration */:
                        return checkPropertyDeclaration(node);
                    case 168 /* PropertySignature */:
                        return checkPropertySignature(node);
                    case 182 /* ConstructorType */:
                    case 181 /* FunctionType */:
                    case 176 /* CallSignature */:
                    case 177 /* ConstructSignature */:
                    case 178 /* IndexSignature */:
                        return checkSignatureDeclaration(node);
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                        return checkMethodDeclaration(node);
                    case 172 /* ClassStaticBlockDeclaration */:
                        return checkClassStaticBlockDeclaration(node);
                    case 173 /* Constructor */:
                        return checkConstructorDeclaration(node);
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        return checkAccessorDeclaration(node);
                    case 180 /* TypeReference */:
                        return checkTypeReferenceNode(node);
                    case 179 /* TypePredicate */:
                        return checkTypePredicate(node);
                    case 183 /* TypeQuery */:
                        return checkTypeQuery(node);
                    case 184 /* TypeLiteral */:
                        return checkTypeLiteral(node);
                    case 185 /* ArrayType */:
                        return checkArrayType(node);
                    case 186 /* TupleType */:
                        return checkTupleType(node);
                    case 189 /* UnionType */:
                    case 190 /* IntersectionType */:
                        return checkUnionOrIntersectionType(node);
                    case 193 /* ParenthesizedType */:
                    case 187 /* OptionalType */:
                    case 188 /* RestType */:
                        return checkSourceElement(node.type);
                    case 194 /* ThisType */:
                        return checkThisType(node);
                    case 195 /* TypeOperator */:
                        return checkTypeOperator(node);
                    case 191 /* ConditionalType */:
                        return checkConditionalType(node);
                    case 192 /* InferType */:
                        return checkInferType(node);
                    case 200 /* TemplateLiteralType */:
                        return checkTemplateLiteralType(node);
                    case 202 /* ImportType */:
                        return checkImportType(node);
                    case 199 /* NamedTupleMember */:
                        return checkNamedTupleMember(node);
                    case 331 /* JSDocAugmentsTag */:
                        return checkJSDocAugmentsTag(node);
                    case 332 /* JSDocImplementsTag */:
                        return checkJSDocImplementsTag(node);
                    case 349 /* JSDocTypedefTag */:
                    case 341 /* JSDocCallbackTag */:
                    case 343 /* JSDocEnumTag */:
                        return checkJSDocTypeAliasTag(node);
                    case 348 /* JSDocTemplateTag */:
                        return checkJSDocTemplateTag(node);
                    case 347 /* JSDocTypeTag */:
                        return checkJSDocTypeTag(node);
                    case 327 /* JSDocLink */:
                    case 328 /* JSDocLinkCode */:
                    case 329 /* JSDocLinkPlain */:
                        return checkJSDocLinkLikeTag(node);
                    case 344 /* JSDocParameterTag */:
                        return checkJSDocParameterTag(node);
                    case 351 /* JSDocPropertyTag */:
                        return checkJSDocPropertyTag(node);
                    case 320 /* JSDocFunctionType */:
                        checkJSDocFunctionType(node);
                    case 318 /* JSDocNonNullableType */:
                    case 317 /* JSDocNullableType */:
                    case 315 /* JSDocAllType */:
                    case 316 /* JSDocUnknownType */:
                    case 325 /* JSDocTypeLiteral */:
                        checkJSDocTypeIsInJsFile(node);
                        forEachChild(node, checkSourceElement);
                        return;
                    case 321 /* JSDocVariadicType */:
                        checkJSDocVariadicType(node);
                        return;
                    case 312 /* JSDocTypeExpression */:
                        return checkSourceElement(node.type);
                    case 336 /* JSDocPublicTag */:
                    case 338 /* JSDocProtectedTag */:
                    case 337 /* JSDocPrivateTag */:
                        return checkJSDocAccessibilityModifiers(node);
                    case 353 /* JSDocSatisfiesTag */:
                        return checkJSDocSatisfiesTag(node);
                    case 196 /* IndexedAccessType */:
                        return checkIndexedAccessType(node);
                    case 197 /* MappedType */:
                        return checkMappedType(node);
                    case 259 /* FunctionDeclaration */:
                        return checkFunctionDeclaration(node);
                    case 238 /* Block */:
                    case 265 /* ModuleBlock */:
                        return checkBlock(node);
                    case 240 /* VariableStatement */:
                        return checkVariableStatement(node);
                    case 241 /* ExpressionStatement */:
                        return checkExpressionStatement(node);
                    case 242 /* IfStatement */:
                        return checkIfStatement(node);
                    case 243 /* DoStatement */:
                        return checkDoStatement(node);
                    case 244 /* WhileStatement */:
                        return checkWhileStatement(node);
                    case 245 /* ForStatement */:
                        return checkForStatement(node);
                    case 246 /* ForInStatement */:
                        return checkForInStatement(node);
                    case 247 /* ForOfStatement */:
                        return checkForOfStatement(node);
                    case 248 /* ContinueStatement */:
                    case 249 /* BreakStatement */:
                        return checkBreakOrContinueStatement(node);
                    case 250 /* ReturnStatement */:
                        return checkReturnStatement(node);
                    case 251 /* WithStatement */:
                        return checkWithStatement(node);
                    case 252 /* SwitchStatement */:
                        return checkSwitchStatement(node);
                    case 253 /* LabeledStatement */:
                        return checkLabeledStatement(node);
                    case 254 /* ThrowStatement */:
                        return checkThrowStatement(node);
                    case 255 /* TryStatement */:
                        return checkTryStatement(node);
                    case 257 /* VariableDeclaration */:
                        return checkVariableDeclaration(node);
                    case 205 /* BindingElement */:
                        return checkBindingElement(node);
                    case 260 /* ClassDeclaration */:
                        return checkClassDeclaration(node);
                    case 261 /* InterfaceDeclaration */:
                        return checkInterfaceDeclaration(node);
                    case 262 /* TypeAliasDeclaration */:
                        return checkTypeAliasDeclaration(node);
                    case 263 /* EnumDeclaration */:
                        return checkEnumDeclaration(node);
                    case 264 /* ModuleDeclaration */:
                        return checkModuleDeclaration(node);
                    case 269 /* ImportDeclaration */:
                        return checkImportDeclaration(node);
                    case 268 /* ImportEqualsDeclaration */:
                        return checkImportEqualsDeclaration(node);
                    case 275 /* ExportDeclaration */:
                        return checkExportDeclaration(node);
                    case 274 /* ExportAssignment */:
                        return checkExportAssignment(node);
                    case 239 /* EmptyStatement */:
                    case 256 /* DebuggerStatement */:
                        checkGrammarStatementInAmbientContext(node);
                        return;
                    case 279 /* MissingDeclaration */:
                        return checkMissingDeclaration(node);
                }
            }
            function checkJSDocCommentWorker(node) {
                if (isArray(node)) {
                    forEach(node, (tag) => {
                        if (isJSDocLinkLike(tag)) {
                            checkSourceElement(tag);
                        }
                    });
                }
            }
            function checkJSDocTypeIsInJsFile(node) {
                if (!isInJSFile(node)) {
                    if (isJSDocNonNullableType(node) || isJSDocNullableType(node)) {
                        const token = tokenToString(isJSDocNonNullableType(node) ? 53 /* ExclamationToken */ : 57 /* QuestionToken */);
                        const diagnostic = node.postfix ? Diagnostics._0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1 : Diagnostics._0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1;
                        const typeNode = node.type;
                        const type = getTypeFromTypeNode(typeNode);
                        grammarErrorOnNode(node, diagnostic, token, typeToString(isJSDocNullableType(node) && !(type === neverType || type === voidType) ? getUnionType(append([type, undefinedType], node.postfix ? void 0 : nullType)) : type));
                    }
                    else {
                        grammarErrorOnNode(node, Diagnostics.JSDoc_types_can_only_be_used_inside_documentation_comments);
                    }
                }
            }
            function checkJSDocVariadicType(node) {
                checkJSDocTypeIsInJsFile(node);
                checkSourceElement(node.type);
                const { parent: parent2 } = node;
                if (isParameter(parent2) && isJSDocFunctionType(parent2.parent)) {
                    if (last(parent2.parent.parameters) !== parent2) {
                        error(node, Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list);
                    }
                    return;
                }
                if (!isJSDocTypeExpression(parent2)) {
                    error(node, Diagnostics.JSDoc_may_only_appear_in_the_last_parameter_of_a_signature);
                }
                const paramTag = node.parent.parent;
                if (!isJSDocParameterTag(paramTag)) {
                    error(node, Diagnostics.JSDoc_may_only_appear_in_the_last_parameter_of_a_signature);
                    return;
                }
                const param = getParameterSymbolFromJSDoc(paramTag);
                if (!param) {
                    return;
                }
                const host2 = getHostSignatureFromJSDoc(paramTag);
                if (!host2 || last(host2.parameters).symbol !== param) {
                    error(node, Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list);
                }
            }
            function getTypeFromJSDocVariadicType(node) {
                const type = getTypeFromTypeNode(node.type);
                const { parent: parent2 } = node;
                const paramTag = node.parent.parent;
                if (isJSDocTypeExpression(node.parent) && isJSDocParameterTag(paramTag)) {
                    const host2 = getHostSignatureFromJSDoc(paramTag);
                    const isCallbackTag = isJSDocCallbackTag(paramTag.parent.parent);
                    if (host2 || isCallbackTag) {
                        const lastParamDeclaration = isCallbackTag ? lastOrUndefined(paramTag.parent.parent.typeExpression.parameters) : lastOrUndefined(host2.parameters);
                        const symbol = getParameterSymbolFromJSDoc(paramTag);
                        if (!lastParamDeclaration || symbol && lastParamDeclaration.symbol === symbol && isRestParameter(lastParamDeclaration)) {
                            return createArrayType(type);
                        }
                    }
                }
                if (isParameter(parent2) && isJSDocFunctionType(parent2.parent)) {
                    return createArrayType(type);
                }
                return addOptionality(type);
            }
            function checkNodeDeferred(node) {
                const enclosingFile = getSourceFileOfNode(node);
                const links = getNodeLinks(enclosingFile);
                if (!(links.flags & 1 /* TypeChecked */)) {
                    links.deferredNodes || (links.deferredNodes = /* @__PURE__ */ new Set());
                    links.deferredNodes.add(node);
                }
                else {
                    Debug.assert(!links.deferredNodes, "A type-checked file should have no deferred nodes.");
                }
            }
            function checkDeferredNodes(context) {
                const links = getNodeLinks(context);
                if (links.deferredNodes) {
                    links.deferredNodes.forEach(checkDeferredNode);
                }
                links.deferredNodes = void 0;
            }
            function checkDeferredNode(node) {
                var _a2, _b;
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Check, "checkDeferredNode", { kind: node.kind, pos: node.pos, end: node.end, path: node.tracingPath });
                const saveCurrentNode = currentNode;
                currentNode = node;
                instantiationCount = 0;
                switch (node.kind) {
                    case 210 /* CallExpression */:
                    case 211 /* NewExpression */:
                    case 212 /* TaggedTemplateExpression */:
                    case 167 /* Decorator */:
                    case 283 /* JsxOpeningElement */:
                        resolveUntypedCall(node);
                        break;
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                        checkFunctionExpressionOrObjectLiteralMethodDeferred(node);
                        break;
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        checkAccessorDeclaration(node);
                        break;
                    case 228 /* ClassExpression */:
                        checkClassExpressionDeferred(node);
                        break;
                    case 165 /* TypeParameter */:
                        checkTypeParameterDeferred(node);
                        break;
                    case 282 /* JsxSelfClosingElement */:
                        checkJsxSelfClosingElementDeferred(node);
                        break;
                    case 281 /* JsxElement */:
                        checkJsxElementDeferred(node);
                        break;
                }
                currentNode = saveCurrentNode;
                (_b = tracing) == null ? void 0 : _b.pop();
            }
            function checkSourceFile(node) {
                var _a2, _b;
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Check, "checkSourceFile", { path: node.path }, 
                /*separateBeginAndEnd*/
                true);
                mark("beforeCheck");
                checkSourceFileWorker(node);
                mark("afterCheck");
                measure("Check", "beforeCheck", "afterCheck");
                (_b = tracing) == null ? void 0 : _b.pop();
            }
            function unusedIsError(kind, isAmbient) {
                if (isAmbient) {
                    return false;
                }
                switch (kind) {
                    case 0 /* Local */:
                        return !!compilerOptions.noUnusedLocals;
                    case 1 /* Parameter */:
                        return !!compilerOptions.noUnusedParameters;
                    default:
                        return Debug.assertNever(kind);
                }
            }
            function getPotentiallyUnusedIdentifiers(sourceFile) {
                return allPotentiallyUnusedIdentifiers.get(sourceFile.path) || emptyArray;
            }
            function checkSourceFileWorker(node) {
                const links = getNodeLinks(node);
                if (!(links.flags & 1 /* TypeChecked */)) {
                    if (skipTypeChecking(node, compilerOptions, host)) {
                        return;
                    }
                    checkGrammarSourceFile(node);
                    clear(potentialThisCollisions);
                    clear(potentialNewTargetCollisions);
                    clear(potentialWeakMapSetCollisions);
                    clear(potentialReflectCollisions);
                    clear(potentialUnusedRenamedBindingElementsInTypes);
                    forEach(node.statements, checkSourceElement);
                    checkSourceElement(node.endOfFileToken);
                    checkDeferredNodes(node);
                    if (isExternalOrCommonJsModule(node)) {
                        registerForUnusedIdentifiersCheck(node);
                    }
                    addLazyDiagnostic(() => {
                        if (!node.isDeclarationFile && (compilerOptions.noUnusedLocals || compilerOptions.noUnusedParameters)) {
                            checkUnusedIdentifiers(getPotentiallyUnusedIdentifiers(node), (containingNode, kind, diag2) => {
                                if (!containsParseError(containingNode) && unusedIsError(kind, !!(containingNode.flags & 16777216 /* Ambient */))) {
                                    diagnostics.add(diag2);
                                }
                            });
                        }
                        if (!node.isDeclarationFile) {
                            checkPotentialUncheckedRenamedBindingElementsInTypes();
                        }
                    });
                    if (compilerOptions.importsNotUsedAsValues === 2 /* Error */ && !node.isDeclarationFile && isExternalModule(node)) {
                        checkImportsForTypeOnlyConversion(node);
                    }
                    if (isExternalOrCommonJsModule(node)) {
                        checkExternalModuleExports(node);
                    }
                    if (potentialThisCollisions.length) {
                        forEach(potentialThisCollisions, checkIfThisIsCapturedInEnclosingScope);
                        clear(potentialThisCollisions);
                    }
                    if (potentialNewTargetCollisions.length) {
                        forEach(potentialNewTargetCollisions, checkIfNewTargetIsCapturedInEnclosingScope);
                        clear(potentialNewTargetCollisions);
                    }
                    if (potentialWeakMapSetCollisions.length) {
                        forEach(potentialWeakMapSetCollisions, checkWeakMapSetCollision);
                        clear(potentialWeakMapSetCollisions);
                    }
                    if (potentialReflectCollisions.length) {
                        forEach(potentialReflectCollisions, checkReflectCollision);
                        clear(potentialReflectCollisions);
                    }
                    links.flags |= 1 /* TypeChecked */;
                }
            }
            function getDiagnostics2(sourceFile, ct) {
                try {
                    cancellationToken = ct;
                    return getDiagnosticsWorker(sourceFile);
                }
                finally {
                    cancellationToken = void 0;
                }
            }
            function ensurePendingDiagnosticWorkComplete() {
                for (const cb of deferredDiagnosticsCallbacks) {
                    cb();
                }
                deferredDiagnosticsCallbacks = [];
            }
            function checkSourceFileWithEagerDiagnostics(sourceFile) {
                ensurePendingDiagnosticWorkComplete();
                const oldAddLazyDiagnostics = addLazyDiagnostic;
                addLazyDiagnostic = (cb) => cb();
                checkSourceFile(sourceFile);
                addLazyDiagnostic = oldAddLazyDiagnostics;
            }
            function getDiagnosticsWorker(sourceFile) {
                if (sourceFile) {
                    ensurePendingDiagnosticWorkComplete();
                    const previousGlobalDiagnostics = diagnostics.getGlobalDiagnostics();
                    const previousGlobalDiagnosticsSize = previousGlobalDiagnostics.length;
                    checkSourceFileWithEagerDiagnostics(sourceFile);
                    const semanticDiagnostics = diagnostics.getDiagnostics(sourceFile.fileName);
                    const currentGlobalDiagnostics = diagnostics.getGlobalDiagnostics();
                    if (currentGlobalDiagnostics !== previousGlobalDiagnostics) {
                        const deferredGlobalDiagnostics = relativeComplement(previousGlobalDiagnostics, currentGlobalDiagnostics, compareDiagnostics);
                        return concatenate(deferredGlobalDiagnostics, semanticDiagnostics);
                    }
                    else if (previousGlobalDiagnosticsSize === 0 && currentGlobalDiagnostics.length > 0) {
                        return concatenate(currentGlobalDiagnostics, semanticDiagnostics);
                    }
                    return semanticDiagnostics;
                }
                forEach(host.getSourceFiles(), checkSourceFileWithEagerDiagnostics);
                return diagnostics.getDiagnostics();
            }
            function getGlobalDiagnostics() {
                ensurePendingDiagnosticWorkComplete();
                return diagnostics.getGlobalDiagnostics();
            }
            function getSymbolsInScope(location, meaning) {
                if (location.flags & 33554432 /* InWithStatement */) {
                    return [];
                }
                const symbols = createSymbolTable();
                let isStaticSymbol = false;
                populateSymbols();
                symbols.delete("this" /* This */);
                return symbolsToArray(symbols);
                function populateSymbols() {
                    while (location) {
                        if (canHaveLocals(location) && location.locals && !isGlobalSourceFile(location)) {
                            copySymbols(location.locals, meaning);
                        }
                        switch (location.kind) {
                            case 308 /* SourceFile */:
                                if (!isExternalModule(location))
                                    break;
                            case 264 /* ModuleDeclaration */:
                                copyLocallyVisibleExportSymbols(getSymbolOfDeclaration(location).exports, meaning & 2623475 /* ModuleMember */);
                                break;
                            case 263 /* EnumDeclaration */:
                                copySymbols(getSymbolOfDeclaration(location).exports, meaning & 8 /* EnumMember */);
                                break;
                            case 228 /* ClassExpression */:
                                const className = location.name;
                                if (className) {
                                    copySymbol(location.symbol, meaning);
                                }
                            case 260 /* ClassDeclaration */:
                            case 261 /* InterfaceDeclaration */:
                                if (!isStaticSymbol) {
                                    copySymbols(getMembersOfSymbol(getSymbolOfDeclaration(location)), meaning & 788968 /* Type */);
                                }
                                break;
                            case 215 /* FunctionExpression */:
                                const funcName = location.name;
                                if (funcName) {
                                    copySymbol(location.symbol, meaning);
                                }
                                break;
                        }
                        if (introducesArgumentsExoticObject(location)) {
                            copySymbol(argumentsSymbol, meaning);
                        }
                        isStaticSymbol = isStatic(location);
                        location = location.parent;
                    }
                    copySymbols(globals, meaning);
                }
                function copySymbol(symbol, meaning2) {
                    if (getCombinedLocalAndExportSymbolFlags(symbol) & meaning2) {
                        const id = symbol.escapedName;
                        if (!symbols.has(id)) {
                            symbols.set(id, symbol);
                        }
                    }
                }
                function copySymbols(source, meaning2) {
                    if (meaning2) {
                        source.forEach((symbol) => {
                            copySymbol(symbol, meaning2);
                        });
                    }
                }
                function copyLocallyVisibleExportSymbols(source, meaning2) {
                    if (meaning2) {
                        source.forEach((symbol) => {
                            if (!getDeclarationOfKind(symbol, 278 /* ExportSpecifier */) && !getDeclarationOfKind(symbol, 277 /* NamespaceExport */)) {
                                copySymbol(symbol, meaning2);
                            }
                        });
                    }
                }
            }
            function isTypeDeclarationName(name) {
                return name.kind === 79 /* Identifier */ && isTypeDeclaration(name.parent) && getNameOfDeclaration(name.parent) === name;
            }
            function isTypeReferenceIdentifier(node) {
                while (node.parent.kind === 163 /* QualifiedName */) {
                    node = node.parent;
                }
                return node.parent.kind === 180 /* TypeReference */;
            }
            function isInNameOfExpressionWithTypeArguments(node) {
                while (node.parent.kind === 208 /* PropertyAccessExpression */) {
                    node = node.parent;
                }
                return node.parent.kind === 230 /* ExpressionWithTypeArguments */;
            }
            function forEachEnclosingClass(node, callback) {
                let result;
                let containingClass = getContainingClass(node);
                while (containingClass) {
                    if (result = callback(containingClass))
                        break;
                    containingClass = getContainingClass(containingClass);
                }
                return result;
            }
            function isNodeUsedDuringClassInitialization(node) {
                return !!findAncestor(node, (element) => {
                    if (isConstructorDeclaration(element) && nodeIsPresent(element.body) || isPropertyDeclaration(element)) {
                        return true;
                    }
                    else if (isClassLike(element) || isFunctionLikeDeclaration(element)) {
                        return "quit";
                    }
                    return false;
                });
            }
            function isNodeWithinClass(node, classDeclaration) {
                return !!forEachEnclosingClass(node, (n) => n === classDeclaration);
            }
            function getLeftSideOfImportEqualsOrExportAssignment(nodeOnRightSide) {
                while (nodeOnRightSide.parent.kind === 163 /* QualifiedName */) {
                    nodeOnRightSide = nodeOnRightSide.parent;
                }
                if (nodeOnRightSide.parent.kind === 268 /* ImportEqualsDeclaration */) {
                    return nodeOnRightSide.parent.moduleReference === nodeOnRightSide ? nodeOnRightSide.parent : void 0;
                }
                if (nodeOnRightSide.parent.kind === 274 /* ExportAssignment */) {
                    return nodeOnRightSide.parent.expression === nodeOnRightSide ? nodeOnRightSide.parent : void 0;
                }
                return void 0;
            }
            function isInRightSideOfImportOrExportAssignment(node) {
                return getLeftSideOfImportEqualsOrExportAssignment(node) !== void 0;
            }
            function getSpecialPropertyAssignmentSymbolFromEntityName(entityName) {
                const specialPropertyAssignmentKind = getAssignmentDeclarationKind(entityName.parent.parent);
                switch (specialPropertyAssignmentKind) {
                    case 1 /* ExportsProperty */:
                    case 3 /* PrototypeProperty */:
                        return getSymbolOfNode(entityName.parent);
                    case 4 /* ThisProperty */:
                    case 2 /* ModuleExports */:
                    case 5 /* Property */:
                        return getSymbolOfDeclaration(entityName.parent.parent);
                }
            }
            function isImportTypeQualifierPart(node) {
                let parent2 = node.parent;
                while (isQualifiedName(parent2)) {
                    node = parent2;
                    parent2 = parent2.parent;
                }
                if (parent2 && parent2.kind === 202 /* ImportType */ && parent2.qualifier === node) {
                    return parent2;
                }
                return void 0;
            }
            function getSymbolOfNameOrPropertyAccessExpression(name) {
                if (isDeclarationName(name)) {
                    return getSymbolOfNode(name.parent);
                }
                if (isInJSFile(name) && name.parent.kind === 208 /* PropertyAccessExpression */ && name.parent === name.parent.parent.left) {
                    if (!isPrivateIdentifier(name) && !isJSDocMemberName(name)) {
                        const specialPropertyAssignmentSymbol = getSpecialPropertyAssignmentSymbolFromEntityName(name);
                        if (specialPropertyAssignmentSymbol) {
                            return specialPropertyAssignmentSymbol;
                        }
                    }
                }
                if (name.parent.kind === 274 /* ExportAssignment */ && isEntityNameExpression(name)) {
                    const success = resolveEntityName(name, 
                    /*all meanings*/
                    111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */, 
                    /*ignoreErrors*/
                    true);
                    if (success && success !== unknownSymbol) {
                        return success;
                    }
                }
                else if (isEntityName(name) && isInRightSideOfImportOrExportAssignment(name)) {
                    const importEqualsDeclaration = getAncestor(name, 268 /* ImportEqualsDeclaration */);
                    Debug.assert(importEqualsDeclaration !== void 0);
                    return getSymbolOfPartOfRightHandSideOfImportEquals(name, 
                    /*dontResolveAlias*/
                    true);
                }
                if (isEntityName(name)) {
                    const possibleImportNode = isImportTypeQualifierPart(name);
                    if (possibleImportNode) {
                        getTypeFromTypeNode(possibleImportNode);
                        const sym = getNodeLinks(name).resolvedSymbol;
                        return sym === unknownSymbol ? void 0 : sym;
                    }
                }
                while (isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName(name)) {
                    name = name.parent;
                }
                if (isInNameOfExpressionWithTypeArguments(name)) {
                    let meaning = 0 /* None */;
                    if (name.parent.kind === 230 /* ExpressionWithTypeArguments */) {
                        meaning = isPartOfTypeNode(name) ? 788968 /* Type */ : 111551 /* Value */;
                        if (isExpressionWithTypeArgumentsInClassExtendsClause(name.parent)) {
                            meaning |= 111551 /* Value */;
                        }
                    }
                    else {
                        meaning = 1920 /* Namespace */;
                    }
                    meaning |= 2097152 /* Alias */;
                    const entityNameSymbol = isEntityNameExpression(name) ? resolveEntityName(name, meaning) : void 0;
                    if (entityNameSymbol) {
                        return entityNameSymbol;
                    }
                }
                if (name.parent.kind === 344 /* JSDocParameterTag */) {
                    return getParameterSymbolFromJSDoc(name.parent);
                }
                if (name.parent.kind === 165 /* TypeParameter */ && name.parent.parent.kind === 348 /* JSDocTemplateTag */) {
                    Debug.assert(!isInJSFile(name));
                    const typeParameter = getTypeParameterFromJsDoc(name.parent);
                    return typeParameter && typeParameter.symbol;
                }
                if (isExpressionNode(name)) {
                    if (nodeIsMissing(name)) {
                        return void 0;
                    }
                    const isJSDoc2 = findAncestor(name, or(isJSDocLinkLike, isJSDocNameReference, isJSDocMemberName));
                    const meaning = isJSDoc2 ? 788968 /* Type */ | 1920 /* Namespace */ | 111551 /* Value */ : 111551 /* Value */;
                    if (name.kind === 79 /* Identifier */) {
                        if (isJSXTagName(name) && isJsxIntrinsicIdentifier(name)) {
                            const symbol = getIntrinsicTagSymbol(name.parent);
                            return symbol === unknownSymbol ? void 0 : symbol;
                        }
                        const result = resolveEntityName(name, meaning, 
                        /*ignoreErrors*/
                        false, 
                        /* dontResolveAlias */
                        true, getHostSignatureFromJSDoc(name));
                        if (!result && isJSDoc2) {
                            const container = findAncestor(name, or(isClassLike, isInterfaceDeclaration));
                            if (container) {
                                return resolveJSDocMemberName(name, 
                                /*ignoreErrors*/
                                false, getSymbolOfDeclaration(container));
                            }
                        }
                        if (result && isJSDoc2) {
                            const container = getJSDocHost(name);
                            if (container && isEnumMember(container) && container === result.valueDeclaration) {
                                return resolveEntityName(name, meaning, 
                                /*ignoreErrors*/
                                true, 
                                /* dontResolveAlias */
                                true, getSourceFileOfNode(container)) || result;
                            }
                        }
                        return result;
                    }
                    else if (isPrivateIdentifier(name)) {
                        return getSymbolForPrivateIdentifierExpression(name);
                    }
                    else if (name.kind === 208 /* PropertyAccessExpression */ || name.kind === 163 /* QualifiedName */) {
                        const links = getNodeLinks(name);
                        if (links.resolvedSymbol) {
                            return links.resolvedSymbol;
                        }
                        if (name.kind === 208 /* PropertyAccessExpression */) {
                            checkPropertyAccessExpression(name, 0 /* Normal */);
                            if (!links.resolvedSymbol) {
                                const expressionType = checkExpressionCached(name.expression);
                                const infos = getApplicableIndexInfos(expressionType, getLiteralTypeFromPropertyName(name.name));
                                if (infos.length && expressionType.members) {
                                    const resolved = resolveStructuredTypeMembers(expressionType);
                                    const symbol = resolved.members.get("__index" /* Index */);
                                    if (infos === getIndexInfosOfType(expressionType)) {
                                        links.resolvedSymbol = symbol;
                                    }
                                    else if (symbol) {
                                        const symbolLinks2 = getSymbolLinks(symbol);
                                        const declarationList = mapDefined(infos, (i) => i.declaration);
                                        const nodeListId = map(declarationList, getNodeId).join(",");
                                        if (!symbolLinks2.filteredIndexSymbolCache) {
                                            symbolLinks2.filteredIndexSymbolCache = /* @__PURE__ */ new Map();
                                        }
                                        if (symbolLinks2.filteredIndexSymbolCache.has(nodeListId)) {
                                            links.resolvedSymbol = symbolLinks2.filteredIndexSymbolCache.get(nodeListId);
                                        }
                                        else {
                                            const copy = createSymbol(131072 /* Signature */, "__index" /* Index */);
                                            copy.declarations = mapDefined(infos, (i) => i.declaration);
                                            copy.parent = expressionType.aliasSymbol ? expressionType.aliasSymbol : expressionType.symbol ? expressionType.symbol : getSymbolAtLocation(copy.declarations[0].parent);
                                            symbolLinks2.filteredIndexSymbolCache.set(nodeListId, copy);
                                            links.resolvedSymbol = symbolLinks2.filteredIndexSymbolCache.get(nodeListId);
                                        }
                                    }
                                }
                            }
                        }
                        else {
                            checkQualifiedName(name, 0 /* Normal */);
                        }
                        if (!links.resolvedSymbol && isJSDoc2 && isQualifiedName(name)) {
                            return resolveJSDocMemberName(name);
                        }
                        return links.resolvedSymbol;
                    }
                    else if (isJSDocMemberName(name)) {
                        return resolveJSDocMemberName(name);
                    }
                }
                else if (isTypeReferenceIdentifier(name)) {
                    const meaning = name.parent.kind === 180 /* TypeReference */ ? 788968 /* Type */ : 1920 /* Namespace */;
                    const symbol = resolveEntityName(name, meaning, 
                    /*ignoreErrors*/
                    false, 
                    /*dontResolveAlias*/
                    true);
                    return symbol && symbol !== unknownSymbol ? symbol : getUnresolvedSymbolForEntityName(name);
                }
                if (name.parent.kind === 179 /* TypePredicate */) {
                    return resolveEntityName(name, 
                    /*meaning*/
                    1 /* FunctionScopedVariable */);
                }
                return void 0;
            }
            function resolveJSDocMemberName(name, ignoreErrors, container) {
                if (isEntityName(name)) {
                    const meaning = 788968 /* Type */ | 1920 /* Namespace */ | 111551 /* Value */;
                    let symbol = resolveEntityName(name, meaning, ignoreErrors, 
                    /*dontResolveAlias*/
                    true, getHostSignatureFromJSDoc(name));
                    if (!symbol && isIdentifier(name) && container) {
                        symbol = getMergedSymbol(getSymbol2(getExportsOfSymbol(container), name.escapedText, meaning));
                    }
                    if (symbol) {
                        return symbol;
                    }
                }
                const left = isIdentifier(name) ? container : resolveJSDocMemberName(name.left, ignoreErrors, container);
                const right = isIdentifier(name) ? name.escapedText : name.right.escapedText;
                if (left) {
                    const proto = left.flags & 111551 /* Value */ && getPropertyOfType(getTypeOfSymbol(left), "prototype");
                    const t = proto ? getTypeOfSymbol(proto) : getDeclaredTypeOfSymbol(left);
                    return getPropertyOfType(t, right);
                }
            }
            function getSymbolAtLocation(node, ignoreErrors) {
                if (isSourceFile(node)) {
                    return isExternalModule(node) ? getMergedSymbol(node.symbol) : void 0;
                }
                const { parent: parent2 } = node;
                const grandParent = parent2.parent;
                if (node.flags & 33554432 /* InWithStatement */) {
                    return void 0;
                }
                if (isDeclarationNameOrImportPropertyName(node)) {
                    const parentSymbol = getSymbolOfDeclaration(parent2);
                    return isImportOrExportSpecifier(node.parent) && node.parent.propertyName === node ? getImmediateAliasedSymbol(parentSymbol) : parentSymbol;
                }
                else if (isLiteralComputedPropertyDeclarationName(node)) {
                    return getSymbolOfDeclaration(parent2.parent);
                }
                if (node.kind === 79 /* Identifier */) {
                    if (isInRightSideOfImportOrExportAssignment(node)) {
                        return getSymbolOfNameOrPropertyAccessExpression(node);
                    }
                    else if (parent2.kind === 205 /* BindingElement */ && grandParent.kind === 203 /* ObjectBindingPattern */ && node === parent2.propertyName) {
                        const typeOfPattern = getTypeOfNode(grandParent);
                        const propertyDeclaration = getPropertyOfType(typeOfPattern, node.escapedText);
                        if (propertyDeclaration) {
                            return propertyDeclaration;
                        }
                    }
                    else if (isMetaProperty(parent2) && parent2.name === node) {
                        if (parent2.keywordToken === 103 /* NewKeyword */ && idText(node) === "target") {
                            return checkNewTargetMetaProperty(parent2).symbol;
                        }
                        if (parent2.keywordToken === 100 /* ImportKeyword */ && idText(node) === "meta") {
                            return getGlobalImportMetaExpressionType().members.get("meta");
                        }
                        return void 0;
                    }
                }
                switch (node.kind) {
                    case 79 /* Identifier */:
                    case 80 /* PrivateIdentifier */:
                    case 208 /* PropertyAccessExpression */:
                    case 163 /* QualifiedName */:
                        if (!isThisInTypeQuery(node)) {
                            return getSymbolOfNameOrPropertyAccessExpression(node);
                        }
                    case 108 /* ThisKeyword */:
                        const container = getThisContainer(node, 
                        /*includeArrowFunctions*/
                        false, 
                        /*includeClassComputedPropertyName*/
                        false);
                        if (isFunctionLike(container)) {
                            const sig = getSignatureFromDeclaration(container);
                            if (sig.thisParameter) {
                                return sig.thisParameter;
                            }
                        }
                        if (isInExpressionContext(node)) {
                            return checkExpression(node).symbol;
                        }
                    case 194 /* ThisType */:
                        return getTypeFromThisTypeNode(node).symbol;
                    case 106 /* SuperKeyword */:
                        return checkExpression(node).symbol;
                    case 135 /* ConstructorKeyword */:
                        const constructorDeclaration = node.parent;
                        if (constructorDeclaration && constructorDeclaration.kind === 173 /* Constructor */) {
                            return constructorDeclaration.parent.symbol;
                        }
                        return void 0;
                    case 10 /* StringLiteral */:
                    case 14 /* NoSubstitutionTemplateLiteral */:
                        if (isExternalModuleImportEqualsDeclaration(node.parent.parent) && getExternalModuleImportEqualsDeclarationExpression(node.parent.parent) === node || (node.parent.kind === 269 /* ImportDeclaration */ || node.parent.kind === 275 /* ExportDeclaration */) && node.parent.moduleSpecifier === node || (isInJSFile(node) && getEmitModuleResolutionKind(compilerOptions) !== 100 /* Bundler */ && isRequireCall(node.parent, 
                        /*checkArgumentIsStringLiteralLike*/
                        false) || isImportCall(node.parent)) || isLiteralTypeNode(node.parent) && isLiteralImportTypeNode(node.parent.parent) && node.parent.parent.argument === node.parent) {
                            return resolveExternalModuleName(node, node, ignoreErrors);
                        }
                        if (isCallExpression(parent2) && isBindableObjectDefinePropertyCall(parent2) && parent2.arguments[1] === node) {
                            return getSymbolOfDeclaration(parent2);
                        }
                    case 8 /* NumericLiteral */:
                        const objectType = isElementAccessExpression(parent2) ? parent2.argumentExpression === node ? getTypeOfExpression(parent2.expression) : void 0 : isLiteralTypeNode(parent2) && isIndexedAccessTypeNode(grandParent) ? getTypeFromTypeNode(grandParent.objectType) : void 0;
                        return objectType && getPropertyOfType(objectType, escapeLeadingUnderscores(node.text));
                    case 88 /* DefaultKeyword */:
                    case 98 /* FunctionKeyword */:
                    case 38 /* EqualsGreaterThanToken */:
                    case 84 /* ClassKeyword */:
                        return getSymbolOfNode(node.parent);
                    case 202 /* ImportType */:
                        return isLiteralImportTypeNode(node) ? getSymbolAtLocation(node.argument.literal, ignoreErrors) : void 0;
                    case 93 /* ExportKeyword */:
                        return isExportAssignment(node.parent) ? Debug.checkDefined(node.parent.symbol) : void 0;
                    case 100 /* ImportKeyword */:
                    case 103 /* NewKeyword */:
                        return isMetaProperty(node.parent) ? checkMetaPropertyKeyword(node.parent).symbol : void 0;
                    case 233 /* MetaProperty */:
                        return checkExpression(node).symbol;
                    default:
                        return void 0;
                }
            }
            function getIndexInfosAtLocation(node) {
                if (isIdentifier(node) && isPropertyAccessExpression(node.parent) && node.parent.name === node) {
                    const keyType = getLiteralTypeFromPropertyName(node);
                    const objectType = getTypeOfExpression(node.parent.expression);
                    const objectTypes = objectType.flags & 1048576 /* Union */ ? objectType.types : [objectType];
                    return flatMap(objectTypes, (t) => filter(getIndexInfosOfType(t), (info) => isApplicableIndexType(keyType, info.keyType)));
                }
                return void 0;
            }
            function getShorthandAssignmentValueSymbol(location) {
                if (location && location.kind === 300 /* ShorthandPropertyAssignment */) {
                    return resolveEntityName(location.name, 111551 /* Value */ | 2097152 /* Alias */);
                }
                return void 0;
            }
            function getExportSpecifierLocalTargetSymbol(node) {
                if (isExportSpecifier(node)) {
                    return node.parent.parent.moduleSpecifier ? getExternalModuleMember(node.parent.parent, node) : resolveEntityName(node.propertyName || node.name, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */);
                }
                else {
                    return resolveEntityName(node, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */);
                }
            }
            function getTypeOfNode(node) {
                if (isSourceFile(node) && !isExternalModule(node)) {
                    return errorType;
                }
                if (node.flags & 33554432 /* InWithStatement */) {
                    return errorType;
                }
                const classDecl = tryGetClassImplementingOrExtendingExpressionWithTypeArguments(node);
                const classType = classDecl && getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(classDecl.class));
                if (isPartOfTypeNode(node)) {
                    const typeFromTypeNode = getTypeFromTypeNode(node);
                    return classType ? getTypeWithThisArgument(typeFromTypeNode, classType.thisType) : typeFromTypeNode;
                }
                if (isExpressionNode(node)) {
                    return getRegularTypeOfExpression(node);
                }
                if (classType && !classDecl.isImplements) {
                    const baseType = firstOrUndefined(getBaseTypes(classType));
                    return baseType ? getTypeWithThisArgument(baseType, classType.thisType) : errorType;
                }
                if (isTypeDeclaration(node)) {
                    const symbol = getSymbolOfDeclaration(node);
                    return getDeclaredTypeOfSymbol(symbol);
                }
                if (isTypeDeclarationName(node)) {
                    const symbol = getSymbolAtLocation(node);
                    return symbol ? getDeclaredTypeOfSymbol(symbol) : errorType;
                }
                if (isDeclaration(node)) {
                    const symbol = getSymbolOfDeclaration(node);
                    return symbol ? getTypeOfSymbol(symbol) : errorType;
                }
                if (isDeclarationNameOrImportPropertyName(node)) {
                    const symbol = getSymbolAtLocation(node);
                    if (symbol) {
                        return getTypeOfSymbol(symbol);
                    }
                    return errorType;
                }
                if (isBindingPattern(node)) {
                    return getTypeForVariableLikeDeclaration(node.parent, 
                    /*includeOptionality*/
                    true, 0 /* Normal */) || errorType;
                }
                if (isInRightSideOfImportOrExportAssignment(node)) {
                    const symbol = getSymbolAtLocation(node);
                    if (symbol) {
                        const declaredType = getDeclaredTypeOfSymbol(symbol);
                        return !isErrorType(declaredType) ? declaredType : getTypeOfSymbol(symbol);
                    }
                }
                if (isMetaProperty(node.parent) && node.parent.keywordToken === node.kind) {
                    return checkMetaPropertyKeyword(node.parent);
                }
                return errorType;
            }
            function getTypeOfAssignmentPattern(expr) {
                Debug.assert(expr.kind === 207 /* ObjectLiteralExpression */ || expr.kind === 206 /* ArrayLiteralExpression */);
                if (expr.parent.kind === 247 /* ForOfStatement */) {
                    const iteratedType = checkRightHandSideOfForOf(expr.parent);
                    return checkDestructuringAssignment(expr, iteratedType || errorType);
                }
                if (expr.parent.kind === 223 /* BinaryExpression */) {
                    const iteratedType = getTypeOfExpression(expr.parent.right);
                    return checkDestructuringAssignment(expr, iteratedType || errorType);
                }
                if (expr.parent.kind === 299 /* PropertyAssignment */) {
                    const node2 = cast(expr.parent.parent, isObjectLiteralExpression);
                    const typeOfParentObjectLiteral = getTypeOfAssignmentPattern(node2) || errorType;
                    const propertyIndex = indexOfNode(node2.properties, expr.parent);
                    return checkObjectLiteralDestructuringPropertyAssignment(node2, typeOfParentObjectLiteral, propertyIndex);
                }
                const node = cast(expr.parent, isArrayLiteralExpression);
                const typeOfArrayLiteral = getTypeOfAssignmentPattern(node) || errorType;
                const elementType = checkIteratedTypeOrElementType(65 /* Destructuring */, typeOfArrayLiteral, undefinedType, expr.parent) || errorType;
                return checkArrayLiteralDestructuringElementAssignment(node, typeOfArrayLiteral, node.elements.indexOf(expr), elementType);
            }
            function getPropertySymbolOfDestructuringAssignment(location) {
                const typeOfObjectLiteral = getTypeOfAssignmentPattern(cast(location.parent.parent, isAssignmentPattern));
                return typeOfObjectLiteral && getPropertyOfType(typeOfObjectLiteral, location.escapedText);
            }
            function getRegularTypeOfExpression(expr) {
                if (isRightSideOfQualifiedNameOrPropertyAccess(expr)) {
                    expr = expr.parent;
                }
                return getRegularTypeOfLiteralType(getTypeOfExpression(expr));
            }
            function getParentTypeOfClassElement(node) {
                const classSymbol = getSymbolOfNode(node.parent);
                return isStatic(node) ? getTypeOfSymbol(classSymbol) : getDeclaredTypeOfSymbol(classSymbol);
            }
            function getClassElementPropertyKeyType(element) {
                const name = element.name;
                switch (name.kind) {
                    case 79 /* Identifier */:
                        return getStringLiteralType(idText(name));
                    case 8 /* NumericLiteral */:
                    case 10 /* StringLiteral */:
                        return getStringLiteralType(name.text);
                    case 164 /* ComputedPropertyName */:
                        const nameType = checkComputedPropertyName(name);
                        return isTypeAssignableToKind(nameType, 12288 /* ESSymbolLike */) ? nameType : stringType;
                    default:
                        return Debug.fail("Unsupported property name.");
                }
            }
            function getAugmentedPropertiesOfType(type) {
                type = getApparentType(type);
                const propsByName = createSymbolTable(getPropertiesOfType(type));
                const functionType = getSignaturesOfType(type, 0 /* Call */).length ? globalCallableFunctionType : getSignaturesOfType(type, 1 /* Construct */).length ? globalNewableFunctionType : void 0;
                if (functionType) {
                    forEach(getPropertiesOfType(functionType), (p) => {
                        if (!propsByName.has(p.escapedName)) {
                            propsByName.set(p.escapedName, p);
                        }
                    });
                }
                return getNamedMembers(propsByName);
            }
            function typeHasCallOrConstructSignatures(type) {
                return getSignaturesOfType(type, 0 /* Call */).length !== 0 || getSignaturesOfType(type, 1 /* Construct */).length !== 0;
            }
            function getRootSymbols(symbol) {
                const roots = getImmediateRootSymbols(symbol);
                return roots ? flatMap(roots, getRootSymbols) : [symbol];
            }
            function getImmediateRootSymbols(symbol) {
                if (getCheckFlags(symbol) & 6 /* Synthetic */) {
                    return mapDefined(getSymbolLinks(symbol).containingType.types, (type) => getPropertyOfType(type, symbol.escapedName));
                }
                else if (symbol.flags & 33554432 /* Transient */) {
                    const { links: { leftSpread, rightSpread, syntheticOrigin } } = symbol;
                    return leftSpread ? [leftSpread, rightSpread] : syntheticOrigin ? [syntheticOrigin] : singleElementArray(tryGetTarget(symbol));
                }
                return void 0;
            }
            function tryGetTarget(symbol) {
                let target;
                let next = symbol;
                while (next = getSymbolLinks(next).target) {
                    target = next;
                }
                return target;
            }
            function isArgumentsLocalBinding(nodeIn) {
                if (isGeneratedIdentifier(nodeIn))
                    return false;
                const node = getParseTreeNode(nodeIn, isIdentifier);
                if (!node)
                    return false;
                const parent2 = node.parent;
                if (!parent2)
                    return false;
                const isPropertyName2 = (isPropertyAccessExpression(parent2) || isPropertyAssignment(parent2)) && parent2.name === node;
                return !isPropertyName2 && getReferencedValueSymbol(node) === argumentsSymbol;
            }
            function moduleExportsSomeValue(moduleReferenceExpression) {
                let moduleSymbol = resolveExternalModuleName(moduleReferenceExpression.parent, moduleReferenceExpression);
                if (!moduleSymbol || isShorthandAmbientModuleSymbol(moduleSymbol)) {
                    return true;
                }
                const hasExportAssignment = hasExportAssignmentSymbol(moduleSymbol);
                moduleSymbol = resolveExternalModuleSymbol(moduleSymbol);
                const symbolLinks2 = getSymbolLinks(moduleSymbol);
                if (symbolLinks2.exportsSomeValue === void 0) {
                    symbolLinks2.exportsSomeValue = hasExportAssignment ? !!(moduleSymbol.flags & 111551 /* Value */) : forEachEntry(getExportsOfModule(moduleSymbol), isValue);
                }
                return symbolLinks2.exportsSomeValue;
                function isValue(s) {
                    s = resolveSymbol(s);
                    return s && !!(getAllSymbolFlags(s) & 111551 /* Value */);
                }
            }
            function isNameOfModuleOrEnumDeclaration(node) {
                return isModuleOrEnumDeclaration(node.parent) && node === node.parent.name;
            }
            function getReferencedExportContainer(nodeIn, prefixLocals) {
                var _a2;
                const node = getParseTreeNode(nodeIn, isIdentifier);
                if (node) {
                    let symbol = getReferencedValueSymbol(node, 
                    /*startInDeclarationContainer*/
                    isNameOfModuleOrEnumDeclaration(node));
                    if (symbol) {
                        if (symbol.flags & 1048576 /* ExportValue */) {
                            const exportSymbol = getMergedSymbol(symbol.exportSymbol);
                            if (!prefixLocals && exportSymbol.flags & 944 /* ExportHasLocal */ && !(exportSymbol.flags & 3 /* Variable */)) {
                                return void 0;
                            }
                            symbol = exportSymbol;
                        }
                        const parentSymbol = getParentOfSymbol(symbol);
                        if (parentSymbol) {
                            if (parentSymbol.flags & 512 /* ValueModule */ && ((_a2 = parentSymbol.valueDeclaration) == null ? void 0 : _a2.kind) === 308 /* SourceFile */) {
                                const symbolFile = parentSymbol.valueDeclaration;
                                const referenceFile = getSourceFileOfNode(node);
                                const symbolIsUmdExport = symbolFile !== referenceFile;
                                return symbolIsUmdExport ? void 0 : symbolFile;
                            }
                            return findAncestor(node.parent, (n) => isModuleOrEnumDeclaration(n) && getSymbolOfDeclaration(n) === parentSymbol);
                        }
                    }
                }
            }
            function getReferencedImportDeclaration(nodeIn) {
                const specifier = getIdentifierGeneratedImportReference(nodeIn);
                if (specifier) {
                    return specifier;
                }
                const node = getParseTreeNode(nodeIn, isIdentifier);
                if (node) {
                    const symbol = getReferencedValueOrAliasSymbol(node);
                    if (isNonLocalAlias(symbol, 
                    /*excludes*/
                    111551 /* Value */) && !getTypeOnlyAliasDeclaration(symbol, 111551 /* Value */)) {
                        return getDeclarationOfAliasSymbol(symbol);
                    }
                }
                return void 0;
            }
            function isSymbolOfDestructuredElementOfCatchBinding(symbol) {
                return symbol.valueDeclaration && isBindingElement(symbol.valueDeclaration) && walkUpBindingElementsAndPatterns(symbol.valueDeclaration).parent.kind === 295 /* CatchClause */;
            }
            function isSymbolOfDeclarationWithCollidingName(symbol) {
                if (symbol.flags & 418 /* BlockScoped */ && symbol.valueDeclaration && !isSourceFile(symbol.valueDeclaration)) {
                    const links = getSymbolLinks(symbol);
                    if (links.isDeclarationWithCollidingName === void 0) {
                        const container = getEnclosingBlockScopeContainer(symbol.valueDeclaration);
                        if (isStatementWithLocals(container) || isSymbolOfDestructuredElementOfCatchBinding(symbol)) {
                            const nodeLinks2 = getNodeLinks(symbol.valueDeclaration);
                            if (resolveName(container.parent, symbol.escapedName, 111551 /* Value */, 
                            /*nameNotFoundMessage*/
                            void 0, 
                            /*nameArg*/
                            void 0, 
                            /*isUse*/
                            false)) {
                                links.isDeclarationWithCollidingName = true;
                            }
                            else if (nodeLinks2.flags & 16384 /* CapturedBlockScopedBinding */) {
                                const isDeclaredInLoop = nodeLinks2.flags & 32768 /* BlockScopedBindingInLoop */;
                                const inLoopInitializer = isIterationStatement(container, 
                                /*lookInLabeledStatements*/
                                false);
                                const inLoopBodyBlock = container.kind === 238 /* Block */ && isIterationStatement(container.parent, 
                                /*lookInLabeledStatements*/
                                false);
                                links.isDeclarationWithCollidingName = !isBlockScopedContainerTopLevel(container) && (!isDeclaredInLoop || !inLoopInitializer && !inLoopBodyBlock);
                            }
                            else {
                                links.isDeclarationWithCollidingName = false;
                            }
                        }
                    }
                    return links.isDeclarationWithCollidingName;
                }
                return false;
            }
            function getReferencedDeclarationWithCollidingName(nodeIn) {
                if (!isGeneratedIdentifier(nodeIn)) {
                    const node = getParseTreeNode(nodeIn, isIdentifier);
                    if (node) {
                        const symbol = getReferencedValueSymbol(node);
                        if (symbol && isSymbolOfDeclarationWithCollidingName(symbol)) {
                            return symbol.valueDeclaration;
                        }
                    }
                }
                return void 0;
            }
            function isDeclarationWithCollidingName(nodeIn) {
                const node = getParseTreeNode(nodeIn, isDeclaration);
                if (node) {
                    const symbol = getSymbolOfDeclaration(node);
                    if (symbol) {
                        return isSymbolOfDeclarationWithCollidingName(symbol);
                    }
                }
                return false;
            }
            function isValueAliasDeclaration(node) {
                Debug.assert(!compilerOptions.verbatimModuleSyntax);
                switch (node.kind) {
                    case 268 /* ImportEqualsDeclaration */:
                        return isAliasResolvedToValue(getSymbolOfDeclaration(node));
                    case 270 /* ImportClause */:
                    case 271 /* NamespaceImport */:
                    case 273 /* ImportSpecifier */:
                    case 278 /* ExportSpecifier */:
                        const symbol = getSymbolOfDeclaration(node);
                        return !!symbol && isAliasResolvedToValue(symbol) && !getTypeOnlyAliasDeclaration(symbol, 111551 /* Value */);
                    case 275 /* ExportDeclaration */:
                        const exportClause = node.exportClause;
                        return !!exportClause && (isNamespaceExport(exportClause) || some(exportClause.elements, isValueAliasDeclaration));
                    case 274 /* ExportAssignment */:
                        return node.expression && node.expression.kind === 79 /* Identifier */ ? isAliasResolvedToValue(getSymbolOfDeclaration(node)) : true;
                }
                return false;
            }
            function isTopLevelValueImportEqualsWithEntityName(nodeIn) {
                const node = getParseTreeNode(nodeIn, isImportEqualsDeclaration);
                if (node === void 0 || node.parent.kind !== 308 /* SourceFile */ || !isInternalModuleImportEqualsDeclaration(node)) {
                    return false;
                }
                const isValue = isAliasResolvedToValue(getSymbolOfDeclaration(node));
                return isValue && node.moduleReference && !nodeIsMissing(node.moduleReference);
            }
            function isAliasResolvedToValue(symbol) {
                var _a2;
                if (!symbol) {
                    return false;
                }
                const target = getExportSymbolOfValueSymbolIfExported(resolveAlias(symbol));
                if (target === unknownSymbol) {
                    return true;
                }
                return !!(((_a2 = getAllSymbolFlags(target)) != null ? _a2 : -1) & 111551 /* Value */) && (shouldPreserveConstEnums(compilerOptions) || !isConstEnumOrConstEnumOnlyModule(target));
            }
            function isConstEnumOrConstEnumOnlyModule(s) {
                return isConstEnumSymbol(s) || !!s.constEnumOnlyModule;
            }
            function isReferencedAliasDeclaration(node, checkChildren) {
                Debug.assert(!compilerOptions.verbatimModuleSyntax);
                if (isAliasSymbolDeclaration2(node)) {
                    const symbol = getSymbolOfDeclaration(node);
                    const links = symbol && getSymbolLinks(symbol);
                    if (links == null ? void 0 : links.referenced) {
                        return true;
                    }
                    const target = getSymbolLinks(symbol).aliasTarget;
                    if (target && getEffectiveModifierFlags(node) & 1 /* Export */ && getAllSymbolFlags(target) & 111551 /* Value */ && (shouldPreserveConstEnums(compilerOptions) || !isConstEnumOrConstEnumOnlyModule(target))) {
                        return true;
                    }
                }
                if (checkChildren) {
                    return !!forEachChild(node, (node2) => isReferencedAliasDeclaration(node2, checkChildren));
                }
                return false;
            }
            function isImplementationOfOverload(node) {
                if (nodeIsPresent(node.body)) {
                    if (isGetAccessor(node) || isSetAccessor(node))
                        return false;
                    const symbol = getSymbolOfDeclaration(node);
                    const signaturesOfSymbol = getSignaturesOfSymbol(symbol);
                    return signaturesOfSymbol.length > 1 || // If there is single signature for the symbol, it is overload if that signature isn't coming from the node
                        // e.g.: function foo(a: string): string;
                        //       function foo(a: any) { // This is implementation of the overloads
                        //           return a;
                        //       }
                        signaturesOfSymbol.length === 1 && signaturesOfSymbol[0].declaration !== node;
                }
                return false;
            }
            function isRequiredInitializedParameter(parameter) {
                return !!strictNullChecks && !isOptionalParameter(parameter) && !isJSDocParameterTag(parameter) && !!parameter.initializer && !hasSyntacticModifier(parameter, 16476 /* ParameterPropertyModifier */);
            }
            function isOptionalUninitializedParameterProperty(parameter) {
                return strictNullChecks && isOptionalParameter(parameter) && !parameter.initializer && hasSyntacticModifier(parameter, 16476 /* ParameterPropertyModifier */);
            }
            function isExpandoFunctionDeclaration(node) {
                const declaration = getParseTreeNode(node, isFunctionDeclaration);
                if (!declaration) {
                    return false;
                }
                const symbol = getSymbolOfDeclaration(declaration);
                if (!symbol || !(symbol.flags & 16 /* Function */)) {
                    return false;
                }
                return !!forEachEntry(getExportsOfSymbol(symbol), (p) => p.flags & 111551 /* Value */ && p.valueDeclaration && isPropertyAccessExpression(p.valueDeclaration));
            }
            function getPropertiesOfContainerFunction(node) {
                const declaration = getParseTreeNode(node, isFunctionDeclaration);
                if (!declaration) {
                    return emptyArray;
                }
                const symbol = getSymbolOfDeclaration(declaration);
                return symbol && getPropertiesOfType(getTypeOfSymbol(symbol)) || emptyArray;
            }
            function getNodeCheckFlags(node) {
                var _a2;
                const nodeId = node.id || 0;
                if (nodeId < 0 || nodeId >= nodeLinks.length)
                    return 0;
                return ((_a2 = nodeLinks[nodeId]) == null ? void 0 : _a2.flags) || 0;
            }
            function getEnumMemberValue(node) {
                computeEnumMemberValues(node.parent);
                return getNodeLinks(node).enumMemberValue;
            }
            function canHaveConstantValue(node) {
                switch (node.kind) {
                    case 302 /* EnumMember */:
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        return true;
                }
                return false;
            }
            function getConstantValue2(node) {
                if (node.kind === 302 /* EnumMember */) {
                    return getEnumMemberValue(node);
                }
                const symbol = getNodeLinks(node).resolvedSymbol;
                if (symbol && symbol.flags & 8 /* EnumMember */) {
                    const member = symbol.valueDeclaration;
                    if (isEnumConst(member.parent)) {
                        return getEnumMemberValue(member);
                    }
                }
                return void 0;
            }
            function isFunctionType(type) {
                return !!(type.flags & 524288 /* Object */) && getSignaturesOfType(type, 0 /* Call */).length > 0;
            }
            function getTypeReferenceSerializationKind(typeNameIn, location) {
                var _a2;
                const typeName = getParseTreeNode(typeNameIn, isEntityName);
                if (!typeName)
                    return 0 /* Unknown */;
                if (location) {
                    location = getParseTreeNode(location);
                    if (!location)
                        return 0 /* Unknown */;
                }
                let isTypeOnly = false;
                if (isQualifiedName(typeName)) {
                    const rootValueSymbol = resolveEntityName(getFirstIdentifier(typeName), 111551 /* Value */, 
                    /*ignoreErrors*/
                    true, 
                    /*dontResolveAlias*/
                    true, location);
                    isTypeOnly = !!((_a2 = rootValueSymbol == null ? void 0 : rootValueSymbol.declarations) == null ? void 0 : _a2.every(isTypeOnlyImportOrExportDeclaration));
                }
                const valueSymbol = resolveEntityName(typeName, 111551 /* Value */, 
                /*ignoreErrors*/
                true, 
                /*dontResolveAlias*/
                true, location);
                const resolvedSymbol = valueSymbol && valueSymbol.flags & 2097152 /* Alias */ ? resolveAlias(valueSymbol) : valueSymbol;
                isTypeOnly || (isTypeOnly = !!(valueSymbol && getTypeOnlyAliasDeclaration(valueSymbol, 111551 /* Value */)));
                const typeSymbol = resolveEntityName(typeName, 788968 /* Type */, 
                /*ignoreErrors*/
                true, 
                /*dontResolveAlias*/
                false, location);
                if (resolvedSymbol && resolvedSymbol === typeSymbol) {
                    const globalPromiseSymbol = getGlobalPromiseConstructorSymbol(
                    /*reportErrors*/
                    false);
                    if (globalPromiseSymbol && resolvedSymbol === globalPromiseSymbol) {
                        return 9 /* Promise */;
                    }
                    const constructorType = getTypeOfSymbol(resolvedSymbol);
                    if (constructorType && isConstructorType(constructorType)) {
                        return isTypeOnly ? 10 /* TypeWithCallSignature */ : 1 /* TypeWithConstructSignatureAndValue */;
                    }
                }
                if (!typeSymbol) {
                    return isTypeOnly ? 11 /* ObjectType */ : 0 /* Unknown */;
                }
                const type = getDeclaredTypeOfSymbol(typeSymbol);
                if (isErrorType(type)) {
                    return isTypeOnly ? 11 /* ObjectType */ : 0 /* Unknown */;
                }
                else if (type.flags & 3 /* AnyOrUnknown */) {
                    return 11 /* ObjectType */;
                }
                else if (isTypeAssignableToKind(type, 16384 /* Void */ | 98304 /* Nullable */ | 131072 /* Never */)) {
                    return 2 /* VoidNullableOrNeverType */;
                }
                else if (isTypeAssignableToKind(type, 528 /* BooleanLike */)) {
                    return 6 /* BooleanType */;
                }
                else if (isTypeAssignableToKind(type, 296 /* NumberLike */)) {
                    return 3 /* NumberLikeType */;
                }
                else if (isTypeAssignableToKind(type, 2112 /* BigIntLike */)) {
                    return 4 /* BigIntLikeType */;
                }
                else if (isTypeAssignableToKind(type, 402653316 /* StringLike */)) {
                    return 5 /* StringLikeType */;
                }
                else if (isTupleType(type)) {
                    return 7 /* ArrayLikeType */;
                }
                else if (isTypeAssignableToKind(type, 12288 /* ESSymbolLike */)) {
                    return 8 /* ESSymbolType */;
                }
                else if (isFunctionType(type)) {
                    return 10 /* TypeWithCallSignature */;
                }
                else if (isArrayType(type)) {
                    return 7 /* ArrayLikeType */;
                }
                else {
                    return 11 /* ObjectType */;
                }
            }
            function createTypeOfDeclaration(declarationIn, enclosingDeclaration, flags, tracker, addUndefined) {
                const declaration = getParseTreeNode(declarationIn, isVariableLikeOrAccessor);
                if (!declaration) {
                    return factory.createToken(131 /* AnyKeyword */);
                }
                const symbol = getSymbolOfDeclaration(declaration);
                let type = symbol && !(symbol.flags & (2048 /* TypeLiteral */ | 131072 /* Signature */)) ? getWidenedLiteralType(getTypeOfSymbol(symbol)) : errorType;
                if (type.flags & 8192 /* UniqueESSymbol */ && type.symbol === symbol) {
                    flags |= 1048576 /* AllowUniqueESSymbolType */;
                }
                if (addUndefined) {
                    type = getOptionalType(type);
                }
                return nodeBuilder.typeToTypeNode(type, enclosingDeclaration, flags | 1024 /* MultilineObjectLiterals */, tracker);
            }
            function createReturnTypeOfSignatureDeclaration(signatureDeclarationIn, enclosingDeclaration, flags, tracker) {
                const signatureDeclaration = getParseTreeNode(signatureDeclarationIn, isFunctionLike);
                if (!signatureDeclaration) {
                    return factory.createToken(131 /* AnyKeyword */);
                }
                const signature = getSignatureFromDeclaration(signatureDeclaration);
                return nodeBuilder.typeToTypeNode(getReturnTypeOfSignature(signature), enclosingDeclaration, flags | 1024 /* MultilineObjectLiterals */, tracker);
            }
            function createTypeOfExpression(exprIn, enclosingDeclaration, flags, tracker) {
                const expr = getParseTreeNode(exprIn, isExpression);
                if (!expr) {
                    return factory.createToken(131 /* AnyKeyword */);
                }
                const type = getWidenedType(getRegularTypeOfExpression(expr));
                return nodeBuilder.typeToTypeNode(type, enclosingDeclaration, flags | 1024 /* MultilineObjectLiterals */, tracker);
            }
            function hasGlobalName(name) {
                return globals.has(escapeLeadingUnderscores(name));
            }
            function getReferencedValueSymbol(reference, startInDeclarationContainer) {
                const resolvedSymbol = getNodeLinks(reference).resolvedSymbol;
                if (resolvedSymbol) {
                    return resolvedSymbol;
                }
                let location = reference;
                if (startInDeclarationContainer) {
                    const parent2 = reference.parent;
                    if (isDeclaration(parent2) && reference === parent2.name) {
                        location = getDeclarationContainer(parent2);
                    }
                }
                return resolveName(location, reference.escapedText, 111551 /* Value */ | 1048576 /* ExportValue */ | 2097152 /* Alias */, 
                /*nodeNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                true);
            }
            function getReferencedValueOrAliasSymbol(reference) {
                const resolvedSymbol = getNodeLinks(reference).resolvedSymbol;
                if (resolvedSymbol && resolvedSymbol !== unknownSymbol) {
                    return resolvedSymbol;
                }
                return resolveName(reference, reference.escapedText, 111551 /* Value */ | 1048576 /* ExportValue */ | 2097152 /* Alias */, 
                /*nodeNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                true, 
                /*excludeGlobals*/
                void 0, 
                /*getSpellingSuggestions*/
                void 0);
            }
            function getReferencedValueDeclaration(referenceIn) {
                if (!isGeneratedIdentifier(referenceIn)) {
                    const reference = getParseTreeNode(referenceIn, isIdentifier);
                    if (reference) {
                        const symbol = getReferencedValueSymbol(reference);
                        if (symbol) {
                            return getExportSymbolOfValueSymbolIfExported(symbol).valueDeclaration;
                        }
                    }
                }
                return void 0;
            }
            function isLiteralConstDeclaration(node) {
                if (isDeclarationReadonly(node) || isVariableDeclaration(node) && isVarConst(node)) {
                    return isFreshLiteralType(getTypeOfSymbol(getSymbolOfDeclaration(node)));
                }
                return false;
            }
            function literalTypeToNode(type, enclosing, tracker) {
                const enumResult = type.flags & 1056 /* EnumLike */ ? nodeBuilder.symbolToExpression(type.symbol, 111551 /* Value */, enclosing, 
                /*flags*/
                void 0, tracker) : type === trueType ? factory.createTrue() : type === falseType && factory.createFalse();
                if (enumResult)
                    return enumResult;
                const literalValue = type.value;
                return typeof literalValue === "object" ? factory.createBigIntLiteral(literalValue) : typeof literalValue === "number" ? factory.createNumericLiteral(literalValue) : factory.createStringLiteral(literalValue);
            }
            function createLiteralConstValue(node, tracker) {
                const type = getTypeOfSymbol(getSymbolOfDeclaration(node));
                return literalTypeToNode(type, node, tracker);
            }
            function getJsxFactoryEntity(location) {
                return location ? (getJsxNamespace(location), getSourceFileOfNode(location).localJsxFactory || _jsxFactoryEntity) : _jsxFactoryEntity;
            }
            function getJsxFragmentFactoryEntity(location) {
                if (location) {
                    const file = getSourceFileOfNode(location);
                    if (file) {
                        if (file.localJsxFragmentFactory) {
                            return file.localJsxFragmentFactory;
                        }
                        const jsxFragPragmas = file.pragmas.get("jsxfrag");
                        const jsxFragPragma = isArray(jsxFragPragmas) ? jsxFragPragmas[0] : jsxFragPragmas;
                        if (jsxFragPragma) {
                            file.localJsxFragmentFactory = parseIsolatedEntityName(jsxFragPragma.arguments.factory, languageVersion);
                            return file.localJsxFragmentFactory;
                        }
                    }
                }
                if (compilerOptions.jsxFragmentFactory) {
                    return parseIsolatedEntityName(compilerOptions.jsxFragmentFactory, languageVersion);
                }
            }
            function createResolver() {
                const resolvedTypeReferenceDirectives = host.getResolvedTypeReferenceDirectives();
                let fileToDirective;
                if (resolvedTypeReferenceDirectives) {
                    fileToDirective = /* @__PURE__ */ new Map();
                    resolvedTypeReferenceDirectives.forEach(({ resolvedTypeReferenceDirective }, key, mode) => {
                        if (!(resolvedTypeReferenceDirective == null ? void 0 : resolvedTypeReferenceDirective.resolvedFileName)) {
                            return;
                        }
                        const file = host.getSourceFile(resolvedTypeReferenceDirective.resolvedFileName);
                        if (file) {
                            addReferencedFilesToTypeDirective(file, key, mode);
                        }
                    });
                }
                return {
                    getReferencedExportContainer,
                    getReferencedImportDeclaration,
                    getReferencedDeclarationWithCollidingName,
                    isDeclarationWithCollidingName,
                    isValueAliasDeclaration: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn);
                        return node ? isValueAliasDeclaration(node) : true;
                    },
                    hasGlobalName,
                    isReferencedAliasDeclaration: (nodeIn, checkChildren) => {
                        const node = getParseTreeNode(nodeIn);
                        return node ? isReferencedAliasDeclaration(node, checkChildren) : true;
                    },
                    getNodeCheckFlags: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn);
                        return node ? getNodeCheckFlags(node) : 0;
                    },
                    isTopLevelValueImportEqualsWithEntityName,
                    isDeclarationVisible,
                    isImplementationOfOverload,
                    isRequiredInitializedParameter,
                    isOptionalUninitializedParameterProperty,
                    isExpandoFunctionDeclaration,
                    getPropertiesOfContainerFunction,
                    createTypeOfDeclaration,
                    createReturnTypeOfSignatureDeclaration,
                    createTypeOfExpression,
                    createLiteralConstValue,
                    isSymbolAccessible,
                    isEntityNameVisible,
                    getConstantValue: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn, canHaveConstantValue);
                        return node ? getConstantValue2(node) : void 0;
                    },
                    collectLinkedAliases,
                    getReferencedValueDeclaration,
                    getTypeReferenceSerializationKind,
                    isOptionalParameter,
                    moduleExportsSomeValue,
                    isArgumentsLocalBinding,
                    getExternalModuleFileFromDeclaration: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn, hasPossibleExternalModuleReference);
                        return node && getExternalModuleFileFromDeclaration(node);
                    },
                    getTypeReferenceDirectivesForEntityName,
                    getTypeReferenceDirectivesForSymbol,
                    isLiteralConstDeclaration,
                    isLateBound: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn, isDeclaration);
                        const symbol = node && getSymbolOfDeclaration(node);
                        return !!(symbol && getCheckFlags(symbol) & 4096 /* Late */);
                    },
                    getJsxFactoryEntity,
                    getJsxFragmentFactoryEntity,
                    getAllAccessorDeclarations(accessor) {
                        accessor = getParseTreeNode(accessor, isGetOrSetAccessorDeclaration);
                        const otherKind = accessor.kind === 175 /* SetAccessor */ ? 174 /* GetAccessor */ : 175 /* SetAccessor */;
                        const otherAccessor = getDeclarationOfKind(getSymbolOfDeclaration(accessor), otherKind);
                        const firstAccessor = otherAccessor && otherAccessor.pos < accessor.pos ? otherAccessor : accessor;
                        const secondAccessor = otherAccessor && otherAccessor.pos < accessor.pos ? accessor : otherAccessor;
                        const setAccessor = accessor.kind === 175 /* SetAccessor */ ? accessor : otherAccessor;
                        const getAccessor = accessor.kind === 174 /* GetAccessor */ ? accessor : otherAccessor;
                        return {
                            firstAccessor,
                            secondAccessor,
                            setAccessor,
                            getAccessor
                        };
                    },
                    getSymbolOfExternalModuleSpecifier: (moduleName) => resolveExternalModuleNameWorker(moduleName, moduleName, 
                    /*moduleNotFoundError*/
                    void 0),
                    isBindingCapturedByNode: (node, decl) => {
                        const parseNode = getParseTreeNode(node);
                        const parseDecl = getParseTreeNode(decl);
                        return !!parseNode && !!parseDecl && (isVariableDeclaration(parseDecl) || isBindingElement(parseDecl)) && isBindingCapturedByNode(parseNode, parseDecl);
                    },
                    getDeclarationStatementsForSourceFile: (node, flags, tracker, bundled) => {
                        const n = getParseTreeNode(node);
                        Debug.assert(n && n.kind === 308 /* SourceFile */, "Non-sourcefile node passed into getDeclarationsForSourceFile");
                        const sym = getSymbolOfDeclaration(node);
                        if (!sym) {
                            return !node.locals ? [] : nodeBuilder.symbolTableToDeclarationStatements(node.locals, node, flags, tracker, bundled);
                        }
                        return !sym.exports ? [] : nodeBuilder.symbolTableToDeclarationStatements(sym.exports, node, flags, tracker, bundled);
                    },
                    isImportRequiredByAugmentation
                };
                function isImportRequiredByAugmentation(node) {
                    const file = getSourceFileOfNode(node);
                    if (!file.symbol)
                        return false;
                    const importTarget = getExternalModuleFileFromDeclaration(node);
                    if (!importTarget)
                        return false;
                    if (importTarget === file)
                        return false;
                    const exports = getExportsOfModule(file.symbol);
                    for (const s of arrayFrom(exports.values())) {
                        if (s.mergeId) {
                            const merged = getMergedSymbol(s);
                            if (merged.declarations) {
                                for (const d of merged.declarations) {
                                    const declFile = getSourceFileOfNode(d);
                                    if (declFile === importTarget) {
                                        return true;
                                    }
                                }
                            }
                        }
                    }
                    return false;
                }
                function isInHeritageClause(node) {
                    return node.parent && node.parent.kind === 230 /* ExpressionWithTypeArguments */ && node.parent.parent && node.parent.parent.kind === 294 /* HeritageClause */;
                }
                function getTypeReferenceDirectivesForEntityName(node) {
                    if (!fileToDirective) {
                        return void 0;
                    }
                    let meaning;
                    if (node.parent.kind === 164 /* ComputedPropertyName */) {
                        meaning = 111551 /* Value */ | 1048576 /* ExportValue */;
                    }
                    else {
                        meaning = 788968 /* Type */ | 1920 /* Namespace */;
                        if (node.kind === 79 /* Identifier */ && isInTypeQuery(node) || node.kind === 208 /* PropertyAccessExpression */ && !isInHeritageClause(node)) {
                            meaning = 111551 /* Value */ | 1048576 /* ExportValue */;
                        }
                    }
                    const symbol = resolveEntityName(node, meaning, 
                    /*ignoreErrors*/
                    true);
                    return symbol && symbol !== unknownSymbol ? getTypeReferenceDirectivesForSymbol(symbol, meaning) : void 0;
                }
                function getTypeReferenceDirectivesForSymbol(symbol, meaning) {
                    if (!fileToDirective || !isSymbolFromTypeDeclarationFile(symbol)) {
                        return void 0;
                    }
                    let typeReferenceDirectives;
                    for (const decl of symbol.declarations) {
                        if (decl.symbol && decl.symbol.flags & meaning) {
                            const file = getSourceFileOfNode(decl);
                            const typeReferenceDirective = fileToDirective.get(file.path);
                            if (typeReferenceDirective) {
                                (typeReferenceDirectives || (typeReferenceDirectives = [])).push(typeReferenceDirective);
                            }
                            else {
                                return void 0;
                            }
                        }
                    }
                    return typeReferenceDirectives;
                }
                function isSymbolFromTypeDeclarationFile(symbol) {
                    if (!symbol.declarations) {
                        return false;
                    }
                    let current = symbol;
                    while (true) {
                        const parent2 = getParentOfSymbol(current);
                        if (parent2) {
                            current = parent2;
                        }
                        else {
                            break;
                        }
                    }
                    if (current.valueDeclaration && current.valueDeclaration.kind === 308 /* SourceFile */ && current.flags & 512 /* ValueModule */) {
                        return false;
                    }
                    for (const decl of symbol.declarations) {
                        const file = getSourceFileOfNode(decl);
                        if (fileToDirective.has(file.path)) {
                            return true;
                        }
                    }
                    return false;
                }
                function addReferencedFilesToTypeDirective(file, key, mode) {
                    if (fileToDirective.has(file.path))
                        return;
                    fileToDirective.set(file.path, [key, mode]);
                    for (const { fileName, resolutionMode } of file.referencedFiles) {
                        const resolvedFile = resolveTripleslashReference(fileName, file.fileName);
                        const referencedFile = host.getSourceFile(resolvedFile);
                        if (referencedFile) {
                            addReferencedFilesToTypeDirective(referencedFile, key, resolutionMode || file.impliedNodeFormat);
                        }
                    }
                }
            }
            function getExternalModuleFileFromDeclaration(declaration) {
                const specifier = declaration.kind === 264 /* ModuleDeclaration */ ? tryCast(declaration.name, isStringLiteral) : getExternalModuleName(declaration);
                const moduleSymbol = resolveExternalModuleNameWorker(specifier, specifier, 
                /*moduleNotFoundError*/
                void 0);
                if (!moduleSymbol) {
                    return void 0;
                }
                return getDeclarationOfKind(moduleSymbol, 308 /* SourceFile */);
            }
            function initializeTypeChecker() {
                for (const file of host.getSourceFiles()) {
                    bindSourceFile(file, compilerOptions);
                }
                amalgamatedDuplicates = /* @__PURE__ */ new Map();
                let augmentations;
                for (const file of host.getSourceFiles()) {
                    if (file.redirectInfo) {
                        continue;
                    }
                    if (!isExternalOrCommonJsModule(file)) {
                        const fileGlobalThisSymbol = file.locals.get("globalThis");
                        if (fileGlobalThisSymbol == null ? void 0 : fileGlobalThisSymbol.declarations) {
                            for (const declaration of fileGlobalThisSymbol.declarations) {
                                diagnostics.add(createDiagnosticForNode(declaration, Diagnostics.Declaration_name_conflicts_with_built_in_global_identifier_0, "globalThis"));
                            }
                        }
                        mergeSymbolTable(globals, file.locals);
                    }
                    if (file.jsGlobalAugmentations) {
                        mergeSymbolTable(globals, file.jsGlobalAugmentations);
                    }
                    if (file.patternAmbientModules && file.patternAmbientModules.length) {
                        patternAmbientModules = concatenate(patternAmbientModules, file.patternAmbientModules);
                    }
                    if (file.moduleAugmentations.length) {
                        (augmentations || (augmentations = [])).push(file.moduleAugmentations);
                    }
                    if (file.symbol && file.symbol.globalExports) {
                        const source = file.symbol.globalExports;
                        source.forEach((sourceSymbol, id) => {
                            if (!globals.has(id)) {
                                globals.set(id, sourceSymbol);
                            }
                        });
                    }
                }
                if (augmentations) {
                    for (const list of augmentations) {
                        for (const augmentation of list) {
                            if (!isGlobalScopeAugmentation(augmentation.parent))
                                continue;
                            mergeModuleAugmentation(augmentation);
                        }
                    }
                }
                addToSymbolTable(globals, builtinGlobals, Diagnostics.Declaration_name_conflicts_with_built_in_global_identifier_0);
                getSymbolLinks(undefinedSymbol).type = undefinedWideningType;
                getSymbolLinks(argumentsSymbol).type = getGlobalType("IArguments", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                getSymbolLinks(unknownSymbol).type = errorType;
                getSymbolLinks(globalThisSymbol).type = createObjectType(16 /* Anonymous */, globalThisSymbol);
                globalArrayType = getGlobalType("Array", 
                /*arity*/
                1, 
                /*reportErrors*/
                true);
                globalObjectType = getGlobalType("Object", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalFunctionType = getGlobalType("Function", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalCallableFunctionType = strictBindCallApply && getGlobalType("CallableFunction", 
                /*arity*/
                0, 
                /*reportErrors*/
                true) || globalFunctionType;
                globalNewableFunctionType = strictBindCallApply && getGlobalType("NewableFunction", 
                /*arity*/
                0, 
                /*reportErrors*/
                true) || globalFunctionType;
                globalStringType = getGlobalType("String", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalNumberType = getGlobalType("Number", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalBooleanType = getGlobalType("Boolean", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalRegExpType = getGlobalType("RegExp", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                anyArrayType = createArrayType(anyType);
                autoArrayType = createArrayType(autoType);
                if (autoArrayType === emptyObjectType) {
                    autoArrayType = createAnonymousType(void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
                }
                globalReadonlyArrayType = getGlobalTypeOrUndefined("ReadonlyArray", 
                /*arity*/
                1) || globalArrayType;
                anyReadonlyArrayType = globalReadonlyArrayType ? createTypeFromGenericGlobalType(globalReadonlyArrayType, [anyType]) : anyArrayType;
                globalThisType = getGlobalTypeOrUndefined("ThisType", 
                /*arity*/
                1);
                if (augmentations) {
                    for (const list of augmentations) {
                        for (const augmentation of list) {
                            if (isGlobalScopeAugmentation(augmentation.parent))
                                continue;
                            mergeModuleAugmentation(augmentation);
                        }
                    }
                }
                amalgamatedDuplicates.forEach(({ firstFile, secondFile, conflictingSymbols }) => {
                    if (conflictingSymbols.size < 8) {
                        conflictingSymbols.forEach(({ isBlockScoped, firstFileLocations, secondFileLocations }, symbolName2) => {
                            const message = isBlockScoped ? Diagnostics.Cannot_redeclare_block_scoped_variable_0 : Diagnostics.Duplicate_identifier_0;
                            for (const node of firstFileLocations) {
                                addDuplicateDeclarationError(node, message, symbolName2, secondFileLocations);
                            }
                            for (const node of secondFileLocations) {
                                addDuplicateDeclarationError(node, message, symbolName2, firstFileLocations);
                            }
                        });
                    }
                    else {
                        const list = arrayFrom(conflictingSymbols.keys()).join(", ");
                        diagnostics.add(addRelatedInfo(createDiagnosticForNode(firstFile, Diagnostics.Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0, list), createDiagnosticForNode(secondFile, Diagnostics.Conflicts_are_in_this_file)));
                        diagnostics.add(addRelatedInfo(createDiagnosticForNode(secondFile, Diagnostics.Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0, list), createDiagnosticForNode(firstFile, Diagnostics.Conflicts_are_in_this_file)));
                    }
                });
                amalgamatedDuplicates = void 0;
            }
            function checkExternalEmitHelpers(location, helpers) {
                if ((requestedExternalEmitHelpers & helpers) !== helpers && compilerOptions.importHelpers) {
                    const sourceFile = getSourceFileOfNode(location);
                    if (isEffectiveExternalModule(sourceFile, compilerOptions) && !(location.flags & 16777216 /* Ambient */)) {
                        const helpersModule = resolveHelpersModule(sourceFile, location);
                        if (helpersModule !== unknownSymbol) {
                            const uncheckedHelpers = helpers & ~requestedExternalEmitHelpers;
                            for (let helper = 1 /* FirstEmitHelper */; helper <= 16777216 /* LastEmitHelper */; helper <<= 1) {
                                if (uncheckedHelpers & helper) {
                                    for (const name of getHelperNames(helper)) {
                                        if (requestedExternalEmitHelperNames.has(name))
                                            continue;
                                        requestedExternalEmitHelperNames.add(name);
                                        const symbol = getSymbol2(helpersModule.exports, escapeLeadingUnderscores(name), 111551 /* Value */);
                                        if (!symbol) {
                                            error(location, Diagnostics.This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_version_of_0, externalHelpersModuleNameText, name);
                                        }
                                        else if (helper & 524288 /* ClassPrivateFieldGet */) {
                                            if (!some(getSignaturesOfSymbol(symbol), (signature) => getParameterCount(signature) > 3)) {
                                                error(location, Diagnostics.This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0, externalHelpersModuleNameText, name, 4);
                                            }
                                        }
                                        else if (helper & 1048576 /* ClassPrivateFieldSet */) {
                                            if (!some(getSignaturesOfSymbol(symbol), (signature) => getParameterCount(signature) > 4)) {
                                                error(location, Diagnostics.This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0, externalHelpersModuleNameText, name, 5);
                                            }
                                        }
                                        else if (helper & 1024 /* SpreadArray */) {
                                            if (!some(getSignaturesOfSymbol(symbol), (signature) => getParameterCount(signature) > 2)) {
                                                error(location, Diagnostics.This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0, externalHelpersModuleNameText, name, 3);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        requestedExternalEmitHelpers |= helpers;
                    }
                }
            }
            function getHelperNames(helper) {
                switch (helper) {
                    case 1 /* Extends */:
                        return ["__extends"];
                    case 2 /* Assign */:
                        return ["__assign"];
                    case 4 /* Rest */:
                        return ["__rest"];
                    case 8 /* Decorate */:
                        return legacyDecorators ? ["__decorate"] : ["__esDecorate", "__runInitializers"];
                    case 16 /* Metadata */:
                        return ["__metadata"];
                    case 32 /* Param */:
                        return ["__param"];
                    case 64 /* Awaiter */:
                        return ["__awaiter"];
                    case 128 /* Generator */:
                        return ["__generator"];
                    case 256 /* Values */:
                        return ["__values"];
                    case 512 /* Read */:
                        return ["__read"];
                    case 1024 /* SpreadArray */:
                        return ["__spreadArray"];
                    case 2048 /* Await */:
                        return ["__await"];
                    case 4096 /* AsyncGenerator */:
                        return ["__asyncGenerator"];
                    case 8192 /* AsyncDelegator */:
                        return ["__asyncDelegator"];
                    case 16384 /* AsyncValues */:
                        return ["__asyncValues"];
                    case 32768 /* ExportStar */:
                        return ["__exportStar"];
                    case 65536 /* ImportStar */:
                        return ["__importStar"];
                    case 131072 /* ImportDefault */:
                        return ["__importDefault"];
                    case 262144 /* MakeTemplateObject */:
                        return ["__makeTemplateObject"];
                    case 524288 /* ClassPrivateFieldGet */:
                        return ["__classPrivateFieldGet"];
                    case 1048576 /* ClassPrivateFieldSet */:
                        return ["__classPrivateFieldSet"];
                    case 2097152 /* ClassPrivateFieldIn */:
                        return ["__classPrivateFieldIn"];
                    case 4194304 /* CreateBinding */:
                        return ["__createBinding"];
                    case 8388608 /* SetFunctionName */:
                        return ["__setFunctionName"];
                    case 16777216 /* PropKey */:
                        return ["__propKey"];
                    default:
                        return Debug.fail("Unrecognized helper");
                }
            }
            function resolveHelpersModule(node, errorNode) {
                if (!externalHelpersModule) {
                    externalHelpersModule = resolveExternalModule(node, externalHelpersModuleNameText, Diagnostics.This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found, errorNode) || unknownSymbol;
                }
                return externalHelpersModule;
            }
            function checkGrammarModifiers(node) {
                const quickResult = reportObviousDecoratorErrors(node) || reportObviousModifierErrors(node);
                if (quickResult !== void 0) {
                    return quickResult;
                }
                if (isParameter(node) && parameterIsThisKeyword(node)) {
                    return grammarErrorOnFirstToken(node, Diagnostics.Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters);
                }
                let lastStatic, lastDeclare, lastAsync, lastOverride, firstDecorator;
                let flags = 0 /* None */;
                let sawExportBeforeDecorators = false;
                let hasLeadingDecorators = false;
                for (const modifier of node.modifiers) {
                    if (isDecorator(modifier)) {
                        if (!nodeCanBeDecorated(legacyDecorators, node, node.parent, node.parent.parent)) {
                            if (node.kind === 171 /* MethodDeclaration */ && !nodeIsPresent(node.body)) {
                                return grammarErrorOnFirstToken(node, Diagnostics.A_decorator_can_only_decorate_a_method_implementation_not_an_overload);
                            }
                            else {
                                return grammarErrorOnFirstToken(node, Diagnostics.Decorators_are_not_valid_here);
                            }
                        }
                        else if (legacyDecorators && (node.kind === 174 /* GetAccessor */ || node.kind === 175 /* SetAccessor */)) {
                            const accessors = getAllAccessorDeclarations(node.parent.members, node);
                            if (hasDecorators(accessors.firstAccessor) && node === accessors.secondAccessor) {
                                return grammarErrorOnFirstToken(node, Diagnostics.Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name);
                            }
                        }
                        if (flags & ~(1025 /* ExportDefault */ | 131072 /* Decorator */)) {
                            return grammarErrorOnNode(modifier, Diagnostics.Decorators_are_not_valid_here);
                        }
                        if (hasLeadingDecorators && flags & 126975 /* Modifier */) {
                            Debug.assertIsDefined(firstDecorator);
                            const sourceFile = getSourceFileOfNode(modifier);
                            if (!hasParseDiagnostics(sourceFile)) {
                                addRelatedInfo(error(modifier, Diagnostics.Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export), createDiagnosticForNode(firstDecorator, Diagnostics.Decorator_used_before_export_here));
                                return true;
                            }
                            return false;
                        }
                        flags |= 131072 /* Decorator */;
                        if (!(flags & 126975 /* Modifier */)) {
                            hasLeadingDecorators = true;
                        }
                        else if (flags & 1 /* Export */) {
                            sawExportBeforeDecorators = true;
                        }
                        firstDecorator != null ? firstDecorator : firstDecorator = modifier;
                    }
                    else {
                        if (modifier.kind !== 146 /* ReadonlyKeyword */) {
                            if (node.kind === 168 /* PropertySignature */ || node.kind === 170 /* MethodSignature */) {
                                return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_type_member, tokenToString(modifier.kind));
                            }
                            if (node.kind === 178 /* IndexSignature */ && (modifier.kind !== 124 /* StaticKeyword */ || !isClassLike(node.parent))) {
                                return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_an_index_signature, tokenToString(modifier.kind));
                            }
                        }
                        if (modifier.kind !== 101 /* InKeyword */ && modifier.kind !== 145 /* OutKeyword */ && modifier.kind !== 85 /* ConstKeyword */) {
                            if (node.kind === 165 /* TypeParameter */) {
                                return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_type_parameter, tokenToString(modifier.kind));
                            }
                        }
                        switch (modifier.kind) {
                            case 85 /* ConstKeyword */:
                                if (node.kind !== 263 /* EnumDeclaration */ && node.kind !== 165 /* TypeParameter */) {
                                    return grammarErrorOnNode(node, Diagnostics.A_class_member_cannot_have_the_0_keyword, tokenToString(85 /* ConstKeyword */));
                                }
                                const parent2 = node.parent;
                                if (node.kind === 165 /* TypeParameter */ && !(isFunctionLikeDeclaration(parent2) || isClassLike(parent2) || isFunctionTypeNode(parent2) || isConstructorTypeNode(parent2) || isCallSignatureDeclaration(parent2) || isConstructSignatureDeclaration(parent2) || isMethodSignature(parent2))) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_can_only_appear_on_a_type_parameter_of_a_function_method_or_class, tokenToString(modifier.kind));
                                }
                                break;
                            case 161 /* OverrideKeyword */:
                                if (flags & 16384 /* Override */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "override");
                                }
                                else if (flags & 2 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "override", "declare");
                                }
                                else if (flags & 64 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "override", "readonly");
                                }
                                else if (flags & 128 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "override", "accessor");
                                }
                                else if (flags & 512 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "override", "async");
                                }
                                flags |= 16384 /* Override */;
                                lastOverride = modifier;
                                break;
                            case 123 /* PublicKeyword */:
                            case 122 /* ProtectedKeyword */:
                            case 121 /* PrivateKeyword */:
                                const text = visibilityToString(modifierToFlag(modifier.kind));
                                if (flags & 28 /* AccessibilityModifier */) {
                                    return grammarErrorOnNode(modifier, Diagnostics.Accessibility_modifier_already_seen);
                                }
                                else if (flags & 16384 /* Override */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "override");
                                }
                                else if (flags & 32 /* Static */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "static");
                                }
                                else if (flags & 128 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "accessor");
                                }
                                else if (flags & 64 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "readonly");
                                }
                                else if (flags & 512 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "async");
                                }
                                else if (node.parent.kind === 265 /* ModuleBlock */ || node.parent.kind === 308 /* SourceFile */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_module_or_namespace_element, text);
                                }
                                else if (flags & 256 /* Abstract */) {
                                    if (modifier.kind === 121 /* PrivateKeyword */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, text, "abstract");
                                    }
                                    else {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "abstract");
                                    }
                                }
                                else if (isPrivateIdentifierClassElementDeclaration(node)) {
                                    return grammarErrorOnNode(modifier, Diagnostics.An_accessibility_modifier_cannot_be_used_with_a_private_identifier);
                                }
                                flags |= modifierToFlag(modifier.kind);
                                break;
                            case 124 /* StaticKeyword */:
                                if (flags & 32 /* Static */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "static");
                                }
                                else if (flags & 64 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "static", "readonly");
                                }
                                else if (flags & 512 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "static", "async");
                                }
                                else if (flags & 128 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "static", "accessor");
                                }
                                else if (node.parent.kind === 265 /* ModuleBlock */ || node.parent.kind === 308 /* SourceFile */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_module_or_namespace_element, "static");
                                }
                                else if (node.kind === 166 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_parameter, "static");
                                }
                                else if (flags & 256 /* Abstract */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "static", "abstract");
                                }
                                else if (flags & 16384 /* Override */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "static", "override");
                                }
                                flags |= 32 /* Static */;
                                lastStatic = modifier;
                                break;
                            case 127 /* AccessorKeyword */:
                                if (flags & 128 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "accessor");
                                }
                                else if (flags & 64 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "accessor", "readonly");
                                }
                                else if (flags & 2 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "accessor", "declare");
                                }
                                else if (node.kind !== 169 /* PropertyDeclaration */) {
                                    return grammarErrorOnNode(modifier, Diagnostics.accessor_modifier_can_only_appear_on_a_property_declaration);
                                }
                                flags |= 128 /* Accessor */;
                                break;
                            case 146 /* ReadonlyKeyword */:
                                if (flags & 64 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "readonly");
                                }
                                else if (node.kind !== 169 /* PropertyDeclaration */ && node.kind !== 168 /* PropertySignature */ && node.kind !== 178 /* IndexSignature */ && node.kind !== 166 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics.readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature);
                                }
                                else if (flags & 128 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "readonly", "accessor");
                                }
                                flags |= 64 /* Readonly */;
                                break;
                            case 93 /* ExportKeyword */:
                                if (compilerOptions.verbatimModuleSyntax && !(node.flags & 16777216 /* Ambient */) && node.kind !== 262 /* TypeAliasDeclaration */ && node.kind !== 261 /* InterfaceDeclaration */ && // ModuleDeclaration needs to be checked that it is uninstantiated later
                                    node.kind !== 264 /* ModuleDeclaration */ && node.parent.kind === 308 /* SourceFile */ && (moduleKind === 1 /* CommonJS */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                                    return grammarErrorOnNode(modifier, Diagnostics.A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                                }
                                if (flags & 1 /* Export */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "export");
                                }
                                else if (flags & 2 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "export", "declare");
                                }
                                else if (flags & 256 /* Abstract */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "export", "abstract");
                                }
                                else if (flags & 512 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "export", "async");
                                }
                                else if (isClassLike(node.parent)) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_class_elements_of_this_kind, "export");
                                }
                                else if (node.kind === 166 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_parameter, "export");
                                }
                                flags |= 1 /* Export */;
                                break;
                            case 88 /* DefaultKeyword */:
                                const container = node.parent.kind === 308 /* SourceFile */ ? node.parent : node.parent.parent;
                                if (container.kind === 264 /* ModuleDeclaration */ && !isAmbientModule(container)) {
                                    return grammarErrorOnNode(modifier, Diagnostics.A_default_export_can_only_be_used_in_an_ECMAScript_style_module);
                                }
                                else if (!(flags & 1 /* Export */)) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "export", "default");
                                }
                                else if (sawExportBeforeDecorators) {
                                    return grammarErrorOnNode(firstDecorator, Diagnostics.Decorators_are_not_valid_here);
                                }
                                flags |= 1024 /* Default */;
                                break;
                            case 136 /* DeclareKeyword */:
                                if (flags & 2 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "declare");
                                }
                                else if (flags & 512 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context, "async");
                                }
                                else if (flags & 16384 /* Override */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context, "override");
                                }
                                else if (isClassLike(node.parent) && !isPropertyDeclaration(node)) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_class_elements_of_this_kind, "declare");
                                }
                                else if (node.kind === 166 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_parameter, "declare");
                                }
                                else if (node.parent.flags & 16777216 /* Ambient */ && node.parent.kind === 265 /* ModuleBlock */) {
                                    return grammarErrorOnNode(modifier, Diagnostics.A_declare_modifier_cannot_be_used_in_an_already_ambient_context);
                                }
                                else if (isPrivateIdentifierClassElementDeclaration(node)) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_a_private_identifier, "declare");
                                }
                                else if (flags & 128 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "declare", "accessor");
                                }
                                flags |= 2 /* Ambient */;
                                lastDeclare = modifier;
                                break;
                            case 126 /* AbstractKeyword */:
                                if (flags & 256 /* Abstract */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "abstract");
                                }
                                if (node.kind !== 260 /* ClassDeclaration */ && node.kind !== 182 /* ConstructorType */) {
                                    if (node.kind !== 171 /* MethodDeclaration */ && node.kind !== 169 /* PropertyDeclaration */ && node.kind !== 174 /* GetAccessor */ && node.kind !== 175 /* SetAccessor */) {
                                        return grammarErrorOnNode(modifier, Diagnostics.abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration);
                                    }
                                    if (!(node.parent.kind === 260 /* ClassDeclaration */ && hasSyntacticModifier(node.parent, 256 /* Abstract */))) {
                                        return grammarErrorOnNode(modifier, Diagnostics.Abstract_methods_can_only_appear_within_an_abstract_class);
                                    }
                                    if (flags & 32 /* Static */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "static", "abstract");
                                    }
                                    if (flags & 8 /* Private */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "private", "abstract");
                                    }
                                    if (flags & 512 /* Async */ && lastAsync) {
                                        return grammarErrorOnNode(lastAsync, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "async", "abstract");
                                    }
                                    if (flags & 16384 /* Override */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "abstract", "override");
                                    }
                                    if (flags & 128 /* Accessor */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "abstract", "accessor");
                                    }
                                }
                                if (isNamedDeclaration(node) && node.name.kind === 80 /* PrivateIdentifier */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_a_private_identifier, "abstract");
                                }
                                flags |= 256 /* Abstract */;
                                break;
                            case 132 /* AsyncKeyword */:
                                if (flags & 512 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "async");
                                }
                                else if (flags & 2 /* Ambient */ || node.parent.flags & 16777216 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context, "async");
                                }
                                else if (node.kind === 166 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_parameter, "async");
                                }
                                if (flags & 256 /* Abstract */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "async", "abstract");
                                }
                                flags |= 512 /* Async */;
                                lastAsync = modifier;
                                break;
                            case 101 /* InKeyword */:
                            case 145 /* OutKeyword */:
                                const inOutFlag = modifier.kind === 101 /* InKeyword */ ? 32768 /* In */ : 65536 /* Out */;
                                const inOutText = modifier.kind === 101 /* InKeyword */ ? "in" : "out";
                                if (node.kind !== 165 /* TypeParameter */ || !(isInterfaceDeclaration(node.parent) || isClassLike(node.parent) || isTypeAliasDeclaration(node.parent))) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias, inOutText);
                                }
                                if (flags & inOutFlag) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, inOutText);
                                }
                                if (inOutFlag & 32768 /* In */ && flags & 65536 /* Out */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "in", "out");
                                }
                                flags |= inOutFlag;
                                break;
                        }
                    }
                }
                if (node.kind === 173 /* Constructor */) {
                    if (flags & 32 /* Static */) {
                        return grammarErrorOnNode(lastStatic, Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "static");
                    }
                    if (flags & 16384 /* Override */) {
                        return grammarErrorOnNode(lastOverride, Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "override");
                    }
                    if (flags & 512 /* Async */) {
                        return grammarErrorOnNode(lastAsync, Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "async");
                    }
                    return false;
                }
                else if ((node.kind === 269 /* ImportDeclaration */ || node.kind === 268 /* ImportEqualsDeclaration */) && flags & 2 /* Ambient */) {
                    return grammarErrorOnNode(lastDeclare, Diagnostics.A_0_modifier_cannot_be_used_with_an_import_declaration, "declare");
                }
                else if (node.kind === 166 /* Parameter */ && flags & 16476 /* ParameterPropertyModifier */ && isBindingPattern(node.name)) {
                    return grammarErrorOnNode(node, Diagnostics.A_parameter_property_may_not_be_declared_using_a_binding_pattern);
                }
                else if (node.kind === 166 /* Parameter */ && flags & 16476 /* ParameterPropertyModifier */ && node.dotDotDotToken) {
                    return grammarErrorOnNode(node, Diagnostics.A_parameter_property_cannot_be_declared_using_a_rest_parameter);
                }
                if (flags & 512 /* Async */) {
                    return checkGrammarAsyncModifier(node, lastAsync);
                }
                return false;
            }
            function reportObviousModifierErrors(node) {
                if (!node.modifiers)
                    return false;
                const modifier = findFirstIllegalModifier(node);
                return modifier && grammarErrorOnFirstToken(modifier, Diagnostics.Modifiers_cannot_appear_here);
            }
            function findFirstModifierExcept(node, allowedModifier) {
                const modifier = find(node.modifiers, isModifier);
                return modifier && modifier.kind !== allowedModifier ? modifier : void 0;
            }
            function findFirstIllegalModifier(node) {
                switch (node.kind) {
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 173 /* Constructor */:
                    case 169 /* PropertyDeclaration */:
                    case 168 /* PropertySignature */:
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                    case 178 /* IndexSignature */:
                    case 264 /* ModuleDeclaration */:
                    case 269 /* ImportDeclaration */:
                    case 268 /* ImportEqualsDeclaration */:
                    case 275 /* ExportDeclaration */:
                    case 274 /* ExportAssignment */:
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                    case 166 /* Parameter */:
                    case 165 /* TypeParameter */:
                        return void 0;
                    case 172 /* ClassStaticBlockDeclaration */:
                    case 299 /* PropertyAssignment */:
                    case 300 /* ShorthandPropertyAssignment */:
                    case 267 /* NamespaceExportDeclaration */:
                    case 279 /* MissingDeclaration */:
                        return find(node.modifiers, isModifier);
                    default:
                        if (node.parent.kind === 265 /* ModuleBlock */ || node.parent.kind === 308 /* SourceFile */) {
                            return void 0;
                        }
                        switch (node.kind) {
                            case 259 /* FunctionDeclaration */:
                                return findFirstModifierExcept(node, 132 /* AsyncKeyword */);
                            case 260 /* ClassDeclaration */:
                            case 182 /* ConstructorType */:
                                return findFirstModifierExcept(node, 126 /* AbstractKeyword */);
                            case 228 /* ClassExpression */:
                            case 261 /* InterfaceDeclaration */:
                            case 240 /* VariableStatement */:
                            case 262 /* TypeAliasDeclaration */:
                                return find(node.modifiers, isModifier);
                            case 263 /* EnumDeclaration */:
                                return findFirstModifierExcept(node, 85 /* ConstKeyword */);
                            default:
                                Debug.assertNever(node);
                        }
                }
            }
            function reportObviousDecoratorErrors(node) {
                const decorator = findFirstIllegalDecorator(node);
                return decorator && grammarErrorOnFirstToken(decorator, Diagnostics.Decorators_are_not_valid_here);
            }
            function findFirstIllegalDecorator(node) {
                return canHaveIllegalDecorators(node) ? find(node.modifiers, isDecorator) : void 0;
            }
            function checkGrammarAsyncModifier(node, asyncModifier) {
                switch (node.kind) {
                    case 171 /* MethodDeclaration */:
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                        return false;
                }
                return grammarErrorOnNode(asyncModifier, Diagnostics._0_modifier_cannot_be_used_here, "async");
            }
            function checkGrammarForDisallowedTrailingComma(list, diag2 = Diagnostics.Trailing_comma_not_allowed) {
                if (list && list.hasTrailingComma) {
                    return grammarErrorAtPos(list[0], list.end - ",".length, ",".length, diag2);
                }
                return false;
            }
            function checkGrammarTypeParameterList(typeParameters, file) {
                if (typeParameters && typeParameters.length === 0) {
                    const start = typeParameters.pos - "<".length;
                    const end = skipTrivia(file.text, typeParameters.end) + ">".length;
                    return grammarErrorAtPos(file, start, end - start, Diagnostics.Type_parameter_list_cannot_be_empty);
                }
                return false;
            }
            function checkGrammarParameterList(parameters) {
                let seenOptionalParameter = false;
                const parameterCount = parameters.length;
                for (let i = 0; i < parameterCount; i++) {
                    const parameter = parameters[i];
                    if (parameter.dotDotDotToken) {
                        if (i !== parameterCount - 1) {
                            return grammarErrorOnNode(parameter.dotDotDotToken, Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list);
                        }
                        if (!(parameter.flags & 16777216 /* Ambient */)) {
                            checkGrammarForDisallowedTrailingComma(parameters, Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma);
                        }
                        if (parameter.questionToken) {
                            return grammarErrorOnNode(parameter.questionToken, Diagnostics.A_rest_parameter_cannot_be_optional);
                        }
                        if (parameter.initializer) {
                            return grammarErrorOnNode(parameter.name, Diagnostics.A_rest_parameter_cannot_have_an_initializer);
                        }
                    }
                    else if (isOptionalParameter(parameter)) {
                        seenOptionalParameter = true;
                        if (parameter.questionToken && parameter.initializer) {
                            return grammarErrorOnNode(parameter.name, Diagnostics.Parameter_cannot_have_question_mark_and_initializer);
                        }
                    }
                    else if (seenOptionalParameter && !parameter.initializer) {
                        return grammarErrorOnNode(parameter.name, Diagnostics.A_required_parameter_cannot_follow_an_optional_parameter);
                    }
                }
            }
            function getNonSimpleParameters(parameters) {
                return filter(parameters, (parameter) => !!parameter.initializer || isBindingPattern(parameter.name) || isRestParameter(parameter));
            }
            function checkGrammarForUseStrictSimpleParameterList(node) {
                if (languageVersion >= 3 /* ES2016 */) {
                    const useStrictDirective = node.body && isBlock(node.body) && findUseStrictPrologue(node.body.statements);
                    if (useStrictDirective) {
                        const nonSimpleParameters = getNonSimpleParameters(node.parameters);
                        if (length(nonSimpleParameters)) {
                            forEach(nonSimpleParameters, (parameter) => {
                                addRelatedInfo(error(parameter, Diagnostics.This_parameter_is_not_allowed_with_use_strict_directive), createDiagnosticForNode(useStrictDirective, Diagnostics.use_strict_directive_used_here));
                            });
                            const diagnostics2 = nonSimpleParameters.map((parameter, index) => index === 0 ? createDiagnosticForNode(parameter, Diagnostics.Non_simple_parameter_declared_here) : createDiagnosticForNode(parameter, Diagnostics.and_here));
                            addRelatedInfo(error(useStrictDirective, Diagnostics.use_strict_directive_cannot_be_used_with_non_simple_parameter_list), ...diagnostics2);
                            return true;
                        }
                    }
                }
                return false;
            }
            function checkGrammarFunctionLikeDeclaration(node) {
                const file = getSourceFileOfNode(node);
                return checkGrammarModifiers(node) || checkGrammarTypeParameterList(node.typeParameters, file) || checkGrammarParameterList(node.parameters) || checkGrammarArrowFunction(node, file) || isFunctionLikeDeclaration(node) && checkGrammarForUseStrictSimpleParameterList(node);
            }
            function checkGrammarClassLikeDeclaration(node) {
                const file = getSourceFileOfNode(node);
                return checkGrammarClassDeclarationHeritageClauses(node) || checkGrammarTypeParameterList(node.typeParameters, file);
            }
            function checkGrammarArrowFunction(node, file) {
                if (!isArrowFunction(node)) {
                    return false;
                }
                if (node.typeParameters && !(length(node.typeParameters) > 1 || node.typeParameters.hasTrailingComma || node.typeParameters[0].constraint)) {
                    if (file && fileExtensionIsOneOf(file.fileName, [".mts" /* Mts */, ".cts" /* Cts */])) {
                        grammarErrorOnNode(node.typeParameters[0], Diagnostics.This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_constraint);
                    }
                }
                const { equalsGreaterThanToken } = node;
                const startLine = getLineAndCharacterOfPosition(file, equalsGreaterThanToken.pos).line;
                const endLine = getLineAndCharacterOfPosition(file, equalsGreaterThanToken.end).line;
                return startLine !== endLine && grammarErrorOnNode(equalsGreaterThanToken, Diagnostics.Line_terminator_not_permitted_before_arrow);
            }
            function checkGrammarIndexSignatureParameters(node) {
                const parameter = node.parameters[0];
                if (node.parameters.length !== 1) {
                    if (parameter) {
                        return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_must_have_exactly_one_parameter);
                    }
                    else {
                        return grammarErrorOnNode(node, Diagnostics.An_index_signature_must_have_exactly_one_parameter);
                    }
                }
                checkGrammarForDisallowedTrailingComma(node.parameters, Diagnostics.An_index_signature_cannot_have_a_trailing_comma);
                if (parameter.dotDotDotToken) {
                    return grammarErrorOnNode(parameter.dotDotDotToken, Diagnostics.An_index_signature_cannot_have_a_rest_parameter);
                }
                if (hasEffectiveModifiers(parameter)) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_cannot_have_an_accessibility_modifier);
                }
                if (parameter.questionToken) {
                    return grammarErrorOnNode(parameter.questionToken, Diagnostics.An_index_signature_parameter_cannot_have_a_question_mark);
                }
                if (parameter.initializer) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_cannot_have_an_initializer);
                }
                if (!parameter.type) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_must_have_a_type_annotation);
                }
                const type = getTypeFromTypeNode(parameter.type);
                if (someType(type, (t) => !!(t.flags & 8576 /* StringOrNumberLiteralOrUnique */)) || isGenericType(type)) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_object_type_instead);
                }
                if (!everyType(type, isValidIndexKeyType)) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type);
                }
                if (!node.type) {
                    return grammarErrorOnNode(node, Diagnostics.An_index_signature_must_have_a_type_annotation);
                }
                return false;
            }
            function checkGrammarIndexSignature(node) {
                return checkGrammarModifiers(node) || checkGrammarIndexSignatureParameters(node);
            }
            function checkGrammarForAtLeastOneTypeArgument(node, typeArguments) {
                if (typeArguments && typeArguments.length === 0) {
                    const sourceFile = getSourceFileOfNode(node);
                    const start = typeArguments.pos - "<".length;
                    const end = skipTrivia(sourceFile.text, typeArguments.end) + ">".length;
                    return grammarErrorAtPos(sourceFile, start, end - start, Diagnostics.Type_argument_list_cannot_be_empty);
                }
                return false;
            }
            function checkGrammarTypeArguments(node, typeArguments) {
                return checkGrammarForDisallowedTrailingComma(typeArguments) || checkGrammarForAtLeastOneTypeArgument(node, typeArguments);
            }
            function checkGrammarTaggedTemplateChain(node) {
                if (node.questionDotToken || node.flags & 32 /* OptionalChain */) {
                    return grammarErrorOnNode(node.template, Diagnostics.Tagged_template_expressions_are_not_permitted_in_an_optional_chain);
                }
                return false;
            }
            function checkGrammarHeritageClause(node) {
                const types = node.types;
                if (checkGrammarForDisallowedTrailingComma(types)) {
                    return true;
                }
                if (types && types.length === 0) {
                    const listType = tokenToString(node.token);
                    return grammarErrorAtPos(node, types.pos, 0, Diagnostics._0_list_cannot_be_empty, listType);
                }
                return some(types, checkGrammarExpressionWithTypeArguments);
            }
            function checkGrammarExpressionWithTypeArguments(node) {
                if (isExpressionWithTypeArguments(node) && isImportKeyword(node.expression) && node.typeArguments) {
                    return grammarErrorOnNode(node, Diagnostics.This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot_have_type_arguments);
                }
                return checkGrammarTypeArguments(node, node.typeArguments);
            }
            function checkGrammarClassDeclarationHeritageClauses(node) {
                let seenExtendsClause = false;
                let seenImplementsClause = false;
                if (!checkGrammarModifiers(node) && node.heritageClauses) {
                    for (const heritageClause of node.heritageClauses) {
                        if (heritageClause.token === 94 /* ExtendsKeyword */) {
                            if (seenExtendsClause) {
                                return grammarErrorOnFirstToken(heritageClause, Diagnostics.extends_clause_already_seen);
                            }
                            if (seenImplementsClause) {
                                return grammarErrorOnFirstToken(heritageClause, Diagnostics.extends_clause_must_precede_implements_clause);
                            }
                            if (heritageClause.types.length > 1) {
                                return grammarErrorOnFirstToken(heritageClause.types[1], Diagnostics.Classes_can_only_extend_a_single_class);
                            }
                            seenExtendsClause = true;
                        }
                        else {
                            Debug.assert(heritageClause.token === 117 /* ImplementsKeyword */);
                            if (seenImplementsClause) {
                                return grammarErrorOnFirstToken(heritageClause, Diagnostics.implements_clause_already_seen);
                            }
                            seenImplementsClause = true;
                        }
                        checkGrammarHeritageClause(heritageClause);
                    }
                }
            }
            function checkGrammarInterfaceDeclaration(node) {
                let seenExtendsClause = false;
                if (node.heritageClauses) {
                    for (const heritageClause of node.heritageClauses) {
                        if (heritageClause.token === 94 /* ExtendsKeyword */) {
                            if (seenExtendsClause) {
                                return grammarErrorOnFirstToken(heritageClause, Diagnostics.extends_clause_already_seen);
                            }
                            seenExtendsClause = true;
                        }
                        else {
                            Debug.assert(heritageClause.token === 117 /* ImplementsKeyword */);
                            return grammarErrorOnFirstToken(heritageClause, Diagnostics.Interface_declaration_cannot_have_implements_clause);
                        }
                        checkGrammarHeritageClause(heritageClause);
                    }
                }
                return false;
            }
            function checkGrammarComputedPropertyName(node) {
                if (node.kind !== 164 /* ComputedPropertyName */) {
                    return false;
                }
                const computedPropertyName = node;
                if (computedPropertyName.expression.kind === 223 /* BinaryExpression */ && computedPropertyName.expression.operatorToken.kind === 27 /* CommaToken */) {
                    return grammarErrorOnNode(computedPropertyName.expression, Diagnostics.A_comma_expression_is_not_allowed_in_a_computed_property_name);
                }
                return false;
            }
            function checkGrammarForGenerator(node) {
                if (node.asteriskToken) {
                    Debug.assert(node.kind === 259 /* FunctionDeclaration */ || node.kind === 215 /* FunctionExpression */ || node.kind === 171 /* MethodDeclaration */);
                    if (node.flags & 16777216 /* Ambient */) {
                        return grammarErrorOnNode(node.asteriskToken, Diagnostics.Generators_are_not_allowed_in_an_ambient_context);
                    }
                    if (!node.body) {
                        return grammarErrorOnNode(node.asteriskToken, Diagnostics.An_overload_signature_cannot_be_declared_as_a_generator);
                    }
                }
            }
            function checkGrammarForInvalidQuestionMark(questionToken, message) {
                return !!questionToken && grammarErrorOnNode(questionToken, message);
            }
            function checkGrammarForInvalidExclamationToken(exclamationToken, message) {
                return !!exclamationToken && grammarErrorOnNode(exclamationToken, message);
            }
            function checkGrammarObjectLiteralExpression(node, inDestructuring) {
                const seen = /* @__PURE__ */ new Map();
                for (const prop of node.properties) {
                    if (prop.kind === 301 /* SpreadAssignment */) {
                        if (inDestructuring) {
                            const expression = skipParentheses(prop.expression);
                            if (isArrayLiteralExpression(expression) || isObjectLiteralExpression(expression)) {
                                return grammarErrorOnNode(prop.expression, Diagnostics.A_rest_element_cannot_contain_a_binding_pattern);
                            }
                        }
                        continue;
                    }
                    const name = prop.name;
                    if (name.kind === 164 /* ComputedPropertyName */) {
                        checkGrammarComputedPropertyName(name);
                    }
                    if (prop.kind === 300 /* ShorthandPropertyAssignment */ && !inDestructuring && prop.objectAssignmentInitializer) {
                        grammarErrorOnNode(prop.equalsToken, Diagnostics.Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern);
                    }
                    if (name.kind === 80 /* PrivateIdentifier */) {
                        grammarErrorOnNode(name, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                    }
                    if (canHaveModifiers(prop) && prop.modifiers) {
                        for (const mod of prop.modifiers) {
                            if (isModifier(mod) && (mod.kind !== 132 /* AsyncKeyword */ || prop.kind !== 171 /* MethodDeclaration */)) {
                                grammarErrorOnNode(mod, Diagnostics._0_modifier_cannot_be_used_here, getTextOfNode(mod));
                            }
                        }
                    }
                    else if (canHaveIllegalModifiers(prop) && prop.modifiers) {
                        for (const mod of prop.modifiers) {
                            if (isModifier(mod)) {
                                grammarErrorOnNode(mod, Diagnostics._0_modifier_cannot_be_used_here, getTextOfNode(mod));
                            }
                        }
                    }
                    let currentKind;
                    switch (prop.kind) {
                        case 300 /* ShorthandPropertyAssignment */:
                        case 299 /* PropertyAssignment */:
                            checkGrammarForInvalidExclamationToken(prop.exclamationToken, Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context);
                            checkGrammarForInvalidQuestionMark(prop.questionToken, Diagnostics.An_object_member_cannot_be_declared_optional);
                            if (name.kind === 8 /* NumericLiteral */) {
                                checkGrammarNumericLiteral(name);
                            }
                            currentKind = 4 /* PropertyAssignment */;
                            break;
                        case 171 /* MethodDeclaration */:
                            currentKind = 8 /* Method */;
                            break;
                        case 174 /* GetAccessor */:
                            currentKind = 1 /* GetAccessor */;
                            break;
                        case 175 /* SetAccessor */:
                            currentKind = 2 /* SetAccessor */;
                            break;
                        default:
                            throw Debug.assertNever(prop, "Unexpected syntax kind:" + prop.kind);
                    }
                    if (!inDestructuring) {
                        const effectiveName = getPropertyNameForPropertyNameNode(name);
                        if (effectiveName === void 0) {
                            continue;
                        }
                        const existingKind = seen.get(effectiveName);
                        if (!existingKind) {
                            seen.set(effectiveName, currentKind);
                        }
                        else {
                            if (currentKind & 8 /* Method */ && existingKind & 8 /* Method */) {
                                grammarErrorOnNode(name, Diagnostics.Duplicate_identifier_0, getTextOfNode(name));
                            }
                            else if (currentKind & 4 /* PropertyAssignment */ && existingKind & 4 /* PropertyAssignment */) {
                                grammarErrorOnNode(name, Diagnostics.An_object_literal_cannot_have_multiple_properties_with_the_same_name, getTextOfNode(name));
                            }
                            else if (currentKind & 3 /* GetOrSetAccessor */ && existingKind & 3 /* GetOrSetAccessor */) {
                                if (existingKind !== 3 /* GetOrSetAccessor */ && currentKind !== existingKind) {
                                    seen.set(effectiveName, currentKind | existingKind);
                                }
                                else {
                                    return grammarErrorOnNode(name, Diagnostics.An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name);
                                }
                            }
                            else {
                                return grammarErrorOnNode(name, Diagnostics.An_object_literal_cannot_have_property_and_accessor_with_the_same_name);
                            }
                        }
                    }
                }
            }
            function checkGrammarJsxElement(node) {
                checkGrammarJsxName(node.tagName);
                checkGrammarTypeArguments(node, node.typeArguments);
                const seen = /* @__PURE__ */ new Map();
                for (const attr of node.attributes.properties) {
                    if (attr.kind === 290 /* JsxSpreadAttribute */) {
                        continue;
                    }
                    const { name, initializer } = attr;
                    if (!seen.get(name.escapedText)) {
                        seen.set(name.escapedText, true);
                    }
                    else {
                        return grammarErrorOnNode(name, Diagnostics.JSX_elements_cannot_have_multiple_attributes_with_the_same_name);
                    }
                    if (initializer && initializer.kind === 291 /* JsxExpression */ && !initializer.expression) {
                        return grammarErrorOnNode(initializer, Diagnostics.JSX_attributes_must_only_be_assigned_a_non_empty_expression);
                    }
                }
            }
            function checkGrammarJsxName(node) {
                if (isPropertyAccessExpression(node)) {
                    let propName = node;
                    do {
                        const check2 = checkGrammarJsxNestedIdentifier(propName.name);
                        if (check2) {
                            return check2;
                        }
                        propName = propName.expression;
                    } while (isPropertyAccessExpression(propName));
                    const check = checkGrammarJsxNestedIdentifier(propName);
                    if (check) {
                        return check;
                    }
                }
                function checkGrammarJsxNestedIdentifier(name) {
                    if (isIdentifier(name) && idText(name).indexOf(":") !== -1) {
                        return grammarErrorOnNode(name, Diagnostics.JSX_property_access_expressions_cannot_include_JSX_namespace_names);
                    }
                }
            }
            function checkGrammarJsxExpression(node) {
                if (node.expression && isCommaSequence(node.expression)) {
                    return grammarErrorOnNode(node.expression, Diagnostics.JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array);
                }
            }
            function checkGrammarForInOrForOfStatement(forInOrOfStatement) {
                if (checkGrammarStatementInAmbientContext(forInOrOfStatement)) {
                    return true;
                }
                if (forInOrOfStatement.kind === 247 /* ForOfStatement */ && forInOrOfStatement.awaitModifier) {
                    if (!(forInOrOfStatement.flags & 32768 /* AwaitContext */)) {
                        const sourceFile = getSourceFileOfNode(forInOrOfStatement);
                        if (isInTopLevelContext(forInOrOfStatement)) {
                            if (!hasParseDiagnostics(sourceFile)) {
                                if (!isEffectiveExternalModule(sourceFile, compilerOptions)) {
                                    diagnostics.add(createDiagnosticForNode(forInOrOfStatement.awaitModifier, Diagnostics.for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module));
                                }
                                switch (moduleKind) {
                                    case 100 /* Node16 */:
                                    case 199 /* NodeNext */:
                                        if (sourceFile.impliedNodeFormat === 1 /* CommonJS */) {
                                            diagnostics.add(createDiagnosticForNode(forInOrOfStatement.awaitModifier, Diagnostics.The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level));
                                            break;
                                        }
                                    case 7 /* ES2022 */:
                                    case 99 /* ESNext */:
                                    case 4 /* System */:
                                        if (languageVersion >= 4 /* ES2017 */) {
                                            break;
                                        }
                                    default:
                                        diagnostics.add(createDiagnosticForNode(forInOrOfStatement.awaitModifier, Diagnostics.Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_or_nodenext_and_the_target_option_is_set_to_es2017_or_higher));
                                        break;
                                }
                            }
                        }
                        else {
                            if (!hasParseDiagnostics(sourceFile)) {
                                const diagnostic = createDiagnosticForNode(forInOrOfStatement.awaitModifier, Diagnostics.for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules);
                                const func = getContainingFunction(forInOrOfStatement);
                                if (func && func.kind !== 173 /* Constructor */) {
                                    Debug.assert((getFunctionFlags(func) & 2 /* Async */) === 0, "Enclosing function should never be an async function.");
                                    const relatedInfo = createDiagnosticForNode(func, Diagnostics.Did_you_mean_to_mark_this_function_as_async);
                                    addRelatedInfo(diagnostic, relatedInfo);
                                }
                                diagnostics.add(diagnostic);
                                return true;
                            }
                        }
                        return false;
                    }
                }
                if (isForOfStatement(forInOrOfStatement) && !(forInOrOfStatement.flags & 32768 /* AwaitContext */) && isIdentifier(forInOrOfStatement.initializer) && forInOrOfStatement.initializer.escapedText === "async") {
                    grammarErrorOnNode(forInOrOfStatement.initializer, Diagnostics.The_left_hand_side_of_a_for_of_statement_may_not_be_async);
                    return false;
                }
                if (forInOrOfStatement.initializer.kind === 258 /* VariableDeclarationList */) {
                    const variableList = forInOrOfStatement.initializer;
                    if (!checkGrammarVariableDeclarationList(variableList)) {
                        const declarations = variableList.declarations;
                        if (!declarations.length) {
                            return false;
                        }
                        if (declarations.length > 1) {
                            const diagnostic = forInOrOfStatement.kind === 246 /* ForInStatement */ ? Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement : Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement;
                            return grammarErrorOnFirstToken(variableList.declarations[1], diagnostic);
                        }
                        const firstDeclaration = declarations[0];
                        if (firstDeclaration.initializer) {
                            const diagnostic = forInOrOfStatement.kind === 246 /* ForInStatement */ ? Diagnostics.The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer : Diagnostics.The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer;
                            return grammarErrorOnNode(firstDeclaration.name, diagnostic);
                        }
                        if (firstDeclaration.type) {
                            const diagnostic = forInOrOfStatement.kind === 246 /* ForInStatement */ ? Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation : Diagnostics.The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation;
                            return grammarErrorOnNode(firstDeclaration, diagnostic);
                        }
                    }
                }
                return false;
            }
            function checkGrammarAccessor(accessor) {
                if (!(accessor.flags & 16777216 /* Ambient */) && accessor.parent.kind !== 184 /* TypeLiteral */ && accessor.parent.kind !== 261 /* InterfaceDeclaration */) {
                    if (languageVersion < 1 /* ES5 */) {
                        return grammarErrorOnNode(accessor.name, Diagnostics.Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher);
                    }
                    if (languageVersion < 2 /* ES2015 */ && isPrivateIdentifier(accessor.name)) {
                        return grammarErrorOnNode(accessor.name, Diagnostics.Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher);
                    }
                    if (accessor.body === void 0 && !hasSyntacticModifier(accessor, 256 /* Abstract */)) {
                        return grammarErrorAtPos(accessor, accessor.end - 1, ";".length, Diagnostics._0_expected, "{");
                    }
                }
                if (accessor.body) {
                    if (hasSyntacticModifier(accessor, 256 /* Abstract */)) {
                        return grammarErrorOnNode(accessor, Diagnostics.An_abstract_accessor_cannot_have_an_implementation);
                    }
                    if (accessor.parent.kind === 184 /* TypeLiteral */ || accessor.parent.kind === 261 /* InterfaceDeclaration */) {
                        return grammarErrorOnNode(accessor.body, Diagnostics.An_implementation_cannot_be_declared_in_ambient_contexts);
                    }
                }
                if (accessor.typeParameters) {
                    return grammarErrorOnNode(accessor.name, Diagnostics.An_accessor_cannot_have_type_parameters);
                }
                if (!doesAccessorHaveCorrectParameterCount(accessor)) {
                    return grammarErrorOnNode(accessor.name, accessor.kind === 174 /* GetAccessor */ ? Diagnostics.A_get_accessor_cannot_have_parameters : Diagnostics.A_set_accessor_must_have_exactly_one_parameter);
                }
                if (accessor.kind === 175 /* SetAccessor */) {
                    if (accessor.type) {
                        return grammarErrorOnNode(accessor.name, Diagnostics.A_set_accessor_cannot_have_a_return_type_annotation);
                    }
                    const parameter = Debug.checkDefined(getSetAccessorValueParameter(accessor), "Return value does not match parameter count assertion.");
                    if (parameter.dotDotDotToken) {
                        return grammarErrorOnNode(parameter.dotDotDotToken, Diagnostics.A_set_accessor_cannot_have_rest_parameter);
                    }
                    if (parameter.questionToken) {
                        return grammarErrorOnNode(parameter.questionToken, Diagnostics.A_set_accessor_cannot_have_an_optional_parameter);
                    }
                    if (parameter.initializer) {
                        return grammarErrorOnNode(accessor.name, Diagnostics.A_set_accessor_parameter_cannot_have_an_initializer);
                    }
                }
                return false;
            }
            function doesAccessorHaveCorrectParameterCount(accessor) {
                return getAccessorThisParameter(accessor) || accessor.parameters.length === (accessor.kind === 174 /* GetAccessor */ ? 0 : 1);
            }
            function getAccessorThisParameter(accessor) {
                if (accessor.parameters.length === (accessor.kind === 174 /* GetAccessor */ ? 1 : 2)) {
                    return getThisParameter(accessor);
                }
            }
            function checkGrammarTypeOperatorNode(node) {
                if (node.operator === 156 /* UniqueKeyword */) {
                    if (node.type.kind !== 153 /* SymbolKeyword */) {
                        return grammarErrorOnNode(node.type, Diagnostics._0_expected, tokenToString(153 /* SymbolKeyword */));
                    }
                    let parent2 = walkUpParenthesizedTypes(node.parent);
                    if (isInJSFile(parent2) && isJSDocTypeExpression(parent2)) {
                        const host2 = getJSDocHost(parent2);
                        if (host2) {
                            parent2 = getSingleVariableOfVariableStatement(host2) || host2;
                        }
                    }
                    switch (parent2.kind) {
                        case 257 /* VariableDeclaration */:
                            const decl = parent2;
                            if (decl.name.kind !== 79 /* Identifier */) {
                                return grammarErrorOnNode(node, Diagnostics.unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name);
                            }
                            if (!isVariableDeclarationInVariableStatement(decl)) {
                                return grammarErrorOnNode(node, Diagnostics.unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement);
                            }
                            if (!(decl.parent.flags & 2 /* Const */)) {
                                return grammarErrorOnNode(parent2.name, Diagnostics.A_variable_whose_type_is_a_unique_symbol_type_must_be_const);
                            }
                            break;
                        case 169 /* PropertyDeclaration */:
                            if (!isStatic(parent2) || !hasEffectiveReadonlyModifier(parent2)) {
                                return grammarErrorOnNode(parent2.name, Diagnostics.A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly);
                            }
                            break;
                        case 168 /* PropertySignature */:
                            if (!hasSyntacticModifier(parent2, 64 /* Readonly */)) {
                                return grammarErrorOnNode(parent2.name, Diagnostics.A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly);
                            }
                            break;
                        default:
                            return grammarErrorOnNode(node, Diagnostics.unique_symbol_types_are_not_allowed_here);
                    }
                }
                else if (node.operator === 146 /* ReadonlyKeyword */) {
                    if (node.type.kind !== 185 /* ArrayType */ && node.type.kind !== 186 /* TupleType */) {
                        return grammarErrorOnFirstToken(node, Diagnostics.readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types, tokenToString(153 /* SymbolKeyword */));
                    }
                }
            }
            function checkGrammarForInvalidDynamicName(node, message) {
                if (isNonBindableDynamicName(node)) {
                    return grammarErrorOnNode(node, message);
                }
            }
            function checkGrammarMethod(node) {
                if (checkGrammarFunctionLikeDeclaration(node)) {
                    return true;
                }
                if (node.kind === 171 /* MethodDeclaration */) {
                    if (node.parent.kind === 207 /* ObjectLiteralExpression */) {
                        if (node.modifiers && !(node.modifiers.length === 1 && first(node.modifiers).kind === 132 /* AsyncKeyword */)) {
                            return grammarErrorOnFirstToken(node, Diagnostics.Modifiers_cannot_appear_here);
                        }
                        else if (checkGrammarForInvalidQuestionMark(node.questionToken, Diagnostics.An_object_member_cannot_be_declared_optional)) {
                            return true;
                        }
                        else if (checkGrammarForInvalidExclamationToken(node.exclamationToken, Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context)) {
                            return true;
                        }
                        else if (node.body === void 0) {
                            return grammarErrorAtPos(node, node.end - 1, ";".length, Diagnostics._0_expected, "{");
                        }
                    }
                    if (checkGrammarForGenerator(node)) {
                        return true;
                    }
                }
                if (isClassLike(node.parent)) {
                    if (languageVersion < 2 /* ES2015 */ && isPrivateIdentifier(node.name)) {
                        return grammarErrorOnNode(node.name, Diagnostics.Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher);
                    }
                    if (node.flags & 16777216 /* Ambient */) {
                        return checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);
                    }
                    else if (node.kind === 171 /* MethodDeclaration */ && !node.body) {
                        return checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);
                    }
                }
                else if (node.parent.kind === 261 /* InterfaceDeclaration */) {
                    return checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);
                }
                else if (node.parent.kind === 184 /* TypeLiteral */) {
                    return checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);
                }
            }
            function checkGrammarBreakOrContinueStatement(node) {
                let current = node;
                while (current) {
                    if (isFunctionLikeOrClassStaticBlockDeclaration(current)) {
                        return grammarErrorOnNode(node, Diagnostics.Jump_target_cannot_cross_function_boundary);
                    }
                    switch (current.kind) {
                        case 253 /* LabeledStatement */:
                            if (node.label && current.label.escapedText === node.label.escapedText) {
                                const isMisplacedContinueLabel = node.kind === 248 /* ContinueStatement */ && !isIterationStatement(current.statement, 
                                /*lookInLabeledStatement*/
                                true);
                                if (isMisplacedContinueLabel) {
                                    return grammarErrorOnNode(node, Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement);
                                }
                                return false;
                            }
                            break;
                        case 252 /* SwitchStatement */:
                            if (node.kind === 249 /* BreakStatement */ && !node.label) {
                                return false;
                            }
                            break;
                        default:
                            if (isIterationStatement(current, 
                            /*lookInLabeledStatement*/
                            false) && !node.label) {
                                return false;
                            }
                            break;
                    }
                    current = current.parent;
                }
                if (node.label) {
                    const message = node.kind === 249 /* BreakStatement */ ? Diagnostics.A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement : Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement;
                    return grammarErrorOnNode(node, message);
                }
                else {
                    const message = node.kind === 249 /* BreakStatement */ ? Diagnostics.A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement : Diagnostics.A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement;
                    return grammarErrorOnNode(node, message);
                }
            }
            function checkGrammarBindingElement(node) {
                if (node.dotDotDotToken) {
                    const elements = node.parent.elements;
                    if (node !== last(elements)) {
                        return grammarErrorOnNode(node, Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern);
                    }
                    checkGrammarForDisallowedTrailingComma(elements, Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma);
                    if (node.propertyName) {
                        return grammarErrorOnNode(node.name, Diagnostics.A_rest_element_cannot_have_a_property_name);
                    }
                }
                if (node.dotDotDotToken && node.initializer) {
                    return grammarErrorAtPos(node, node.initializer.pos - 1, 1, Diagnostics.A_rest_element_cannot_have_an_initializer);
                }
            }
            function isStringOrNumberLiteralExpression(expr) {
                return isStringOrNumericLiteralLike(expr) || expr.kind === 221 /* PrefixUnaryExpression */ && expr.operator === 40 /* MinusToken */ && expr.operand.kind === 8 /* NumericLiteral */;
            }
            function isBigIntLiteralExpression(expr) {
                return expr.kind === 9 /* BigIntLiteral */ || expr.kind === 221 /* PrefixUnaryExpression */ && expr.operator === 40 /* MinusToken */ && expr.operand.kind === 9 /* BigIntLiteral */;
            }
            function isSimpleLiteralEnumReference(expr) {
                if ((isPropertyAccessExpression(expr) || isElementAccessExpression(expr) && isStringOrNumberLiteralExpression(expr.argumentExpression)) && isEntityNameExpression(expr.expression)) {
                    return !!(checkExpressionCached(expr).flags & 1056 /* EnumLike */);
                }
            }
            function checkAmbientInitializer(node) {
                const initializer = node.initializer;
                if (initializer) {
                    const isInvalidInitializer = !(isStringOrNumberLiteralExpression(initializer) || isSimpleLiteralEnumReference(initializer) || initializer.kind === 110 /* TrueKeyword */ || initializer.kind === 95 /* FalseKeyword */ || isBigIntLiteralExpression(initializer));
                    const isConstOrReadonly = isDeclarationReadonly(node) || isVariableDeclaration(node) && isVarConst(node);
                    if (isConstOrReadonly && !node.type) {
                        if (isInvalidInitializer) {
                            return grammarErrorOnNode(initializer, Diagnostics.A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_reference);
                        }
                    }
                    else {
                        return grammarErrorOnNode(initializer, Diagnostics.Initializers_are_not_allowed_in_ambient_contexts);
                    }
                }
            }
            function checkGrammarVariableDeclaration(node) {
                if (node.parent.parent.kind !== 246 /* ForInStatement */ && node.parent.parent.kind !== 247 /* ForOfStatement */) {
                    if (node.flags & 16777216 /* Ambient */) {
                        checkAmbientInitializer(node);
                    }
                    else if (!node.initializer) {
                        if (isBindingPattern(node.name) && !isBindingPattern(node.parent)) {
                            return grammarErrorOnNode(node, Diagnostics.A_destructuring_declaration_must_have_an_initializer);
                        }
                        if (isVarConst(node)) {
                            return grammarErrorOnNode(node, Diagnostics.const_declarations_must_be_initialized);
                        }
                    }
                }
                if (node.exclamationToken && (node.parent.parent.kind !== 240 /* VariableStatement */ || !node.type || node.initializer || node.flags & 16777216 /* Ambient */)) {
                    const message = node.initializer ? Diagnostics.Declarations_with_initializers_cannot_also_have_definite_assignment_assertions : !node.type ? Diagnostics.Declarations_with_definite_assignment_assertions_must_also_have_type_annotations : Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context;
                    return grammarErrorOnNode(node.exclamationToken, message);
                }
                if ((moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */) && moduleKind !== 4 /* System */ && !(node.parent.parent.flags & 16777216 /* Ambient */) && hasSyntacticModifier(node.parent.parent, 1 /* Export */)) {
                    checkESModuleMarker(node.name);
                }
                const checkLetConstNames = isLet(node) || isVarConst(node);
                return checkLetConstNames && checkGrammarNameInLetOrConstDeclarations(node.name);
            }
            function checkESModuleMarker(name) {
                if (name.kind === 79 /* Identifier */) {
                    if (idText(name) === "__esModule") {
                        return grammarErrorOnNodeSkippedOn("noEmit", name, Diagnostics.Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules);
                    }
                }
                else {
                    const elements = name.elements;
                    for (const element of elements) {
                        if (!isOmittedExpression(element)) {
                            return checkESModuleMarker(element.name);
                        }
                    }
                }
                return false;
            }
            function checkGrammarNameInLetOrConstDeclarations(name) {
                if (name.kind === 79 /* Identifier */) {
                    if (name.escapedText === "let") {
                        return grammarErrorOnNode(name, Diagnostics.let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations);
                    }
                }
                else {
                    const elements = name.elements;
                    for (const element of elements) {
                        if (!isOmittedExpression(element)) {
                            checkGrammarNameInLetOrConstDeclarations(element.name);
                        }
                    }
                }
                return false;
            }
            function checkGrammarVariableDeclarationList(declarationList) {
                const declarations = declarationList.declarations;
                if (checkGrammarForDisallowedTrailingComma(declarationList.declarations)) {
                    return true;
                }
                if (!declarationList.declarations.length) {
                    return grammarErrorAtPos(declarationList, declarations.pos, declarations.end - declarations.pos, Diagnostics.Variable_declaration_list_cannot_be_empty);
                }
                return false;
            }
            function allowLetAndConstDeclarations(parent2) {
                switch (parent2.kind) {
                    case 242 /* IfStatement */:
                    case 243 /* DoStatement */:
                    case 244 /* WhileStatement */:
                    case 251 /* WithStatement */:
                    case 245 /* ForStatement */:
                    case 246 /* ForInStatement */:
                    case 247 /* ForOfStatement */:
                        return false;
                    case 253 /* LabeledStatement */:
                        return allowLetAndConstDeclarations(parent2.parent);
                }
                return true;
            }
            function checkGrammarForDisallowedLetOrConstStatement(node) {
                if (!allowLetAndConstDeclarations(node.parent)) {
                    if (isLet(node.declarationList)) {
                        return grammarErrorOnNode(node, Diagnostics.let_declarations_can_only_be_declared_inside_a_block);
                    }
                    else if (isVarConst(node.declarationList)) {
                        return grammarErrorOnNode(node, Diagnostics.const_declarations_can_only_be_declared_inside_a_block);
                    }
                }
            }
            function checkGrammarMetaProperty(node) {
                const escapedText = node.name.escapedText;
                switch (node.keywordToken) {
                    case 103 /* NewKeyword */:
                        if (escapedText !== "target") {
                            return grammarErrorOnNode(node.name, Diagnostics._0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2, node.name.escapedText, tokenToString(node.keywordToken), "target");
                        }
                        break;
                    case 100 /* ImportKeyword */:
                        if (escapedText !== "meta") {
                            return grammarErrorOnNode(node.name, Diagnostics._0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2, node.name.escapedText, tokenToString(node.keywordToken), "meta");
                        }
                        break;
                }
            }
            function hasParseDiagnostics(sourceFile) {
                return sourceFile.parseDiagnostics.length > 0;
            }
            function grammarErrorOnFirstToken(node, message, arg0, arg1, arg2) {
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    const span = getSpanOfTokenAtPosition(sourceFile, node.pos);
                    diagnostics.add(createFileDiagnostic(sourceFile, span.start, span.length, message, arg0, arg1, arg2));
                    return true;
                }
                return false;
            }
            function grammarErrorAtPos(nodeForSourceFile, start, length2, message, arg0, arg1, arg2) {
                const sourceFile = getSourceFileOfNode(nodeForSourceFile);
                if (!hasParseDiagnostics(sourceFile)) {
                    diagnostics.add(createFileDiagnostic(sourceFile, start, length2, message, arg0, arg1, arg2));
                    return true;
                }
                return false;
            }
            function grammarErrorOnNodeSkippedOn(key, node, message, arg0, arg1, arg2) {
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    errorSkippedOn(key, node, message, arg0, arg1, arg2);
                    return true;
                }
                return false;
            }
            function grammarErrorOnNode(node, message, arg0, arg1, arg2) {
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    diagnostics.add(createDiagnosticForNode(node, message, arg0, arg1, arg2));
                    return true;
                }
                return false;
            }
            function checkGrammarConstructorTypeParameters(node) {
                const jsdocTypeParameters = isInJSFile(node) ? getJSDocTypeParameterDeclarations(node) : void 0;
                const range = node.typeParameters || jsdocTypeParameters && firstOrUndefined(jsdocTypeParameters);
                if (range) {
                    const pos = range.pos === range.end ? range.pos : skipTrivia(getSourceFileOfNode(node).text, range.pos);
                    return grammarErrorAtPos(node, pos, range.end - pos, Diagnostics.Type_parameters_cannot_appear_on_a_constructor_declaration);
                }
            }
            function checkGrammarConstructorTypeAnnotation(node) {
                const type = node.type || getEffectiveReturnTypeNode(node);
                if (type) {
                    return grammarErrorOnNode(type, Diagnostics.Type_annotation_cannot_appear_on_a_constructor_declaration);
                }
            }
            function checkGrammarProperty(node) {
                if (isComputedPropertyName(node.name) && isBinaryExpression(node.name.expression) && node.name.expression.operatorToken.kind === 101 /* InKeyword */) {
                    return grammarErrorOnNode(node.parent.members[0], Diagnostics.A_mapped_type_may_not_declare_properties_or_methods);
                }
                if (isClassLike(node.parent)) {
                    if (isStringLiteral(node.name) && node.name.text === "constructor") {
                        return grammarErrorOnNode(node.name, Diagnostics.Classes_may_not_have_a_field_named_constructor);
                    }
                    if (checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_symbol_type)) {
                        return true;
                    }
                    if (languageVersion < 2 /* ES2015 */ && isPrivateIdentifier(node.name)) {
                        return grammarErrorOnNode(node.name, Diagnostics.Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher);
                    }
                    if (languageVersion < 2 /* ES2015 */ && isAutoAccessorPropertyDeclaration(node)) {
                        return grammarErrorOnNode(node.name, Diagnostics.Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher);
                    }
                    if (isAutoAccessorPropertyDeclaration(node) && checkGrammarForInvalidQuestionMark(node.questionToken, Diagnostics.An_accessor_property_cannot_be_declared_optional)) {
                        return true;
                    }
                }
                else if (node.parent.kind === 261 /* InterfaceDeclaration */) {
                    if (checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type)) {
                        return true;
                    }
                    Debug.assertNode(node, isPropertySignature);
                    if (node.initializer) {
                        return grammarErrorOnNode(node.initializer, Diagnostics.An_interface_property_cannot_have_an_initializer);
                    }
                }
                else if (isTypeLiteralNode(node.parent)) {
                    if (checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type)) {
                        return true;
                    }
                    Debug.assertNode(node, isPropertySignature);
                    if (node.initializer) {
                        return grammarErrorOnNode(node.initializer, Diagnostics.A_type_literal_property_cannot_have_an_initializer);
                    }
                }
                if (node.flags & 16777216 /* Ambient */) {
                    checkAmbientInitializer(node);
                }
                if (isPropertyDeclaration(node) && node.exclamationToken && (!isClassLike(node.parent) || !node.type || node.initializer || node.flags & 16777216 /* Ambient */ || isStatic(node) || hasAbstractModifier(node))) {
                    const message = node.initializer ? Diagnostics.Declarations_with_initializers_cannot_also_have_definite_assignment_assertions : !node.type ? Diagnostics.Declarations_with_definite_assignment_assertions_must_also_have_type_annotations : Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context;
                    return grammarErrorOnNode(node.exclamationToken, message);
                }
            }
            function checkGrammarTopLevelElementForRequiredDeclareModifier(node) {
                if (node.kind === 261 /* InterfaceDeclaration */ || node.kind === 262 /* TypeAliasDeclaration */ || node.kind === 269 /* ImportDeclaration */ || node.kind === 268 /* ImportEqualsDeclaration */ || node.kind === 275 /* ExportDeclaration */ || node.kind === 274 /* ExportAssignment */ || node.kind === 267 /* NamespaceExportDeclaration */ || hasSyntacticModifier(node, 2 /* Ambient */ | 1 /* Export */ | 1024 /* Default */)) {
                    return false;
                }
                return grammarErrorOnFirstToken(node, Diagnostics.Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier);
            }
            function checkGrammarTopLevelElementsForRequiredDeclareModifier(file) {
                for (const decl of file.statements) {
                    if (isDeclaration(decl) || decl.kind === 240 /* VariableStatement */) {
                        if (checkGrammarTopLevelElementForRequiredDeclareModifier(decl)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function checkGrammarSourceFile(node) {
                return !!(node.flags & 16777216 /* Ambient */) && checkGrammarTopLevelElementsForRequiredDeclareModifier(node);
            }
            function checkGrammarStatementInAmbientContext(node) {
                if (node.flags & 16777216 /* Ambient */) {
                    const links = getNodeLinks(node);
                    if (!links.hasReportedStatementInAmbientContext && (isFunctionLike(node.parent) || isAccessor(node.parent))) {
                        return getNodeLinks(node).hasReportedStatementInAmbientContext = grammarErrorOnFirstToken(node, Diagnostics.An_implementation_cannot_be_declared_in_ambient_contexts);
                    }
                    if (node.parent.kind === 238 /* Block */ || node.parent.kind === 265 /* ModuleBlock */ || node.parent.kind === 308 /* SourceFile */) {
                        const links2 = getNodeLinks(node.parent);
                        if (!links2.hasReportedStatementInAmbientContext) {
                            return links2.hasReportedStatementInAmbientContext = grammarErrorOnFirstToken(node, Diagnostics.Statements_are_not_allowed_in_ambient_contexts);
                        }
                    }
                    else {
                    }
                }
                return false;
            }
            function checkGrammarNumericLiteral(node) {
                if (node.numericLiteralFlags & 32 /* Octal */) {
                    let diagnosticMessage;
                    if (languageVersion >= 1 /* ES5 */) {
                        diagnosticMessage = Diagnostics.Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher_Use_the_syntax_0;
                    }
                    else if (isChildOfNodeWithKind(node, 198 /* LiteralType */)) {
                        diagnosticMessage = Diagnostics.Octal_literal_types_must_use_ES2015_syntax_Use_the_syntax_0;
                    }
                    else if (isChildOfNodeWithKind(node, 302 /* EnumMember */)) {
                        diagnosticMessage = Diagnostics.Octal_literals_are_not_allowed_in_enums_members_initializer_Use_the_syntax_0;
                    }
                    if (diagnosticMessage) {
                        const withMinus = isPrefixUnaryExpression(node.parent) && node.parent.operator === 40 /* MinusToken */;
                        const literal = (withMinus ? "-" : "") + "0o" + node.text;
                        return grammarErrorOnNode(withMinus ? node.parent : node, diagnosticMessage, literal);
                    }
                }
                checkNumericLiteralValueSize(node);
                return false;
            }
            function checkNumericLiteralValueSize(node) {
                const isFractional = getTextOfNode(node).indexOf(".") !== -1;
                const isScientific = node.numericLiteralFlags & 16 /* Scientific */;
                if (isFractional || isScientific) {
                    return;
                }
                const value = +node.text;
                if (value <= 2 ** 53 - 1) {
                    return;
                }
                addErrorOrSuggestion(
                /*isError*/
                false, createDiagnosticForNode(node, Diagnostics.Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers));
            }
            function checkGrammarBigIntLiteral(node) {
                const literalType = isLiteralTypeNode(node.parent) || isPrefixUnaryExpression(node.parent) && isLiteralTypeNode(node.parent.parent);
                if (!literalType) {
                    if (languageVersion < 7 /* ES2020 */) {
                        if (grammarErrorOnNode(node, Diagnostics.BigInt_literals_are_not_available_when_targeting_lower_than_ES2020)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function grammarErrorAfterFirstToken(node, message, arg0, arg1, arg2) {
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    const span = getSpanOfTokenAtPosition(sourceFile, node.pos);
                    diagnostics.add(createFileDiagnostic(sourceFile, textSpanEnd(span), 
                    /*length*/
                    0, message, arg0, arg1, arg2));
                    return true;
                }
                return false;
            }
            function getAmbientModules() {
                if (!ambientModulesCache) {
                    ambientModulesCache = [];
                    globals.forEach((global2, sym) => {
                        if (ambientModuleSymbolRegex.test(sym)) {
                            ambientModulesCache.push(global2);
                        }
                    });
                }
                return ambientModulesCache;
            }
            function checkGrammarImportClause(node) {
                var _a2;
                if (node.isTypeOnly && node.name && node.namedBindings) {
                    return grammarErrorOnNode(node, Diagnostics.A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both);
                }
                if (node.isTypeOnly && ((_a2 = node.namedBindings) == null ? void 0 : _a2.kind) === 272 /* NamedImports */) {
                    return checkGrammarNamedImportsOrExports(node.namedBindings);
                }
                return false;
            }
            function checkGrammarNamedImportsOrExports(namedBindings) {
                return !!forEach(namedBindings.elements, (specifier) => {
                    if (specifier.isTypeOnly) {
                        return grammarErrorOnFirstToken(specifier, specifier.kind === 273 /* ImportSpecifier */ ? Diagnostics.The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement : Diagnostics.The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement);
                    }
                });
            }
            function checkGrammarImportCallExpression(node) {
                if (compilerOptions.verbatimModuleSyntax && moduleKind === 1 /* CommonJS */) {
                    return grammarErrorOnNode(node, Diagnostics.ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                }
                if (moduleKind === 5 /* ES2015 */) {
                    return grammarErrorOnNode(node, Diagnostics.Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd_system_umd_node16_or_nodenext);
                }
                if (node.typeArguments) {
                    return grammarErrorOnNode(node, Diagnostics.This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot_have_type_arguments);
                }
                const nodeArguments = node.arguments;
                if (moduleKind !== 99 /* ESNext */ && moduleKind !== 199 /* NodeNext */ && moduleKind !== 100 /* Node16 */) {
                    checkGrammarForDisallowedTrailingComma(nodeArguments);
                    if (nodeArguments.length > 1) {
                        const assertionArgument = nodeArguments[1];
                        return grammarErrorOnNode(assertionArgument, Diagnostics.Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_or_nodenext);
                    }
                }
                if (nodeArguments.length === 0 || nodeArguments.length > 2) {
                    return grammarErrorOnNode(node, Diagnostics.Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_assertion_as_arguments);
                }
                const spreadElement = find(nodeArguments, isSpreadElement);
                if (spreadElement) {
                    return grammarErrorOnNode(spreadElement, Diagnostics.Argument_of_dynamic_import_cannot_be_spread_element);
                }
                return false;
            }
            function findMatchingTypeReferenceOrTypeAliasReference(source, unionTarget) {
                const sourceObjectFlags = getObjectFlags(source);
                if (sourceObjectFlags & (4 /* Reference */ | 16 /* Anonymous */) && unionTarget.flags & 1048576 /* Union */) {
                    return find(unionTarget.types, (target) => {
                        if (target.flags & 524288 /* Object */) {
                            const overlapObjFlags = sourceObjectFlags & getObjectFlags(target);
                            if (overlapObjFlags & 4 /* Reference */) {
                                return source.target === target.target;
                            }
                            if (overlapObjFlags & 16 /* Anonymous */) {
                                return !!source.aliasSymbol && source.aliasSymbol === target.aliasSymbol;
                            }
                        }
                        return false;
                    });
                }
            }
            function findBestTypeForObjectLiteral(source, unionTarget) {
                if (getObjectFlags(source) & 128 /* ObjectLiteral */ && someType(unionTarget, isArrayLikeType)) {
                    return find(unionTarget.types, (t) => !isArrayLikeType(t));
                }
            }
            function findBestTypeForInvokable(source, unionTarget) {
                let signatureKind = 0 /* Call */;
                const hasSignatures = getSignaturesOfType(source, signatureKind).length > 0 || (signatureKind = 1 /* Construct */, getSignaturesOfType(source, signatureKind).length > 0);
                if (hasSignatures) {
                    return find(unionTarget.types, (t) => getSignaturesOfType(t, signatureKind).length > 0);
                }
            }
            function findMostOverlappyType(source, unionTarget) {
                let bestMatch;
                if (!(source.flags & (134348796 /* Primitive */ | 406847488 /* InstantiablePrimitive */))) {
                    let matchingCount = 0;
                    for (const target of unionTarget.types) {
                        if (!(target.flags & (134348796 /* Primitive */ | 406847488 /* InstantiablePrimitive */))) {
                            const overlap = getIntersectionType([getIndexType(source), getIndexType(target)]);
                            if (overlap.flags & 4194304 /* Index */) {
                                return target;
                            }
                            else if (isUnitType(overlap) || overlap.flags & 1048576 /* Union */) {
                                const len = overlap.flags & 1048576 /* Union */ ? countWhere(overlap.types, isUnitType) : 1;
                                if (len >= matchingCount) {
                                    bestMatch = target;
                                    matchingCount = len;
                                }
                            }
                        }
                    }
                }
                return bestMatch;
            }
            function filterPrimitivesIfContainsNonPrimitive(type) {
                if (maybeTypeOfKind(type, 67108864 /* NonPrimitive */)) {
                    const result = filterType(type, (t) => !(t.flags & 134348796 /* Primitive */));
                    if (!(result.flags & 131072 /* Never */)) {
                        return result;
                    }
                }
                return type;
            }
            function findMatchingDiscriminantType(source, target, isRelatedTo, skipPartial) {
                if (target.flags & 1048576 /* Union */ && source.flags & (2097152 /* Intersection */ | 524288 /* Object */)) {
                    const match = getMatchingUnionConstituentForType(target, source);
                    if (match) {
                        return match;
                    }
                    const sourceProperties = getPropertiesOfType(source);
                    if (sourceProperties) {
                        const sourcePropertiesFiltered = findDiscriminantProperties(sourceProperties, target);
                        if (sourcePropertiesFiltered) {
                            return discriminateTypeByDiscriminableItems(target, map(sourcePropertiesFiltered, (p) => [() => getTypeOfSymbol(p), p.escapedName]), isRelatedTo, 
                            /*defaultValue*/
                            void 0, skipPartial);
                        }
                    }
                }
                return void 0;
            }
        }
        function isNotAccessor(declaration) {
            return !isAccessor(declaration);
        }
        function isNotOverload(declaration) {
            return declaration.kind !== 259 /* FunctionDeclaration */ && declaration.kind !== 171 /* MethodDeclaration */ || !!declaration.body;
        }
        function isDeclarationNameOrImportPropertyName(name) {
            switch (name.parent.kind) {
                case 273 /* ImportSpecifier */:
                case 278 /* ExportSpecifier */:
                    return isIdentifier(name);
                default:
                    return isDeclarationName(name);
            }
        }
        function getIterationTypesKeyFromIterationTypeKind(typeKind) {
            switch (typeKind) {
                case 0 /* Yield */:
                    return "yieldType";
                case 1 /* Return */:
                    return "returnType";
                case 2 /* Next */:
                    return "nextType";
            }
        }
        function signatureHasRestParameter(s) {
            return !!(s.flags & 1 /* HasRestParameter */);
        }
        function signatureHasLiteralTypes(s) {
            return !!(s.flags & 2 /* HasLiteralTypes */);
        }
        function createBasicNodeBuilderModuleSpecifierResolutionHost(host) {
            return {
                getCommonSourceDirectory: !!host.getCommonSourceDirectory ? () => host.getCommonSourceDirectory() : () => "",
                getCurrentDirectory: () => host.getCurrentDirectory(),
                getSymlinkCache: maybeBind(host, host.getSymlinkCache),
                getPackageJsonInfoCache: () => {
                    var _a2;
                    return (_a2 = host.getPackageJsonInfoCache) == null ? void 0 : _a2.call(host);
                },
                useCaseSensitiveFileNames: maybeBind(host, host.useCaseSensitiveFileNames),
                redirectTargetsMap: host.redirectTargetsMap,
                getProjectReferenceRedirect: (fileName) => host.getProjectReferenceRedirect(fileName),
                isSourceOfProjectReferenceRedirect: (fileName) => host.isSourceOfProjectReferenceRedirect(fileName),
                fileExists: (fileName) => host.fileExists(fileName),
                getFileIncludeReasons: () => host.getFileIncludeReasons(),
                readFile: host.readFile ? (fileName) => host.readFile(fileName) : void 0
            };
        }
        var ambientModuleSymbolRegex, anon, nextSymbolId, nextNodeId, nextMergeId, nextFlowId, TypeFacts, typeofNEFacts, CheckMode, SignatureCheckMode, isNotOverloadAndNotAccessor, intrinsicTypeKinds, SymbolLinks, JsxNames, SymbolTrackerImpl;
        var init_checker = __esm({
            "src/compiler/checker.ts"() {
                "use strict";
                init_ts2();
                init_ts_moduleSpecifiers();
                init_ts_performance();
                ambientModuleSymbolRegex = /^".+"$/;
                anon = "(anonymous)";
                nextSymbolId = 1;
                nextNodeId = 1;
                nextMergeId = 1;
                nextFlowId = 1;
                TypeFacts = /* @__PURE__ */ ((TypeFacts3) => {
                    TypeFacts3[TypeFacts3["None"] = 0] = "None";
                    TypeFacts3[TypeFacts3["TypeofEQString"] = 1] = "TypeofEQString";
                    TypeFacts3[TypeFacts3["TypeofEQNumber"] = 2] = "TypeofEQNumber";
                    TypeFacts3[TypeFacts3["TypeofEQBigInt"] = 4] = "TypeofEQBigInt";
                    TypeFacts3[TypeFacts3["TypeofEQBoolean"] = 8] = "TypeofEQBoolean";
                    TypeFacts3[TypeFacts3["TypeofEQSymbol"] = 16] = "TypeofEQSymbol";
                    TypeFacts3[TypeFacts3["TypeofEQObject"] = 32] = "TypeofEQObject";
                    TypeFacts3[TypeFacts3["TypeofEQFunction"] = 64] = "TypeofEQFunction";
                    TypeFacts3[TypeFacts3["TypeofEQHostObject"] = 128] = "TypeofEQHostObject";
                    TypeFacts3[TypeFacts3["TypeofNEString"] = 256] = "TypeofNEString";
                    TypeFacts3[TypeFacts3["TypeofNENumber"] = 512] = "TypeofNENumber";
                    TypeFacts3[TypeFacts3["TypeofNEBigInt"] = 1024] = "TypeofNEBigInt";
                    TypeFacts3[TypeFacts3["TypeofNEBoolean"] = 2048] = "TypeofNEBoolean";
                    TypeFacts3[TypeFacts3["TypeofNESymbol"] = 4096] = "TypeofNESymbol";
                    TypeFacts3[TypeFacts3["TypeofNEObject"] = 8192] = "TypeofNEObject";
                    TypeFacts3[TypeFacts3["TypeofNEFunction"] = 16384] = "TypeofNEFunction";
                    TypeFacts3[TypeFacts3["TypeofNEHostObject"] = 32768] = "TypeofNEHostObject";
                    TypeFacts3[TypeFacts3["EQUndefined"] = 65536] = "EQUndefined";
                    TypeFacts3[TypeFacts3["EQNull"] = 131072] = "EQNull";
                    TypeFacts3[TypeFacts3["EQUndefinedOrNull"] = 262144] = "EQUndefinedOrNull";
                    TypeFacts3[TypeFacts3["NEUndefined"] = 524288] = "NEUndefined";
                    TypeFacts3[TypeFacts3["NENull"] = 1048576] = "NENull";
                    TypeFacts3[TypeFacts3["NEUndefinedOrNull"] = 2097152] = "NEUndefinedOrNull";
                    TypeFacts3[TypeFacts3["Truthy"] = 4194304] = "Truthy";
                    TypeFacts3[TypeFacts3["Falsy"] = 8388608] = "Falsy";
                    TypeFacts3[TypeFacts3["IsUndefined"] = 16777216] = "IsUndefined";
                    TypeFacts3[TypeFacts3["IsNull"] = 33554432] = "IsNull";
                    TypeFacts3[TypeFacts3["IsUndefinedOrNull"] = 50331648] = "IsUndefinedOrNull";
                    TypeFacts3[TypeFacts3["All"] = 134217727] = "All";
                    TypeFacts3[TypeFacts3["BaseStringStrictFacts"] = 3735041] = "BaseStringStrictFacts";
                    TypeFacts3[TypeFacts3["BaseStringFacts"] = 12582401] = "BaseStringFacts";
                    TypeFacts3[TypeFacts3["StringStrictFacts"] = 16317953] = "StringStrictFacts";
                    TypeFacts3[TypeFacts3["StringFacts"] = 16776705] = "StringFacts";
                    TypeFacts3[TypeFacts3["EmptyStringStrictFacts"] = 12123649] = "EmptyStringStrictFacts";
                    TypeFacts3[TypeFacts3["EmptyStringFacts"] = 12582401 /* BaseStringFacts */] = "EmptyStringFacts";
                    TypeFacts3[TypeFacts3["NonEmptyStringStrictFacts"] = 7929345] = "NonEmptyStringStrictFacts";
                    TypeFacts3[TypeFacts3["NonEmptyStringFacts"] = 16776705] = "NonEmptyStringFacts";
                    TypeFacts3[TypeFacts3["BaseNumberStrictFacts"] = 3734786] = "BaseNumberStrictFacts";
                    TypeFacts3[TypeFacts3["BaseNumberFacts"] = 12582146] = "BaseNumberFacts";
                    TypeFacts3[TypeFacts3["NumberStrictFacts"] = 16317698] = "NumberStrictFacts";
                    TypeFacts3[TypeFacts3["NumberFacts"] = 16776450] = "NumberFacts";
                    TypeFacts3[TypeFacts3["ZeroNumberStrictFacts"] = 12123394] = "ZeroNumberStrictFacts";
                    TypeFacts3[TypeFacts3["ZeroNumberFacts"] = 12582146 /* BaseNumberFacts */] = "ZeroNumberFacts";
                    TypeFacts3[TypeFacts3["NonZeroNumberStrictFacts"] = 7929090] = "NonZeroNumberStrictFacts";
                    TypeFacts3[TypeFacts3["NonZeroNumberFacts"] = 16776450] = "NonZeroNumberFacts";
                    TypeFacts3[TypeFacts3["BaseBigIntStrictFacts"] = 3734276] = "BaseBigIntStrictFacts";
                    TypeFacts3[TypeFacts3["BaseBigIntFacts"] = 12581636] = "BaseBigIntFacts";
                    TypeFacts3[TypeFacts3["BigIntStrictFacts"] = 16317188] = "BigIntStrictFacts";
                    TypeFacts3[TypeFacts3["BigIntFacts"] = 16775940] = "BigIntFacts";
                    TypeFacts3[TypeFacts3["ZeroBigIntStrictFacts"] = 12122884] = "ZeroBigIntStrictFacts";
                    TypeFacts3[TypeFacts3["ZeroBigIntFacts"] = 12581636 /* BaseBigIntFacts */] = "ZeroBigIntFacts";
                    TypeFacts3[TypeFacts3["NonZeroBigIntStrictFacts"] = 7928580] = "NonZeroBigIntStrictFacts";
                    TypeFacts3[TypeFacts3["NonZeroBigIntFacts"] = 16775940] = "NonZeroBigIntFacts";
                    TypeFacts3[TypeFacts3["BaseBooleanStrictFacts"] = 3733256] = "BaseBooleanStrictFacts";
                    TypeFacts3[TypeFacts3["BaseBooleanFacts"] = 12580616] = "BaseBooleanFacts";
                    TypeFacts3[TypeFacts3["BooleanStrictFacts"] = 16316168] = "BooleanStrictFacts";
                    TypeFacts3[TypeFacts3["BooleanFacts"] = 16774920] = "BooleanFacts";
                    TypeFacts3[TypeFacts3["FalseStrictFacts"] = 12121864] = "FalseStrictFacts";
                    TypeFacts3[TypeFacts3["FalseFacts"] = 12580616 /* BaseBooleanFacts */] = "FalseFacts";
                    TypeFacts3[TypeFacts3["TrueStrictFacts"] = 7927560] = "TrueStrictFacts";
                    TypeFacts3[TypeFacts3["TrueFacts"] = 16774920] = "TrueFacts";
                    TypeFacts3[TypeFacts3["SymbolStrictFacts"] = 7925520] = "SymbolStrictFacts";
                    TypeFacts3[TypeFacts3["SymbolFacts"] = 16772880] = "SymbolFacts";
                    TypeFacts3[TypeFacts3["ObjectStrictFacts"] = 7888800] = "ObjectStrictFacts";
                    TypeFacts3[TypeFacts3["ObjectFacts"] = 16736160] = "ObjectFacts";
                    TypeFacts3[TypeFacts3["FunctionStrictFacts"] = 7880640] = "FunctionStrictFacts";
                    TypeFacts3[TypeFacts3["FunctionFacts"] = 16728e3] = "FunctionFacts";
                    TypeFacts3[TypeFacts3["VoidFacts"] = 9830144] = "VoidFacts";
                    TypeFacts3[TypeFacts3["UndefinedFacts"] = 26607360] = "UndefinedFacts";
                    TypeFacts3[TypeFacts3["NullFacts"] = 42917664] = "NullFacts";
                    TypeFacts3[TypeFacts3["EmptyObjectStrictFacts"] = 83427327] = "EmptyObjectStrictFacts";
                    TypeFacts3[TypeFacts3["EmptyObjectFacts"] = 83886079] = "EmptyObjectFacts";
                    TypeFacts3[TypeFacts3["UnknownFacts"] = 83886079] = "UnknownFacts";
                    TypeFacts3[TypeFacts3["AllTypeofNE"] = 556800] = "AllTypeofNE";
                    TypeFacts3[TypeFacts3["OrFactsMask"] = 8256] = "OrFactsMask";
                    TypeFacts3[TypeFacts3["AndFactsMask"] = 134209471] = "AndFactsMask";
                    return TypeFacts3;
                })(TypeFacts || {});
                typeofNEFacts = new Map(Object.entries({
                    string: 256 /* TypeofNEString */,
                    number: 512 /* TypeofNENumber */,
                    bigint: 1024 /* TypeofNEBigInt */,
                    boolean: 2048 /* TypeofNEBoolean */,
                    symbol: 4096 /* TypeofNESymbol */,
                    undefined: 524288 /* NEUndefined */,
                    object: 8192 /* TypeofNEObject */,
                    function: 16384 /* TypeofNEFunction */
                }));
                CheckMode = /* @__PURE__ */ ((CheckMode3) => {
                    CheckMode3[CheckMode3["Normal"] = 0] = "Normal";
                    CheckMode3[CheckMode3["Contextual"] = 1] = "Contextual";
                    CheckMode3[CheckMode3["Inferential"] = 2] = "Inferential";
                    CheckMode3[CheckMode3["SkipContextSensitive"] = 4] = "SkipContextSensitive";
                    CheckMode3[CheckMode3["SkipGenericFunctions"] = 8] = "SkipGenericFunctions";
                    CheckMode3[CheckMode3["IsForSignatureHelp"] = 16] = "IsForSignatureHelp";
                    CheckMode3[CheckMode3["IsForStringLiteralArgumentCompletions"] = 32] = "IsForStringLiteralArgumentCompletions";
                    CheckMode3[CheckMode3["RestBindingElement"] = 64] = "RestBindingElement";
                    return CheckMode3;
                })(CheckMode || {});
                SignatureCheckMode = /* @__PURE__ */ ((SignatureCheckMode3) => {
                    SignatureCheckMode3[SignatureCheckMode3["None"] = 0] = "None";
                    SignatureCheckMode3[SignatureCheckMode3["BivariantCallback"] = 1] = "BivariantCallback";
                    SignatureCheckMode3[SignatureCheckMode3["StrictCallback"] = 2] = "StrictCallback";
                    SignatureCheckMode3[SignatureCheckMode3["IgnoreReturnTypes"] = 4] = "IgnoreReturnTypes";
                    SignatureCheckMode3[SignatureCheckMode3["StrictArity"] = 8] = "StrictArity";
                    SignatureCheckMode3[SignatureCheckMode3["StrictTopSignature"] = 16] = "StrictTopSignature";
                    SignatureCheckMode3[SignatureCheckMode3["Callback"] = 3] = "Callback";
                    return SignatureCheckMode3;
                })(SignatureCheckMode || {});
                isNotOverloadAndNotAccessor = and(isNotOverload, isNotAccessor);
                intrinsicTypeKinds = new Map(Object.entries({
                    Uppercase: 0 /* Uppercase */,
                    Lowercase: 1 /* Lowercase */,
                    Capitalize: 2 /* Capitalize */,
                    Uncapitalize: 3 /* Uncapitalize */
                }));
                SymbolLinks = class {
                };
                ((JsxNames2) => {
                    JsxNames2.JSX = "JSX";
                    JsxNames2.IntrinsicElements = "IntrinsicElements";
                    JsxNames2.ElementClass = "ElementClass";
                    JsxNames2.ElementAttributesPropertyNameContainer = "ElementAttributesProperty";
                    JsxNames2.ElementChildrenAttributeNameContainer = "ElementChildrenAttribute";
                    JsxNames2.Element = "Element";
                    JsxNames2.IntrinsicAttributes = "IntrinsicAttributes";
                    JsxNames2.IntrinsicClassAttributes = "IntrinsicClassAttributes";
                    JsxNames2.LibraryManagedAttributes = "LibraryManagedAttributes";
                })(JsxNames || (JsxNames = {}));
                SymbolTrackerImpl = class {
                    constructor(context, tracker, moduleResolverHost) {
                        this.moduleResolverHost = void 0;
                        this.inner = void 0;
                        this.disableTrackSymbol = false;
                        var _a2;
                        while (tracker instanceof SymbolTrackerImpl) {
                            tracker = tracker.inner;
                        }
                        this.inner = tracker;
                        this.moduleResolverHost = moduleResolverHost;
                        this.context = context;
                        this.canTrackSymbol = !!((_a2 = this.inner) == null ? void 0 : _a2.trackSymbol);
                    }
                    trackSymbol(symbol, enclosingDeclaration, meaning) {
                        var _a2;
                        if (((_a2 = this.inner) == null ? void 0 : _a2.trackSymbol) && !this.disableTrackSymbol) {
                            if (this.inner.trackSymbol(symbol, enclosingDeclaration, meaning)) {
                                this.onDiagnosticReported();
                                return true;
                            }
                        }
                        return false;
                    }
                    reportInaccessibleThisError() {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.reportInaccessibleThisError) {
                            this.onDiagnosticReported();
                            this.inner.reportInaccessibleThisError();
                        }
                    }
                    reportPrivateInBaseOfClassExpression(propertyName) {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.reportPrivateInBaseOfClassExpression) {
                            this.onDiagnosticReported();
                            this.inner.reportPrivateInBaseOfClassExpression(propertyName);
                        }
                    }
                    reportInaccessibleUniqueSymbolError() {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.reportInaccessibleUniqueSymbolError) {
                            this.onDiagnosticReported();
                            this.inner.reportInaccessibleUniqueSymbolError();
                        }
                    }
                    reportCyclicStructureError() {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.reportCyclicStructureError) {
                            this.onDiagnosticReported();
                            this.inner.reportCyclicStructureError();
                        }
                    }
                    reportLikelyUnsafeImportRequiredError(specifier) {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.reportLikelyUnsafeImportRequiredError) {
                            this.onDiagnosticReported();
                            this.inner.reportLikelyUnsafeImportRequiredError(specifier);
                        }
                    }
                    reportTruncationError() {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.reportTruncationError) {
                            this.onDiagnosticReported();
                            this.inner.reportTruncationError();
                        }
                    }
                    trackReferencedAmbientModule(decl, symbol) {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.trackReferencedAmbientModule) {
                            this.onDiagnosticReported();
                            this.inner.trackReferencedAmbientModule(decl, symbol);
                        }
                    }
                    trackExternalModuleSymbolOfImportTypeNode(symbol) {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.trackExternalModuleSymbolOfImportTypeNode) {
                            this.onDiagnosticReported();
                            this.inner.trackExternalModuleSymbolOfImportTypeNode(symbol);
                        }
                    }
                    reportNonlocalAugmentation(containingFile, parentSymbol, augmentingSymbol) {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.reportNonlocalAugmentation) {
                            this.onDiagnosticReported();
                            this.inner.reportNonlocalAugmentation(containingFile, parentSymbol, augmentingSymbol);
                        }
                    }
                    reportNonSerializableProperty(propertyName) {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.reportNonSerializableProperty) {
                            this.onDiagnosticReported();
                            this.inner.reportNonSerializableProperty(propertyName);
                        }
                    }
                    reportImportTypeNodeResolutionModeOverride() {
                        var _a2;
                        if ((_a2 = this.inner) == null ? void 0 : _a2.reportImportTypeNodeResolutionModeOverride) {
                            this.onDiagnosticReported();
                            this.inner.reportImportTypeNodeResolutionModeOverride();
                        }
                    }
                    onDiagnosticReported() {
                        this.context.reportedDiagnostic = true;
                    }
                };
            }
        });
        // src/compiler/visitorPublic.ts
        function visitNode(node, visitor, test, lift) {
            if (node === void 0) {
                return node;
            }
            const visited = visitor(node);
            let visitedNode;
            if (visited === void 0) {
                return void 0;
            }
            else if (isArray(visited)) {
                visitedNode = (lift || extractSingleNode)(visited);
            }
            else {
                visitedNode = visited;
            }
            Debug.assertNode(visitedNode, test);
            return visitedNode;
        }
        function visitNodes2(nodes, visitor, test, start, count) {
            if (nodes === void 0) {
                return nodes;
            }
            const length2 = nodes.length;
            if (start === void 0 || start < 0) {
                start = 0;
            }
            if (count === void 0 || count > length2 - start) {
                count = length2 - start;
            }
            let hasTrailingComma;
            let pos = -1;
            let end = -1;
            if (start > 0 || count < length2) {
                hasTrailingComma = nodes.hasTrailingComma && start + count === length2;
            }
            else {
                pos = nodes.pos;
                end = nodes.end;
                hasTrailingComma = nodes.hasTrailingComma;
            }
            const updated = visitArrayWorker(nodes, visitor, test, start, count);
            if (updated !== nodes) {
                const updatedArray = factory.createNodeArray(updated, hasTrailingComma);
                setTextRangePosEnd(updatedArray, pos, end);
                return updatedArray;
            }
            return nodes;
        }
        function visitArray(nodes, visitor, test, start, count) {
            if (nodes === void 0) {
                return nodes;
            }
            const length2 = nodes.length;
            if (start === void 0 || start < 0) {
                start = 0;
            }
            if (count === void 0 || count > length2 - start) {
                count = length2 - start;
            }
            return visitArrayWorker(nodes, visitor, test, start, count);
        }
        function visitArrayWorker(nodes, visitor, test, start, count) {
            let updated;
            const length2 = nodes.length;
            if (start > 0 || count < length2) {
                updated = [];
            }
            for (let i = 0; i < count; i++) {
                const node = nodes[i + start];
                const visited = node !== void 0 ? visitor ? visitor(node) : node : void 0;
                if (updated !== void 0 || visited === void 0 || visited !== node) {
                    if (updated === void 0) {
                        updated = nodes.slice(0, i);
                        Debug.assertEachNode(updated, test);
                    }
                    if (visited) {
                        if (isArray(visited)) {
                            for (const visitedNode of visited) {
                                Debug.assertNode(visitedNode, test);
                                updated.push(visitedNode);
                            }
                        }
                        else {
                            Debug.assertNode(visited, test);
                            updated.push(visited);
                        }
                    }
                }
            }
            if (updated) {
                return updated;
            }
            Debug.assertEachNode(nodes, test);
            return nodes;
        }
        function visitLexicalEnvironment(statements, visitor, context, start, ensureUseStrict, nodesVisitor = visitNodes2) {
            context.startLexicalEnvironment();
            statements = nodesVisitor(statements, visitor, isStatement, start);
            if (ensureUseStrict)
                statements = context.factory.ensureUseStrict(statements);
            return factory.mergeLexicalEnvironment(statements, context.endLexicalEnvironment());
        }
        function visitParameterList(nodes, visitor, context, nodesVisitor = visitNodes2) {
            let updated;
            context.startLexicalEnvironment();
            if (nodes) {
                context.setLexicalEnvironmentFlags(1 /* InParameters */, true);
                updated = nodesVisitor(nodes, visitor, isParameter);
                if (context.getLexicalEnvironmentFlags() & 2 /* VariablesHoistedInParameters */ && getEmitScriptTarget(context.getCompilerOptions()) >= 2 /* ES2015 */) {
                    updated = addDefaultValueAssignmentsIfNeeded(updated, context);
                }
                context.setLexicalEnvironmentFlags(1 /* InParameters */, false);
            }
            context.suspendLexicalEnvironment();
            return updated;
        }
        function addDefaultValueAssignmentsIfNeeded(parameters, context) {
            let result;
            for (let i = 0; i < parameters.length; i++) {
                const parameter = parameters[i];
                const updated = addDefaultValueAssignmentIfNeeded(parameter, context);
                if (result || updated !== parameter) {
                    if (!result)
                        result = parameters.slice(0, i);
                    result[i] = updated;
                }
            }
            if (result) {
                return setTextRange(context.factory.createNodeArray(result, parameters.hasTrailingComma), parameters);
            }
            return parameters;
        }
        function addDefaultValueAssignmentIfNeeded(parameter, context) {
            return parameter.dotDotDotToken ? parameter : isBindingPattern(parameter.name) ? addDefaultValueAssignmentForBindingPattern(parameter, context) : parameter.initializer ? addDefaultValueAssignmentForInitializer(parameter, parameter.name, parameter.initializer, context) : parameter;
        }
        function addDefaultValueAssignmentForBindingPattern(parameter, context) {
            const { factory: factory2 } = context;
            context.addInitializationStatement(factory2.createVariableStatement(
            /*modifiers*/
            void 0, factory2.createVariableDeclarationList([
                factory2.createVariableDeclaration(parameter.name, 
                /*exclamationToken*/
                void 0, parameter.type, parameter.initializer ? factory2.createConditionalExpression(factory2.createStrictEquality(factory2.getGeneratedNameForNode(parameter), factory2.createVoidZero()), 
                /*questionToken*/
                void 0, parameter.initializer, 
                /*colonToken*/
                void 0, factory2.getGeneratedNameForNode(parameter)) : factory2.getGeneratedNameForNode(parameter))
            ])));
            return factory2.updateParameterDeclaration(parameter, parameter.modifiers, parameter.dotDotDotToken, factory2.getGeneratedNameForNode(parameter), parameter.questionToken, parameter.type, 
            /*initializer*/
            void 0);
        }
        function addDefaultValueAssignmentForInitializer(parameter, name, initializer, context) {
            const factory2 = context.factory;
            context.addInitializationStatement(factory2.createIfStatement(factory2.createTypeCheck(factory2.cloneNode(name), "undefined"), setEmitFlags(setTextRange(factory2.createBlock([
                factory2.createExpressionStatement(setEmitFlags(setTextRange(factory2.createAssignment(setEmitFlags(factory2.cloneNode(name), 96 /* NoSourceMap */), setEmitFlags(initializer, 96 /* NoSourceMap */ | getEmitFlags(initializer) | 3072 /* NoComments */)), parameter), 3072 /* NoComments */))
            ]), parameter), 1 /* SingleLine */ | 64 /* NoTrailingSourceMap */ | 768 /* NoTokenSourceMaps */ | 3072 /* NoComments */)));
            return factory2.updateParameterDeclaration(parameter, parameter.modifiers, parameter.dotDotDotToken, parameter.name, parameter.questionToken, parameter.type, 
            /*initializer*/
            void 0);
        }
        function visitFunctionBody(node, visitor, context, nodeVisitor = visitNode) {
            context.resumeLexicalEnvironment();
            const updated = nodeVisitor(node, visitor, isConciseBody);
            const declarations = context.endLexicalEnvironment();
            if (some(declarations)) {
                if (!updated) {
                    return context.factory.createBlock(declarations);
                }
                const block = context.factory.converters.convertToFunctionBlock(updated);
                const statements = factory.mergeLexicalEnvironment(block.statements, declarations);
                return context.factory.updateBlock(block, statements);
            }
            return updated;
        }
        function visitIterationBody(body, visitor, context, nodeVisitor = visitNode) {
            context.startBlockScope();
            const updated = nodeVisitor(body, visitor, isStatement, context.factory.liftToBlock);
            Debug.assert(updated);
            const declarations = context.endBlockScope();
            if (some(declarations)) {
                if (isBlock(updated)) {
                    declarations.push(...updated.statements);
                    return context.factory.updateBlock(updated, declarations);
                }
                declarations.push(updated);
                return context.factory.createBlock(declarations);
            }
            return updated;
        }
        function visitCommaListElements(elements, visitor, discardVisitor = visitor) {
            if (discardVisitor === visitor || elements.length <= 1) {
                return visitNodes2(elements, visitor, isExpression);
            }
            let i = 0;
            const length2 = elements.length;
            return visitNodes2(elements, (node) => {
                const discarded = i < length2 - 1;
                i++;
                return discarded ? discardVisitor(node) : visitor(node);
            }, isExpression);
        }
        function visitEachChild(node, visitor, context, nodesVisitor = visitNodes2, tokenVisitor, nodeVisitor = visitNode) {
            if (node === void 0) {
                return void 0;
            }
            const fn = visitEachChildTable[node.kind];
            return fn === void 0 ? node : fn(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor);
        }
        function extractSingleNode(nodes) {
            Debug.assert(nodes.length <= 1, "Too many nodes written to output.");
            return singleOrUndefined(nodes);
        }
        var visitEachChildTable;
        var init_visitorPublic = __esm({
            "src/compiler/visitorPublic.ts"() {
                "use strict";
                init_ts2();
                visitEachChildTable = {
                    [163 /* QualifiedName */]: function visitEachChildOfQualifiedName(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateQualifiedName(node, Debug.checkDefined(nodeVisitor(node.left, visitor, isEntityName)), Debug.checkDefined(nodeVisitor(node.right, visitor, isIdentifier)));
                    },
                    [164 /* ComputedPropertyName */]: function visitEachChildOfComputedPropertyName(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateComputedPropertyName(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    // Signature elements
                    [165 /* TypeParameter */]: function visitEachChildOfTypeParameterDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeParameterDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodeVisitor(node.constraint, visitor, isTypeNode), nodeVisitor(node.default, visitor, isTypeNode));
                    },
                    [166 /* Parameter */]: function visitEachChildOfParameterDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateParameterDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), tokenVisitor ? nodeVisitor(node.dotDotDotToken, tokenVisitor, isDotDotDotToken) : node.dotDotDotToken, Debug.checkDefined(nodeVisitor(node.name, visitor, isBindingName)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, nodeVisitor(node.type, visitor, isTypeNode), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    [167 /* Decorator */]: function visitEachChildOfDecorator(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateDecorator(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    // Type elements
                    [168 /* PropertySignature */]: function visitEachChildOfPropertySignature(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updatePropertySignature(node, nodesVisitor(node.modifiers, visitor, isModifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [169 /* PropertyDeclaration */]: function visitEachChildOfPropertyDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        var _a2, _b;
                        return context.factory.updatePropertyDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), 
                        // QuestionToken and ExclamationToken are mutually exclusive in PropertyDeclaration
                        tokenVisitor ? nodeVisitor((_a2 = node.questionToken) != null ? _a2 : node.exclamationToken, tokenVisitor, isQuestionOrExclamationToken) : (_b = node.questionToken) != null ? _b : node.exclamationToken, nodeVisitor(node.type, visitor, isTypeNode), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    [170 /* MethodSignature */]: function visitEachChildOfMethodSignature(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateMethodSignature(node, nodesVisitor(node.modifiers, visitor, isModifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [171 /* MethodDeclaration */]: function visitEachChildOfMethodDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateMethodDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), tokenVisitor ? nodeVisitor(node.asteriskToken, tokenVisitor, isAsteriskToken) : node.asteriskToken, Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [173 /* Constructor */]: function visitEachChildOfConstructorDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateConstructorDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), visitParameterList(node.parameters, visitor, context, nodesVisitor), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [174 /* GetAccessor */]: function visitEachChildOfGetAccessorDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateGetAccessorDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [175 /* SetAccessor */]: function visitEachChildOfSetAccessorDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSetAccessorDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), visitParameterList(node.parameters, visitor, context, nodesVisitor), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [172 /* ClassStaticBlockDeclaration */]: function visitEachChildOfClassStaticBlockDeclaration(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        context.startLexicalEnvironment();
                        context.suspendLexicalEnvironment();
                        return context.factory.updateClassStaticBlockDeclaration(node, visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [176 /* CallSignature */]: function visitEachChildOfCallSignatureDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCallSignature(node, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [177 /* ConstructSignature */]: function visitEachChildOfConstructSignatureDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateConstructSignature(node, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [178 /* IndexSignature */]: function visitEachChildOfIndexSignatureDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateIndexSignature(node, nodesVisitor(node.modifiers, visitor, isModifierLike), nodesVisitor(node.parameters, visitor, isParameter), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    // Types
                    [179 /* TypePredicate */]: function visitEachChildOfTypePredicateNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypePredicateNode(node, nodeVisitor(node.assertsModifier, visitor, isAssertsKeyword), Debug.checkDefined(nodeVisitor(node.parameterName, visitor, isIdentifierOrThisTypeNode)), nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [180 /* TypeReference */]: function visitEachChildOfTypeReferenceNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeReferenceNode(node, Debug.checkDefined(nodeVisitor(node.typeName, visitor, isEntityName)), nodesVisitor(node.typeArguments, visitor, isTypeNode));
                    },
                    [181 /* FunctionType */]: function visitEachChildOfFunctionTypeNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateFunctionTypeNode(node, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [182 /* ConstructorType */]: function visitEachChildOfConstructorTypeNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateConstructorTypeNode(node, nodesVisitor(node.modifiers, visitor, isModifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [183 /* TypeQuery */]: function visitEachChildOfTypeQueryNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeQueryNode(node, Debug.checkDefined(nodeVisitor(node.exprName, visitor, isEntityName)), nodesVisitor(node.typeArguments, visitor, isTypeNode));
                    },
                    [184 /* TypeLiteral */]: function visitEachChildOfTypeLiteralNode(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeLiteralNode(node, nodesVisitor(node.members, visitor, isTypeElement));
                    },
                    [185 /* ArrayType */]: function visitEachChildOfArrayTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateArrayTypeNode(node, Debug.checkDefined(nodeVisitor(node.elementType, visitor, isTypeNode)));
                    },
                    [186 /* TupleType */]: function visitEachChildOfTupleTypeNode(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTupleTypeNode(node, nodesVisitor(node.elements, visitor, isTypeNode));
                    },
                    [187 /* OptionalType */]: function visitEachChildOfOptionalTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateOptionalTypeNode(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [188 /* RestType */]: function visitEachChildOfRestTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateRestTypeNode(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [189 /* UnionType */]: function visitEachChildOfUnionTypeNode(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateUnionTypeNode(node, nodesVisitor(node.types, visitor, isTypeNode));
                    },
                    [190 /* IntersectionType */]: function visitEachChildOfIntersectionTypeNode(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateIntersectionTypeNode(node, nodesVisitor(node.types, visitor, isTypeNode));
                    },
                    [191 /* ConditionalType */]: function visitEachChildOfConditionalTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateConditionalTypeNode(node, Debug.checkDefined(nodeVisitor(node.checkType, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.extendsType, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.trueType, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.falseType, visitor, isTypeNode)));
                    },
                    [192 /* InferType */]: function visitEachChildOfInferTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateInferTypeNode(node, Debug.checkDefined(nodeVisitor(node.typeParameter, visitor, isTypeParameterDeclaration)));
                    },
                    [202 /* ImportType */]: function visitEachChildOfImportTypeNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportTypeNode(node, Debug.checkDefined(nodeVisitor(node.argument, visitor, isTypeNode)), nodeVisitor(node.assertions, visitor, isImportTypeAssertionContainer), nodeVisitor(node.qualifier, visitor, isEntityName), nodesVisitor(node.typeArguments, visitor, isTypeNode), node.isTypeOf);
                    },
                    [298 /* ImportTypeAssertionContainer */]: function visitEachChildOfImportTypeAssertionContainer(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportTypeAssertionContainer(node, Debug.checkDefined(nodeVisitor(node.assertClause, visitor, isAssertClause)), node.multiLine);
                    },
                    [199 /* NamedTupleMember */]: function visitEachChildOfNamedTupleMember(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateNamedTupleMember(node, tokenVisitor ? nodeVisitor(node.dotDotDotToken, tokenVisitor, isDotDotDotToken) : node.dotDotDotToken, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [193 /* ParenthesizedType */]: function visitEachChildOfParenthesizedType(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateParenthesizedType(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [195 /* TypeOperator */]: function visitEachChildOfTypeOperatorNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeOperatorNode(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [196 /* IndexedAccessType */]: function visitEachChildOfIndexedAccessType(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateIndexedAccessTypeNode(node, Debug.checkDefined(nodeVisitor(node.objectType, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.indexType, visitor, isTypeNode)));
                    },
                    [197 /* MappedType */]: function visitEachChildOfMappedType(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateMappedTypeNode(node, tokenVisitor ? nodeVisitor(node.readonlyToken, tokenVisitor, isReadonlyKeywordOrPlusOrMinusToken) : node.readonlyToken, Debug.checkDefined(nodeVisitor(node.typeParameter, visitor, isTypeParameterDeclaration)), nodeVisitor(node.nameType, visitor, isTypeNode), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionOrPlusOrMinusToken) : node.questionToken, nodeVisitor(node.type, visitor, isTypeNode), nodesVisitor(node.members, visitor, isTypeElement));
                    },
                    [198 /* LiteralType */]: function visitEachChildOfLiteralTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateLiteralTypeNode(node, Debug.checkDefined(nodeVisitor(node.literal, visitor, isLiteralTypeLiteral)));
                    },
                    [200 /* TemplateLiteralType */]: function visitEachChildOfTemplateLiteralType(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTemplateLiteralType(node, Debug.checkDefined(nodeVisitor(node.head, visitor, isTemplateHead)), nodesVisitor(node.templateSpans, visitor, isTemplateLiteralTypeSpan));
                    },
                    [201 /* TemplateLiteralTypeSpan */]: function visitEachChildOfTemplateLiteralTypeSpan(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTemplateLiteralTypeSpan(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.literal, visitor, isTemplateMiddleOrTemplateTail)));
                    },
                    // Binding patterns
                    [203 /* ObjectBindingPattern */]: function visitEachChildOfObjectBindingPattern(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateObjectBindingPattern(node, nodesVisitor(node.elements, visitor, isBindingElement));
                    },
                    [204 /* ArrayBindingPattern */]: function visitEachChildOfArrayBindingPattern(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateArrayBindingPattern(node, nodesVisitor(node.elements, visitor, isArrayBindingElement));
                    },
                    [205 /* BindingElement */]: function visitEachChildOfBindingElement(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateBindingElement(node, tokenVisitor ? nodeVisitor(node.dotDotDotToken, tokenVisitor, isDotDotDotToken) : node.dotDotDotToken, nodeVisitor(node.propertyName, visitor, isPropertyName), Debug.checkDefined(nodeVisitor(node.name, visitor, isBindingName)), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    // Expression
                    [206 /* ArrayLiteralExpression */]: function visitEachChildOfArrayLiteralExpression(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateArrayLiteralExpression(node, nodesVisitor(node.elements, visitor, isExpression));
                    },
                    [207 /* ObjectLiteralExpression */]: function visitEachChildOfObjectLiteralExpression(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateObjectLiteralExpression(node, nodesVisitor(node.properties, visitor, isObjectLiteralElementLike));
                    },
                    [208 /* PropertyAccessExpression */]: function visitEachChildOfPropertyAccessExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return isPropertyAccessChain(node) ? context.factory.updatePropertyAccessChain(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), tokenVisitor ? nodeVisitor(node.questionDotToken, tokenVisitor, isQuestionDotToken) : node.questionDotToken, Debug.checkDefined(nodeVisitor(node.name, visitor, isMemberName))) : context.factory.updatePropertyAccessExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.name, visitor, isMemberName)));
                    },
                    [209 /* ElementAccessExpression */]: function visitEachChildOfElementAccessExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return isElementAccessChain(node) ? context.factory.updateElementAccessChain(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), tokenVisitor ? nodeVisitor(node.questionDotToken, tokenVisitor, isQuestionDotToken) : node.questionDotToken, Debug.checkDefined(nodeVisitor(node.argumentExpression, visitor, isExpression))) : context.factory.updateElementAccessExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.argumentExpression, visitor, isExpression)));
                    },
                    [210 /* CallExpression */]: function visitEachChildOfCallExpression(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return isCallChain(node) ? context.factory.updateCallChain(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), tokenVisitor ? nodeVisitor(node.questionDotToken, tokenVisitor, isQuestionDotToken) : node.questionDotToken, nodesVisitor(node.typeArguments, visitor, isTypeNode), nodesVisitor(node.arguments, visitor, isExpression)) : context.factory.updateCallExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), nodesVisitor(node.arguments, visitor, isExpression));
                    },
                    [211 /* NewExpression */]: function visitEachChildOfNewExpression(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNewExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), nodesVisitor(node.arguments, visitor, isExpression));
                    },
                    [212 /* TaggedTemplateExpression */]: function visitEachChildOfTaggedTemplateExpression(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTaggedTemplateExpression(node, Debug.checkDefined(nodeVisitor(node.tag, visitor, isExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), Debug.checkDefined(nodeVisitor(node.template, visitor, isTemplateLiteral)));
                    },
                    [213 /* TypeAssertionExpression */]: function visitEachChildOfTypeAssertionExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeAssertion(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [214 /* ParenthesizedExpression */]: function visitEachChildOfParenthesizedExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateParenthesizedExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [215 /* FunctionExpression */]: function visitEachChildOfFunctionExpression(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateFunctionExpression(node, nodesVisitor(node.modifiers, visitor, isModifier), tokenVisitor ? nodeVisitor(node.asteriskToken, tokenVisitor, isAsteriskToken) : node.asteriskToken, nodeVisitor(node.name, visitor, isIdentifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [216 /* ArrowFunction */]: function visitEachChildOfArrowFunction(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateArrowFunction(node, nodesVisitor(node.modifiers, visitor, isModifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), tokenVisitor ? Debug.checkDefined(nodeVisitor(node.equalsGreaterThanToken, tokenVisitor, isEqualsGreaterThanToken)) : node.equalsGreaterThanToken, visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [217 /* DeleteExpression */]: function visitEachChildOfDeleteExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateDeleteExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [218 /* TypeOfExpression */]: function visitEachChildOfTypeOfExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeOfExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [219 /* VoidExpression */]: function visitEachChildOfVoidExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateVoidExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [220 /* AwaitExpression */]: function visitEachChildOfAwaitExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateAwaitExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [221 /* PrefixUnaryExpression */]: function visitEachChildOfPrefixUnaryExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updatePrefixUnaryExpression(node, Debug.checkDefined(nodeVisitor(node.operand, visitor, isExpression)));
                    },
                    [222 /* PostfixUnaryExpression */]: function visitEachChildOfPostfixUnaryExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updatePostfixUnaryExpression(node, Debug.checkDefined(nodeVisitor(node.operand, visitor, isExpression)));
                    },
                    [223 /* BinaryExpression */]: function visitEachChildOfBinaryExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateBinaryExpression(node, Debug.checkDefined(nodeVisitor(node.left, visitor, isExpression)), tokenVisitor ? Debug.checkDefined(nodeVisitor(node.operatorToken, tokenVisitor, isBinaryOperatorToken)) : node.operatorToken, Debug.checkDefined(nodeVisitor(node.right, visitor, isExpression)));
                    },
                    [224 /* ConditionalExpression */]: function visitEachChildOfConditionalExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateConditionalExpression(node, Debug.checkDefined(nodeVisitor(node.condition, visitor, isExpression)), tokenVisitor ? Debug.checkDefined(nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken)) : node.questionToken, Debug.checkDefined(nodeVisitor(node.whenTrue, visitor, isExpression)), tokenVisitor ? Debug.checkDefined(nodeVisitor(node.colonToken, tokenVisitor, isColonToken)) : node.colonToken, Debug.checkDefined(nodeVisitor(node.whenFalse, visitor, isExpression)));
                    },
                    [225 /* TemplateExpression */]: function visitEachChildOfTemplateExpression(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTemplateExpression(node, Debug.checkDefined(nodeVisitor(node.head, visitor, isTemplateHead)), nodesVisitor(node.templateSpans, visitor, isTemplateSpan));
                    },
                    [226 /* YieldExpression */]: function visitEachChildOfYieldExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateYieldExpression(node, tokenVisitor ? nodeVisitor(node.asteriskToken, tokenVisitor, isAsteriskToken) : node.asteriskToken, nodeVisitor(node.expression, visitor, isExpression));
                    },
                    [227 /* SpreadElement */]: function visitEachChildOfSpreadElement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSpreadElement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [228 /* ClassExpression */]: function visitEachChildOfClassExpression(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateClassExpression(node, nodesVisitor(node.modifiers, visitor, isModifierLike), nodeVisitor(node.name, visitor, isIdentifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.heritageClauses, visitor, isHeritageClause), nodesVisitor(node.members, visitor, isClassElement));
                    },
                    [230 /* ExpressionWithTypeArguments */]: function visitEachChildOfExpressionWithTypeArguments(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExpressionWithTypeArguments(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode));
                    },
                    [231 /* AsExpression */]: function visitEachChildOfAsExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateAsExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [235 /* SatisfiesExpression */]: function visitEachChildOfSatisfiesExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSatisfiesExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [232 /* NonNullExpression */]: function visitEachChildOfNonNullExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return isOptionalChain(node) ? context.factory.updateNonNullChain(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression))) : context.factory.updateNonNullExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [233 /* MetaProperty */]: function visitEachChildOfMetaProperty(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateMetaProperty(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    // Misc
                    [236 /* TemplateSpan */]: function visitEachChildOfTemplateSpan(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTemplateSpan(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.literal, visitor, isTemplateMiddleOrTemplateTail)));
                    },
                    // Element
                    [238 /* Block */]: function visitEachChildOfBlock(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateBlock(node, nodesVisitor(node.statements, visitor, isStatement));
                    },
                    [240 /* VariableStatement */]: function visitEachChildOfVariableStatement(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateVariableStatement(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.declarationList, visitor, isVariableDeclarationList)));
                    },
                    [241 /* ExpressionStatement */]: function visitEachChildOfExpressionStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExpressionStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [242 /* IfStatement */]: function visitEachChildOfIfStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateIfStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.thenStatement, visitor, isStatement, context.factory.liftToBlock)), nodeVisitor(node.elseStatement, visitor, isStatement, context.factory.liftToBlock));
                    },
                    [243 /* DoStatement */]: function visitEachChildOfDoStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateDoStatement(node, visitIterationBody(node.statement, visitor, context, nodeVisitor), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [244 /* WhileStatement */]: function visitEachChildOfWhileStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateWhileStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), visitIterationBody(node.statement, visitor, context, nodeVisitor));
                    },
                    [245 /* ForStatement */]: function visitEachChildOfForStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateForStatement(node, nodeVisitor(node.initializer, visitor, isForInitializer), nodeVisitor(node.condition, visitor, isExpression), nodeVisitor(node.incrementor, visitor, isExpression), visitIterationBody(node.statement, visitor, context, nodeVisitor));
                    },
                    [246 /* ForInStatement */]: function visitEachChildOfForInStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateForInStatement(node, Debug.checkDefined(nodeVisitor(node.initializer, visitor, isForInitializer)), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), visitIterationBody(node.statement, visitor, context, nodeVisitor));
                    },
                    [247 /* ForOfStatement */]: function visitEachChildOfForOfStatement(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateForOfStatement(node, tokenVisitor ? nodeVisitor(node.awaitModifier, tokenVisitor, isAwaitKeyword) : node.awaitModifier, Debug.checkDefined(nodeVisitor(node.initializer, visitor, isForInitializer)), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), visitIterationBody(node.statement, visitor, context, nodeVisitor));
                    },
                    [248 /* ContinueStatement */]: function visitEachChildOfContinueStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateContinueStatement(node, nodeVisitor(node.label, visitor, isIdentifier));
                    },
                    [249 /* BreakStatement */]: function visitEachChildOfBreakStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateBreakStatement(node, nodeVisitor(node.label, visitor, isIdentifier));
                    },
                    [250 /* ReturnStatement */]: function visitEachChildOfReturnStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateReturnStatement(node, nodeVisitor(node.expression, visitor, isExpression));
                    },
                    [251 /* WithStatement */]: function visitEachChildOfWithStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateWithStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.statement, visitor, isStatement, context.factory.liftToBlock)));
                    },
                    [252 /* SwitchStatement */]: function visitEachChildOfSwitchStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSwitchStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.caseBlock, visitor, isCaseBlock)));
                    },
                    [253 /* LabeledStatement */]: function visitEachChildOfLabeledStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateLabeledStatement(node, Debug.checkDefined(nodeVisitor(node.label, visitor, isIdentifier)), Debug.checkDefined(nodeVisitor(node.statement, visitor, isStatement, context.factory.liftToBlock)));
                    },
                    [254 /* ThrowStatement */]: function visitEachChildOfThrowStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateThrowStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [255 /* TryStatement */]: function visitEachChildOfTryStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTryStatement(node, Debug.checkDefined(nodeVisitor(node.tryBlock, visitor, isBlock)), nodeVisitor(node.catchClause, visitor, isCatchClause), nodeVisitor(node.finallyBlock, visitor, isBlock));
                    },
                    [257 /* VariableDeclaration */]: function visitEachChildOfVariableDeclaration(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateVariableDeclaration(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isBindingName)), tokenVisitor ? nodeVisitor(node.exclamationToken, tokenVisitor, isExclamationToken) : node.exclamationToken, nodeVisitor(node.type, visitor, isTypeNode), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    [258 /* VariableDeclarationList */]: function visitEachChildOfVariableDeclarationList(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateVariableDeclarationList(node, nodesVisitor(node.declarations, visitor, isVariableDeclaration));
                    },
                    [259 /* FunctionDeclaration */]: function visitEachChildOfFunctionDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateFunctionDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifier), tokenVisitor ? nodeVisitor(node.asteriskToken, tokenVisitor, isAsteriskToken) : node.asteriskToken, nodeVisitor(node.name, visitor, isIdentifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [260 /* ClassDeclaration */]: function visitEachChildOfClassDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateClassDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), nodeVisitor(node.name, visitor, isIdentifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.heritageClauses, visitor, isHeritageClause), nodesVisitor(node.members, visitor, isClassElement));
                    },
                    [261 /* InterfaceDeclaration */]: function visitEachChildOfInterfaceDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateInterfaceDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.heritageClauses, visitor, isHeritageClause), nodesVisitor(node.members, visitor, isTypeElement));
                    },
                    [262 /* TypeAliasDeclaration */]: function visitEachChildOfTypeAliasDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeAliasDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [263 /* EnumDeclaration */]: function visitEachChildOfEnumDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateEnumDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodesVisitor(node.members, visitor, isEnumMember));
                    },
                    [264 /* ModuleDeclaration */]: function visitEachChildOfModuleDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateModuleDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isModuleName)), nodeVisitor(node.body, visitor, isModuleBody));
                    },
                    [265 /* ModuleBlock */]: function visitEachChildOfModuleBlock(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateModuleBlock(node, nodesVisitor(node.statements, visitor, isStatement));
                    },
                    [266 /* CaseBlock */]: function visitEachChildOfCaseBlock(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCaseBlock(node, nodesVisitor(node.clauses, visitor, isCaseOrDefaultClause));
                    },
                    [267 /* NamespaceExportDeclaration */]: function visitEachChildOfNamespaceExportDeclaration(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamespaceExportDeclaration(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    [268 /* ImportEqualsDeclaration */]: function visitEachChildOfImportEqualsDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportEqualsDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), node.isTypeOnly, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), Debug.checkDefined(nodeVisitor(node.moduleReference, visitor, isModuleReference)));
                    },
                    [269 /* ImportDeclaration */]: function visitEachChildOfImportDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), nodeVisitor(node.importClause, visitor, isImportClause), Debug.checkDefined(nodeVisitor(node.moduleSpecifier, visitor, isExpression)), nodeVisitor(node.assertClause, visitor, isAssertClause));
                    },
                    [296 /* AssertClause */]: function visitEachChildOfAssertClause(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateAssertClause(node, nodesVisitor(node.elements, visitor, isAssertEntry), node.multiLine);
                    },
                    [297 /* AssertEntry */]: function visitEachChildOfAssertEntry(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateAssertEntry(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isAssertionKey)), Debug.checkDefined(nodeVisitor(node.value, visitor, isExpression)));
                    },
                    [270 /* ImportClause */]: function visitEachChildOfImportClause(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportClause(node, node.isTypeOnly, nodeVisitor(node.name, visitor, isIdentifier), nodeVisitor(node.namedBindings, visitor, isNamedImportBindings));
                    },
                    [271 /* NamespaceImport */]: function visitEachChildOfNamespaceImport(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamespaceImport(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    [277 /* NamespaceExport */]: function visitEachChildOfNamespaceExport(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamespaceExport(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    [272 /* NamedImports */]: function visitEachChildOfNamedImports(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamedImports(node, nodesVisitor(node.elements, visitor, isImportSpecifier));
                    },
                    [273 /* ImportSpecifier */]: function visitEachChildOfImportSpecifier(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportSpecifier(node, node.isTypeOnly, nodeVisitor(node.propertyName, visitor, isIdentifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    [274 /* ExportAssignment */]: function visitEachChildOfExportAssignment(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExportAssignment(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [275 /* ExportDeclaration */]: function visitEachChildOfExportDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExportDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), node.isTypeOnly, nodeVisitor(node.exportClause, visitor, isNamedExportBindings), nodeVisitor(node.moduleSpecifier, visitor, isExpression), nodeVisitor(node.assertClause, visitor, isAssertClause));
                    },
                    [276 /* NamedExports */]: function visitEachChildOfNamedExports(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamedExports(node, nodesVisitor(node.elements, visitor, isExportSpecifier));
                    },
                    [278 /* ExportSpecifier */]: function visitEachChildOfExportSpecifier(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExportSpecifier(node, node.isTypeOnly, nodeVisitor(node.propertyName, visitor, isIdentifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    // Module references
                    [280 /* ExternalModuleReference */]: function visitEachChildOfExternalModuleReference(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExternalModuleReference(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    // JSX
                    [281 /* JsxElement */]: function visitEachChildOfJsxElement(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxElement(node, Debug.checkDefined(nodeVisitor(node.openingElement, visitor, isJsxOpeningElement)), nodesVisitor(node.children, visitor, isJsxChild), Debug.checkDefined(nodeVisitor(node.closingElement, visitor, isJsxClosingElement)));
                    },
                    [282 /* JsxSelfClosingElement */]: function visitEachChildOfJsxSelfClosingElement(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxSelfClosingElement(node, Debug.checkDefined(nodeVisitor(node.tagName, visitor, isJsxTagNameExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), Debug.checkDefined(nodeVisitor(node.attributes, visitor, isJsxAttributes)));
                    },
                    [283 /* JsxOpeningElement */]: function visitEachChildOfJsxOpeningElement(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxOpeningElement(node, Debug.checkDefined(nodeVisitor(node.tagName, visitor, isJsxTagNameExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), Debug.checkDefined(nodeVisitor(node.attributes, visitor, isJsxAttributes)));
                    },
                    [284 /* JsxClosingElement */]: function visitEachChildOfJsxClosingElement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxClosingElement(node, Debug.checkDefined(nodeVisitor(node.tagName, visitor, isJsxTagNameExpression)));
                    },
                    [285 /* JsxFragment */]: function visitEachChildOfJsxFragment(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxFragment(node, Debug.checkDefined(nodeVisitor(node.openingFragment, visitor, isJsxOpeningFragment)), nodesVisitor(node.children, visitor, isJsxChild), Debug.checkDefined(nodeVisitor(node.closingFragment, visitor, isJsxClosingFragment)));
                    },
                    [288 /* JsxAttribute */]: function visitEachChildOfJsxAttribute(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxAttribute(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodeVisitor(node.initializer, visitor, isStringLiteralOrJsxExpression));
                    },
                    [289 /* JsxAttributes */]: function visitEachChildOfJsxAttributes(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxAttributes(node, nodesVisitor(node.properties, visitor, isJsxAttributeLike));
                    },
                    [290 /* JsxSpreadAttribute */]: function visitEachChildOfJsxSpreadAttribute(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxSpreadAttribute(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [291 /* JsxExpression */]: function visitEachChildOfJsxExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxExpression(node, nodeVisitor(node.expression, visitor, isExpression));
                    },
                    // Clauses
                    [292 /* CaseClause */]: function visitEachChildOfCaseClause(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCaseClause(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), nodesVisitor(node.statements, visitor, isStatement));
                    },
                    [293 /* DefaultClause */]: function visitEachChildOfDefaultClause(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateDefaultClause(node, nodesVisitor(node.statements, visitor, isStatement));
                    },
                    [294 /* HeritageClause */]: function visitEachChildOfHeritageClause(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateHeritageClause(node, nodesVisitor(node.types, visitor, isExpressionWithTypeArguments));
                    },
                    [295 /* CatchClause */]: function visitEachChildOfCatchClause(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCatchClause(node, nodeVisitor(node.variableDeclaration, visitor, isVariableDeclaration), Debug.checkDefined(nodeVisitor(node.block, visitor, isBlock)));
                    },
                    // Property assignments
                    [299 /* PropertyAssignment */]: function visitEachChildOfPropertyAssignment(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updatePropertyAssignment(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), Debug.checkDefined(nodeVisitor(node.initializer, visitor, isExpression)));
                    },
                    [300 /* ShorthandPropertyAssignment */]: function visitEachChildOfShorthandPropertyAssignment(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateShorthandPropertyAssignment(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodeVisitor(node.objectAssignmentInitializer, visitor, isExpression));
                    },
                    [301 /* SpreadAssignment */]: function visitEachChildOfSpreadAssignment(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSpreadAssignment(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    // Enum
                    [302 /* EnumMember */]: function visitEachChildOfEnumMember(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateEnumMember(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    // Top-level nodes
                    [308 /* SourceFile */]: function visitEachChildOfSourceFile(node, visitor, context, _nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSourceFile(node, visitLexicalEnvironment(node.statements, visitor, context));
                    },
                    // Transformation nodes
                    [356 /* PartiallyEmittedExpression */]: function visitEachChildOfPartiallyEmittedExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updatePartiallyEmittedExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [357 /* CommaListExpression */]: function visitEachChildOfCommaListExpression(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCommaListExpression(node, nodesVisitor(node.elements, visitor, isExpression));
                    }
                };
            }
        });
        // src/compiler/sourcemap.ts
        function createSourceMapGenerator(host, file, sourceRoot, sourcesDirectoryPath, generatorOptions) {
            var { enter, exit } = generatorOptions.extendedDiagnostics ? createTimer("Source Map", "beforeSourcemap", "afterSourcemap") : nullTimer;
            var rawSources = [];
            var sources = [];
            var sourceToSourceIndexMap = /* @__PURE__ */ new Map();
            var sourcesContent;
            var names = [];
            var nameToNameIndexMap;
            var mappingCharCodes = [];
            var mappings = "";
            var lastGeneratedLine = 0;
            var lastGeneratedCharacter = 0;
            var lastSourceIndex = 0;
            var lastSourceLine = 0;
            var lastSourceCharacter = 0;
            var lastNameIndex = 0;
            var hasLast = false;
            var pendingGeneratedLine = 0;
            var pendingGeneratedCharacter = 0;
            var pendingSourceIndex = 0;
            var pendingSourceLine = 0;
            var pendingSourceCharacter = 0;
            var pendingNameIndex = 0;
            var hasPending = false;
            var hasPendingSource = false;
            var hasPendingName = false;
            return {
                getSources: () => rawSources,
                addSource,
                setSourceContent,
                addName,
                addMapping,
                appendSourceMap,
                toJSON,
                toString: () => JSON.stringify(toJSON())
            };
            function addSource(fileName) {
                enter();
                const source = getRelativePathToDirectoryOrUrl(sourcesDirectoryPath, fileName, host.getCurrentDirectory(), host.getCanonicalFileName, 
                /*isAbsolutePathAnUrl*/
                true);
                let sourceIndex = sourceToSourceIndexMap.get(source);
                if (sourceIndex === void 0) {
                    sourceIndex = sources.length;
                    sources.push(source);
                    rawSources.push(fileName);
                    sourceToSourceIndexMap.set(source, sourceIndex);
                }
                exit();
                return sourceIndex;
            }
            function setSourceContent(sourceIndex, content) {
                enter();
                if (content !== null) {
                    if (!sourcesContent)
                        sourcesContent = [];
                    while (sourcesContent.length < sourceIndex) {
                        sourcesContent.push(null);
                    }
                    sourcesContent[sourceIndex] = content;
                }
                exit();
            }
            function addName(name) {
                enter();
                if (!nameToNameIndexMap)
                    nameToNameIndexMap = /* @__PURE__ */ new Map();
                let nameIndex = nameToNameIndexMap.get(name);
                if (nameIndex === void 0) {
                    nameIndex = names.length;
                    names.push(name);
                    nameToNameIndexMap.set(name, nameIndex);
                }
                exit();
                return nameIndex;
            }
            function isNewGeneratedPosition(generatedLine, generatedCharacter) {
                return !hasPending || pendingGeneratedLine !== generatedLine || pendingGeneratedCharacter !== generatedCharacter;
            }
            function isBacktrackingSourcePosition(sourceIndex, sourceLine, sourceCharacter) {
                return sourceIndex !== void 0 && sourceLine !== void 0 && sourceCharacter !== void 0 && pendingSourceIndex === sourceIndex && (pendingSourceLine > sourceLine || pendingSourceLine === sourceLine && pendingSourceCharacter > sourceCharacter);
            }
            function addMapping(generatedLine, generatedCharacter, sourceIndex, sourceLine, sourceCharacter, nameIndex) {
                Debug.assert(generatedLine >= pendingGeneratedLine, "generatedLine cannot backtrack");
                Debug.assert(generatedCharacter >= 0, "generatedCharacter cannot be negative");
                Debug.assert(sourceIndex === void 0 || sourceIndex >= 0, "sourceIndex cannot be negative");
                Debug.assert(sourceLine === void 0 || sourceLine >= 0, "sourceLine cannot be negative");
                Debug.assert(sourceCharacter === void 0 || sourceCharacter >= 0, "sourceCharacter cannot be negative");
                enter();
                if (isNewGeneratedPosition(generatedLine, generatedCharacter) || isBacktrackingSourcePosition(sourceIndex, sourceLine, sourceCharacter)) {
                    commitPendingMapping();
                    pendingGeneratedLine = generatedLine;
                    pendingGeneratedCharacter = generatedCharacter;
                    hasPendingSource = false;
                    hasPendingName = false;
                    hasPending = true;
                }
                if (sourceIndex !== void 0 && sourceLine !== void 0 && sourceCharacter !== void 0) {
                    pendingSourceIndex = sourceIndex;
                    pendingSourceLine = sourceLine;
                    pendingSourceCharacter = sourceCharacter;
                    hasPendingSource = true;
                    if (nameIndex !== void 0) {
                        pendingNameIndex = nameIndex;
                        hasPendingName = true;
                    }
                }
                exit();
            }
            function appendSourceMap(generatedLine, generatedCharacter, map2, sourceMapPath, start, end) {
                Debug.assert(generatedLine >= pendingGeneratedLine, "generatedLine cannot backtrack");
                Debug.assert(generatedCharacter >= 0, "generatedCharacter cannot be negative");
                enter();
                const sourceIndexToNewSourceIndexMap = [];
                let nameIndexToNewNameIndexMap;
                const mappingIterator = decodeMappings(map2.mappings);
                for (const raw of mappingIterator) {
                    if (end && (raw.generatedLine > end.line || raw.generatedLine === end.line && raw.generatedCharacter > end.character)) {
                        break;
                    }
                    if (start && (raw.generatedLine < start.line || start.line === raw.generatedLine && raw.generatedCharacter < start.character)) {
                        continue;
                    }
                    let newSourceIndex;
                    let newSourceLine;
                    let newSourceCharacter;
                    let newNameIndex;
                    if (raw.sourceIndex !== void 0) {
                        newSourceIndex = sourceIndexToNewSourceIndexMap[raw.sourceIndex];
                        if (newSourceIndex === void 0) {
                            const rawPath = map2.sources[raw.sourceIndex];
                            const relativePath = map2.sourceRoot ? combinePaths(map2.sourceRoot, rawPath) : rawPath;
                            const combinedPath = combinePaths(getDirectoryPath(sourceMapPath), relativePath);
                            sourceIndexToNewSourceIndexMap[raw.sourceIndex] = newSourceIndex = addSource(combinedPath);
                            if (map2.sourcesContent && typeof map2.sourcesContent[raw.sourceIndex] === "string") {
                                setSourceContent(newSourceIndex, map2.sourcesContent[raw.sourceIndex]);
                            }
                        }
                        newSourceLine = raw.sourceLine;
                        newSourceCharacter = raw.sourceCharacter;
                        if (map2.names && raw.nameIndex !== void 0) {
                            if (!nameIndexToNewNameIndexMap)
                                nameIndexToNewNameIndexMap = [];
                            newNameIndex = nameIndexToNewNameIndexMap[raw.nameIndex];
                            if (newNameIndex === void 0) {
                                nameIndexToNewNameIndexMap[raw.nameIndex] = newNameIndex = addName(map2.names[raw.nameIndex]);
                            }
                        }
                    }
                    const rawGeneratedLine = raw.generatedLine - (start ? start.line : 0);
                    const newGeneratedLine = rawGeneratedLine + generatedLine;
                    const rawGeneratedCharacter = start && start.line === raw.generatedLine ? raw.generatedCharacter - start.character : raw.generatedCharacter;
                    const newGeneratedCharacter = rawGeneratedLine === 0 ? rawGeneratedCharacter + generatedCharacter : rawGeneratedCharacter;
                    addMapping(newGeneratedLine, newGeneratedCharacter, newSourceIndex, newSourceLine, newSourceCharacter, newNameIndex);
                }
                exit();
            }
            function shouldCommitMapping() {
                return !hasLast || lastGeneratedLine !== pendingGeneratedLine || lastGeneratedCharacter !== pendingGeneratedCharacter || lastSourceIndex !== pendingSourceIndex || lastSourceLine !== pendingSourceLine || lastSourceCharacter !== pendingSourceCharacter || lastNameIndex !== pendingNameIndex;
            }
            function appendMappingCharCode(charCode) {
                mappingCharCodes.push(charCode);
                if (mappingCharCodes.length >= 1024) {
                    flushMappingBuffer();
                }
            }
            function commitPendingMapping() {
                if (!hasPending || !shouldCommitMapping()) {
                    return;
                }
                enter();
                if (lastGeneratedLine < pendingGeneratedLine) {
                    do {
                        appendMappingCharCode(59 /* semicolon */);
                        lastGeneratedLine++;
                    } while (lastGeneratedLine < pendingGeneratedLine);
                    lastGeneratedCharacter = 0;
                }
                else {
                    Debug.assertEqual(lastGeneratedLine, pendingGeneratedLine, "generatedLine cannot backtrack");
                    if (hasLast) {
                        appendMappingCharCode(44 /* comma */);
                    }
                }
                appendBase64VLQ(pendingGeneratedCharacter - lastGeneratedCharacter);
                lastGeneratedCharacter = pendingGeneratedCharacter;
                if (hasPendingSource) {
                    appendBase64VLQ(pendingSourceIndex - lastSourceIndex);
                    lastSourceIndex = pendingSourceIndex;
                    appendBase64VLQ(pendingSourceLine - lastSourceLine);
                    lastSourceLine = pendingSourceLine;
                    appendBase64VLQ(pendingSourceCharacter - lastSourceCharacter);
                    lastSourceCharacter = pendingSourceCharacter;
                    if (hasPendingName) {
                        appendBase64VLQ(pendingNameIndex - lastNameIndex);
                        lastNameIndex = pendingNameIndex;
                    }
                }
                hasLast = true;
                exit();
            }
            function flushMappingBuffer() {
                if (mappingCharCodes.length > 0) {
                    mappings += String.fromCharCode.apply(void 0, mappingCharCodes);
                    mappingCharCodes.length = 0;
                }
            }
            function toJSON() {
                commitPendingMapping();
                flushMappingBuffer();
                return {
                    version: 3,
                    file,
                    sourceRoot,
                    sources,
                    names,
                    mappings,
                    sourcesContent
                };
            }
            function appendBase64VLQ(inValue) {
                if (inValue < 0) {
                    inValue = (-inValue << 1) + 1;
                }
                else {
                    inValue = inValue << 1;
                }
                do {
                    let currentDigit = inValue & 31;
                    inValue = inValue >> 5;
                    if (inValue > 0) {
                        currentDigit = currentDigit | 32;
                    }
                    appendMappingCharCode(base64FormatEncode(currentDigit));
                } while (inValue > 0);
            }
        }
        function getLineInfo(text, lineStarts) {
            return {
                getLineCount: () => lineStarts.length,
                getLineText: (line) => text.substring(lineStarts[line], lineStarts[line + 1])
            };
        }
        function tryGetSourceMappingURL(lineInfo) {
            for (let index = lineInfo.getLineCount() - 1; index >= 0; index--) {
                const line = lineInfo.getLineText(index);
                const comment = sourceMapCommentRegExp.exec(line);
                if (comment) {
                    return trimStringEnd(comment[1]);
                }
                else if (!line.match(whitespaceOrMapCommentRegExp)) {
                    break;
                }
            }
        }
        function isStringOrNull(x) {
            return typeof x === "string" || x === null;
        }
        function isRawSourceMap(x) {
            return x !== null && typeof x === "object" && x.version === 3 && typeof x.file === "string" && typeof x.mappings === "string" && isArray(x.sources) && every(x.sources, isString) && (x.sourceRoot === void 0 || x.sourceRoot === null || typeof x.sourceRoot === "string") && (x.sourcesContent === void 0 || x.sourcesContent === null || isArray(x.sourcesContent) && every(x.sourcesContent, isStringOrNull)) && (x.names === void 0 || x.names === null || isArray(x.names) && every(x.names, isString));
        }
        function tryParseRawSourceMap(text) {
            try {
                const parsed = JSON.parse(text);
                if (isRawSourceMap(parsed)) {
                    return parsed;
                }
            }
            catch (e) {
            }
            return void 0;
        }
        function decodeMappings(mappings) {
            let done = false;
            let pos = 0;
            let generatedLine = 0;
            let generatedCharacter = 0;
            let sourceIndex = 0;
            let sourceLine = 0;
            let sourceCharacter = 0;
            let nameIndex = 0;
            let error;
            return {
                get pos() {
                    return pos;
                },
                get error() {
                    return error;
                },
                get state() {
                    return captureMapping(
                    /*hasSource*/
                    true, 
                    /*hasName*/
                    true);
                },
                next() {
                    while (!done && pos < mappings.length) {
                        const ch = mappings.charCodeAt(pos);
                        if (ch === 59 /* semicolon */) {
                            generatedLine++;
                            generatedCharacter = 0;
                            pos++;
                            continue;
                        }
                        if (ch === 44 /* comma */) {
                            pos++;
                            continue;
                        }
                        let hasSource = false;
                        let hasName = false;
                        generatedCharacter += base64VLQFormatDecode();
                        if (hasReportedError())
                            return stopIterating();
                        if (generatedCharacter < 0)
                            return setErrorAndStopIterating("Invalid generatedCharacter found");
                        if (!isSourceMappingSegmentEnd()) {
                            hasSource = true;
                            sourceIndex += base64VLQFormatDecode();
                            if (hasReportedError())
                                return stopIterating();
                            if (sourceIndex < 0)
                                return setErrorAndStopIterating("Invalid sourceIndex found");
                            if (isSourceMappingSegmentEnd())
                                return setErrorAndStopIterating("Unsupported Format: No entries after sourceIndex");
                            sourceLine += base64VLQFormatDecode();
                            if (hasReportedError())
                                return stopIterating();
                            if (sourceLine < 0)
                                return setErrorAndStopIterating("Invalid sourceLine found");
                            if (isSourceMappingSegmentEnd())
                                return setErrorAndStopIterating("Unsupported Format: No entries after sourceLine");
                            sourceCharacter += base64VLQFormatDecode();
                            if (hasReportedError())
                                return stopIterating();
                            if (sourceCharacter < 0)
                                return setErrorAndStopIterating("Invalid sourceCharacter found");
                            if (!isSourceMappingSegmentEnd()) {
                                hasName = true;
                                nameIndex += base64VLQFormatDecode();
                                if (hasReportedError())
                                    return stopIterating();
                                if (nameIndex < 0)
                                    return setErrorAndStopIterating("Invalid nameIndex found");
                                if (!isSourceMappingSegmentEnd())
                                    return setErrorAndStopIterating("Unsupported Error Format: Entries after nameIndex");
                            }
                        }
                        return { value: captureMapping(hasSource, hasName), done };
                    }
                    return stopIterating();
                },
                [Symbol.iterator]() {
                    return this;
                }
            };
            function captureMapping(hasSource, hasName) {
                return {
                    generatedLine,
                    generatedCharacter,
                    sourceIndex: hasSource ? sourceIndex : void 0,
                    sourceLine: hasSource ? sourceLine : void 0,
                    sourceCharacter: hasSource ? sourceCharacter : void 0,
                    nameIndex: hasName ? nameIndex : void 0
                };
            }
            function stopIterating() {
                done = true;
                return { value: void 0, done: true };
            }
            function setError(message) {
                if (error === void 0) {
                    error = message;
                }
            }
            function setErrorAndStopIterating(message) {
                setError(message);
                return stopIterating();
            }
            function hasReportedError() {
                return error !== void 0;
            }
            function isSourceMappingSegmentEnd() {
                return pos === mappings.length || mappings.charCodeAt(pos) === 44 /* comma */ || mappings.charCodeAt(pos) === 59 /* semicolon */;
            }
            function base64VLQFormatDecode() {
                let moreDigits = true;
                let shiftCount = 0;
                let value = 0;
                for (; moreDigits; pos++) {
                    if (pos >= mappings.length)
                        return setError("Error in decoding base64VLQFormatDecode, past the mapping string"), -1;
                    const currentByte = base64FormatDecode(mappings.charCodeAt(pos));
                    if (currentByte === -1)
                        return setError("Invalid character in VLQ"), -1;
                    moreDigits = (currentByte & 32) !== 0;
                    value = value | (currentByte & 31) << shiftCount;
                    shiftCount += 5;
                }
                if ((value & 1) === 0) {
                    value = value >> 1;
                }
                else {
                    value = value >> 1;
                    value = -value;
                }
                return value;
            }
        }
        function sameMapping(left, right) {
            return left === right || left.generatedLine === right.generatedLine && left.generatedCharacter === right.generatedCharacter && left.sourceIndex === right.sourceIndex && left.sourceLine === right.sourceLine && left.sourceCharacter === right.sourceCharacter && left.nameIndex === right.nameIndex;
        }
        function isSourceMapping(mapping) {
            return mapping.sourceIndex !== void 0 && mapping.sourceLine !== void 0 && mapping.sourceCharacter !== void 0;
        }
        function base64FormatEncode(value) {
            return value >= 0 && value < 26 ? 65 /* A */ + value : value >= 26 && value < 52 ? 97 /* a */ + value - 26 : value >= 52 && value < 62 ? 48 /* _0 */ + value - 52 : value === 62 ? 43 /* plus */ : value === 63 ? 47 /* slash */ : Debug.fail(`${value}: not a base64 value`);
        }
        function base64FormatDecode(ch) {
            return ch >= 65 /* A */ && ch <= 90 /* Z */ ? ch - 65 /* A */ : ch >= 97 /* a */ && ch <= 122 /* z */ ? ch - 97 /* a */ + 26 : ch >= 48 /* _0 */ && ch <= 57 /* _9 */ ? ch - 48 /* _0 */ + 52 : ch === 43 /* plus */ ? 62 : ch === 47 /* slash */ ? 63 : -1;
        }
        function isSourceMappedPosition(value) {
            return value.sourceIndex !== void 0 && value.sourcePosition !== void 0;
        }
        function sameMappedPosition(left, right) {
            return left.generatedPosition === right.generatedPosition && left.sourceIndex === right.sourceIndex && left.sourcePosition === right.sourcePosition;
        }
        function compareSourcePositions(left, right) {
            Debug.assert(left.sourceIndex === right.sourceIndex);
            return compareValues(left.sourcePosition, right.sourcePosition);
        }
        function compareGeneratedPositions(left, right) {
            return compareValues(left.generatedPosition, right.generatedPosition);
        }
        function getSourcePositionOfMapping(value) {
            return value.sourcePosition;
        }
        function getGeneratedPositionOfMapping(value) {
            return value.generatedPosition;
        }
        function createDocumentPositionMapper(host, map2, mapPath) {
            const mapDirectory = getDirectoryPath(mapPath);
            const sourceRoot = map2.sourceRoot ? getNormalizedAbsolutePath(map2.sourceRoot, mapDirectory) : mapDirectory;
            const generatedAbsoluteFilePath = getNormalizedAbsolutePath(map2.file, mapDirectory);
            const generatedFile = host.getSourceFileLike(generatedAbsoluteFilePath);
            const sourceFileAbsolutePaths = map2.sources.map((source) => getNormalizedAbsolutePath(source, sourceRoot));
            const sourceToSourceIndexMap = new Map(sourceFileAbsolutePaths.map((source, i) => [host.getCanonicalFileName(source), i]));
            let decodedMappings;
            let generatedMappings;
            let sourceMappings;
            return {
                getSourcePosition,
                getGeneratedPosition
            };
            function processMapping(mapping) {
                const generatedPosition = generatedFile !== void 0 ? getPositionOfLineAndCharacter(generatedFile, mapping.generatedLine, mapping.generatedCharacter, 
                /*allowEdits*/
                true) : -1;
                let source;
                let sourcePosition;
                if (isSourceMapping(mapping)) {
                    const sourceFile = host.getSourceFileLike(sourceFileAbsolutePaths[mapping.sourceIndex]);
                    source = map2.sources[mapping.sourceIndex];
                    sourcePosition = sourceFile !== void 0 ? getPositionOfLineAndCharacter(sourceFile, mapping.sourceLine, mapping.sourceCharacter, 
                    /*allowEdits*/
                    true) : -1;
                }
                return {
                    generatedPosition,
                    source,
                    sourceIndex: mapping.sourceIndex,
                    sourcePosition,
                    nameIndex: mapping.nameIndex
                };
            }
            function getDecodedMappings() {
                if (decodedMappings === void 0) {
                    const decoder = decodeMappings(map2.mappings);
                    const mappings = arrayFrom(decoder, processMapping);
                    if (decoder.error !== void 0) {
                        if (host.log) {
                            host.log(`Encountered error while decoding sourcemap: ${decoder.error}`);
                        }
                        decodedMappings = emptyArray;
                    }
                    else {
                        decodedMappings = mappings;
                    }
                }
                return decodedMappings;
            }
            function getSourceMappings(sourceIndex) {
                if (sourceMappings === void 0) {
                    const lists = [];
                    for (const mapping of getDecodedMappings()) {
                        if (!isSourceMappedPosition(mapping))
                            continue;
                        let list = lists[mapping.sourceIndex];
                        if (!list)
                            lists[mapping.sourceIndex] = list = [];
                        list.push(mapping);
                    }
                    sourceMappings = lists.map((list) => sortAndDeduplicate(list, compareSourcePositions, sameMappedPosition));
                }
                return sourceMappings[sourceIndex];
            }
            function getGeneratedMappings() {
                if (generatedMappings === void 0) {
                    const list = [];
                    for (const mapping of getDecodedMappings()) {
                        list.push(mapping);
                    }
                    generatedMappings = sortAndDeduplicate(list, compareGeneratedPositions, sameMappedPosition);
                }
                return generatedMappings;
            }
            function getGeneratedPosition(loc) {
                const sourceIndex = sourceToSourceIndexMap.get(host.getCanonicalFileName(loc.fileName));
                if (sourceIndex === void 0)
                    return loc;
                const sourceMappings2 = getSourceMappings(sourceIndex);
                if (!some(sourceMappings2))
                    return loc;
                let targetIndex = binarySearchKey(sourceMappings2, loc.pos, getSourcePositionOfMapping, compareValues);
                if (targetIndex < 0) {
                    targetIndex = ~targetIndex;
                }
                const mapping = sourceMappings2[targetIndex];
                if (mapping === void 0 || mapping.sourceIndex !== sourceIndex) {
                    return loc;
                }
                return { fileName: generatedAbsoluteFilePath, pos: mapping.generatedPosition };
            }
            function getSourcePosition(loc) {
                const generatedMappings2 = getGeneratedMappings();
                if (!some(generatedMappings2))
                    return loc;
                let targetIndex = binarySearchKey(generatedMappings2, loc.pos, getGeneratedPositionOfMapping, compareValues);
                if (targetIndex < 0) {
                    targetIndex = ~targetIndex;
                }
                const mapping = generatedMappings2[targetIndex];
                if (mapping === void 0 || !isSourceMappedPosition(mapping)) {
                    return loc;
                }
                return { fileName: sourceFileAbsolutePaths[mapping.sourceIndex], pos: mapping.sourcePosition };
            }
        }
        var sourceMapCommentRegExpDontCareLineStart, sourceMapCommentRegExp, whitespaceOrMapCommentRegExp, identitySourceMapConsumer;
        var init_sourcemap = __esm({
            "src/compiler/sourcemap.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                sourceMapCommentRegExpDontCareLineStart = /\/\/[@#] source[M]appingURL=(.+)\r?\n?$/;
                sourceMapCommentRegExp = /^\/\/[@#] source[M]appingURL=(.+)\r?\n?$/;
                whitespaceOrMapCommentRegExp = /^\s*(\/\/[@#] .*)?$/;
                identitySourceMapConsumer = {
                    getSourcePosition: identity,
                    getGeneratedPosition: identity
                };
            }
        });
        // src/compiler/transformers/utilities.ts
        function getOriginalNodeId(node) {
            node = getOriginalNode(node);
            return node ? getNodeId(node) : 0;
        }
        function containsDefaultReference(node) {
            if (!node)
                return false;
            if (!isNamedImports(node))
                return false;
            return some(node.elements, isNamedDefaultReference);
        }
        function isNamedDefaultReference(e) {
            return e.propertyName !== void 0 && e.propertyName.escapedText === "default" /* Default */;
        }
        function chainBundle(context, transformSourceFile) {
            return transformSourceFileOrBundle;
            function transformSourceFileOrBundle(node) {
                return node.kind === 308 /* SourceFile */ ? transformSourceFile(node) : transformBundle(node);
            }
            function transformBundle(node) {
                return context.factory.createBundle(map(node.sourceFiles, transformSourceFile), node.prepends);
            }
        }
        function getExportNeedsImportStarHelper(node) {
            return !!getNamespaceDeclarationNode(node);
        }
        function getImportNeedsImportStarHelper(node) {
            if (!!getNamespaceDeclarationNode(node)) {
                return true;
            }
            const bindings = node.importClause && node.importClause.namedBindings;
            if (!bindings) {
                return false;
            }
            if (!isNamedImports(bindings))
                return false;
            let defaultRefCount = 0;
            for (const binding of bindings.elements) {
                if (isNamedDefaultReference(binding)) {
                    defaultRefCount++;
                }
            }
            return defaultRefCount > 0 && defaultRefCount !== bindings.elements.length || !!(bindings.elements.length - defaultRefCount) && isDefaultImport(node);
        }
        function getImportNeedsImportDefaultHelper(node) {
            return !getImportNeedsImportStarHelper(node) && (isDefaultImport(node) || !!node.importClause && isNamedImports(node.importClause.namedBindings) && containsDefaultReference(node.importClause.namedBindings));
        }
        function collectExternalModuleInfo(context, sourceFile, resolver, compilerOptions) {
            const externalImports = [];
            const exportSpecifiers = createMultiMap();
            const exportedBindings = [];
            const uniqueExports = /* @__PURE__ */ new Map();
            let exportedNames;
            let hasExportDefault = false;
            let exportEquals;
            let hasExportStarsToExportValues = false;
            let hasImportStar = false;
            let hasImportDefault = false;
            for (const node of sourceFile.statements) {
                switch (node.kind) {
                    case 269 /* ImportDeclaration */:
                        externalImports.push(node);
                        if (!hasImportStar && getImportNeedsImportStarHelper(node)) {
                            hasImportStar = true;
                        }
                        if (!hasImportDefault && getImportNeedsImportDefaultHelper(node)) {
                            hasImportDefault = true;
                        }
                        break;
                    case 268 /* ImportEqualsDeclaration */:
                        if (node.moduleReference.kind === 280 /* ExternalModuleReference */) {
                            externalImports.push(node);
                        }
                        break;
                    case 275 /* ExportDeclaration */:
                        if (node.moduleSpecifier) {
                            if (!node.exportClause) {
                                externalImports.push(node);
                                hasExportStarsToExportValues = true;
                            }
                            else {
                                externalImports.push(node);
                                if (isNamedExports(node.exportClause)) {
                                    addExportedNamesForExportDeclaration(node);
                                }
                                else {
                                    const name = node.exportClause.name;
                                    if (!uniqueExports.get(idText(name))) {
                                        multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), name);
                                        uniqueExports.set(idText(name), true);
                                        exportedNames = append(exportedNames, name);
                                    }
                                    hasImportStar = true;
                                }
                            }
                        }
                        else {
                            addExportedNamesForExportDeclaration(node);
                        }
                        break;
                    case 274 /* ExportAssignment */:
                        if (node.isExportEquals && !exportEquals) {
                            exportEquals = node;
                        }
                        break;
                    case 240 /* VariableStatement */:
                        if (hasSyntacticModifier(node, 1 /* Export */)) {
                            for (const decl of node.declarationList.declarations) {
                                exportedNames = collectExportedVariableInfo(decl, uniqueExports, exportedNames);
                            }
                        }
                        break;
                    case 259 /* FunctionDeclaration */:
                        if (hasSyntacticModifier(node, 1 /* Export */)) {
                            if (hasSyntacticModifier(node, 1024 /* Default */)) {
                                if (!hasExportDefault) {
                                    multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), context.factory.getDeclarationName(node));
                                    hasExportDefault = true;
                                }
                            }
                            else {
                                const name = node.name;
                                if (!uniqueExports.get(idText(name))) {
                                    multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), name);
                                    uniqueExports.set(idText(name), true);
                                    exportedNames = append(exportedNames, name);
                                }
                            }
                        }
                        break;
                    case 260 /* ClassDeclaration */:
                        if (hasSyntacticModifier(node, 1 /* Export */)) {
                            if (hasSyntacticModifier(node, 1024 /* Default */)) {
                                if (!hasExportDefault) {
                                    multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), context.factory.getDeclarationName(node));
                                    hasExportDefault = true;
                                }
                            }
                            else {
                                const name = node.name;
                                if (name && !uniqueExports.get(idText(name))) {
                                    multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), name);
                                    uniqueExports.set(idText(name), true);
                                    exportedNames = append(exportedNames, name);
                                }
                            }
                        }
                        break;
                }
            }
            const externalHelpersImportDeclaration = createExternalHelpersImportDeclarationIfNeeded(context.factory, context.getEmitHelperFactory(), sourceFile, compilerOptions, hasExportStarsToExportValues, hasImportStar, hasImportDefault);
            if (externalHelpersImportDeclaration) {
                externalImports.unshift(externalHelpersImportDeclaration);
            }
            return { externalImports, exportSpecifiers, exportEquals, hasExportStarsToExportValues, exportedBindings, exportedNames, externalHelpersImportDeclaration };
            function addExportedNamesForExportDeclaration(node) {
                for (const specifier of cast(node.exportClause, isNamedExports).elements) {
                    if (!uniqueExports.get(idText(specifier.name))) {
                        const name = specifier.propertyName || specifier.name;
                        if (!node.moduleSpecifier) {
                            exportSpecifiers.add(idText(name), specifier);
                        }
                        const decl = resolver.getReferencedImportDeclaration(name) || resolver.getReferencedValueDeclaration(name);
                        if (decl) {
                            multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(decl), specifier.name);
                        }
                        uniqueExports.set(idText(specifier.name), true);
                        exportedNames = append(exportedNames, specifier.name);
                    }
                }
            }
        }
        function collectExportedVariableInfo(decl, uniqueExports, exportedNames) {
            if (isBindingPattern(decl.name)) {
                for (const element of decl.name.elements) {
                    if (!isOmittedExpression(element)) {
                        exportedNames = collectExportedVariableInfo(element, uniqueExports, exportedNames);
                    }
                }
            }
            else if (!isGeneratedIdentifier(decl.name)) {
                const text = idText(decl.name);
                if (!uniqueExports.get(text)) {
                    uniqueExports.set(text, true);
                    exportedNames = append(exportedNames, decl.name);
                }
            }
            return exportedNames;
        }
        function multiMapSparseArrayAdd(map2, key, value) {
            let values = map2[key];
            if (values) {
                values.push(value);
            }
            else {
                map2[key] = values = [value];
            }
            return values;
        }
        function isSimpleCopiableExpression(expression) {
            return isStringLiteralLike(expression) || expression.kind === 8 /* NumericLiteral */ || isKeyword(expression.kind) || isIdentifier(expression);
        }
        function isSimpleInlineableExpression(expression) {
            return !isIdentifier(expression) && isSimpleCopiableExpression(expression);
        }
        function isCompoundAssignment(kind) {
            return kind >= 64 /* FirstCompoundAssignment */ && kind <= 78 /* LastCompoundAssignment */;
        }
        function getNonAssignmentOperatorForCompoundAssignment(kind) {
            switch (kind) {
                case 64 /* PlusEqualsToken */:
                    return 39 /* PlusToken */;
                case 65 /* MinusEqualsToken */:
                    return 40 /* MinusToken */;
                case 66 /* AsteriskEqualsToken */:
                    return 41 /* AsteriskToken */;
                case 67 /* AsteriskAsteriskEqualsToken */:
                    return 42 /* AsteriskAsteriskToken */;
                case 68 /* SlashEqualsToken */:
                    return 43 /* SlashToken */;
                case 69 /* PercentEqualsToken */:
                    return 44 /* PercentToken */;
                case 70 /* LessThanLessThanEqualsToken */:
                    return 47 /* LessThanLessThanToken */;
                case 71 /* GreaterThanGreaterThanEqualsToken */:
                    return 48 /* GreaterThanGreaterThanToken */;
                case 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                    return 49 /* GreaterThanGreaterThanGreaterThanToken */;
                case 73 /* AmpersandEqualsToken */:
                    return 50 /* AmpersandToken */;
                case 74 /* BarEqualsToken */:
                    return 51 /* BarToken */;
                case 78 /* CaretEqualsToken */:
                    return 52 /* CaretToken */;
                case 75 /* BarBarEqualsToken */:
                    return 56 /* BarBarToken */;
                case 76 /* AmpersandAmpersandEqualsToken */:
                    return 55 /* AmpersandAmpersandToken */;
                case 77 /* QuestionQuestionEqualsToken */:
                    return 60 /* QuestionQuestionToken */;
            }
        }
        function getSuperCallFromStatement(statement) {
            if (!isExpressionStatement(statement)) {
                return void 0;
            }
            const expression = skipParentheses(statement.expression);
            return isSuperCall(expression) ? expression : void 0;
        }
        function findSuperStatementIndex(statements, indexAfterLastPrologueStatement) {
            for (let i = indexAfterLastPrologueStatement; i < statements.length; i += 1) {
                const statement = statements[i];
                if (getSuperCallFromStatement(statement)) {
                    return i;
                }
            }
            return -1;
        }
        function getProperties(node, requireInitializer, isStatic2) {
            return filter(node.members, (m) => isInitializedOrStaticProperty(m, requireInitializer, isStatic2));
        }
        function isStaticPropertyDeclarationOrClassStaticBlockDeclaration(element) {
            return isStaticPropertyDeclaration(element) || isClassStaticBlockDeclaration(element);
        }
        function getStaticPropertiesAndClassStaticBlock(node) {
            return filter(node.members, isStaticPropertyDeclarationOrClassStaticBlockDeclaration);
        }
        function isInitializedOrStaticProperty(member, requireInitializer, isStatic2) {
            return isPropertyDeclaration(member) && (!!member.initializer || !requireInitializer) && hasStaticModifier(member) === isStatic2;
        }
        function isStaticPropertyDeclaration(member) {
            return isPropertyDeclaration(member) && hasStaticModifier(member);
        }
        function isInitializedProperty(member) {
            return member.kind === 169 /* PropertyDeclaration */ && member.initializer !== void 0;
        }
        function isNonStaticMethodOrAccessorWithPrivateName(member) {
            return !isStatic(member) && (isMethodOrAccessor(member) || isAutoAccessorPropertyDeclaration(member)) && isPrivateIdentifier(member.name);
        }
        function getDecoratorsOfParameters(node) {
            let decorators;
            if (node) {
                const parameters = node.parameters;
                const firstParameterIsThis = parameters.length > 0 && parameterIsThisKeyword(parameters[0]);
                const firstParameterOffset = firstParameterIsThis ? 1 : 0;
                const numParameters = firstParameterIsThis ? parameters.length - 1 : parameters.length;
                for (let i = 0; i < numParameters; i++) {
                    const parameter = parameters[i + firstParameterOffset];
                    if (decorators || hasDecorators(parameter)) {
                        if (!decorators) {
                            decorators = new Array(numParameters);
                        }
                        decorators[i] = getDecorators(parameter);
                    }
                }
            }
            return decorators;
        }
        function getAllDecoratorsOfClass(node) {
            const decorators = getDecorators(node);
            const parameters = getDecoratorsOfParameters(getFirstConstructorWithBody(node));
            if (!some(decorators) && !some(parameters)) {
                return void 0;
            }
            return {
                decorators,
                parameters
            };
        }
        function getAllDecoratorsOfClassElement(member, parent2, useLegacyDecorators) {
            switch (member.kind) {
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    if (!useLegacyDecorators) {
                        return getAllDecoratorsOfMethod(member);
                    }
                    return getAllDecoratorsOfAccessors(member, parent2);
                case 171 /* MethodDeclaration */:
                    return getAllDecoratorsOfMethod(member);
                case 169 /* PropertyDeclaration */:
                    return getAllDecoratorsOfProperty(member);
                default:
                    return void 0;
            }
        }
        function getAllDecoratorsOfAccessors(accessor, parent2) {
            if (!accessor.body) {
                return void 0;
            }
            const { firstAccessor, secondAccessor, getAccessor, setAccessor } = getAllAccessorDeclarations(parent2.members, accessor);
            const firstAccessorWithDecorators = hasDecorators(firstAccessor) ? firstAccessor : secondAccessor && hasDecorators(secondAccessor) ? secondAccessor : void 0;
            if (!firstAccessorWithDecorators || accessor !== firstAccessorWithDecorators) {
                return void 0;
            }
            const decorators = getDecorators(firstAccessorWithDecorators);
            const parameters = getDecoratorsOfParameters(setAccessor);
            if (!some(decorators) && !some(parameters)) {
                return void 0;
            }
            return {
                decorators,
                parameters,
                getDecorators: getAccessor && getDecorators(getAccessor),
                setDecorators: setAccessor && getDecorators(setAccessor)
            };
        }
        function getAllDecoratorsOfMethod(method) {
            if (!method.body) {
                return void 0;
            }
            const decorators = getDecorators(method);
            const parameters = getDecoratorsOfParameters(method);
            if (!some(decorators) && !some(parameters)) {
                return void 0;
            }
            return { decorators, parameters };
        }
        function getAllDecoratorsOfProperty(property) {
            const decorators = getDecorators(property);
            if (!some(decorators)) {
                return void 0;
            }
            return { decorators };
        }
        function walkUpLexicalEnvironments(env, cb) {
            while (env) {
                const result = cb(env);
                if (result !== void 0)
                    return result;
                env = env.previous;
            }
        }
        function newPrivateEnvironment(data) {
            return { data };
        }
        function getPrivateIdentifier(privateEnv, name) {
            var _a2, _b;
            return isGeneratedPrivateIdentifier(name) ? (_a2 = privateEnv == null ? void 0 : privateEnv.generatedIdentifiers) == null ? void 0 : _a2.get(getNodeForGeneratedName(name)) : (_b = privateEnv == null ? void 0 : privateEnv.identifiers) == null ? void 0 : _b.get(name.escapedText);
        }
        function setPrivateIdentifier(privateEnv, name, entry) {
            var _a2, _b;
            if (isGeneratedPrivateIdentifier(name)) {
                (_a2 = privateEnv.generatedIdentifiers) != null ? _a2 : privateEnv.generatedIdentifiers = /* @__PURE__ */ new Map();
                privateEnv.generatedIdentifiers.set(getNodeForGeneratedName(name), entry);
            }
            else {
                (_b = privateEnv.identifiers) != null ? _b : privateEnv.identifiers = /* @__PURE__ */ new Map();
                privateEnv.identifiers.set(name.escapedText, entry);
            }
        }
        function accessPrivateIdentifier(env, name) {
            return walkUpLexicalEnvironments(env, (env2) => getPrivateIdentifier(env2.privateEnv, name));
        }
        var init_utilities3 = __esm({
            "src/compiler/transformers/utilities.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/destructuring.ts
        function flattenDestructuringAssignment(node, visitor, context, level, needsValue, createAssignmentCallback) {
            let location = node;
            let value;
            if (isDestructuringAssignment(node)) {
                value = node.right;
                while (isEmptyArrayLiteral(node.left) || isEmptyObjectLiteral(node.left)) {
                    if (isDestructuringAssignment(value)) {
                        location = node = value;
                        value = node.right;
                    }
                    else {
                        return Debug.checkDefined(visitNode(value, visitor, isExpression));
                    }
                }
            }
            let expressions;
            const flattenContext = {
                context,
                level,
                downlevelIteration: !!context.getCompilerOptions().downlevelIteration,
                hoistTempVariables: true,
                emitExpression,
                emitBindingOrAssignment,
                createArrayBindingOrAssignmentPattern: (elements) => makeArrayAssignmentPattern(context.factory, elements),
                createObjectBindingOrAssignmentPattern: (elements) => makeObjectAssignmentPattern(context.factory, elements),
                createArrayBindingOrAssignmentElement: makeAssignmentElement,
                visitor
            };
            if (value) {
                value = visitNode(value, visitor, isExpression);
                Debug.assert(value);
                if (isIdentifier(value) && bindingOrAssignmentElementAssignsToName(node, value.escapedText) || bindingOrAssignmentElementContainsNonLiteralComputedName(node)) {
                    value = ensureIdentifier(flattenContext, value, 
                    /*reuseIdentifierExpressions*/
                    false, location);
                }
                else if (needsValue) {
                    value = ensureIdentifier(flattenContext, value, 
                    /*reuseIdentifierExpressions*/
                    true, location);
                }
                else if (nodeIsSynthesized(node)) {
                    location = value;
                }
            }
            flattenBindingOrAssignmentElement(flattenContext, node, value, location, 
            /*skipInitializer*/
            isDestructuringAssignment(node));
            if (value && needsValue) {
                if (!some(expressions)) {
                    return value;
                }
                expressions.push(value);
            }
            return context.factory.inlineExpressions(expressions) || context.factory.createOmittedExpression();
            function emitExpression(expression) {
                expressions = append(expressions, expression);
            }
            function emitBindingOrAssignment(target, value2, location2, original) {
                Debug.assertNode(target, createAssignmentCallback ? isIdentifier : isExpression);
                const expression = createAssignmentCallback ? createAssignmentCallback(target, value2, location2) : setTextRange(context.factory.createAssignment(Debug.checkDefined(visitNode(target, visitor, isExpression)), value2), location2);
                expression.original = original;
                emitExpression(expression);
            }
        }
        function bindingOrAssignmentElementAssignsToName(element, escapedName) {
            const target = getTargetOfBindingOrAssignmentElement(element);
            if (isBindingOrAssignmentPattern(target)) {
                return bindingOrAssignmentPatternAssignsToName(target, escapedName);
            }
            else if (isIdentifier(target)) {
                return target.escapedText === escapedName;
            }
            return false;
        }
        function bindingOrAssignmentPatternAssignsToName(pattern, escapedName) {
            const elements = getElementsOfBindingOrAssignmentPattern(pattern);
            for (const element of elements) {
                if (bindingOrAssignmentElementAssignsToName(element, escapedName)) {
                    return true;
                }
            }
            return false;
        }
        function bindingOrAssignmentElementContainsNonLiteralComputedName(element) {
            const propertyName = tryGetPropertyNameOfBindingOrAssignmentElement(element);
            if (propertyName && isComputedPropertyName(propertyName) && !isLiteralExpression(propertyName.expression)) {
                return true;
            }
            const target = getTargetOfBindingOrAssignmentElement(element);
            return !!target && isBindingOrAssignmentPattern(target) && bindingOrAssignmentPatternContainsNonLiteralComputedName(target);
        }
        function bindingOrAssignmentPatternContainsNonLiteralComputedName(pattern) {
            return !!forEach(getElementsOfBindingOrAssignmentPattern(pattern), bindingOrAssignmentElementContainsNonLiteralComputedName);
        }
        function flattenDestructuringBinding(node, visitor, context, level, rval, hoistTempVariables = false, skipInitializer) {
            let pendingExpressions;
            const pendingDeclarations = [];
            const declarations = [];
            const flattenContext = {
                context,
                level,
                downlevelIteration: !!context.getCompilerOptions().downlevelIteration,
                hoistTempVariables,
                emitExpression,
                emitBindingOrAssignment,
                createArrayBindingOrAssignmentPattern: (elements) => makeArrayBindingPattern(context.factory, elements),
                createObjectBindingOrAssignmentPattern: (elements) => makeObjectBindingPattern(context.factory, elements),
                createArrayBindingOrAssignmentElement: (name) => makeBindingElement(context.factory, name),
                visitor
            };
            if (isVariableDeclaration(node)) {
                let initializer = getInitializerOfBindingOrAssignmentElement(node);
                if (initializer && (isIdentifier(initializer) && bindingOrAssignmentElementAssignsToName(node, initializer.escapedText) || bindingOrAssignmentElementContainsNonLiteralComputedName(node))) {
                    initializer = ensureIdentifier(flattenContext, Debug.checkDefined(visitNode(initializer, flattenContext.visitor, isExpression)), 
                    /*reuseIdentifierExpressions*/
                    false, initializer);
                    node = context.factory.updateVariableDeclaration(node, node.name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer);
                }
            }
            flattenBindingOrAssignmentElement(flattenContext, node, rval, node, skipInitializer);
            if (pendingExpressions) {
                const temp = context.factory.createTempVariable(
                /*recordTempVariable*/
                void 0);
                if (hoistTempVariables) {
                    const value = context.factory.inlineExpressions(pendingExpressions);
                    pendingExpressions = void 0;
                    emitBindingOrAssignment(temp, value, 
                    /*location*/
                    void 0, 
                    /*original*/
                    void 0);
                }
                else {
                    context.hoistVariableDeclaration(temp);
                    const pendingDeclaration = last(pendingDeclarations);
                    pendingDeclaration.pendingExpressions = append(pendingDeclaration.pendingExpressions, context.factory.createAssignment(temp, pendingDeclaration.value));
                    addRange(pendingDeclaration.pendingExpressions, pendingExpressions);
                    pendingDeclaration.value = temp;
                }
            }
            for (const { pendingExpressions: pendingExpressions2, name, value, location, original } of pendingDeclarations) {
                const variable = context.factory.createVariableDeclaration(name, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, pendingExpressions2 ? context.factory.inlineExpressions(append(pendingExpressions2, value)) : value);
                variable.original = original;
                setTextRange(variable, location);
                declarations.push(variable);
            }
            return declarations;
            function emitExpression(value) {
                pendingExpressions = append(pendingExpressions, value);
            }
            function emitBindingOrAssignment(target, value, location, original) {
                Debug.assertNode(target, isBindingName);
                if (pendingExpressions) {
                    value = context.factory.inlineExpressions(append(pendingExpressions, value));
                    pendingExpressions = void 0;
                }
                pendingDeclarations.push({ pendingExpressions, name: target, value, location, original });
            }
        }
        function flattenBindingOrAssignmentElement(flattenContext, element, value, location, skipInitializer) {
            const bindingTarget = getTargetOfBindingOrAssignmentElement(element);
            if (!skipInitializer) {
                const initializer = visitNode(getInitializerOfBindingOrAssignmentElement(element), flattenContext.visitor, isExpression);
                if (initializer) {
                    if (value) {
                        value = createDefaultValueCheck(flattenContext, value, initializer, location);
                        if (!isSimpleInlineableExpression(initializer) && isBindingOrAssignmentPattern(bindingTarget)) {
                            value = ensureIdentifier(flattenContext, value, 
                            /*reuseIdentifierExpressions*/
                            true, location);
                        }
                    }
                    else {
                        value = initializer;
                    }
                }
                else if (!value) {
                    value = flattenContext.context.factory.createVoidZero();
                }
            }
            if (isObjectBindingOrAssignmentPattern(bindingTarget)) {
                flattenObjectBindingOrAssignmentPattern(flattenContext, element, bindingTarget, value, location);
            }
            else if (isArrayBindingOrAssignmentPattern(bindingTarget)) {
                flattenArrayBindingOrAssignmentPattern(flattenContext, element, bindingTarget, value, location);
            }
            else {
                flattenContext.emitBindingOrAssignment(bindingTarget, value, location, 
                /*original*/
                element);
            }
        }
        function flattenObjectBindingOrAssignmentPattern(flattenContext, parent2, pattern, value, location) {
            const elements = getElementsOfBindingOrAssignmentPattern(pattern);
            const numElements = elements.length;
            if (numElements !== 1) {
                const reuseIdentifierExpressions = !isDeclarationBindingElement(parent2) || numElements !== 0;
                value = ensureIdentifier(flattenContext, value, reuseIdentifierExpressions, location);
            }
            let bindingElements;
            let computedTempVariables;
            for (let i = 0; i < numElements; i++) {
                const element = elements[i];
                if (!getRestIndicatorOfBindingOrAssignmentElement(element)) {
                    const propertyName = getPropertyNameOfBindingOrAssignmentElement(element);
                    if (flattenContext.level >= 1 /* ObjectRest */ && !(element.transformFlags & (32768 /* ContainsRestOrSpread */ | 65536 /* ContainsObjectRestOrSpread */)) && !(getTargetOfBindingOrAssignmentElement(element).transformFlags & (32768 /* ContainsRestOrSpread */ | 65536 /* ContainsObjectRestOrSpread */)) && !isComputedPropertyName(propertyName)) {
                        bindingElements = append(bindingElements, visitNode(element, flattenContext.visitor, isBindingOrAssignmentElement));
                    }
                    else {
                        if (bindingElements) {
                            flattenContext.emitBindingOrAssignment(flattenContext.createObjectBindingOrAssignmentPattern(bindingElements), value, location, pattern);
                            bindingElements = void 0;
                        }
                        const rhsValue = createDestructuringPropertyAccess(flattenContext, value, propertyName);
                        if (isComputedPropertyName(propertyName)) {
                            computedTempVariables = append(computedTempVariables, rhsValue.argumentExpression);
                        }
                        flattenBindingOrAssignmentElement(flattenContext, element, rhsValue, 
                        /*location*/
                        element);
                    }
                }
                else if (i === numElements - 1) {
                    if (bindingElements) {
                        flattenContext.emitBindingOrAssignment(flattenContext.createObjectBindingOrAssignmentPattern(bindingElements), value, location, pattern);
                        bindingElements = void 0;
                    }
                    const rhsValue = flattenContext.context.getEmitHelperFactory().createRestHelper(value, elements, computedTempVariables, pattern);
                    flattenBindingOrAssignmentElement(flattenContext, element, rhsValue, element);
                }
            }
            if (bindingElements) {
                flattenContext.emitBindingOrAssignment(flattenContext.createObjectBindingOrAssignmentPattern(bindingElements), value, location, pattern);
            }
        }
        function flattenArrayBindingOrAssignmentPattern(flattenContext, parent2, pattern, value, location) {
            const elements = getElementsOfBindingOrAssignmentPattern(pattern);
            const numElements = elements.length;
            if (flattenContext.level < 1 /* ObjectRest */ && flattenContext.downlevelIteration) {
                value = ensureIdentifier(flattenContext, setTextRange(flattenContext.context.getEmitHelperFactory().createReadHelper(value, numElements > 0 && getRestIndicatorOfBindingOrAssignmentElement(elements[numElements - 1]) ? void 0 : numElements), location), 
                /*reuseIdentifierExpressions*/
                false, location);
            }
            else if (numElements !== 1 && (flattenContext.level < 1 /* ObjectRest */ || numElements === 0) || every(elements, isOmittedExpression)) {
                const reuseIdentifierExpressions = !isDeclarationBindingElement(parent2) || numElements !== 0;
                value = ensureIdentifier(flattenContext, value, reuseIdentifierExpressions, location);
            }
            let bindingElements;
            let restContainingElements;
            for (let i = 0; i < numElements; i++) {
                const element = elements[i];
                if (flattenContext.level >= 1 /* ObjectRest */) {
                    if (element.transformFlags & 65536 /* ContainsObjectRestOrSpread */ || flattenContext.hasTransformedPriorElement && !isSimpleBindingOrAssignmentElement(element)) {
                        flattenContext.hasTransformedPriorElement = true;
                        const temp = flattenContext.context.factory.createTempVariable(
                        /*recordTempVariable*/
                        void 0);
                        if (flattenContext.hoistTempVariables) {
                            flattenContext.context.hoistVariableDeclaration(temp);
                        }
                        restContainingElements = append(restContainingElements, [temp, element]);
                        bindingElements = append(bindingElements, flattenContext.createArrayBindingOrAssignmentElement(temp));
                    }
                    else {
                        bindingElements = append(bindingElements, element);
                    }
                }
                else if (isOmittedExpression(element)) {
                    continue;
                }
                else if (!getRestIndicatorOfBindingOrAssignmentElement(element)) {
                    const rhsValue = flattenContext.context.factory.createElementAccessExpression(value, i);
                    flattenBindingOrAssignmentElement(flattenContext, element, rhsValue, 
                    /*location*/
                    element);
                }
                else if (i === numElements - 1) {
                    const rhsValue = flattenContext.context.factory.createArraySliceCall(value, i);
                    flattenBindingOrAssignmentElement(flattenContext, element, rhsValue, 
                    /*location*/
                    element);
                }
            }
            if (bindingElements) {
                flattenContext.emitBindingOrAssignment(flattenContext.createArrayBindingOrAssignmentPattern(bindingElements), value, location, pattern);
            }
            if (restContainingElements) {
                for (const [id, element] of restContainingElements) {
                    flattenBindingOrAssignmentElement(flattenContext, element, id, element);
                }
            }
        }
        function isSimpleBindingOrAssignmentElement(element) {
            const target = getTargetOfBindingOrAssignmentElement(element);
            if (!target || isOmittedExpression(target))
                return true;
            const propertyName = tryGetPropertyNameOfBindingOrAssignmentElement(element);
            if (propertyName && !isPropertyNameLiteral(propertyName))
                return false;
            const initializer = getInitializerOfBindingOrAssignmentElement(element);
            if (initializer && !isSimpleInlineableExpression(initializer))
                return false;
            if (isBindingOrAssignmentPattern(target))
                return every(getElementsOfBindingOrAssignmentPattern(target), isSimpleBindingOrAssignmentElement);
            return isIdentifier(target);
        }
        function createDefaultValueCheck(flattenContext, value, defaultValue, location) {
            value = ensureIdentifier(flattenContext, value, 
            /*reuseIdentifierExpressions*/
            true, location);
            return flattenContext.context.factory.createConditionalExpression(flattenContext.context.factory.createTypeCheck(value, "undefined"), 
            /*questionToken*/
            void 0, defaultValue, 
            /*colonToken*/
            void 0, value);
        }
        function createDestructuringPropertyAccess(flattenContext, value, propertyName) {
            if (isComputedPropertyName(propertyName)) {
                const argumentExpression = ensureIdentifier(flattenContext, Debug.checkDefined(visitNode(propertyName.expression, flattenContext.visitor, isExpression)), 
                /*reuseIdentifierExpressions*/
                false, 
                /*location*/
                propertyName);
                return flattenContext.context.factory.createElementAccessExpression(value, argumentExpression);
            }
            else if (isStringOrNumericLiteralLike(propertyName)) {
                const argumentExpression = factory.cloneNode(propertyName);
                return flattenContext.context.factory.createElementAccessExpression(value, argumentExpression);
            }
            else {
                const name = flattenContext.context.factory.createIdentifier(idText(propertyName));
                return flattenContext.context.factory.createPropertyAccessExpression(value, name);
            }
        }
        function ensureIdentifier(flattenContext, value, reuseIdentifierExpressions, location) {
            if (isIdentifier(value) && reuseIdentifierExpressions) {
                return value;
            }
            else {
                const temp = flattenContext.context.factory.createTempVariable(
                /*recordTempVariable*/
                void 0);
                if (flattenContext.hoistTempVariables) {
                    flattenContext.context.hoistVariableDeclaration(temp);
                    flattenContext.emitExpression(setTextRange(flattenContext.context.factory.createAssignment(temp, value), location));
                }
                else {
                    flattenContext.emitBindingOrAssignment(temp, value, location, 
                    /*original*/
                    void 0);
                }
                return temp;
            }
        }
        function makeArrayBindingPattern(factory2, elements) {
            Debug.assertEachNode(elements, isArrayBindingElement);
            return factory2.createArrayBindingPattern(elements);
        }
        function makeArrayAssignmentPattern(factory2, elements) {
            Debug.assertEachNode(elements, isArrayBindingOrAssignmentElement);
            return factory2.createArrayLiteralExpression(map(elements, factory2.converters.convertToArrayAssignmentElement));
        }
        function makeObjectBindingPattern(factory2, elements) {
            Debug.assertEachNode(elements, isBindingElement);
            return factory2.createObjectBindingPattern(elements);
        }
        function makeObjectAssignmentPattern(factory2, elements) {
            Debug.assertEachNode(elements, isObjectBindingOrAssignmentElement);
            return factory2.createObjectLiteralExpression(map(elements, factory2.converters.convertToObjectAssignmentElement));
        }
        function makeBindingElement(factory2, name) {
            return factory2.createBindingElement(
            /*dotDotDotToken*/
            void 0, 
            /*propertyName*/
            void 0, name);
        }
        function makeAssignmentElement(name) {
            return name;
        }
        var FlattenLevel;
        var init_destructuring = __esm({
            "src/compiler/transformers/destructuring.ts"() {
                "use strict";
                init_ts2();
                FlattenLevel = /* @__PURE__ */ ((FlattenLevel2) => {
                    FlattenLevel2[FlattenLevel2["All"] = 0] = "All";
                    FlattenLevel2[FlattenLevel2["ObjectRest"] = 1] = "ObjectRest";
                    return FlattenLevel2;
                })(FlattenLevel || {});
            }
        });
        // src/compiler/transformers/taggedTemplate.ts
        function processTaggedTemplateExpression(context, node, visitor, currentSourceFile, recordTaggedTemplateString, level) {
            const tag = visitNode(node.tag, visitor, isExpression);
            Debug.assert(tag);
            const templateArguments = [void 0];
            const cookedStrings = [];
            const rawStrings = [];
            const template = node.template;
            if (level === 0 /* LiftRestriction */ && !hasInvalidEscape(template)) {
                return visitEachChild(node, visitor, context);
            }
            if (isNoSubstitutionTemplateLiteral(template)) {
                cookedStrings.push(createTemplateCooked(template));
                rawStrings.push(getRawLiteral(template, currentSourceFile));
            }
            else {
                cookedStrings.push(createTemplateCooked(template.head));
                rawStrings.push(getRawLiteral(template.head, currentSourceFile));
                for (const templateSpan of template.templateSpans) {
                    cookedStrings.push(createTemplateCooked(templateSpan.literal));
                    rawStrings.push(getRawLiteral(templateSpan.literal, currentSourceFile));
                    templateArguments.push(Debug.checkDefined(visitNode(templateSpan.expression, visitor, isExpression)));
                }
            }
            const helperCall = context.getEmitHelperFactory().createTemplateObjectHelper(factory.createArrayLiteralExpression(cookedStrings), factory.createArrayLiteralExpression(rawStrings));
            if (isExternalModule(currentSourceFile)) {
                const tempVar = factory.createUniqueName("templateObject");
                recordTaggedTemplateString(tempVar);
                templateArguments[0] = factory.createLogicalOr(tempVar, factory.createAssignment(tempVar, helperCall));
            }
            else {
                templateArguments[0] = helperCall;
            }
            return factory.createCallExpression(tag, 
            /*typeArguments*/
            void 0, templateArguments);
        }
        function createTemplateCooked(template) {
            return template.templateFlags ? factory.createVoidZero() : factory.createStringLiteral(template.text);
        }
        function getRawLiteral(node, currentSourceFile) {
            let text = node.rawText;
            if (text === void 0) {
                Debug.assertIsDefined(currentSourceFile, "Template literal node is missing 'rawText' and does not have a source file. Possibly bad transform.");
                text = getSourceTextOfNodeFromSourceFile(currentSourceFile, node);
                const isLast = node.kind === 14 /* NoSubstitutionTemplateLiteral */ || node.kind === 17 /* TemplateTail */;
                text = text.substring(1, text.length - (isLast ? 1 : 2));
            }
            text = text.replace(/\r\n?/g, "\n");
            return setTextRange(factory.createStringLiteral(text), node);
        }
        var ProcessLevel;
        var init_taggedTemplate = __esm({
            "src/compiler/transformers/taggedTemplate.ts"() {
                "use strict";
                init_ts2();
                ProcessLevel = /* @__PURE__ */ ((ProcessLevel2) => {
                    ProcessLevel2[ProcessLevel2["LiftRestriction"] = 0] = "LiftRestriction";
                    ProcessLevel2[ProcessLevel2["All"] = 1] = "All";
                    return ProcessLevel2;
                })(ProcessLevel || {});
            }
        });
        // src/compiler/transformers/ts.ts
        function transformTypeScript(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, startLexicalEnvironment, resumeLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const moduleKind = getEmitModuleKind(compilerOptions);
            const legacyDecorators = !!compilerOptions.experimentalDecorators;
            const typeSerializer = compilerOptions.emitDecoratorMetadata ? createRuntimeTypeSerializer(context) : void 0;
            const previousOnEmitNode = context.onEmitNode;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.enableSubstitution(208 /* PropertyAccessExpression */);
            context.enableSubstitution(209 /* ElementAccessExpression */);
            let currentSourceFile;
            let currentNamespace;
            let currentNamespaceContainerName;
            let currentLexicalScope;
            let currentScopeFirstDeclarationsOfName;
            let currentClassHasParameterProperties;
            let enabledSubstitutions;
            let applicableSubstitutions;
            return transformSourceFileOrBundle;
            function transformSourceFileOrBundle(node) {
                if (node.kind === 309 /* Bundle */) {
                    return transformBundle(node);
                }
                return transformSourceFile(node);
            }
            function transformBundle(node) {
                return factory2.createBundle(node.sourceFiles.map(transformSourceFile), mapDefined(node.prepends, (prepend) => {
                    if (prepend.kind === 311 /* InputFiles */) {
                        return createUnparsedSourceFile(prepend, "js");
                    }
                    return prepend;
                }));
            }
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                const visited = saveStateAndInvoke(node, visitSourceFile);
                addEmitHelpers(visited, context.readEmitHelpers());
                currentSourceFile = void 0;
                return visited;
            }
            function saveStateAndInvoke(node, f) {
                const savedCurrentScope = currentLexicalScope;
                const savedCurrentScopeFirstDeclarationsOfName = currentScopeFirstDeclarationsOfName;
                const savedCurrentClassHasParameterProperties = currentClassHasParameterProperties;
                onBeforeVisitNode(node);
                const visited = f(node);
                if (currentLexicalScope !== savedCurrentScope) {
                    currentScopeFirstDeclarationsOfName = savedCurrentScopeFirstDeclarationsOfName;
                }
                currentLexicalScope = savedCurrentScope;
                currentClassHasParameterProperties = savedCurrentClassHasParameterProperties;
                return visited;
            }
            function onBeforeVisitNode(node) {
                switch (node.kind) {
                    case 308 /* SourceFile */:
                    case 266 /* CaseBlock */:
                    case 265 /* ModuleBlock */:
                    case 238 /* Block */:
                        currentLexicalScope = node;
                        currentScopeFirstDeclarationsOfName = void 0;
                        break;
                    case 260 /* ClassDeclaration */:
                    case 259 /* FunctionDeclaration */:
                        if (hasSyntacticModifier(node, 2 /* Ambient */)) {
                            break;
                        }
                        if (node.name) {
                            recordEmittedDeclarationInScope(node);
                        }
                        else {
                            Debug.assert(node.kind === 260 /* ClassDeclaration */ || hasSyntacticModifier(node, 1024 /* Default */));
                        }
                        break;
                }
            }
            function visitor(node) {
                return saveStateAndInvoke(node, visitorWorker);
            }
            function visitorWorker(node) {
                if (node.transformFlags & 1 /* ContainsTypeScript */) {
                    return visitTypeScript(node);
                }
                return node;
            }
            function sourceElementVisitor(node) {
                return saveStateAndInvoke(node, sourceElementVisitorWorker);
            }
            function sourceElementVisitorWorker(node) {
                switch (node.kind) {
                    case 269 /* ImportDeclaration */:
                    case 268 /* ImportEqualsDeclaration */:
                    case 274 /* ExportAssignment */:
                    case 275 /* ExportDeclaration */:
                        return visitElidableStatement(node);
                    default:
                        return visitorWorker(node);
                }
            }
            function visitElidableStatement(node) {
                const parsed = getParseTreeNode(node);
                if (parsed !== node) {
                    if (node.transformFlags & 1 /* ContainsTypeScript */) {
                        return visitEachChild(node, visitor, context);
                    }
                    return node;
                }
                switch (node.kind) {
                    case 269 /* ImportDeclaration */:
                        return visitImportDeclaration(node);
                    case 268 /* ImportEqualsDeclaration */:
                        return visitImportEqualsDeclaration(node);
                    case 274 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    case 275 /* ExportDeclaration */:
                        return visitExportDeclaration(node);
                    default:
                        Debug.fail("Unhandled ellided statement");
                }
            }
            function namespaceElementVisitor(node) {
                return saveStateAndInvoke(node, namespaceElementVisitorWorker);
            }
            function namespaceElementVisitorWorker(node) {
                if (node.kind === 275 /* ExportDeclaration */ || node.kind === 269 /* ImportDeclaration */ || node.kind === 270 /* ImportClause */ || node.kind === 268 /* ImportEqualsDeclaration */ && node.moduleReference.kind === 280 /* ExternalModuleReference */) {
                    return void 0;
                }
                else if (node.transformFlags & 1 /* ContainsTypeScript */ || hasSyntacticModifier(node, 1 /* Export */)) {
                    return visitTypeScript(node);
                }
                return node;
            }
            function getClassElementVisitor(parent2) {
                return (node) => saveStateAndInvoke(node, (n) => classElementVisitorWorker(n, parent2));
            }
            function classElementVisitorWorker(node, parent2) {
                switch (node.kind) {
                    case 173 /* Constructor */:
                        return visitConstructor(node);
                    case 169 /* PropertyDeclaration */:
                        return visitPropertyDeclaration(node, parent2);
                    case 174 /* GetAccessor */:
                        return visitGetAccessor(node, parent2);
                    case 175 /* SetAccessor */:
                        return visitSetAccessor(node, parent2);
                    case 171 /* MethodDeclaration */:
                        return visitMethodDeclaration(node, parent2);
                    case 172 /* ClassStaticBlockDeclaration */:
                        return visitEachChild(node, visitor, context);
                    case 237 /* SemicolonClassElement */:
                        return node;
                    case 178 /* IndexSignature */:
                        return;
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function getObjectLiteralElementVisitor(parent2) {
                return (node) => saveStateAndInvoke(node, (n) => objectLiteralElementVisitorWorker(n, parent2));
            }
            function objectLiteralElementVisitorWorker(node, parent2) {
                switch (node.kind) {
                    case 299 /* PropertyAssignment */:
                    case 300 /* ShorthandPropertyAssignment */:
                    case 301 /* SpreadAssignment */:
                        return visitor(node);
                    case 174 /* GetAccessor */:
                        return visitGetAccessor(node, parent2);
                    case 175 /* SetAccessor */:
                        return visitSetAccessor(node, parent2);
                    case 171 /* MethodDeclaration */:
                        return visitMethodDeclaration(node, parent2);
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function decoratorElidingVisitor(node) {
                return isDecorator(node) ? void 0 : visitor(node);
            }
            function modifierElidingVisitor(node) {
                return isModifier(node) ? void 0 : visitor(node);
            }
            function modifierVisitor(node) {
                if (isDecorator(node))
                    return void 0;
                if (modifierToFlag(node.kind) & 117086 /* TypeScriptModifier */) {
                    return void 0;
                }
                else if (currentNamespace && node.kind === 93 /* ExportKeyword */) {
                    return void 0;
                }
                return node;
            }
            function visitTypeScript(node) {
                if (isStatement(node) && hasSyntacticModifier(node, 2 /* Ambient */)) {
                    return factory2.createNotEmittedStatement(node);
                }
                switch (node.kind) {
                    case 93 /* ExportKeyword */:
                    case 88 /* DefaultKeyword */:
                        return currentNamespace ? void 0 : node;
                    case 123 /* PublicKeyword */:
                    case 121 /* PrivateKeyword */:
                    case 122 /* ProtectedKeyword */:
                    case 126 /* AbstractKeyword */:
                    case 161 /* OverrideKeyword */:
                    case 85 /* ConstKeyword */:
                    case 136 /* DeclareKeyword */:
                    case 146 /* ReadonlyKeyword */:
                    case 101 /* InKeyword */:
                    case 145 /* OutKeyword */:
                    case 185 /* ArrayType */:
                    case 186 /* TupleType */:
                    case 187 /* OptionalType */:
                    case 188 /* RestType */:
                    case 184 /* TypeLiteral */:
                    case 179 /* TypePredicate */:
                    case 165 /* TypeParameter */:
                    case 131 /* AnyKeyword */:
                    case 157 /* UnknownKeyword */:
                    case 134 /* BooleanKeyword */:
                    case 152 /* StringKeyword */:
                    case 148 /* NumberKeyword */:
                    case 144 /* NeverKeyword */:
                    case 114 /* VoidKeyword */:
                    case 153 /* SymbolKeyword */:
                    case 182 /* ConstructorType */:
                    case 181 /* FunctionType */:
                    case 183 /* TypeQuery */:
                    case 180 /* TypeReference */:
                    case 189 /* UnionType */:
                    case 190 /* IntersectionType */:
                    case 191 /* ConditionalType */:
                    case 193 /* ParenthesizedType */:
                    case 194 /* ThisType */:
                    case 195 /* TypeOperator */:
                    case 196 /* IndexedAccessType */:
                    case 197 /* MappedType */:
                    case 198 /* LiteralType */:
                    case 178 /* IndexSignature */:
                        return void 0;
                    case 262 /* TypeAliasDeclaration */:
                        return factory2.createNotEmittedStatement(node);
                    case 267 /* NamespaceExportDeclaration */:
                        return void 0;
                    case 261 /* InterfaceDeclaration */:
                        return factory2.createNotEmittedStatement(node);
                    case 260 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 228 /* ClassExpression */:
                        return visitClassExpression(node);
                    case 294 /* HeritageClause */:
                        return visitHeritageClause(node);
                    case 230 /* ExpressionWithTypeArguments */:
                        return visitExpressionWithTypeArguments(node);
                    case 207 /* ObjectLiteralExpression */:
                        return visitObjectLiteralExpression(node);
                    case 173 /* Constructor */:
                    case 169 /* PropertyDeclaration */:
                    case 171 /* MethodDeclaration */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 172 /* ClassStaticBlockDeclaration */:
                        return Debug.fail("Class and object literal elements must be visited with their respective visitors");
                    case 259 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 215 /* FunctionExpression */:
                        return visitFunctionExpression(node);
                    case 216 /* ArrowFunction */:
                        return visitArrowFunction(node);
                    case 166 /* Parameter */:
                        return visitParameter(node);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node);
                    case 213 /* TypeAssertionExpression */:
                    case 231 /* AsExpression */:
                        return visitAssertionExpression(node);
                    case 235 /* SatisfiesExpression */:
                        return visitSatisfiesExpression(node);
                    case 210 /* CallExpression */:
                        return visitCallExpression(node);
                    case 211 /* NewExpression */:
                        return visitNewExpression(node);
                    case 212 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 232 /* NonNullExpression */:
                        return visitNonNullExpression(node);
                    case 263 /* EnumDeclaration */:
                        return visitEnumDeclaration(node);
                    case 240 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 257 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 264 /* ModuleDeclaration */:
                        return visitModuleDeclaration(node);
                    case 268 /* ImportEqualsDeclaration */:
                        return visitImportEqualsDeclaration(node);
                    case 282 /* JsxSelfClosingElement */:
                        return visitJsxSelfClosingElement(node);
                    case 283 /* JsxOpeningElement */:
                        return visitJsxJsxOpeningElement(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitSourceFile(node) {
                const alwaysStrict = getStrictOptionValue(compilerOptions, "alwaysStrict") && !(isExternalModule(node) && moduleKind >= 5 /* ES2015 */) && !isJsonSourceFile(node);
                return factory2.updateSourceFile(node, visitLexicalEnvironment(node.statements, sourceElementVisitor, context, 
                /*start*/
                0, alwaysStrict));
            }
            function visitObjectLiteralExpression(node) {
                return factory2.updateObjectLiteralExpression(node, visitNodes2(node.properties, getObjectLiteralElementVisitor(node), isObjectLiteralElementLike));
            }
            function getClassFacts(node) {
                let facts = 0 /* None */;
                if (some(getProperties(node, 
                /*requireInitialized*/
                true, 
                /*isStatic*/
                true)))
                    facts |= 1 /* HasStaticInitializedProperties */;
                const extendsClauseElement = getEffectiveBaseTypeNode(node);
                if (extendsClauseElement && skipOuterExpressions(extendsClauseElement.expression).kind !== 104 /* NullKeyword */)
                    facts |= 64 /* IsDerivedClass */;
                if (classOrConstructorParameterIsDecorated(legacyDecorators, node))
                    facts |= 2 /* HasClassOrConstructorParameterDecorators */;
                if (childIsDecorated(legacyDecorators, node))
                    facts |= 4 /* HasMemberDecorators */;
                if (isExportOfNamespace(node))
                    facts |= 8 /* IsExportOfNamespace */;
                else if (isDefaultExternalModuleExport(node))
                    facts |= 32 /* IsDefaultExternalExport */;
                else if (isNamedExternalModuleExport(node))
                    facts |= 16 /* IsNamedExternalExport */;
                return facts;
            }
            function hasTypeScriptClassSyntax(node) {
                return !!(node.transformFlags & 8192 /* ContainsTypeScriptClassSyntax */);
            }
            function isClassLikeDeclarationWithTypeScriptSyntax(node) {
                return hasDecorators(node) || some(node.typeParameters) || some(node.heritageClauses, hasTypeScriptClassSyntax) || some(node.members, hasTypeScriptClassSyntax);
            }
            function visitClassDeclaration(node) {
                var _a2;
                const facts = getClassFacts(node);
                const promoteToIIFE = languageVersion <= 1 /* ES5 */ && !!(facts & 7 /* MayNeedImmediatelyInvokedFunctionExpression */);
                if (!isClassLikeDeclarationWithTypeScriptSyntax(node) && !classOrConstructorParameterIsDecorated(legacyDecorators, node) && !isExportOfNamespace(node)) {
                    return factory2.updateClassDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.name, 
                    /*typeParameters*/
                    void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), visitNodes2(node.members, getClassElementVisitor(node), isClassElement));
                }
                if (promoteToIIFE) {
                    context.startLexicalEnvironment();
                }
                const moveModifiers = promoteToIIFE || facts & 8 /* IsExportOfNamespace */ || facts & 2 /* HasClassOrConstructorParameterDecorators */ && legacyDecorators || facts & 1 /* HasStaticInitializedProperties */;
                let modifiers = moveModifiers ? visitNodes2(node.modifiers, modifierElidingVisitor, isModifierLike) : visitNodes2(node.modifiers, visitor, isModifierLike);
                if (facts & 2 /* HasClassOrConstructorParameterDecorators */) {
                    modifiers = injectClassTypeMetadata(modifiers, node);
                }
                const needsName = moveModifiers && !node.name || facts & 4 /* HasMemberDecorators */ || facts & 1 /* HasStaticInitializedProperties */;
                const name = needsName ? (_a2 = node.name) != null ? _a2 : factory2.getGeneratedNameForNode(node) : node.name;
                const classDeclaration = factory2.updateClassDeclaration(node, modifiers, name, 
                /*typeParameters*/
                void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), transformClassMembers(node));
                let emitFlags = getEmitFlags(node);
                if (facts & 1 /* HasStaticInitializedProperties */) {
                    emitFlags |= 64 /* NoTrailingSourceMap */;
                }
                setEmitFlags(classDeclaration, emitFlags);
                let statement;
                if (promoteToIIFE) {
                    const statements = [classDeclaration];
                    const closingBraceLocation = createTokenRange(skipTrivia(currentSourceFile.text, node.members.end), 19 /* CloseBraceToken */);
                    const localName = factory2.getInternalName(node);
                    const outer = factory2.createPartiallyEmittedExpression(localName);
                    setTextRangeEnd(outer, closingBraceLocation.end);
                    setEmitFlags(outer, 3072 /* NoComments */);
                    const returnStatement = factory2.createReturnStatement(outer);
                    setTextRangePos(returnStatement, closingBraceLocation.pos);
                    setEmitFlags(returnStatement, 3072 /* NoComments */ | 768 /* NoTokenSourceMaps */);
                    statements.push(returnStatement);
                    insertStatementsAfterStandardPrologue(statements, context.endLexicalEnvironment());
                    const iife = factory2.createImmediatelyInvokedArrowFunction(statements);
                    setInternalEmitFlags(iife, 1 /* TypeScriptClassWrapper */);
                    const modifiers2 = facts & 16 /* IsNamedExternalExport */ ? factory2.createModifiersFromModifierFlags(1 /* Export */) : void 0;
                    const varStatement = factory2.createVariableStatement(modifiers2, factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(factory2.getLocalName(node, 
                        /*allowComments*/
                        false, 
                        /*allowSourceMaps*/
                        false), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, iife)
                    ], 1 /* Let */));
                    setOriginalNode(varStatement, node);
                    setCommentRange(varStatement, node);
                    setSourceMapRange(varStatement, moveRangePastDecorators(node));
                    startOnNewLine(varStatement);
                    statement = varStatement;
                }
                else {
                    statement = classDeclaration;
                }
                if (moveModifiers) {
                    if (facts & 8 /* IsExportOfNamespace */) {
                        return demarcateMultiStatementExport(statement, createExportMemberAssignmentStatement(node));
                    }
                    if (facts & 32 /* IsDefaultExternalExport */) {
                        return demarcateMultiStatementExport(statement, factory2.createExportDefault(factory2.getLocalName(node, 
                        /*allowComments*/
                        false, 
                        /*allowSourceMaps*/
                        true)));
                    }
                    if (facts & 16 /* IsNamedExternalExport */ && !promoteToIIFE) {
                        return demarcateMultiStatementExport(statement, factory2.createExternalModuleExport(factory2.getLocalName(node, 
                        /*allowComments*/
                        false, 
                        /*allowSourceMaps*/
                        true)));
                    }
                }
                return statement;
            }
            function demarcateMultiStatementExport(declarationStatement, exportStatement) {
                addEmitFlags(declarationStatement, 8388608 /* HasEndOfDeclarationMarker */);
                return [
                    declarationStatement,
                    exportStatement,
                    factory2.createEndOfDeclarationMarker(declarationStatement)
                ];
            }
            function visitClassExpression(node) {
                let modifiers = visitNodes2(node.modifiers, modifierElidingVisitor, isModifierLike);
                if (classOrConstructorParameterIsDecorated(legacyDecorators, node)) {
                    modifiers = injectClassTypeMetadata(modifiers, node);
                }
                return factory2.updateClassExpression(node, modifiers, node.name, 
                /*typeParameters*/
                void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), transformClassMembers(node));
            }
            function transformClassMembers(node) {
                const members = visitNodes2(node.members, getClassElementVisitor(node), isClassElement);
                let newMembers;
                const constructor = getFirstConstructorWithBody(node);
                const parametersWithPropertyAssignments = constructor && filter(constructor.parameters, (p) => isParameterPropertyDeclaration(p, constructor));
                if (parametersWithPropertyAssignments) {
                    for (const parameter of parametersWithPropertyAssignments) {
                        const parameterProperty = factory2.createPropertyDeclaration(
                        /*modifiers*/
                        void 0, parameter.name, 
                        /*questionOrExclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0);
                        setOriginalNode(parameterProperty, parameter);
                        newMembers = append(newMembers, parameterProperty);
                    }
                }
                if (newMembers) {
                    newMembers = addRange(newMembers, members);
                    return setTextRange(factory2.createNodeArray(newMembers), 
                    /*location*/
                    node.members);
                }
                return members;
            }
            function injectClassTypeMetadata(modifiers, node) {
                const metadata = getTypeMetadata(node, node);
                if (some(metadata)) {
                    const modifiersArray = [];
                    addRange(modifiersArray, takeWhile(modifiers, isExportOrDefaultModifier));
                    addRange(modifiersArray, filter(modifiers, isDecorator));
                    addRange(modifiersArray, metadata);
                    addRange(modifiersArray, filter(skipWhile(modifiers, isExportOrDefaultModifier), isModifier));
                    modifiers = setTextRange(factory2.createNodeArray(modifiersArray), modifiers);
                }
                return modifiers;
            }
            function injectClassElementTypeMetadata(modifiers, node, container) {
                if (isClassLike(container) && classElementOrClassElementParameterIsDecorated(legacyDecorators, node, container)) {
                    const metadata = getTypeMetadata(node, container);
                    if (some(metadata)) {
                        const modifiersArray = [];
                        addRange(modifiersArray, filter(modifiers, isDecorator));
                        addRange(modifiersArray, metadata);
                        addRange(modifiersArray, filter(modifiers, isModifier));
                        modifiers = setTextRange(factory2.createNodeArray(modifiersArray), modifiers);
                    }
                }
                return modifiers;
            }
            function getTypeMetadata(node, container) {
                if (!legacyDecorators)
                    return void 0;
                return USE_NEW_TYPE_METADATA_FORMAT ? getNewTypeMetadata(node, container) : getOldTypeMetadata(node, container);
            }
            function getOldTypeMetadata(node, container) {
                if (typeSerializer) {
                    let decorators;
                    if (shouldAddTypeMetadata(node)) {
                        const typeMetadata = emitHelpers().createMetadataHelper("design:type", typeSerializer.serializeTypeOfNode({ currentLexicalScope, currentNameScope: container }, node));
                        decorators = append(decorators, factory2.createDecorator(typeMetadata));
                    }
                    if (shouldAddParamTypesMetadata(node)) {
                        const paramTypesMetadata = emitHelpers().createMetadataHelper("design:paramtypes", typeSerializer.serializeParameterTypesOfNode({ currentLexicalScope, currentNameScope: container }, node, container));
                        decorators = append(decorators, factory2.createDecorator(paramTypesMetadata));
                    }
                    if (shouldAddReturnTypeMetadata(node)) {
                        const returnTypeMetadata = emitHelpers().createMetadataHelper("design:returntype", typeSerializer.serializeReturnTypeOfNode({ currentLexicalScope, currentNameScope: container }, node));
                        decorators = append(decorators, factory2.createDecorator(returnTypeMetadata));
                    }
                    return decorators;
                }
            }
            function getNewTypeMetadata(node, container) {
                if (typeSerializer) {
                    let properties;
                    if (shouldAddTypeMetadata(node)) {
                        const typeProperty = factory2.createPropertyAssignment("type", factory2.createArrowFunction(
                        /*modifiers*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [], 
                        /*type*/
                        void 0, factory2.createToken(38 /* EqualsGreaterThanToken */), typeSerializer.serializeTypeOfNode({ currentLexicalScope, currentNameScope: container }, node)));
                        properties = append(properties, typeProperty);
                    }
                    if (shouldAddParamTypesMetadata(node)) {
                        const paramTypeProperty = factory2.createPropertyAssignment("paramTypes", factory2.createArrowFunction(
                        /*modifiers*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [], 
                        /*type*/
                        void 0, factory2.createToken(38 /* EqualsGreaterThanToken */), typeSerializer.serializeParameterTypesOfNode({ currentLexicalScope, currentNameScope: container }, node, container)));
                        properties = append(properties, paramTypeProperty);
                    }
                    if (shouldAddReturnTypeMetadata(node)) {
                        const returnTypeProperty = factory2.createPropertyAssignment("returnType", factory2.createArrowFunction(
                        /*modifiers*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [], 
                        /*type*/
                        void 0, factory2.createToken(38 /* EqualsGreaterThanToken */), typeSerializer.serializeReturnTypeOfNode({ currentLexicalScope, currentNameScope: container }, node)));
                        properties = append(properties, returnTypeProperty);
                    }
                    if (properties) {
                        const typeInfoMetadata = emitHelpers().createMetadataHelper("design:typeinfo", factory2.createObjectLiteralExpression(properties, 
                        /*multiLine*/
                        true));
                        return [factory2.createDecorator(typeInfoMetadata)];
                    }
                }
            }
            function shouldAddTypeMetadata(node) {
                const kind = node.kind;
                return kind === 171 /* MethodDeclaration */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */ || kind === 169 /* PropertyDeclaration */;
            }
            function shouldAddReturnTypeMetadata(node) {
                return node.kind === 171 /* MethodDeclaration */;
            }
            function shouldAddParamTypesMetadata(node) {
                switch (node.kind) {
                    case 260 /* ClassDeclaration */:
                    case 228 /* ClassExpression */:
                        return getFirstConstructorWithBody(node) !== void 0;
                    case 171 /* MethodDeclaration */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        return true;
                }
                return false;
            }
            function getExpressionForPropertyName(member, generateNameForComputedPropertyName) {
                const name = member.name;
                if (isPrivateIdentifier(name)) {
                    return factory2.createIdentifier("");
                }
                else if (isComputedPropertyName(name)) {
                    return generateNameForComputedPropertyName && !isSimpleInlineableExpression(name.expression) ? factory2.getGeneratedNameForNode(name) : name.expression;
                }
                else if (isIdentifier(name)) {
                    return factory2.createStringLiteral(idText(name));
                }
                else {
                    return factory2.cloneNode(name);
                }
            }
            function visitPropertyNameOfClassElement(member) {
                const name = member.name;
                if (isComputedPropertyName(name) && (!hasStaticModifier(member) && currentClassHasParameterProperties || hasDecorators(member) && legacyDecorators)) {
                    const expression = visitNode(name.expression, visitor, isExpression);
                    Debug.assert(expression);
                    const innerExpression = skipPartiallyEmittedExpressions(expression);
                    if (!isSimpleInlineableExpression(innerExpression)) {
                        const generatedName = factory2.getGeneratedNameForNode(name);
                        hoistVariableDeclaration(generatedName);
                        return factory2.updateComputedPropertyName(name, factory2.createAssignment(generatedName, expression));
                    }
                }
                return Debug.checkDefined(visitNode(name, visitor, isPropertyName));
            }
            function visitHeritageClause(node) {
                if (node.token === 117 /* ImplementsKeyword */) {
                    return void 0;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitExpressionWithTypeArguments(node) {
                return factory2.updateExpressionWithTypeArguments(node, Debug.checkDefined(visitNode(node.expression, visitor, isLeftHandSideExpression)), 
                /*typeArguments*/
                void 0);
            }
            function shouldEmitFunctionLikeDeclaration(node) {
                return !nodeIsMissing(node.body);
            }
            function visitPropertyDeclaration(node, parent2) {
                const isAmbient = node.flags & 16777216 /* Ambient */ || hasSyntacticModifier(node, 256 /* Abstract */);
                if (isAmbient && !(legacyDecorators && hasDecorators(node))) {
                    return void 0;
                }
                let modifiers = isClassLike(parent2) ? !isAmbient ? visitNodes2(node.modifiers, visitor, isModifierLike) : visitNodes2(node.modifiers, modifierElidingVisitor, isModifierLike) : visitNodes2(node.modifiers, decoratorElidingVisitor, isModifierLike);
                modifiers = injectClassElementTypeMetadata(modifiers, node, parent2);
                if (isAmbient) {
                    return factory2.updatePropertyDeclaration(node, concatenate(modifiers, factory2.createModifiersFromModifierFlags(2 /* Ambient */)), Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), 
                    /*questionOrExclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0);
                }
                return factory2.updatePropertyDeclaration(node, modifiers, visitPropertyNameOfClassElement(node), 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
            }
            function visitConstructor(node) {
                if (!shouldEmitFunctionLikeDeclaration(node)) {
                    return void 0;
                }
                return factory2.updateConstructorDeclaration(node, 
                /*modifiers*/
                void 0, visitParameterList(node.parameters, visitor, context), transformConstructorBody(node.body, node));
            }
            function transformConstructorBody(body, constructor) {
                const parametersWithPropertyAssignments = constructor && filter(constructor.parameters, (p) => isParameterPropertyDeclaration(p, constructor));
                if (!some(parametersWithPropertyAssignments)) {
                    return visitFunctionBody(body, visitor, context);
                }
                let statements = [];
                resumeLexicalEnvironment();
                const prologueStatementCount = factory2.copyPrologue(body.statements, statements, 
                /*ensureUseStrict*/
                false, visitor);
                const superStatementIndex = findSuperStatementIndex(body.statements, prologueStatementCount);
                if (superStatementIndex >= 0) {
                    addRange(statements, visitNodes2(body.statements, visitor, isStatement, prologueStatementCount, superStatementIndex + 1 - prologueStatementCount));
                }
                const parameterPropertyAssignments = mapDefined(parametersWithPropertyAssignments, transformParameterWithPropertyAssignment);
                if (superStatementIndex >= 0) {
                    addRange(statements, parameterPropertyAssignments);
                }
                else {
                    statements = [
                        ...statements.slice(0, prologueStatementCount),
                        ...parameterPropertyAssignments,
                        ...statements.slice(prologueStatementCount)
                    ];
                }
                const start = superStatementIndex >= 0 ? superStatementIndex + 1 : prologueStatementCount;
                addRange(statements, visitNodes2(body.statements, visitor, isStatement, start));
                statements = factory2.mergeLexicalEnvironment(statements, endLexicalEnvironment());
                const block = factory2.createBlock(setTextRange(factory2.createNodeArray(statements), body.statements), 
                /*multiLine*/
                true);
                setTextRange(block, 
                /*location*/
                body);
                setOriginalNode(block, body);
                return block;
            }
            function transformParameterWithPropertyAssignment(node) {
                const name = node.name;
                if (!isIdentifier(name)) {
                    return void 0;
                }
                const propertyName = setParent(setTextRange(factory2.cloneNode(name), name), name.parent);
                setEmitFlags(propertyName, 3072 /* NoComments */ | 96 /* NoSourceMap */);
                const localName = setParent(setTextRange(factory2.cloneNode(name), name), name.parent);
                setEmitFlags(localName, 3072 /* NoComments */);
                return startOnNewLine(removeAllComments(setTextRange(setOriginalNode(factory2.createExpressionStatement(factory2.createAssignment(setTextRange(factory2.createPropertyAccessExpression(factory2.createThis(), propertyName), node.name), localName)), node), moveRangePos(node, -1))));
            }
            function visitMethodDeclaration(node, parent2) {
                if (!(node.transformFlags & 1 /* ContainsTypeScript */)) {
                    return node;
                }
                if (!shouldEmitFunctionLikeDeclaration(node)) {
                    return void 0;
                }
                let modifiers = isClassLike(parent2) ? visitNodes2(node.modifiers, visitor, isModifierLike) : visitNodes2(node.modifiers, decoratorElidingVisitor, isModifierLike);
                modifiers = injectClassElementTypeMetadata(modifiers, node, parent2);
                return factory2.updateMethodDeclaration(node, modifiers, node.asteriskToken, visitPropertyNameOfClassElement(node), 
                /*questionToken*/
                void 0, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, visitFunctionBody(node.body, visitor, context));
            }
            function shouldEmitAccessorDeclaration(node) {
                return !(nodeIsMissing(node.body) && hasSyntacticModifier(node, 256 /* Abstract */));
            }
            function visitGetAccessor(node, parent2) {
                if (!(node.transformFlags & 1 /* ContainsTypeScript */)) {
                    return node;
                }
                if (!shouldEmitAccessorDeclaration(node)) {
                    return void 0;
                }
                let modifiers = isClassLike(parent2) ? visitNodes2(node.modifiers, visitor, isModifierLike) : visitNodes2(node.modifiers, decoratorElidingVisitor, isModifierLike);
                modifiers = injectClassElementTypeMetadata(modifiers, node, parent2);
                return factory2.updateGetAccessorDeclaration(node, modifiers, visitPropertyNameOfClassElement(node), visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, visitFunctionBody(node.body, visitor, context) || factory2.createBlock([]));
            }
            function visitSetAccessor(node, parent2) {
                if (!(node.transformFlags & 1 /* ContainsTypeScript */)) {
                    return node;
                }
                if (!shouldEmitAccessorDeclaration(node)) {
                    return void 0;
                }
                let modifiers = isClassLike(parent2) ? visitNodes2(node.modifiers, visitor, isModifierLike) : visitNodes2(node.modifiers, decoratorElidingVisitor, isModifierLike);
                modifiers = injectClassElementTypeMetadata(modifiers, node, parent2);
                return factory2.updateSetAccessorDeclaration(node, modifiers, visitPropertyNameOfClassElement(node), visitParameterList(node.parameters, visitor, context), visitFunctionBody(node.body, visitor, context) || factory2.createBlock([]));
            }
            function visitFunctionDeclaration(node) {
                if (!shouldEmitFunctionLikeDeclaration(node)) {
                    return factory2.createNotEmittedStatement(node);
                }
                const updated = factory2.updateFunctionDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, visitFunctionBody(node.body, visitor, context) || factory2.createBlock([]));
                if (isExportOfNamespace(node)) {
                    const statements = [updated];
                    addExportMemberAssignment(statements, node);
                    return statements;
                }
                return updated;
            }
            function visitFunctionExpression(node) {
                if (!shouldEmitFunctionLikeDeclaration(node)) {
                    return factory2.createOmittedExpression();
                }
                const updated = factory2.updateFunctionExpression(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, visitFunctionBody(node.body, visitor, context) || factory2.createBlock([]));
                return updated;
            }
            function visitArrowFunction(node) {
                const updated = factory2.updateArrowFunction(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, node.equalsGreaterThanToken, visitFunctionBody(node.body, visitor, context));
                return updated;
            }
            function visitParameter(node) {
                if (parameterIsThisKeyword(node)) {
                    return void 0;
                }
                const updated = factory2.updateParameterDeclaration(node, visitNodes2(node.modifiers, (node2) => isDecorator(node2) ? visitor(node2) : void 0, isModifierLike), node.dotDotDotToken, Debug.checkDefined(visitNode(node.name, visitor, isBindingName)), 
                /*questionToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
                if (updated !== node) {
                    setCommentRange(updated, node);
                    setTextRange(updated, moveRangePastModifiers(node));
                    setSourceMapRange(updated, moveRangePastModifiers(node));
                    setEmitFlags(updated.name, 64 /* NoTrailingSourceMap */);
                }
                return updated;
            }
            function visitVariableStatement(node) {
                if (isExportOfNamespace(node)) {
                    const variables = getInitializedVariables(node.declarationList);
                    if (variables.length === 0) {
                        return void 0;
                    }
                    return setTextRange(factory2.createExpressionStatement(factory2.inlineExpressions(map(variables, transformInitializedVariable))), node);
                }
                else {
                    return visitEachChild(node, visitor, context);
                }
            }
            function transformInitializedVariable(node) {
                const name = node.name;
                if (isBindingPattern(name)) {
                    return flattenDestructuringAssignment(node, visitor, context, 0 /* All */, 
                    /*needsValue*/
                    false, createNamespaceExportExpression);
                }
                else {
                    return setTextRange(factory2.createAssignment(getNamespaceMemberNameWithSourceMapsAndWithoutComments(name), Debug.checkDefined(visitNode(node.initializer, visitor, isExpression))), 
                    /*location*/
                    node);
                }
            }
            function visitVariableDeclaration(node) {
                const updated = factory2.updateVariableDeclaration(node, Debug.checkDefined(visitNode(node.name, visitor, isBindingName)), 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
                if (node.type) {
                    setTypeNode(updated.name, node.type);
                }
                return updated;
            }
            function visitParenthesizedExpression(node) {
                const innerExpression = skipOuterExpressions(node.expression, ~6 /* Assertions */);
                if (isAssertionExpression(innerExpression)) {
                    const expression = visitNode(node.expression, visitor, isExpression);
                    Debug.assert(expression);
                    return factory2.createPartiallyEmittedExpression(expression, node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssertionExpression(node) {
                const expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                return factory2.createPartiallyEmittedExpression(expression, node);
            }
            function visitNonNullExpression(node) {
                const expression = visitNode(node.expression, visitor, isLeftHandSideExpression);
                Debug.assert(expression);
                return factory2.createPartiallyEmittedExpression(expression, node);
            }
            function visitSatisfiesExpression(node) {
                const expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                return factory2.createPartiallyEmittedExpression(expression, node);
            }
            function visitCallExpression(node) {
                return factory2.updateCallExpression(node, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), 
                /*typeArguments*/
                void 0, visitNodes2(node.arguments, visitor, isExpression));
            }
            function visitNewExpression(node) {
                return factory2.updateNewExpression(node, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), 
                /*typeArguments*/
                void 0, visitNodes2(node.arguments, visitor, isExpression));
            }
            function visitTaggedTemplateExpression(node) {
                return factory2.updateTaggedTemplateExpression(node, Debug.checkDefined(visitNode(node.tag, visitor, isExpression)), 
                /*typeArguments*/
                void 0, Debug.checkDefined(visitNode(node.template, visitor, isTemplateLiteral)));
            }
            function visitJsxSelfClosingElement(node) {
                return factory2.updateJsxSelfClosingElement(node, Debug.checkDefined(visitNode(node.tagName, visitor, isJsxTagNameExpression)), 
                /*typeArguments*/
                void 0, Debug.checkDefined(visitNode(node.attributes, visitor, isJsxAttributes)));
            }
            function visitJsxJsxOpeningElement(node) {
                return factory2.updateJsxOpeningElement(node, Debug.checkDefined(visitNode(node.tagName, visitor, isJsxTagNameExpression)), 
                /*typeArguments*/
                void 0, Debug.checkDefined(visitNode(node.attributes, visitor, isJsxAttributes)));
            }
            function shouldEmitEnumDeclaration(node) {
                return !isEnumConst(node) || shouldPreserveConstEnums(compilerOptions);
            }
            function visitEnumDeclaration(node) {
                if (!shouldEmitEnumDeclaration(node)) {
                    return factory2.createNotEmittedStatement(node);
                }
                const statements = [];
                let emitFlags = 4 /* AdviseOnEmitNode */;
                const varAdded = addVarForEnumOrModuleDeclaration(statements, node);
                if (varAdded) {
                    if (moduleKind !== 4 /* System */ || currentLexicalScope !== currentSourceFile) {
                        emitFlags |= 1024 /* NoLeadingComments */;
                    }
                }
                const parameterName = getNamespaceParameterName(node);
                const containerName = getNamespaceContainerName(node);
                const exportName = hasSyntacticModifier(node, 1 /* Export */) ? factory2.getExternalModuleOrNamespaceExportName(currentNamespaceContainerName, node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true) : factory2.getLocalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
                let moduleArg = factory2.createLogicalOr(exportName, factory2.createAssignment(exportName, factory2.createObjectLiteralExpression()));
                if (hasNamespaceQualifiedExportName(node)) {
                    const localName = factory2.getLocalName(node, 
                    /*allowComments*/
                    false, 
                    /*allowSourceMaps*/
                    true);
                    moduleArg = factory2.createAssignment(localName, moduleArg);
                }
                const enumStatement = factory2.createExpressionStatement(factory2.createCallExpression(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, parameterName)], 
                /*type*/
                void 0, transformEnumBody(node, containerName)), 
                /*typeArguments*/
                void 0, [moduleArg]));
                setOriginalNode(enumStatement, node);
                if (varAdded) {
                    setSyntheticLeadingComments(enumStatement, void 0);
                    setSyntheticTrailingComments(enumStatement, void 0);
                }
                setTextRange(enumStatement, node);
                addEmitFlags(enumStatement, emitFlags);
                statements.push(enumStatement);
                statements.push(factory2.createEndOfDeclarationMarker(node));
                return statements;
            }
            function transformEnumBody(node, localName) {
                const savedCurrentNamespaceLocalName = currentNamespaceContainerName;
                currentNamespaceContainerName = localName;
                const statements = [];
                startLexicalEnvironment();
                const members = map(node.members, transformEnumMember);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                addRange(statements, members);
                currentNamespaceContainerName = savedCurrentNamespaceLocalName;
                return factory2.createBlock(setTextRange(factory2.createNodeArray(statements), 
                /*location*/
                node.members), 
                /*multiLine*/
                true);
            }
            function transformEnumMember(member) {
                const name = getExpressionForPropertyName(member, 
                /*generateNameForComputedPropertyName*/
                false);
                const valueExpression = transformEnumMemberDeclarationValue(member);
                const innerAssignment = factory2.createAssignment(factory2.createElementAccessExpression(currentNamespaceContainerName, name), valueExpression);
                const outerAssignment = valueExpression.kind === 10 /* StringLiteral */ ? innerAssignment : factory2.createAssignment(factory2.createElementAccessExpression(currentNamespaceContainerName, innerAssignment), name);
                return setTextRange(factory2.createExpressionStatement(setTextRange(outerAssignment, member)), member);
            }
            function transformEnumMemberDeclarationValue(member) {
                const value = resolver.getConstantValue(member);
                if (value !== void 0) {
                    return typeof value === "string" ? factory2.createStringLiteral(value) : factory2.createNumericLiteral(value);
                }
                else {
                    enableSubstitutionForNonQualifiedEnumMembers();
                    if (member.initializer) {
                        return Debug.checkDefined(visitNode(member.initializer, visitor, isExpression));
                    }
                    else {
                        return factory2.createVoidZero();
                    }
                }
            }
            function shouldEmitModuleDeclaration(nodeIn) {
                const node = getParseTreeNode(nodeIn, isModuleDeclaration);
                if (!node) {
                    return true;
                }
                return isInstantiatedModule(node, shouldPreserveConstEnums(compilerOptions));
            }
            function hasNamespaceQualifiedExportName(node) {
                return isExportOfNamespace(node) || isExternalModuleExport(node) && moduleKind !== 5 /* ES2015 */ && moduleKind !== 6 /* ES2020 */ && moduleKind !== 7 /* ES2022 */ && moduleKind !== 99 /* ESNext */ && moduleKind !== 4 /* System */;
            }
            function recordEmittedDeclarationInScope(node) {
                if (!currentScopeFirstDeclarationsOfName) {
                    currentScopeFirstDeclarationsOfName = /* @__PURE__ */ new Map();
                }
                const name = declaredNameInScope(node);
                if (!currentScopeFirstDeclarationsOfName.has(name)) {
                    currentScopeFirstDeclarationsOfName.set(name, node);
                }
            }
            function isFirstEmittedDeclarationInScope(node) {
                if (currentScopeFirstDeclarationsOfName) {
                    const name = declaredNameInScope(node);
                    return currentScopeFirstDeclarationsOfName.get(name) === node;
                }
                return true;
            }
            function declaredNameInScope(node) {
                Debug.assertNode(node.name, isIdentifier);
                return node.name.escapedText;
            }
            function addVarForEnumOrModuleDeclaration(statements, node) {
                const statement = factory2.createVariableStatement(visitNodes2(node.modifiers, modifierVisitor, isModifier), factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(factory2.getLocalName(node, 
                    /*allowComments*/
                    false, 
                    /*allowSourceMaps*/
                    true))
                ], currentLexicalScope.kind === 308 /* SourceFile */ ? 0 /* None */ : 1 /* Let */));
                setOriginalNode(statement, node);
                recordEmittedDeclarationInScope(node);
                if (isFirstEmittedDeclarationInScope(node)) {
                    if (node.kind === 263 /* EnumDeclaration */) {
                        setSourceMapRange(statement.declarationList, node);
                    }
                    else {
                        setSourceMapRange(statement, node);
                    }
                    setCommentRange(statement, node);
                    addEmitFlags(statement, 2048 /* NoTrailingComments */ | 8388608 /* HasEndOfDeclarationMarker */);
                    statements.push(statement);
                    return true;
                }
                else {
                    const mergeMarker = factory2.createMergeDeclarationMarker(statement);
                    setEmitFlags(mergeMarker, 3072 /* NoComments */ | 8388608 /* HasEndOfDeclarationMarker */);
                    statements.push(mergeMarker);
                    return false;
                }
            }
            function visitModuleDeclaration(node) {
                if (!shouldEmitModuleDeclaration(node)) {
                    return factory2.createNotEmittedStatement(node);
                }
                Debug.assertNode(node.name, isIdentifier, "A TypeScript namespace should have an Identifier name.");
                enableSubstitutionForNamespaceExports();
                const statements = [];
                let emitFlags = 4 /* AdviseOnEmitNode */;
                const varAdded = addVarForEnumOrModuleDeclaration(statements, node);
                if (varAdded) {
                    if (moduleKind !== 4 /* System */ || currentLexicalScope !== currentSourceFile) {
                        emitFlags |= 1024 /* NoLeadingComments */;
                    }
                }
                const parameterName = getNamespaceParameterName(node);
                const containerName = getNamespaceContainerName(node);
                const exportName = hasSyntacticModifier(node, 1 /* Export */) ? factory2.getExternalModuleOrNamespaceExportName(currentNamespaceContainerName, node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true) : factory2.getLocalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
                let moduleArg = factory2.createLogicalOr(exportName, factory2.createAssignment(exportName, factory2.createObjectLiteralExpression()));
                if (hasNamespaceQualifiedExportName(node)) {
                    const localName = factory2.getLocalName(node, 
                    /*allowComments*/
                    false, 
                    /*allowSourceMaps*/
                    true);
                    moduleArg = factory2.createAssignment(localName, moduleArg);
                }
                const moduleStatement = factory2.createExpressionStatement(factory2.createCallExpression(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, parameterName)], 
                /*type*/
                void 0, transformModuleBody(node, containerName)), 
                /*typeArguments*/
                void 0, [moduleArg]));
                setOriginalNode(moduleStatement, node);
                if (varAdded) {
                    setSyntheticLeadingComments(moduleStatement, void 0);
                    setSyntheticTrailingComments(moduleStatement, void 0);
                }
                setTextRange(moduleStatement, node);
                addEmitFlags(moduleStatement, emitFlags);
                statements.push(moduleStatement);
                statements.push(factory2.createEndOfDeclarationMarker(node));
                return statements;
            }
            function transformModuleBody(node, namespaceLocalName) {
                const savedCurrentNamespaceContainerName = currentNamespaceContainerName;
                const savedCurrentNamespace = currentNamespace;
                const savedCurrentScopeFirstDeclarationsOfName = currentScopeFirstDeclarationsOfName;
                currentNamespaceContainerName = namespaceLocalName;
                currentNamespace = node;
                currentScopeFirstDeclarationsOfName = void 0;
                const statements = [];
                startLexicalEnvironment();
                let statementsLocation;
                let blockLocation;
                if (node.body) {
                    if (node.body.kind === 265 /* ModuleBlock */) {
                        saveStateAndInvoke(node.body, (body) => addRange(statements, visitNodes2(body.statements, namespaceElementVisitor, isStatement)));
                        statementsLocation = node.body.statements;
                        blockLocation = node.body;
                    }
                    else {
                        const result = visitModuleDeclaration(node.body);
                        if (result) {
                            if (isArray(result)) {
                                addRange(statements, result);
                            }
                            else {
                                statements.push(result);
                            }
                        }
                        const moduleBlock = getInnerMostModuleDeclarationFromDottedModule(node).body;
                        statementsLocation = moveRangePos(moduleBlock.statements, -1);
                    }
                }
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                currentNamespaceContainerName = savedCurrentNamespaceContainerName;
                currentNamespace = savedCurrentNamespace;
                currentScopeFirstDeclarationsOfName = savedCurrentScopeFirstDeclarationsOfName;
                const block = factory2.createBlock(setTextRange(factory2.createNodeArray(statements), 
                /*location*/
                statementsLocation), 
                /*multiLine*/
                true);
                setTextRange(block, blockLocation);
                if (!node.body || node.body.kind !== 265 /* ModuleBlock */) {
                    setEmitFlags(block, getEmitFlags(block) | 3072 /* NoComments */);
                }
                return block;
            }
            function getInnerMostModuleDeclarationFromDottedModule(moduleDeclaration) {
                if (moduleDeclaration.body.kind === 264 /* ModuleDeclaration */) {
                    const recursiveInnerModule = getInnerMostModuleDeclarationFromDottedModule(moduleDeclaration.body);
                    return recursiveInnerModule || moduleDeclaration.body;
                }
            }
            function visitImportDeclaration(node) {
                if (!node.importClause) {
                    return node;
                }
                if (node.importClause.isTypeOnly) {
                    return void 0;
                }
                const importClause = visitNode(node.importClause, visitImportClause, isImportClause);
                return importClause || compilerOptions.importsNotUsedAsValues === 1 /* Preserve */ || compilerOptions.importsNotUsedAsValues === 2 /* Error */ ? factory2.updateImportDeclaration(node, 
                /*modifiers*/
                void 0, importClause, node.moduleSpecifier, node.assertClause) : void 0;
            }
            function visitImportClause(node) {
                Debug.assert(!node.isTypeOnly);
                const name = shouldEmitAliasDeclaration(node) ? node.name : void 0;
                const namedBindings = visitNode(node.namedBindings, visitNamedImportBindings, isNamedImportBindings);
                return name || namedBindings ? factory2.updateImportClause(node, 
                /*isTypeOnly*/
                false, name, namedBindings) : void 0;
            }
            function visitNamedImportBindings(node) {
                if (node.kind === 271 /* NamespaceImport */) {
                    return shouldEmitAliasDeclaration(node) ? node : void 0;
                }
                else {
                    const allowEmpty = compilerOptions.verbatimModuleSyntax || compilerOptions.preserveValueImports && (compilerOptions.importsNotUsedAsValues === 1 /* Preserve */ || compilerOptions.importsNotUsedAsValues === 2 /* Error */);
                    const elements = visitNodes2(node.elements, visitImportSpecifier, isImportSpecifier);
                    return allowEmpty || some(elements) ? factory2.updateNamedImports(node, elements) : void 0;
                }
            }
            function visitImportSpecifier(node) {
                return !node.isTypeOnly && shouldEmitAliasDeclaration(node) ? node : void 0;
            }
            function visitExportAssignment(node) {
                return compilerOptions.verbatimModuleSyntax || resolver.isValueAliasDeclaration(node) ? visitEachChild(node, visitor, context) : void 0;
            }
            function visitExportDeclaration(node) {
                if (node.isTypeOnly) {
                    return void 0;
                }
                if (!node.exportClause || isNamespaceExport(node.exportClause)) {
                    return node;
                }
                const allowEmpty = compilerOptions.verbatimModuleSyntax || !!node.moduleSpecifier && (compilerOptions.importsNotUsedAsValues === 1 /* Preserve */ || compilerOptions.importsNotUsedAsValues === 2 /* Error */);
                const exportClause = visitNode(node.exportClause, (bindings) => visitNamedExportBindings(bindings, allowEmpty), isNamedExportBindings);
                return exportClause ? factory2.updateExportDeclaration(node, 
                /*modifiers*/
                void 0, node.isTypeOnly, exportClause, node.moduleSpecifier, node.assertClause) : void 0;
            }
            function visitNamedExports(node, allowEmpty) {
                const elements = visitNodes2(node.elements, visitExportSpecifier, isExportSpecifier);
                return allowEmpty || some(elements) ? factory2.updateNamedExports(node, elements) : void 0;
            }
            function visitNamespaceExports(node) {
                return factory2.updateNamespaceExport(node, Debug.checkDefined(visitNode(node.name, visitor, isIdentifier)));
            }
            function visitNamedExportBindings(node, allowEmpty) {
                return isNamespaceExport(node) ? visitNamespaceExports(node) : visitNamedExports(node, allowEmpty);
            }
            function visitExportSpecifier(node) {
                return !node.isTypeOnly && (compilerOptions.verbatimModuleSyntax || resolver.isValueAliasDeclaration(node)) ? node : void 0;
            }
            function shouldEmitImportEqualsDeclaration(node) {
                return shouldEmitAliasDeclaration(node) || !isExternalModule(currentSourceFile) && resolver.isTopLevelValueImportEqualsWithEntityName(node);
            }
            function visitImportEqualsDeclaration(node) {
                if (node.isTypeOnly) {
                    return void 0;
                }
                if (isExternalModuleImportEqualsDeclaration(node)) {
                    const isReferenced = shouldEmitAliasDeclaration(node);
                    if (!isReferenced && compilerOptions.importsNotUsedAsValues === 1 /* Preserve */) {
                        return setOriginalNode(setTextRange(factory2.createImportDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*importClause*/
                        void 0, node.moduleReference.expression, 
                        /*assertClause*/
                        void 0), node), node);
                    }
                    return isReferenced ? visitEachChild(node, visitor, context) : void 0;
                }
                if (!shouldEmitImportEqualsDeclaration(node)) {
                    return void 0;
                }
                const moduleReference = createExpressionFromEntityName(factory2, node.moduleReference);
                setEmitFlags(moduleReference, 3072 /* NoComments */ | 4096 /* NoNestedComments */);
                if (isNamedExternalModuleExport(node) || !isExportOfNamespace(node)) {
                    return setOriginalNode(setTextRange(factory2.createVariableStatement(visitNodes2(node.modifiers, modifierVisitor, isModifier), factory2.createVariableDeclarationList([
                        setOriginalNode(factory2.createVariableDeclaration(node.name, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, moduleReference), node)
                    ])), node), node);
                }
                else {
                    return setOriginalNode(createNamespaceExport(node.name, moduleReference, node), node);
                }
            }
            function isExportOfNamespace(node) {
                return currentNamespace !== void 0 && hasSyntacticModifier(node, 1 /* Export */);
            }
            function isExternalModuleExport(node) {
                return currentNamespace === void 0 && hasSyntacticModifier(node, 1 /* Export */);
            }
            function isNamedExternalModuleExport(node) {
                return isExternalModuleExport(node) && !hasSyntacticModifier(node, 1024 /* Default */);
            }
            function isDefaultExternalModuleExport(node) {
                return isExternalModuleExport(node) && hasSyntacticModifier(node, 1024 /* Default */);
            }
            function createExportMemberAssignmentStatement(node) {
                const expression = factory2.createAssignment(factory2.getExternalModuleOrNamespaceExportName(currentNamespaceContainerName, node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true), factory2.getLocalName(node));
                setSourceMapRange(expression, createRange(node.name ? node.name.pos : node.pos, node.end));
                const statement = factory2.createExpressionStatement(expression);
                setSourceMapRange(statement, createRange(-1, node.end));
                return statement;
            }
            function addExportMemberAssignment(statements, node) {
                statements.push(createExportMemberAssignmentStatement(node));
            }
            function createNamespaceExport(exportName, exportValue, location) {
                return setTextRange(factory2.createExpressionStatement(factory2.createAssignment(factory2.getNamespaceMemberName(currentNamespaceContainerName, exportName, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true), exportValue)), location);
            }
            function createNamespaceExportExpression(exportName, exportValue, location) {
                return setTextRange(factory2.createAssignment(getNamespaceMemberNameWithSourceMapsAndWithoutComments(exportName), exportValue), location);
            }
            function getNamespaceMemberNameWithSourceMapsAndWithoutComments(name) {
                return factory2.getNamespaceMemberName(currentNamespaceContainerName, name, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
            }
            function getNamespaceParameterName(node) {
                const name = factory2.getGeneratedNameForNode(node);
                setSourceMapRange(name, node.name);
                return name;
            }
            function getNamespaceContainerName(node) {
                return factory2.getGeneratedNameForNode(node);
            }
            function enableSubstitutionForNonQualifiedEnumMembers() {
                if ((enabledSubstitutions & 8 /* NonQualifiedEnumMembers */) === 0) {
                    enabledSubstitutions |= 8 /* NonQualifiedEnumMembers */;
                    context.enableSubstitution(79 /* Identifier */);
                }
            }
            function enableSubstitutionForNamespaceExports() {
                if ((enabledSubstitutions & 2 /* NamespaceExports */) === 0) {
                    enabledSubstitutions |= 2 /* NamespaceExports */;
                    context.enableSubstitution(79 /* Identifier */);
                    context.enableSubstitution(300 /* ShorthandPropertyAssignment */);
                    context.enableEmitNotification(264 /* ModuleDeclaration */);
                }
            }
            function isTransformedModuleDeclaration(node) {
                return getOriginalNode(node).kind === 264 /* ModuleDeclaration */;
            }
            function isTransformedEnumDeclaration(node) {
                return getOriginalNode(node).kind === 263 /* EnumDeclaration */;
            }
            function onEmitNode(hint, node, emitCallback) {
                const savedApplicableSubstitutions = applicableSubstitutions;
                const savedCurrentSourceFile = currentSourceFile;
                if (isSourceFile(node)) {
                    currentSourceFile = node;
                }
                if (enabledSubstitutions & 2 /* NamespaceExports */ && isTransformedModuleDeclaration(node)) {
                    applicableSubstitutions |= 2 /* NamespaceExports */;
                }
                if (enabledSubstitutions & 8 /* NonQualifiedEnumMembers */ && isTransformedEnumDeclaration(node)) {
                    applicableSubstitutions |= 8 /* NonQualifiedEnumMembers */;
                }
                previousOnEmitNode(hint, node, emitCallback);
                applicableSubstitutions = savedApplicableSubstitutions;
                currentSourceFile = savedCurrentSourceFile;
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                else if (isShorthandPropertyAssignment(node)) {
                    return substituteShorthandPropertyAssignment(node);
                }
                return node;
            }
            function substituteShorthandPropertyAssignment(node) {
                if (enabledSubstitutions & 2 /* NamespaceExports */) {
                    const name = node.name;
                    const exportedName = trySubstituteNamespaceExportedName(name);
                    if (exportedName) {
                        if (node.objectAssignmentInitializer) {
                            const initializer = factory2.createAssignment(exportedName, node.objectAssignmentInitializer);
                            return setTextRange(factory2.createPropertyAssignment(name, initializer), node);
                        }
                        return setTextRange(factory2.createPropertyAssignment(name, exportedName), node);
                    }
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 208 /* PropertyAccessExpression */:
                        return substitutePropertyAccessExpression(node);
                    case 209 /* ElementAccessExpression */:
                        return substituteElementAccessExpression(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                return trySubstituteNamespaceExportedName(node) || node;
            }
            function trySubstituteNamespaceExportedName(node) {
                if (enabledSubstitutions & applicableSubstitutions && !isGeneratedIdentifier(node) && !isLocalName(node)) {
                    const container = resolver.getReferencedExportContainer(node, 
                    /*prefixLocals*/
                    false);
                    if (container && container.kind !== 308 /* SourceFile */) {
                        const substitute = applicableSubstitutions & 2 /* NamespaceExports */ && container.kind === 264 /* ModuleDeclaration */ || applicableSubstitutions & 8 /* NonQualifiedEnumMembers */ && container.kind === 263 /* EnumDeclaration */;
                        if (substitute) {
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(container), node), 
                            /*location*/
                            node);
                        }
                    }
                }
                return void 0;
            }
            function substitutePropertyAccessExpression(node) {
                return substituteConstantValue(node);
            }
            function substituteElementAccessExpression(node) {
                return substituteConstantValue(node);
            }
            function safeMultiLineComment(value) {
                return value.replace(/\*\//g, "*_/");
            }
            function substituteConstantValue(node) {
                const constantValue = tryGetConstEnumValue(node);
                if (constantValue !== void 0) {
                    setConstantValue(node, constantValue);
                    const substitute = typeof constantValue === "string" ? factory2.createStringLiteral(constantValue) : factory2.createNumericLiteral(constantValue);
                    if (!compilerOptions.removeComments) {
                        const originalNode = getOriginalNode(node, isAccessExpression);
                        addSyntheticTrailingComment(substitute, 3 /* MultiLineCommentTrivia */, ` ${safeMultiLineComment(getTextOfNode(originalNode))} `);
                    }
                    return substitute;
                }
                return node;
            }
            function tryGetConstEnumValue(node) {
                if (getIsolatedModules(compilerOptions)) {
                    return void 0;
                }
                return isPropertyAccessExpression(node) || isElementAccessExpression(node) ? resolver.getConstantValue(node) : void 0;
            }
            function shouldEmitAliasDeclaration(node) {
                return compilerOptions.verbatimModuleSyntax || isInJSFile(node) || (compilerOptions.preserveValueImports ? resolver.isValueAliasDeclaration(node) : resolver.isReferencedAliasDeclaration(node));
            }
        }
        var USE_NEW_TYPE_METADATA_FORMAT;
        var init_ts = __esm({
            "src/compiler/transformers/ts.ts"() {
                "use strict";
                init_ts2();
                USE_NEW_TYPE_METADATA_FORMAT = false;
            }
        });
        // src/compiler/transformers/classFields.ts
        function transformClassFields(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, hoistVariableDeclaration, endLexicalEnvironment, startLexicalEnvironment, resumeLexicalEnvironment, addBlockScopedVariable } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const useDefineForClassFields = getUseDefineForClassFields(compilerOptions);
            const legacyDecorators = !!compilerOptions.experimentalDecorators;
            const shouldTransformInitializersUsingSet = !useDefineForClassFields;
            const shouldTransformInitializersUsingDefine = useDefineForClassFields && languageVersion < 9 /* ES2022 */;
            const shouldTransformInitializers = shouldTransformInitializersUsingSet || shouldTransformInitializersUsingDefine;
            const shouldTransformPrivateElementsOrClassStaticBlocks = languageVersion < 9 /* ES2022 */;
            const shouldTransformAutoAccessors = languageVersion < 99 /* ESNext */ ? -1 /* True */ : !useDefineForClassFields ? 3 /* Maybe */ : 0 /* False */;
            const shouldTransformThisInStaticInitializers = languageVersion < 9 /* ES2022 */;
            const shouldTransformSuperInStaticInitializers = shouldTransformThisInStaticInitializers && languageVersion >= 2 /* ES2015 */;
            const shouldTransformAnything = shouldTransformInitializers || shouldTransformPrivateElementsOrClassStaticBlocks || shouldTransformAutoAccessors === -1 /* True */;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            context.onEmitNode = onEmitNode;
            let shouldTransformPrivateStaticElementsInFile = false;
            let enabledSubstitutions;
            let classAliases;
            let pendingExpressions;
            let pendingStatements;
            let lexicalEnvironment;
            const lexicalEnvironmentMap = /* @__PURE__ */ new Map();
            let currentClassContainer;
            let currentStaticPropertyDeclarationOrStaticBlock;
            let shouldSubstituteThisWithClassThis = false;
            let previousShouldSubstituteThisWithClassThis = false;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                lexicalEnvironment = void 0;
                shouldTransformPrivateStaticElementsInFile = !!(getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */);
                if (!shouldTransformAnything && !shouldTransformPrivateStaticElementsInFile) {
                    return node;
                }
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                return visited;
            }
            function modifierVisitor(node) {
                switch (node.kind) {
                    case 127 /* AccessorKeyword */:
                        return shouldTransformAutoAccessorsInCurrentClass() ? void 0 : node;
                    default:
                        return tryCast(node, isModifier);
                }
            }
            function visitor(node) {
                if (!(node.transformFlags & 16777216 /* ContainsClassFields */) && !(node.transformFlags & 134234112 /* ContainsLexicalThisOrSuper */)) {
                    return node;
                }
                switch (node.kind) {
                    case 127 /* AccessorKeyword */:
                        return Debug.fail("Use `modifierVisitor` instead.");
                    case 260 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 228 /* ClassExpression */:
                        return visitClassExpression(node, 
                        /*referencedName*/
                        void 0);
                    case 172 /* ClassStaticBlockDeclaration */:
                    case 169 /* PropertyDeclaration */:
                        return Debug.fail("Use `classElementVisitor` instead.");
                    case 299 /* PropertyAssignment */:
                        return visitPropertyAssignment(node);
                    case 240 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 257 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 166 /* Parameter */:
                        return visitParameterDeclaration(node);
                    case 205 /* BindingElement */:
                        return visitBindingElement(node);
                    case 274 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    case 80 /* PrivateIdentifier */:
                        return visitPrivateIdentifier(node);
                    case 208 /* PropertyAccessExpression */:
                        return visitPropertyAccessExpression(node);
                    case 209 /* ElementAccessExpression */:
                        return visitElementAccessExpression(node);
                    case 221 /* PrefixUnaryExpression */:
                    case 222 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, 
                        /*discarded*/
                        false);
                    case 223 /* BinaryExpression */:
                        return visitBinaryExpression(node, 
                        /*discarded*/
                        false);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        false, 
                        /*referencedName*/
                        void 0);
                    case 210 /* CallExpression */:
                        return visitCallExpression(node);
                    case 241 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 212 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 245 /* ForStatement */:
                        return visitForStatement(node);
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                    case 173 /* Constructor */:
                    case 171 /* MethodDeclaration */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */: {
                        return setCurrentStaticPropertyDeclarationOrStaticBlockAnd(
                        /*current*/
                        void 0, fallbackVisitor, node);
                    }
                    default:
                        return fallbackVisitor(node);
                }
            }
            function fallbackVisitor(node) {
                return visitEachChild(node, visitor, context);
            }
            function namedEvaluationVisitor(node, referencedName) {
                switch (node.kind) {
                    case 356 /* PartiallyEmittedExpression */:
                        return visitPartiallyEmittedExpression(node, 
                        /*discarded*/
                        false, referencedName);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        false, referencedName);
                    case 228 /* ClassExpression */:
                        return visitClassExpression(node, referencedName);
                    default:
                        return visitor(node);
                }
            }
            function discardedValueVisitor(node) {
                switch (node.kind) {
                    case 221 /* PrefixUnaryExpression */:
                    case 222 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, 
                        /*discarded*/
                        true);
                    case 223 /* BinaryExpression */:
                        return visitBinaryExpression(node, 
                        /*discarded*/
                        true);
                    case 357 /* CommaListExpression */:
                        return visitCommaListExpression(node, 
                        /*discarded*/
                        true);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        true, 
                        /*referencedName*/
                        void 0);
                    default:
                        return visitor(node);
                }
            }
            function heritageClauseVisitor(node) {
                switch (node.kind) {
                    case 294 /* HeritageClause */:
                        return visitEachChild(node, heritageClauseVisitor, context);
                    case 230 /* ExpressionWithTypeArguments */:
                        return visitExpressionWithTypeArgumentsInHeritageClause(node);
                    default:
                        return visitor(node);
                }
            }
            function assignmentTargetVisitor(node) {
                switch (node.kind) {
                    case 207 /* ObjectLiteralExpression */:
                    case 206 /* ArrayLiteralExpression */:
                        return visitAssignmentPattern(node);
                    default:
                        return visitor(node);
                }
            }
            function classElementVisitor(node) {
                switch (node.kind) {
                    case 173 /* Constructor */:
                        return visitConstructorDeclaration(node);
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 171 /* MethodDeclaration */:
                        return setCurrentStaticPropertyDeclarationOrStaticBlockAnd(
                        /*current*/
                        void 0, visitMethodOrAccessorDeclaration, node);
                    case 169 /* PropertyDeclaration */:
                        return setCurrentStaticPropertyDeclarationOrStaticBlockAnd(
                        /*current*/
                        void 0, visitPropertyDeclaration, node);
                    case 172 /* ClassStaticBlockDeclaration */:
                        return visitClassStaticBlockDeclaration(node);
                    case 164 /* ComputedPropertyName */:
                        return visitComputedPropertyName(node);
                    case 237 /* SemicolonClassElement */:
                        return node;
                    default:
                        return isModifierLike(node) ? modifierVisitor(node) : visitor(node);
                }
            }
            function propertyNameVisitor(node) {
                switch (node.kind) {
                    case 164 /* ComputedPropertyName */:
                        return visitComputedPropertyName(node);
                    default:
                        return visitor(node);
                }
            }
            function accessorFieldResultVisitor(node) {
                switch (node.kind) {
                    case 169 /* PropertyDeclaration */:
                        return transformFieldInitializer(node);
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        return classElementVisitor(node);
                    default:
                        Debug.assertMissingNode(node, "Expected node to either be a PropertyDeclaration, GetAccessorDeclaration, or SetAccessorDeclaration");
                        break;
                }
            }
            function visitPrivateIdentifier(node) {
                if (!shouldTransformPrivateElementsOrClassStaticBlocks) {
                    return node;
                }
                if (isStatement(node.parent)) {
                    return node;
                }
                return setOriginalNode(factory2.createIdentifier(""), node);
            }
            function transformPrivateIdentifierInInExpression(node) {
                const info = accessPrivateIdentifier2(node.left);
                if (info) {
                    const receiver = visitNode(node.right, visitor, isExpression);
                    return setOriginalNode(emitHelpers().createClassPrivateFieldInHelper(info.brandCheckIdentifier, receiver), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitPropertyAssignment(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const { referencedName, name } = visitReferencedPropertyName(node.name);
                    const initializer = visitNode(node.initializer, (node2) => namedEvaluationVisitor(node2, referencedName), isExpression);
                    return factory2.updatePropertyAssignment(node, name, initializer);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableStatement(node) {
                const savedPendingStatements = pendingStatements;
                pendingStatements = [];
                const visitedNode = visitEachChild(node, visitor, context);
                const statement = some(pendingStatements) ? [visitedNode, ...pendingStatements] : visitedNode;
                pendingStatements = savedPendingStatements;
                return statement;
            }
            function getAssignedNameOfIdentifier(name, initializer) {
                const originalClass = getOriginalNode(initializer, isClassLike);
                return originalClass && !originalClass.name && hasSyntacticModifier(originalClass, 1024 /* Default */) ? factory2.createStringLiteral("default") : factory2.createStringLiteralFromNode(name);
            }
            function visitVariableDeclaration(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const assignedName = getAssignedNameOfIdentifier(node.name, node.initializer);
                    const name = visitNode(node.name, visitor, isBindingName);
                    const initializer = visitNode(node.initializer, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    return factory2.updateVariableDeclaration(node, name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitParameterDeclaration(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const assignedName = getAssignedNameOfIdentifier(node.name, node.initializer);
                    const name = visitNode(node.name, visitor, isBindingName);
                    const initializer = visitNode(node.initializer, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    return factory2.updateParameterDeclaration(node, 
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, name, 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitBindingElement(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const assignedName = getAssignedNameOfIdentifier(node.name, node.initializer);
                    const propertyName = visitNode(node.propertyName, visitor, isPropertyName);
                    const name = visitNode(node.name, visitor, isBindingName);
                    const initializer = visitNode(node.initializer, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    return factory2.updateBindingElement(node, 
                    /*dotDotDotToken*/
                    void 0, propertyName, name, initializer);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitExportAssignment(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const assignedName = factory2.createStringLiteral(node.isExportEquals ? "" : "default");
                    const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                    const expression = visitNode(node.expression, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    return factory2.updateExportAssignment(node, modifiers, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function injectPendingExpressions(expression) {
                if (some(pendingExpressions)) {
                    if (isParenthesizedExpression(expression)) {
                        pendingExpressions.push(expression.expression);
                        expression = factory2.updateParenthesizedExpression(expression, factory2.inlineExpressions(pendingExpressions));
                    }
                    else {
                        pendingExpressions.push(expression);
                        expression = factory2.inlineExpressions(pendingExpressions);
                    }
                    pendingExpressions = void 0;
                }
                return expression;
            }
            function visitComputedPropertyName(node) {
                const expression = visitNode(node.expression, visitor, isExpression);
                return factory2.updateComputedPropertyName(node, injectPendingExpressions(expression));
            }
            function visitConstructorDeclaration(node) {
                if (currentClassContainer) {
                    return transformConstructor(node, currentClassContainer);
                }
                return fallbackVisitor(node);
            }
            function shouldTransformClassElementToWeakMap(node) {
                if (shouldTransformPrivateElementsOrClassStaticBlocks)
                    return true;
                if (hasStaticModifier(node) && getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */)
                    return true;
                return false;
            }
            function visitMethodOrAccessorDeclaration(node) {
                Debug.assert(!hasDecorators(node));
                if (!isPrivateIdentifierClassElementDeclaration(node) || !shouldTransformClassElementToWeakMap(node)) {
                    return visitEachChild(node, classElementVisitor, context);
                }
                const info = accessPrivateIdentifier2(node.name);
                Debug.assert(info, "Undeclared private name for property declaration.");
                if (!info.isValid) {
                    return node;
                }
                const functionName = getHoistedFunctionName(node);
                if (functionName) {
                    getPendingExpressions().push(factory2.createAssignment(functionName, factory2.createFunctionExpression(filter(node.modifiers, (m) => isModifier(m) && !isStaticModifier(m) && !isAccessorModifier(m)), node.asteriskToken, functionName, 
                    /* typeParameters */
                    void 0, visitParameterList(node.parameters, visitor, context), 
                    /* type */
                    void 0, visitFunctionBody(node.body, visitor, context))));
                }
                return void 0;
            }
            function setCurrentStaticPropertyDeclarationOrStaticBlockAnd(current, visitor2, arg) {
                const savedCurrentStaticPropertyDeclarationOrStaticBlock = currentStaticPropertyDeclarationOrStaticBlock;
                currentStaticPropertyDeclarationOrStaticBlock = current;
                const result = visitor2(arg);
                currentStaticPropertyDeclarationOrStaticBlock = savedCurrentStaticPropertyDeclarationOrStaticBlock;
                return result;
            }
            function getHoistedFunctionName(node) {
                Debug.assert(isPrivateIdentifier(node.name));
                const info = accessPrivateIdentifier2(node.name);
                Debug.assert(info, "Undeclared private name for property declaration.");
                if (info.kind === "m" /* Method */) {
                    return info.methodName;
                }
                if (info.kind === "a" /* Accessor */) {
                    if (isGetAccessor(node)) {
                        return info.getterName;
                    }
                    if (isSetAccessor(node)) {
                        return info.setterName;
                    }
                }
            }
            function transformAutoAccessor(node) {
                const commentRange = getCommentRange(node);
                const sourceMapRange = getSourceMapRange(node);
                const name = node.name;
                let getterName = name;
                let setterName = name;
                if (isComputedPropertyName(name) && !isSimpleInlineableExpression(name.expression)) {
                    const cacheAssignment = findComputedPropertyNameCacheAssignment(name);
                    if (cacheAssignment) {
                        getterName = factory2.updateComputedPropertyName(name, visitNode(name.expression, visitor, isExpression));
                        setterName = factory2.updateComputedPropertyName(name, cacheAssignment.left);
                    }
                    else {
                        const temp = factory2.createTempVariable(hoistVariableDeclaration);
                        setSourceMapRange(temp, name.expression);
                        const expression = visitNode(name.expression, visitor, isExpression);
                        const assignment = factory2.createAssignment(temp, expression);
                        setSourceMapRange(assignment, name.expression);
                        getterName = factory2.updateComputedPropertyName(name, assignment);
                        setterName = factory2.updateComputedPropertyName(name, temp);
                    }
                }
                const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const backingField = createAccessorPropertyBackingField(factory2, node, modifiers, node.initializer);
                setOriginalNode(backingField, node);
                setEmitFlags(backingField, 3072 /* NoComments */);
                setSourceMapRange(backingField, sourceMapRange);
                const getter = createAccessorPropertyGetRedirector(factory2, node, modifiers, getterName);
                setOriginalNode(getter, node);
                setCommentRange(getter, commentRange);
                setSourceMapRange(getter, sourceMapRange);
                const setter = createAccessorPropertySetRedirector(factory2, node, modifiers, setterName);
                setOriginalNode(setter, node);
                setEmitFlags(setter, 3072 /* NoComments */);
                setSourceMapRange(setter, sourceMapRange);
                return visitArray([backingField, getter, setter], accessorFieldResultVisitor, isClassElement);
            }
            function transformPrivateFieldInitializer(node) {
                if (shouldTransformClassElementToWeakMap(node)) {
                    const info = accessPrivateIdentifier2(node.name);
                    Debug.assert(info, "Undeclared private name for property declaration.");
                    if (!info.isValid) {
                        return node;
                    }
                    if (info.isStatic && !shouldTransformPrivateElementsOrClassStaticBlocks) {
                        const statement = transformPropertyOrClassStaticBlock(node, factory2.createThis());
                        if (statement) {
                            return factory2.createClassStaticBlockDeclaration(factory2.createBlock([statement], 
                            /*multiLine*/
                            true));
                        }
                    }
                    return void 0;
                }
                if (shouldTransformInitializersUsingSet && !isStatic(node) && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) && lexicalEnvironment.data.facts & 16 /* WillHoistInitializersToConstructor */) {
                    return factory2.updatePropertyDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.name, 
                    /*questionOrExclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0);
                }
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const { referencedName, name } = visitReferencedPropertyName(node.name);
                    return factory2.updatePropertyDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), name, 
                    /*questionOrExclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, visitNode(node.initializer, (child) => namedEvaluationVisitor(child, referencedName), isExpression));
                }
                return factory2.updatePropertyDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), visitNode(node.name, propertyNameVisitor, isPropertyName), 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
            }
            function transformPublicFieldInitializer(node) {
                if (shouldTransformInitializers && !isAutoAccessorPropertyDeclaration(node)) {
                    const expr = getPropertyNameExpressionIfNeeded(node.name, 
                    /*shouldHoist*/
                    !!node.initializer || useDefineForClassFields, 
                    /*captureReferencedName*/
                    isNamedEvaluation(node, isAnonymousClassNeedingAssignedName));
                    if (expr) {
                        getPendingExpressions().push(...flattenCommaList(expr));
                    }
                    if (isStatic(node) && !shouldTransformPrivateElementsOrClassStaticBlocks) {
                        const initializerStatement = transformPropertyOrClassStaticBlock(node, factory2.createThis());
                        if (initializerStatement) {
                            const staticBlock = factory2.createClassStaticBlockDeclaration(factory2.createBlock([initializerStatement]));
                            setOriginalNode(staticBlock, node);
                            setCommentRange(staticBlock, node);
                            setCommentRange(initializerStatement, { pos: -1, end: -1 });
                            setSyntheticLeadingComments(initializerStatement, void 0);
                            setSyntheticTrailingComments(initializerStatement, void 0);
                            return staticBlock;
                        }
                    }
                    return void 0;
                }
                return factory2.updatePropertyDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), visitNode(node.name, propertyNameVisitor, isPropertyName), 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
            }
            function transformFieldInitializer(node) {
                Debug.assert(!hasDecorators(node), "Decorators should already have been transformed and elided.");
                return isPrivateIdentifierClassElementDeclaration(node) ? transformPrivateFieldInitializer(node) : transformPublicFieldInitializer(node);
            }
            function shouldTransformAutoAccessorsInCurrentClass() {
                return shouldTransformAutoAccessors === -1 /* True */ || shouldTransformAutoAccessors === 3 /* Maybe */ && !!(lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) && !!(lexicalEnvironment.data.facts & 16 /* WillHoistInitializersToConstructor */);
            }
            function visitPropertyDeclaration(node) {
                if (isAutoAccessorPropertyDeclaration(node) && (shouldTransformAutoAccessorsInCurrentClass() || hasStaticModifier(node) && getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */)) {
                    return transformAutoAccessor(node);
                }
                return transformFieldInitializer(node);
            }
            function createPrivateIdentifierAccess(info, receiver) {
                return createPrivateIdentifierAccessHelper(info, visitNode(receiver, visitor, isExpression));
            }
            function createPrivateIdentifierAccessHelper(info, receiver) {
                setCommentRange(receiver, moveRangePos(receiver, -1));
                switch (info.kind) {
                    case "a" /* Accessor */:
                        return emitHelpers().createClassPrivateFieldGetHelper(receiver, info.brandCheckIdentifier, info.kind, info.getterName);
                    case "m" /* Method */:
                        return emitHelpers().createClassPrivateFieldGetHelper(receiver, info.brandCheckIdentifier, info.kind, info.methodName);
                    case "f" /* Field */:
                        return emitHelpers().createClassPrivateFieldGetHelper(receiver, info.brandCheckIdentifier, info.kind, info.isStatic ? info.variableName : void 0);
                    case "untransformed":
                        return Debug.fail("Access helpers should not be created for untransformed private elements");
                    default:
                        Debug.assertNever(info, "Unknown private element type");
                }
            }
            function visitPropertyAccessExpression(node) {
                if (isPrivateIdentifier(node.name)) {
                    const privateIdentifierInfo = accessPrivateIdentifier2(node.name);
                    if (privateIdentifierInfo) {
                        return setTextRange(setOriginalNode(createPrivateIdentifierAccess(privateIdentifierInfo, node.expression), node), node);
                    }
                }
                if (shouldTransformSuperInStaticInitializers && isSuperProperty(node) && isIdentifier(node.name) && currentStaticPropertyDeclarationOrStaticBlock && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                    const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                    if (facts & 1 /* ClassWasDecorated */) {
                        return visitInvalidSuperProperty(node);
                    }
                    if (classConstructor && superClassReference) {
                        const superProperty = factory2.createReflectGetCall(superClassReference, factory2.createStringLiteralFromNode(node.name), classConstructor);
                        setOriginalNode(superProperty, node.expression);
                        setTextRange(superProperty, node.expression);
                        return superProperty;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitElementAccessExpression(node) {
                if (shouldTransformSuperInStaticInitializers && isSuperProperty(node) && currentStaticPropertyDeclarationOrStaticBlock && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                    const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                    if (facts & 1 /* ClassWasDecorated */) {
                        return visitInvalidSuperProperty(node);
                    }
                    if (classConstructor && superClassReference) {
                        const superProperty = factory2.createReflectGetCall(superClassReference, visitNode(node.argumentExpression, visitor, isExpression), classConstructor);
                        setOriginalNode(superProperty, node.expression);
                        setTextRange(superProperty, node.expression);
                        return superProperty;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitPreOrPostfixUnaryExpression(node, discarded) {
                if (node.operator === 45 /* PlusPlusToken */ || node.operator === 46 /* MinusMinusToken */) {
                    const operand = skipParentheses(node.operand);
                    if (isPrivateIdentifierPropertyAccessExpression(operand)) {
                        let info;
                        if (info = accessPrivateIdentifier2(operand.name)) {
                            const receiver = visitNode(operand.expression, visitor, isExpression);
                            const { readExpression, initializeExpression } = createCopiableReceiverExpr(receiver);
                            let expression = createPrivateIdentifierAccess(info, readExpression);
                            const temp = isPrefixUnaryExpression(node) || discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                            expression = expandPreOrPostfixIncrementOrDecrementExpression(factory2, node, expression, hoistVariableDeclaration, temp);
                            expression = createPrivateIdentifierAssignment(info, initializeExpression || readExpression, expression, 63 /* EqualsToken */);
                            setOriginalNode(expression, node);
                            setTextRange(expression, node);
                            if (temp) {
                                expression = factory2.createComma(expression, temp);
                                setTextRange(expression, node);
                            }
                            return expression;
                        }
                    }
                    else if (shouldTransformSuperInStaticInitializers && isSuperProperty(operand) && currentStaticPropertyDeclarationOrStaticBlock && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                        const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                        if (facts & 1 /* ClassWasDecorated */) {
                            const expression = visitInvalidSuperProperty(operand);
                            return isPrefixUnaryExpression(node) ? factory2.updatePrefixUnaryExpression(node, expression) : factory2.updatePostfixUnaryExpression(node, expression);
                        }
                        if (classConstructor && superClassReference) {
                            let setterName;
                            let getterName;
                            if (isPropertyAccessExpression(operand)) {
                                if (isIdentifier(operand.name)) {
                                    getterName = setterName = factory2.createStringLiteralFromNode(operand.name);
                                }
                            }
                            else {
                                if (isSimpleInlineableExpression(operand.argumentExpression)) {
                                    getterName = setterName = operand.argumentExpression;
                                }
                                else {
                                    getterName = factory2.createTempVariable(hoistVariableDeclaration);
                                    setterName = factory2.createAssignment(getterName, visitNode(operand.argumentExpression, visitor, isExpression));
                                }
                            }
                            if (setterName && getterName) {
                                let expression = factory2.createReflectGetCall(superClassReference, getterName, classConstructor);
                                setTextRange(expression, operand);
                                const temp = discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                                expression = expandPreOrPostfixIncrementOrDecrementExpression(factory2, node, expression, hoistVariableDeclaration, temp);
                                expression = factory2.createReflectSetCall(superClassReference, setterName, expression, classConstructor);
                                setOriginalNode(expression, node);
                                setTextRange(expression, node);
                                if (temp) {
                                    expression = factory2.createComma(expression, temp);
                                    setTextRange(expression, node);
                                }
                                return expression;
                            }
                        }
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForStatement(node) {
                return factory2.updateForStatement(node, visitNode(node.initializer, discardedValueVisitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, discardedValueVisitor, isExpression), visitIterationBody(node.statement, visitor, context));
            }
            function visitExpressionStatement(node) {
                return factory2.updateExpressionStatement(node, visitNode(node.expression, discardedValueVisitor, isExpression));
            }
            function createCopiableReceiverExpr(receiver) {
                const clone2 = nodeIsSynthesized(receiver) ? receiver : factory2.cloneNode(receiver);
                if (isSimpleInlineableExpression(receiver)) {
                    return { readExpression: clone2, initializeExpression: void 0 };
                }
                const readExpression = factory2.createTempVariable(hoistVariableDeclaration);
                const initializeExpression = factory2.createAssignment(readExpression, clone2);
                return { readExpression, initializeExpression };
            }
            function visitCallExpression(node) {
                var _a2;
                if (isPrivateIdentifierPropertyAccessExpression(node.expression) && accessPrivateIdentifier2(node.expression.name)) {
                    const { thisArg, target } = factory2.createCallBinding(node.expression, hoistVariableDeclaration, languageVersion);
                    if (isCallChain(node)) {
                        return factory2.updateCallChain(node, factory2.createPropertyAccessChain(visitNode(target, visitor, isExpression), node.questionDotToken, "call"), 
                        /*questionDotToken*/
                        void 0, 
                        /*typeArguments*/
                        void 0, [visitNode(thisArg, visitor, isExpression), ...visitNodes2(node.arguments, visitor, isExpression)]);
                    }
                    return factory2.updateCallExpression(node, factory2.createPropertyAccessExpression(visitNode(target, visitor, isExpression), "call"), 
                    /*typeArguments*/
                    void 0, [visitNode(thisArg, visitor, isExpression), ...visitNodes2(node.arguments, visitor, isExpression)]);
                }
                if (shouldTransformSuperInStaticInitializers && isSuperProperty(node.expression) && currentStaticPropertyDeclarationOrStaticBlock && ((_a2 = lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) == null ? void 0 : _a2.classConstructor)) {
                    const invocation = factory2.createFunctionCallCall(visitNode(node.expression, visitor, isExpression), lexicalEnvironment.data.classConstructor, visitNodes2(node.arguments, visitor, isExpression));
                    setOriginalNode(invocation, node);
                    setTextRange(invocation, node);
                    return invocation;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitTaggedTemplateExpression(node) {
                var _a2;
                if (isPrivateIdentifierPropertyAccessExpression(node.tag) && accessPrivateIdentifier2(node.tag.name)) {
                    const { thisArg, target } = factory2.createCallBinding(node.tag, hoistVariableDeclaration, languageVersion);
                    return factory2.updateTaggedTemplateExpression(node, factory2.createCallExpression(factory2.createPropertyAccessExpression(visitNode(target, visitor, isExpression), "bind"), 
                    /*typeArguments*/
                    void 0, [visitNode(thisArg, visitor, isExpression)]), 
                    /*typeArguments*/
                    void 0, visitNode(node.template, visitor, isTemplateLiteral));
                }
                if (shouldTransformSuperInStaticInitializers && isSuperProperty(node.tag) && currentStaticPropertyDeclarationOrStaticBlock && ((_a2 = lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) == null ? void 0 : _a2.classConstructor)) {
                    const invocation = factory2.createFunctionBindCall(visitNode(node.tag, visitor, isExpression), lexicalEnvironment.data.classConstructor, []);
                    setOriginalNode(invocation, node);
                    setTextRange(invocation, node);
                    return factory2.updateTaggedTemplateExpression(node, invocation, 
                    /*typeArguments*/
                    void 0, visitNode(node.template, visitor, isTemplateLiteral));
                }
                return visitEachChild(node, visitor, context);
            }
            function transformClassStaticBlockDeclaration(node) {
                if (lexicalEnvironment) {
                    lexicalEnvironmentMap.set(getOriginalNode(node), lexicalEnvironment);
                }
                if (shouldTransformPrivateElementsOrClassStaticBlocks) {
                    startLexicalEnvironment();
                    let statements = setCurrentStaticPropertyDeclarationOrStaticBlockAnd(node, (statements2) => visitNodes2(statements2, visitor, isStatement), node.body.statements);
                    statements = factory2.mergeLexicalEnvironment(statements, endLexicalEnvironment());
                    const iife = factory2.createImmediatelyInvokedArrowFunction(statements);
                    setOriginalNode(iife, node);
                    setTextRange(iife, node);
                    addEmitFlags(iife, 4 /* AdviseOnEmitNode */);
                    return iife;
                }
            }
            function isAnonymousClassNeedingAssignedName(node) {
                if (isClassExpression(node) && !node.name) {
                    const staticPropertiesOrClassStaticBlocks = getStaticPropertiesAndClassStaticBlock(node);
                    const classStaticBlock = find(staticPropertiesOrClassStaticBlocks, isClassStaticBlockDeclaration);
                    if (classStaticBlock) {
                        for (const statement of classStaticBlock.body.statements) {
                            if (isExpressionStatement(statement) && isCallToHelper(statement.expression, "___setFunctionName")) {
                                return false;
                            }
                        }
                    }
                    const hasTransformableStatics = (shouldTransformPrivateElementsOrClassStaticBlocks || !!(getInternalEmitFlags(node) && 32 /* TransformPrivateStaticElements */)) && some(staticPropertiesOrClassStaticBlocks, (node2) => isClassStaticBlockDeclaration(node2) || isPrivateIdentifierClassElementDeclaration(node2) || shouldTransformInitializers && isInitializedProperty(node2));
                    return hasTransformableStatics;
                }
                return false;
            }
            function visitBinaryExpression(node, discarded) {
                if (isDestructuringAssignment(node)) {
                    const savedPendingExpressions = pendingExpressions;
                    pendingExpressions = void 0;
                    node = factory2.updateBinaryExpression(node, visitNode(node.left, assignmentTargetVisitor, isExpression), node.operatorToken, visitNode(node.right, visitor, isExpression));
                    const expr = some(pendingExpressions) ? factory2.inlineExpressions(compact([...pendingExpressions, node])) : node;
                    pendingExpressions = savedPendingExpressions;
                    return expr;
                }
                if (isAssignmentExpression(node)) {
                    if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                        const assignedName = getAssignedNameOfIdentifier(node.left, node.right);
                        const left = visitNode(node.left, visitor, isExpression);
                        const right = visitNode(node.right, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                        return factory2.updateBinaryExpression(node, left, node.operatorToken, right);
                    }
                    if (isPrivateIdentifierPropertyAccessExpression(node.left)) {
                        const info = accessPrivateIdentifier2(node.left.name);
                        if (info) {
                            return setTextRange(setOriginalNode(createPrivateIdentifierAssignment(info, node.left.expression, node.right, node.operatorToken.kind), node), node);
                        }
                    }
                    else if (shouldTransformSuperInStaticInitializers && isSuperProperty(node.left) && currentStaticPropertyDeclarationOrStaticBlock && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                        const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                        if (facts & 1 /* ClassWasDecorated */) {
                            return factory2.updateBinaryExpression(node, visitInvalidSuperProperty(node.left), node.operatorToken, visitNode(node.right, visitor, isExpression));
                        }
                        if (classConstructor && superClassReference) {
                            let setterName = isElementAccessExpression(node.left) ? visitNode(node.left.argumentExpression, visitor, isExpression) : isIdentifier(node.left.name) ? factory2.createStringLiteralFromNode(node.left.name) : void 0;
                            if (setterName) {
                                let expression = visitNode(node.right, visitor, isExpression);
                                if (isCompoundAssignment(node.operatorToken.kind)) {
                                    let getterName = setterName;
                                    if (!isSimpleInlineableExpression(setterName)) {
                                        getterName = factory2.createTempVariable(hoistVariableDeclaration);
                                        setterName = factory2.createAssignment(getterName, setterName);
                                    }
                                    const superPropertyGet = factory2.createReflectGetCall(superClassReference, getterName, classConstructor);
                                    setOriginalNode(superPropertyGet, node.left);
                                    setTextRange(superPropertyGet, node.left);
                                    expression = factory2.createBinaryExpression(superPropertyGet, getNonAssignmentOperatorForCompoundAssignment(node.operatorToken.kind), expression);
                                    setTextRange(expression, node);
                                }
                                const temp = discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                                if (temp) {
                                    expression = factory2.createAssignment(temp, expression);
                                    setTextRange(temp, node);
                                }
                                expression = factory2.createReflectSetCall(superClassReference, setterName, expression, classConstructor);
                                setOriginalNode(expression, node);
                                setTextRange(expression, node);
                                if (temp) {
                                    expression = factory2.createComma(expression, temp);
                                    setTextRange(expression, node);
                                }
                                return expression;
                            }
                        }
                    }
                }
                if (isPrivateIdentifierInExpression(node)) {
                    return transformPrivateIdentifierInInExpression(node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaListExpression(node, discarded) {
                const elements = discarded ? visitCommaListElements(node.elements, discardedValueVisitor) : visitCommaListElements(node.elements, visitor, discardedValueVisitor);
                return factory2.updateCommaListExpression(node, elements);
            }
            function visitParenthesizedExpression(node, discarded, referencedName) {
                const visitorFunc = discarded ? discardedValueVisitor : referencedName ? (node2) => namedEvaluationVisitor(node2, referencedName) : visitor;
                const expression = visitNode(node.expression, visitorFunc, isExpression);
                return factory2.updateParenthesizedExpression(node, expression);
            }
            function visitPartiallyEmittedExpression(node, discarded, referencedName) {
                const visitorFunc = discarded ? discardedValueVisitor : referencedName ? (node2) => namedEvaluationVisitor(node2, referencedName) : visitor;
                const expression = visitNode(node.expression, visitorFunc, isExpression);
                return factory2.updatePartiallyEmittedExpression(node, expression);
            }
            function visitReferencedPropertyName(node) {
                if (isPropertyNameLiteral(node) || isPrivateIdentifier(node)) {
                    const referencedName2 = factory2.createStringLiteralFromNode(node);
                    const name2 = visitNode(node, visitor, isPropertyName);
                    return { referencedName: referencedName2, name: name2 };
                }
                if (isPropertyNameLiteral(node.expression) && !isIdentifier(node.expression)) {
                    const referencedName2 = factory2.createStringLiteralFromNode(node.expression);
                    const name2 = visitNode(node, visitor, isPropertyName);
                    return { referencedName: referencedName2, name: name2 };
                }
                const referencedName = factory2.createTempVariable(hoistVariableDeclaration);
                const key = emitHelpers().createPropKeyHelper(visitNode(node.expression, visitor, isExpression));
                const assignment = factory2.createAssignment(referencedName, key);
                const name = factory2.updateComputedPropertyName(node, injectPendingExpressions(assignment));
                return { referencedName, name };
            }
            function createPrivateIdentifierAssignment(info, receiver, right, operator) {
                receiver = visitNode(receiver, visitor, isExpression);
                right = visitNode(right, visitor, isExpression);
                if (isCompoundAssignment(operator)) {
                    const { readExpression, initializeExpression } = createCopiableReceiverExpr(receiver);
                    receiver = initializeExpression || readExpression;
                    right = factory2.createBinaryExpression(createPrivateIdentifierAccessHelper(info, readExpression), getNonAssignmentOperatorForCompoundAssignment(operator), right);
                }
                setCommentRange(receiver, moveRangePos(receiver, -1));
                switch (info.kind) {
                    case "a" /* Accessor */:
                        return emitHelpers().createClassPrivateFieldSetHelper(receiver, info.brandCheckIdentifier, right, info.kind, info.setterName);
                    case "m" /* Method */:
                        return emitHelpers().createClassPrivateFieldSetHelper(receiver, info.brandCheckIdentifier, right, info.kind, 
                        /* f */
                        void 0);
                    case "f" /* Field */:
                        return emitHelpers().createClassPrivateFieldSetHelper(receiver, info.brandCheckIdentifier, right, info.kind, info.isStatic ? info.variableName : void 0);
                    case "untransformed":
                        return Debug.fail("Access helpers should not be created for untransformed private elements");
                    default:
                        Debug.assertNever(info, "Unknown private element type");
                }
            }
            function getPrivateInstanceMethodsAndAccessors(node) {
                return filter(node.members, isNonStaticMethodOrAccessorWithPrivateName);
            }
            function getClassFacts(node) {
                let facts = 0 /* None */;
                const original = getOriginalNode(node);
                if (isClassDeclaration(original) && classOrConstructorParameterIsDecorated(legacyDecorators, original)) {
                    facts |= 1 /* ClassWasDecorated */;
                }
                let containsPublicInstanceFields = false;
                let containsInitializedPublicInstanceFields = false;
                let containsInstancePrivateElements = false;
                let containsInstanceAutoAccessors = false;
                for (const member of node.members) {
                    if (isStatic(member)) {
                        if (member.name && (isPrivateIdentifier(member.name) || isAutoAccessorPropertyDeclaration(member)) && shouldTransformPrivateElementsOrClassStaticBlocks) {
                            facts |= 2 /* NeedsClassConstructorReference */;
                        }
                        if (isPropertyDeclaration(member) || isClassStaticBlockDeclaration(member)) {
                            if (shouldTransformThisInStaticInitializers && member.transformFlags & 16384 /* ContainsLexicalThis */) {
                                facts |= 8 /* NeedsSubstitutionForThisInClassStaticField */;
                                if (!(facts & 1 /* ClassWasDecorated */)) {
                                    facts |= 2 /* NeedsClassConstructorReference */;
                                }
                            }
                            if (shouldTransformSuperInStaticInitializers && member.transformFlags & 134217728 /* ContainsLexicalSuper */) {
                                if (!(facts & 1 /* ClassWasDecorated */)) {
                                    facts |= 2 /* NeedsClassConstructorReference */ | 4 /* NeedsClassSuperReference */;
                                }
                            }
                        }
                    }
                    else if (!hasAbstractModifier(getOriginalNode(member))) {
                        if (isAutoAccessorPropertyDeclaration(member)) {
                            containsInstanceAutoAccessors = true;
                            containsInstancePrivateElements || (containsInstancePrivateElements = isPrivateIdentifierClassElementDeclaration(member));
                        }
                        else if (isPrivateIdentifierClassElementDeclaration(member)) {
                            containsInstancePrivateElements = true;
                        }
                        else if (isPropertyDeclaration(member)) {
                            containsPublicInstanceFields = true;
                            containsInitializedPublicInstanceFields || (containsInitializedPublicInstanceFields = !!member.initializer);
                        }
                    }
                }
                const willHoistInitializersToConstructor = shouldTransformInitializersUsingDefine && containsPublicInstanceFields || shouldTransformInitializersUsingSet && containsInitializedPublicInstanceFields || shouldTransformPrivateElementsOrClassStaticBlocks && containsInstancePrivateElements || shouldTransformPrivateElementsOrClassStaticBlocks && containsInstanceAutoAccessors && shouldTransformAutoAccessors === -1 /* True */;
                if (willHoistInitializersToConstructor) {
                    facts |= 16 /* WillHoistInitializersToConstructor */;
                }
                return facts;
            }
            function visitExpressionWithTypeArgumentsInHeritageClause(node) {
                var _a2;
                const facts = ((_a2 = lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) == null ? void 0 : _a2.facts) || 0 /* None */;
                if (facts & 4 /* NeedsClassSuperReference */) {
                    const temp = factory2.createTempVariable(hoistVariableDeclaration, 
                    /*reserveInNestedScopes*/
                    true);
                    getClassLexicalEnvironment().superClassReference = temp;
                    return factory2.updateExpressionWithTypeArguments(node, factory2.createAssignment(temp, visitNode(node.expression, visitor, isExpression)), 
                    /*typeArguments*/
                    void 0);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitInNewClassLexicalEnvironment(node, referencedName, visitor2) {
                const savedCurrentClassContainer = currentClassContainer;
                const savedPendingExpressions = pendingExpressions;
                const savedLexicalEnvironment = lexicalEnvironment;
                currentClassContainer = node;
                pendingExpressions = void 0;
                startClassLexicalEnvironment();
                const shouldAlwaysTransformPrivateStaticElements = getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */;
                if (shouldTransformPrivateElementsOrClassStaticBlocks || shouldAlwaysTransformPrivateStaticElements) {
                    const name = getNameOfDeclaration(node);
                    if (name && isIdentifier(name)) {
                        getPrivateIdentifierEnvironment().data.className = name;
                    }
                }
                if (shouldTransformPrivateElementsOrClassStaticBlocks) {
                    const privateInstanceMethodsAndAccessors = getPrivateInstanceMethodsAndAccessors(node);
                    if (some(privateInstanceMethodsAndAccessors)) {
                        getPrivateIdentifierEnvironment().data.weakSetName = createHoistedVariableForClass("instances", privateInstanceMethodsAndAccessors[0].name);
                    }
                }
                const facts = getClassFacts(node);
                if (facts) {
                    getClassLexicalEnvironment().facts = facts;
                }
                if (facts & 8 /* NeedsSubstitutionForThisInClassStaticField */) {
                    enableSubstitutionForClassStaticThisOrSuperReference();
                }
                const result = visitor2(node, facts, referencedName);
                endClassLexicalEnvironment();
                Debug.assert(lexicalEnvironment === savedLexicalEnvironment);
                currentClassContainer = savedCurrentClassContainer;
                pendingExpressions = savedPendingExpressions;
                return result;
            }
            function visitClassDeclaration(node) {
                return visitInNewClassLexicalEnvironment(node, 
                /*referencedName*/
                void 0, visitClassDeclarationInNewClassLexicalEnvironment);
            }
            function visitClassDeclarationInNewClassLexicalEnvironment(node, facts) {
                var _a2, _b;
                let pendingClassReferenceAssignment;
                if (facts & 2 /* NeedsClassConstructorReference */) {
                    if (shouldTransformPrivateElementsOrClassStaticBlocks && ((_a2 = node.emitNode) == null ? void 0 : _a2.classThis)) {
                        getClassLexicalEnvironment().classConstructor = node.emitNode.classThis;
                        pendingClassReferenceAssignment = factory2.createAssignment(node.emitNode.classThis, factory2.getInternalName(node));
                    }
                    else {
                        const temp = factory2.createTempVariable(hoistVariableDeclaration, 
                        /*reservedInNestedScopes*/
                        true);
                        getClassLexicalEnvironment().classConstructor = factory2.cloneNode(temp);
                        pendingClassReferenceAssignment = factory2.createAssignment(temp, factory2.getInternalName(node));
                    }
                    if ((_b = node.emitNode) == null ? void 0 : _b.classThis) {
                        getClassLexicalEnvironment().classThis = node.emitNode.classThis;
                    }
                }
                const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const heritageClauses = visitNodes2(node.heritageClauses, heritageClauseVisitor, isHeritageClause);
                const { members, prologue } = transformClassMembers(node);
                const classDecl = factory2.updateClassDeclaration(node, modifiers, node.name, 
                /*typeParameters*/
                void 0, heritageClauses, members);
                const statements = [];
                if (prologue) {
                    statements.push(factory2.createExpressionStatement(prologue));
                }
                statements.push(classDecl);
                if (pendingClassReferenceAssignment) {
                    getPendingExpressions().unshift(pendingClassReferenceAssignment);
                }
                if (some(pendingExpressions)) {
                    statements.push(factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions)));
                }
                if (shouldTransformInitializersUsingSet || shouldTransformPrivateElementsOrClassStaticBlocks || getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */) {
                    const staticProperties = getStaticPropertiesAndClassStaticBlock(node);
                    if (some(staticProperties)) {
                        addPropertyOrClassStaticBlockStatements(statements, staticProperties, factory2.getInternalName(node));
                    }
                }
                return statements;
            }
            function visitClassExpression(node, referencedName) {
                return visitInNewClassLexicalEnvironment(node, referencedName, visitClassExpressionInNewClassLexicalEnvironment);
            }
            function visitClassExpressionInNewClassLexicalEnvironment(node, facts, referencedName) {
                var _a2, _b, _c, _d, _e, _f;
                const isDecoratedClassDeclaration = !!(facts & 1 /* ClassWasDecorated */);
                const staticPropertiesOrClassStaticBlocks = getStaticPropertiesAndClassStaticBlock(node);
                const isClassWithConstructorReference = resolver.getNodeCheckFlags(node) & 1048576 /* ClassWithConstructorReference */;
                let temp;
                function createClassTempVar() {
                    var _a3;
                    if (shouldTransformPrivateElementsOrClassStaticBlocks && ((_a3 = node.emitNode) == null ? void 0 : _a3.classThis)) {
                        return getClassLexicalEnvironment().classConstructor = node.emitNode.classThis;
                    }
                    const classCheckFlags = resolver.getNodeCheckFlags(node);
                    const isClassWithConstructorReference2 = classCheckFlags & 1048576 /* ClassWithConstructorReference */;
                    const requiresBlockScopedVar = classCheckFlags & 32768 /* BlockScopedBindingInLoop */;
                    const temp2 = factory2.createTempVariable(requiresBlockScopedVar ? addBlockScopedVariable : hoistVariableDeclaration, !!isClassWithConstructorReference2);
                    getClassLexicalEnvironment().classConstructor = factory2.cloneNode(temp2);
                    return temp2;
                }
                if ((_a2 = node.emitNode) == null ? void 0 : _a2.classThis) {
                    getClassLexicalEnvironment().classThis = node.emitNode.classThis;
                }
                if (facts & 2 /* NeedsClassConstructorReference */) {
                    temp != null ? temp : temp = createClassTempVar();
                }
                const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const heritageClauses = visitNodes2(node.heritageClauses, heritageClauseVisitor, isHeritageClause);
                const { members, prologue } = transformClassMembers(node);
                let classExpression = factory2.updateClassExpression(node, modifiers, node.name, 
                /*typeParameters*/
                void 0, heritageClauses, members);
                const expressions = [];
                if (prologue) {
                    expressions.push(prologue);
                }
                const hasTransformableStatics = (shouldTransformPrivateElementsOrClassStaticBlocks || getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */) && some(staticPropertiesOrClassStaticBlocks, (node2) => isClassStaticBlockDeclaration(node2) || isPrivateIdentifierClassElementDeclaration(node2) || shouldTransformInitializers && isInitializedProperty(node2));
                if (hasTransformableStatics || some(pendingExpressions) || referencedName) {
                    if (isDecoratedClassDeclaration) {
                        Debug.assertIsDefined(pendingStatements, "Decorated classes transformed by TypeScript are expected to be within a variable declaration.");
                        if (some(pendingExpressions)) {
                            addRange(pendingStatements, map(pendingExpressions, factory2.createExpressionStatement));
                        }
                        if (referencedName) {
                            if (shouldTransformPrivateElementsOrClassStaticBlocks) {
                                const setNameExpression = emitHelpers().createSetFunctionNameHelper((_c = temp != null ? temp : (_b = node.emitNode) == null ? void 0 : _b.classThis) != null ? _c : factory2.getInternalName(node), referencedName);
                                pendingStatements.push(factory2.createExpressionStatement(setNameExpression));
                            }
                            else {
                                const setNameExpression = emitHelpers().createSetFunctionNameHelper(factory2.createThis(), referencedName);
                                classExpression = factory2.updateClassExpression(classExpression, classExpression.modifiers, classExpression.name, classExpression.typeParameters, classExpression.heritageClauses, [
                                    factory2.createClassStaticBlockDeclaration(factory2.createBlock([
                                        factory2.createExpressionStatement(setNameExpression)
                                    ])),
                                    ...classExpression.members
                                ]);
                            }
                        }
                        if (some(staticPropertiesOrClassStaticBlocks)) {
                            addPropertyOrClassStaticBlockStatements(pendingStatements, staticPropertiesOrClassStaticBlocks, (_e = (_d = node.emitNode) == null ? void 0 : _d.classThis) != null ? _e : factory2.getInternalName(node));
                        }
                        if (temp) {
                            expressions.push(factory2.createAssignment(temp, classExpression));
                        }
                        else if (shouldTransformPrivateElementsOrClassStaticBlocks && ((_f = node.emitNode) == null ? void 0 : _f.classThis)) {
                            expressions.push(factory2.createAssignment(node.emitNode.classThis, classExpression));
                        }
                        else {
                            expressions.push(classExpression);
                        }
                    }
                    else {
                        temp != null ? temp : temp = createClassTempVar();
                        if (isClassWithConstructorReference) {
                            enableSubstitutionForClassAliases();
                            const alias = factory2.cloneNode(temp);
                            alias.emitNode.autoGenerate.flags &= ~8 /* ReservedInNestedScopes */;
                            classAliases[getOriginalNodeId(node)] = alias;
                        }
                        expressions.push(factory2.createAssignment(temp, classExpression));
                        addRange(expressions, pendingExpressions);
                        if (referencedName) {
                            expressions.push(emitHelpers().createSetFunctionNameHelper(temp, referencedName));
                        }
                        addRange(expressions, generateInitializedPropertyExpressionsOrClassStaticBlock(staticPropertiesOrClassStaticBlocks, temp));
                        expressions.push(factory2.cloneNode(temp));
                    }
                }
                else {
                    expressions.push(classExpression);
                }
                if (expressions.length > 1) {
                    addEmitFlags(classExpression, 131072 /* Indented */);
                    expressions.forEach(startOnNewLine);
                }
                return factory2.inlineExpressions(expressions);
            }
            function visitClassStaticBlockDeclaration(node) {
                if (!shouldTransformPrivateElementsOrClassStaticBlocks) {
                    return visitEachChild(node, visitor, context);
                }
                return void 0;
            }
            function transformClassMembers(node) {
                const shouldTransformPrivateStaticElementsInClass = !!(getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */);
                if (shouldTransformPrivateElementsOrClassStaticBlocks || shouldTransformPrivateStaticElementsInFile) {
                    for (const member of node.members) {
                        if (isPrivateIdentifierClassElementDeclaration(member)) {
                            if (shouldTransformClassElementToWeakMap(member)) {
                                addPrivateIdentifierToEnvironment(member, member.name, addPrivateIdentifierClassElementToEnvironment);
                            }
                            else {
                                const privateEnv = getPrivateIdentifierEnvironment();
                                setPrivateIdentifier(privateEnv, member.name, { kind: "untransformed" });
                            }
                        }
                    }
                    if (shouldTransformPrivateElementsOrClassStaticBlocks) {
                        if (some(getPrivateInstanceMethodsAndAccessors(node))) {
                            createBrandCheckWeakSetForPrivateMethods();
                        }
                    }
                    if (shouldTransformAutoAccessorsInCurrentClass()) {
                        for (const member of node.members) {
                            if (isAutoAccessorPropertyDeclaration(member)) {
                                const storageName = factory2.getGeneratedPrivateNameForNode(member.name, 
                                /*prefix*/
                                void 0, "_accessor_storage");
                                if (shouldTransformPrivateElementsOrClassStaticBlocks || shouldTransformPrivateStaticElementsInClass && hasStaticModifier(member)) {
                                    addPrivateIdentifierToEnvironment(member, storageName, addPrivateIdentifierPropertyDeclarationToEnvironment);
                                }
                                else {
                                    const privateEnv = getPrivateIdentifierEnvironment();
                                    setPrivateIdentifier(privateEnv, storageName, { kind: "untransformed" });
                                }
                            }
                        }
                    }
                }
                let members = visitNodes2(node.members, classElementVisitor, isClassElement);
                let syntheticConstructor;
                if (!some(members, isConstructorDeclaration)) {
                    syntheticConstructor = transformConstructor(
                    /*constructor*/
                    void 0, node);
                }
                let prologue;
                let syntheticStaticBlock;
                if (!shouldTransformPrivateElementsOrClassStaticBlocks && some(pendingExpressions)) {
                    let statement = factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions));
                    if (statement.transformFlags & 134234112 /* ContainsLexicalThisOrSuper */) {
                        const temp = factory2.createTempVariable(hoistVariableDeclaration);
                        const arrow = factory2.createArrowFunction(
                        /*modifiers*/
                        void 0, 
                        /*typeParameters*/
                        void 0, 
                        /*parameters*/
                        [], 
                        /*type*/
                        void 0, 
                        /*equalsGreaterThanToken*/
                        void 0, factory2.createBlock([statement]));
                        prologue = factory2.createAssignment(temp, arrow);
                        statement = factory2.createExpressionStatement(factory2.createCallExpression(temp, 
                        /*typeArguments*/
                        void 0, []));
                    }
                    const block = factory2.createBlock([statement]);
                    syntheticStaticBlock = factory2.createClassStaticBlockDeclaration(block);
                    pendingExpressions = void 0;
                }
                if (syntheticConstructor || syntheticStaticBlock) {
                    let membersArray;
                    membersArray = append(membersArray, syntheticConstructor);
                    membersArray = append(membersArray, syntheticStaticBlock);
                    membersArray = addRange(membersArray, members);
                    members = setTextRange(factory2.createNodeArray(membersArray), 
                    /*location*/
                    node.members);
                }
                return { members, prologue };
            }
            function createBrandCheckWeakSetForPrivateMethods() {
                const { weakSetName } = getPrivateIdentifierEnvironment().data;
                Debug.assert(weakSetName, "weakSetName should be set in private identifier environment");
                getPendingExpressions().push(factory2.createAssignment(weakSetName, factory2.createNewExpression(factory2.createIdentifier("WeakSet"), 
                /*typeArguments*/
                void 0, [])));
            }
            function transformConstructor(constructor, container) {
                constructor = visitNode(constructor, visitor, isConstructorDeclaration);
                if (!(lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) || !(lexicalEnvironment.data.facts & 16 /* WillHoistInitializersToConstructor */)) {
                    return constructor;
                }
                const extendsClauseElement = getEffectiveBaseTypeNode(container);
                const isDerivedClass = !!(extendsClauseElement && skipOuterExpressions(extendsClauseElement.expression).kind !== 104 /* NullKeyword */);
                const parameters = visitParameterList(constructor ? constructor.parameters : void 0, visitor, context);
                const body = transformConstructorBody(container, constructor, isDerivedClass);
                if (!body) {
                    return constructor;
                }
                if (constructor) {
                    Debug.assert(parameters);
                    return factory2.updateConstructorDeclaration(constructor, 
                    /*modifiers*/
                    void 0, parameters, body);
                }
                return startOnNewLine(setOriginalNode(setTextRange(factory2.createConstructorDeclaration(
                /*modifiers*/
                void 0, parameters != null ? parameters : [], body), constructor || container), constructor));
            }
            function transformConstructorBody(node, constructor, isDerivedClass) {
                var _a2, _b;
                const instanceProperties = getProperties(node, 
                /*requireInitializer*/
                false, 
                /*isStatic*/
                false);
                let properties = instanceProperties;
                if (!useDefineForClassFields) {
                    properties = filter(properties, (property) => !!property.initializer || isPrivateIdentifier(property.name) || hasAccessorModifier(property));
                }
                const privateMethodsAndAccessors = getPrivateInstanceMethodsAndAccessors(node);
                const needsConstructorBody = some(properties) || some(privateMethodsAndAccessors);
                if (!constructor && !needsConstructorBody) {
                    return visitFunctionBody(
                    /*node*/
                    void 0, visitor, context);
                }
                resumeLexicalEnvironment();
                const needsSyntheticConstructor = !constructor && isDerivedClass;
                let indexOfFirstStatementAfterSuperAndPrologue = 0;
                let prologueStatementCount = 0;
                let superStatementIndex = -1;
                let statements = [];
                if ((_a2 = constructor == null ? void 0 : constructor.body) == null ? void 0 : _a2.statements) {
                    prologueStatementCount = factory2.copyPrologue(constructor.body.statements, statements, 
                    /*ensureUseStrict*/
                    false, visitor);
                    superStatementIndex = findSuperStatementIndex(constructor.body.statements, prologueStatementCount);
                    if (superStatementIndex >= 0) {
                        indexOfFirstStatementAfterSuperAndPrologue = superStatementIndex + 1;
                        statements = [
                            ...statements.slice(0, prologueStatementCount),
                            ...visitNodes2(constructor.body.statements, visitor, isStatement, prologueStatementCount, indexOfFirstStatementAfterSuperAndPrologue - prologueStatementCount),
                            ...statements.slice(prologueStatementCount)
                        ];
                    }
                    else if (prologueStatementCount >= 0) {
                        indexOfFirstStatementAfterSuperAndPrologue = prologueStatementCount;
                    }
                }
                if (needsSyntheticConstructor) {
                    statements.push(factory2.createExpressionStatement(factory2.createCallExpression(factory2.createSuper(), 
                    /*typeArguments*/
                    void 0, [factory2.createSpreadElement(factory2.createIdentifier("arguments"))])));
                }
                let parameterPropertyDeclarationCount = 0;
                if (constructor == null ? void 0 : constructor.body) {
                    for (let i = indexOfFirstStatementAfterSuperAndPrologue; i < constructor.body.statements.length; i++) {
                        const statement = constructor.body.statements[i];
                        if (isParameterPropertyDeclaration(getOriginalNode(statement), constructor)) {
                            parameterPropertyDeclarationCount++;
                        }
                        else {
                            break;
                        }
                    }
                    if (parameterPropertyDeclarationCount > 0) {
                        indexOfFirstStatementAfterSuperAndPrologue += parameterPropertyDeclarationCount;
                    }
                }
                const receiver = factory2.createThis();
                addInstanceMethodStatements(statements, privateMethodsAndAccessors, receiver);
                if (constructor) {
                    const parameterProperties = filter(instanceProperties, (prop) => isParameterPropertyDeclaration(getOriginalNode(prop), constructor));
                    const nonParameterProperties = filter(properties, (prop) => !isParameterPropertyDeclaration(getOriginalNode(prop), constructor));
                    addPropertyOrClassStaticBlockStatements(statements, parameterProperties, receiver);
                    addPropertyOrClassStaticBlockStatements(statements, nonParameterProperties, receiver);
                }
                else {
                    addPropertyOrClassStaticBlockStatements(statements, properties, receiver);
                }
                if (constructor) {
                    addRange(statements, visitNodes2(constructor.body.statements, visitor, isStatement, indexOfFirstStatementAfterSuperAndPrologue));
                }
                statements = factory2.mergeLexicalEnvironment(statements, endLexicalEnvironment());
                if (statements.length === 0 && !constructor) {
                    return void 0;
                }
                const multiLine = (constructor == null ? void 0 : constructor.body) && constructor.body.statements.length >= statements.length ? (_b = constructor.body.multiLine) != null ? _b : statements.length > 0 : statements.length > 0;
                return setTextRange(factory2.createBlock(setTextRange(factory2.createNodeArray(statements), 
                /*location*/
                constructor ? constructor.body.statements : node.members), multiLine), 
                /*location*/
                constructor ? constructor.body : void 0);
            }
            function addPropertyOrClassStaticBlockStatements(statements, properties, receiver) {
                for (const property of properties) {
                    if (isStatic(property) && !shouldTransformPrivateElementsOrClassStaticBlocks) {
                        continue;
                    }
                    const statement = transformPropertyOrClassStaticBlock(property, receiver);
                    if (!statement) {
                        continue;
                    }
                    statements.push(statement);
                }
            }
            function transformPropertyOrClassStaticBlock(property, receiver) {
                const expression = isClassStaticBlockDeclaration(property) ? transformClassStaticBlockDeclaration(property) : transformProperty(property, receiver);
                if (!expression) {
                    return void 0;
                }
                const statement = factory2.createExpressionStatement(expression);
                setOriginalNode(statement, property);
                addEmitFlags(statement, getEmitFlags(property) & 3072 /* NoComments */);
                setCommentRange(statement, property);
                const propertyOriginalNode = getOriginalNode(property);
                if (isParameter(propertyOriginalNode)) {
                    setSourceMapRange(statement, propertyOriginalNode);
                    removeAllComments(statement);
                }
                else {
                    setSourceMapRange(statement, moveRangePastModifiers(property));
                }
                setSyntheticLeadingComments(expression, void 0);
                setSyntheticTrailingComments(expression, void 0);
                if (hasAccessorModifier(propertyOriginalNode)) {
                    addEmitFlags(statement, 3072 /* NoComments */);
                }
                return statement;
            }
            function generateInitializedPropertyExpressionsOrClassStaticBlock(propertiesOrClassStaticBlocks, receiver) {
                const expressions = [];
                for (const property of propertiesOrClassStaticBlocks) {
                    const expression = isClassStaticBlockDeclaration(property) ? transformClassStaticBlockDeclaration(property) : transformProperty(property, receiver);
                    if (!expression) {
                        continue;
                    }
                    startOnNewLine(expression);
                    setOriginalNode(expression, property);
                    addEmitFlags(expression, getEmitFlags(property) & 3072 /* NoComments */);
                    setSourceMapRange(expression, moveRangePastModifiers(property));
                    setCommentRange(expression, property);
                    expressions.push(expression);
                }
                return expressions;
            }
            function transformProperty(property, receiver) {
                var _a2;
                const savedCurrentStaticPropertyDeclarationOrStaticBlock = currentStaticPropertyDeclarationOrStaticBlock;
                const transformed = transformPropertyWorker(property, receiver);
                if (transformed && hasStaticModifier(property) && ((_a2 = lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) == null ? void 0 : _a2.facts)) {
                    setOriginalNode(transformed, property);
                    addEmitFlags(transformed, 4 /* AdviseOnEmitNode */);
                    setSourceMapRange(transformed, getSourceMapRange(property.name));
                    lexicalEnvironmentMap.set(getOriginalNode(property), lexicalEnvironment);
                }
                currentStaticPropertyDeclarationOrStaticBlock = savedCurrentStaticPropertyDeclarationOrStaticBlock;
                return transformed;
            }
            function transformPropertyWorker(property, receiver) {
                const emitAssignment = !useDefineForClassFields;
                let referencedName;
                if (isNamedEvaluation(property, isAnonymousClassNeedingAssignedName)) {
                    if (isPropertyNameLiteral(property.name) || isPrivateIdentifier(property.name)) {
                        referencedName = factory2.createStringLiteralFromNode(property.name);
                    }
                    else if (isPropertyNameLiteral(property.name.expression) && !isIdentifier(property.name.expression)) {
                        referencedName = factory2.createStringLiteralFromNode(property.name.expression);
                    }
                    else {
                        referencedName = factory2.getGeneratedNameForNode(property.name);
                    }
                }
                const propertyName = hasAccessorModifier(property) ? factory2.getGeneratedPrivateNameForNode(property.name) : isComputedPropertyName(property.name) && !isSimpleInlineableExpression(property.name.expression) ? factory2.updateComputedPropertyName(property.name, factory2.getGeneratedNameForNode(property.name)) : property.name;
                if (hasStaticModifier(property)) {
                    currentStaticPropertyDeclarationOrStaticBlock = property;
                }
                const initializerVisitor = referencedName ? (child) => namedEvaluationVisitor(child, referencedName) : visitor;
                if (isPrivateIdentifier(propertyName) && shouldTransformClassElementToWeakMap(property)) {
                    const privateIdentifierInfo = accessPrivateIdentifier2(propertyName);
                    if (privateIdentifierInfo) {
                        if (privateIdentifierInfo.kind === "f" /* Field */) {
                            if (!privateIdentifierInfo.isStatic) {
                                return createPrivateInstanceFieldInitializer(receiver, visitNode(property.initializer, initializerVisitor, isExpression), privateIdentifierInfo.brandCheckIdentifier);
                            }
                            else {
                                return createPrivateStaticFieldInitializer(privateIdentifierInfo.variableName, visitNode(property.initializer, initializerVisitor, isExpression));
                            }
                        }
                        else {
                            return void 0;
                        }
                    }
                    else {
                        Debug.fail("Undeclared private name for property declaration.");
                    }
                }
                if ((isPrivateIdentifier(propertyName) || hasStaticModifier(property)) && !property.initializer) {
                    return void 0;
                }
                const propertyOriginalNode = getOriginalNode(property);
                if (hasSyntacticModifier(propertyOriginalNode, 256 /* Abstract */)) {
                    return void 0;
                }
                let initializer = visitNode(property.initializer, initializerVisitor, isExpression);
                if (isParameterPropertyDeclaration(propertyOriginalNode, propertyOriginalNode.parent) && isIdentifier(propertyName)) {
                    const localName = factory2.cloneNode(propertyName);
                    if (initializer) {
                        if (isParenthesizedExpression(initializer) && isCommaExpression(initializer.expression) && isCallToHelper(initializer.expression.left, "___runInitializers") && isVoidExpression(initializer.expression.right) && isNumericLiteral(initializer.expression.right.expression)) {
                            initializer = initializer.expression.left;
                        }
                        initializer = factory2.inlineExpressions([initializer, localName]);
                    }
                    else {
                        initializer = localName;
                    }
                    setEmitFlags(propertyName, 3072 /* NoComments */ | 96 /* NoSourceMap */);
                    setSourceMapRange(localName, propertyOriginalNode.name);
                    setEmitFlags(localName, 3072 /* NoComments */);
                }
                else {
                    initializer != null ? initializer : initializer = factory2.createVoidZero();
                }
                if (emitAssignment || isPrivateIdentifier(propertyName)) {
                    const memberAccess = createMemberAccessForPropertyName(factory2, receiver, propertyName, 
                    /*location*/
                    propertyName);
                    addEmitFlags(memberAccess, 1024 /* NoLeadingComments */);
                    const expression = factory2.createAssignment(memberAccess, initializer);
                    return expression;
                }
                else {
                    const name = isComputedPropertyName(propertyName) ? propertyName.expression : isIdentifier(propertyName) ? factory2.createStringLiteral(unescapeLeadingUnderscores(propertyName.escapedText)) : propertyName;
                    const descriptor = factory2.createPropertyDescriptor({ value: initializer, configurable: true, writable: true, enumerable: true });
                    return factory2.createObjectDefinePropertyCall(receiver, name, descriptor);
                }
            }
            function enableSubstitutionForClassAliases() {
                if ((enabledSubstitutions & 1 /* ClassAliases */) === 0) {
                    enabledSubstitutions |= 1 /* ClassAliases */;
                    context.enableSubstitution(79 /* Identifier */);
                    classAliases = [];
                }
            }
            function enableSubstitutionForClassStaticThisOrSuperReference() {
                if ((enabledSubstitutions & 2 /* ClassStaticThisOrSuperReference */) === 0) {
                    enabledSubstitutions |= 2 /* ClassStaticThisOrSuperReference */;
                    context.enableSubstitution(108 /* ThisKeyword */);
                    context.enableEmitNotification(259 /* FunctionDeclaration */);
                    context.enableEmitNotification(215 /* FunctionExpression */);
                    context.enableEmitNotification(173 /* Constructor */);
                    context.enableEmitNotification(174 /* GetAccessor */);
                    context.enableEmitNotification(175 /* SetAccessor */);
                    context.enableEmitNotification(171 /* MethodDeclaration */);
                    context.enableEmitNotification(169 /* PropertyDeclaration */);
                    context.enableEmitNotification(164 /* ComputedPropertyName */);
                }
            }
            function addInstanceMethodStatements(statements, methods, receiver) {
                if (!shouldTransformPrivateElementsOrClassStaticBlocks || !some(methods)) {
                    return;
                }
                const { weakSetName } = getPrivateIdentifierEnvironment().data;
                Debug.assert(weakSetName, "weakSetName should be set in private identifier environment");
                statements.push(factory2.createExpressionStatement(createPrivateInstanceMethodInitializer(receiver, weakSetName)));
            }
            function visitInvalidSuperProperty(node) {
                return isPropertyAccessExpression(node) ? factory2.updatePropertyAccessExpression(node, factory2.createVoidZero(), node.name) : factory2.updateElementAccessExpression(node, factory2.createVoidZero(), visitNode(node.argumentExpression, visitor, isExpression));
            }
            function getPropertyNameExpressionIfNeeded(name, shouldHoist, captureReferencedName) {
                if (isComputedPropertyName(name)) {
                    const cacheAssignment = findComputedPropertyNameCacheAssignment(name);
                    let expression = visitNode(name.expression, visitor, isExpression);
                    const innerExpression = skipPartiallyEmittedExpressions(expression);
                    const inlinable = isSimpleInlineableExpression(innerExpression);
                    const alreadyTransformed = !!cacheAssignment || isAssignmentExpression(innerExpression) && isGeneratedIdentifier(innerExpression.left);
                    if (!alreadyTransformed && !inlinable && shouldHoist) {
                        const generatedName = factory2.getGeneratedNameForNode(name);
                        if (resolver.getNodeCheckFlags(name) & 32768 /* BlockScopedBindingInLoop */) {
                            addBlockScopedVariable(generatedName);
                        }
                        else {
                            hoistVariableDeclaration(generatedName);
                        }
                        if (captureReferencedName) {
                            expression = emitHelpers().createPropKeyHelper(expression);
                        }
                        return factory2.createAssignment(generatedName, expression);
                    }
                    return inlinable || isIdentifier(innerExpression) ? void 0 : expression;
                }
            }
            function startClassLexicalEnvironment() {
                lexicalEnvironment = { previous: lexicalEnvironment, data: void 0 };
            }
            function endClassLexicalEnvironment() {
                lexicalEnvironment = lexicalEnvironment == null ? void 0 : lexicalEnvironment.previous;
            }
            function getClassLexicalEnvironment() {
                var _a2;
                Debug.assert(lexicalEnvironment);
                return (_a2 = lexicalEnvironment.data) != null ? _a2 : lexicalEnvironment.data = {
                    facts: 0 /* None */,
                    classConstructor: void 0,
                    classThis: void 0,
                    superClassReference: void 0
                    // privateIdentifierEnvironment: undefined,
                };
            }
            function getPrivateIdentifierEnvironment() {
                var _a2;
                Debug.assert(lexicalEnvironment);
                return (_a2 = lexicalEnvironment.privateEnv) != null ? _a2 : lexicalEnvironment.privateEnv = newPrivateEnvironment({
                    className: void 0,
                    weakSetName: void 0
                });
            }
            function getPendingExpressions() {
                return pendingExpressions != null ? pendingExpressions : pendingExpressions = [];
            }
            function addPrivateIdentifierClassElementToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo) {
                if (isAutoAccessorPropertyDeclaration(node)) {
                    addPrivateIdentifierAutoAccessorPropertyDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
                else if (isPropertyDeclaration(node)) {
                    addPrivateIdentifierPropertyDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
                else if (isMethodDeclaration(node)) {
                    addPrivateIdentifierMethodDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
                else if (isGetAccessorDeclaration(node)) {
                    addPrivateIdentifierGetAccessorDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
                else if (isSetAccessorDeclaration(node)) {
                    addPrivateIdentifierSetAccessorDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
            }
            function addPrivateIdentifierPropertyDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, _previousInfo) {
                var _a2;
                if (isStatic2) {
                    const brandCheckIdentifier = Debug.checkDefined((_a2 = lex.classThis) != null ? _a2 : lex.classConstructor, "classConstructor should be set in private identifier environment");
                    const variableName = createHoistedVariableForPrivateName(name);
                    setPrivateIdentifier(privateEnv, name, {
                        kind: "f" /* Field */,
                        isStatic: true,
                        brandCheckIdentifier,
                        variableName,
                        isValid
                    });
                }
                else {
                    const weakMapName = createHoistedVariableForPrivateName(name);
                    setPrivateIdentifier(privateEnv, name, {
                        kind: "f" /* Field */,
                        isStatic: false,
                        brandCheckIdentifier: weakMapName,
                        isValid
                    });
                    getPendingExpressions().push(factory2.createAssignment(weakMapName, factory2.createNewExpression(factory2.createIdentifier("WeakMap"), 
                    /*typeArguments*/
                    void 0, [])));
                }
            }
            function addPrivateIdentifierMethodDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, _previousInfo) {
                var _a2;
                const methodName = createHoistedVariableForPrivateName(name);
                const brandCheckIdentifier = isStatic2 ? Debug.checkDefined((_a2 = lex.classThis) != null ? _a2 : lex.classConstructor, "classConstructor should be set in private identifier environment") : Debug.checkDefined(privateEnv.data.weakSetName, "weakSetName should be set in private identifier environment");
                setPrivateIdentifier(privateEnv, name, {
                    kind: "m" /* Method */,
                    methodName,
                    brandCheckIdentifier,
                    isStatic: isStatic2,
                    isValid
                });
            }
            function addPrivateIdentifierGetAccessorDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, previousInfo) {
                var _a2;
                const getterName = createHoistedVariableForPrivateName(name, "_get");
                const brandCheckIdentifier = isStatic2 ? Debug.checkDefined((_a2 = lex.classThis) != null ? _a2 : lex.classConstructor, "classConstructor should be set in private identifier environment") : Debug.checkDefined(privateEnv.data.weakSetName, "weakSetName should be set in private identifier environment");
                if ((previousInfo == null ? void 0 : previousInfo.kind) === "a" /* Accessor */ && previousInfo.isStatic === isStatic2 && !previousInfo.getterName) {
                    previousInfo.getterName = getterName;
                }
                else {
                    setPrivateIdentifier(privateEnv, name, {
                        kind: "a" /* Accessor */,
                        getterName,
                        setterName: void 0,
                        brandCheckIdentifier,
                        isStatic: isStatic2,
                        isValid
                    });
                }
            }
            function addPrivateIdentifierSetAccessorDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, previousInfo) {
                var _a2;
                const setterName = createHoistedVariableForPrivateName(name, "_set");
                const brandCheckIdentifier = isStatic2 ? Debug.checkDefined((_a2 = lex.classThis) != null ? _a2 : lex.classConstructor, "classConstructor should be set in private identifier environment") : Debug.checkDefined(privateEnv.data.weakSetName, "weakSetName should be set in private identifier environment");
                if ((previousInfo == null ? void 0 : previousInfo.kind) === "a" /* Accessor */ && previousInfo.isStatic === isStatic2 && !previousInfo.setterName) {
                    previousInfo.setterName = setterName;
                }
                else {
                    setPrivateIdentifier(privateEnv, name, {
                        kind: "a" /* Accessor */,
                        getterName: void 0,
                        setterName,
                        brandCheckIdentifier,
                        isStatic: isStatic2,
                        isValid
                    });
                }
            }
            function addPrivateIdentifierAutoAccessorPropertyDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, _previousInfo) {
                var _a2;
                const getterName = createHoistedVariableForPrivateName(name, "_get");
                const setterName = createHoistedVariableForPrivateName(name, "_set");
                const brandCheckIdentifier = isStatic2 ? Debug.checkDefined((_a2 = lex.classThis) != null ? _a2 : lex.classConstructor, "classConstructor should be set in private identifier environment") : Debug.checkDefined(privateEnv.data.weakSetName, "weakSetName should be set in private identifier environment");
                setPrivateIdentifier(privateEnv, name, {
                    kind: "a" /* Accessor */,
                    getterName,
                    setterName,
                    brandCheckIdentifier,
                    isStatic: isStatic2,
                    isValid
                });
            }
            function addPrivateIdentifierToEnvironment(node, name, addDeclaration) {
                const lex = getClassLexicalEnvironment();
                const privateEnv = getPrivateIdentifierEnvironment();
                const previousInfo = getPrivateIdentifier(privateEnv, name);
                const isStatic2 = hasStaticModifier(node);
                const isValid = !isReservedPrivateName(name) && previousInfo === void 0;
                addDeclaration(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
            }
            function createHoistedVariableForClass(name, node, suffix) {
                const { className } = getPrivateIdentifierEnvironment().data;
                const prefix = className ? { prefix: "_", node: className, suffix: "_" } : "_";
                const identifier = typeof name === "object" ? factory2.getGeneratedNameForNode(name, 16 /* Optimistic */ | 8 /* ReservedInNestedScopes */, prefix, suffix) : typeof name === "string" ? factory2.createUniqueName(name, 16 /* Optimistic */, prefix, suffix) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0, 
                /*reserveInNestedScopes*/
                true, prefix, suffix);
                if (resolver.getNodeCheckFlags(node) & 32768 /* BlockScopedBindingInLoop */) {
                    addBlockScopedVariable(identifier);
                }
                else {
                    hoistVariableDeclaration(identifier);
                }
                return identifier;
            }
            function createHoistedVariableForPrivateName(name, suffix) {
                var _a2;
                const text = tryGetTextOfPropertyName(name);
                return createHoistedVariableForClass((_a2 = text == null ? void 0 : text.substring(1)) != null ? _a2 : name, name, suffix);
            }
            function accessPrivateIdentifier2(name) {
                const info = accessPrivateIdentifier(lexicalEnvironment, name);
                return (info == null ? void 0 : info.kind) === "untransformed" ? void 0 : info;
            }
            function wrapPrivateIdentifierForDestructuringTarget(node) {
                const parameter = factory2.getGeneratedNameForNode(node);
                const info = accessPrivateIdentifier2(node.name);
                if (!info) {
                    return visitEachChild(node, visitor, context);
                }
                let receiver = node.expression;
                if (isThisProperty(node) || isSuperProperty(node) || !isSimpleCopiableExpression(node.expression)) {
                    receiver = factory2.createTempVariable(hoistVariableDeclaration, 
                    /*reservedInNestedScopes*/
                    true);
                    getPendingExpressions().push(factory2.createBinaryExpression(receiver, 63 /* EqualsToken */, visitNode(node.expression, visitor, isExpression)));
                }
                return factory2.createAssignmentTargetWrapper(parameter, createPrivateIdentifierAssignment(info, receiver, parameter, 63 /* EqualsToken */));
            }
            function visitDestructuringAssignmentTarget(node) {
                if (isObjectLiteralExpression(node) || isArrayLiteralExpression(node)) {
                    return visitAssignmentPattern(node);
                }
                if (isPrivateIdentifierPropertyAccessExpression(node)) {
                    return wrapPrivateIdentifierForDestructuringTarget(node);
                }
                else if (shouldTransformSuperInStaticInitializers && isSuperProperty(node) && currentStaticPropertyDeclarationOrStaticBlock && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                    const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                    if (facts & 1 /* ClassWasDecorated */) {
                        return visitInvalidSuperProperty(node);
                    }
                    else if (classConstructor && superClassReference) {
                        const name = isElementAccessExpression(node) ? visitNode(node.argumentExpression, visitor, isExpression) : isIdentifier(node.name) ? factory2.createStringLiteralFromNode(node.name) : void 0;
                        if (name) {
                            const temp = factory2.createTempVariable(
                            /*recordTempVariable*/
                            void 0);
                            return factory2.createAssignmentTargetWrapper(temp, factory2.createReflectSetCall(superClassReference, name, temp, classConstructor));
                        }
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentElement(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const left = visitDestructuringAssignmentTarget(node.left);
                    const assignedName = getAssignedNameOfIdentifier(node.left, node.right);
                    const right = visitNode(node.right, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    return factory2.updateBinaryExpression(node, left, node.operatorToken, right);
                }
                if (isAssignmentExpression(node, 
                /*excludeCompoundAssignment*/
                true)) {
                    const left = visitDestructuringAssignmentTarget(node.left);
                    const right = visitNode(node.right, visitor, isExpression);
                    return factory2.updateBinaryExpression(node, left, node.operatorToken, right);
                }
                return visitDestructuringAssignmentTarget(node);
            }
            function visitAssignmentRestElement(node) {
                if (isLeftHandSideExpression(node.expression)) {
                    const expression = visitDestructuringAssignmentTarget(node.expression);
                    return factory2.updateSpreadElement(node, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitArrayAssignmentElement(node) {
                if (isArrayBindingOrAssignmentElement(node)) {
                    if (isSpreadElement(node))
                        return visitAssignmentRestElement(node);
                    if (!isOmittedExpression(node))
                        return visitAssignmentElement(node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentProperty(node) {
                const name = visitNode(node.name, visitor, isPropertyName);
                if (isAssignmentExpression(node.initializer, 
                /*excludeCompoundAssignment*/
                true)) {
                    const assignmentElement = visitAssignmentElement(node.initializer);
                    return factory2.updatePropertyAssignment(node, name, assignmentElement);
                }
                if (isLeftHandSideExpression(node.initializer)) {
                    const assignmentElement = visitDestructuringAssignmentTarget(node.initializer);
                    return factory2.updatePropertyAssignment(node, name, assignmentElement);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitShorthandAssignmentProperty(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const assignedName = getAssignedNameOfIdentifier(node.name, node.objectAssignmentInitializer);
                    const objectAssignmentInitializer = visitNode(node.objectAssignmentInitializer, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    return factory2.updateShorthandPropertyAssignment(node, node.name, objectAssignmentInitializer);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentRestProperty(node) {
                if (isLeftHandSideExpression(node.expression)) {
                    const expression = visitDestructuringAssignmentTarget(node.expression);
                    return factory2.updateSpreadAssignment(node, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitObjectAssignmentElement(node) {
                Debug.assertNode(node, isObjectBindingOrAssignmentElement);
                if (isSpreadAssignment(node))
                    return visitAssignmentRestProperty(node);
                if (isShorthandPropertyAssignment(node))
                    return visitShorthandAssignmentProperty(node);
                if (isPropertyAssignment(node))
                    return visitAssignmentProperty(node);
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentPattern(node) {
                if (isArrayLiteralExpression(node)) {
                    return factory2.updateArrayLiteralExpression(node, visitNodes2(node.elements, visitArrayAssignmentElement, isExpression));
                }
                else {
                    return factory2.updateObjectLiteralExpression(node, visitNodes2(node.properties, visitObjectAssignmentElement, isObjectLiteralElementLike));
                }
            }
            function onEmitNode(hint, node, emitCallback) {
                const original = getOriginalNode(node);
                const lex = lexicalEnvironmentMap.get(original);
                if (lex) {
                    const savedLexicalEnvironment = lexicalEnvironment;
                    const savedPreviousShouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                    lexicalEnvironment = lex;
                    previousShouldSubstituteThisWithClassThis = shouldSubstituteThisWithClassThis;
                    shouldSubstituteThisWithClassThis = !isClassStaticBlockDeclaration(original) || !(getInternalEmitFlags(original) & 32 /* TransformPrivateStaticElements */);
                    previousOnEmitNode(hint, node, emitCallback);
                    shouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                    previousShouldSubstituteThisWithClassThis = savedPreviousShouldSubstituteThisWithClassThis;
                    lexicalEnvironment = savedLexicalEnvironment;
                    return;
                }
                switch (node.kind) {
                    case 215 /* FunctionExpression */:
                        if (isArrowFunction(original) || getEmitFlags(node) & 524288 /* AsyncFunctionBody */) {
                            break;
                        }
                    case 259 /* FunctionDeclaration */:
                    case 173 /* Constructor */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 171 /* MethodDeclaration */:
                    case 169 /* PropertyDeclaration */: {
                        const savedLexicalEnvironment = lexicalEnvironment;
                        const savedPreviousShouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                        lexicalEnvironment = void 0;
                        previousShouldSubstituteThisWithClassThis = shouldSubstituteThisWithClassThis;
                        shouldSubstituteThisWithClassThis = false;
                        previousOnEmitNode(hint, node, emitCallback);
                        shouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                        previousShouldSubstituteThisWithClassThis = savedPreviousShouldSubstituteThisWithClassThis;
                        lexicalEnvironment = savedLexicalEnvironment;
                        return;
                    }
                    case 164 /* ComputedPropertyName */: {
                        const savedLexicalEnvironment = lexicalEnvironment;
                        const savedShouldSubstituteThisWithClassThis = shouldSubstituteThisWithClassThis;
                        lexicalEnvironment = lexicalEnvironment == null ? void 0 : lexicalEnvironment.previous;
                        shouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                        previousOnEmitNode(hint, node, emitCallback);
                        shouldSubstituteThisWithClassThis = savedShouldSubstituteThisWithClassThis;
                        lexicalEnvironment = savedLexicalEnvironment;
                        return;
                    }
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 108 /* ThisKeyword */:
                        return substituteThisExpression(node);
                }
                return node;
            }
            function substituteThisExpression(node) {
                if (enabledSubstitutions & 2 /* ClassStaticThisOrSuperReference */ && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                    const { facts, classConstructor, classThis } = lexicalEnvironment.data;
                    if (facts & 1 /* ClassWasDecorated */ && legacyDecorators) {
                        return factory2.createParenthesizedExpression(factory2.createVoidZero());
                    }
                    const substituteThis = shouldSubstituteThisWithClassThis ? classThis != null ? classThis : classConstructor : classConstructor;
                    if (substituteThis) {
                        return setTextRange(setOriginalNode(factory2.cloneNode(substituteThis), node), node);
                    }
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                return trySubstituteClassAlias(node) || node;
            }
            function trySubstituteClassAlias(node) {
                if (enabledSubstitutions & 1 /* ClassAliases */) {
                    if (resolver.getNodeCheckFlags(node) & 2097152 /* ConstructorReferenceInClass */) {
                        const declaration = resolver.getReferencedValueDeclaration(node);
                        if (declaration) {
                            const classAlias = classAliases[declaration.id];
                            if (classAlias) {
                                const clone2 = factory2.cloneNode(classAlias);
                                setSourceMapRange(clone2, node);
                                setCommentRange(clone2, node);
                                return clone2;
                            }
                        }
                    }
                }
                return void 0;
            }
        }
        function createPrivateStaticFieldInitializer(variableName, initializer) {
            return factory.createAssignment(variableName, factory.createObjectLiteralExpression([
                factory.createPropertyAssignment("value", initializer || factory.createVoidZero())
            ]));
        }
        function createPrivateInstanceFieldInitializer(receiver, initializer, weakMapName) {
            return factory.createCallExpression(factory.createPropertyAccessExpression(weakMapName, "set"), 
            /*typeArguments*/
            void 0, [receiver, initializer || factory.createVoidZero()]);
        }
        function createPrivateInstanceMethodInitializer(receiver, weakSetName) {
            return factory.createCallExpression(factory.createPropertyAccessExpression(weakSetName, "add"), 
            /*typeArguments*/
            void 0, [receiver]);
        }
        function isReservedPrivateName(node) {
            return !isGeneratedPrivateIdentifier(node) && node.escapedText === "#constructor";
        }
        function isPrivateIdentifierInExpression(node) {
            return isPrivateIdentifier(node.left) && node.operatorToken.kind === 101 /* InKeyword */;
        }
        var init_classFields = __esm({
            "src/compiler/transformers/classFields.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/typeSerializer.ts
        function createRuntimeTypeSerializer(context) {
            const { hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const strictNullChecks = getStrictOptionValue(compilerOptions, "strictNullChecks");
            let currentLexicalScope;
            let currentNameScope;
            return {
                serializeTypeNode: (serializerContext, node) => setSerializerContextAnd(serializerContext, serializeTypeNode, node),
                serializeTypeOfNode: (serializerContext, node) => setSerializerContextAnd(serializerContext, serializeTypeOfNode, node),
                serializeParameterTypesOfNode: (serializerContext, node, container) => setSerializerContextAnd(serializerContext, serializeParameterTypesOfNode, node, container),
                serializeReturnTypeOfNode: (serializerContext, node) => setSerializerContextAnd(serializerContext, serializeReturnTypeOfNode, node)
            };
            function setSerializerContextAnd(serializerContext, cb, node, arg) {
                const savedCurrentLexicalScope = currentLexicalScope;
                const savedCurrentNameScope = currentNameScope;
                currentLexicalScope = serializerContext.currentLexicalScope;
                currentNameScope = serializerContext.currentNameScope;
                const result = arg === void 0 ? cb(node) : cb(node, arg);
                currentLexicalScope = savedCurrentLexicalScope;
                currentNameScope = savedCurrentNameScope;
                return result;
            }
            function getAccessorTypeNode(node) {
                const accessors = resolver.getAllAccessorDeclarations(node);
                return accessors.setAccessor && getSetAccessorTypeAnnotationNode(accessors.setAccessor) || accessors.getAccessor && getEffectiveReturnTypeNode(accessors.getAccessor);
            }
            function serializeTypeOfNode(node) {
                switch (node.kind) {
                    case 169 /* PropertyDeclaration */:
                    case 166 /* Parameter */:
                        return serializeTypeNode(node.type);
                    case 175 /* SetAccessor */:
                    case 174 /* GetAccessor */:
                        return serializeTypeNode(getAccessorTypeNode(node));
                    case 260 /* ClassDeclaration */:
                    case 228 /* ClassExpression */:
                    case 171 /* MethodDeclaration */:
                        return factory.createIdentifier("Function");
                    default:
                        return factory.createVoidZero();
                }
            }
            function serializeParameterTypesOfNode(node, container) {
                const valueDeclaration = isClassLike(node) ? getFirstConstructorWithBody(node) : isFunctionLike(node) && nodeIsPresent(node.body) ? node : void 0;
                const expressions = [];
                if (valueDeclaration) {
                    const parameters = getParametersOfDecoratedDeclaration(valueDeclaration, container);
                    const numParameters = parameters.length;
                    for (let i = 0; i < numParameters; i++) {
                        const parameter = parameters[i];
                        if (i === 0 && isIdentifier(parameter.name) && parameter.name.escapedText === "this") {
                            continue;
                        }
                        if (parameter.dotDotDotToken) {
                            expressions.push(serializeTypeNode(getRestParameterElementType(parameter.type)));
                        }
                        else {
                            expressions.push(serializeTypeOfNode(parameter));
                        }
                    }
                }
                return factory.createArrayLiteralExpression(expressions);
            }
            function getParametersOfDecoratedDeclaration(node, container) {
                if (container && node.kind === 174 /* GetAccessor */) {
                    const { setAccessor } = getAllAccessorDeclarations(container.members, node);
                    if (setAccessor) {
                        return setAccessor.parameters;
                    }
                }
                return node.parameters;
            }
            function serializeReturnTypeOfNode(node) {
                if (isFunctionLike(node) && node.type) {
                    return serializeTypeNode(node.type);
                }
                else if (isAsyncFunction(node)) {
                    return factory.createIdentifier("Promise");
                }
                return factory.createVoidZero();
            }
            function serializeTypeNode(node) {
                if (node === void 0) {
                    return factory.createIdentifier("Object");
                }
                node = skipTypeParentheses(node);
                switch (node.kind) {
                    case 114 /* VoidKeyword */:
                    case 155 /* UndefinedKeyword */:
                    case 144 /* NeverKeyword */:
                        return factory.createVoidZero();
                    case 181 /* FunctionType */:
                    case 182 /* ConstructorType */:
                        return factory.createIdentifier("Function");
                    case 185 /* ArrayType */:
                    case 186 /* TupleType */:
                        return factory.createIdentifier("Array");
                    case 179 /* TypePredicate */:
                        return node.assertsModifier ? factory.createVoidZero() : factory.createIdentifier("Boolean");
                    case 134 /* BooleanKeyword */:
                        return factory.createIdentifier("Boolean");
                    case 200 /* TemplateLiteralType */:
                    case 152 /* StringKeyword */:
                        return factory.createIdentifier("String");
                    case 149 /* ObjectKeyword */:
                        return factory.createIdentifier("Object");
                    case 198 /* LiteralType */:
                        return serializeLiteralOfLiteralTypeNode(node.literal);
                    case 148 /* NumberKeyword */:
                        return factory.createIdentifier("Number");
                    case 160 /* BigIntKeyword */:
                        return getGlobalConstructor("BigInt", 7 /* ES2020 */);
                    case 153 /* SymbolKeyword */:
                        return getGlobalConstructor("Symbol", 2 /* ES2015 */);
                    case 180 /* TypeReference */:
                        return serializeTypeReferenceNode(node);
                    case 190 /* IntersectionType */:
                        return serializeUnionOrIntersectionConstituents(node.types, 
                        /*isIntersection*/
                        true);
                    case 189 /* UnionType */:
                        return serializeUnionOrIntersectionConstituents(node.types, 
                        /*isIntersection*/
                        false);
                    case 191 /* ConditionalType */:
                        return serializeUnionOrIntersectionConstituents([node.trueType, node.falseType], 
                        /*isIntersection*/
                        false);
                    case 195 /* TypeOperator */:
                        if (node.operator === 146 /* ReadonlyKeyword */) {
                            return serializeTypeNode(node.type);
                        }
                        break;
                    case 183 /* TypeQuery */:
                    case 196 /* IndexedAccessType */:
                    case 197 /* MappedType */:
                    case 184 /* TypeLiteral */:
                    case 131 /* AnyKeyword */:
                    case 157 /* UnknownKeyword */:
                    case 194 /* ThisType */:
                    case 202 /* ImportType */:
                        break;
                    case 315 /* JSDocAllType */:
                    case 316 /* JSDocUnknownType */:
                    case 320 /* JSDocFunctionType */:
                    case 321 /* JSDocVariadicType */:
                    case 322 /* JSDocNamepathType */:
                        break;
                    case 317 /* JSDocNullableType */:
                    case 318 /* JSDocNonNullableType */:
                    case 319 /* JSDocOptionalType */:
                        return serializeTypeNode(node.type);
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
                return factory.createIdentifier("Object");
            }
            function serializeLiteralOfLiteralTypeNode(node) {
                switch (node.kind) {
                    case 10 /* StringLiteral */:
                    case 14 /* NoSubstitutionTemplateLiteral */:
                        return factory.createIdentifier("String");
                    case 221 /* PrefixUnaryExpression */: {
                        const operand = node.operand;
                        switch (operand.kind) {
                            case 8 /* NumericLiteral */:
                            case 9 /* BigIntLiteral */:
                                return serializeLiteralOfLiteralTypeNode(operand);
                            default:
                                return Debug.failBadSyntaxKind(operand);
                        }
                    }
                    case 8 /* NumericLiteral */:
                        return factory.createIdentifier("Number");
                    case 9 /* BigIntLiteral */:
                        return getGlobalConstructor("BigInt", 7 /* ES2020 */);
                    case 110 /* TrueKeyword */:
                    case 95 /* FalseKeyword */:
                        return factory.createIdentifier("Boolean");
                    case 104 /* NullKeyword */:
                        return factory.createVoidZero();
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function serializeUnionOrIntersectionConstituents(types, isIntersection) {
                let serializedType;
                for (let typeNode of types) {
                    typeNode = skipTypeParentheses(typeNode);
                    if (typeNode.kind === 144 /* NeverKeyword */) {
                        if (isIntersection)
                            return factory.createVoidZero();
                        continue;
                    }
                    if (typeNode.kind === 157 /* UnknownKeyword */) {
                        if (!isIntersection)
                            return factory.createIdentifier("Object");
                        continue;
                    }
                    if (typeNode.kind === 131 /* AnyKeyword */) {
                        return factory.createIdentifier("Object");
                    }
                    if (!strictNullChecks && (isLiteralTypeNode(typeNode) && typeNode.literal.kind === 104 /* NullKeyword */ || typeNode.kind === 155 /* UndefinedKeyword */)) {
                        continue;
                    }
                    const serializedConstituent = serializeTypeNode(typeNode);
                    if (isIdentifier(serializedConstituent) && serializedConstituent.escapedText === "Object") {
                        return serializedConstituent;
                    }
                    if (serializedType) {
                        if (!equateSerializedTypeNodes(serializedType, serializedConstituent)) {
                            return factory.createIdentifier("Object");
                        }
                    }
                    else {
                        serializedType = serializedConstituent;
                    }
                }
                return serializedType != null ? serializedType : factory.createVoidZero();
            }
            function equateSerializedTypeNodes(left, right) {
                return (
                // temp vars used in fallback
                isGeneratedIdentifier(left) ? isGeneratedIdentifier(right) : (
                // entity names
                isIdentifier(left) ? isIdentifier(right) && left.escapedText === right.escapedText : isPropertyAccessExpression(left) ? isPropertyAccessExpression(right) && equateSerializedTypeNodes(left.expression, right.expression) && equateSerializedTypeNodes(left.name, right.name) : (
                // `void 0`
                isVoidExpression(left) ? isVoidExpression(right) && isNumericLiteral(left.expression) && left.expression.text === "0" && isNumericLiteral(right.expression) && right.expression.text === "0" : (
                // `"undefined"` or `"function"` in `typeof` checks
                isStringLiteral(left) ? isStringLiteral(right) && left.text === right.text : (
                // used in `typeof` checks for fallback
                isTypeOfExpression(left) ? isTypeOfExpression(right) && equateSerializedTypeNodes(left.expression, right.expression) : (
                // parens in `typeof` checks with temps
                isParenthesizedExpression(left) ? isParenthesizedExpression(right) && equateSerializedTypeNodes(left.expression, right.expression) : (
                // conditionals used in fallback
                isConditionalExpression(left) ? isConditionalExpression(right) && equateSerializedTypeNodes(left.condition, right.condition) && equateSerializedTypeNodes(left.whenTrue, right.whenTrue) && equateSerializedTypeNodes(left.whenFalse, right.whenFalse) : (
                // logical binary and assignments used in fallback
                isBinaryExpression(left) ? isBinaryExpression(right) && left.operatorToken.kind === right.operatorToken.kind && equateSerializedTypeNodes(left.left, right.left) && equateSerializedTypeNodes(left.right, right.right) : false))))))));
            }
            function serializeTypeReferenceNode(node) {
                const kind = resolver.getTypeReferenceSerializationKind(node.typeName, currentNameScope != null ? currentNameScope : currentLexicalScope);
                switch (kind) {
                    case 0 /* Unknown */:
                        if (findAncestor(node, (n) => n.parent && isConditionalTypeNode(n.parent) && (n.parent.trueType === n || n.parent.falseType === n))) {
                            return factory.createIdentifier("Object");
                        }
                        const serialized = serializeEntityNameAsExpressionFallback(node.typeName);
                        const temp = factory.createTempVariable(hoistVariableDeclaration);
                        return factory.createConditionalExpression(factory.createTypeCheck(factory.createAssignment(temp, serialized), "function"), 
                        /*questionToken*/
                        void 0, temp, 
                        /*colonToken*/
                        void 0, factory.createIdentifier("Object"));
                    case 1 /* TypeWithConstructSignatureAndValue */:
                        return serializeEntityNameAsExpression(node.typeName);
                    case 2 /* VoidNullableOrNeverType */:
                        return factory.createVoidZero();
                    case 4 /* BigIntLikeType */:
                        return getGlobalConstructor("BigInt", 7 /* ES2020 */);
                    case 6 /* BooleanType */:
                        return factory.createIdentifier("Boolean");
                    case 3 /* NumberLikeType */:
                        return factory.createIdentifier("Number");
                    case 5 /* StringLikeType */:
                        return factory.createIdentifier("String");
                    case 7 /* ArrayLikeType */:
                        return factory.createIdentifier("Array");
                    case 8 /* ESSymbolType */:
                        return getGlobalConstructor("Symbol", 2 /* ES2015 */);
                    case 10 /* TypeWithCallSignature */:
                        return factory.createIdentifier("Function");
                    case 9 /* Promise */:
                        return factory.createIdentifier("Promise");
                    case 11 /* ObjectType */:
                        return factory.createIdentifier("Object");
                    default:
                        return Debug.assertNever(kind);
                }
            }
            function createCheckedValue(left, right) {
                return factory.createLogicalAnd(factory.createStrictInequality(factory.createTypeOfExpression(left), factory.createStringLiteral("undefined")), right);
            }
            function serializeEntityNameAsExpressionFallback(node) {
                if (node.kind === 79 /* Identifier */) {
                    const copied = serializeEntityNameAsExpression(node);
                    return createCheckedValue(copied, copied);
                }
                if (node.left.kind === 79 /* Identifier */) {
                    return createCheckedValue(serializeEntityNameAsExpression(node.left), serializeEntityNameAsExpression(node));
                }
                const left = serializeEntityNameAsExpressionFallback(node.left);
                const temp = factory.createTempVariable(hoistVariableDeclaration);
                return factory.createLogicalAnd(factory.createLogicalAnd(left.left, factory.createStrictInequality(factory.createAssignment(temp, left.right), factory.createVoidZero())), factory.createPropertyAccessExpression(temp, node.right));
            }
            function serializeEntityNameAsExpression(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        const name = setParent(setTextRange(parseNodeFactory.cloneNode(node), node), node.parent);
                        name.original = void 0;
                        setParent(name, getParseTreeNode(currentLexicalScope));
                        return name;
                    case 163 /* QualifiedName */:
                        return serializeQualifiedNameAsExpression(node);
                }
            }
            function serializeQualifiedNameAsExpression(node) {
                return factory.createPropertyAccessExpression(serializeEntityNameAsExpression(node.left), node.right);
            }
            function getGlobalConstructorWithFallback(name) {
                return factory.createConditionalExpression(factory.createTypeCheck(factory.createIdentifier(name), "function"), 
                /*questionToken*/
                void 0, factory.createIdentifier(name), 
                /*colonToken*/
                void 0, factory.createIdentifier("Object"));
            }
            function getGlobalConstructor(name, minLanguageVersion) {
                return languageVersion < minLanguageVersion ? getGlobalConstructorWithFallback(name) : factory.createIdentifier(name);
            }
        }
        var init_typeSerializer = __esm({
            "src/compiler/transformers/typeSerializer.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/legacyDecorators.ts
        function transformLegacyDecorators(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            let classAliases;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                return visited;
            }
            function modifierVisitor(node) {
                return isDecorator(node) ? void 0 : node;
            }
            function visitor(node) {
                if (!(node.transformFlags & 33554432 /* ContainsDecorators */)) {
                    return node;
                }
                switch (node.kind) {
                    case 167 /* Decorator */:
                        return void 0;
                    case 260 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 228 /* ClassExpression */:
                        return visitClassExpression(node);
                    case 173 /* Constructor */:
                        return visitConstructorDeclaration(node);
                    case 171 /* MethodDeclaration */:
                        return visitMethodDeclaration(node);
                    case 175 /* SetAccessor */:
                        return visitSetAccessorDeclaration(node);
                    case 174 /* GetAccessor */:
                        return visitGetAccessorDeclaration(node);
                    case 169 /* PropertyDeclaration */:
                        return visitPropertyDeclaration(node);
                    case 166 /* Parameter */:
                        return visitParameterDeclaration(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitClassDeclaration(node) {
                if (!(classOrConstructorParameterIsDecorated(
                /*legacyDecorators*/
                true, node) || childIsDecorated(
                /*legacyDecorators*/
                true, node))) {
                    return visitEachChild(node, visitor, context);
                }
                const statements = classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                true, node) ? transformClassDeclarationWithClassDecorators(node, node.name) : transformClassDeclarationWithoutClassDecorators(node, node.name);
                if (statements.length > 1) {
                    statements.push(factory2.createEndOfDeclarationMarker(node));
                    setEmitFlags(statements[0], getEmitFlags(statements[0]) | 8388608 /* HasEndOfDeclarationMarker */);
                }
                return singleOrMany(statements);
            }
            function decoratorContainsPrivateIdentifierInExpression(decorator) {
                return !!(decorator.transformFlags & 536870912 /* ContainsPrivateIdentifierInExpression */);
            }
            function parameterDecoratorsContainPrivateIdentifierInExpression(parameterDecorators) {
                return some(parameterDecorators, decoratorContainsPrivateIdentifierInExpression);
            }
            function hasClassElementWithDecoratorContainingPrivateIdentifierInExpression(node) {
                for (const member of node.members) {
                    if (!canHaveDecorators(member))
                        continue;
                    const allDecorators = getAllDecoratorsOfClassElement(member, node, 
                    /*useLegacyDecorators*/
                    true);
                    if (some(allDecorators == null ? void 0 : allDecorators.decorators, decoratorContainsPrivateIdentifierInExpression))
                        return true;
                    if (some(allDecorators == null ? void 0 : allDecorators.parameters, parameterDecoratorsContainPrivateIdentifierInExpression))
                        return true;
                }
                return false;
            }
            function transformDecoratorsOfClassElements(node, members) {
                let decorationStatements = [];
                addClassElementDecorationStatements(decorationStatements, node, 
                /*isStatic*/
                false);
                addClassElementDecorationStatements(decorationStatements, node, 
                /*isStatic*/
                true);
                if (hasClassElementWithDecoratorContainingPrivateIdentifierInExpression(node)) {
                    members = setTextRange(factory2.createNodeArray([
                        ...members,
                        factory2.createClassStaticBlockDeclaration(factory2.createBlock(decorationStatements, 
                        /*multiLine*/
                        true))
                    ]), members);
                    decorationStatements = void 0;
                }
                return { decorationStatements, members };
            }
            function transformClassDeclarationWithoutClassDecorators(node, name) {
                const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const heritageClauses = visitNodes2(node.heritageClauses, visitor, isHeritageClause);
                let members = visitNodes2(node.members, visitor, isClassElement);
                let decorationStatements = [];
                ({ members, decorationStatements } = transformDecoratorsOfClassElements(node, members));
                const updated = factory2.updateClassDeclaration(node, modifiers, name, 
                /*typeParameters*/
                void 0, heritageClauses, members);
                return addRange([updated], decorationStatements);
            }
            function transformClassDeclarationWithClassDecorators(node, name) {
                const location = moveRangePastModifiers(node);
                const classAlias = getClassAliasIfNeeded(node);
                const declName = languageVersion <= 2 /* ES2015 */ ? factory2.getInternalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true) : factory2.getLocalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
                const heritageClauses = visitNodes2(node.heritageClauses, visitor, isHeritageClause);
                let members = visitNodes2(node.members, visitor, isClassElement);
                let decorationStatements = [];
                ({ members, decorationStatements } = transformDecoratorsOfClassElements(node, members));
                const classExpression = factory2.createClassExpression(
                /*modifiers*/
                void 0, name && isGeneratedIdentifier(name) ? void 0 : name, 
                /*typeParameters*/
                void 0, heritageClauses, members);
                setOriginalNode(classExpression, node);
                setTextRange(classExpression, location);
                const statement = factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(declName, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, classAlias ? factory2.createAssignment(classAlias, classExpression) : classExpression)
                ], 1 /* Let */));
                setOriginalNode(statement, node);
                setTextRange(statement, location);
                setCommentRange(statement, node);
                const statements = [statement];
                addRange(statements, decorationStatements);
                addConstructorDecorationStatement(statements, node);
                return statements;
            }
            function visitClassExpression(node) {
                return factory2.updateClassExpression(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.name, 
                /*typeParameters*/
                void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), visitNodes2(node.members, visitor, isClassElement));
            }
            function visitConstructorDeclaration(node) {
                return factory2.updateConstructorDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), visitNodes2(node.parameters, visitor, isParameter), visitNode(node.body, visitor, isBlock));
            }
            function finishClassElement(updated, original) {
                if (updated !== original) {
                    setCommentRange(updated, original);
                    setSourceMapRange(updated, moveRangePastModifiers(original));
                }
                return updated;
            }
            function visitMethodDeclaration(node) {
                return finishClassElement(factory2.updateMethodDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.asteriskToken, Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), 
                /*questionToken*/
                void 0, 
                /*typeParameters*/
                void 0, visitNodes2(node.parameters, visitor, isParameter), 
                /*type*/
                void 0, visitNode(node.body, visitor, isBlock)), node);
            }
            function visitGetAccessorDeclaration(node) {
                return finishClassElement(factory2.updateGetAccessorDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), visitNodes2(node.parameters, visitor, isParameter), 
                /*type*/
                void 0, visitNode(node.body, visitor, isBlock)), node);
            }
            function visitSetAccessorDeclaration(node) {
                return finishClassElement(factory2.updateSetAccessorDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), visitNodes2(node.parameters, visitor, isParameter), visitNode(node.body, visitor, isBlock)), node);
            }
            function visitPropertyDeclaration(node) {
                if (node.flags & 16777216 /* Ambient */ || hasSyntacticModifier(node, 2 /* Ambient */)) {
                    return void 0;
                }
                return finishClassElement(factory2.updatePropertyDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression)), node);
            }
            function visitParameterDeclaration(node) {
                const updated = factory2.updateParameterDeclaration(node, elideNodes(factory2, node.modifiers), node.dotDotDotToken, Debug.checkDefined(visitNode(node.name, visitor, isBindingName)), 
                /*questionToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
                if (updated !== node) {
                    setCommentRange(updated, node);
                    setTextRange(updated, moveRangePastModifiers(node));
                    setSourceMapRange(updated, moveRangePastModifiers(node));
                    setEmitFlags(updated.name, 64 /* NoTrailingSourceMap */);
                }
                return updated;
            }
            function isSyntheticMetadataDecorator(node) {
                return isCallToHelper(node.expression, "___metadata");
            }
            function transformAllDecoratorsOfDeclaration(allDecorators) {
                if (!allDecorators) {
                    return void 0;
                }
                const { false: decorators, true: metadata } = groupBy(allDecorators.decorators, isSyntheticMetadataDecorator);
                const decoratorExpressions = [];
                addRange(decoratorExpressions, map(decorators, transformDecorator));
                addRange(decoratorExpressions, flatMap(allDecorators.parameters, transformDecoratorsOfParameter));
                addRange(decoratorExpressions, map(metadata, transformDecorator));
                return decoratorExpressions;
            }
            function addClassElementDecorationStatements(statements, node, isStatic2) {
                addRange(statements, map(generateClassElementDecorationExpressions(node, isStatic2), (expr) => factory2.createExpressionStatement(expr)));
            }
            function isDecoratedClassElement(member, isStaticElement, parent2) {
                return nodeOrChildIsDecorated(
                /*legacyDecorators*/
                true, member, parent2) && isStaticElement === isStatic(member);
            }
            function getDecoratedClassElements(node, isStatic2) {
                return filter(node.members, (m) => isDecoratedClassElement(m, isStatic2, node));
            }
            function generateClassElementDecorationExpressions(node, isStatic2) {
                const members = getDecoratedClassElements(node, isStatic2);
                let expressions;
                for (const member of members) {
                    expressions = append(expressions, generateClassElementDecorationExpression(node, member));
                }
                return expressions;
            }
            function generateClassElementDecorationExpression(node, member) {
                const allDecorators = getAllDecoratorsOfClassElement(member, node, 
                /*useLegacyDecorators*/
                true);
                const decoratorExpressions = transformAllDecoratorsOfDeclaration(allDecorators);
                if (!decoratorExpressions) {
                    return void 0;
                }
                const prefix = getClassMemberPrefix(node, member);
                const memberName = getExpressionForPropertyName(member, 
                /*generateNameForComputedPropertyName*/
                !hasSyntacticModifier(member, 2 /* Ambient */));
                const descriptor = languageVersion > 0 /* ES3 */ ? isPropertyDeclaration(member) && !hasAccessorModifier(member) ? factory2.createVoidZero() : factory2.createNull() : void 0;
                const helper = emitHelpers().createDecorateHelper(decoratorExpressions, prefix, memberName, descriptor);
                setEmitFlags(helper, 3072 /* NoComments */);
                setSourceMapRange(helper, moveRangePastModifiers(member));
                return helper;
            }
            function addConstructorDecorationStatement(statements, node) {
                const expression = generateConstructorDecorationExpression(node);
                if (expression) {
                    statements.push(setOriginalNode(factory2.createExpressionStatement(expression), node));
                }
            }
            function generateConstructorDecorationExpression(node) {
                const allDecorators = getAllDecoratorsOfClass(node);
                const decoratorExpressions = transformAllDecoratorsOfDeclaration(allDecorators);
                if (!decoratorExpressions) {
                    return void 0;
                }
                const classAlias = classAliases && classAliases[getOriginalNodeId(node)];
                const localName = languageVersion <= 2 /* ES2015 */ ? factory2.getInternalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true) : factory2.getLocalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
                const decorate = emitHelpers().createDecorateHelper(decoratorExpressions, localName);
                const expression = factory2.createAssignment(localName, classAlias ? factory2.createAssignment(classAlias, decorate) : decorate);
                setEmitFlags(expression, 3072 /* NoComments */);
                setSourceMapRange(expression, moveRangePastModifiers(node));
                return expression;
            }
            function transformDecorator(decorator) {
                return Debug.checkDefined(visitNode(decorator.expression, visitor, isExpression));
            }
            function transformDecoratorsOfParameter(decorators, parameterOffset) {
                let expressions;
                if (decorators) {
                    expressions = [];
                    for (const decorator of decorators) {
                        const helper = emitHelpers().createParamHelper(transformDecorator(decorator), parameterOffset);
                        setTextRange(helper, decorator.expression);
                        setEmitFlags(helper, 3072 /* NoComments */);
                        expressions.push(helper);
                    }
                }
                return expressions;
            }
            function getExpressionForPropertyName(member, generateNameForComputedPropertyName) {
                const name = member.name;
                if (isPrivateIdentifier(name)) {
                    return factory2.createIdentifier("");
                }
                else if (isComputedPropertyName(name)) {
                    return generateNameForComputedPropertyName && !isSimpleInlineableExpression(name.expression) ? factory2.getGeneratedNameForNode(name) : name.expression;
                }
                else if (isIdentifier(name)) {
                    return factory2.createStringLiteral(idText(name));
                }
                else {
                    return factory2.cloneNode(name);
                }
            }
            function enableSubstitutionForClassAliases() {
                if (!classAliases) {
                    context.enableSubstitution(79 /* Identifier */);
                    classAliases = [];
                }
            }
            function getClassAliasIfNeeded(node) {
                if (resolver.getNodeCheckFlags(node) & 1048576 /* ClassWithConstructorReference */) {
                    enableSubstitutionForClassAliases();
                    const classAlias = factory2.createUniqueName(node.name && !isGeneratedIdentifier(node.name) ? idText(node.name) : "default");
                    classAliases[getOriginalNodeId(node)] = classAlias;
                    hoistVariableDeclaration(classAlias);
                    return classAlias;
                }
            }
            function getClassPrototype(node) {
                return factory2.createPropertyAccessExpression(factory2.getDeclarationName(node), "prototype");
            }
            function getClassMemberPrefix(node, member) {
                return isStatic(member) ? factory2.getDeclarationName(node) : getClassPrototype(node);
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                var _a2;
                return (_a2 = trySubstituteClassAlias(node)) != null ? _a2 : node;
            }
            function trySubstituteClassAlias(node) {
                if (classAliases) {
                    if (resolver.getNodeCheckFlags(node) & 2097152 /* ConstructorReferenceInClass */) {
                        const declaration = resolver.getReferencedValueDeclaration(node);
                        if (declaration) {
                            const classAlias = classAliases[declaration.id];
                            if (classAlias) {
                                const clone2 = factory2.cloneNode(classAlias);
                                setSourceMapRange(clone2, node);
                                setCommentRange(clone2, node);
                                return clone2;
                            }
                        }
                    }
                }
                return void 0;
            }
        }
        var init_legacyDecorators = __esm({
            "src/compiler/transformers/legacyDecorators.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/esDecorators.ts
        function transformESDecorators(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, startLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            let top;
            let classInfo;
            let classThis;
            let classSuper;
            let pendingExpressions;
            let shouldTransformPrivateStaticElementsInFile;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                top = void 0;
                shouldTransformPrivateStaticElementsInFile = false;
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                if (shouldTransformPrivateStaticElementsInFile) {
                    addInternalEmitFlags(visited, 32 /* TransformPrivateStaticElements */);
                    shouldTransformPrivateStaticElementsInFile = false;
                }
                return visited;
            }
            function updateState() {
                classInfo = void 0;
                classThis = void 0;
                classSuper = void 0;
                switch (top == null ? void 0 : top.kind) {
                    case "class":
                        classInfo = top.classInfo;
                        break;
                    case "class-element":
                        classInfo = top.next.classInfo;
                        classThis = top.classThis;
                        classSuper = top.classSuper;
                        break;
                    case "name":
                        const grandparent = top.next.next.next;
                        if ((grandparent == null ? void 0 : grandparent.kind) === "class-element") {
                            classInfo = grandparent.next.classInfo;
                            classThis = grandparent.classThis;
                            classSuper = grandparent.classSuper;
                        }
                        break;
                }
            }
            function enterClass(classInfo2) {
                top = { kind: "class", next: top, classInfo: classInfo2, savedPendingExpressions: pendingExpressions };
                pendingExpressions = void 0;
                updateState();
            }
            function exitClass() {
                Debug.assert((top == null ? void 0 : top.kind) === "class", "Incorrect value for top.kind.", () => `Expected top.kind to be 'class' but got '${top == null ? void 0 : top.kind}' instead.`);
                pendingExpressions = top.savedPendingExpressions;
                top = top.next;
                updateState();
            }
            function enterClassElement(node) {
                var _a2, _b;
                Debug.assert((top == null ? void 0 : top.kind) === "class", "Incorrect value for top.kind.", () => `Expected top.kind to be 'class' but got '${top == null ? void 0 : top.kind}' instead.`);
                top = { kind: "class-element", next: top };
                if (isClassStaticBlockDeclaration(node) || isPropertyDeclaration(node) && hasStaticModifier(node)) {
                    top.classThis = (_a2 = top.next.classInfo) == null ? void 0 : _a2.classThis;
                    top.classSuper = (_b = top.next.classInfo) == null ? void 0 : _b.classSuper;
                }
                updateState();
            }
            function exitClassElement() {
                var _a2;
                Debug.assert((top == null ? void 0 : top.kind) === "class-element", "Incorrect value for top.kind.", () => `Expected top.kind to be 'class-element' but got '${top == null ? void 0 : top.kind}' instead.`);
                Debug.assert(((_a2 = top.next) == null ? void 0 : _a2.kind) === "class", "Incorrect value for top.next.kind.", () => {
                    var _a3;
                    return `Expected top.next.kind to be 'class' but got '${(_a3 = top.next) == null ? void 0 : _a3.kind}' instead.`;
                });
                top = top.next;
                updateState();
            }
            function enterName() {
                Debug.assert((top == null ? void 0 : top.kind) === "class-element", "Incorrect value for top.kind.", () => `Expected top.kind to be 'class-element' but got '${top == null ? void 0 : top.kind}' instead.`);
                top = { kind: "name", next: top };
                updateState();
            }
            function exitName() {
                Debug.assert((top == null ? void 0 : top.kind) === "name", "Incorrect value for top.kind.", () => `Expected top.kind to be 'name' but got '${top == null ? void 0 : top.kind}' instead.`);
                top = top.next;
                updateState();
            }
            function enterOther() {
                if ((top == null ? void 0 : top.kind) === "other") {
                    Debug.assert(!pendingExpressions);
                    top.depth++;
                }
                else {
                    top = { kind: "other", next: top, depth: 0, savedPendingExpressions: pendingExpressions };
                    pendingExpressions = void 0;
                    updateState();
                }
            }
            function exitOther() {
                Debug.assert((top == null ? void 0 : top.kind) === "other", "Incorrect value for top.kind.", () => `Expected top.kind to be 'other' but got '${top == null ? void 0 : top.kind}' instead.`);
                if (top.depth > 0) {
                    Debug.assert(!pendingExpressions);
                    top.depth--;
                }
                else {
                    pendingExpressions = top.savedPendingExpressions;
                    top = top.next;
                    updateState();
                }
            }
            function shouldVisitNode(node) {
                return !!(node.transformFlags & 33554432 /* ContainsDecorators */) || !!classThis && !!(node.transformFlags & 16384 /* ContainsLexicalThis */) || !!classThis && !!classSuper && !!(node.transformFlags & 134217728 /* ContainsLexicalSuper */);
            }
            function visitor(node) {
                if (!shouldVisitNode(node)) {
                    return node;
                }
                switch (node.kind) {
                    case 167 /* Decorator */:
                        return Debug.fail("Use `modifierVisitor` instead.");
                    case 260 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 228 /* ClassExpression */:
                        return visitClassExpression(node, 
                        /*referencedName*/
                        void 0);
                    case 173 /* Constructor */:
                    case 169 /* PropertyDeclaration */:
                    case 172 /* ClassStaticBlockDeclaration */:
                        return Debug.fail("Not supported outside of a class. Use 'classElementVisitor' instead.");
                    case 166 /* Parameter */:
                        return visitParameterDeclaration(node);
                    case 223 /* BinaryExpression */:
                        return visitBinaryExpression(node, 
                        /*discarded*/
                        false);
                    case 299 /* PropertyAssignment */:
                        return visitPropertyAssignment(node);
                    case 257 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 205 /* BindingElement */:
                        return visitBindingElement(node);
                    case 274 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    case 108 /* ThisKeyword */:
                        return visitThisExpression(node);
                    case 245 /* ForStatement */:
                        return visitForStatement(node);
                    case 241 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 357 /* CommaListExpression */:
                        return visitCommaListExpression(node, 
                        /*discarded*/
                        false);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        false, 
                        /*referencedName*/
                        void 0);
                    case 356 /* PartiallyEmittedExpression */:
                        return visitPartiallyEmittedExpression(node, 
                        /*discarded*/
                        false, 
                        /*referencedName*/
                        void 0);
                    case 210 /* CallExpression */:
                        return visitCallExpression(node);
                    case 212 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 221 /* PrefixUnaryExpression */:
                    case 222 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, 
                        /*discard*/
                        false);
                    case 208 /* PropertyAccessExpression */:
                        return visitPropertyAccessExpression(node);
                    case 209 /* ElementAccessExpression */:
                        return visitElementAccessExpression(node);
                    case 164 /* ComputedPropertyName */:
                        return visitComputedPropertyName(node);
                    case 171 /* MethodDeclaration */:
                    case 175 /* SetAccessor */:
                    case 174 /* GetAccessor */:
                    case 215 /* FunctionExpression */:
                    case 259 /* FunctionDeclaration */: {
                        enterOther();
                        const result = visitEachChild(node, fallbackVisitor, context);
                        exitOther();
                        return result;
                    }
                    default:
                        return visitEachChild(node, fallbackVisitor, context);
                }
            }
            function fallbackVisitor(node) {
                switch (node.kind) {
                    case 167 /* Decorator */:
                        return void 0;
                    default:
                        return visitor(node);
                }
            }
            function modifierVisitor(node) {
                switch (node.kind) {
                    case 167 /* Decorator */:
                        return void 0;
                    default:
                        return node;
                }
            }
            function classElementVisitor(node) {
                switch (node.kind) {
                    case 173 /* Constructor */:
                        return visitConstructorDeclaration(node);
                    case 171 /* MethodDeclaration */:
                        return visitMethodDeclaration(node);
                    case 174 /* GetAccessor */:
                        return visitGetAccessorDeclaration(node);
                    case 175 /* SetAccessor */:
                        return visitSetAccessorDeclaration(node);
                    case 169 /* PropertyDeclaration */:
                        return visitPropertyDeclaration(node);
                    case 172 /* ClassStaticBlockDeclaration */:
                        return visitClassStaticBlockDeclaration(node);
                    default:
                        return visitor(node);
                }
            }
            function namedEvaluationVisitor(node, referencedName) {
                switch (node.kind) {
                    case 356 /* PartiallyEmittedExpression */:
                        return visitPartiallyEmittedExpression(node, 
                        /*discarded*/
                        false, referencedName);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        false, referencedName);
                    case 228 /* ClassExpression */:
                        return visitClassExpression(node, referencedName);
                    default:
                        return visitor(node);
                }
            }
            function discardedValueVisitor(node) {
                switch (node.kind) {
                    case 221 /* PrefixUnaryExpression */:
                    case 222 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, 
                        /*discarded*/
                        true);
                    case 223 /* BinaryExpression */:
                        return visitBinaryExpression(node, 
                        /*discarded*/
                        true);
                    case 357 /* CommaListExpression */:
                        return visitCommaListExpression(node, 
                        /*discarded*/
                        true);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        true, 
                        /*referencedName*/
                        void 0);
                    default:
                        return visitor(node);
                }
            }
            function getHelperVariableName(node) {
                let declarationName = node.name && isIdentifier(node.name) && !isGeneratedIdentifier(node.name) ? idText(node.name) : node.name && isPrivateIdentifier(node.name) && !isGeneratedIdentifier(node.name) ? idText(node.name).slice(1) : node.name && isStringLiteral(node.name) && isIdentifierText(node.name.text, 99 /* ESNext */) ? node.name.text : isClassLike(node) ? "class" : "member";
                if (isGetAccessor(node))
                    declarationName = `get_${declarationName}`;
                if (isSetAccessor(node))
                    declarationName = `set_${declarationName}`;
                if (node.name && isPrivateIdentifier(node.name))
                    declarationName = `private_${declarationName}`;
                if (isStatic(node))
                    declarationName = `static_${declarationName}`;
                return "_" + declarationName;
            }
            function createHelperVariable(node, suffix) {
                return factory2.createUniqueName(`${getHelperVariableName(node)}_${suffix}`, 16 /* Optimistic */ | 8 /* ReservedInNestedScopes */);
            }
            function createLet(name, initializer) {
                return factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer)
                ], 1 /* Let */));
            }
            function createClassInfo(node) {
                let instanceExtraInitializersName;
                let staticExtraInitializersName;
                let hasStaticInitializers = false;
                let hasNonAmbientInstanceFields = false;
                let hasStaticPrivateClassElements = false;
                for (const member of node.members) {
                    if (isNamedClassElement(member) && nodeOrChildIsDecorated(
                    /*legacyDecorators*/
                    false, member, node)) {
                        if (hasStaticModifier(member)) {
                            staticExtraInitializersName != null ? staticExtraInitializersName : staticExtraInitializersName = factory2.createUniqueName("_staticExtraInitializers", 16 /* Optimistic */);
                        }
                        else {
                            instanceExtraInitializersName != null ? instanceExtraInitializersName : instanceExtraInitializersName = factory2.createUniqueName("_instanceExtraInitializers", 16 /* Optimistic */);
                        }
                    }
                    if (isClassStaticBlockDeclaration(member)) {
                        hasStaticInitializers = true;
                    }
                    else if (isPropertyDeclaration(member)) {
                        if (hasStaticModifier(member)) {
                            hasStaticInitializers || (hasStaticInitializers = !!member.initializer || hasDecorators(member));
                        }
                        else {
                            hasNonAmbientInstanceFields || (hasNonAmbientInstanceFields = !isAmbientPropertyDeclaration(member));
                        }
                    }
                    if ((isPrivateIdentifierClassElementDeclaration(member) || isAutoAccessorPropertyDeclaration(member)) && hasStaticModifier(member)) {
                        hasStaticPrivateClassElements = true;
                    }
                    if (staticExtraInitializersName && instanceExtraInitializersName && hasStaticInitializers && hasNonAmbientInstanceFields && hasStaticPrivateClassElements) {
                        break;
                    }
                }
                return {
                    class: node,
                    instanceExtraInitializersName,
                    staticExtraInitializersName,
                    hasStaticInitializers,
                    hasNonAmbientInstanceFields,
                    hasStaticPrivateClassElements
                };
            }
            function containsLexicalSuperInStaticInitializer(node) {
                for (const member of node.members) {
                    if (isClassStaticBlockDeclaration(member) || isPropertyDeclaration(member) && hasStaticModifier(member)) {
                        if (member.transformFlags & 134217728 /* ContainsLexicalSuper */) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function transformClassLike(node, className) {
                var _a2, _b, _c, _d, _e;
                startLexicalEnvironment();
                const classReference = (_a2 = node.name) != null ? _a2 : factory2.getGeneratedNameForNode(node);
                const classInfo2 = createClassInfo(node);
                const classDefinitionStatements = [];
                let leadingBlockStatements;
                let trailingBlockStatements;
                let syntheticConstructor;
                let heritageClauses;
                let shouldTransformPrivateStaticElementsInClass = false;
                const classDecorators = transformAllDecoratorsOfDeclaration(getAllDecoratorsOfClass(node));
                if (classDecorators) {
                    classInfo2.classDecoratorsName = factory2.createUniqueName("_classDecorators", 16 /* Optimistic */);
                    classInfo2.classDescriptorName = factory2.createUniqueName("_classDescriptor", 16 /* Optimistic */);
                    classInfo2.classExtraInitializersName = factory2.createUniqueName("_classExtraInitializers", 16 /* Optimistic */);
                    classInfo2.classThis = factory2.createUniqueName("_classThis", 16 /* Optimistic */);
                    classDefinitionStatements.push(createLet(classInfo2.classDecoratorsName, factory2.createArrayLiteralExpression(classDecorators)), createLet(classInfo2.classDescriptorName), createLet(classInfo2.classExtraInitializersName, factory2.createArrayLiteralExpression()), createLet(classInfo2.classThis));
                    if (classInfo2.hasStaticPrivateClassElements) {
                        shouldTransformPrivateStaticElementsInClass = true;
                        shouldTransformPrivateStaticElementsInFile = true;
                    }
                }
                if (classDecorators && containsLexicalSuperInStaticInitializer(node)) {
                    const extendsClause = getHeritageClause(node.heritageClauses, 94 /* ExtendsKeyword */);
                    const extendsElement = extendsClause && firstOrUndefined(extendsClause.types);
                    const extendsExpression = extendsElement && visitNode(extendsElement.expression, visitor, isExpression);
                    if (extendsExpression) {
                        classInfo2.classSuper = factory2.createUniqueName("_classSuper", 16 /* Optimistic */);
                        const unwrapped = skipOuterExpressions(extendsExpression);
                        const safeExtendsExpression = isClassExpression(unwrapped) && !unwrapped.name || isFunctionExpression(unwrapped) && !unwrapped.name || isArrowFunction(unwrapped) ? factory2.createComma(factory2.createNumericLiteral(0), extendsExpression) : extendsExpression;
                        classDefinitionStatements.push(createLet(classInfo2.classSuper, safeExtendsExpression));
                        const updatedExtendsElement = factory2.updateExpressionWithTypeArguments(extendsElement, classInfo2.classSuper, 
                        /*typeArguments*/
                        void 0);
                        const updatedExtendsClause = factory2.updateHeritageClause(extendsClause, [updatedExtendsElement]);
                        heritageClauses = factory2.createNodeArray([updatedExtendsClause]);
                    }
                }
                else {
                    heritageClauses = visitNodes2(node.heritageClauses, visitor, isHeritageClause);
                }
                const renamedClassThis = (_b = classInfo2.classThis) != null ? _b : factory2.createThis();
                const needsSetNameHelper = !((_c = getOriginalNode(node, isClassLike)) == null ? void 0 : _c.name) && (classDecorators || !isStringLiteral(className) || !isEmptyStringLiteral(className));
                if (needsSetNameHelper) {
                    const setNameExpr = emitHelpers().createSetFunctionNameHelper(factory2.createThis(), className);
                    leadingBlockStatements = append(leadingBlockStatements, factory2.createExpressionStatement(setNameExpr));
                }
                enterClass(classInfo2);
                let members = visitNodes2(node.members, classElementVisitor, isClassElement);
                if (pendingExpressions) {
                    let outerThis;
                    for (let expression of pendingExpressions) {
                        expression = visitNode(expression, function thisVisitor(node2) {
                            if (!(node2.transformFlags & 16384 /* ContainsLexicalThis */)) {
                                return node2;
                            }
                            switch (node2.kind) {
                                case 108 /* ThisKeyword */:
                                    if (!outerThis) {
                                        outerThis = factory2.createUniqueName("_outerThis", 16 /* Optimistic */);
                                        classDefinitionStatements.unshift(createLet(outerThis, factory2.createThis()));
                                    }
                                    return outerThis;
                                default:
                                    return visitEachChild(node2, thisVisitor, context);
                            }
                        }, isExpression);
                        const statement = factory2.createExpressionStatement(expression);
                        leadingBlockStatements = append(leadingBlockStatements, statement);
                    }
                    pendingExpressions = void 0;
                }
                exitClass();
                if (classInfo2.instanceExtraInitializersName && !getFirstConstructorWithBody(node)) {
                    const initializerStatements = prepareConstructor(node, classInfo2);
                    if (initializerStatements) {
                        const extendsClauseElement = getEffectiveBaseTypeNode(node);
                        const isDerivedClass = !!(extendsClauseElement && skipOuterExpressions(extendsClauseElement.expression).kind !== 104 /* NullKeyword */);
                        const constructorStatements = [];
                        if (isDerivedClass) {
                            const spreadArguments = factory2.createSpreadElement(factory2.createIdentifier("arguments"));
                            const superCall = factory2.createCallExpression(factory2.createSuper(), 
                            /*typeArguments*/
                            void 0, [spreadArguments]);
                            constructorStatements.push(factory2.createExpressionStatement(superCall));
                        }
                        addRange(constructorStatements, initializerStatements);
                        const constructorBody = factory2.createBlock(constructorStatements, 
                        /*multiLine*/
                        true);
                        syntheticConstructor = factory2.createConstructorDeclaration(
                        /*modifiers*/
                        void 0, [], constructorBody);
                    }
                }
                if (classInfo2.staticExtraInitializersName) {
                    classDefinitionStatements.push(createLet(classInfo2.staticExtraInitializersName, factory2.createArrayLiteralExpression()));
                }
                if (classInfo2.instanceExtraInitializersName) {
                    classDefinitionStatements.push(createLet(classInfo2.instanceExtraInitializersName, factory2.createArrayLiteralExpression()));
                }
                if (classInfo2.memberInfos) {
                    forEachEntry(classInfo2.memberInfos, (memberInfo, member) => {
                        if (isStatic(member)) {
                            classDefinitionStatements.push(createLet(memberInfo.memberDecoratorsName));
                            if (memberInfo.memberInitializersName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberInitializersName, factory2.createArrayLiteralExpression()));
                            }
                            if (memberInfo.memberDescriptorName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberDescriptorName));
                            }
                        }
                    });
                }
                if (classInfo2.memberInfos) {
                    forEachEntry(classInfo2.memberInfos, (memberInfo, member) => {
                        if (!isStatic(member)) {
                            classDefinitionStatements.push(createLet(memberInfo.memberDecoratorsName));
                            if (memberInfo.memberInitializersName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberInitializersName, factory2.createArrayLiteralExpression()));
                            }
                            if (memberInfo.memberDescriptorName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberDescriptorName));
                            }
                        }
                    });
                }
                leadingBlockStatements = addRange(leadingBlockStatements, classInfo2.staticNonFieldDecorationStatements);
                leadingBlockStatements = addRange(leadingBlockStatements, classInfo2.nonStaticNonFieldDecorationStatements);
                leadingBlockStatements = addRange(leadingBlockStatements, classInfo2.staticFieldDecorationStatements);
                leadingBlockStatements = addRange(leadingBlockStatements, classInfo2.nonStaticFieldDecorationStatements);
                if (classInfo2.classDescriptorName && classInfo2.classDecoratorsName && classInfo2.classExtraInitializersName && classInfo2.classThis) {
                    leadingBlockStatements != null ? leadingBlockStatements : leadingBlockStatements = [];
                    const valueProperty = factory2.createPropertyAssignment("value", factory2.createThis());
                    const classDescriptor = factory2.createObjectLiteralExpression([valueProperty]);
                    const classDescriptorAssignment = factory2.createAssignment(classInfo2.classDescriptorName, classDescriptor);
                    const classNameReference = factory2.createPropertyAccessExpression(factory2.createThis(), "name");
                    const esDecorateHelper2 = emitHelpers().createESDecorateHelper(factory2.createNull(), classDescriptorAssignment, classInfo2.classDecoratorsName, { kind: "class", name: classNameReference }, factory2.createNull(), classInfo2.classExtraInitializersName);
                    const esDecorateStatement = factory2.createExpressionStatement(esDecorateHelper2);
                    setSourceMapRange(esDecorateStatement, moveRangePastDecorators(node));
                    leadingBlockStatements.push(esDecorateStatement);
                    const classDescriptorValueReference = factory2.createPropertyAccessExpression(classInfo2.classDescriptorName, "value");
                    const classThisAssignment = factory2.createAssignment(classInfo2.classThis, classDescriptorValueReference);
                    const classReferenceAssignment = factory2.createAssignment(classReference, classThisAssignment);
                    leadingBlockStatements.push(factory2.createExpressionStatement(classReferenceAssignment));
                }
                if (classInfo2.staticExtraInitializersName) {
                    const runStaticInitializersHelper = emitHelpers().createRunInitializersHelper(renamedClassThis, classInfo2.staticExtraInitializersName);
                    const runStaticInitializersStatement = factory2.createExpressionStatement(runStaticInitializersHelper);
                    setSourceMapRange(runStaticInitializersStatement, (_d = node.name) != null ? _d : moveRangePastDecorators(node));
                    leadingBlockStatements = append(leadingBlockStatements, runStaticInitializersStatement);
                }
                if (classInfo2.classExtraInitializersName) {
                    const runClassInitializersHelper = emitHelpers().createRunInitializersHelper(renamedClassThis, classInfo2.classExtraInitializersName);
                    const runClassInitializersStatement = factory2.createExpressionStatement(runClassInitializersHelper);
                    setSourceMapRange(runClassInitializersStatement, (_e = node.name) != null ? _e : moveRangePastDecorators(node));
                    trailingBlockStatements = append(trailingBlockStatements, runClassInitializersStatement);
                }
                if (leadingBlockStatements && trailingBlockStatements && !classInfo2.hasStaticInitializers) {
                    addRange(leadingBlockStatements, trailingBlockStatements);
                    trailingBlockStatements = void 0;
                }
                let newMembers = members;
                if (leadingBlockStatements) {
                    const leadingStaticBlockBody = factory2.createBlock(leadingBlockStatements, 
                    /*multiline*/
                    true);
                    const leadingStaticBlock = factory2.createClassStaticBlockDeclaration(leadingStaticBlockBody);
                    if (shouldTransformPrivateStaticElementsInClass) {
                        setInternalEmitFlags(leadingStaticBlock, 32 /* TransformPrivateStaticElements */);
                    }
                    newMembers = [leadingStaticBlock, ...newMembers];
                }
                if (syntheticConstructor) {
                    newMembers = [...newMembers, syntheticConstructor];
                }
                if (trailingBlockStatements) {
                    const trailingStaticBlockBody = factory2.createBlock(trailingBlockStatements, 
                    /*multiline*/
                    true);
                    const trailingStaticBlock = factory2.createClassStaticBlockDeclaration(trailingStaticBlockBody);
                    newMembers = [...newMembers, trailingStaticBlock];
                }
                if (newMembers !== members) {
                    members = setTextRange(factory2.createNodeArray(newMembers), members);
                }
                const lexicalEnvironment = endLexicalEnvironment();
                let classExpression;
                if (classDecorators) {
                    classExpression = factory2.createClassExpression(
                    /*modifiers*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, heritageClauses, members);
                    const classReferenceDeclaration = factory2.createVariableDeclaration(classReference, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, classExpression);
                    const classReferenceVarDeclList = factory2.createVariableDeclarationList([classReferenceDeclaration]);
                    const returnExpr = classInfo2.classThis ? factory2.createAssignment(classReference, classInfo2.classThis) : classReference;
                    classDefinitionStatements.push(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, classReferenceVarDeclList), factory2.createReturnStatement(returnExpr));
                }
                else {
                    classExpression = factory2.createClassExpression(
                    /*modifiers*/
                    void 0, node.name, 
                    /*typeParameters*/
                    void 0, heritageClauses, members);
                    classDefinitionStatements.push(factory2.createReturnStatement(classExpression));
                }
                if (shouldTransformPrivateStaticElementsInClass) {
                    addInternalEmitFlags(classExpression, 32 /* TransformPrivateStaticElements */);
                    for (const member of classExpression.members) {
                        if ((isPrivateIdentifierClassElementDeclaration(member) || isAutoAccessorPropertyDeclaration(member)) && hasStaticModifier(member)) {
                            addInternalEmitFlags(member, 32 /* TransformPrivateStaticElements */);
                        }
                    }
                }
                setOriginalNode(classExpression, node);
                getOrCreateEmitNode(classExpression).classThis = classInfo2.classThis;
                return factory2.createImmediatelyInvokedArrowFunction(factory2.mergeLexicalEnvironment(classDefinitionStatements, lexicalEnvironment));
            }
            function isDecoratedClassLike(node) {
                return classOrConstructorParameterIsDecorated(
                /*legacyDecorators*/
                false, node) || childIsDecorated(
                /*legacyDecorators*/
                false, node);
            }
            function visitClassDeclaration(node) {
                var _a2;
                if (isDecoratedClassLike(node)) {
                    if (hasSyntacticModifier(node, 1 /* Export */) && hasSyntacticModifier(node, 1024 /* Default */)) {
                        const originalClass = (_a2 = getOriginalNode(node, isClassLike)) != null ? _a2 : node;
                        const className = originalClass.name ? factory2.createStringLiteralFromNode(originalClass.name) : factory2.createStringLiteral("default");
                        const iife = transformClassLike(node, className);
                        const statement = factory2.createExportDefault(iife);
                        setOriginalNode(statement, node);
                        setCommentRange(statement, getCommentRange(node));
                        setSourceMapRange(statement, moveRangePastDecorators(node));
                        return statement;
                    }
                    else {
                        Debug.assertIsDefined(node.name, "A class declaration that is not a default export must have a name.");
                        const iife = transformClassLike(node, factory2.createStringLiteralFromNode(node.name));
                        const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                        const varDecl = factory2.createVariableDeclaration(node.name, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, iife);
                        const varDecls = factory2.createVariableDeclarationList([varDecl], 1 /* Let */);
                        const statement = factory2.createVariableStatement(modifiers, varDecls);
                        setOriginalNode(statement, node);
                        setCommentRange(statement, getCommentRange(node));
                        return statement;
                    }
                }
                else {
                    const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                    const heritageClauses = visitNodes2(node.heritageClauses, visitor, isHeritageClause);
                    enterClass(
                    /*classInfo*/
                    void 0);
                    const members = visitNodes2(node.members, classElementVisitor, isClassElement);
                    exitClass();
                    return factory2.updateClassDeclaration(node, modifiers, node.name, 
                    /*typeParameters*/
                    void 0, heritageClauses, members);
                }
            }
            function visitClassExpression(node, referencedName) {
                if (isDecoratedClassLike(node)) {
                    const className = node.name ? factory2.createStringLiteralFromNode(node.name) : referencedName != null ? referencedName : factory2.createStringLiteral("");
                    const iife = transformClassLike(node, className);
                    setOriginalNode(iife, node);
                    return iife;
                }
                else {
                    const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                    const heritageClauses = visitNodes2(node.heritageClauses, visitor, isHeritageClause);
                    enterClass(
                    /*classInfo*/
                    void 0);
                    const members = visitNodes2(node.members, classElementVisitor, isClassElement);
                    exitClass();
                    return factory2.updateClassExpression(node, modifiers, node.name, 
                    /*typeParameters*/
                    void 0, heritageClauses, members);
                }
            }
            function prepareConstructor(_parent, classInfo2) {
                if (classInfo2.instanceExtraInitializersName && !classInfo2.hasNonAmbientInstanceFields) {
                    const statements = [];
                    statements.push(factory2.createExpressionStatement(emitHelpers().createRunInitializersHelper(factory2.createThis(), classInfo2.instanceExtraInitializersName)));
                    return statements;
                }
            }
            function visitConstructorDeclaration(node) {
                enterClassElement(node);
                const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const parameters = visitNodes2(node.parameters, visitor, isParameter);
                let body;
                if (node.body && classInfo) {
                    const initializerStatements = prepareConstructor(classInfo.class, classInfo);
                    if (initializerStatements) {
                        const statements = [];
                        const nonPrologueStart = factory2.copyPrologue(node.body.statements, statements, 
                        /*ensureUseStrict*/
                        false, visitor);
                        const superStatementIndex = findSuperStatementIndex(node.body.statements, nonPrologueStart);
                        if (superStatementIndex >= 0) {
                            addRange(statements, visitNodes2(node.body.statements, visitor, isStatement, nonPrologueStart, superStatementIndex + 1 - nonPrologueStart));
                            addRange(statements, initializerStatements);
                            addRange(statements, visitNodes2(node.body.statements, visitor, isStatement, superStatementIndex + 1));
                        }
                        else {
                            addRange(statements, initializerStatements);
                            addRange(statements, visitNodes2(node.body.statements, visitor, isStatement));
                        }
                        body = factory2.createBlock(statements, 
                        /*multiLine*/
                        true);
                        setOriginalNode(body, node.body);
                        setTextRange(body, node.body);
                    }
                }
                body != null ? body : body = visitNode(node.body, visitor, isBlock);
                exitClassElement();
                return factory2.updateConstructorDeclaration(node, modifiers, parameters, body);
            }
            function finishClassElement(updated, original) {
                if (updated !== original) {
                    setCommentRange(updated, original);
                    setSourceMapRange(updated, moveRangePastDecorators(original));
                }
                return updated;
            }
            function partialTransformClassElement(member, useNamedEvaluation, classInfo2, createDescriptor) {
                var _a2, _b, _c, _d, _e, _f, _g, _h;
                let referencedName;
                let name;
                let initializersName;
                let thisArg;
                let descriptorName;
                if (!classInfo2) {
                    const modifiers2 = visitNodes2(member.modifiers, modifierVisitor, isModifier);
                    enterName();
                    if (useNamedEvaluation) {
                        ({ referencedName, name } = visitReferencedPropertyName(member.name));
                    }
                    else {
                        name = visitPropertyName(member.name);
                    }
                    exitName();
                    return { modifiers: modifiers2, referencedName, name, initializersName, descriptorName, thisArg };
                }
                const memberDecorators = transformAllDecoratorsOfDeclaration(getAllDecoratorsOfClassElement(member, classInfo2.class, 
                /*useLegacyDecorators*/
                false));
                const modifiers = visitNodes2(member.modifiers, modifierVisitor, isModifier);
                if (memberDecorators) {
                    const memberDecoratorsName = createHelperVariable(member, "decorators");
                    const memberDecoratorsArray = factory2.createArrayLiteralExpression(memberDecorators);
                    const memberDecoratorsAssignment = factory2.createAssignment(memberDecoratorsName, memberDecoratorsArray);
                    const memberInfo = { memberDecoratorsName };
                    (_a2 = classInfo2.memberInfos) != null ? _a2 : classInfo2.memberInfos = /* @__PURE__ */ new Map();
                    classInfo2.memberInfos.set(member, memberInfo);
                    pendingExpressions != null ? pendingExpressions : pendingExpressions = [];
                    pendingExpressions.push(memberDecoratorsAssignment);
                    const statements = isMethodOrAccessor(member) || isAutoAccessorPropertyDeclaration(member) ? isStatic(member) ? (_b = classInfo2.staticNonFieldDecorationStatements) != null ? _b : classInfo2.staticNonFieldDecorationStatements = [] : (_c = classInfo2.nonStaticNonFieldDecorationStatements) != null ? _c : classInfo2.nonStaticNonFieldDecorationStatements = [] : isPropertyDeclaration(member) && !isAutoAccessorPropertyDeclaration(member) ? isStatic(member) ? (_d = classInfo2.staticFieldDecorationStatements) != null ? _d : classInfo2.staticFieldDecorationStatements = [] : (_e = classInfo2.nonStaticFieldDecorationStatements) != null ? _e : classInfo2.nonStaticFieldDecorationStatements = [] : Debug.fail();
                    const kind = isGetAccessorDeclaration(member) ? "getter" : isSetAccessorDeclaration(member) ? "setter" : isMethodDeclaration(member) ? "method" : isAutoAccessorPropertyDeclaration(member) ? "accessor" : isPropertyDeclaration(member) ? "field" : Debug.fail();
                    let propertyName;
                    if (isIdentifier(member.name) || isPrivateIdentifier(member.name)) {
                        propertyName = { computed: false, name: member.name };
                    }
                    else if (isPropertyNameLiteral(member.name)) {
                        propertyName = { computed: true, name: factory2.createStringLiteralFromNode(member.name) };
                    }
                    else {
                        const expression = member.name.expression;
                        if (isPropertyNameLiteral(expression) && !isIdentifier(expression)) {
                            propertyName = { computed: true, name: factory2.createStringLiteralFromNode(expression) };
                        }
                        else {
                            enterName();
                            ({ referencedName, name } = visitReferencedPropertyName(member.name));
                            propertyName = { computed: true, name: referencedName };
                            exitName();
                        }
                    }
                    const context2 = {
                        kind,
                        name: propertyName,
                        static: isStatic(member),
                        private: isPrivateIdentifier(member.name),
                        access: {
                            // 15.7.3 CreateDecoratorAccessObject (kind, name)
                            // 2. If _kind_ is ~field~, ~method~, ~accessor~, or ~getter~, then ...
                            get: isPropertyDeclaration(member) || isGetAccessorDeclaration(member) || isMethodDeclaration(member),
                            // 3. If _kind_ is ~field~, ~accessor~, or ~setter~, then ...
                            set: isPropertyDeclaration(member) || isSetAccessorDeclaration(member)
                        }
                    };
                    const extraInitializers = isStatic(member) ? (_f = classInfo2.staticExtraInitializersName) != null ? _f : classInfo2.staticExtraInitializersName = factory2.createUniqueName("_staticExtraInitializers", 16 /* Optimistic */) : (_g = classInfo2.instanceExtraInitializersName) != null ? _g : classInfo2.instanceExtraInitializersName = factory2.createUniqueName("_instanceExtraInitializers", 16 /* Optimistic */);
                    if (isMethodOrAccessor(member)) {
                        let descriptor;
                        if (isPrivateIdentifierClassElementDeclaration(member) && createDescriptor) {
                            descriptor = createDescriptor(member, visitNodes2(modifiers, (node) => tryCast(node, isAsyncModifier), isModifier));
                            memberInfo.memberDescriptorName = descriptorName = createHelperVariable(member, "descriptor");
                            descriptor = factory2.createAssignment(descriptorName, descriptor);
                        }
                        const esDecorateExpression = emitHelpers().createESDecorateHelper(factory2.createThis(), descriptor != null ? descriptor : factory2.createNull(), memberDecoratorsName, context2, factory2.createNull(), extraInitializers);
                        const esDecorateStatement = factory2.createExpressionStatement(esDecorateExpression);
                        setSourceMapRange(esDecorateStatement, moveRangePastDecorators(member));
                        statements.push(esDecorateStatement);
                    }
                    else if (isPropertyDeclaration(member)) {
                        initializersName = (_h = memberInfo.memberInitializersName) != null ? _h : memberInfo.memberInitializersName = createHelperVariable(member, "initializers");
                        if (isStatic(member)) {
                            thisArg = classInfo2.classThis;
                        }
                        let descriptor;
                        if (isPrivateIdentifierClassElementDeclaration(member) && hasAccessorModifier(member) && createDescriptor) {
                            descriptor = createDescriptor(member, 
                            /*modifiers*/
                            void 0);
                            memberInfo.memberDescriptorName = descriptorName = createHelperVariable(member, "descriptor");
                            descriptor = factory2.createAssignment(descriptorName, descriptor);
                        }
                        const esDecorateExpression = emitHelpers().createESDecorateHelper(isAutoAccessorPropertyDeclaration(member) ? factory2.createThis() : factory2.createNull(), descriptor != null ? descriptor : factory2.createNull(), memberDecoratorsName, context2, initializersName, extraInitializers);
                        const esDecorateStatement = factory2.createExpressionStatement(esDecorateExpression);
                        setSourceMapRange(esDecorateStatement, moveRangePastDecorators(member));
                        statements.push(esDecorateStatement);
                    }
                }
                if (name === void 0) {
                    enterName();
                    if (useNamedEvaluation) {
                        ({ referencedName, name } = visitReferencedPropertyName(member.name));
                    }
                    else {
                        name = visitPropertyName(member.name);
                    }
                    exitName();
                }
                if (!some(modifiers) && (isMethodDeclaration(member) || isPropertyDeclaration(member))) {
                    setEmitFlags(name, 1024 /* NoLeadingComments */);
                }
                return { modifiers, referencedName, name, initializersName, descriptorName, thisArg };
            }
            function visitMethodDeclaration(node) {
                enterClassElement(node);
                const { modifiers, name, descriptorName } = partialTransformClassElement(node, 
                /*useNamedEvaluation*/
                false, classInfo, createMethodDescriptorObject);
                if (descriptorName) {
                    exitClassElement();
                    return finishClassElement(createMethodDescriptorForwarder(modifiers, name, descriptorName), node);
                }
                else {
                    const parameters = visitNodes2(node.parameters, visitor, isParameter);
                    const body = visitNode(node.body, visitor, isBlock);
                    exitClassElement();
                    return finishClassElement(factory2.updateMethodDeclaration(node, modifiers, node.asteriskToken, name, 
                    /*questionToken*/
                    void 0, 
                    /*typeParameters*/
                    void 0, parameters, 
                    /*type*/
                    void 0, body), node);
                }
            }
            function visitGetAccessorDeclaration(node) {
                enterClassElement(node);
                const { modifiers, name, descriptorName } = partialTransformClassElement(node, 
                /*useNamedEvaluation*/
                false, classInfo, createGetAccessorDescriptorObject);
                if (descriptorName) {
                    exitClassElement();
                    return finishClassElement(createGetAccessorDescriptorForwarder(modifiers, name, descriptorName), node);
                }
                else {
                    const parameters = visitNodes2(node.parameters, visitor, isParameter);
                    const body = visitNode(node.body, visitor, isBlock);
                    exitClassElement();
                    return finishClassElement(factory2.updateGetAccessorDeclaration(node, modifiers, name, parameters, 
                    /*type*/
                    void 0, body), node);
                }
            }
            function visitSetAccessorDeclaration(node) {
                enterClassElement(node);
                const { modifiers, name, descriptorName } = partialTransformClassElement(node, 
                /*useNamedEvaluation*/
                false, classInfo, createSetAccessorDescriptorObject);
                if (descriptorName) {
                    exitClassElement();
                    return finishClassElement(createSetAccessorDescriptorForwarder(modifiers, name, descriptorName), node);
                }
                else {
                    const parameters = visitNodes2(node.parameters, visitor, isParameter);
                    const body = visitNode(node.body, visitor, isBlock);
                    exitClassElement();
                    return finishClassElement(factory2.updateSetAccessorDeclaration(node, modifiers, name, parameters, body), node);
                }
            }
            function visitClassStaticBlockDeclaration(node) {
                enterClassElement(node);
                if (classInfo)
                    classInfo.hasStaticInitializers = true;
                const result = visitEachChild(node, visitor, context);
                exitClassElement();
                return result;
            }
            function visitPropertyDeclaration(node) {
                enterClassElement(node);
                Debug.assert(!isAmbientPropertyDeclaration(node), "Not yet implemented.");
                const useNamedEvaluation = isNamedEvaluation(node, isAnonymousClassNeedingAssignedName);
                const { modifiers, name, referencedName, initializersName, descriptorName, thisArg } = partialTransformClassElement(node, useNamedEvaluation, classInfo, hasAccessorModifier(node) ? createAccessorPropertyDescriptorObject : void 0);
                startLexicalEnvironment();
                let initializer = referencedName ? visitNode(node.initializer, (node2) => namedEvaluationVisitor(node2, referencedName), isExpression) : visitNode(node.initializer, visitor, isExpression);
                if (initializersName) {
                    initializer = emitHelpers().createRunInitializersHelper(thisArg != null ? thisArg : factory2.createThis(), initializersName, initializer != null ? initializer : factory2.createVoidZero());
                }
                if (!isStatic(node) && (classInfo == null ? void 0 : classInfo.instanceExtraInitializersName) && !(classInfo == null ? void 0 : classInfo.hasInjectedInstanceInitializers)) {
                    classInfo.hasInjectedInstanceInitializers = true;
                    initializer != null ? initializer : initializer = factory2.createVoidZero();
                    initializer = factory2.createParenthesizedExpression(factory2.createComma(emitHelpers().createRunInitializersHelper(factory2.createThis(), classInfo.instanceExtraInitializersName), initializer));
                }
                if (isStatic(node) && classInfo && initializer) {
                    classInfo.hasStaticInitializers = true;
                }
                const declarations = endLexicalEnvironment();
                if (some(declarations)) {
                    initializer = factory2.createImmediatelyInvokedArrowFunction([
                        ...declarations,
                        factory2.createReturnStatement(initializer)
                    ]);
                }
                exitClassElement();
                if (hasAccessorModifier(node) && descriptorName) {
                    const commentRange = getCommentRange(node);
                    const sourceMapRange = getSourceMapRange(node);
                    const name2 = node.name;
                    let getterName = name2;
                    let setterName = name2;
                    if (isComputedPropertyName(name2) && !isSimpleInlineableExpression(name2.expression)) {
                        const cacheAssignment = findComputedPropertyNameCacheAssignment(name2);
                        if (cacheAssignment) {
                            getterName = factory2.updateComputedPropertyName(name2, visitNode(name2.expression, visitor, isExpression));
                            setterName = factory2.updateComputedPropertyName(name2, cacheAssignment.left);
                        }
                        else {
                            const temp = factory2.createTempVariable(hoistVariableDeclaration);
                            setSourceMapRange(temp, name2.expression);
                            const expression = visitNode(name2.expression, visitor, isExpression);
                            const assignment = factory2.createAssignment(temp, expression);
                            setSourceMapRange(assignment, name2.expression);
                            getterName = factory2.updateComputedPropertyName(name2, assignment);
                            setterName = factory2.updateComputedPropertyName(name2, temp);
                        }
                    }
                    const modifiersWithoutAccessor = visitNodes2(modifiers, (node2) => node2.kind !== 127 /* AccessorKeyword */ ? node2 : void 0, isModifier);
                    const backingField = createAccessorPropertyBackingField(factory2, node, modifiersWithoutAccessor, initializer);
                    setOriginalNode(backingField, node);
                    setEmitFlags(backingField, 3072 /* NoComments */);
                    setSourceMapRange(backingField, sourceMapRange);
                    setSourceMapRange(backingField.name, node.name);
                    const getter = createGetAccessorDescriptorForwarder(modifiersWithoutAccessor, getterName, descriptorName);
                    setOriginalNode(getter, node);
                    setCommentRange(getter, commentRange);
                    setSourceMapRange(getter, sourceMapRange);
                    const setter = createSetAccessorDescriptorForwarder(modifiersWithoutAccessor, setterName, descriptorName);
                    setOriginalNode(setter, node);
                    setEmitFlags(setter, 3072 /* NoComments */);
                    setSourceMapRange(setter, sourceMapRange);
                    return [backingField, getter, setter];
                }
                return finishClassElement(factory2.updatePropertyDeclaration(node, modifiers, name, 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, initializer), node);
            }
            function visitThisExpression(node) {
                return classThis != null ? classThis : node;
            }
            function visitCallExpression(node) {
                if (isSuperProperty(node.expression) && classThis) {
                    const expression = visitNode(node.expression, visitor, isExpression);
                    const argumentsList = visitNodes2(node.arguments, visitor, isExpression);
                    const invocation = factory2.createFunctionCallCall(expression, classThis, argumentsList);
                    setOriginalNode(invocation, node);
                    setTextRange(invocation, node);
                    return invocation;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitTaggedTemplateExpression(node) {
                if (isSuperProperty(node.tag) && classThis) {
                    const tag = visitNode(node.tag, visitor, isExpression);
                    const boundTag = factory2.createFunctionBindCall(tag, classThis, []);
                    setOriginalNode(boundTag, node);
                    setTextRange(boundTag, node);
                    const template = visitNode(node.template, visitor, isTemplateLiteral);
                    return factory2.updateTaggedTemplateExpression(node, boundTag, 
                    /*typeArguments*/
                    void 0, template);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitPropertyAccessExpression(node) {
                if (isSuperProperty(node) && isIdentifier(node.name) && classThis && classSuper) {
                    const propertyName = factory2.createStringLiteralFromNode(node.name);
                    const superProperty = factory2.createReflectGetCall(classSuper, propertyName, classThis);
                    setOriginalNode(superProperty, node.expression);
                    setTextRange(superProperty, node.expression);
                    return superProperty;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitElementAccessExpression(node) {
                if (isSuperProperty(node) && classThis && classSuper) {
                    const propertyName = visitNode(node.argumentExpression, visitor, isExpression);
                    const superProperty = factory2.createReflectGetCall(classSuper, propertyName, classThis);
                    setOriginalNode(superProperty, node.expression);
                    setTextRange(superProperty, node.expression);
                    return superProperty;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitParameterDeclaration(node) {
                let updated;
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const assignedName = getAssignedNameOfIdentifier(node.name, node.initializer);
                    const name = visitNode(node.name, visitor, isBindingName);
                    const initializer = visitNode(node.initializer, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    updated = factory2.updateParameterDeclaration(node, 
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, name, 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer);
                }
                else {
                    updated = factory2.updateParameterDeclaration(node, 
                    /*modifiers*/
                    void 0, node.dotDotDotToken, visitNode(node.name, visitor, isBindingName), 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, visitNode(node.initializer, visitor, isExpression));
                }
                if (updated !== node) {
                    setCommentRange(updated, node);
                    setTextRange(updated, moveRangePastModifiers(node));
                    setSourceMapRange(updated, moveRangePastModifiers(node));
                    setEmitFlags(updated.name, 64 /* NoTrailingSourceMap */);
                }
                return updated;
            }
            function isAnonymousClassNeedingAssignedName(node) {
                return isClassExpression(node) && !node.name && isDecoratedClassLike(node);
            }
            function visitForStatement(node) {
                return factory2.updateForStatement(node, visitNode(node.initializer, discardedValueVisitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, discardedValueVisitor, isExpression), visitIterationBody(node.statement, visitor, context));
            }
            function visitExpressionStatement(node) {
                return visitEachChild(node, discardedValueVisitor, context);
            }
            function visitBinaryExpression(node, discarded) {
                if (isDestructuringAssignment(node)) {
                    const left = visitAssignmentPattern(node.left);
                    const right = visitNode(node.right, visitor, isExpression);
                    return factory2.updateBinaryExpression(node, left, node.operatorToken, right);
                }
                if (isAssignmentExpression(node)) {
                    if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                        const assignedName = getAssignedNameOfIdentifier(node.left, node.right);
                        const left = visitNode(node.left, visitor, isExpression);
                        const right = visitNode(node.right, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                        return factory2.updateBinaryExpression(node, left, node.operatorToken, right);
                    }
                    if (isSuperProperty(node.left) && classThis && classSuper) {
                        let setterName = isElementAccessExpression(node.left) ? visitNode(node.left.argumentExpression, visitor, isExpression) : isIdentifier(node.left.name) ? factory2.createStringLiteralFromNode(node.left.name) : void 0;
                        if (setterName) {
                            let expression = visitNode(node.right, visitor, isExpression);
                            if (isCompoundAssignment(node.operatorToken.kind)) {
                                let getterName = setterName;
                                if (!isSimpleInlineableExpression(setterName)) {
                                    getterName = factory2.createTempVariable(hoistVariableDeclaration);
                                    setterName = factory2.createAssignment(getterName, setterName);
                                }
                                const superPropertyGet = factory2.createReflectGetCall(classSuper, getterName, classThis);
                                setOriginalNode(superPropertyGet, node.left);
                                setTextRange(superPropertyGet, node.left);
                                expression = factory2.createBinaryExpression(superPropertyGet, getNonAssignmentOperatorForCompoundAssignment(node.operatorToken.kind), expression);
                                setTextRange(expression, node);
                            }
                            const temp = discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                            if (temp) {
                                expression = factory2.createAssignment(temp, expression);
                                setTextRange(temp, node);
                            }
                            expression = factory2.createReflectSetCall(classSuper, setterName, expression, classThis);
                            setOriginalNode(expression, node);
                            setTextRange(expression, node);
                            if (temp) {
                                expression = factory2.createComma(expression, temp);
                                setTextRange(expression, node);
                            }
                            return expression;
                        }
                    }
                }
                if (node.operatorToken.kind === 27 /* CommaToken */) {
                    const left = visitNode(node.left, discardedValueVisitor, isExpression);
                    const right = visitNode(node.right, discarded ? discardedValueVisitor : visitor, isExpression);
                    return factory2.updateBinaryExpression(node, left, node.operatorToken, right);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitPreOrPostfixUnaryExpression(node, discarded) {
                if (node.operator === 45 /* PlusPlusToken */ || node.operator === 46 /* MinusMinusToken */) {
                    const operand = skipParentheses(node.operand);
                    if (isSuperProperty(operand) && classThis && classSuper) {
                        let setterName = isElementAccessExpression(operand) ? visitNode(operand.argumentExpression, visitor, isExpression) : isIdentifier(operand.name) ? factory2.createStringLiteralFromNode(operand.name) : void 0;
                        if (setterName) {
                            let getterName = setterName;
                            if (!isSimpleInlineableExpression(setterName)) {
                                getterName = factory2.createTempVariable(hoistVariableDeclaration);
                                setterName = factory2.createAssignment(getterName, setterName);
                            }
                            let expression = factory2.createReflectGetCall(classSuper, getterName, classThis);
                            setOriginalNode(expression, node);
                            setTextRange(expression, node);
                            const temp = discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                            expression = expandPreOrPostfixIncrementOrDecrementExpression(factory2, node, expression, hoistVariableDeclaration, temp);
                            expression = factory2.createReflectSetCall(classSuper, setterName, expression, classThis);
                            setOriginalNode(expression, node);
                            setTextRange(expression, node);
                            if (temp) {
                                expression = factory2.createComma(expression, temp);
                                setTextRange(expression, node);
                            }
                            return expression;
                        }
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaListExpression(node, discarded) {
                const elements = discarded ? visitCommaListElements(node.elements, discardedValueVisitor) : visitCommaListElements(node.elements, visitor, discardedValueVisitor);
                return factory2.updateCommaListExpression(node, elements);
            }
            function visitReferencedPropertyName(node) {
                if (isPropertyNameLiteral(node) || isPrivateIdentifier(node)) {
                    const referencedName2 = factory2.createStringLiteralFromNode(node);
                    const name2 = visitNode(node, visitor, isPropertyName);
                    return { referencedName: referencedName2, name: name2 };
                }
                if (isPropertyNameLiteral(node.expression) && !isIdentifier(node.expression)) {
                    const referencedName2 = factory2.createStringLiteralFromNode(node.expression);
                    const name2 = visitNode(node, visitor, isPropertyName);
                    return { referencedName: referencedName2, name: name2 };
                }
                const referencedName = factory2.getGeneratedNameForNode(node);
                hoistVariableDeclaration(referencedName);
                const key = emitHelpers().createPropKeyHelper(visitNode(node.expression, visitor, isExpression));
                const assignment = factory2.createAssignment(referencedName, key);
                const name = factory2.updateComputedPropertyName(node, injectPendingExpressions(assignment));
                return { referencedName, name };
            }
            function visitPropertyName(node) {
                if (isComputedPropertyName(node)) {
                    return visitComputedPropertyName(node);
                }
                return visitNode(node, visitor, isPropertyName);
            }
            function visitComputedPropertyName(node) {
                let expression = visitNode(node.expression, visitor, isExpression);
                if (!isSimpleInlineableExpression(expression)) {
                    expression = injectPendingExpressions(expression);
                }
                return factory2.updateComputedPropertyName(node, expression);
            }
            function visitPropertyAssignment(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const { referencedName, name } = visitReferencedPropertyName(node.name);
                    const initializer = visitNode(node.initializer, (node2) => namedEvaluationVisitor(node2, referencedName), isExpression);
                    return factory2.updatePropertyAssignment(node, name, initializer);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableDeclaration(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const assignedName = getAssignedNameOfIdentifier(node.name, node.initializer);
                    const name = visitNode(node.name, visitor, isBindingName);
                    const initializer = visitNode(node.initializer, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    return factory2.updateVariableDeclaration(node, name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitBindingElement(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const assignedName = getAssignedNameOfIdentifier(node.name, node.initializer);
                    const propertyName = visitNode(node.propertyName, visitor, isPropertyName);
                    const name = visitNode(node.name, visitor, isBindingName);
                    const initializer = visitNode(node.initializer, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    return factory2.updateBindingElement(node, 
                    /*dotDotDotToken*/
                    void 0, propertyName, name, initializer);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitDestructuringAssignmentTarget(node) {
                if (isObjectLiteralExpression(node) || isArrayLiteralExpression(node)) {
                    return visitAssignmentPattern(node);
                }
                if (isSuperProperty(node) && classThis && classSuper) {
                    const propertyName = isElementAccessExpression(node) ? visitNode(node.argumentExpression, visitor, isExpression) : isIdentifier(node.name) ? factory2.createStringLiteralFromNode(node.name) : void 0;
                    if (propertyName) {
                        const paramName = factory2.createTempVariable(
                        /*recordTempVariable*/
                        void 0);
                        const expression = factory2.createAssignmentTargetWrapper(paramName, factory2.createReflectSetCall(classSuper, propertyName, paramName, classThis));
                        setOriginalNode(expression, node);
                        setTextRange(expression, node);
                        return expression;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentElement(node) {
                if (isAssignmentExpression(node, 
                /*excludeCompoundAssignment*/
                true)) {
                    const assignmentTarget = visitDestructuringAssignmentTarget(node.left);
                    let initializer;
                    if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                        const assignedName = getAssignedNameOfIdentifier(node.left, node.right);
                        initializer = visitNode(node.right, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    }
                    else {
                        initializer = visitNode(node.right, visitor, isExpression);
                    }
                    return factory2.updateBinaryExpression(node, assignmentTarget, node.operatorToken, initializer);
                }
                else {
                    return visitDestructuringAssignmentTarget(node);
                }
            }
            function visitAssignmentRestElement(node) {
                if (isLeftHandSideExpression(node.expression)) {
                    const expression = visitDestructuringAssignmentTarget(node.expression);
                    return factory2.updateSpreadElement(node, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitArrayAssignmentElement(node) {
                Debug.assertNode(node, isArrayBindingOrAssignmentElement);
                if (isSpreadElement(node))
                    return visitAssignmentRestElement(node);
                if (!isOmittedExpression(node))
                    return visitAssignmentElement(node);
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentProperty(node) {
                const name = visitNode(node.name, visitor, isPropertyName);
                if (isAssignmentExpression(node.initializer, 
                /*excludeCompoundAssignment*/
                true)) {
                    const assignmentElement = visitAssignmentElement(node.initializer);
                    return factory2.updatePropertyAssignment(node, name, assignmentElement);
                }
                if (isLeftHandSideExpression(node.initializer)) {
                    const assignmentElement = visitDestructuringAssignmentTarget(node.initializer);
                    return factory2.updatePropertyAssignment(node, name, assignmentElement);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitShorthandAssignmentProperty(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const assignedName = getAssignedNameOfIdentifier(node.name, node.objectAssignmentInitializer);
                    const name = visitNode(node.name, visitor, isIdentifier);
                    const objectAssignmentInitializer = visitNode(node.objectAssignmentInitializer, (node2) => namedEvaluationVisitor(node2, assignedName), isExpression);
                    return factory2.updateShorthandPropertyAssignment(node, name, objectAssignmentInitializer);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentRestProperty(node) {
                if (isLeftHandSideExpression(node.expression)) {
                    const expression = visitDestructuringAssignmentTarget(node.expression);
                    return factory2.updateSpreadAssignment(node, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitObjectAssignmentElement(node) {
                Debug.assertNode(node, isObjectBindingOrAssignmentElement);
                if (isSpreadAssignment(node))
                    return visitAssignmentRestProperty(node);
                if (isShorthandPropertyAssignment(node))
                    return visitShorthandAssignmentProperty(node);
                if (isPropertyAssignment(node))
                    return visitAssignmentProperty(node);
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentPattern(node) {
                if (isArrayLiteralExpression(node)) {
                    const elements = visitNodes2(node.elements, visitArrayAssignmentElement, isExpression);
                    return factory2.updateArrayLiteralExpression(node, elements);
                }
                else {
                    const properties = visitNodes2(node.properties, visitObjectAssignmentElement, isObjectLiteralElementLike);
                    return factory2.updateObjectLiteralExpression(node, properties);
                }
            }
            function visitExportAssignment(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    const referencedName = factory2.createStringLiteral(node.isExportEquals ? "" : "default");
                    const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                    const expression = visitNode(node.expression, (node2) => namedEvaluationVisitor(node2, referencedName), isExpression);
                    return factory2.updateExportAssignment(node, modifiers, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitParenthesizedExpression(node, discarded, referencedName) {
                const visitorFunc = discarded ? discardedValueVisitor : referencedName ? (node2) => namedEvaluationVisitor(node2, referencedName) : visitor;
                const expression = visitNode(node.expression, visitorFunc, isExpression);
                return factory2.updateParenthesizedExpression(node, expression);
            }
            function visitPartiallyEmittedExpression(node, discarded, referencedName) {
                const visitorFunc = discarded ? discardedValueVisitor : referencedName ? (node2) => namedEvaluationVisitor(node2, referencedName) : visitor;
                const expression = visitNode(node.expression, visitorFunc, isExpression);
                return factory2.updatePartiallyEmittedExpression(node, expression);
            }
            function injectPendingExpressions(expression) {
                if (some(pendingExpressions)) {
                    if (isParenthesizedExpression(expression)) {
                        pendingExpressions.push(expression.expression);
                        expression = factory2.updateParenthesizedExpression(expression, factory2.inlineExpressions(pendingExpressions));
                    }
                    else {
                        pendingExpressions.push(expression);
                        expression = factory2.inlineExpressions(pendingExpressions);
                    }
                    pendingExpressions = void 0;
                }
                return expression;
            }
            function transformAllDecoratorsOfDeclaration(allDecorators) {
                if (!allDecorators) {
                    return void 0;
                }
                const decoratorExpressions = [];
                addRange(decoratorExpressions, map(allDecorators.decorators, transformDecorator));
                return decoratorExpressions;
            }
            function transformDecorator(decorator) {
                const expression = visitNode(decorator.expression, visitor, isExpression);
                setEmitFlags(expression, 3072 /* NoComments */);
                return expression;
            }
            function createDescriptorMethod(original, name, modifiers, asteriskToken, kind, parameters, body) {
                const func = factory2.createFunctionExpression(modifiers, asteriskToken, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, parameters, 
                /*type*/
                void 0, body != null ? body : factory2.createBlock([]));
                setOriginalNode(func, original);
                setSourceMapRange(func, moveRangePastDecorators(original));
                setEmitFlags(func, 3072 /* NoComments */);
                const prefix = kind === "get" || kind === "set" ? kind : void 0;
                const functionName = factory2.createStringLiteralFromNode(name, 
                /*isSingleQuote*/
                void 0);
                const namedFunction = emitHelpers().createSetFunctionNameHelper(func, functionName, prefix);
                const method = factory2.createPropertyAssignment(factory2.createIdentifier(kind), namedFunction);
                setOriginalNode(method, original);
                setSourceMapRange(method, moveRangePastDecorators(original));
                setEmitFlags(method, 3072 /* NoComments */);
                return method;
            }
            function createMethodDescriptorObject(node, modifiers) {
                return factory2.createObjectLiteralExpression([
                    createDescriptorMethod(node, node.name, modifiers, node.asteriskToken, "value", visitNodes2(node.parameters, visitor, isParameter), visitNode(node.body, visitor, isBlock))
                ]);
            }
            function createGetAccessorDescriptorObject(node, modifiers) {
                return factory2.createObjectLiteralExpression([
                    createDescriptorMethod(node, node.name, modifiers, 
                    /*asteriskToken*/
                    void 0, "get", [], visitNode(node.body, visitor, isBlock))
                ]);
            }
            function createSetAccessorDescriptorObject(node, modifiers) {
                return factory2.createObjectLiteralExpression([
                    createDescriptorMethod(node, node.name, modifiers, 
                    /*asteriskToken*/
                    void 0, "set", visitNodes2(node.parameters, visitor, isParameter), visitNode(node.body, visitor, isBlock))
                ]);
            }
            function createAccessorPropertyDescriptorObject(node, modifiers) {
                return factory2.createObjectLiteralExpression([
                    createDescriptorMethod(node, node.name, modifiers, 
                    /*asteriskToken*/
                    void 0, "get", [], factory2.createBlock([
                        factory2.createReturnStatement(factory2.createPropertyAccessExpression(factory2.createThis(), factory2.getGeneratedPrivateNameForNode(node.name)))
                    ])),
                    createDescriptorMethod(node, node.name, modifiers, 
                    /*asteriskToken*/
                    void 0, "set", [factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, "value")], factory2.createBlock([
                        factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createThis(), factory2.getGeneratedPrivateNameForNode(node.name)), factory2.createIdentifier("value")))
                    ]))
                ]);
            }
            function createMethodDescriptorForwarder(modifiers, name, descriptorName) {
                modifiers = visitNodes2(modifiers, (node) => isStaticModifier(node) ? node : void 0, isModifier);
                return factory2.createGetAccessorDeclaration(modifiers, name, [], 
                /*type*/
                void 0, factory2.createBlock([
                    factory2.createReturnStatement(factory2.createPropertyAccessExpression(descriptorName, factory2.createIdentifier("value")))
                ]));
            }
            function createGetAccessorDescriptorForwarder(modifiers, name, descriptorName) {
                modifiers = visitNodes2(modifiers, (node) => isStaticModifier(node) ? node : void 0, isModifier);
                return factory2.createGetAccessorDeclaration(modifiers, name, [], 
                /*type*/
                void 0, factory2.createBlock([
                    factory2.createReturnStatement(factory2.createFunctionCallCall(factory2.createPropertyAccessExpression(descriptorName, factory2.createIdentifier("get")), factory2.createThis(), []))
                ]));
            }
            function createSetAccessorDescriptorForwarder(modifiers, name, descriptorName) {
                modifiers = visitNodes2(modifiers, (node) => isStaticModifier(node) ? node : void 0, isModifier);
                return factory2.createSetAccessorDeclaration(modifiers, name, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, "value")], factory2.createBlock([
                    factory2.createReturnStatement(factory2.createFunctionCallCall(factory2.createPropertyAccessExpression(descriptorName, factory2.createIdentifier("set")), factory2.createThis(), [factory2.createIdentifier("value")]))
                ]));
            }
            function getAssignedNameOfIdentifier(name, initializer) {
                const originalClass = getOriginalNode(initializer, isClassLike);
                return originalClass && !originalClass.name && hasSyntacticModifier(originalClass, 1024 /* Default */) ? factory2.createStringLiteral("default") : factory2.createStringLiteralFromNode(name);
            }
        }
        var init_esDecorators = __esm({
            "src/compiler/transformers/esDecorators.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2017.ts
        function transformES2017(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, resumeLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            let enabledSubstitutions;
            let enclosingSuperContainerFlags = 0;
            let enclosingFunctionParameterNames;
            let capturedSuperProperties;
            let hasSuperElementAccess;
            const substitutedSuperAccessors = [];
            let contextFlags = 0 /* None */;
            const previousOnEmitNode = context.onEmitNode;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                setContextFlag(1 /* NonTopLevel */, false);
                setContextFlag(2 /* HasLexicalThis */, !isEffectiveStrictModeSourceFile(node, compilerOptions));
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                return visited;
            }
            function setContextFlag(flag, val) {
                contextFlags = val ? contextFlags | flag : contextFlags & ~flag;
            }
            function inContext(flags) {
                return (contextFlags & flags) !== 0;
            }
            function inTopLevelContext() {
                return !inContext(1 /* NonTopLevel */);
            }
            function inHasLexicalThisContext() {
                return inContext(2 /* HasLexicalThis */);
            }
            function doWithContext(flags, cb, value) {
                const contextFlagsToSet = flags & ~contextFlags;
                if (contextFlagsToSet) {
                    setContextFlag(contextFlagsToSet, 
                    /*val*/
                    true);
                    const result = cb(value);
                    setContextFlag(contextFlagsToSet, 
                    /*val*/
                    false);
                    return result;
                }
                return cb(value);
            }
            function visitDefault(node) {
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 256 /* ContainsES2017 */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 132 /* AsyncKeyword */:
                        return void 0;
                    case 220 /* AwaitExpression */:
                        return visitAwaitExpression(node);
                    case 171 /* MethodDeclaration */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitMethodDeclaration, node);
                    case 259 /* FunctionDeclaration */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitFunctionDeclaration, node);
                    case 215 /* FunctionExpression */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitFunctionExpression, node);
                    case 216 /* ArrowFunction */:
                        return doWithContext(1 /* NonTopLevel */, visitArrowFunction, node);
                    case 208 /* PropertyAccessExpression */:
                        if (capturedSuperProperties && isPropertyAccessExpression(node) && node.expression.kind === 106 /* SuperKeyword */) {
                            capturedSuperProperties.add(node.name.escapedText);
                        }
                        return visitEachChild(node, visitor, context);
                    case 209 /* ElementAccessExpression */:
                        if (capturedSuperProperties && node.expression.kind === 106 /* SuperKeyword */) {
                            hasSuperElementAccess = true;
                        }
                        return visitEachChild(node, visitor, context);
                    case 174 /* GetAccessor */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitGetAccessorDeclaration, node);
                    case 175 /* SetAccessor */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitSetAccessorDeclaration, node);
                    case 173 /* Constructor */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitConstructorDeclaration, node);
                    case 260 /* ClassDeclaration */:
                    case 228 /* ClassExpression */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitDefault, node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function asyncBodyVisitor(node) {
                if (isNodeWithPossibleHoistedDeclaration(node)) {
                    switch (node.kind) {
                        case 240 /* VariableStatement */:
                            return visitVariableStatementInAsyncBody(node);
                        case 245 /* ForStatement */:
                            return visitForStatementInAsyncBody(node);
                        case 246 /* ForInStatement */:
                            return visitForInStatementInAsyncBody(node);
                        case 247 /* ForOfStatement */:
                            return visitForOfStatementInAsyncBody(node);
                        case 295 /* CatchClause */:
                            return visitCatchClauseInAsyncBody(node);
                        case 238 /* Block */:
                        case 252 /* SwitchStatement */:
                        case 266 /* CaseBlock */:
                        case 292 /* CaseClause */:
                        case 293 /* DefaultClause */:
                        case 255 /* TryStatement */:
                        case 243 /* DoStatement */:
                        case 244 /* WhileStatement */:
                        case 242 /* IfStatement */:
                        case 251 /* WithStatement */:
                        case 253 /* LabeledStatement */:
                            return visitEachChild(node, asyncBodyVisitor, context);
                        default:
                            return Debug.assertNever(node, "Unhandled node.");
                    }
                }
                return visitor(node);
            }
            function visitCatchClauseInAsyncBody(node) {
                const catchClauseNames = /* @__PURE__ */ new Set();
                recordDeclarationName(node.variableDeclaration, catchClauseNames);
                let catchClauseUnshadowedNames;
                catchClauseNames.forEach((_, escapedName) => {
                    if (enclosingFunctionParameterNames.has(escapedName)) {
                        if (!catchClauseUnshadowedNames) {
                            catchClauseUnshadowedNames = new Set(enclosingFunctionParameterNames);
                        }
                        catchClauseUnshadowedNames.delete(escapedName);
                    }
                });
                if (catchClauseUnshadowedNames) {
                    const savedEnclosingFunctionParameterNames = enclosingFunctionParameterNames;
                    enclosingFunctionParameterNames = catchClauseUnshadowedNames;
                    const result = visitEachChild(node, asyncBodyVisitor, context);
                    enclosingFunctionParameterNames = savedEnclosingFunctionParameterNames;
                    return result;
                }
                else {
                    return visitEachChild(node, asyncBodyVisitor, context);
                }
            }
            function visitVariableStatementInAsyncBody(node) {
                if (isVariableDeclarationListWithCollidingName(node.declarationList)) {
                    const expression = visitVariableDeclarationListWithCollidingNames(node.declarationList, 
                    /*hasReceiver*/
                    false);
                    return expression ? factory2.createExpressionStatement(expression) : void 0;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForInStatementInAsyncBody(node) {
                return factory2.updateForInStatement(node, isVariableDeclarationListWithCollidingName(node.initializer) ? visitVariableDeclarationListWithCollidingNames(node.initializer, 
                /*hasReceiver*/
                true) : Debug.checkDefined(visitNode(node.initializer, visitor, isForInitializer)), Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), visitIterationBody(node.statement, asyncBodyVisitor, context));
            }
            function visitForOfStatementInAsyncBody(node) {
                return factory2.updateForOfStatement(node, visitNode(node.awaitModifier, visitor, isAwaitKeyword), isVariableDeclarationListWithCollidingName(node.initializer) ? visitVariableDeclarationListWithCollidingNames(node.initializer, 
                /*hasReceiver*/
                true) : Debug.checkDefined(visitNode(node.initializer, visitor, isForInitializer)), Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), visitIterationBody(node.statement, asyncBodyVisitor, context));
            }
            function visitForStatementInAsyncBody(node) {
                const initializer = node.initializer;
                return factory2.updateForStatement(node, isVariableDeclarationListWithCollidingName(initializer) ? visitVariableDeclarationListWithCollidingNames(initializer, 
                /*hasReceiver*/
                false) : visitNode(node.initializer, visitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, visitor, isExpression), visitIterationBody(node.statement, asyncBodyVisitor, context));
            }
            function visitAwaitExpression(node) {
                if (inTopLevelContext()) {
                    return visitEachChild(node, visitor, context);
                }
                return setOriginalNode(setTextRange(factory2.createYieldExpression(
                /*asteriskToken*/
                void 0, visitNode(node.expression, visitor, isExpression)), node), node);
            }
            function visitConstructorDeclaration(node) {
                return factory2.updateConstructorDeclaration(node, visitNodes2(node.modifiers, visitor, isModifier), visitParameterList(node.parameters, visitor, context), transformMethodBody(node));
            }
            function visitMethodDeclaration(node) {
                return factory2.updateMethodDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.asteriskToken, node.name, 
                /*questionToken*/
                void 0, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, getFunctionFlags(node) & 2 /* Async */ ? transformAsyncFunctionBody(node) : transformMethodBody(node));
            }
            function visitGetAccessorDeclaration(node) {
                return factory2.updateGetAccessorDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.name, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, transformMethodBody(node));
            }
            function visitSetAccessorDeclaration(node) {
                return factory2.updateSetAccessorDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.name, visitParameterList(node.parameters, visitor, context), transformMethodBody(node));
            }
            function visitFunctionDeclaration(node) {
                return factory2.updateFunctionDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, getFunctionFlags(node) & 2 /* Async */ ? transformAsyncFunctionBody(node) : visitFunctionBody(node.body, visitor, context));
            }
            function visitFunctionExpression(node) {
                return factory2.updateFunctionExpression(node, visitNodes2(node.modifiers, visitor, isModifier), node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, getFunctionFlags(node) & 2 /* Async */ ? transformAsyncFunctionBody(node) : visitFunctionBody(node.body, visitor, context));
            }
            function visitArrowFunction(node) {
                return factory2.updateArrowFunction(node, visitNodes2(node.modifiers, visitor, isModifier), 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, node.equalsGreaterThanToken, getFunctionFlags(node) & 2 /* Async */ ? transformAsyncFunctionBody(node) : visitFunctionBody(node.body, visitor, context));
            }
            function recordDeclarationName({ name }, names) {
                if (isIdentifier(name)) {
                    names.add(name.escapedText);
                }
                else {
                    for (const element of name.elements) {
                        if (!isOmittedExpression(element)) {
                            recordDeclarationName(element, names);
                        }
                    }
                }
            }
            function isVariableDeclarationListWithCollidingName(node) {
                return !!node && isVariableDeclarationList(node) && !(node.flags & 3 /* BlockScoped */) && node.declarations.some(collidesWithParameterName);
            }
            function visitVariableDeclarationListWithCollidingNames(node, hasReceiver) {
                hoistVariableDeclarationList(node);
                const variables = getInitializedVariables(node);
                if (variables.length === 0) {
                    if (hasReceiver) {
                        return visitNode(factory2.converters.convertToAssignmentElementTarget(node.declarations[0].name), visitor, isExpression);
                    }
                    return void 0;
                }
                return factory2.inlineExpressions(map(variables, transformInitializedVariable));
            }
            function hoistVariableDeclarationList(node) {
                forEach(node.declarations, hoistVariable);
            }
            function hoistVariable({ name }) {
                if (isIdentifier(name)) {
                    hoistVariableDeclaration(name);
                }
                else {
                    for (const element of name.elements) {
                        if (!isOmittedExpression(element)) {
                            hoistVariable(element);
                        }
                    }
                }
            }
            function transformInitializedVariable(node) {
                const converted = setSourceMapRange(factory2.createAssignment(factory2.converters.convertToAssignmentElementTarget(node.name), node.initializer), node);
                return Debug.checkDefined(visitNode(converted, visitor, isExpression));
            }
            function collidesWithParameterName({ name }) {
                if (isIdentifier(name)) {
                    return enclosingFunctionParameterNames.has(name.escapedText);
                }
                else {
                    for (const element of name.elements) {
                        if (!isOmittedExpression(element) && collidesWithParameterName(element)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function transformMethodBody(node) {
                Debug.assertIsDefined(node.body);
                const savedCapturedSuperProperties = capturedSuperProperties;
                const savedHasSuperElementAccess = hasSuperElementAccess;
                capturedSuperProperties = /* @__PURE__ */ new Set();
                hasSuperElementAccess = false;
                let updated = visitFunctionBody(node.body, visitor, context);
                const originalMethod = getOriginalNode(node, isFunctionLikeDeclaration);
                const emitSuperHelpers = languageVersion >= 2 /* ES2015 */ && resolver.getNodeCheckFlags(node) & (256 /* MethodWithSuperPropertyAssignmentInAsync */ | 128 /* MethodWithSuperPropertyAccessInAsync */) && (getFunctionFlags(originalMethod) & 3 /* AsyncGenerator */) !== 3 /* AsyncGenerator */;
                if (emitSuperHelpers) {
                    enableSubstitutionForAsyncMethodsWithSuper();
                    if (capturedSuperProperties.size) {
                        const variableStatement = createSuperAccessVariableStatement(factory2, resolver, node, capturedSuperProperties);
                        substitutedSuperAccessors[getNodeId(variableStatement)] = true;
                        const statements = updated.statements.slice();
                        insertStatementsAfterStandardPrologue(statements, [variableStatement]);
                        updated = factory2.updateBlock(updated, statements);
                    }
                    if (hasSuperElementAccess) {
                        if (resolver.getNodeCheckFlags(node) & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                            addEmitHelper(updated, advancedAsyncSuperHelper);
                        }
                        else if (resolver.getNodeCheckFlags(node) & 128 /* MethodWithSuperPropertyAccessInAsync */) {
                            addEmitHelper(updated, asyncSuperHelper);
                        }
                    }
                }
                capturedSuperProperties = savedCapturedSuperProperties;
                hasSuperElementAccess = savedHasSuperElementAccess;
                return updated;
            }
            function transformAsyncFunctionBody(node) {
                resumeLexicalEnvironment();
                const original = getOriginalNode(node, isFunctionLike);
                const nodeType = original.type;
                const promiseConstructor = languageVersion < 2 /* ES2015 */ ? getPromiseConstructor(nodeType) : void 0;
                const isArrowFunction2 = node.kind === 216 /* ArrowFunction */;
                const hasLexicalArguments = (resolver.getNodeCheckFlags(node) & 512 /* CaptureArguments */) !== 0;
                const savedEnclosingFunctionParameterNames = enclosingFunctionParameterNames;
                enclosingFunctionParameterNames = /* @__PURE__ */ new Set();
                for (const parameter of node.parameters) {
                    recordDeclarationName(parameter, enclosingFunctionParameterNames);
                }
                const savedCapturedSuperProperties = capturedSuperProperties;
                const savedHasSuperElementAccess = hasSuperElementAccess;
                if (!isArrowFunction2) {
                    capturedSuperProperties = /* @__PURE__ */ new Set();
                    hasSuperElementAccess = false;
                }
                let result;
                if (!isArrowFunction2) {
                    const statements = [];
                    const statementOffset = factory2.copyPrologue(node.body.statements, statements, 
                    /*ensureUseStrict*/
                    false, visitor);
                    statements.push(factory2.createReturnStatement(emitHelpers().createAwaiterHelper(inHasLexicalThisContext(), hasLexicalArguments, promiseConstructor, transformAsyncFunctionBodyWorker(node.body, statementOffset))));
                    insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                    const emitSuperHelpers = languageVersion >= 2 /* ES2015 */ && resolver.getNodeCheckFlags(node) & (256 /* MethodWithSuperPropertyAssignmentInAsync */ | 128 /* MethodWithSuperPropertyAccessInAsync */);
                    if (emitSuperHelpers) {
                        enableSubstitutionForAsyncMethodsWithSuper();
                        if (capturedSuperProperties.size) {
                            const variableStatement = createSuperAccessVariableStatement(factory2, resolver, node, capturedSuperProperties);
                            substitutedSuperAccessors[getNodeId(variableStatement)] = true;
                            insertStatementsAfterStandardPrologue(statements, [variableStatement]);
                        }
                    }
                    const block = factory2.createBlock(statements, 
                    /*multiLine*/
                    true);
                    setTextRange(block, node.body);
                    if (emitSuperHelpers && hasSuperElementAccess) {
                        if (resolver.getNodeCheckFlags(node) & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                            addEmitHelper(block, advancedAsyncSuperHelper);
                        }
                        else if (resolver.getNodeCheckFlags(node) & 128 /* MethodWithSuperPropertyAccessInAsync */) {
                            addEmitHelper(block, asyncSuperHelper);
                        }
                    }
                    result = block;
                }
                else {
                    const expression = emitHelpers().createAwaiterHelper(inHasLexicalThisContext(), hasLexicalArguments, promiseConstructor, transformAsyncFunctionBodyWorker(node.body));
                    const declarations = endLexicalEnvironment();
                    if (some(declarations)) {
                        const block = factory2.converters.convertToFunctionBlock(expression);
                        result = factory2.updateBlock(block, setTextRange(factory2.createNodeArray(concatenate(declarations, block.statements)), block.statements));
                    }
                    else {
                        result = expression;
                    }
                }
                enclosingFunctionParameterNames = savedEnclosingFunctionParameterNames;
                if (!isArrowFunction2) {
                    capturedSuperProperties = savedCapturedSuperProperties;
                    hasSuperElementAccess = savedHasSuperElementAccess;
                }
                return result;
            }
            function transformAsyncFunctionBodyWorker(body, start) {
                if (isBlock(body)) {
                    return factory2.updateBlock(body, visitNodes2(body.statements, asyncBodyVisitor, isStatement, start));
                }
                else {
                    return factory2.converters.convertToFunctionBlock(Debug.checkDefined(visitNode(body, asyncBodyVisitor, isConciseBody)));
                }
            }
            function getPromiseConstructor(type) {
                const typeName = type && getEntityNameFromTypeNode(type);
                if (typeName && isEntityName(typeName)) {
                    const serializationKind = resolver.getTypeReferenceSerializationKind(typeName);
                    if (serializationKind === 1 /* TypeWithConstructSignatureAndValue */ || serializationKind === 0 /* Unknown */) {
                        return typeName;
                    }
                }
                return void 0;
            }
            function enableSubstitutionForAsyncMethodsWithSuper() {
                if ((enabledSubstitutions & 1 /* AsyncMethodsWithSuper */) === 0) {
                    enabledSubstitutions |= 1 /* AsyncMethodsWithSuper */;
                    context.enableSubstitution(210 /* CallExpression */);
                    context.enableSubstitution(208 /* PropertyAccessExpression */);
                    context.enableSubstitution(209 /* ElementAccessExpression */);
                    context.enableEmitNotification(260 /* ClassDeclaration */);
                    context.enableEmitNotification(171 /* MethodDeclaration */);
                    context.enableEmitNotification(174 /* GetAccessor */);
                    context.enableEmitNotification(175 /* SetAccessor */);
                    context.enableEmitNotification(173 /* Constructor */);
                    context.enableEmitNotification(240 /* VariableStatement */);
                }
            }
            function onEmitNode(hint, node, emitCallback) {
                if (enabledSubstitutions & 1 /* AsyncMethodsWithSuper */ && isSuperContainer(node)) {
                    const superContainerFlags = resolver.getNodeCheckFlags(node) & (128 /* MethodWithSuperPropertyAccessInAsync */ | 256 /* MethodWithSuperPropertyAssignmentInAsync */);
                    if (superContainerFlags !== enclosingSuperContainerFlags) {
                        const savedEnclosingSuperContainerFlags = enclosingSuperContainerFlags;
                        enclosingSuperContainerFlags = superContainerFlags;
                        previousOnEmitNode(hint, node, emitCallback);
                        enclosingSuperContainerFlags = savedEnclosingSuperContainerFlags;
                        return;
                    }
                }
                else if (enabledSubstitutions && substitutedSuperAccessors[getNodeId(node)]) {
                    const savedEnclosingSuperContainerFlags = enclosingSuperContainerFlags;
                    enclosingSuperContainerFlags = 0;
                    previousOnEmitNode(hint, node, emitCallback);
                    enclosingSuperContainerFlags = savedEnclosingSuperContainerFlags;
                    return;
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */ && enclosingSuperContainerFlags) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 208 /* PropertyAccessExpression */:
                        return substitutePropertyAccessExpression(node);
                    case 209 /* ElementAccessExpression */:
                        return substituteElementAccessExpression(node);
                    case 210 /* CallExpression */:
                        return substituteCallExpression(node);
                }
                return node;
            }
            function substitutePropertyAccessExpression(node) {
                if (node.expression.kind === 106 /* SuperKeyword */) {
                    return setTextRange(factory2.createPropertyAccessExpression(factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */), node.name), node);
                }
                return node;
            }
            function substituteElementAccessExpression(node) {
                if (node.expression.kind === 106 /* SuperKeyword */) {
                    return createSuperElementAccessInAsyncMethod(node.argumentExpression, node);
                }
                return node;
            }
            function substituteCallExpression(node) {
                const expression = node.expression;
                if (isSuperProperty(expression)) {
                    const argumentExpression = isPropertyAccessExpression(expression) ? substitutePropertyAccessExpression(expression) : substituteElementAccessExpression(expression);
                    return factory2.createCallExpression(factory2.createPropertyAccessExpression(argumentExpression, "call"), 
                    /*typeArguments*/
                    void 0, [
                        factory2.createThis(),
                        ...node.arguments
                    ]);
                }
                return node;
            }
            function isSuperContainer(node) {
                const kind = node.kind;
                return kind === 260 /* ClassDeclaration */ || kind === 173 /* Constructor */ || kind === 171 /* MethodDeclaration */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */;
            }
            function createSuperElementAccessInAsyncMethod(argumentExpression, location) {
                if (enclosingSuperContainerFlags & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                    return setTextRange(factory2.createPropertyAccessExpression(factory2.createCallExpression(factory2.createUniqueName("_superIndex", 16 /* Optimistic */ | 32 /* FileLevel */), 
                    /*typeArguments*/
                    void 0, [argumentExpression]), "value"), location);
                }
                else {
                    return setTextRange(factory2.createCallExpression(factory2.createUniqueName("_superIndex", 16 /* Optimistic */ | 32 /* FileLevel */), 
                    /*typeArguments*/
                    void 0, [argumentExpression]), location);
                }
            }
        }
        function createSuperAccessVariableStatement(factory2, resolver, node, names) {
            const hasBinding = (resolver.getNodeCheckFlags(node) & 256 /* MethodWithSuperPropertyAssignmentInAsync */) !== 0;
            const accessors = [];
            names.forEach((_, key) => {
                const name = unescapeLeadingUnderscores(key);
                const getterAndSetter = [];
                getterAndSetter.push(factory2.createPropertyAssignment("get", factory2.createArrowFunction(
                /* modifiers */
                void 0, 
                /* typeParameters */
                void 0, 
                /* parameters */
                [], 
                /* type */
                void 0, 
                /* equalsGreaterThanToken */
                void 0, setEmitFlags(factory2.createPropertyAccessExpression(setEmitFlags(factory2.createSuper(), 8 /* NoSubstitution */), name), 8 /* NoSubstitution */))));
                if (hasBinding) {
                    getterAndSetter.push(factory2.createPropertyAssignment("set", factory2.createArrowFunction(
                    /* modifiers */
                    void 0, 
                    /* typeParameters */
                    void 0, 
                    /* parameters */
                    [
                        factory2.createParameterDeclaration(
                        /* modifiers */
                        void 0, 
                        /* dotDotDotToken */
                        void 0, "v", 
                        /* questionToken */
                        void 0, 
                        /* type */
                        void 0, 
                        /* initializer */
                        void 0)
                    ], 
                    /* type */
                    void 0, 
                    /* equalsGreaterThanToken */
                    void 0, factory2.createAssignment(setEmitFlags(factory2.createPropertyAccessExpression(setEmitFlags(factory2.createSuper(), 8 /* NoSubstitution */), name), 8 /* NoSubstitution */), factory2.createIdentifier("v")))));
                }
                accessors.push(factory2.createPropertyAssignment(name, factory2.createObjectLiteralExpression(getterAndSetter)));
            });
            return factory2.createVariableStatement(
            /* modifiers */
            void 0, factory2.createVariableDeclarationList([
                factory2.createVariableDeclaration(factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */), 
                /*exclamationToken*/
                void 0, 
                /* type */
                void 0, factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "create"), 
                /* typeArguments */
                void 0, [
                    factory2.createNull(),
                    factory2.createObjectLiteralExpression(accessors, 
                    /* multiline */
                    true)
                ]))
            ], 2 /* Const */));
        }
        var init_es2017 = __esm({
            "src/compiler/transformers/es2017.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2018.ts
        function transformES2018(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, resumeLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const previousOnEmitNode = context.onEmitNode;
            context.onEmitNode = onEmitNode;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            let exportedVariableStatement = false;
            let enabledSubstitutions;
            let enclosingFunctionFlags;
            let parametersWithPrecedingObjectRestOrSpread;
            let enclosingSuperContainerFlags = 0;
            let hierarchyFacts = 0;
            let currentSourceFile;
            let taggedTemplateStringDeclarations;
            let capturedSuperProperties;
            let hasSuperElementAccess;
            const substitutedSuperAccessors = [];
            return chainBundle(context, transformSourceFile);
            function affectsSubtree(excludeFacts, includeFacts) {
                return hierarchyFacts !== (hierarchyFacts & ~excludeFacts | includeFacts);
            }
            function enterSubtree(excludeFacts, includeFacts) {
                const ancestorFacts = hierarchyFacts;
                hierarchyFacts = (hierarchyFacts & ~excludeFacts | includeFacts) & 3 /* AncestorFactsMask */;
                return ancestorFacts;
            }
            function exitSubtree(ancestorFacts) {
                hierarchyFacts = ancestorFacts;
            }
            function recordTaggedTemplateString(temp) {
                taggedTemplateStringDeclarations = append(taggedTemplateStringDeclarations, factory2.createVariableDeclaration(temp));
            }
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                const visited = visitSourceFile(node);
                addEmitHelpers(visited, context.readEmitHelpers());
                currentSourceFile = void 0;
                taggedTemplateStringDeclarations = void 0;
                return visited;
            }
            function visitor(node) {
                return visitorWorker(node, 
                /*expressionResultIsUnused*/
                false);
            }
            function visitorWithUnusedExpressionResult(node) {
                return visitorWorker(node, 
                /*expressionResultIsUnused*/
                true);
            }
            function visitorNoAsyncModifier(node) {
                if (node.kind === 132 /* AsyncKeyword */) {
                    return void 0;
                }
                return node;
            }
            function doWithHierarchyFacts(cb, value, excludeFacts, includeFacts) {
                if (affectsSubtree(excludeFacts, includeFacts)) {
                    const ancestorFacts = enterSubtree(excludeFacts, includeFacts);
                    const result = cb(value);
                    exitSubtree(ancestorFacts);
                    return result;
                }
                return cb(value);
            }
            function visitDefault(node) {
                return visitEachChild(node, visitor, context);
            }
            function visitorWorker(node, expressionResultIsUnused2) {
                if ((node.transformFlags & 128 /* ContainsES2018 */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 220 /* AwaitExpression */:
                        return visitAwaitExpression(node);
                    case 226 /* YieldExpression */:
                        return visitYieldExpression(node);
                    case 250 /* ReturnStatement */:
                        return visitReturnStatement(node);
                    case 253 /* LabeledStatement */:
                        return visitLabeledStatement(node);
                    case 207 /* ObjectLiteralExpression */:
                        return visitObjectLiteralExpression(node);
                    case 223 /* BinaryExpression */:
                        return visitBinaryExpression(node, expressionResultIsUnused2);
                    case 357 /* CommaListExpression */:
                        return visitCommaListExpression(node, expressionResultIsUnused2);
                    case 295 /* CatchClause */:
                        return visitCatchClause(node);
                    case 240 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 257 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 243 /* DoStatement */:
                    case 244 /* WhileStatement */:
                    case 246 /* ForInStatement */:
                        return doWithHierarchyFacts(visitDefault, node, 0 /* IterationStatementExcludes */, 2 /* IterationStatementIncludes */);
                    case 247 /* ForOfStatement */:
                        return visitForOfStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 245 /* ForStatement */:
                        return doWithHierarchyFacts(visitForStatement, node, 0 /* IterationStatementExcludes */, 2 /* IterationStatementIncludes */);
                    case 219 /* VoidExpression */:
                        return visitVoidExpression(node);
                    case 173 /* Constructor */:
                        return doWithHierarchyFacts(visitConstructorDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 171 /* MethodDeclaration */:
                        return doWithHierarchyFacts(visitMethodDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 174 /* GetAccessor */:
                        return doWithHierarchyFacts(visitGetAccessorDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 175 /* SetAccessor */:
                        return doWithHierarchyFacts(visitSetAccessorDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 259 /* FunctionDeclaration */:
                        return doWithHierarchyFacts(visitFunctionDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 215 /* FunctionExpression */:
                        return doWithHierarchyFacts(visitFunctionExpression, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 216 /* ArrowFunction */:
                        return doWithHierarchyFacts(visitArrowFunction, node, 2 /* ArrowFunctionExcludes */, 0 /* ArrowFunctionIncludes */);
                    case 166 /* Parameter */:
                        return visitParameter(node);
                    case 241 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, expressionResultIsUnused2);
                    case 212 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 208 /* PropertyAccessExpression */:
                        if (capturedSuperProperties && isPropertyAccessExpression(node) && node.expression.kind === 106 /* SuperKeyword */) {
                            capturedSuperProperties.add(node.name.escapedText);
                        }
                        return visitEachChild(node, visitor, context);
                    case 209 /* ElementAccessExpression */:
                        if (capturedSuperProperties && node.expression.kind === 106 /* SuperKeyword */) {
                            hasSuperElementAccess = true;
                        }
                        return visitEachChild(node, visitor, context);
                    case 260 /* ClassDeclaration */:
                    case 228 /* ClassExpression */:
                        return doWithHierarchyFacts(visitDefault, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitAwaitExpression(node) {
                if (enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */) {
                    return setOriginalNode(setTextRange(factory2.createYieldExpression(
                    /*asteriskToken*/
                    void 0, emitHelpers().createAwaitHelper(visitNode(node.expression, visitor, isExpression))), 
                    /*location*/
                    node), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitYieldExpression(node) {
                if (enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */) {
                    if (node.asteriskToken) {
                        const expression = visitNode(Debug.checkDefined(node.expression), visitor, isExpression);
                        return setOriginalNode(setTextRange(factory2.createYieldExpression(
                        /*asteriskToken*/
                        void 0, emitHelpers().createAwaitHelper(factory2.updateYieldExpression(node, node.asteriskToken, setTextRange(emitHelpers().createAsyncDelegatorHelper(setTextRange(emitHelpers().createAsyncValuesHelper(expression), expression)), expression)))), node), node);
                    }
                    return setOriginalNode(setTextRange(factory2.createYieldExpression(
                    /*asteriskToken*/
                    void 0, createDownlevelAwait(node.expression ? visitNode(node.expression, visitor, isExpression) : factory2.createVoidZero())), node), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitReturnStatement(node) {
                if (enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */) {
                    return factory2.updateReturnStatement(node, createDownlevelAwait(node.expression ? visitNode(node.expression, visitor, isExpression) : factory2.createVoidZero()));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitLabeledStatement(node) {
                if (enclosingFunctionFlags & 2 /* Async */) {
                    const statement = unwrapInnermostStatementOfLabel(node);
                    if (statement.kind === 247 /* ForOfStatement */ && statement.awaitModifier) {
                        return visitForOfStatement(statement, node);
                    }
                    return factory2.restoreEnclosingLabel(visitNode(statement, visitor, isStatement, factory2.liftToBlock), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function chunkObjectLiteralElements(elements) {
                let chunkObject;
                const objects = [];
                for (const e of elements) {
                    if (e.kind === 301 /* SpreadAssignment */) {
                        if (chunkObject) {
                            objects.push(factory2.createObjectLiteralExpression(chunkObject));
                            chunkObject = void 0;
                        }
                        const target = e.expression;
                        objects.push(visitNode(target, visitor, isExpression));
                    }
                    else {
                        chunkObject = append(chunkObject, e.kind === 299 /* PropertyAssignment */ ? factory2.createPropertyAssignment(e.name, visitNode(e.initializer, visitor, isExpression)) : visitNode(e, visitor, isObjectLiteralElementLike));
                    }
                }
                if (chunkObject) {
                    objects.push(factory2.createObjectLiteralExpression(chunkObject));
                }
                return objects;
            }
            function visitObjectLiteralExpression(node) {
                if (node.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                    const objects = chunkObjectLiteralElements(node.properties);
                    if (objects.length && objects[0].kind !== 207 /* ObjectLiteralExpression */) {
                        objects.unshift(factory2.createObjectLiteralExpression());
                    }
                    let expression = objects[0];
                    if (objects.length > 1) {
                        for (let i = 1; i < objects.length; i++) {
                            expression = emitHelpers().createAssignHelper([expression, objects[i]]);
                        }
                        return expression;
                    }
                    else {
                        return emitHelpers().createAssignHelper(objects);
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitExpressionStatement(node) {
                return visitEachChild(node, visitorWithUnusedExpressionResult, context);
            }
            function visitParenthesizedExpression(node, expressionResultIsUnused2) {
                return visitEachChild(node, expressionResultIsUnused2 ? visitorWithUnusedExpressionResult : visitor, context);
            }
            function visitSourceFile(node) {
                const ancestorFacts = enterSubtree(2 /* SourceFileExcludes */, isEffectiveStrictModeSourceFile(node, compilerOptions) ? 0 /* StrictModeSourceFileIncludes */ : 1 /* SourceFileIncludes */);
                exportedVariableStatement = false;
                const visited = visitEachChild(node, visitor, context);
                const statement = concatenate(visited.statements, taggedTemplateStringDeclarations && [
                    factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(taggedTemplateStringDeclarations))
                ]);
                const result = factory2.updateSourceFile(visited, setTextRange(factory2.createNodeArray(statement), node.statements));
                exitSubtree(ancestorFacts);
                return result;
            }
            function visitTaggedTemplateExpression(node) {
                return processTaggedTemplateExpression(context, node, visitor, currentSourceFile, recordTaggedTemplateString, 0 /* LiftRestriction */);
            }
            function visitBinaryExpression(node, expressionResultIsUnused2) {
                if (isDestructuringAssignment(node) && containsObjectRestOrSpread(node.left)) {
                    return flattenDestructuringAssignment(node, visitor, context, 1 /* ObjectRest */, !expressionResultIsUnused2);
                }
                if (node.operatorToken.kind === 27 /* CommaToken */) {
                    return factory2.updateBinaryExpression(node, visitNode(node.left, visitorWithUnusedExpressionResult, isExpression), node.operatorToken, visitNode(node.right, expressionResultIsUnused2 ? visitorWithUnusedExpressionResult : visitor, isExpression));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaListExpression(node, expressionResultIsUnused2) {
                if (expressionResultIsUnused2) {
                    return visitEachChild(node, visitorWithUnusedExpressionResult, context);
                }
                let result;
                for (let i = 0; i < node.elements.length; i++) {
                    const element = node.elements[i];
                    const visited = visitNode(element, i < node.elements.length - 1 ? visitorWithUnusedExpressionResult : visitor, isExpression);
                    if (result || visited !== element) {
                        result || (result = node.elements.slice(0, i));
                        result.push(visited);
                    }
                }
                const elements = result ? setTextRange(factory2.createNodeArray(result), node.elements) : node.elements;
                return factory2.updateCommaListExpression(node, elements);
            }
            function visitCatchClause(node) {
                if (node.variableDeclaration && isBindingPattern(node.variableDeclaration.name) && node.variableDeclaration.name.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                    const name = factory2.getGeneratedNameForNode(node.variableDeclaration.name);
                    const updatedDecl = factory2.updateVariableDeclaration(node.variableDeclaration, node.variableDeclaration.name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, name);
                    const visitedBindings = flattenDestructuringBinding(updatedDecl, visitor, context, 1 /* ObjectRest */);
                    let block = visitNode(node.block, visitor, isBlock);
                    if (some(visitedBindings)) {
                        block = factory2.updateBlock(block, [
                            factory2.createVariableStatement(
                            /*modifiers*/
                            void 0, visitedBindings),
                            ...block.statements
                        ]);
                    }
                    return factory2.updateCatchClause(node, factory2.updateVariableDeclaration(node.variableDeclaration, name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0), block);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableStatement(node) {
                if (hasSyntacticModifier(node, 1 /* Export */)) {
                    const savedExportedVariableStatement = exportedVariableStatement;
                    exportedVariableStatement = true;
                    const visited = visitEachChild(node, visitor, context);
                    exportedVariableStatement = savedExportedVariableStatement;
                    return visited;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableDeclaration(node) {
                if (exportedVariableStatement) {
                    const savedExportedVariableStatement = exportedVariableStatement;
                    exportedVariableStatement = false;
                    const visited = visitVariableDeclarationWorker(node, 
                    /*exportedVariableStatement*/
                    true);
                    exportedVariableStatement = savedExportedVariableStatement;
                    return visited;
                }
                return visitVariableDeclarationWorker(node, 
                /*exportedVariableStatement*/
                false);
            }
            function visitVariableDeclarationWorker(node, exportedVariableStatement2) {
                if (isBindingPattern(node.name) && node.name.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                    return flattenDestructuringBinding(node, visitor, context, 1 /* ObjectRest */, 
                    /*rval*/
                    void 0, exportedVariableStatement2);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForStatement(node) {
                return factory2.updateForStatement(node, visitNode(node.initializer, visitorWithUnusedExpressionResult, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, visitorWithUnusedExpressionResult, isExpression), visitIterationBody(node.statement, visitor, context));
            }
            function visitVoidExpression(node) {
                return visitEachChild(node, visitorWithUnusedExpressionResult, context);
            }
            function visitForOfStatement(node, outermostLabeledStatement) {
                const ancestorFacts = enterSubtree(0 /* IterationStatementExcludes */, 2 /* IterationStatementIncludes */);
                if (node.initializer.transformFlags & 65536 /* ContainsObjectRestOrSpread */ || isAssignmentPattern(node.initializer) && containsObjectRestOrSpread(node.initializer)) {
                    node = transformForOfStatementWithObjectRest(node);
                }
                const result = node.awaitModifier ? transformForAwaitOfStatement(node, outermostLabeledStatement, ancestorFacts) : factory2.restoreEnclosingLabel(visitEachChild(node, visitor, context), outermostLabeledStatement);
                exitSubtree(ancestorFacts);
                return result;
            }
            function transformForOfStatementWithObjectRest(node) {
                const initializerWithoutParens = skipParentheses(node.initializer);
                if (isVariableDeclarationList(initializerWithoutParens) || isAssignmentPattern(initializerWithoutParens)) {
                    let bodyLocation;
                    let statementsLocation;
                    const temp = factory2.createTempVariable(
                    /*recordTempVariable*/
                    void 0);
                    const statements = [createForOfBindingStatement(factory2, initializerWithoutParens, temp)];
                    if (isBlock(node.statement)) {
                        addRange(statements, node.statement.statements);
                        bodyLocation = node.statement;
                        statementsLocation = node.statement.statements;
                    }
                    else if (node.statement) {
                        append(statements, node.statement);
                        bodyLocation = node.statement;
                        statementsLocation = node.statement;
                    }
                    return factory2.updateForOfStatement(node, node.awaitModifier, setTextRange(factory2.createVariableDeclarationList([
                        setTextRange(factory2.createVariableDeclaration(temp), node.initializer)
                    ], 1 /* Let */), node.initializer), node.expression, setTextRange(factory2.createBlock(setTextRange(factory2.createNodeArray(statements), statementsLocation), 
                    /*multiLine*/
                    true), bodyLocation));
                }
                return node;
            }
            function convertForOfStatementHead(node, boundValue, nonUserCode) {
                const value = factory2.createTempVariable(hoistVariableDeclaration);
                const iteratorValueExpression = factory2.createAssignment(value, boundValue);
                const iteratorValueStatement = factory2.createExpressionStatement(iteratorValueExpression);
                setSourceMapRange(iteratorValueStatement, node.expression);
                const exitNonUserCodeExpression = factory2.createAssignment(nonUserCode, factory2.createFalse());
                const exitNonUserCodeStatement = factory2.createExpressionStatement(exitNonUserCodeExpression);
                setSourceMapRange(exitNonUserCodeStatement, node.expression);
                const enterNonUserCodeExpression = factory2.createAssignment(nonUserCode, factory2.createTrue());
                const enterNonUserCodeStatement = factory2.createExpressionStatement(enterNonUserCodeExpression);
                setSourceMapRange(exitNonUserCodeStatement, node.expression);
                const statements = [];
                const binding = createForOfBindingStatement(factory2, node.initializer, value);
                statements.push(visitNode(binding, visitor, isStatement));
                let bodyLocation;
                let statementsLocation;
                const statement = visitIterationBody(node.statement, visitor, context);
                if (isBlock(statement)) {
                    addRange(statements, statement.statements);
                    bodyLocation = statement;
                    statementsLocation = statement.statements;
                }
                else {
                    statements.push(statement);
                }
                const body = setEmitFlags(setTextRange(factory2.createBlock(setTextRange(factory2.createNodeArray(statements), statementsLocation), 
                /*multiLine*/
                true), bodyLocation), 96 /* NoSourceMap */ | 768 /* NoTokenSourceMaps */);
                return factory2.createBlock([
                    iteratorValueStatement,
                    exitNonUserCodeStatement,
                    factory2.createTryStatement(body, 
                    /*catchClause*/
                    void 0, factory2.createBlock([
                        enterNonUserCodeStatement
                    ]))
                ]);
            }
            function createDownlevelAwait(expression) {
                return enclosingFunctionFlags & 1 /* Generator */ ? factory2.createYieldExpression(
                /*asteriskToken*/
                void 0, emitHelpers().createAwaitHelper(expression)) : factory2.createAwaitExpression(expression);
            }
            function transformForAwaitOfStatement(node, outermostLabeledStatement, ancestorFacts) {
                const expression = visitNode(node.expression, visitor, isExpression);
                const iterator = isIdentifier(expression) ? factory2.getGeneratedNameForNode(expression) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const result = isIdentifier(expression) ? factory2.getGeneratedNameForNode(iterator) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const nonUserCode = factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const done = factory2.createTempVariable(hoistVariableDeclaration);
                const errorRecord = factory2.createUniqueName("e");
                const catchVariable = factory2.getGeneratedNameForNode(errorRecord);
                const returnMethod = factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const callValues = setTextRange(emitHelpers().createAsyncValuesHelper(expression), node.expression);
                const callNext = factory2.createCallExpression(factory2.createPropertyAccessExpression(iterator, "next"), 
                /*typeArguments*/
                void 0, []);
                const getDone = factory2.createPropertyAccessExpression(result, "done");
                const getValue = factory2.createPropertyAccessExpression(result, "value");
                const callReturn = factory2.createFunctionCallCall(returnMethod, iterator, []);
                hoistVariableDeclaration(errorRecord);
                hoistVariableDeclaration(returnMethod);
                const initializer = ancestorFacts & 2 /* IterationContainer */ ? factory2.inlineExpressions([factory2.createAssignment(errorRecord, factory2.createVoidZero()), callValues]) : callValues;
                const forStatement = setEmitFlags(setTextRange(factory2.createForStatement(
                /*initializer*/
                setEmitFlags(setTextRange(factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(nonUserCode, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createTrue()),
                    setTextRange(factory2.createVariableDeclaration(iterator, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer), node.expression),
                    factory2.createVariableDeclaration(result)
                ]), node.expression), 4194304 /* NoHoisting */), 
                /*condition*/
                factory2.inlineExpressions([
                    factory2.createAssignment(result, createDownlevelAwait(callNext)),
                    factory2.createAssignment(done, getDone),
                    factory2.createLogicalNot(done)
                ]), 
                /*incrementor*/
                void 0, 
                /*statement*/
                convertForOfStatementHead(node, getValue, nonUserCode)), 
                /*location*/
                node), 512 /* NoTokenTrailingSourceMaps */);
                setOriginalNode(forStatement, node);
                return factory2.createTryStatement(factory2.createBlock([
                    factory2.restoreEnclosingLabel(forStatement, outermostLabeledStatement)
                ]), factory2.createCatchClause(factory2.createVariableDeclaration(catchVariable), setEmitFlags(factory2.createBlock([
                    factory2.createExpressionStatement(factory2.createAssignment(errorRecord, factory2.createObjectLiteralExpression([
                        factory2.createPropertyAssignment("error", catchVariable)
                    ])))
                ]), 1 /* SingleLine */)), factory2.createBlock([
                    factory2.createTryStatement(
                    /*tryBlock*/
                    factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(factory2.createLogicalAnd(factory2.createLogicalAnd(factory2.createLogicalNot(nonUserCode), factory2.createLogicalNot(done)), factory2.createAssignment(returnMethod, factory2.createPropertyAccessExpression(iterator, "return"))), factory2.createExpressionStatement(createDownlevelAwait(callReturn))), 1 /* SingleLine */)
                    ]), 
                    /*catchClause*/
                    void 0, 
                    /*finallyBlock*/
                    setEmitFlags(factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(errorRecord, factory2.createThrowStatement(factory2.createPropertyAccessExpression(errorRecord, "error"))), 1 /* SingleLine */)
                    ]), 1 /* SingleLine */))
                ]));
            }
            function parameterVisitor(node) {
                Debug.assertNode(node, isParameter);
                return visitParameter(node);
            }
            function visitParameter(node) {
                if (parametersWithPrecedingObjectRestOrSpread == null ? void 0 : parametersWithPrecedingObjectRestOrSpread.has(node)) {
                    return factory2.updateParameterDeclaration(node, 
                    /*modifiers*/
                    void 0, node.dotDotDotToken, isBindingPattern(node.name) ? factory2.getGeneratedNameForNode(node) : node.name, 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0);
                }
                if (node.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                    return factory2.updateParameterDeclaration(node, 
                    /*modifiers*/
                    void 0, node.dotDotDotToken, factory2.getGeneratedNameForNode(node), 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, visitNode(node.initializer, visitor, isExpression));
                }
                return visitEachChild(node, visitor, context);
            }
            function collectParametersWithPrecedingObjectRestOrSpread(node) {
                let parameters;
                for (const parameter of node.parameters) {
                    if (parameters) {
                        parameters.add(parameter);
                    }
                    else if (parameter.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                        parameters = /* @__PURE__ */ new Set();
                    }
                }
                return parameters;
            }
            function visitConstructorDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateConstructorDeclaration(node, node.modifiers, visitParameterList(node.parameters, parameterVisitor, context), transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitGetAccessorDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateGetAccessorDeclaration(node, node.modifiers, visitNode(node.name, visitor, isPropertyName), visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitSetAccessorDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateSetAccessorDeclaration(node, node.modifiers, visitNode(node.name, visitor, isPropertyName), visitParameterList(node.parameters, parameterVisitor, context), transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitMethodDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateMethodDeclaration(node, enclosingFunctionFlags & 1 /* Generator */ ? visitNodes2(node.modifiers, visitorNoAsyncModifier, isModifierLike) : node.modifiers, enclosingFunctionFlags & 2 /* Async */ ? void 0 : node.asteriskToken, visitNode(node.name, visitor, isPropertyName), visitNode(
                /*questionToken*/
                void 0, visitor, isQuestionToken), 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */ ? transformAsyncGeneratorFunctionBody(node) : transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitFunctionDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateFunctionDeclaration(node, enclosingFunctionFlags & 1 /* Generator */ ? visitNodes2(node.modifiers, visitorNoAsyncModifier, isModifier) : node.modifiers, enclosingFunctionFlags & 2 /* Async */ ? void 0 : node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */ ? transformAsyncGeneratorFunctionBody(node) : transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitArrowFunction(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateArrowFunction(node, node.modifiers, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, node.equalsGreaterThanToken, transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitFunctionExpression(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateFunctionExpression(node, enclosingFunctionFlags & 1 /* Generator */ ? visitNodes2(node.modifiers, visitorNoAsyncModifier, isModifier) : node.modifiers, enclosingFunctionFlags & 2 /* Async */ ? void 0 : node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */ ? transformAsyncGeneratorFunctionBody(node) : transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function transformAsyncGeneratorFunctionBody(node) {
                resumeLexicalEnvironment();
                const statements = [];
                const statementOffset = factory2.copyPrologue(node.body.statements, statements, 
                /*ensureUseStrict*/
                false, visitor);
                appendObjectRestAssignmentsIfNeeded(statements, node);
                const savedCapturedSuperProperties = capturedSuperProperties;
                const savedHasSuperElementAccess = hasSuperElementAccess;
                capturedSuperProperties = /* @__PURE__ */ new Set();
                hasSuperElementAccess = false;
                const returnStatement = factory2.createReturnStatement(emitHelpers().createAsyncGeneratorHelper(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, factory2.createToken(41 /* AsteriskToken */), node.name && factory2.getGeneratedNameForNode(node.name), 
                /*typeParameters*/
                void 0, 
                /*parameters*/
                [], 
                /*type*/
                void 0, factory2.updateBlock(node.body, visitLexicalEnvironment(node.body.statements, visitor, context, statementOffset))), !!(hierarchyFacts & 1 /* HasLexicalThis */)));
                const emitSuperHelpers = languageVersion >= 2 /* ES2015 */ && resolver.getNodeCheckFlags(node) & (256 /* MethodWithSuperPropertyAssignmentInAsync */ | 128 /* MethodWithSuperPropertyAccessInAsync */);
                if (emitSuperHelpers) {
                    enableSubstitutionForAsyncMethodsWithSuper();
                    const variableStatement = createSuperAccessVariableStatement(factory2, resolver, node, capturedSuperProperties);
                    substitutedSuperAccessors[getNodeId(variableStatement)] = true;
                    insertStatementsAfterStandardPrologue(statements, [variableStatement]);
                }
                statements.push(returnStatement);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                const block = factory2.updateBlock(node.body, statements);
                if (emitSuperHelpers && hasSuperElementAccess) {
                    if (resolver.getNodeCheckFlags(node) & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                        addEmitHelper(block, advancedAsyncSuperHelper);
                    }
                    else if (resolver.getNodeCheckFlags(node) & 128 /* MethodWithSuperPropertyAccessInAsync */) {
                        addEmitHelper(block, asyncSuperHelper);
                    }
                }
                capturedSuperProperties = savedCapturedSuperProperties;
                hasSuperElementAccess = savedHasSuperElementAccess;
                return block;
            }
            function transformFunctionBody2(node) {
                var _a2;
                resumeLexicalEnvironment();
                let statementOffset = 0;
                const statements = [];
                const body = (_a2 = visitNode(node.body, visitor, isConciseBody)) != null ? _a2 : factory2.createBlock([]);
                if (isBlock(body)) {
                    statementOffset = factory2.copyPrologue(body.statements, statements, 
                    /*ensureUseStrict*/
                    false, visitor);
                }
                addRange(statements, appendObjectRestAssignmentsIfNeeded(
                /*statements*/
                void 0, node));
                const leadingStatements = endLexicalEnvironment();
                if (statementOffset > 0 || some(statements) || some(leadingStatements)) {
                    const block = factory2.converters.convertToFunctionBlock(body, 
                    /*multiLine*/
                    true);
                    insertStatementsAfterStandardPrologue(statements, leadingStatements);
                    addRange(statements, block.statements.slice(statementOffset));
                    return factory2.updateBlock(block, setTextRange(factory2.createNodeArray(statements), block.statements));
                }
                return body;
            }
            function appendObjectRestAssignmentsIfNeeded(statements, node) {
                let containsPrecedingObjectRestOrSpread = false;
                for (const parameter of node.parameters) {
                    if (containsPrecedingObjectRestOrSpread) {
                        if (isBindingPattern(parameter.name)) {
                            if (parameter.name.elements.length > 0) {
                                const declarations = flattenDestructuringBinding(parameter, visitor, context, 0 /* All */, factory2.getGeneratedNameForNode(parameter));
                                if (some(declarations)) {
                                    const declarationList = factory2.createVariableDeclarationList(declarations);
                                    const statement = factory2.createVariableStatement(
                                    /*modifiers*/
                                    void 0, declarationList);
                                    setEmitFlags(statement, 2097152 /* CustomPrologue */);
                                    statements = append(statements, statement);
                                }
                            }
                            else if (parameter.initializer) {
                                const name = factory2.getGeneratedNameForNode(parameter);
                                const initializer = visitNode(parameter.initializer, visitor, isExpression);
                                const assignment = factory2.createAssignment(name, initializer);
                                const statement = factory2.createExpressionStatement(assignment);
                                setEmitFlags(statement, 2097152 /* CustomPrologue */);
                                statements = append(statements, statement);
                            }
                        }
                        else if (parameter.initializer) {
                            const name = factory2.cloneNode(parameter.name);
                            setTextRange(name, parameter.name);
                            setEmitFlags(name, 96 /* NoSourceMap */);
                            const initializer = visitNode(parameter.initializer, visitor, isExpression);
                            addEmitFlags(initializer, 96 /* NoSourceMap */ | 3072 /* NoComments */);
                            const assignment = factory2.createAssignment(name, initializer);
                            setTextRange(assignment, parameter);
                            setEmitFlags(assignment, 3072 /* NoComments */);
                            const block = factory2.createBlock([factory2.createExpressionStatement(assignment)]);
                            setTextRange(block, parameter);
                            setEmitFlags(block, 1 /* SingleLine */ | 64 /* NoTrailingSourceMap */ | 768 /* NoTokenSourceMaps */ | 3072 /* NoComments */);
                            const typeCheck = factory2.createTypeCheck(factory2.cloneNode(parameter.name), "undefined");
                            const statement = factory2.createIfStatement(typeCheck, block);
                            startOnNewLine(statement);
                            setTextRange(statement, parameter);
                            setEmitFlags(statement, 768 /* NoTokenSourceMaps */ | 64 /* NoTrailingSourceMap */ | 2097152 /* CustomPrologue */ | 3072 /* NoComments */);
                            statements = append(statements, statement);
                        }
                    }
                    else if (parameter.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                        containsPrecedingObjectRestOrSpread = true;
                        const declarations = flattenDestructuringBinding(parameter, visitor, context, 1 /* ObjectRest */, factory2.getGeneratedNameForNode(parameter), 
                        /*doNotRecordTempVariablesInLine*/
                        false, 
                        /*skipInitializer*/
                        true);
                        if (some(declarations)) {
                            const declarationList = factory2.createVariableDeclarationList(declarations);
                            const statement = factory2.createVariableStatement(
                            /*modifiers*/
                            void 0, declarationList);
                            setEmitFlags(statement, 2097152 /* CustomPrologue */);
                            statements = append(statements, statement);
                        }
                    }
                }
                return statements;
            }
            function enableSubstitutionForAsyncMethodsWithSuper() {
                if ((enabledSubstitutions & 1 /* AsyncMethodsWithSuper */) === 0) {
                    enabledSubstitutions |= 1 /* AsyncMethodsWithSuper */;
                    context.enableSubstitution(210 /* CallExpression */);
                    context.enableSubstitution(208 /* PropertyAccessExpression */);
                    context.enableSubstitution(209 /* ElementAccessExpression */);
                    context.enableEmitNotification(260 /* ClassDeclaration */);
                    context.enableEmitNotification(171 /* MethodDeclaration */);
                    context.enableEmitNotification(174 /* GetAccessor */);
                    context.enableEmitNotification(175 /* SetAccessor */);
                    context.enableEmitNotification(173 /* Constructor */);
                    context.enableEmitNotification(240 /* VariableStatement */);
                }
            }
            function onEmitNode(hint, node, emitCallback) {
                if (enabledSubstitutions & 1 /* AsyncMethodsWithSuper */ && isSuperContainer(node)) {
                    const superContainerFlags = resolver.getNodeCheckFlags(node) & (128 /* MethodWithSuperPropertyAccessInAsync */ | 256 /* MethodWithSuperPropertyAssignmentInAsync */);
                    if (superContainerFlags !== enclosingSuperContainerFlags) {
                        const savedEnclosingSuperContainerFlags = enclosingSuperContainerFlags;
                        enclosingSuperContainerFlags = superContainerFlags;
                        previousOnEmitNode(hint, node, emitCallback);
                        enclosingSuperContainerFlags = savedEnclosingSuperContainerFlags;
                        return;
                    }
                }
                else if (enabledSubstitutions && substitutedSuperAccessors[getNodeId(node)]) {
                    const savedEnclosingSuperContainerFlags = enclosingSuperContainerFlags;
                    enclosingSuperContainerFlags = 0;
                    previousOnEmitNode(hint, node, emitCallback);
                    enclosingSuperContainerFlags = savedEnclosingSuperContainerFlags;
                    return;
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */ && enclosingSuperContainerFlags) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 208 /* PropertyAccessExpression */:
                        return substitutePropertyAccessExpression(node);
                    case 209 /* ElementAccessExpression */:
                        return substituteElementAccessExpression(node);
                    case 210 /* CallExpression */:
                        return substituteCallExpression(node);
                }
                return node;
            }
            function substitutePropertyAccessExpression(node) {
                if (node.expression.kind === 106 /* SuperKeyword */) {
                    return setTextRange(factory2.createPropertyAccessExpression(factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */), node.name), node);
                }
                return node;
            }
            function substituteElementAccessExpression(node) {
                if (node.expression.kind === 106 /* SuperKeyword */) {
                    return createSuperElementAccessInAsyncMethod(node.argumentExpression, node);
                }
                return node;
            }
            function substituteCallExpression(node) {
                const expression = node.expression;
                if (isSuperProperty(expression)) {
                    const argumentExpression = isPropertyAccessExpression(expression) ? substitutePropertyAccessExpression(expression) : substituteElementAccessExpression(expression);
                    return factory2.createCallExpression(factory2.createPropertyAccessExpression(argumentExpression, "call"), 
                    /*typeArguments*/
                    void 0, [
                        factory2.createThis(),
                        ...node.arguments
                    ]);
                }
                return node;
            }
            function isSuperContainer(node) {
                const kind = node.kind;
                return kind === 260 /* ClassDeclaration */ || kind === 173 /* Constructor */ || kind === 171 /* MethodDeclaration */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */;
            }
            function createSuperElementAccessInAsyncMethod(argumentExpression, location) {
                if (enclosingSuperContainerFlags & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                    return setTextRange(factory2.createPropertyAccessExpression(factory2.createCallExpression(factory2.createIdentifier("_superIndex"), 
                    /*typeArguments*/
                    void 0, [argumentExpression]), "value"), location);
                }
                else {
                    return setTextRange(factory2.createCallExpression(factory2.createIdentifier("_superIndex"), 
                    /*typeArguments*/
                    void 0, [argumentExpression]), location);
                }
            }
        }
        var init_es2018 = __esm({
            "src/compiler/transformers/es2018.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2019.ts
        function transformES2019(context) {
            const factory2 = context.factory;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 64 /* ContainsES2019 */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 295 /* CatchClause */:
                        return visitCatchClause(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitCatchClause(node) {
                if (!node.variableDeclaration) {
                    return factory2.updateCatchClause(node, factory2.createVariableDeclaration(factory2.createTempVariable(
                    /*recordTempVariable*/
                    void 0)), visitNode(node.block, visitor, isBlock));
                }
                return visitEachChild(node, visitor, context);
            }
        }
        var init_es2019 = __esm({
            "src/compiler/transformers/es2019.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2020.ts
        function transformES2020(context) {
            const { factory: factory2, hoistVariableDeclaration } = context;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 32 /* ContainsES2020 */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 210 /* CallExpression */: {
                        const updated = visitNonOptionalCallExpression(node, 
                        /*captureThisArg*/
                        false);
                        Debug.assertNotNode(updated, isSyntheticReference);
                        return updated;
                    }
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        if (isOptionalChain(node)) {
                            const updated = visitOptionalExpression(node, 
                            /*captureThisArg*/
                            false, 
                            /*isDelete*/
                            false);
                            Debug.assertNotNode(updated, isSyntheticReference);
                            return updated;
                        }
                        return visitEachChild(node, visitor, context);
                    case 223 /* BinaryExpression */:
                        if (node.operatorToken.kind === 60 /* QuestionQuestionToken */) {
                            return transformNullishCoalescingExpression(node);
                        }
                        return visitEachChild(node, visitor, context);
                    case 217 /* DeleteExpression */:
                        return visitDeleteExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function flattenChain(chain) {
                Debug.assertNotNode(chain, isNonNullChain);
                const links = [chain];
                while (!chain.questionDotToken && !isTaggedTemplateExpression(chain)) {
                    chain = cast(skipPartiallyEmittedExpressions(chain.expression), isOptionalChain);
                    Debug.assertNotNode(chain, isNonNullChain);
                    links.unshift(chain);
                }
                return { expression: chain.expression, chain: links };
            }
            function visitNonOptionalParenthesizedExpression(node, captureThisArg, isDelete) {
                const expression = visitNonOptionalExpression(node.expression, captureThisArg, isDelete);
                if (isSyntheticReference(expression)) {
                    return factory2.createSyntheticReferenceExpression(factory2.updateParenthesizedExpression(node, expression.expression), expression.thisArg);
                }
                return factory2.updateParenthesizedExpression(node, expression);
            }
            function visitNonOptionalPropertyOrElementAccessExpression(node, captureThisArg, isDelete) {
                if (isOptionalChain(node)) {
                    return visitOptionalExpression(node, captureThisArg, isDelete);
                }
                let expression = visitNode(node.expression, visitor, isExpression);
                Debug.assertNotNode(expression, isSyntheticReference);
                let thisArg;
                if (captureThisArg) {
                    if (!isSimpleCopiableExpression(expression)) {
                        thisArg = factory2.createTempVariable(hoistVariableDeclaration);
                        expression = factory2.createAssignment(thisArg, expression);
                    }
                    else {
                        thisArg = expression;
                    }
                }
                expression = node.kind === 208 /* PropertyAccessExpression */ ? factory2.updatePropertyAccessExpression(node, expression, visitNode(node.name, visitor, isIdentifier)) : factory2.updateElementAccessExpression(node, expression, visitNode(node.argumentExpression, visitor, isExpression));
                return thisArg ? factory2.createSyntheticReferenceExpression(expression, thisArg) : expression;
            }
            function visitNonOptionalCallExpression(node, captureThisArg) {
                if (isOptionalChain(node)) {
                    return visitOptionalExpression(node, captureThisArg, 
                    /*isDelete*/
                    false);
                }
                if (isParenthesizedExpression(node.expression) && isOptionalChain(skipParentheses(node.expression))) {
                    const expression = visitNonOptionalParenthesizedExpression(node.expression, 
                    /*captureThisArg*/
                    true, 
                    /*isDelete*/
                    false);
                    const args = visitNodes2(node.arguments, visitor, isExpression);
                    if (isSyntheticReference(expression)) {
                        return setTextRange(factory2.createFunctionCallCall(expression.expression, expression.thisArg, args), node);
                    }
                    return factory2.updateCallExpression(node, expression, 
                    /*typeArguments*/
                    void 0, args);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitNonOptionalExpression(node, captureThisArg, isDelete) {
                switch (node.kind) {
                    case 214 /* ParenthesizedExpression */:
                        return visitNonOptionalParenthesizedExpression(node, captureThisArg, isDelete);
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        return visitNonOptionalPropertyOrElementAccessExpression(node, captureThisArg, isDelete);
                    case 210 /* CallExpression */:
                        return visitNonOptionalCallExpression(node, captureThisArg);
                    default:
                        return visitNode(node, visitor, isExpression);
                }
            }
            function visitOptionalExpression(node, captureThisArg, isDelete) {
                const { expression, chain } = flattenChain(node);
                const left = visitNonOptionalExpression(skipPartiallyEmittedExpressions(expression), isCallChain(chain[0]), 
                /*isDelete*/
                false);
                let leftThisArg = isSyntheticReference(left) ? left.thisArg : void 0;
                let capturedLeft = isSyntheticReference(left) ? left.expression : left;
                let leftExpression = factory2.restoreOuterExpressions(expression, capturedLeft, 8 /* PartiallyEmittedExpressions */);
                if (!isSimpleCopiableExpression(capturedLeft)) {
                    capturedLeft = factory2.createTempVariable(hoistVariableDeclaration);
                    leftExpression = factory2.createAssignment(capturedLeft, leftExpression);
                }
                let rightExpression = capturedLeft;
                let thisArg;
                for (let i = 0; i < chain.length; i++) {
                    const segment = chain[i];
                    switch (segment.kind) {
                        case 208 /* PropertyAccessExpression */:
                        case 209 /* ElementAccessExpression */:
                            if (i === chain.length - 1 && captureThisArg) {
                                if (!isSimpleCopiableExpression(rightExpression)) {
                                    thisArg = factory2.createTempVariable(hoistVariableDeclaration);
                                    rightExpression = factory2.createAssignment(thisArg, rightExpression);
                                }
                                else {
                                    thisArg = rightExpression;
                                }
                            }
                            rightExpression = segment.kind === 208 /* PropertyAccessExpression */ ? factory2.createPropertyAccessExpression(rightExpression, visitNode(segment.name, visitor, isIdentifier)) : factory2.createElementAccessExpression(rightExpression, visitNode(segment.argumentExpression, visitor, isExpression));
                            break;
                        case 210 /* CallExpression */:
                            if (i === 0 && leftThisArg) {
                                if (!isGeneratedIdentifier(leftThisArg)) {
                                    leftThisArg = factory2.cloneNode(leftThisArg);
                                    addEmitFlags(leftThisArg, 3072 /* NoComments */);
                                }
                                rightExpression = factory2.createFunctionCallCall(rightExpression, leftThisArg.kind === 106 /* SuperKeyword */ ? factory2.createThis() : leftThisArg, visitNodes2(segment.arguments, visitor, isExpression));
                            }
                            else {
                                rightExpression = factory2.createCallExpression(rightExpression, 
                                /*typeArguments*/
                                void 0, visitNodes2(segment.arguments, visitor, isExpression));
                            }
                            break;
                    }
                    setOriginalNode(rightExpression, segment);
                }
                const target = isDelete ? factory2.createConditionalExpression(createNotNullCondition(leftExpression, capturedLeft, 
                /*invert*/
                true), 
                /*questionToken*/
                void 0, factory2.createTrue(), 
                /*colonToken*/
                void 0, factory2.createDeleteExpression(rightExpression)) : factory2.createConditionalExpression(createNotNullCondition(leftExpression, capturedLeft, 
                /*invert*/
                true), 
                /*questionToken*/
                void 0, factory2.createVoidZero(), 
                /*colonToken*/
                void 0, rightExpression);
                setTextRange(target, node);
                return thisArg ? factory2.createSyntheticReferenceExpression(target, thisArg) : target;
            }
            function createNotNullCondition(left, right, invert) {
                return factory2.createBinaryExpression(factory2.createBinaryExpression(left, factory2.createToken(invert ? 36 /* EqualsEqualsEqualsToken */ : 37 /* ExclamationEqualsEqualsToken */), factory2.createNull()), factory2.createToken(invert ? 56 /* BarBarToken */ : 55 /* AmpersandAmpersandToken */), factory2.createBinaryExpression(right, factory2.createToken(invert ? 36 /* EqualsEqualsEqualsToken */ : 37 /* ExclamationEqualsEqualsToken */), factory2.createVoidZero()));
            }
            function transformNullishCoalescingExpression(node) {
                let left = visitNode(node.left, visitor, isExpression);
                let right = left;
                if (!isSimpleCopiableExpression(left)) {
                    right = factory2.createTempVariable(hoistVariableDeclaration);
                    left = factory2.createAssignment(right, left);
                }
                return setTextRange(factory2.createConditionalExpression(createNotNullCondition(left, right), 
                /*questionToken*/
                void 0, right, 
                /*colonToken*/
                void 0, visitNode(node.right, visitor, isExpression)), node);
            }
            function visitDeleteExpression(node) {
                return isOptionalChain(skipParentheses(node.expression)) ? setOriginalNode(visitNonOptionalExpression(node.expression, 
                /*captureThisArg*/
                false, 
                /*isDelete*/
                true), node) : factory2.updateDeleteExpression(node, visitNode(node.expression, visitor, isExpression));
            }
        }
        var init_es2020 = __esm({
            "src/compiler/transformers/es2020.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2021.ts
        function transformES2021(context) {
            const { hoistVariableDeclaration, factory: factory2 } = context;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 16 /* ContainsES2021 */) === 0) {
                    return node;
                }
                if (isLogicalOrCoalescingAssignmentExpression(node)) {
                    return transformLogicalAssignment(node);
                }
                return visitEachChild(node, visitor, context);
            }
            function transformLogicalAssignment(binaryExpression) {
                const operator = binaryExpression.operatorToken;
                const nonAssignmentOperator = getNonAssignmentOperatorForCompoundAssignment(operator.kind);
                let left = skipParentheses(visitNode(binaryExpression.left, visitor, isLeftHandSideExpression));
                let assignmentTarget = left;
                const right = skipParentheses(visitNode(binaryExpression.right, visitor, isExpression));
                if (isAccessExpression(left)) {
                    const propertyAccessTargetSimpleCopiable = isSimpleCopiableExpression(left.expression);
                    const propertyAccessTarget = propertyAccessTargetSimpleCopiable ? left.expression : factory2.createTempVariable(hoistVariableDeclaration);
                    const propertyAccessTargetAssignment = propertyAccessTargetSimpleCopiable ? left.expression : factory2.createAssignment(propertyAccessTarget, left.expression);
                    if (isPropertyAccessExpression(left)) {
                        assignmentTarget = factory2.createPropertyAccessExpression(propertyAccessTarget, left.name);
                        left = factory2.createPropertyAccessExpression(propertyAccessTargetAssignment, left.name);
                    }
                    else {
                        const elementAccessArgumentSimpleCopiable = isSimpleCopiableExpression(left.argumentExpression);
                        const elementAccessArgument = elementAccessArgumentSimpleCopiable ? left.argumentExpression : factory2.createTempVariable(hoistVariableDeclaration);
                        assignmentTarget = factory2.createElementAccessExpression(propertyAccessTarget, elementAccessArgument);
                        left = factory2.createElementAccessExpression(propertyAccessTargetAssignment, elementAccessArgumentSimpleCopiable ? left.argumentExpression : factory2.createAssignment(elementAccessArgument, left.argumentExpression));
                    }
                }
                return factory2.createBinaryExpression(left, nonAssignmentOperator, factory2.createParenthesizedExpression(factory2.createAssignment(assignmentTarget, right)));
            }
        }
        var init_es2021 = __esm({
            "src/compiler/transformers/es2021.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/esnext.ts
        function transformESNext(context) {
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 4 /* ContainsESNext */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
        }
        var init_esnext = __esm({
            "src/compiler/transformers/esnext.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/jsx.ts
        function transformJsx(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers } = context;
            const compilerOptions = context.getCompilerOptions();
            let currentSourceFile;
            let currentFileState;
            return chainBundle(context, transformSourceFile);
            function getCurrentFileNameExpression() {
                if (currentFileState.filenameDeclaration) {
                    return currentFileState.filenameDeclaration.name;
                }
                const declaration = factory2.createVariableDeclaration(factory2.createUniqueName("_jsxFileName", 16 /* Optimistic */ | 32 /* FileLevel */), 
                /*exclaimationToken*/
                void 0, 
                /*type*/
                void 0, factory2.createStringLiteral(currentSourceFile.fileName));
                currentFileState.filenameDeclaration = declaration;
                return currentFileState.filenameDeclaration.name;
            }
            function getJsxFactoryCalleePrimitive(isStaticChildren) {
                return compilerOptions.jsx === 5 /* ReactJSXDev */ ? "jsxDEV" : isStaticChildren ? "jsxs" : "jsx";
            }
            function getJsxFactoryCallee(isStaticChildren) {
                const type = getJsxFactoryCalleePrimitive(isStaticChildren);
                return getImplicitImportForName(type);
            }
            function getImplicitJsxFragmentReference() {
                return getImplicitImportForName("Fragment");
            }
            function getImplicitImportForName(name) {
                var _a2, _b;
                const importSource = name === "createElement" ? currentFileState.importSpecifier : getJSXRuntimeImport(currentFileState.importSpecifier, compilerOptions);
                const existing = (_b = (_a2 = currentFileState.utilizedImplicitRuntimeImports) == null ? void 0 : _a2.get(importSource)) == null ? void 0 : _b.get(name);
                if (existing) {
                    return existing.name;
                }
                if (!currentFileState.utilizedImplicitRuntimeImports) {
                    currentFileState.utilizedImplicitRuntimeImports = /* @__PURE__ */ new Map();
                }
                let specifierSourceImports = currentFileState.utilizedImplicitRuntimeImports.get(importSource);
                if (!specifierSourceImports) {
                    specifierSourceImports = /* @__PURE__ */ new Map();
                    currentFileState.utilizedImplicitRuntimeImports.set(importSource, specifierSourceImports);
                }
                const generatedName = factory2.createUniqueName(`_${name}`, 16 /* Optimistic */ | 32 /* FileLevel */ | 64 /* AllowNameSubstitution */);
                const specifier = factory2.createImportSpecifier(
                /*isTypeOnly*/
                false, factory2.createIdentifier(name), generatedName);
                setIdentifierGeneratedImportReference(generatedName, specifier);
                specifierSourceImports.set(name, specifier);
                return generatedName;
            }
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                currentFileState = {};
                currentFileState.importSpecifier = getJSXImplicitImportBase(compilerOptions, node);
                let visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                let statements = visited.statements;
                if (currentFileState.filenameDeclaration) {
                    statements = insertStatementAfterCustomPrologue(statements.slice(), factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([currentFileState.filenameDeclaration], 2 /* Const */)));
                }
                if (currentFileState.utilizedImplicitRuntimeImports) {
                    for (const [importSource, importSpecifiersMap] of arrayFrom(currentFileState.utilizedImplicitRuntimeImports.entries())) {
                        if (isExternalModule(node)) {
                            const importStatement = factory2.createImportDeclaration(
                            /*modifiers*/
                            void 0, factory2.createImportClause(
                            /*typeOnly*/
                            false, 
                            /*name*/
                            void 0, factory2.createNamedImports(arrayFrom(importSpecifiersMap.values()))), factory2.createStringLiteral(importSource), 
                            /*assertClause*/
                            void 0);
                            setParentRecursive(importStatement, 
                            /*incremental*/
                            false);
                            statements = insertStatementAfterCustomPrologue(statements.slice(), importStatement);
                        }
                        else if (isExternalOrCommonJsModule(node)) {
                            const requireStatement = factory2.createVariableStatement(
                            /*modifiers*/
                            void 0, factory2.createVariableDeclarationList([
                                factory2.createVariableDeclaration(factory2.createObjectBindingPattern(arrayFrom(importSpecifiersMap.values(), (s) => factory2.createBindingElement(
                                /*dotdotdot*/
                                void 0, s.propertyName, s.name))), 
                                /*exclaimationToken*/
                                void 0, 
                                /*type*/
                                void 0, factory2.createCallExpression(factory2.createIdentifier("require"), 
                                /*typeArguments*/
                                void 0, [factory2.createStringLiteral(importSource)]))
                            ], 2 /* Const */));
                            setParentRecursive(requireStatement, 
                            /*incremental*/
                            false);
                            statements = insertStatementAfterCustomPrologue(statements.slice(), requireStatement);
                        }
                        else {
                        }
                    }
                }
                if (statements !== visited.statements) {
                    visited = factory2.updateSourceFile(visited, statements);
                }
                currentFileState = void 0;
                return visited;
            }
            function visitor(node) {
                if (node.transformFlags & 2 /* ContainsJsx */) {
                    return visitorWorker(node);
                }
                else {
                    return node;
                }
            }
            function visitorWorker(node) {
                switch (node.kind) {
                    case 281 /* JsxElement */:
                        return visitJsxElement(node, 
                        /*isChild*/
                        false);
                    case 282 /* JsxSelfClosingElement */:
                        return visitJsxSelfClosingElement(node, 
                        /*isChild*/
                        false);
                    case 285 /* JsxFragment */:
                        return visitJsxFragment(node, 
                        /*isChild*/
                        false);
                    case 291 /* JsxExpression */:
                        return visitJsxExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function transformJsxChildToExpression(node) {
                switch (node.kind) {
                    case 11 /* JsxText */:
                        return visitJsxText(node);
                    case 291 /* JsxExpression */:
                        return visitJsxExpression(node);
                    case 281 /* JsxElement */:
                        return visitJsxElement(node, 
                        /*isChild*/
                        true);
                    case 282 /* JsxSelfClosingElement */:
                        return visitJsxSelfClosingElement(node, 
                        /*isChild*/
                        true);
                    case 285 /* JsxFragment */:
                        return visitJsxFragment(node, 
                        /*isChild*/
                        true);
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function hasKeyAfterPropsSpread(node) {
                let spread = false;
                for (const elem of node.attributes.properties) {
                    if (isJsxSpreadAttribute(elem)) {
                        spread = true;
                    }
                    else if (spread && isJsxAttribute(elem) && elem.name.escapedText === "key") {
                        return true;
                    }
                }
                return false;
            }
            function shouldUseCreateElement(node) {
                return currentFileState.importSpecifier === void 0 || hasKeyAfterPropsSpread(node);
            }
            function visitJsxElement(node, isChild) {
                const tagTransform = shouldUseCreateElement(node.openingElement) ? visitJsxOpeningLikeElementCreateElement : visitJsxOpeningLikeElementJSX;
                return tagTransform(node.openingElement, node.children, isChild, 
                /*location*/
                node);
            }
            function visitJsxSelfClosingElement(node, isChild) {
                const tagTransform = shouldUseCreateElement(node) ? visitJsxOpeningLikeElementCreateElement : visitJsxOpeningLikeElementJSX;
                return tagTransform(node, 
                /*children*/
                void 0, isChild, 
                /*location*/
                node);
            }
            function visitJsxFragment(node, isChild) {
                const tagTransform = currentFileState.importSpecifier === void 0 ? visitJsxOpeningFragmentCreateElement : visitJsxOpeningFragmentJSX;
                return tagTransform(node.openingFragment, node.children, isChild, 
                /*location*/
                node);
            }
            function convertJsxChildrenToChildrenPropObject(children) {
                const prop = convertJsxChildrenToChildrenPropAssignment(children);
                return prop && factory2.createObjectLiteralExpression([prop]);
            }
            function convertJsxChildrenToChildrenPropAssignment(children) {
                const nonWhitespaceChildren = getSemanticJsxChildren(children);
                if (length(nonWhitespaceChildren) === 1 && !nonWhitespaceChildren[0].dotDotDotToken) {
                    const result2 = transformJsxChildToExpression(nonWhitespaceChildren[0]);
                    return result2 && factory2.createPropertyAssignment("children", result2);
                }
                const result = mapDefined(children, transformJsxChildToExpression);
                return length(result) ? factory2.createPropertyAssignment("children", factory2.createArrayLiteralExpression(result)) : void 0;
            }
            function visitJsxOpeningLikeElementJSX(node, children, isChild, location) {
                const tagName = getTagName(node);
                const childrenProp = children && children.length ? convertJsxChildrenToChildrenPropAssignment(children) : void 0;
                const keyAttr = find(node.attributes.properties, (p) => !!p.name && isIdentifier(p.name) && p.name.escapedText === "key");
                const attrs = keyAttr ? filter(node.attributes.properties, (p) => p !== keyAttr) : node.attributes.properties;
                const objectProperties = length(attrs) ? transformJsxAttributesToObjectProps(attrs, childrenProp) : factory2.createObjectLiteralExpression(childrenProp ? [childrenProp] : emptyArray);
                return visitJsxOpeningLikeElementOrFragmentJSX(tagName, objectProperties, keyAttr, children || emptyArray, isChild, location);
            }
            function visitJsxOpeningLikeElementOrFragmentJSX(tagName, objectProperties, keyAttr, children, isChild, location) {
                var _a2;
                const nonWhitespaceChildren = getSemanticJsxChildren(children);
                const isStaticChildren = length(nonWhitespaceChildren) > 1 || !!((_a2 = nonWhitespaceChildren[0]) == null ? void 0 : _a2.dotDotDotToken);
                const args = [tagName, objectProperties];
                if (keyAttr) {
                    args.push(transformJsxAttributeInitializer(keyAttr.initializer));
                }
                if (compilerOptions.jsx === 5 /* ReactJSXDev */) {
                    const originalFile = getOriginalNode(currentSourceFile);
                    if (originalFile && isSourceFile(originalFile)) {
                        if (keyAttr === void 0) {
                            args.push(factory2.createVoidZero());
                        }
                        args.push(isStaticChildren ? factory2.createTrue() : factory2.createFalse());
                        const lineCol = getLineAndCharacterOfPosition(originalFile, location.pos);
                        args.push(factory2.createObjectLiteralExpression([
                            factory2.createPropertyAssignment("fileName", getCurrentFileNameExpression()),
                            factory2.createPropertyAssignment("lineNumber", factory2.createNumericLiteral(lineCol.line + 1)),
                            factory2.createPropertyAssignment("columnNumber", factory2.createNumericLiteral(lineCol.character + 1))
                        ]));
                        args.push(factory2.createThis());
                    }
                }
                const element = setTextRange(factory2.createCallExpression(getJsxFactoryCallee(isStaticChildren), 
                /*typeArguments*/
                void 0, args), location);
                if (isChild) {
                    startOnNewLine(element);
                }
                return element;
            }
            function visitJsxOpeningLikeElementCreateElement(node, children, isChild, location) {
                const tagName = getTagName(node);
                const attrs = node.attributes.properties;
                const objectProperties = length(attrs) ? transformJsxAttributesToObjectProps(attrs) : factory2.createNull();
                const callee = currentFileState.importSpecifier === void 0 ? createJsxFactoryExpression(factory2, context.getEmitResolver().getJsxFactoryEntity(currentSourceFile), compilerOptions.reactNamespace, 
                // TODO: GH#18217
                node) : getImplicitImportForName("createElement");
                const element = createExpressionForJsxElement(factory2, callee, tagName, objectProperties, mapDefined(children, transformJsxChildToExpression), location);
                if (isChild) {
                    startOnNewLine(element);
                }
                return element;
            }
            function visitJsxOpeningFragmentJSX(_node, children, isChild, location) {
                let childrenProps;
                if (children && children.length) {
                    const result = convertJsxChildrenToChildrenPropObject(children);
                    if (result) {
                        childrenProps = result;
                    }
                }
                return visitJsxOpeningLikeElementOrFragmentJSX(getImplicitJsxFragmentReference(), childrenProps || factory2.createObjectLiteralExpression([]), 
                /*keyAttr*/
                void 0, children, isChild, location);
            }
            function visitJsxOpeningFragmentCreateElement(node, children, isChild, location) {
                const element = createExpressionForJsxFragment(factory2, context.getEmitResolver().getJsxFactoryEntity(currentSourceFile), context.getEmitResolver().getJsxFragmentFactoryEntity(currentSourceFile), compilerOptions.reactNamespace, 
                // TODO: GH#18217
                mapDefined(children, transformJsxChildToExpression), node, location);
                if (isChild) {
                    startOnNewLine(element);
                }
                return element;
            }
            function transformJsxSpreadAttributeToSpreadAssignment(node) {
                return factory2.createSpreadAssignment(Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
            }
            function transformJsxAttributesToObjectProps(attrs, children) {
                const target = getEmitScriptTarget(compilerOptions);
                return target && target >= 5 /* ES2018 */ ? factory2.createObjectLiteralExpression(transformJsxAttributesToProps(attrs, children)) : transformJsxAttributesToExpression(attrs, children);
            }
            function transformJsxAttributesToProps(attrs, children) {
                const props = flatten(spanMap(attrs, isJsxSpreadAttribute, (attrs2, isSpread) => map(attrs2, (attr) => isSpread ? transformJsxSpreadAttributeToSpreadAssignment(attr) : transformJsxAttributeToObjectLiteralElement(attr))));
                if (children) {
                    props.push(children);
                }
                return props;
            }
            function transformJsxAttributesToExpression(attrs, children) {
                const expressions = flatten(spanMap(attrs, isJsxSpreadAttribute, (attrs2, isSpread) => isSpread ? map(attrs2, transformJsxSpreadAttributeToExpression) : factory2.createObjectLiteralExpression(map(attrs2, transformJsxAttributeToObjectLiteralElement))));
                if (isJsxSpreadAttribute(attrs[0])) {
                    expressions.unshift(factory2.createObjectLiteralExpression());
                }
                if (children) {
                    expressions.push(factory2.createObjectLiteralExpression([children]));
                }
                return singleOrUndefined(expressions) || emitHelpers().createAssignHelper(expressions);
            }
            function transformJsxSpreadAttributeToExpression(node) {
                return Debug.checkDefined(visitNode(node.expression, visitor, isExpression));
            }
            function transformJsxAttributeToObjectLiteralElement(node) {
                const name = getAttributeName(node);
                const expression = transformJsxAttributeInitializer(node.initializer);
                return factory2.createPropertyAssignment(name, expression);
            }
            function transformJsxAttributeInitializer(node) {
                if (node === void 0) {
                    return factory2.createTrue();
                }
                if (node.kind === 10 /* StringLiteral */) {
                    const singleQuote = node.singleQuote !== void 0 ? node.singleQuote : !isStringDoubleQuoted(node, currentSourceFile);
                    const literal = factory2.createStringLiteral(tryDecodeEntities(node.text) || node.text, singleQuote);
                    return setTextRange(literal, node);
                }
                if (node.kind === 291 /* JsxExpression */) {
                    if (node.expression === void 0) {
                        return factory2.createTrue();
                    }
                    return Debug.checkDefined(visitNode(node.expression, visitor, isExpression));
                }
                if (isJsxElement(node)) {
                    return visitJsxElement(node, 
                    /*isChild*/
                    false);
                }
                if (isJsxSelfClosingElement(node)) {
                    return visitJsxSelfClosingElement(node, 
                    /*isChild*/
                    false);
                }
                if (isJsxFragment(node)) {
                    return visitJsxFragment(node, 
                    /*isChild*/
                    false);
                }
                return Debug.failBadSyntaxKind(node);
            }
            function visitJsxText(node) {
                const fixed = fixupWhitespaceAndDecodeEntities(node.text);
                return fixed === void 0 ? void 0 : factory2.createStringLiteral(fixed);
            }
            function fixupWhitespaceAndDecodeEntities(text) {
                let acc;
                let firstNonWhitespace = 0;
                let lastNonWhitespace = -1;
                for (let i = 0; i < text.length; i++) {
                    const c = text.charCodeAt(i);
                    if (isLineBreak(c)) {
                        if (firstNonWhitespace !== -1 && lastNonWhitespace !== -1) {
                            acc = addLineOfJsxText(acc, text.substr(firstNonWhitespace, lastNonWhitespace - firstNonWhitespace + 1));
                        }
                        firstNonWhitespace = -1;
                    }
                    else if (!isWhiteSpaceSingleLine(c)) {
                        lastNonWhitespace = i;
                        if (firstNonWhitespace === -1) {
                            firstNonWhitespace = i;
                        }
                    }
                }
                return firstNonWhitespace !== -1 ? addLineOfJsxText(acc, text.substr(firstNonWhitespace)) : acc;
            }
            function addLineOfJsxText(acc, trimmedLine) {
                const decoded = decodeEntities(trimmedLine);
                return acc === void 0 ? decoded : acc + " " + decoded;
            }
            function decodeEntities(text) {
                return text.replace(/&((#((\d+)|x([\da-fA-F]+)))|(\w+));/g, (match, _all, _number, _digits, decimal, hex, word) => {
                    if (decimal) {
                        return utf16EncodeAsString(parseInt(decimal, 10));
                    }
                    else if (hex) {
                        return utf16EncodeAsString(parseInt(hex, 16));
                    }
                    else {
                        const ch = entities.get(word);
                        return ch ? utf16EncodeAsString(ch) : match;
                    }
                });
            }
            function tryDecodeEntities(text) {
                const decoded = decodeEntities(text);
                return decoded === text ? void 0 : decoded;
            }
            function getTagName(node) {
                if (node.kind === 281 /* JsxElement */) {
                    return getTagName(node.openingElement);
                }
                else {
                    const name = node.tagName;
                    if (isIdentifier(name) && isIntrinsicJsxName(name.escapedText)) {
                        return factory2.createStringLiteral(idText(name));
                    }
                    else {
                        return createExpressionFromEntityName(factory2, name);
                    }
                }
            }
            function getAttributeName(node) {
                const name = node.name;
                const text = idText(name);
                if (/^[A-Za-z_]\w*$/.test(text)) {
                    return name;
                }
                else {
                    return factory2.createStringLiteral(text);
                }
            }
            function visitJsxExpression(node) {
                const expression = visitNode(node.expression, visitor, isExpression);
                return node.dotDotDotToken ? factory2.createSpreadElement(expression) : expression;
            }
        }
        var entities;
        var init_jsx = __esm({
            "src/compiler/transformers/jsx.ts"() {
                "use strict";
                init_ts2();
                entities = new Map(Object.entries({
                    quot: 34,
                    amp: 38,
                    apos: 39,
                    lt: 60,
                    gt: 62,
                    nbsp: 160,
                    iexcl: 161,
                    cent: 162,
                    pound: 163,
                    curren: 164,
                    yen: 165,
                    brvbar: 166,
                    sect: 167,
                    uml: 168,
                    copy: 169,
                    ordf: 170,
                    laquo: 171,
                    not: 172,
                    shy: 173,
                    reg: 174,
                    macr: 175,
                    deg: 176,
                    plusmn: 177,
                    sup2: 178,
                    sup3: 179,
                    acute: 180,
                    micro: 181,
                    para: 182,
                    middot: 183,
                    cedil: 184,
                    sup1: 185,
                    ordm: 186,
                    raquo: 187,
                    frac14: 188,
                    frac12: 189,
                    frac34: 190,
                    iquest: 191,
                    Agrave: 192,
                    Aacute: 193,
                    Acirc: 194,
                    Atilde: 195,
                    Auml: 196,
                    Aring: 197,
                    AElig: 198,
                    Ccedil: 199,
                    Egrave: 200,
                    Eacute: 201,
                    Ecirc: 202,
                    Euml: 203,
                    Igrave: 204,
                    Iacute: 205,
                    Icirc: 206,
                    Iuml: 207,
                    ETH: 208,
                    Ntilde: 209,
                    Ograve: 210,
                    Oacute: 211,
                    Ocirc: 212,
                    Otilde: 213,
                    Ouml: 214,
                    times: 215,
                    Oslash: 216,
                    Ugrave: 217,
                    Uacute: 218,
                    Ucirc: 219,
                    Uuml: 220,
                    Yacute: 221,
                    THORN: 222,
                    szlig: 223,
                    agrave: 224,
                    aacute: 225,
                    acirc: 226,
                    atilde: 227,
                    auml: 228,
                    aring: 229,
                    aelig: 230,
                    ccedil: 231,
                    egrave: 232,
                    eacute: 233,
                    ecirc: 234,
                    euml: 235,
                    igrave: 236,
                    iacute: 237,
                    icirc: 238,
                    iuml: 239,
                    eth: 240,
                    ntilde: 241,
                    ograve: 242,
                    oacute: 243,
                    ocirc: 244,
                    otilde: 245,
                    ouml: 246,
                    divide: 247,
                    oslash: 248,
                    ugrave: 249,
                    uacute: 250,
                    ucirc: 251,
                    uuml: 252,
                    yacute: 253,
                    thorn: 254,
                    yuml: 255,
                    OElig: 338,
                    oelig: 339,
                    Scaron: 352,
                    scaron: 353,
                    Yuml: 376,
                    fnof: 402,
                    circ: 710,
                    tilde: 732,
                    Alpha: 913,
                    Beta: 914,
                    Gamma: 915,
                    Delta: 916,
                    Epsilon: 917,
                    Zeta: 918,
                    Eta: 919,
                    Theta: 920,
                    Iota: 921,
                    Kappa: 922,
                    Lambda: 923,
                    Mu: 924,
                    Nu: 925,
                    Xi: 926,
                    Omicron: 927,
                    Pi: 928,
                    Rho: 929,
                    Sigma: 931,
                    Tau: 932,
                    Upsilon: 933,
                    Phi: 934,
                    Chi: 935,
                    Psi: 936,
                    Omega: 937,
                    alpha: 945,
                    beta: 946,
                    gamma: 947,
                    delta: 948,
                    epsilon: 949,
                    zeta: 950,
                    eta: 951,
                    theta: 952,
                    iota: 953,
                    kappa: 954,
                    lambda: 955,
                    mu: 956,
                    nu: 957,
                    xi: 958,
                    omicron: 959,
                    pi: 960,
                    rho: 961,
                    sigmaf: 962,
                    sigma: 963,
                    tau: 964,
                    upsilon: 965,
                    phi: 966,
                    chi: 967,
                    psi: 968,
                    omega: 969,
                    thetasym: 977,
                    upsih: 978,
                    piv: 982,
                    ensp: 8194,
                    emsp: 8195,
                    thinsp: 8201,
                    zwnj: 8204,
                    zwj: 8205,
                    lrm: 8206,
                    rlm: 8207,
                    ndash: 8211,
                    mdash: 8212,
                    lsquo: 8216,
                    rsquo: 8217,
                    sbquo: 8218,
                    ldquo: 8220,
                    rdquo: 8221,
                    bdquo: 8222,
                    dagger: 8224,
                    Dagger: 8225,
                    bull: 8226,
                    hellip: 8230,
                    permil: 8240,
                    prime: 8242,
                    Prime: 8243,
                    lsaquo: 8249,
                    rsaquo: 8250,
                    oline: 8254,
                    frasl: 8260,
                    euro: 8364,
                    image: 8465,
                    weierp: 8472,
                    real: 8476,
                    trade: 8482,
                    alefsym: 8501,
                    larr: 8592,
                    uarr: 8593,
                    rarr: 8594,
                    darr: 8595,
                    harr: 8596,
                    crarr: 8629,
                    lArr: 8656,
                    uArr: 8657,
                    rArr: 8658,
                    dArr: 8659,
                    hArr: 8660,
                    forall: 8704,
                    part: 8706,
                    exist: 8707,
                    empty: 8709,
                    nabla: 8711,
                    isin: 8712,
                    notin: 8713,
                    ni: 8715,
                    prod: 8719,
                    sum: 8721,
                    minus: 8722,
                    lowast: 8727,
                    radic: 8730,
                    prop: 8733,
                    infin: 8734,
                    ang: 8736,
                    and: 8743,
                    or: 8744,
                    cap: 8745,
                    cup: 8746,
                    int: 8747,
                    there4: 8756,
                    sim: 8764,
                    cong: 8773,
                    asymp: 8776,
                    ne: 8800,
                    equiv: 8801,
                    le: 8804,
                    ge: 8805,
                    sub: 8834,
                    sup: 8835,
                    nsub: 8836,
                    sube: 8838,
                    supe: 8839,
                    oplus: 8853,
                    otimes: 8855,
                    perp: 8869,
                    sdot: 8901,
                    lceil: 8968,
                    rceil: 8969,
                    lfloor: 8970,
                    rfloor: 8971,
                    lang: 9001,
                    rang: 9002,
                    loz: 9674,
                    spades: 9824,
                    clubs: 9827,
                    hearts: 9829,
                    diams: 9830
                }));
            }
        });
        // src/compiler/transformers/es2016.ts
        function transformES2016(context) {
            const { factory: factory2, hoistVariableDeclaration } = context;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 512 /* ContainsES2016 */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 223 /* BinaryExpression */:
                        return visitBinaryExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitBinaryExpression(node) {
                switch (node.operatorToken.kind) {
                    case 67 /* AsteriskAsteriskEqualsToken */:
                        return visitExponentiationAssignmentExpression(node);
                    case 42 /* AsteriskAsteriskToken */:
                        return visitExponentiationExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitExponentiationAssignmentExpression(node) {
                let target;
                let value;
                const left = visitNode(node.left, visitor, isExpression);
                const right = visitNode(node.right, visitor, isExpression);
                if (isElementAccessExpression(left)) {
                    const expressionTemp = factory2.createTempVariable(hoistVariableDeclaration);
                    const argumentExpressionTemp = factory2.createTempVariable(hoistVariableDeclaration);
                    target = setTextRange(factory2.createElementAccessExpression(setTextRange(factory2.createAssignment(expressionTemp, left.expression), left.expression), setTextRange(factory2.createAssignment(argumentExpressionTemp, left.argumentExpression), left.argumentExpression)), left);
                    value = setTextRange(factory2.createElementAccessExpression(expressionTemp, argumentExpressionTemp), left);
                }
                else if (isPropertyAccessExpression(left)) {
                    const expressionTemp = factory2.createTempVariable(hoistVariableDeclaration);
                    target = setTextRange(factory2.createPropertyAccessExpression(setTextRange(factory2.createAssignment(expressionTemp, left.expression), left.expression), left.name), left);
                    value = setTextRange(factory2.createPropertyAccessExpression(expressionTemp, left.name), left);
                }
                else {
                    target = left;
                    value = left;
                }
                return setTextRange(factory2.createAssignment(target, setTextRange(factory2.createGlobalMethodCall("Math", "pow", [value, right]), node)), node);
            }
            function visitExponentiationExpression(node) {
                const left = visitNode(node.left, visitor, isExpression);
                const right = visitNode(node.right, visitor, isExpression);
                return setTextRange(factory2.createGlobalMethodCall("Math", "pow", [left, right]), node);
            }
        }
        var init_es2016 = __esm({
            "src/compiler/transformers/es2016.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2015.ts
        function createSpreadSegment(kind, expression) {
            return { kind, expression };
        }
        function transformES2015(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, startLexicalEnvironment, resumeLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const compilerOptions = context.getCompilerOptions();
            const resolver = context.getEmitResolver();
            const previousOnSubstituteNode = context.onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            context.onEmitNode = onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            let currentSourceFile;
            let currentText;
            let hierarchyFacts;
            let taggedTemplateStringDeclarations;
            function recordTaggedTemplateString(temp) {
                taggedTemplateStringDeclarations = append(taggedTemplateStringDeclarations, factory2.createVariableDeclaration(temp));
            }
            let convertedLoopState;
            let enabledSubstitutions;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                currentText = node.text;
                const visited = visitSourceFile(node);
                addEmitHelpers(visited, context.readEmitHelpers());
                currentSourceFile = void 0;
                currentText = void 0;
                taggedTemplateStringDeclarations = void 0;
                hierarchyFacts = 0 /* None */;
                return visited;
            }
            function enterSubtree(excludeFacts, includeFacts) {
                const ancestorFacts = hierarchyFacts;
                hierarchyFacts = (hierarchyFacts & ~excludeFacts | includeFacts) & 32767 /* AncestorFactsMask */;
                return ancestorFacts;
            }
            function exitSubtree(ancestorFacts, excludeFacts, includeFacts) {
                hierarchyFacts = (hierarchyFacts & ~excludeFacts | includeFacts) & -32768 /* SubtreeFactsMask */ | ancestorFacts;
            }
            function isReturnVoidStatementInConstructorWithCapturedSuper(node) {
                return (hierarchyFacts & 8192 /* ConstructorWithCapturedSuper */) !== 0 && node.kind === 250 /* ReturnStatement */ && !node.expression;
            }
            function isOrMayContainReturnCompletion(node) {
                return node.transformFlags & 4194304 /* ContainsHoistedDeclarationOrCompletion */ && (isReturnStatement(node) || isIfStatement(node) || isWithStatement(node) || isSwitchStatement(node) || isCaseBlock(node) || isCaseClause(node) || isDefaultClause(node) || isTryStatement(node) || isCatchClause(node) || isLabeledStatement(node) || isIterationStatement(node, 
                /*lookInLabeledStatements*/
                false) || isBlock(node));
            }
            function shouldVisitNode(node) {
                return (node.transformFlags & 1024 /* ContainsES2015 */) !== 0 || convertedLoopState !== void 0 || hierarchyFacts & 8192 /* ConstructorWithCapturedSuper */ && isOrMayContainReturnCompletion(node) || isIterationStatement(node, 
                /*lookInLabeledStatements*/
                false) && shouldConvertIterationStatement(node) || (getInternalEmitFlags(node) & 1 /* TypeScriptClassWrapper */) !== 0;
            }
            function visitor(node) {
                return shouldVisitNode(node) ? visitorWorker(node, 
                /*expressionResultIsUnused*/
                false) : node;
            }
            function visitorWithUnusedExpressionResult(node) {
                return shouldVisitNode(node) ? visitorWorker(node, 
                /*expressionResultIsUnused*/
                true) : node;
            }
            function classWrapperStatementVisitor(node) {
                if (shouldVisitNode(node)) {
                    const original = getOriginalNode(node);
                    if (isPropertyDeclaration(original) && hasStaticModifier(original)) {
                        const ancestorFacts = enterSubtree(32670 /* StaticInitializerExcludes */, 16449 /* StaticInitializerIncludes */);
                        const result = visitorWorker(node, 
                        /*expressionResultIsUnused*/
                        false);
                        exitSubtree(ancestorFacts, 98304 /* FunctionSubtreeExcludes */, 0 /* None */);
                        return result;
                    }
                    return visitorWorker(node, 
                    /*expressionResultIsUnused*/
                    false);
                }
                return node;
            }
            function callExpressionVisitor(node) {
                if (node.kind === 106 /* SuperKeyword */) {
                    return visitSuperKeyword(
                    /*isExpressionOfCall*/
                    true);
                }
                return visitor(node);
            }
            function visitorWorker(node, expressionResultIsUnused2) {
                switch (node.kind) {
                    case 124 /* StaticKeyword */:
                        return void 0;
                    case 260 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 228 /* ClassExpression */:
                        return visitClassExpression(node);
                    case 166 /* Parameter */:
                        return visitParameter(node);
                    case 259 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 216 /* ArrowFunction */:
                        return visitArrowFunction(node);
                    case 215 /* FunctionExpression */:
                        return visitFunctionExpression(node);
                    case 257 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 79 /* Identifier */:
                        return visitIdentifier(node);
                    case 258 /* VariableDeclarationList */:
                        return visitVariableDeclarationList(node);
                    case 252 /* SwitchStatement */:
                        return visitSwitchStatement(node);
                    case 266 /* CaseBlock */:
                        return visitCaseBlock(node);
                    case 238 /* Block */:
                        return visitBlock(node, 
                        /*isFunctionBody*/
                        false);
                    case 249 /* BreakStatement */:
                    case 248 /* ContinueStatement */:
                        return visitBreakOrContinueStatement(node);
                    case 253 /* LabeledStatement */:
                        return visitLabeledStatement(node);
                    case 243 /* DoStatement */:
                    case 244 /* WhileStatement */:
                        return visitDoOrWhileStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 245 /* ForStatement */:
                        return visitForStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 246 /* ForInStatement */:
                        return visitForInStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 247 /* ForOfStatement */:
                        return visitForOfStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 241 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 207 /* ObjectLiteralExpression */:
                        return visitObjectLiteralExpression(node);
                    case 295 /* CatchClause */:
                        return visitCatchClause(node);
                    case 300 /* ShorthandPropertyAssignment */:
                        return visitShorthandPropertyAssignment(node);
                    case 164 /* ComputedPropertyName */:
                        return visitComputedPropertyName(node);
                    case 206 /* ArrayLiteralExpression */:
                        return visitArrayLiteralExpression(node);
                    case 210 /* CallExpression */:
                        return visitCallExpression(node);
                    case 211 /* NewExpression */:
                        return visitNewExpression(node);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, expressionResultIsUnused2);
                    case 223 /* BinaryExpression */:
                        return visitBinaryExpression(node, expressionResultIsUnused2);
                    case 357 /* CommaListExpression */:
                        return visitCommaListExpression(node, expressionResultIsUnused2);
                    case 14 /* NoSubstitutionTemplateLiteral */:
                    case 15 /* TemplateHead */:
                    case 16 /* TemplateMiddle */:
                    case 17 /* TemplateTail */:
                        return visitTemplateLiteral(node);
                    case 10 /* StringLiteral */:
                        return visitStringLiteral(node);
                    case 8 /* NumericLiteral */:
                        return visitNumericLiteral(node);
                    case 212 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 225 /* TemplateExpression */:
                        return visitTemplateExpression(node);
                    case 226 /* YieldExpression */:
                        return visitYieldExpression(node);
                    case 227 /* SpreadElement */:
                        return visitSpreadElement(node);
                    case 106 /* SuperKeyword */:
                        return visitSuperKeyword(
                        /*isExpressionOfCall*/
                        false);
                    case 108 /* ThisKeyword */:
                        return visitThisKeyword(node);
                    case 233 /* MetaProperty */:
                        return visitMetaProperty(node);
                    case 171 /* MethodDeclaration */:
                        return visitMethodDeclaration(node);
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        return visitAccessorDeclaration(node);
                    case 240 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 250 /* ReturnStatement */:
                        return visitReturnStatement(node);
                    case 219 /* VoidExpression */:
                        return visitVoidExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitSourceFile(node) {
                const ancestorFacts = enterSubtree(8064 /* SourceFileExcludes */, 64 /* SourceFileIncludes */);
                const prologue = [];
                const statements = [];
                startLexicalEnvironment();
                const statementOffset = factory2.copyPrologue(node.statements, prologue, 
                /*ensureUseStrict*/
                false, visitor);
                addRange(statements, visitNodes2(node.statements, visitor, isStatement, statementOffset));
                if (taggedTemplateStringDeclarations) {
                    statements.push(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(taggedTemplateStringDeclarations)));
                }
                factory2.mergeLexicalEnvironment(prologue, endLexicalEnvironment());
                insertCaptureThisForNodeIfNeeded(prologue, node);
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray(concatenate(prologue, statements)), node.statements));
            }
            function visitSwitchStatement(node) {
                if (convertedLoopState !== void 0) {
                    const savedAllowedNonLabeledJumps = convertedLoopState.allowedNonLabeledJumps;
                    convertedLoopState.allowedNonLabeledJumps |= 2 /* Break */;
                    const result = visitEachChild(node, visitor, context);
                    convertedLoopState.allowedNonLabeledJumps = savedAllowedNonLabeledJumps;
                    return result;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCaseBlock(node) {
                const ancestorFacts = enterSubtree(7104 /* BlockScopeExcludes */, 0 /* BlockScopeIncludes */);
                const updated = visitEachChild(node, visitor, context);
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function returnCapturedThis(node) {
                return setOriginalNode(factory2.createReturnStatement(factory2.createUniqueName("_this", 16 /* Optimistic */ | 32 /* FileLevel */)), node);
            }
            function visitReturnStatement(node) {
                if (convertedLoopState) {
                    convertedLoopState.nonLocalJumps |= 8 /* Return */;
                    if (isReturnVoidStatementInConstructorWithCapturedSuper(node)) {
                        node = returnCapturedThis(node);
                    }
                    return factory2.createReturnStatement(factory2.createObjectLiteralExpression([
                        factory2.createPropertyAssignment(factory2.createIdentifier("value"), node.expression ? Debug.checkDefined(visitNode(node.expression, visitor, isExpression)) : factory2.createVoidZero())
                    ]));
                }
                else if (isReturnVoidStatementInConstructorWithCapturedSuper(node)) {
                    return returnCapturedThis(node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitThisKeyword(node) {
                if (hierarchyFacts & 2 /* ArrowFunction */ && !(hierarchyFacts & 16384 /* StaticInitializer */)) {
                    hierarchyFacts |= 65536 /* CapturedLexicalThis */;
                }
                if (convertedLoopState) {
                    if (hierarchyFacts & 2 /* ArrowFunction */) {
                        convertedLoopState.containsLexicalThis = true;
                        return node;
                    }
                    return convertedLoopState.thisName || (convertedLoopState.thisName = factory2.createUniqueName("this"));
                }
                return node;
            }
            function visitVoidExpression(node) {
                return visitEachChild(node, visitorWithUnusedExpressionResult, context);
            }
            function visitIdentifier(node) {
                if (convertedLoopState) {
                    if (resolver.isArgumentsLocalBinding(node)) {
                        return convertedLoopState.argumentsName || (convertedLoopState.argumentsName = factory2.createUniqueName("arguments"));
                    }
                }
                if (node.flags & 128 /* IdentifierHasExtendedUnicodeEscape */) {
                    return setOriginalNode(setTextRange(factory2.createIdentifier(unescapeLeadingUnderscores(node.escapedText)), node), node);
                }
                return node;
            }
            function visitBreakOrContinueStatement(node) {
                if (convertedLoopState) {
                    const jump = node.kind === 249 /* BreakStatement */ ? 2 /* Break */ : 4 /* Continue */;
                    const canUseBreakOrContinue = node.label && convertedLoopState.labels && convertedLoopState.labels.get(idText(node.label)) || !node.label && convertedLoopState.allowedNonLabeledJumps & jump;
                    if (!canUseBreakOrContinue) {
                        let labelMarker;
                        const label = node.label;
                        if (!label) {
                            if (node.kind === 249 /* BreakStatement */) {
                                convertedLoopState.nonLocalJumps |= 2 /* Break */;
                                labelMarker = "break";
                            }
                            else {
                                convertedLoopState.nonLocalJumps |= 4 /* Continue */;
                                labelMarker = "continue";
                            }
                        }
                        else {
                            if (node.kind === 249 /* BreakStatement */) {
                                labelMarker = `break-${label.escapedText}`;
                                setLabeledJump(convertedLoopState, 
                                /*isBreak*/
                                true, idText(label), labelMarker);
                            }
                            else {
                                labelMarker = `continue-${label.escapedText}`;
                                setLabeledJump(convertedLoopState, 
                                /*isBreak*/
                                false, idText(label), labelMarker);
                            }
                        }
                        let returnExpression = factory2.createStringLiteral(labelMarker);
                        if (convertedLoopState.loopOutParameters.length) {
                            const outParams = convertedLoopState.loopOutParameters;
                            let expr;
                            for (let i = 0; i < outParams.length; i++) {
                                const copyExpr = copyOutParameter(outParams[i], 1 /* ToOutParameter */);
                                if (i === 0) {
                                    expr = copyExpr;
                                }
                                else {
                                    expr = factory2.createBinaryExpression(expr, 27 /* CommaToken */, copyExpr);
                                }
                            }
                            returnExpression = factory2.createBinaryExpression(expr, 27 /* CommaToken */, returnExpression);
                        }
                        return factory2.createReturnStatement(returnExpression);
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitClassDeclaration(node) {
                const variable = factory2.createVariableDeclaration(factory2.getLocalName(node, 
                /*allowComments*/
                true), 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, transformClassLikeDeclarationToExpression(node));
                setOriginalNode(variable, node);
                const statements = [];
                const statement = factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([variable]));
                setOriginalNode(statement, node);
                setTextRange(statement, node);
                startOnNewLine(statement);
                statements.push(statement);
                if (hasSyntacticModifier(node, 1 /* Export */)) {
                    const exportStatement = hasSyntacticModifier(node, 1024 /* Default */) ? factory2.createExportDefault(factory2.getLocalName(node)) : factory2.createExternalModuleExport(factory2.getLocalName(node));
                    setOriginalNode(exportStatement, statement);
                    statements.push(exportStatement);
                }
                const emitFlags = getEmitFlags(node);
                if ((emitFlags & 8388608 /* HasEndOfDeclarationMarker */) === 0) {
                    statements.push(factory2.createEndOfDeclarationMarker(node));
                    setEmitFlags(statement, emitFlags | 8388608 /* HasEndOfDeclarationMarker */);
                }
                return singleOrMany(statements);
            }
            function visitClassExpression(node) {
                return transformClassLikeDeclarationToExpression(node);
            }
            function transformClassLikeDeclarationToExpression(node) {
                if (node.name) {
                    enableSubstitutionsForBlockScopedBindings();
                }
                const extendsClauseElement = getClassExtendsHeritageElement(node);
                const classFunction = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, extendsClauseElement ? [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */))] : [], 
                /*type*/
                void 0, transformClassBody(node, extendsClauseElement));
                setEmitFlags(classFunction, getEmitFlags(node) & 131072 /* Indented */ | 1048576 /* ReuseTempVariableScope */);
                const inner = factory2.createPartiallyEmittedExpression(classFunction);
                setTextRangeEnd(inner, node.end);
                setEmitFlags(inner, 3072 /* NoComments */);
                const outer = factory2.createPartiallyEmittedExpression(inner);
                setTextRangeEnd(outer, skipTrivia(currentText, node.pos));
                setEmitFlags(outer, 3072 /* NoComments */);
                const result = factory2.createParenthesizedExpression(factory2.createCallExpression(outer, 
                /*typeArguments*/
                void 0, extendsClauseElement ? [Debug.checkDefined(visitNode(extendsClauseElement.expression, visitor, isExpression))] : []));
                addSyntheticLeadingComment(result, 3 /* MultiLineCommentTrivia */, "* @class ");
                return result;
            }
            function transformClassBody(node, extendsClauseElement) {
                const statements = [];
                const name = factory2.getInternalName(node);
                const constructorLikeName = isIdentifierANonContextualKeyword(name) ? factory2.getGeneratedNameForNode(name) : name;
                startLexicalEnvironment();
                addExtendsHelperIfNeeded(statements, node, extendsClauseElement);
                addConstructor(statements, node, constructorLikeName, extendsClauseElement);
                addClassMembers(statements, node);
                const closingBraceLocation = createTokenRange(skipTrivia(currentText, node.members.end), 19 /* CloseBraceToken */);
                const outer = factory2.createPartiallyEmittedExpression(constructorLikeName);
                setTextRangeEnd(outer, closingBraceLocation.end);
                setEmitFlags(outer, 3072 /* NoComments */);
                const statement = factory2.createReturnStatement(outer);
                setTextRangePos(statement, closingBraceLocation.pos);
                setEmitFlags(statement, 3072 /* NoComments */ | 768 /* NoTokenSourceMaps */);
                statements.push(statement);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                const block = factory2.createBlock(setTextRange(factory2.createNodeArray(statements), 
                /*location*/
                node.members), 
                /*multiLine*/
                true);
                setEmitFlags(block, 3072 /* NoComments */);
                return block;
            }
            function addExtendsHelperIfNeeded(statements, node, extendsClauseElement) {
                if (extendsClauseElement) {
                    statements.push(setTextRange(factory2.createExpressionStatement(emitHelpers().createExtendsHelper(factory2.getInternalName(node))), 
                    /*location*/
                    extendsClauseElement));
                }
            }
            function addConstructor(statements, node, name, extendsClauseElement) {
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = enterSubtree(32662 /* ConstructorExcludes */, 73 /* ConstructorIncludes */);
                const constructor = getFirstConstructorWithBody(node);
                const hasSynthesizedSuper = hasSynthesizedDefaultSuperCall(constructor, extendsClauseElement !== void 0);
                const constructorFunction = factory2.createFunctionDeclaration(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, name, 
                /*typeParameters*/
                void 0, transformConstructorParameters(constructor, hasSynthesizedSuper), 
                /*type*/
                void 0, transformConstructorBody(constructor, node, extendsClauseElement, hasSynthesizedSuper));
                setTextRange(constructorFunction, constructor || node);
                if (extendsClauseElement) {
                    setEmitFlags(constructorFunction, 16 /* CapturesThis */);
                }
                statements.push(constructorFunction);
                exitSubtree(ancestorFacts, 98304 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
            }
            function transformConstructorParameters(constructor, hasSynthesizedSuper) {
                return visitParameterList(constructor && !hasSynthesizedSuper ? constructor.parameters : void 0, visitor, context) || [];
            }
            function createDefaultConstructorBody(node, isDerivedClass) {
                const statements = [];
                resumeLexicalEnvironment();
                factory2.mergeLexicalEnvironment(statements, endLexicalEnvironment());
                if (isDerivedClass) {
                    statements.push(factory2.createReturnStatement(createDefaultSuperCallOrThis()));
                }
                const statementsArray = factory2.createNodeArray(statements);
                setTextRange(statementsArray, node.members);
                const block = factory2.createBlock(statementsArray, 
                /*multiLine*/
                true);
                setTextRange(block, node);
                setEmitFlags(block, 3072 /* NoComments */);
                return block;
            }
            function transformConstructorBody(constructor, node, extendsClauseElement, hasSynthesizedSuper) {
                const isDerivedClass = !!extendsClauseElement && skipOuterExpressions(extendsClauseElement.expression).kind !== 104 /* NullKeyword */;
                if (!constructor)
                    return createDefaultConstructorBody(node, isDerivedClass);
                const prologue = [];
                const statements = [];
                resumeLexicalEnvironment();
                const existingPrologue = takeWhile(constructor.body.statements, isPrologueDirective);
                const { superCall, superStatementIndex } = findSuperCallAndStatementIndex(constructor.body.statements, existingPrologue);
                const postSuperStatementsStart = superStatementIndex === -1 ? existingPrologue.length : superStatementIndex + 1;
                let statementOffset = postSuperStatementsStart;
                if (!hasSynthesizedSuper)
                    statementOffset = factory2.copyStandardPrologue(constructor.body.statements, prologue, statementOffset, 
                    /*ensureUseStrict*/
                    false);
                if (!hasSynthesizedSuper)
                    statementOffset = factory2.copyCustomPrologue(constructor.body.statements, statements, statementOffset, visitor, 
                    /*filter*/
                    void 0);
                let superCallExpression;
                if (hasSynthesizedSuper) {
                    superCallExpression = createDefaultSuperCallOrThis();
                }
                else if (superCall) {
                    superCallExpression = visitSuperCallInBody(superCall);
                }
                if (superCallExpression) {
                    hierarchyFacts |= 8192 /* ConstructorWithCapturedSuper */;
                }
                addDefaultValueAssignmentsIfNeeded2(prologue, constructor);
                addRestParameterIfNeeded(prologue, constructor, hasSynthesizedSuper);
                addRange(statements, visitNodes2(constructor.body.statements, visitor, isStatement, 
                /*start*/
                statementOffset));
                factory2.mergeLexicalEnvironment(prologue, endLexicalEnvironment());
                insertCaptureNewTargetIfNeeded(prologue, constructor, 
                /*copyOnWrite*/
                false);
                if (isDerivedClass || superCallExpression) {
                    if (superCallExpression && postSuperStatementsStart === constructor.body.statements.length && !(constructor.body.transformFlags & 16384 /* ContainsLexicalThis */)) {
                        const superCall2 = cast(cast(superCallExpression, isBinaryExpression).left, isCallExpression);
                        const returnStatement = factory2.createReturnStatement(superCallExpression);
                        setCommentRange(returnStatement, getCommentRange(superCall2));
                        setEmitFlags(superCall2, 3072 /* NoComments */);
                        statements.push(returnStatement);
                    }
                    else {
                        if (superStatementIndex <= existingPrologue.length) {
                            insertCaptureThisForNode(statements, constructor, superCallExpression || createActualThis());
                        }
                        else {
                            insertCaptureThisForNode(prologue, constructor, createActualThis());
                            if (superCallExpression) {
                                insertSuperThisCaptureThisForNode(statements, superCallExpression);
                            }
                        }
                        if (!isSufficientlyCoveredByReturnStatements(constructor.body)) {
                            statements.push(factory2.createReturnStatement(factory2.createUniqueName("_this", 16 /* Optimistic */ | 32 /* FileLevel */)));
                        }
                    }
                }
                else {
                    insertCaptureThisForNodeIfNeeded(prologue, constructor);
                }
                const body = factory2.createBlock(setTextRange(factory2.createNodeArray([
                    ...existingPrologue,
                    ...prologue,
                    ...superStatementIndex <= existingPrologue.length ? emptyArray : visitNodes2(constructor.body.statements, visitor, isStatement, existingPrologue.length, superStatementIndex - existingPrologue.length),
                    ...statements
                ]), 
                /*location*/
                constructor.body.statements), 
                /*multiLine*/
                true);
                setTextRange(body, constructor.body);
                return body;
            }
            function findSuperCallAndStatementIndex(originalBodyStatements, existingPrologue) {
                for (let i = existingPrologue.length; i < originalBodyStatements.length; i += 1) {
                    const superCall = getSuperCallFromStatement(originalBodyStatements[i]);
                    if (superCall) {
                        return {
                            superCall,
                            superStatementIndex: i
                        };
                    }
                }
                return {
                    superStatementIndex: -1
                };
            }
            function isSufficientlyCoveredByReturnStatements(statement) {
                if (statement.kind === 250 /* ReturnStatement */) {
                    return true;
                }
                else if (statement.kind === 242 /* IfStatement */) {
                    const ifStatement = statement;
                    if (ifStatement.elseStatement) {
                        return isSufficientlyCoveredByReturnStatements(ifStatement.thenStatement) && isSufficientlyCoveredByReturnStatements(ifStatement.elseStatement);
                    }
                }
                else if (statement.kind === 238 /* Block */) {
                    const lastStatement = lastOrUndefined(statement.statements);
                    if (lastStatement && isSufficientlyCoveredByReturnStatements(lastStatement)) {
                        return true;
                    }
                }
                return false;
            }
            function createActualThis() {
                return setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */);
            }
            function createDefaultSuperCallOrThis() {
                return factory2.createLogicalOr(factory2.createLogicalAnd(factory2.createStrictInequality(factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */), factory2.createNull()), factory2.createFunctionApplyCall(factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */), createActualThis(), factory2.createIdentifier("arguments"))), createActualThis());
            }
            function visitParameter(node) {
                if (node.dotDotDotToken) {
                    return void 0;
                }
                else if (isBindingPattern(node.name)) {
                    return setOriginalNode(setTextRange(factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.getGeneratedNameForNode(node), 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0), 
                    /*location*/
                    node), 
                    /*original*/
                    node);
                }
                else if (node.initializer) {
                    return setOriginalNode(setTextRange(factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, node.name, 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0), 
                    /*location*/
                    node), 
                    /*original*/
                    node);
                }
                else {
                    return node;
                }
            }
            function hasDefaultValueOrBindingPattern(node) {
                return node.initializer !== void 0 || isBindingPattern(node.name);
            }
            function addDefaultValueAssignmentsIfNeeded2(statements, node) {
                if (!some(node.parameters, hasDefaultValueOrBindingPattern)) {
                    return false;
                }
                let added = false;
                for (const parameter of node.parameters) {
                    const { name, initializer, dotDotDotToken } = parameter;
                    if (dotDotDotToken) {
                        continue;
                    }
                    if (isBindingPattern(name)) {
                        added = insertDefaultValueAssignmentForBindingPattern(statements, parameter, name, initializer) || added;
                    }
                    else if (initializer) {
                        insertDefaultValueAssignmentForInitializer(statements, parameter, name, initializer);
                        added = true;
                    }
                }
                return added;
            }
            function insertDefaultValueAssignmentForBindingPattern(statements, parameter, name, initializer) {
                if (name.elements.length > 0) {
                    insertStatementAfterCustomPrologue(statements, setEmitFlags(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(flattenDestructuringBinding(parameter, visitor, context, 0 /* All */, factory2.getGeneratedNameForNode(parameter)))), 2097152 /* CustomPrologue */));
                    return true;
                }
                else if (initializer) {
                    insertStatementAfterCustomPrologue(statements, setEmitFlags(factory2.createExpressionStatement(factory2.createAssignment(factory2.getGeneratedNameForNode(parameter), Debug.checkDefined(visitNode(initializer, visitor, isExpression)))), 2097152 /* CustomPrologue */));
                    return true;
                }
                return false;
            }
            function insertDefaultValueAssignmentForInitializer(statements, parameter, name, initializer) {
                initializer = Debug.checkDefined(visitNode(initializer, visitor, isExpression));
                const statement = factory2.createIfStatement(factory2.createTypeCheck(factory2.cloneNode(name), "undefined"), setEmitFlags(setTextRange(factory2.createBlock([
                    factory2.createExpressionStatement(setEmitFlags(setTextRange(factory2.createAssignment(
                    // TODO(rbuckton): Does this need to be parented?
                    setEmitFlags(setParent(setTextRange(factory2.cloneNode(name), name), name.parent), 96 /* NoSourceMap */), setEmitFlags(initializer, 96 /* NoSourceMap */ | getEmitFlags(initializer) | 3072 /* NoComments */)), parameter), 3072 /* NoComments */))
                ]), parameter), 1 /* SingleLine */ | 64 /* NoTrailingSourceMap */ | 768 /* NoTokenSourceMaps */ | 3072 /* NoComments */));
                startOnNewLine(statement);
                setTextRange(statement, parameter);
                setEmitFlags(statement, 768 /* NoTokenSourceMaps */ | 64 /* NoTrailingSourceMap */ | 2097152 /* CustomPrologue */ | 3072 /* NoComments */);
                insertStatementAfterCustomPrologue(statements, statement);
            }
            function shouldAddRestParameter(node, inConstructorWithSynthesizedSuper) {
                return !!(node && node.dotDotDotToken && !inConstructorWithSynthesizedSuper);
            }
            function addRestParameterIfNeeded(statements, node, inConstructorWithSynthesizedSuper) {
                const prologueStatements = [];
                const parameter = lastOrUndefined(node.parameters);
                if (!shouldAddRestParameter(parameter, inConstructorWithSynthesizedSuper)) {
                    return false;
                }
                const declarationName = parameter.name.kind === 79 /* Identifier */ ? setParent(setTextRange(factory2.cloneNode(parameter.name), parameter.name), parameter.name.parent) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                setEmitFlags(declarationName, 96 /* NoSourceMap */);
                const expressionName = parameter.name.kind === 79 /* Identifier */ ? factory2.cloneNode(parameter.name) : declarationName;
                const restIndex = node.parameters.length - 1;
                const temp = factory2.createLoopVariable();
                prologueStatements.push(setEmitFlags(setTextRange(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(declarationName, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createArrayLiteralExpression([]))
                ])), 
                /*location*/
                parameter), 2097152 /* CustomPrologue */));
                const forStatement = factory2.createForStatement(setTextRange(factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(temp, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createNumericLiteral(restIndex))
                ]), parameter), setTextRange(factory2.createLessThan(temp, factory2.createPropertyAccessExpression(factory2.createIdentifier("arguments"), "length")), parameter), setTextRange(factory2.createPostfixIncrement(temp), parameter), factory2.createBlock([
                    startOnNewLine(setTextRange(factory2.createExpressionStatement(factory2.createAssignment(factory2.createElementAccessExpression(expressionName, restIndex === 0 ? temp : factory2.createSubtract(temp, factory2.createNumericLiteral(restIndex))), factory2.createElementAccessExpression(factory2.createIdentifier("arguments"), temp))), 
                    /*location*/
                    parameter))
                ]));
                setEmitFlags(forStatement, 2097152 /* CustomPrologue */);
                startOnNewLine(forStatement);
                prologueStatements.push(forStatement);
                if (parameter.name.kind !== 79 /* Identifier */) {
                    prologueStatements.push(setEmitFlags(setTextRange(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(flattenDestructuringBinding(parameter, visitor, context, 0 /* All */, expressionName))), parameter), 2097152 /* CustomPrologue */));
                }
                insertStatementsAfterCustomPrologue(statements, prologueStatements);
                return true;
            }
            function insertCaptureThisForNodeIfNeeded(statements, node) {
                if (hierarchyFacts & 65536 /* CapturedLexicalThis */ && node.kind !== 216 /* ArrowFunction */) {
                    insertCaptureThisForNode(statements, node, factory2.createThis());
                    return true;
                }
                return false;
            }
            function insertSuperThisCaptureThisForNode(statements, superExpression) {
                enableSubstitutionsForCapturedThis();
                const assignSuperExpression = factory2.createExpressionStatement(factory2.createBinaryExpression(factory2.createThis(), 63 /* EqualsToken */, superExpression));
                insertStatementAfterCustomPrologue(statements, assignSuperExpression);
                setCommentRange(assignSuperExpression, getOriginalNode(superExpression).parent);
            }
            function insertCaptureThisForNode(statements, node, initializer) {
                enableSubstitutionsForCapturedThis();
                const captureThisStatement = factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(factory2.createUniqueName("_this", 16 /* Optimistic */ | 32 /* FileLevel */), 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer)
                ]));
                setEmitFlags(captureThisStatement, 3072 /* NoComments */ | 2097152 /* CustomPrologue */);
                setSourceMapRange(captureThisStatement, node);
                insertStatementAfterCustomPrologue(statements, captureThisStatement);
            }
            function insertCaptureNewTargetIfNeeded(statements, node, copyOnWrite) {
                if (hierarchyFacts & 32768 /* NewTarget */) {
                    let newTarget;
                    switch (node.kind) {
                        case 216 /* ArrowFunction */:
                            return statements;
                        case 171 /* MethodDeclaration */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            newTarget = factory2.createVoidZero();
                            break;
                        case 173 /* Constructor */:
                            newTarget = factory2.createPropertyAccessExpression(setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */), "constructor");
                            break;
                        case 259 /* FunctionDeclaration */:
                        case 215 /* FunctionExpression */:
                            newTarget = factory2.createConditionalExpression(factory2.createLogicalAnd(setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */), factory2.createBinaryExpression(setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */), 102 /* InstanceOfKeyword */, factory2.getLocalName(node))), 
                            /*questionToken*/
                            void 0, factory2.createPropertyAccessExpression(setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */), "constructor"), 
                            /*colonToken*/
                            void 0, factory2.createVoidZero());
                            break;
                        default:
                            return Debug.failBadSyntaxKind(node);
                    }
                    const captureNewTargetStatement = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(factory2.createUniqueName("_newTarget", 16 /* Optimistic */ | 32 /* FileLevel */), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, newTarget)
                    ]));
                    setEmitFlags(captureNewTargetStatement, 3072 /* NoComments */ | 2097152 /* CustomPrologue */);
                    if (copyOnWrite) {
                        statements = statements.slice();
                    }
                    insertStatementAfterCustomPrologue(statements, captureNewTargetStatement);
                }
                return statements;
            }
            function addClassMembers(statements, node) {
                for (const member of node.members) {
                    switch (member.kind) {
                        case 237 /* SemicolonClassElement */:
                            statements.push(transformSemicolonClassElementToStatement(member));
                            break;
                        case 171 /* MethodDeclaration */:
                            statements.push(transformClassMethodDeclarationToStatement(getClassMemberPrefix(node, member), member, node));
                            break;
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            const accessors = getAllAccessorDeclarations(node.members, member);
                            if (member === accessors.firstAccessor) {
                                statements.push(transformAccessorsToStatement(getClassMemberPrefix(node, member), accessors, node));
                            }
                            break;
                        case 173 /* Constructor */:
                        case 172 /* ClassStaticBlockDeclaration */:
                            break;
                        default:
                            Debug.failBadSyntaxKind(member, currentSourceFile && currentSourceFile.fileName);
                            break;
                    }
                }
            }
            function transformSemicolonClassElementToStatement(member) {
                return setTextRange(factory2.createEmptyStatement(), member);
            }
            function transformClassMethodDeclarationToStatement(receiver, member, container) {
                const commentRange = getCommentRange(member);
                const sourceMapRange = getSourceMapRange(member);
                const memberFunction = transformFunctionLikeToExpression(member, 
                /*location*/
                member, 
                /*name*/
                void 0, container);
                const propertyName = visitNode(member.name, visitor, isPropertyName);
                Debug.assert(propertyName);
                let e;
                if (!isPrivateIdentifier(propertyName) && getUseDefineForClassFields(context.getCompilerOptions())) {
                    const name = isComputedPropertyName(propertyName) ? propertyName.expression : isIdentifier(propertyName) ? factory2.createStringLiteral(unescapeLeadingUnderscores(propertyName.escapedText)) : propertyName;
                    e = factory2.createObjectDefinePropertyCall(receiver, name, factory2.createPropertyDescriptor({ value: memberFunction, enumerable: false, writable: true, configurable: true }));
                }
                else {
                    const memberName = createMemberAccessForPropertyName(factory2, receiver, propertyName, 
                    /*location*/
                    member.name);
                    e = factory2.createAssignment(memberName, memberFunction);
                }
                setEmitFlags(memberFunction, 3072 /* NoComments */);
                setSourceMapRange(memberFunction, sourceMapRange);
                const statement = setTextRange(factory2.createExpressionStatement(e), 
                /*location*/
                member);
                setOriginalNode(statement, member);
                setCommentRange(statement, commentRange);
                setEmitFlags(statement, 96 /* NoSourceMap */);
                return statement;
            }
            function transformAccessorsToStatement(receiver, accessors, container) {
                const statement = factory2.createExpressionStatement(transformAccessorsToExpression(receiver, accessors, container, 
                /*startsOnNewLine*/
                false));
                setEmitFlags(statement, 3072 /* NoComments */);
                setSourceMapRange(statement, getSourceMapRange(accessors.firstAccessor));
                return statement;
            }
            function transformAccessorsToExpression(receiver, { firstAccessor, getAccessor, setAccessor }, container, startsOnNewLine) {
                const target = setParent(setTextRange(factory2.cloneNode(receiver), receiver), receiver.parent);
                setEmitFlags(target, 3072 /* NoComments */ | 64 /* NoTrailingSourceMap */);
                setSourceMapRange(target, firstAccessor.name);
                const visitedAccessorName = visitNode(firstAccessor.name, visitor, isPropertyName);
                Debug.assert(visitedAccessorName);
                if (isPrivateIdentifier(visitedAccessorName)) {
                    return Debug.failBadSyntaxKind(visitedAccessorName, "Encountered unhandled private identifier while transforming ES2015.");
                }
                const propertyName = createExpressionForPropertyName(factory2, visitedAccessorName);
                setEmitFlags(propertyName, 3072 /* NoComments */ | 32 /* NoLeadingSourceMap */);
                setSourceMapRange(propertyName, firstAccessor.name);
                const properties = [];
                if (getAccessor) {
                    const getterFunction = transformFunctionLikeToExpression(getAccessor, 
                    /*location*/
                    void 0, 
                    /*name*/
                    void 0, container);
                    setSourceMapRange(getterFunction, getSourceMapRange(getAccessor));
                    setEmitFlags(getterFunction, 1024 /* NoLeadingComments */);
                    const getter = factory2.createPropertyAssignment("get", getterFunction);
                    setCommentRange(getter, getCommentRange(getAccessor));
                    properties.push(getter);
                }
                if (setAccessor) {
                    const setterFunction = transformFunctionLikeToExpression(setAccessor, 
                    /*location*/
                    void 0, 
                    /*name*/
                    void 0, container);
                    setSourceMapRange(setterFunction, getSourceMapRange(setAccessor));
                    setEmitFlags(setterFunction, 1024 /* NoLeadingComments */);
                    const setter = factory2.createPropertyAssignment("set", setterFunction);
                    setCommentRange(setter, getCommentRange(setAccessor));
                    properties.push(setter);
                }
                properties.push(factory2.createPropertyAssignment("enumerable", getAccessor || setAccessor ? factory2.createFalse() : factory2.createTrue()), factory2.createPropertyAssignment("configurable", factory2.createTrue()));
                const call = factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "defineProperty"), 
                /*typeArguments*/
                void 0, [
                    target,
                    propertyName,
                    factory2.createObjectLiteralExpression(properties, 
                    /*multiLine*/
                    true)
                ]);
                if (startsOnNewLine) {
                    startOnNewLine(call);
                }
                return call;
            }
            function visitArrowFunction(node) {
                if (node.transformFlags & 16384 /* ContainsLexicalThis */ && !(hierarchyFacts & 16384 /* StaticInitializer */)) {
                    hierarchyFacts |= 65536 /* CapturedLexicalThis */;
                }
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = enterSubtree(15232 /* ArrowFunctionExcludes */, 66 /* ArrowFunctionIncludes */);
                const func = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, transformFunctionBody2(node));
                setTextRange(func, node);
                setOriginalNode(func, node);
                setEmitFlags(func, 16 /* CapturesThis */);
                exitSubtree(ancestorFacts, 0 /* ArrowFunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return func;
            }
            function visitFunctionExpression(node) {
                const ancestorFacts = getEmitFlags(node) & 524288 /* AsyncFunctionBody */ ? enterSubtree(32662 /* AsyncFunctionBodyExcludes */, 69 /* AsyncFunctionBodyIncludes */) : enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */);
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const parameters = visitParameterList(node.parameters, visitor, context);
                const body = transformFunctionBody2(node);
                const name = hierarchyFacts & 32768 /* NewTarget */ ? factory2.getLocalName(node) : node.name;
                exitSubtree(ancestorFacts, 98304 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return factory2.updateFunctionExpression(node, 
                /*modifiers*/
                void 0, node.asteriskToken, name, 
                /*typeParameters*/
                void 0, parameters, 
                /*type*/
                void 0, body);
            }
            function visitFunctionDeclaration(node) {
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */);
                const parameters = visitParameterList(node.parameters, visitor, context);
                const body = transformFunctionBody2(node);
                const name = hierarchyFacts & 32768 /* NewTarget */ ? factory2.getLocalName(node) : node.name;
                exitSubtree(ancestorFacts, 98304 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return factory2.updateFunctionDeclaration(node, visitNodes2(node.modifiers, visitor, isModifier), node.asteriskToken, name, 
                /*typeParameters*/
                void 0, parameters, 
                /*type*/
                void 0, body);
            }
            function transformFunctionLikeToExpression(node, location, name, container) {
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = container && isClassLike(container) && !isStatic(node) ? enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */ | 8 /* NonStaticClassElement */) : enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */);
                const parameters = visitParameterList(node.parameters, visitor, context);
                const body = transformFunctionBody2(node);
                if (hierarchyFacts & 32768 /* NewTarget */ && !name && (node.kind === 259 /* FunctionDeclaration */ || node.kind === 215 /* FunctionExpression */)) {
                    name = factory2.getGeneratedNameForNode(node);
                }
                exitSubtree(ancestorFacts, 98304 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return setOriginalNode(setTextRange(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, node.asteriskToken, name, 
                /*typeParameters*/
                void 0, parameters, 
                /*type*/
                void 0, body), location), 
                /*original*/
                node);
            }
            function transformFunctionBody2(node) {
                let multiLine = false;
                let singleLine = false;
                let statementsLocation;
                let closeBraceLocation;
                const prologue = [];
                const statements = [];
                const body = node.body;
                let statementOffset;
                resumeLexicalEnvironment();
                if (isBlock(body)) {
                    statementOffset = factory2.copyStandardPrologue(body.statements, prologue, 0, 
                    /*ensureUseStrict*/
                    false);
                    statementOffset = factory2.copyCustomPrologue(body.statements, statements, statementOffset, visitor, isHoistedFunction);
                    statementOffset = factory2.copyCustomPrologue(body.statements, statements, statementOffset, visitor, isHoistedVariableStatement);
                }
                multiLine = addDefaultValueAssignmentsIfNeeded2(statements, node) || multiLine;
                multiLine = addRestParameterIfNeeded(statements, node, 
                /*inConstructorWithSynthesizedSuper*/
                false) || multiLine;
                if (isBlock(body)) {
                    statementOffset = factory2.copyCustomPrologue(body.statements, statements, statementOffset, visitor);
                    statementsLocation = body.statements;
                    addRange(statements, visitNodes2(body.statements, visitor, isStatement, statementOffset));
                    if (!multiLine && body.multiLine) {
                        multiLine = true;
                    }
                }
                else {
                    Debug.assert(node.kind === 216 /* ArrowFunction */);
                    statementsLocation = moveRangeEnd(body, -1);
                    const equalsGreaterThanToken = node.equalsGreaterThanToken;
                    if (!nodeIsSynthesized(equalsGreaterThanToken) && !nodeIsSynthesized(body)) {
                        if (rangeEndIsOnSameLineAsRangeStart(equalsGreaterThanToken, body, currentSourceFile)) {
                            singleLine = true;
                        }
                        else {
                            multiLine = true;
                        }
                    }
                    const expression = visitNode(body, visitor, isExpression);
                    const returnStatement = factory2.createReturnStatement(expression);
                    setTextRange(returnStatement, body);
                    moveSyntheticComments(returnStatement, body);
                    setEmitFlags(returnStatement, 768 /* NoTokenSourceMaps */ | 64 /* NoTrailingSourceMap */ | 2048 /* NoTrailingComments */);
                    statements.push(returnStatement);
                    closeBraceLocation = body;
                }
                factory2.mergeLexicalEnvironment(prologue, endLexicalEnvironment());
                insertCaptureNewTargetIfNeeded(prologue, node, 
                /*copyOnWrite*/
                false);
                insertCaptureThisForNodeIfNeeded(prologue, node);
                if (some(prologue)) {
                    multiLine = true;
                }
                statements.unshift(...prologue);
                if (isBlock(body) && arrayIsEqualTo(statements, body.statements)) {
                    return body;
                }
                const block = factory2.createBlock(setTextRange(factory2.createNodeArray(statements), statementsLocation), multiLine);
                setTextRange(block, node.body);
                if (!multiLine && singleLine) {
                    setEmitFlags(block, 1 /* SingleLine */);
                }
                if (closeBraceLocation) {
                    setTokenSourceMapRange(block, 19 /* CloseBraceToken */, closeBraceLocation);
                }
                setOriginalNode(block, node.body);
                return block;
            }
            function visitBlock(node, isFunctionBody2) {
                if (isFunctionBody2) {
                    return visitEachChild(node, visitor, context);
                }
                const ancestorFacts = hierarchyFacts & 256 /* IterationStatement */ ? enterSubtree(7104 /* IterationStatementBlockExcludes */, 512 /* IterationStatementBlockIncludes */) : enterSubtree(6976 /* BlockExcludes */, 128 /* BlockIncludes */);
                const updated = visitEachChild(node, visitor, context);
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function visitExpressionStatement(node) {
                return visitEachChild(node, visitorWithUnusedExpressionResult, context);
            }
            function visitParenthesizedExpression(node, expressionResultIsUnused2) {
                return visitEachChild(node, expressionResultIsUnused2 ? visitorWithUnusedExpressionResult : visitor, context);
            }
            function visitBinaryExpression(node, expressionResultIsUnused2) {
                if (isDestructuringAssignment(node)) {
                    return flattenDestructuringAssignment(node, visitor, context, 0 /* All */, !expressionResultIsUnused2);
                }
                if (node.operatorToken.kind === 27 /* CommaToken */) {
                    return factory2.updateBinaryExpression(node, Debug.checkDefined(visitNode(node.left, visitorWithUnusedExpressionResult, isExpression)), node.operatorToken, Debug.checkDefined(visitNode(node.right, expressionResultIsUnused2 ? visitorWithUnusedExpressionResult : visitor, isExpression)));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaListExpression(node, expressionResultIsUnused2) {
                if (expressionResultIsUnused2) {
                    return visitEachChild(node, visitorWithUnusedExpressionResult, context);
                }
                let result;
                for (let i = 0; i < node.elements.length; i++) {
                    const element = node.elements[i];
                    const visited = visitNode(element, i < node.elements.length - 1 ? visitorWithUnusedExpressionResult : visitor, isExpression);
                    if (result || visited !== element) {
                        result || (result = node.elements.slice(0, i));
                        Debug.assert(visited);
                        result.push(visited);
                    }
                }
                const elements = result ? setTextRange(factory2.createNodeArray(result), node.elements) : node.elements;
                return factory2.updateCommaListExpression(node, elements);
            }
            function isVariableStatementOfTypeScriptClassWrapper(node) {
                return node.declarationList.declarations.length === 1 && !!node.declarationList.declarations[0].initializer && !!(getInternalEmitFlags(node.declarationList.declarations[0].initializer) & 1 /* TypeScriptClassWrapper */);
            }
            function visitVariableStatement(node) {
                const ancestorFacts = enterSubtree(0 /* None */, hasSyntacticModifier(node, 1 /* Export */) ? 32 /* ExportedVariableStatement */ : 0 /* None */);
                let updated;
                if (convertedLoopState && (node.declarationList.flags & 3 /* BlockScoped */) === 0 && !isVariableStatementOfTypeScriptClassWrapper(node)) {
                    let assignments;
                    for (const decl of node.declarationList.declarations) {
                        hoistVariableDeclarationDeclaredInConvertedLoop(convertedLoopState, decl);
                        if (decl.initializer) {
                            let assignment;
                            if (isBindingPattern(decl.name)) {
                                assignment = flattenDestructuringAssignment(decl, visitor, context, 0 /* All */);
                            }
                            else {
                                assignment = factory2.createBinaryExpression(decl.name, 63 /* EqualsToken */, Debug.checkDefined(visitNode(decl.initializer, visitor, isExpression)));
                                setTextRange(assignment, decl);
                            }
                            assignments = append(assignments, assignment);
                        }
                    }
                    if (assignments) {
                        updated = setTextRange(factory2.createExpressionStatement(factory2.inlineExpressions(assignments)), node);
                    }
                    else {
                        updated = void 0;
                    }
                }
                else {
                    updated = visitEachChild(node, visitor, context);
                }
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function visitVariableDeclarationList(node) {
                if (node.flags & 3 /* BlockScoped */ || node.transformFlags & 524288 /* ContainsBindingPattern */) {
                    if (node.flags & 3 /* BlockScoped */) {
                        enableSubstitutionsForBlockScopedBindings();
                    }
                    const declarations = visitNodes2(node.declarations, node.flags & 1 /* Let */ ? visitVariableDeclarationInLetDeclarationList : visitVariableDeclaration, isVariableDeclaration);
                    const declarationList = factory2.createVariableDeclarationList(declarations);
                    setOriginalNode(declarationList, node);
                    setTextRange(declarationList, node);
                    setCommentRange(declarationList, node);
                    if (node.transformFlags & 524288 /* ContainsBindingPattern */ && (isBindingPattern(node.declarations[0].name) || isBindingPattern(last(node.declarations).name))) {
                        setSourceMapRange(declarationList, getRangeUnion(declarations));
                    }
                    return declarationList;
                }
                return visitEachChild(node, visitor, context);
            }
            function getRangeUnion(declarations) {
                let pos = -1, end = -1;
                for (const node of declarations) {
                    pos = pos === -1 ? node.pos : node.pos === -1 ? pos : Math.min(pos, node.pos);
                    end = Math.max(end, node.end);
                }
                return createRange(pos, end);
            }
            function shouldEmitExplicitInitializerForLetDeclaration(node) {
                const flags = resolver.getNodeCheckFlags(node);
                const isCapturedInFunction = flags & 16384 /* CapturedBlockScopedBinding */;
                const isDeclaredInLoop = flags & 32768 /* BlockScopedBindingInLoop */;
                const emittedAsTopLevel = (hierarchyFacts & 64 /* TopLevel */) !== 0 || isCapturedInFunction && isDeclaredInLoop && (hierarchyFacts & 512 /* IterationStatementBlock */) !== 0;
                const emitExplicitInitializer = !emittedAsTopLevel && (hierarchyFacts & 4096 /* ForInOrForOfStatement */) === 0 && (!resolver.isDeclarationWithCollidingName(node) || isDeclaredInLoop && !isCapturedInFunction && (hierarchyFacts & (2048 /* ForStatement */ | 4096 /* ForInOrForOfStatement */)) === 0);
                return emitExplicitInitializer;
            }
            function visitVariableDeclarationInLetDeclarationList(node) {
                const name = node.name;
                if (isBindingPattern(name)) {
                    return visitVariableDeclaration(node);
                }
                if (!node.initializer && shouldEmitExplicitInitializerForLetDeclaration(node)) {
                    return factory2.updateVariableDeclaration(node, node.name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createVoidZero());
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableDeclaration(node) {
                const ancestorFacts = enterSubtree(32 /* ExportedVariableStatement */, 0 /* None */);
                let updated;
                if (isBindingPattern(node.name)) {
                    updated = flattenDestructuringBinding(node, visitor, context, 0 /* All */, 
                    /*value*/
                    void 0, (ancestorFacts & 32 /* ExportedVariableStatement */) !== 0);
                }
                else {
                    updated = visitEachChild(node, visitor, context);
                }
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function recordLabel(node) {
                convertedLoopState.labels.set(idText(node.label), true);
            }
            function resetLabel(node) {
                convertedLoopState.labels.set(idText(node.label), false);
            }
            function visitLabeledStatement(node) {
                if (convertedLoopState && !convertedLoopState.labels) {
                    convertedLoopState.labels = /* @__PURE__ */ new Map();
                }
                const statement = unwrapInnermostStatementOfLabel(node, convertedLoopState && recordLabel);
                return isIterationStatement(statement, 
                /*lookInLabeledStatements*/
                false) ? visitIterationStatement(statement, 
                /*outermostLabeledStatement*/
                node) : factory2.restoreEnclosingLabel(Debug.checkDefined(visitNode(statement, visitor, isStatement, factory2.liftToBlock)), node, convertedLoopState && resetLabel);
            }
            function visitIterationStatement(node, outermostLabeledStatement) {
                switch (node.kind) {
                    case 243 /* DoStatement */:
                    case 244 /* WhileStatement */:
                        return visitDoOrWhileStatement(node, outermostLabeledStatement);
                    case 245 /* ForStatement */:
                        return visitForStatement(node, outermostLabeledStatement);
                    case 246 /* ForInStatement */:
                        return visitForInStatement(node, outermostLabeledStatement);
                    case 247 /* ForOfStatement */:
                        return visitForOfStatement(node, outermostLabeledStatement);
                }
            }
            function visitIterationStatementWithFacts(excludeFacts, includeFacts, node, outermostLabeledStatement, convert) {
                const ancestorFacts = enterSubtree(excludeFacts, includeFacts);
                const updated = convertIterationStatementBodyIfNecessary(node, outermostLabeledStatement, ancestorFacts, convert);
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function visitDoOrWhileStatement(node, outermostLabeledStatement) {
                return visitIterationStatementWithFacts(0 /* DoOrWhileStatementExcludes */, 1280 /* DoOrWhileStatementIncludes */, node, outermostLabeledStatement);
            }
            function visitForStatement(node, outermostLabeledStatement) {
                return visitIterationStatementWithFacts(5056 /* ForStatementExcludes */, 3328 /* ForStatementIncludes */, node, outermostLabeledStatement);
            }
            function visitEachChildOfForStatement2(node) {
                return factory2.updateForStatement(node, visitNode(node.initializer, visitorWithUnusedExpressionResult, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, visitorWithUnusedExpressionResult, isExpression), Debug.checkDefined(visitNode(node.statement, visitor, isStatement, factory2.liftToBlock)));
            }
            function visitForInStatement(node, outermostLabeledStatement) {
                return visitIterationStatementWithFacts(3008 /* ForInOrForOfStatementExcludes */, 5376 /* ForInOrForOfStatementIncludes */, node, outermostLabeledStatement);
            }
            function visitForOfStatement(node, outermostLabeledStatement) {
                return visitIterationStatementWithFacts(3008 /* ForInOrForOfStatementExcludes */, 5376 /* ForInOrForOfStatementIncludes */, node, outermostLabeledStatement, compilerOptions.downlevelIteration ? convertForOfStatementForIterable : convertForOfStatementForArray);
            }
            function convertForOfStatementHead(node, boundValue, convertedLoopBodyStatements) {
                const statements = [];
                const initializer = node.initializer;
                if (isVariableDeclarationList(initializer)) {
                    if (node.initializer.flags & 3 /* BlockScoped */) {
                        enableSubstitutionsForBlockScopedBindings();
                    }
                    const firstOriginalDeclaration = firstOrUndefined(initializer.declarations);
                    if (firstOriginalDeclaration && isBindingPattern(firstOriginalDeclaration.name)) {
                        const declarations = flattenDestructuringBinding(firstOriginalDeclaration, visitor, context, 0 /* All */, boundValue);
                        const declarationList = setTextRange(factory2.createVariableDeclarationList(declarations), node.initializer);
                        setOriginalNode(declarationList, node.initializer);
                        setSourceMapRange(declarationList, createRange(declarations[0].pos, last(declarations).end));
                        statements.push(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, declarationList));
                    }
                    else {
                        statements.push(setTextRange(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, setOriginalNode(setTextRange(factory2.createVariableDeclarationList([
                            factory2.createVariableDeclaration(firstOriginalDeclaration ? firstOriginalDeclaration.name : factory2.createTempVariable(
                            /*recordTempVariable*/
                            void 0), 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, boundValue)
                        ]), moveRangePos(initializer, -1)), initializer)), moveRangeEnd(initializer, -1)));
                    }
                }
                else {
                    const assignment = factory2.createAssignment(initializer, boundValue);
                    if (isDestructuringAssignment(assignment)) {
                        statements.push(factory2.createExpressionStatement(visitBinaryExpression(assignment, 
                        /*expressionResultIsUnused*/
                        true)));
                    }
                    else {
                        setTextRangeEnd(assignment, initializer.end);
                        statements.push(setTextRange(factory2.createExpressionStatement(Debug.checkDefined(visitNode(assignment, visitor, isExpression))), moveRangeEnd(initializer, -1)));
                    }
                }
                if (convertedLoopBodyStatements) {
                    return createSyntheticBlockForConvertedStatements(addRange(statements, convertedLoopBodyStatements));
                }
                else {
                    const statement = visitNode(node.statement, visitor, isStatement, factory2.liftToBlock);
                    Debug.assert(statement);
                    if (isBlock(statement)) {
                        return factory2.updateBlock(statement, setTextRange(factory2.createNodeArray(concatenate(statements, statement.statements)), statement.statements));
                    }
                    else {
                        statements.push(statement);
                        return createSyntheticBlockForConvertedStatements(statements);
                    }
                }
            }
            function createSyntheticBlockForConvertedStatements(statements) {
                return setEmitFlags(factory2.createBlock(factory2.createNodeArray(statements), 
                /*multiLine*/
                true), 96 /* NoSourceMap */ | 768 /* NoTokenSourceMaps */);
            }
            function convertForOfStatementForArray(node, outermostLabeledStatement, convertedLoopBodyStatements) {
                const expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                const counter = factory2.createLoopVariable();
                const rhsReference = isIdentifier(expression) ? factory2.getGeneratedNameForNode(expression) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                setEmitFlags(expression, 96 /* NoSourceMap */ | getEmitFlags(expression));
                const forStatement = setTextRange(factory2.createForStatement(
                /*initializer*/
                setEmitFlags(setTextRange(factory2.createVariableDeclarationList([
                    setTextRange(factory2.createVariableDeclaration(counter, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createNumericLiteral(0)), moveRangePos(node.expression, -1)),
                    setTextRange(factory2.createVariableDeclaration(rhsReference, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, expression), node.expression)
                ]), node.expression), 4194304 /* NoHoisting */), 
                /*condition*/
                setTextRange(factory2.createLessThan(counter, factory2.createPropertyAccessExpression(rhsReference, "length")), node.expression), 
                /*incrementor*/
                setTextRange(factory2.createPostfixIncrement(counter), node.expression), 
                /*statement*/
                convertForOfStatementHead(node, factory2.createElementAccessExpression(rhsReference, counter), convertedLoopBodyStatements)), 
                /*location*/
                node);
                setEmitFlags(forStatement, 512 /* NoTokenTrailingSourceMaps */);
                setTextRange(forStatement, node);
                return factory2.restoreEnclosingLabel(forStatement, outermostLabeledStatement, convertedLoopState && resetLabel);
            }
            function convertForOfStatementForIterable(node, outermostLabeledStatement, convertedLoopBodyStatements, ancestorFacts) {
                const expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                const iterator = isIdentifier(expression) ? factory2.getGeneratedNameForNode(expression) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const result = isIdentifier(expression) ? factory2.getGeneratedNameForNode(iterator) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const errorRecord = factory2.createUniqueName("e");
                const catchVariable = factory2.getGeneratedNameForNode(errorRecord);
                const returnMethod = factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const values = setTextRange(emitHelpers().createValuesHelper(expression), node.expression);
                const next = factory2.createCallExpression(factory2.createPropertyAccessExpression(iterator, "next"), 
                /*typeArguments*/
                void 0, []);
                hoistVariableDeclaration(errorRecord);
                hoistVariableDeclaration(returnMethod);
                const initializer = ancestorFacts & 1024 /* IterationContainer */ ? factory2.inlineExpressions([factory2.createAssignment(errorRecord, factory2.createVoidZero()), values]) : values;
                const forStatement = setEmitFlags(setTextRange(factory2.createForStatement(
                /*initializer*/
                setEmitFlags(setTextRange(factory2.createVariableDeclarationList([
                    setTextRange(factory2.createVariableDeclaration(iterator, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer), node.expression),
                    factory2.createVariableDeclaration(result, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, next)
                ]), node.expression), 4194304 /* NoHoisting */), 
                /*condition*/
                factory2.createLogicalNot(factory2.createPropertyAccessExpression(result, "done")), 
                /*incrementor*/
                factory2.createAssignment(result, next), 
                /*statement*/
                convertForOfStatementHead(node, factory2.createPropertyAccessExpression(result, "value"), convertedLoopBodyStatements)), 
                /*location*/
                node), 512 /* NoTokenTrailingSourceMaps */);
                return factory2.createTryStatement(factory2.createBlock([
                    factory2.restoreEnclosingLabel(forStatement, outermostLabeledStatement, convertedLoopState && resetLabel)
                ]), factory2.createCatchClause(factory2.createVariableDeclaration(catchVariable), setEmitFlags(factory2.createBlock([
                    factory2.createExpressionStatement(factory2.createAssignment(errorRecord, factory2.createObjectLiteralExpression([
                        factory2.createPropertyAssignment("error", catchVariable)
                    ])))
                ]), 1 /* SingleLine */)), factory2.createBlock([
                    factory2.createTryStatement(
                    /*tryBlock*/
                    factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(factory2.createLogicalAnd(factory2.createLogicalAnd(result, factory2.createLogicalNot(factory2.createPropertyAccessExpression(result, "done"))), factory2.createAssignment(returnMethod, factory2.createPropertyAccessExpression(iterator, "return"))), factory2.createExpressionStatement(factory2.createFunctionCallCall(returnMethod, iterator, []))), 1 /* SingleLine */)
                    ]), 
                    /*catchClause*/
                    void 0, 
                    /*finallyBlock*/
                    setEmitFlags(factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(errorRecord, factory2.createThrowStatement(factory2.createPropertyAccessExpression(errorRecord, "error"))), 1 /* SingleLine */)
                    ]), 1 /* SingleLine */))
                ]));
            }
            function visitObjectLiteralExpression(node) {
                const properties = node.properties;
                let numInitialProperties = -1, hasComputed = false;
                for (let i = 0; i < properties.length; i++) {
                    const property = properties[i];
                    if (property.transformFlags & 1048576 /* ContainsYield */ && hierarchyFacts & 4 /* AsyncFunctionBody */ || (hasComputed = Debug.checkDefined(property.name).kind === 164 /* ComputedPropertyName */)) {
                        numInitialProperties = i;
                        break;
                    }
                }
                if (numInitialProperties < 0) {
                    return visitEachChild(node, visitor, context);
                }
                const temp = factory2.createTempVariable(hoistVariableDeclaration);
                const expressions = [];
                const assignment = factory2.createAssignment(temp, setEmitFlags(factory2.createObjectLiteralExpression(visitNodes2(properties, visitor, isObjectLiteralElementLike, 0, numInitialProperties), node.multiLine), hasComputed ? 131072 /* Indented */ : 0));
                if (node.multiLine) {
                    startOnNewLine(assignment);
                }
                expressions.push(assignment);
                addObjectLiteralMembers(expressions, node, temp, numInitialProperties);
                expressions.push(node.multiLine ? startOnNewLine(setParent(setTextRange(factory2.cloneNode(temp), temp), temp.parent)) : temp);
                return factory2.inlineExpressions(expressions);
            }
            function shouldConvertPartOfIterationStatement(node) {
                return (resolver.getNodeCheckFlags(node) & 8192 /* ContainsCapturedBlockScopeBinding */) !== 0;
            }
            function shouldConvertInitializerOfForStatement(node) {
                return isForStatement(node) && !!node.initializer && shouldConvertPartOfIterationStatement(node.initializer);
            }
            function shouldConvertConditionOfForStatement(node) {
                return isForStatement(node) && !!node.condition && shouldConvertPartOfIterationStatement(node.condition);
            }
            function shouldConvertIncrementorOfForStatement(node) {
                return isForStatement(node) && !!node.incrementor && shouldConvertPartOfIterationStatement(node.incrementor);
            }
            function shouldConvertIterationStatement(node) {
                return shouldConvertBodyOfIterationStatement(node) || shouldConvertInitializerOfForStatement(node);
            }
            function shouldConvertBodyOfIterationStatement(node) {
                return (resolver.getNodeCheckFlags(node) & 4096 /* LoopWithCapturedBlockScopedBinding */) !== 0;
            }
            function hoistVariableDeclarationDeclaredInConvertedLoop(state, node) {
                if (!state.hoistedLocalVariables) {
                    state.hoistedLocalVariables = [];
                }
                visit(node.name);
                function visit(node2) {
                    if (node2.kind === 79 /* Identifier */) {
                        state.hoistedLocalVariables.push(node2);
                    }
                    else {
                        for (const element of node2.elements) {
                            if (!isOmittedExpression(element)) {
                                visit(element.name);
                            }
                        }
                    }
                }
            }
            function convertIterationStatementBodyIfNecessary(node, outermostLabeledStatement, ancestorFacts, convert) {
                if (!shouldConvertIterationStatement(node)) {
                    let saveAllowedNonLabeledJumps;
                    if (convertedLoopState) {
                        saveAllowedNonLabeledJumps = convertedLoopState.allowedNonLabeledJumps;
                        convertedLoopState.allowedNonLabeledJumps = 2 /* Break */ | 4 /* Continue */;
                    }
                    const result = convert ? convert(node, outermostLabeledStatement, 
                    /*convertedLoopBodyStatements*/
                    void 0, ancestorFacts) : factory2.restoreEnclosingLabel(isForStatement(node) ? visitEachChildOfForStatement2(node) : visitEachChild(node, visitor, context), outermostLabeledStatement, convertedLoopState && resetLabel);
                    if (convertedLoopState) {
                        convertedLoopState.allowedNonLabeledJumps = saveAllowedNonLabeledJumps;
                    }
                    return result;
                }
                const currentState = createConvertedLoopState(node);
                const statements = [];
                const outerConvertedLoopState = convertedLoopState;
                convertedLoopState = currentState;
                const initializerFunction = shouldConvertInitializerOfForStatement(node) ? createFunctionForInitializerOfForStatement(node, currentState) : void 0;
                const bodyFunction = shouldConvertBodyOfIterationStatement(node) ? createFunctionForBodyOfIterationStatement(node, currentState, outerConvertedLoopState) : void 0;
                convertedLoopState = outerConvertedLoopState;
                if (initializerFunction)
                    statements.push(initializerFunction.functionDeclaration);
                if (bodyFunction)
                    statements.push(bodyFunction.functionDeclaration);
                addExtraDeclarationsForConvertedLoop(statements, currentState, outerConvertedLoopState);
                if (initializerFunction) {
                    statements.push(generateCallToConvertedLoopInitializer(initializerFunction.functionName, initializerFunction.containsYield));
                }
                let loop;
                if (bodyFunction) {
                    if (convert) {
                        loop = convert(node, outermostLabeledStatement, bodyFunction.part, ancestorFacts);
                    }
                    else {
                        const clone2 = convertIterationStatementCore(node, initializerFunction, factory2.createBlock(bodyFunction.part, 
                        /*multiLine*/
                        true));
                        loop = factory2.restoreEnclosingLabel(clone2, outermostLabeledStatement, convertedLoopState && resetLabel);
                    }
                }
                else {
                    const clone2 = convertIterationStatementCore(node, initializerFunction, Debug.checkDefined(visitNode(node.statement, visitor, isStatement, factory2.liftToBlock)));
                    loop = factory2.restoreEnclosingLabel(clone2, outermostLabeledStatement, convertedLoopState && resetLabel);
                }
                statements.push(loop);
                return statements;
            }
            function convertIterationStatementCore(node, initializerFunction, convertedLoopBody) {
                switch (node.kind) {
                    case 245 /* ForStatement */:
                        return convertForStatement(node, initializerFunction, convertedLoopBody);
                    case 246 /* ForInStatement */:
                        return convertForInStatement(node, convertedLoopBody);
                    case 247 /* ForOfStatement */:
                        return convertForOfStatement(node, convertedLoopBody);
                    case 243 /* DoStatement */:
                        return convertDoStatement(node, convertedLoopBody);
                    case 244 /* WhileStatement */:
                        return convertWhileStatement(node, convertedLoopBody);
                    default:
                        return Debug.failBadSyntaxKind(node, "IterationStatement expected");
                }
            }
            function convertForStatement(node, initializerFunction, convertedLoopBody) {
                const shouldConvertCondition = node.condition && shouldConvertPartOfIterationStatement(node.condition);
                const shouldConvertIncrementor = shouldConvertCondition || node.incrementor && shouldConvertPartOfIterationStatement(node.incrementor);
                return factory2.updateForStatement(node, visitNode(initializerFunction ? initializerFunction.part : node.initializer, visitorWithUnusedExpressionResult, isForInitializer), visitNode(shouldConvertCondition ? void 0 : node.condition, visitor, isExpression), visitNode(shouldConvertIncrementor ? void 0 : node.incrementor, visitorWithUnusedExpressionResult, isExpression), convertedLoopBody);
            }
            function convertForOfStatement(node, convertedLoopBody) {
                return factory2.updateForOfStatement(node, 
                /*awaitModifier*/
                void 0, Debug.checkDefined(visitNode(node.initializer, visitor, isForInitializer)), Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), convertedLoopBody);
            }
            function convertForInStatement(node, convertedLoopBody) {
                return factory2.updateForInStatement(node, Debug.checkDefined(visitNode(node.initializer, visitor, isForInitializer)), Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), convertedLoopBody);
            }
            function convertDoStatement(node, convertedLoopBody) {
                return factory2.updateDoStatement(node, convertedLoopBody, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
            }
            function convertWhileStatement(node, convertedLoopBody) {
                return factory2.updateWhileStatement(node, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), convertedLoopBody);
            }
            function createConvertedLoopState(node) {
                let loopInitializer;
                switch (node.kind) {
                    case 245 /* ForStatement */:
                    case 246 /* ForInStatement */:
                    case 247 /* ForOfStatement */:
                        const initializer = node.initializer;
                        if (initializer && initializer.kind === 258 /* VariableDeclarationList */) {
                            loopInitializer = initializer;
                        }
                        break;
                }
                const loopParameters = [];
                const loopOutParameters = [];
                if (loopInitializer && getCombinedNodeFlags(loopInitializer) & 3 /* BlockScoped */) {
                    const hasCapturedBindingsInForHead = shouldConvertInitializerOfForStatement(node) || shouldConvertConditionOfForStatement(node) || shouldConvertIncrementorOfForStatement(node);
                    for (const decl of loopInitializer.declarations) {
                        processLoopVariableDeclaration(node, decl, loopParameters, loopOutParameters, hasCapturedBindingsInForHead);
                    }
                }
                const currentState = { loopParameters, loopOutParameters };
                if (convertedLoopState) {
                    if (convertedLoopState.argumentsName) {
                        currentState.argumentsName = convertedLoopState.argumentsName;
                    }
                    if (convertedLoopState.thisName) {
                        currentState.thisName = convertedLoopState.thisName;
                    }
                    if (convertedLoopState.hoistedLocalVariables) {
                        currentState.hoistedLocalVariables = convertedLoopState.hoistedLocalVariables;
                    }
                }
                return currentState;
            }
            function addExtraDeclarationsForConvertedLoop(statements, state, outerState) {
                let extraVariableDeclarations;
                if (state.argumentsName) {
                    if (outerState) {
                        outerState.argumentsName = state.argumentsName;
                    }
                    else {
                        (extraVariableDeclarations || (extraVariableDeclarations = [])).push(factory2.createVariableDeclaration(state.argumentsName, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.createIdentifier("arguments")));
                    }
                }
                if (state.thisName) {
                    if (outerState) {
                        outerState.thisName = state.thisName;
                    }
                    else {
                        (extraVariableDeclarations || (extraVariableDeclarations = [])).push(factory2.createVariableDeclaration(state.thisName, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.createIdentifier("this")));
                    }
                }
                if (state.hoistedLocalVariables) {
                    if (outerState) {
                        outerState.hoistedLocalVariables = state.hoistedLocalVariables;
                    }
                    else {
                        if (!extraVariableDeclarations) {
                            extraVariableDeclarations = [];
                        }
                        for (const identifier of state.hoistedLocalVariables) {
                            extraVariableDeclarations.push(factory2.createVariableDeclaration(identifier));
                        }
                    }
                }
                if (state.loopOutParameters.length) {
                    if (!extraVariableDeclarations) {
                        extraVariableDeclarations = [];
                    }
                    for (const outParam of state.loopOutParameters) {
                        extraVariableDeclarations.push(factory2.createVariableDeclaration(outParam.outParamName));
                    }
                }
                if (state.conditionVariable) {
                    if (!extraVariableDeclarations) {
                        extraVariableDeclarations = [];
                    }
                    extraVariableDeclarations.push(factory2.createVariableDeclaration(state.conditionVariable, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createFalse()));
                }
                if (extraVariableDeclarations) {
                    statements.push(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(extraVariableDeclarations)));
                }
            }
            function createOutVariable(p) {
                return factory2.createVariableDeclaration(p.originalName, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, p.outParamName);
            }
            function createFunctionForInitializerOfForStatement(node, currentState) {
                const functionName = factory2.createUniqueName("_loop_init");
                const containsYield = (node.initializer.transformFlags & 1048576 /* ContainsYield */) !== 0;
                let emitFlags = 0 /* None */;
                if (currentState.containsLexicalThis)
                    emitFlags |= 16 /* CapturesThis */;
                if (containsYield && hierarchyFacts & 4 /* AsyncFunctionBody */)
                    emitFlags |= 524288 /* AsyncFunctionBody */;
                const statements = [];
                statements.push(factory2.createVariableStatement(
                /*modifiers*/
                void 0, node.initializer));
                copyOutParameters(currentState.loopOutParameters, 2 /* Initializer */, 1 /* ToOutParameter */, statements);
                const functionDeclaration = factory2.createVariableStatement(
                /*modifiers*/
                void 0, setEmitFlags(factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(functionName, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, setEmitFlags(factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, containsYield ? factory2.createToken(41 /* AsteriskToken */) : void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, 
                    /*parameters*/
                    void 0, 
                    /*type*/
                    void 0, Debug.checkDefined(visitNode(factory2.createBlock(statements, 
                    /*multiLine*/
                    true), visitor, isBlock))), emitFlags))
                ]), 4194304 /* NoHoisting */));
                const part = factory2.createVariableDeclarationList(map(currentState.loopOutParameters, createOutVariable));
                return { functionName, containsYield, functionDeclaration, part };
            }
            function createFunctionForBodyOfIterationStatement(node, currentState, outerState) {
                const functionName = factory2.createUniqueName("_loop");
                startLexicalEnvironment();
                const statement = visitNode(node.statement, visitor, isStatement, factory2.liftToBlock);
                const lexicalEnvironment = endLexicalEnvironment();
                const statements = [];
                if (shouldConvertConditionOfForStatement(node) || shouldConvertIncrementorOfForStatement(node)) {
                    currentState.conditionVariable = factory2.createUniqueName("inc");
                    if (node.incrementor) {
                        statements.push(factory2.createIfStatement(currentState.conditionVariable, factory2.createExpressionStatement(Debug.checkDefined(visitNode(node.incrementor, visitor, isExpression))), factory2.createExpressionStatement(factory2.createAssignment(currentState.conditionVariable, factory2.createTrue()))));
                    }
                    else {
                        statements.push(factory2.createIfStatement(factory2.createLogicalNot(currentState.conditionVariable), factory2.createExpressionStatement(factory2.createAssignment(currentState.conditionVariable, factory2.createTrue()))));
                    }
                    if (shouldConvertConditionOfForStatement(node)) {
                        statements.push(factory2.createIfStatement(factory2.createPrefixUnaryExpression(53 /* ExclamationToken */, Debug.checkDefined(visitNode(node.condition, visitor, isExpression))), Debug.checkDefined(visitNode(factory2.createBreakStatement(), visitor, isStatement))));
                    }
                }
                Debug.assert(statement);
                if (isBlock(statement)) {
                    addRange(statements, statement.statements);
                }
                else {
                    statements.push(statement);
                }
                copyOutParameters(currentState.loopOutParameters, 1 /* Body */, 1 /* ToOutParameter */, statements);
                insertStatementsAfterStandardPrologue(statements, lexicalEnvironment);
                const loopBody = factory2.createBlock(statements, 
                /*multiLine*/
                true);
                if (isBlock(statement))
                    setOriginalNode(loopBody, statement);
                const containsYield = (node.statement.transformFlags & 1048576 /* ContainsYield */) !== 0;
                let emitFlags = 1048576 /* ReuseTempVariableScope */;
                if (currentState.containsLexicalThis)
                    emitFlags |= 16 /* CapturesThis */;
                if (containsYield && (hierarchyFacts & 4 /* AsyncFunctionBody */) !== 0)
                    emitFlags |= 524288 /* AsyncFunctionBody */;
                const functionDeclaration = factory2.createVariableStatement(
                /*modifiers*/
                void 0, setEmitFlags(factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(functionName, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, setEmitFlags(factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, containsYield ? factory2.createToken(41 /* AsteriskToken */) : void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, currentState.loopParameters, 
                    /*type*/
                    void 0, loopBody), emitFlags))
                ]), 4194304 /* NoHoisting */));
                const part = generateCallToConvertedLoop(functionName, currentState, outerState, containsYield);
                return { functionName, containsYield, functionDeclaration, part };
            }
            function copyOutParameter(outParam, copyDirection) {
                const source = copyDirection === 0 /* ToOriginal */ ? outParam.outParamName : outParam.originalName;
                const target = copyDirection === 0 /* ToOriginal */ ? outParam.originalName : outParam.outParamName;
                return factory2.createBinaryExpression(target, 63 /* EqualsToken */, source);
            }
            function copyOutParameters(outParams, partFlags, copyDirection, statements) {
                for (const outParam of outParams) {
                    if (outParam.flags & partFlags) {
                        statements.push(factory2.createExpressionStatement(copyOutParameter(outParam, copyDirection)));
                    }
                }
            }
            function generateCallToConvertedLoopInitializer(initFunctionExpressionName, containsYield) {
                const call = factory2.createCallExpression(initFunctionExpressionName, 
                /*typeArguments*/
                void 0, []);
                const callResult = containsYield ? factory2.createYieldExpression(factory2.createToken(41 /* AsteriskToken */), setEmitFlags(call, 16777216 /* Iterator */)) : call;
                return factory2.createExpressionStatement(callResult);
            }
            function generateCallToConvertedLoop(loopFunctionExpressionName, state, outerState, containsYield) {
                const statements = [];
                const isSimpleLoop = !(state.nonLocalJumps & ~4 /* Continue */) && !state.labeledNonLocalBreaks && !state.labeledNonLocalContinues;
                const call = factory2.createCallExpression(loopFunctionExpressionName, 
                /*typeArguments*/
                void 0, map(state.loopParameters, (p) => p.name));
                const callResult = containsYield ? factory2.createYieldExpression(factory2.createToken(41 /* AsteriskToken */), setEmitFlags(call, 16777216 /* Iterator */)) : call;
                if (isSimpleLoop) {
                    statements.push(factory2.createExpressionStatement(callResult));
                    copyOutParameters(state.loopOutParameters, 1 /* Body */, 0 /* ToOriginal */, statements);
                }
                else {
                    const loopResultName = factory2.createUniqueName("state");
                    const stateVariable = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([factory2.createVariableDeclaration(loopResultName, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, callResult)]));
                    statements.push(stateVariable);
                    copyOutParameters(state.loopOutParameters, 1 /* Body */, 0 /* ToOriginal */, statements);
                    if (state.nonLocalJumps & 8 /* Return */) {
                        let returnStatement;
                        if (outerState) {
                            outerState.nonLocalJumps |= 8 /* Return */;
                            returnStatement = factory2.createReturnStatement(loopResultName);
                        }
                        else {
                            returnStatement = factory2.createReturnStatement(factory2.createPropertyAccessExpression(loopResultName, "value"));
                        }
                        statements.push(factory2.createIfStatement(factory2.createTypeCheck(loopResultName, "object"), returnStatement));
                    }
                    if (state.nonLocalJumps & 2 /* Break */) {
                        statements.push(factory2.createIfStatement(factory2.createStrictEquality(loopResultName, factory2.createStringLiteral("break")), factory2.createBreakStatement()));
                    }
                    if (state.labeledNonLocalBreaks || state.labeledNonLocalContinues) {
                        const caseClauses = [];
                        processLabeledJumps(state.labeledNonLocalBreaks, 
                        /*isBreak*/
                        true, loopResultName, outerState, caseClauses);
                        processLabeledJumps(state.labeledNonLocalContinues, 
                        /*isBreak*/
                        false, loopResultName, outerState, caseClauses);
                        statements.push(factory2.createSwitchStatement(loopResultName, factory2.createCaseBlock(caseClauses)));
                    }
                }
                return statements;
            }
            function setLabeledJump(state, isBreak, labelText, labelMarker) {
                if (isBreak) {
                    if (!state.labeledNonLocalBreaks) {
                        state.labeledNonLocalBreaks = /* @__PURE__ */ new Map();
                    }
                    state.labeledNonLocalBreaks.set(labelText, labelMarker);
                }
                else {
                    if (!state.labeledNonLocalContinues) {
                        state.labeledNonLocalContinues = /* @__PURE__ */ new Map();
                    }
                    state.labeledNonLocalContinues.set(labelText, labelMarker);
                }
            }
            function processLabeledJumps(table, isBreak, loopResultName, outerLoop, caseClauses) {
                if (!table) {
                    return;
                }
                table.forEach((labelMarker, labelText) => {
                    const statements = [];
                    if (!outerLoop || outerLoop.labels && outerLoop.labels.get(labelText)) {
                        const label = factory2.createIdentifier(labelText);
                        statements.push(isBreak ? factory2.createBreakStatement(label) : factory2.createContinueStatement(label));
                    }
                    else {
                        setLabeledJump(outerLoop, isBreak, labelText, labelMarker);
                        statements.push(factory2.createReturnStatement(loopResultName));
                    }
                    caseClauses.push(factory2.createCaseClause(factory2.createStringLiteral(labelMarker), statements));
                });
            }
            function processLoopVariableDeclaration(container, decl, loopParameters, loopOutParameters, hasCapturedBindingsInForHead) {
                const name = decl.name;
                if (isBindingPattern(name)) {
                    for (const element of name.elements) {
                        if (!isOmittedExpression(element)) {
                            processLoopVariableDeclaration(container, element, loopParameters, loopOutParameters, hasCapturedBindingsInForHead);
                        }
                    }
                }
                else {
                    loopParameters.push(factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, name));
                    const checkFlags = resolver.getNodeCheckFlags(decl);
                    if (checkFlags & 262144 /* NeedsLoopOutParameter */ || hasCapturedBindingsInForHead) {
                        const outParamName = factory2.createUniqueName("out_" + idText(name));
                        let flags = 0 /* None */;
                        if (checkFlags & 262144 /* NeedsLoopOutParameter */) {
                            flags |= 1 /* Body */;
                        }
                        if (isForStatement(container)) {
                            if (container.initializer && resolver.isBindingCapturedByNode(container.initializer, decl)) {
                                flags |= 2 /* Initializer */;
                            }
                            if (container.condition && resolver.isBindingCapturedByNode(container.condition, decl) || container.incrementor && resolver.isBindingCapturedByNode(container.incrementor, decl)) {
                                flags |= 1 /* Body */;
                            }
                        }
                        loopOutParameters.push({ flags, originalName: name, outParamName });
                    }
                }
            }
            function addObjectLiteralMembers(expressions, node, receiver, start) {
                const properties = node.properties;
                const numProperties = properties.length;
                for (let i = start; i < numProperties; i++) {
                    const property = properties[i];
                    switch (property.kind) {
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            const accessors = getAllAccessorDeclarations(node.properties, property);
                            if (property === accessors.firstAccessor) {
                                expressions.push(transformAccessorsToExpression(receiver, accessors, node, !!node.multiLine));
                            }
                            break;
                        case 171 /* MethodDeclaration */:
                            expressions.push(transformObjectLiteralMethodDeclarationToExpression(property, receiver, node, node.multiLine));
                            break;
                        case 299 /* PropertyAssignment */:
                            expressions.push(transformPropertyAssignmentToExpression(property, receiver, node.multiLine));
                            break;
                        case 300 /* ShorthandPropertyAssignment */:
                            expressions.push(transformShorthandPropertyAssignmentToExpression(property, receiver, node.multiLine));
                            break;
                        default:
                            Debug.failBadSyntaxKind(node);
                            break;
                    }
                }
            }
            function transformPropertyAssignmentToExpression(property, receiver, startsOnNewLine) {
                const expression = factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, Debug.checkDefined(visitNode(property.name, visitor, isPropertyName))), Debug.checkDefined(visitNode(property.initializer, visitor, isExpression)));
                setTextRange(expression, property);
                if (startsOnNewLine) {
                    startOnNewLine(expression);
                }
                return expression;
            }
            function transformShorthandPropertyAssignmentToExpression(property, receiver, startsOnNewLine) {
                const expression = factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, Debug.checkDefined(visitNode(property.name, visitor, isPropertyName))), factory2.cloneNode(property.name));
                setTextRange(expression, property);
                if (startsOnNewLine) {
                    startOnNewLine(expression);
                }
                return expression;
            }
            function transformObjectLiteralMethodDeclarationToExpression(method, receiver, container, startsOnNewLine) {
                const expression = factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, Debug.checkDefined(visitNode(method.name, visitor, isPropertyName))), transformFunctionLikeToExpression(method, 
                /*location*/
                method, 
                /*name*/
                void 0, container));
                setTextRange(expression, method);
                if (startsOnNewLine) {
                    startOnNewLine(expression);
                }
                return expression;
            }
            function visitCatchClause(node) {
                const ancestorFacts = enterSubtree(7104 /* BlockScopeExcludes */, 0 /* BlockScopeIncludes */);
                let updated;
                Debug.assert(!!node.variableDeclaration, "Catch clause variable should always be present when downleveling ES2015.");
                if (isBindingPattern(node.variableDeclaration.name)) {
                    const temp = factory2.createTempVariable(
                    /*recordTempVariable*/
                    void 0);
                    const newVariableDeclaration = factory2.createVariableDeclaration(temp);
                    setTextRange(newVariableDeclaration, node.variableDeclaration);
                    const vars = flattenDestructuringBinding(node.variableDeclaration, visitor, context, 0 /* All */, temp);
                    const list = factory2.createVariableDeclarationList(vars);
                    setTextRange(list, node.variableDeclaration);
                    const destructure = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, list);
                    updated = factory2.updateCatchClause(node, newVariableDeclaration, addStatementToStartOfBlock(node.block, destructure));
                }
                else {
                    updated = visitEachChild(node, visitor, context);
                }
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function addStatementToStartOfBlock(block, statement) {
                const transformedStatements = visitNodes2(block.statements, visitor, isStatement);
                return factory2.updateBlock(block, [statement, ...transformedStatements]);
            }
            function visitMethodDeclaration(node) {
                Debug.assert(!isComputedPropertyName(node.name));
                const functionExpression = transformFunctionLikeToExpression(node, 
                /*location*/
                moveRangePos(node, -1), 
                /*name*/
                void 0, 
                /*container*/
                void 0);
                setEmitFlags(functionExpression, 1024 /* NoLeadingComments */ | getEmitFlags(functionExpression));
                return setTextRange(factory2.createPropertyAssignment(node.name, functionExpression), 
                /*location*/
                node);
            }
            function visitAccessorDeclaration(node) {
                Debug.assert(!isComputedPropertyName(node.name));
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */);
                let updated;
                const parameters = visitParameterList(node.parameters, visitor, context);
                const body = transformFunctionBody2(node);
                if (node.kind === 174 /* GetAccessor */) {
                    updated = factory2.updateGetAccessorDeclaration(node, node.modifiers, node.name, parameters, node.type, body);
                }
                else {
                    updated = factory2.updateSetAccessorDeclaration(node, node.modifiers, node.name, parameters, body);
                }
                exitSubtree(ancestorFacts, 98304 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return updated;
            }
            function visitShorthandPropertyAssignment(node) {
                return setTextRange(factory2.createPropertyAssignment(node.name, visitIdentifier(factory2.cloneNode(node.name))), 
                /*location*/
                node);
            }
            function visitComputedPropertyName(node) {
                return visitEachChild(node, visitor, context);
            }
            function visitYieldExpression(node) {
                return visitEachChild(node, visitor, context);
            }
            function visitArrayLiteralExpression(node) {
                if (some(node.elements, isSpreadElement)) {
                    return transformAndSpreadElements(node.elements, 
                    /*isArgumentList*/
                    false, !!node.multiLine, 
                    /*hasTrailingComma*/
                    !!node.elements.hasTrailingComma);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCallExpression(node) {
                if (getInternalEmitFlags(node) & 1 /* TypeScriptClassWrapper */) {
                    return visitTypeScriptClassWrapper(node);
                }
                const expression = skipOuterExpressions(node.expression);
                if (expression.kind === 106 /* SuperKeyword */ || isSuperProperty(expression) || some(node.arguments, isSpreadElement)) {
                    return visitCallExpressionWithPotentialCapturedThisAssignment(node, 
                    /*assignToCapturedThis*/
                    true);
                }
                return factory2.updateCallExpression(node, Debug.checkDefined(visitNode(node.expression, callExpressionVisitor, isExpression)), 
                /*typeArguments*/
                void 0, visitNodes2(node.arguments, visitor, isExpression));
            }
            function visitTypeScriptClassWrapper(node) {
                const body = cast(cast(skipOuterExpressions(node.expression), isArrowFunction).body, isBlock);
                const isVariableStatementWithInitializer = (stmt) => isVariableStatement(stmt) && !!first(stmt.declarationList.declarations).initializer;
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const bodyStatements = visitNodes2(body.statements, classWrapperStatementVisitor, isStatement);
                convertedLoopState = savedConvertedLoopState;
                const classStatements = filter(bodyStatements, isVariableStatementWithInitializer);
                const remainingStatements = filter(bodyStatements, (stmt) => !isVariableStatementWithInitializer(stmt));
                const varStatement = cast(first(classStatements), isVariableStatement);
                const variable = varStatement.declarationList.declarations[0];
                const initializer = skipOuterExpressions(variable.initializer);
                let aliasAssignment = tryCast(initializer, isAssignmentExpression);
                if (!aliasAssignment && isBinaryExpression(initializer) && initializer.operatorToken.kind === 27 /* CommaToken */) {
                    aliasAssignment = tryCast(initializer.left, isAssignmentExpression);
                }
                const call = cast(aliasAssignment ? skipOuterExpressions(aliasAssignment.right) : initializer, isCallExpression);
                const func = cast(skipOuterExpressions(call.expression), isFunctionExpression);
                const funcStatements = func.body.statements;
                let classBodyStart = 0;
                let classBodyEnd = -1;
                const statements = [];
                if (aliasAssignment) {
                    const extendsCall = tryCast(funcStatements[classBodyStart], isExpressionStatement);
                    if (extendsCall) {
                        statements.push(extendsCall);
                        classBodyStart++;
                    }
                    statements.push(funcStatements[classBodyStart]);
                    classBodyStart++;
                    statements.push(factory2.createExpressionStatement(factory2.createAssignment(aliasAssignment.left, cast(variable.name, isIdentifier))));
                }
                while (!isReturnStatement(elementAt(funcStatements, classBodyEnd))) {
                    classBodyEnd--;
                }
                addRange(statements, funcStatements, classBodyStart, classBodyEnd);
                if (classBodyEnd < -1) {
                    addRange(statements, funcStatements, classBodyEnd + 1);
                }
                const returnStatement = tryCast(elementAt(funcStatements, classBodyEnd), isReturnStatement);
                for (const statement of remainingStatements) {
                    if (isReturnStatement(statement) && (returnStatement == null ? void 0 : returnStatement.expression) && !isIdentifier(returnStatement.expression)) {
                        statements.push(returnStatement);
                    }
                    else {
                        statements.push(statement);
                    }
                }
                addRange(statements, classStatements, 
                /*start*/
                1);
                return factory2.restoreOuterExpressions(node.expression, factory2.restoreOuterExpressions(variable.initializer, factory2.restoreOuterExpressions(aliasAssignment && aliasAssignment.right, factory2.updateCallExpression(call, factory2.restoreOuterExpressions(call.expression, factory2.updateFunctionExpression(func, 
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, func.parameters, 
                /*type*/
                void 0, factory2.updateBlock(func.body, statements))), 
                /*typeArguments*/
                void 0, call.arguments))));
            }
            function visitSuperCallInBody(node) {
                return visitCallExpressionWithPotentialCapturedThisAssignment(node, 
                /*assignToCapturedThis*/
                false);
            }
            function visitCallExpressionWithPotentialCapturedThisAssignment(node, assignToCapturedThis) {
                if (node.transformFlags & 32768 /* ContainsRestOrSpread */ || node.expression.kind === 106 /* SuperKeyword */ || isSuperProperty(skipOuterExpressions(node.expression))) {
                    const { target, thisArg } = factory2.createCallBinding(node.expression, hoistVariableDeclaration);
                    if (node.expression.kind === 106 /* SuperKeyword */) {
                        setEmitFlags(thisArg, 8 /* NoSubstitution */);
                    }
                    let resultingCall;
                    if (node.transformFlags & 32768 /* ContainsRestOrSpread */) {
                        resultingCall = factory2.createFunctionApplyCall(Debug.checkDefined(visitNode(target, callExpressionVisitor, isExpression)), node.expression.kind === 106 /* SuperKeyword */ ? thisArg : Debug.checkDefined(visitNode(thisArg, visitor, isExpression)), transformAndSpreadElements(node.arguments, 
                        /*isArgumentList*/
                        true, 
                        /*multiLine*/
                        false, 
                        /*hasTrailingComma*/
                        false));
                    }
                    else {
                        resultingCall = setTextRange(factory2.createFunctionCallCall(Debug.checkDefined(visitNode(target, callExpressionVisitor, isExpression)), node.expression.kind === 106 /* SuperKeyword */ ? thisArg : Debug.checkDefined(visitNode(thisArg, visitor, isExpression)), visitNodes2(node.arguments, visitor, isExpression)), node);
                    }
                    if (node.expression.kind === 106 /* SuperKeyword */) {
                        const initializer = factory2.createLogicalOr(resultingCall, createActualThis());
                        resultingCall = assignToCapturedThis ? factory2.createAssignment(factory2.createUniqueName("_this", 16 /* Optimistic */ | 32 /* FileLevel */), initializer) : initializer;
                    }
                    return setOriginalNode(resultingCall, node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitNewExpression(node) {
                if (some(node.arguments, isSpreadElement)) {
                    const { target, thisArg } = factory2.createCallBinding(factory2.createPropertyAccessExpression(node.expression, "bind"), hoistVariableDeclaration);
                    return factory2.createNewExpression(factory2.createFunctionApplyCall(Debug.checkDefined(visitNode(target, visitor, isExpression)), thisArg, transformAndSpreadElements(factory2.createNodeArray([factory2.createVoidZero(), ...node.arguments]), 
                    /*isArgumentList*/
                    true, 
                    /*multiLine*/
                    false, 
                    /*hasTrailingComma*/
                    false)), 
                    /*typeArguments*/
                    void 0, []);
                }
                return visitEachChild(node, visitor, context);
            }
            function transformAndSpreadElements(elements, isArgumentList, multiLine, hasTrailingComma) {
                const numElements = elements.length;
                const segments = flatten(
                // As we visit each element, we return one of two functions to use as the "key":
                // - `visitSpanOfSpreads` for one or more contiguous `...` spread expressions, i.e. `...a, ...b` in `[1, 2, ...a, ...b]`
                // - `visitSpanOfNonSpreads` for one or more contiguous non-spread elements, i.e. `1, 2`, in `[1, 2, ...a, ...b]`
                spanMap(elements, partitionSpread, (partition, visitPartition, _start, end) => visitPartition(partition, multiLine, hasTrailingComma && end === numElements)));
                if (segments.length === 1) {
                    const firstSegment = segments[0];
                    if (isArgumentList && !compilerOptions.downlevelIteration || isPackedArrayLiteral(firstSegment.expression) || isCallToHelper(firstSegment.expression, "___spreadArray")) {
                        return firstSegment.expression;
                    }
                }
                const helpers = emitHelpers();
                const startsWithSpread = segments[0].kind !== 0 /* None */;
                let expression = startsWithSpread ? factory2.createArrayLiteralExpression() : segments[0].expression;
                for (let i = startsWithSpread ? 0 : 1; i < segments.length; i++) {
                    const segment = segments[i];
                    expression = helpers.createSpreadArrayHelper(expression, segment.expression, segment.kind === 1 /* UnpackedSpread */ && !isArgumentList);
                }
                return expression;
            }
            function partitionSpread(node) {
                return isSpreadElement(node) ? visitSpanOfSpreads : visitSpanOfNonSpreads;
            }
            function visitSpanOfSpreads(chunk) {
                return map(chunk, visitExpressionOfSpread);
            }
            function visitExpressionOfSpread(node) {
                Debug.assertNode(node, isSpreadElement);
                let expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                const isCallToReadHelper = isCallToHelper(expression, "___read");
                let kind = isCallToReadHelper || isPackedArrayLiteral(expression) ? 2 /* PackedSpread */ : 1 /* UnpackedSpread */;
                if (compilerOptions.downlevelIteration && kind === 1 /* UnpackedSpread */ && !isArrayLiteralExpression(expression) && !isCallToReadHelper) {
                    expression = emitHelpers().createReadHelper(expression, 
                    /*count*/
                    void 0);
                    kind = 2 /* PackedSpread */;
                }
                return createSpreadSegment(kind, expression);
            }
            function visitSpanOfNonSpreads(chunk, multiLine, hasTrailingComma) {
                const expression = factory2.createArrayLiteralExpression(visitNodes2(factory2.createNodeArray(chunk, hasTrailingComma), visitor, isExpression), multiLine);
                return createSpreadSegment(0 /* None */, expression);
            }
            function visitSpreadElement(node) {
                return visitNode(node.expression, visitor, isExpression);
            }
            function visitTemplateLiteral(node) {
                return setTextRange(factory2.createStringLiteral(node.text), node);
            }
            function visitStringLiteral(node) {
                if (node.hasExtendedUnicodeEscape) {
                    return setTextRange(factory2.createStringLiteral(node.text), node);
                }
                return node;
            }
            function visitNumericLiteral(node) {
                if (node.numericLiteralFlags & 384 /* BinaryOrOctalSpecifier */) {
                    return setTextRange(factory2.createNumericLiteral(node.text), node);
                }
                return node;
            }
            function visitTaggedTemplateExpression(node) {
                return processTaggedTemplateExpression(context, node, visitor, currentSourceFile, recordTaggedTemplateString, 1 /* All */);
            }
            function visitTemplateExpression(node) {
                let expression = factory2.createStringLiteral(node.head.text);
                for (const span of node.templateSpans) {
                    const args = [Debug.checkDefined(visitNode(span.expression, visitor, isExpression))];
                    if (span.literal.text.length > 0) {
                        args.push(factory2.createStringLiteral(span.literal.text));
                    }
                    expression = factory2.createCallExpression(factory2.createPropertyAccessExpression(expression, "concat"), 
                    /*typeArguments*/
                    void 0, args);
                }
                return setTextRange(expression, node);
            }
            function visitSuperKeyword(isExpressionOfCall) {
                return hierarchyFacts & 8 /* NonStaticClassElement */ && !isExpressionOfCall ? factory2.createPropertyAccessExpression(factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */), "prototype") : factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */);
            }
            function visitMetaProperty(node) {
                if (node.keywordToken === 103 /* NewKeyword */ && node.name.escapedText === "target") {
                    hierarchyFacts |= 32768 /* NewTarget */;
                    return factory2.createUniqueName("_newTarget", 16 /* Optimistic */ | 32 /* FileLevel */);
                }
                return node;
            }
            function onEmitNode(hint, node, emitCallback) {
                if (enabledSubstitutions & 1 /* CapturedThis */ && isFunctionLike(node)) {
                    const ancestorFacts = enterSubtree(32670 /* FunctionExcludes */, getEmitFlags(node) & 16 /* CapturesThis */ ? 65 /* FunctionIncludes */ | 16 /* CapturesThis */ : 65 /* FunctionIncludes */);
                    previousOnEmitNode(hint, node, emitCallback);
                    exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                    return;
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function enableSubstitutionsForBlockScopedBindings() {
                if ((enabledSubstitutions & 2 /* BlockScopedBindings */) === 0) {
                    enabledSubstitutions |= 2 /* BlockScopedBindings */;
                    context.enableSubstitution(79 /* Identifier */);
                }
            }
            function enableSubstitutionsForCapturedThis() {
                if ((enabledSubstitutions & 1 /* CapturedThis */) === 0) {
                    enabledSubstitutions |= 1 /* CapturedThis */;
                    context.enableSubstitution(108 /* ThisKeyword */);
                    context.enableEmitNotification(173 /* Constructor */);
                    context.enableEmitNotification(171 /* MethodDeclaration */);
                    context.enableEmitNotification(174 /* GetAccessor */);
                    context.enableEmitNotification(175 /* SetAccessor */);
                    context.enableEmitNotification(216 /* ArrowFunction */);
                    context.enableEmitNotification(215 /* FunctionExpression */);
                    context.enableEmitNotification(259 /* FunctionDeclaration */);
                }
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                if (isIdentifier(node)) {
                    return substituteIdentifier(node);
                }
                return node;
            }
            function substituteIdentifier(node) {
                if (enabledSubstitutions & 2 /* BlockScopedBindings */ && !isInternalName(node)) {
                    const original = getParseTreeNode(node, isIdentifier);
                    if (original && isNameOfDeclarationWithCollidingName(original)) {
                        return setTextRange(factory2.getGeneratedNameForNode(original), node);
                    }
                }
                return node;
            }
            function isNameOfDeclarationWithCollidingName(node) {
                switch (node.parent.kind) {
                    case 205 /* BindingElement */:
                    case 260 /* ClassDeclaration */:
                    case 263 /* EnumDeclaration */:
                    case 257 /* VariableDeclaration */:
                        return node.parent.name === node && resolver.isDeclarationWithCollidingName(node.parent);
                }
                return false;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 108 /* ThisKeyword */:
                        return substituteThisKeyword(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                if (enabledSubstitutions & 2 /* BlockScopedBindings */ && !isInternalName(node)) {
                    const declaration = resolver.getReferencedDeclarationWithCollidingName(node);
                    if (declaration && !(isClassLike(declaration) && isPartOfClassBody(declaration, node))) {
                        return setTextRange(factory2.getGeneratedNameForNode(getNameOfDeclaration(declaration)), node);
                    }
                }
                return node;
            }
            function isPartOfClassBody(declaration, node) {
                let currentNode = getParseTreeNode(node);
                if (!currentNode || currentNode === declaration || currentNode.end <= declaration.pos || currentNode.pos >= declaration.end) {
                    return false;
                }
                const blockScope = getEnclosingBlockScopeContainer(declaration);
                while (currentNode) {
                    if (currentNode === blockScope || currentNode === declaration) {
                        return false;
                    }
                    if (isClassElement(currentNode) && currentNode.parent === declaration) {
                        return true;
                    }
                    currentNode = currentNode.parent;
                }
                return false;
            }
            function substituteThisKeyword(node) {
                if (enabledSubstitutions & 1 /* CapturedThis */ && hierarchyFacts & 16 /* CapturesThis */) {
                    return setTextRange(factory2.createUniqueName("_this", 16 /* Optimistic */ | 32 /* FileLevel */), node);
                }
                return node;
            }
            function getClassMemberPrefix(node, member) {
                return isStatic(member) ? factory2.getInternalName(node) : factory2.createPropertyAccessExpression(factory2.getInternalName(node), "prototype");
            }
            function hasSynthesizedDefaultSuperCall(constructor, hasExtendsClause) {
                if (!constructor || !hasExtendsClause) {
                    return false;
                }
                if (some(constructor.parameters)) {
                    return false;
                }
                const statement = firstOrUndefined(constructor.body.statements);
                if (!statement || !nodeIsSynthesized(statement) || statement.kind !== 241 /* ExpressionStatement */) {
                    return false;
                }
                const statementExpression = statement.expression;
                if (!nodeIsSynthesized(statementExpression) || statementExpression.kind !== 210 /* CallExpression */) {
                    return false;
                }
                const callTarget = statementExpression.expression;
                if (!nodeIsSynthesized(callTarget) || callTarget.kind !== 106 /* SuperKeyword */) {
                    return false;
                }
                const callArgument = singleOrUndefined(statementExpression.arguments);
                if (!callArgument || !nodeIsSynthesized(callArgument) || callArgument.kind !== 227 /* SpreadElement */) {
                    return false;
                }
                const expression = callArgument.expression;
                return isIdentifier(expression) && expression.escapedText === "arguments";
            }
        }
        var init_es2015 = __esm({
            "src/compiler/transformers/es2015.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es5.ts
        function transformES5(context) {
            const { factory: factory2 } = context;
            const compilerOptions = context.getCompilerOptions();
            let previousOnEmitNode;
            let noSubstitution;
            if (compilerOptions.jsx === 1 /* Preserve */ || compilerOptions.jsx === 3 /* ReactNative */) {
                previousOnEmitNode = context.onEmitNode;
                context.onEmitNode = onEmitNode;
                context.enableEmitNotification(283 /* JsxOpeningElement */);
                context.enableEmitNotification(284 /* JsxClosingElement */);
                context.enableEmitNotification(282 /* JsxSelfClosingElement */);
                noSubstitution = [];
            }
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            context.enableSubstitution(208 /* PropertyAccessExpression */);
            context.enableSubstitution(299 /* PropertyAssignment */);
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                return node;
            }
            function onEmitNode(hint, node, emitCallback) {
                switch (node.kind) {
                    case 283 /* JsxOpeningElement */:
                    case 284 /* JsxClosingElement */:
                    case 282 /* JsxSelfClosingElement */:
                        const tagName = node.tagName;
                        noSubstitution[getOriginalNodeId(tagName)] = true;
                        break;
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function onSubstituteNode(hint, node) {
                if (node.id && noSubstitution && noSubstitution[node.id]) {
                    return previousOnSubstituteNode(hint, node);
                }
                node = previousOnSubstituteNode(hint, node);
                if (isPropertyAccessExpression(node)) {
                    return substitutePropertyAccessExpression(node);
                }
                else if (isPropertyAssignment(node)) {
                    return substitutePropertyAssignment(node);
                }
                return node;
            }
            function substitutePropertyAccessExpression(node) {
                if (isPrivateIdentifier(node.name)) {
                    return node;
                }
                const literalName = trySubstituteReservedName(node.name);
                if (literalName) {
                    return setTextRange(factory2.createElementAccessExpression(node.expression, literalName), node);
                }
                return node;
            }
            function substitutePropertyAssignment(node) {
                const literalName = isIdentifier(node.name) && trySubstituteReservedName(node.name);
                if (literalName) {
                    return factory2.updatePropertyAssignment(node, literalName, node.initializer);
                }
                return node;
            }
            function trySubstituteReservedName(name) {
                const token = identifierToKeywordKind(name);
                if (token !== void 0 && token >= 81 /* FirstReservedWord */ && token <= 116 /* LastReservedWord */) {
                    return setTextRange(factory2.createStringLiteralFromNode(name), name);
                }
                return void 0;
            }
        }
        var init_es5 = __esm({
            "src/compiler/transformers/es5.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/generators.ts
        function getInstructionName(instruction) {
            switch (instruction) {
                case 2 /* Return */:
                    return "return";
                case 3 /* Break */:
                    return "break";
                case 4 /* Yield */:
                    return "yield";
                case 5 /* YieldStar */:
                    return "yield*";
                case 7 /* Endfinally */:
                    return "endfinally";
                default:
                    return void 0;
            }
        }
        function transformGenerators(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, resumeLexicalEnvironment, endLexicalEnvironment, hoistFunctionDeclaration, hoistVariableDeclaration } = context;
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const resolver = context.getEmitResolver();
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            let renamedCatchVariables;
            let renamedCatchVariableDeclarations;
            let inGeneratorFunctionBody;
            let inStatementContainingYield;
            let blocks;
            let blockOffsets;
            let blockActions;
            let blockStack;
            let labelOffsets;
            let labelExpressions;
            let nextLabelId = 1;
            let operations;
            let operationArguments;
            let operationLocations;
            let state;
            let blockIndex = 0;
            let labelNumber = 0;
            let labelNumbers;
            let lastOperationWasAbrupt;
            let lastOperationWasCompletion;
            let clauses;
            let statements;
            let exceptionBlockStack;
            let currentExceptionBlock;
            let withBlockStack;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile || (node.transformFlags & 2048 /* ContainsGenerator */) === 0) {
                    return node;
                }
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                return visited;
            }
            function visitor(node) {
                const transformFlags = node.transformFlags;
                if (inStatementContainingYield) {
                    return visitJavaScriptInStatementContainingYield(node);
                }
                else if (inGeneratorFunctionBody) {
                    return visitJavaScriptInGeneratorFunctionBody(node);
                }
                else if (isFunctionLikeDeclaration(node) && node.asteriskToken) {
                    return visitGenerator(node);
                }
                else if (transformFlags & 2048 /* ContainsGenerator */) {
                    return visitEachChild(node, visitor, context);
                }
                else {
                    return node;
                }
            }
            function visitJavaScriptInStatementContainingYield(node) {
                switch (node.kind) {
                    case 243 /* DoStatement */:
                        return visitDoStatement(node);
                    case 244 /* WhileStatement */:
                        return visitWhileStatement(node);
                    case 252 /* SwitchStatement */:
                        return visitSwitchStatement(node);
                    case 253 /* LabeledStatement */:
                        return visitLabeledStatement(node);
                    default:
                        return visitJavaScriptInGeneratorFunctionBody(node);
                }
            }
            function visitJavaScriptInGeneratorFunctionBody(node) {
                switch (node.kind) {
                    case 259 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 215 /* FunctionExpression */:
                        return visitFunctionExpression(node);
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        return visitAccessorDeclaration(node);
                    case 240 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 245 /* ForStatement */:
                        return visitForStatement(node);
                    case 246 /* ForInStatement */:
                        return visitForInStatement(node);
                    case 249 /* BreakStatement */:
                        return visitBreakStatement(node);
                    case 248 /* ContinueStatement */:
                        return visitContinueStatement(node);
                    case 250 /* ReturnStatement */:
                        return visitReturnStatement(node);
                    default:
                        if (node.transformFlags & 1048576 /* ContainsYield */) {
                            return visitJavaScriptContainingYield(node);
                        }
                        else if (node.transformFlags & (2048 /* ContainsGenerator */ | 4194304 /* ContainsHoistedDeclarationOrCompletion */)) {
                            return visitEachChild(node, visitor, context);
                        }
                        else {
                            return node;
                        }
                }
            }
            function visitJavaScriptContainingYield(node) {
                switch (node.kind) {
                    case 223 /* BinaryExpression */:
                        return visitBinaryExpression(node);
                    case 357 /* CommaListExpression */:
                        return visitCommaListExpression(node);
                    case 224 /* ConditionalExpression */:
                        return visitConditionalExpression(node);
                    case 226 /* YieldExpression */:
                        return visitYieldExpression(node);
                    case 206 /* ArrayLiteralExpression */:
                        return visitArrayLiteralExpression(node);
                    case 207 /* ObjectLiteralExpression */:
                        return visitObjectLiteralExpression(node);
                    case 209 /* ElementAccessExpression */:
                        return visitElementAccessExpression(node);
                    case 210 /* CallExpression */:
                        return visitCallExpression(node);
                    case 211 /* NewExpression */:
                        return visitNewExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitGenerator(node) {
                switch (node.kind) {
                    case 259 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 215 /* FunctionExpression */:
                        return visitFunctionExpression(node);
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function visitFunctionDeclaration(node) {
                if (node.asteriskToken) {
                    node = setOriginalNode(setTextRange(factory2.createFunctionDeclaration(node.modifiers, 
                    /*asteriskToken*/
                    void 0, node.name, 
                    /*typeParameters*/
                    void 0, visitParameterList(node.parameters, visitor, context), 
                    /*type*/
                    void 0, transformGeneratorFunctionBody(node.body)), 
                    /*location*/
                    node), node);
                }
                else {
                    const savedInGeneratorFunctionBody = inGeneratorFunctionBody;
                    const savedInStatementContainingYield = inStatementContainingYield;
                    inGeneratorFunctionBody = false;
                    inStatementContainingYield = false;
                    node = visitEachChild(node, visitor, context);
                    inGeneratorFunctionBody = savedInGeneratorFunctionBody;
                    inStatementContainingYield = savedInStatementContainingYield;
                }
                if (inGeneratorFunctionBody) {
                    hoistFunctionDeclaration(node);
                    return void 0;
                }
                else {
                    return node;
                }
            }
            function visitFunctionExpression(node) {
                if (node.asteriskToken) {
                    node = setOriginalNode(setTextRange(factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, node.name, 
                    /*typeParameters*/
                    void 0, visitParameterList(node.parameters, visitor, context), 
                    /*type*/
                    void 0, transformGeneratorFunctionBody(node.body)), 
                    /*location*/
                    node), node);
                }
                else {
                    const savedInGeneratorFunctionBody = inGeneratorFunctionBody;
                    const savedInStatementContainingYield = inStatementContainingYield;
                    inGeneratorFunctionBody = false;
                    inStatementContainingYield = false;
                    node = visitEachChild(node, visitor, context);
                    inGeneratorFunctionBody = savedInGeneratorFunctionBody;
                    inStatementContainingYield = savedInStatementContainingYield;
                }
                return node;
            }
            function visitAccessorDeclaration(node) {
                const savedInGeneratorFunctionBody = inGeneratorFunctionBody;
                const savedInStatementContainingYield = inStatementContainingYield;
                inGeneratorFunctionBody = false;
                inStatementContainingYield = false;
                node = visitEachChild(node, visitor, context);
                inGeneratorFunctionBody = savedInGeneratorFunctionBody;
                inStatementContainingYield = savedInStatementContainingYield;
                return node;
            }
            function transformGeneratorFunctionBody(body) {
                const statements2 = [];
                const savedInGeneratorFunctionBody = inGeneratorFunctionBody;
                const savedInStatementContainingYield = inStatementContainingYield;
                const savedBlocks = blocks;
                const savedBlockOffsets = blockOffsets;
                const savedBlockActions = blockActions;
                const savedBlockStack = blockStack;
                const savedLabelOffsets = labelOffsets;
                const savedLabelExpressions = labelExpressions;
                const savedNextLabelId = nextLabelId;
                const savedOperations = operations;
                const savedOperationArguments = operationArguments;
                const savedOperationLocations = operationLocations;
                const savedState = state;
                inGeneratorFunctionBody = true;
                inStatementContainingYield = false;
                blocks = void 0;
                blockOffsets = void 0;
                blockActions = void 0;
                blockStack = void 0;
                labelOffsets = void 0;
                labelExpressions = void 0;
                nextLabelId = 1;
                operations = void 0;
                operationArguments = void 0;
                operationLocations = void 0;
                state = factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                resumeLexicalEnvironment();
                const statementOffset = factory2.copyPrologue(body.statements, statements2, 
                /*ensureUseStrict*/
                false, visitor);
                transformAndEmitStatements(body.statements, statementOffset);
                const buildResult = build2();
                insertStatementsAfterStandardPrologue(statements2, endLexicalEnvironment());
                statements2.push(factory2.createReturnStatement(buildResult));
                inGeneratorFunctionBody = savedInGeneratorFunctionBody;
                inStatementContainingYield = savedInStatementContainingYield;
                blocks = savedBlocks;
                blockOffsets = savedBlockOffsets;
                blockActions = savedBlockActions;
                blockStack = savedBlockStack;
                labelOffsets = savedLabelOffsets;
                labelExpressions = savedLabelExpressions;
                nextLabelId = savedNextLabelId;
                operations = savedOperations;
                operationArguments = savedOperationArguments;
                operationLocations = savedOperationLocations;
                state = savedState;
                return setTextRange(factory2.createBlock(statements2, body.multiLine), body);
            }
            function visitVariableStatement(node) {
                if (node.transformFlags & 1048576 /* ContainsYield */) {
                    transformAndEmitVariableDeclarationList(node.declarationList);
                    return void 0;
                }
                else {
                    if (getEmitFlags(node) & 2097152 /* CustomPrologue */) {
                        return node;
                    }
                    for (const variable of node.declarationList.declarations) {
                        hoistVariableDeclaration(variable.name);
                    }
                    const variables = getInitializedVariables(node.declarationList);
                    if (variables.length === 0) {
                        return void 0;
                    }
                    return setSourceMapRange(factory2.createExpressionStatement(factory2.inlineExpressions(map(variables, transformInitializedVariable))), node);
                }
            }
            function visitBinaryExpression(node) {
                const assoc = getExpressionAssociativity(node);
                switch (assoc) {
                    case 0 /* Left */:
                        return visitLeftAssociativeBinaryExpression(node);
                    case 1 /* Right */:
                        return visitRightAssociativeBinaryExpression(node);
                    default:
                        return Debug.assertNever(assoc);
                }
            }
            function visitRightAssociativeBinaryExpression(node) {
                const { left, right } = node;
                if (containsYield(right)) {
                    let target;
                    switch (left.kind) {
                        case 208 /* PropertyAccessExpression */:
                            target = factory2.updatePropertyAccessExpression(left, cacheExpression(Debug.checkDefined(visitNode(left.expression, visitor, isLeftHandSideExpression))), left.name);
                            break;
                        case 209 /* ElementAccessExpression */:
                            target = factory2.updateElementAccessExpression(left, cacheExpression(Debug.checkDefined(visitNode(left.expression, visitor, isLeftHandSideExpression))), cacheExpression(Debug.checkDefined(visitNode(left.argumentExpression, visitor, isExpression))));
                            break;
                        default:
                            target = Debug.checkDefined(visitNode(left, visitor, isExpression));
                            break;
                    }
                    const operator = node.operatorToken.kind;
                    if (isCompoundAssignment(operator)) {
                        return setTextRange(factory2.createAssignment(target, setTextRange(factory2.createBinaryExpression(cacheExpression(target), getNonAssignmentOperatorForCompoundAssignment(operator), Debug.checkDefined(visitNode(right, visitor, isExpression))), node)), node);
                    }
                    else {
                        return factory2.updateBinaryExpression(node, target, node.operatorToken, Debug.checkDefined(visitNode(right, visitor, isExpression)));
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitLeftAssociativeBinaryExpression(node) {
                if (containsYield(node.right)) {
                    if (isLogicalOperator(node.operatorToken.kind)) {
                        return visitLogicalBinaryExpression(node);
                    }
                    else if (node.operatorToken.kind === 27 /* CommaToken */) {
                        return visitCommaExpression(node);
                    }
                    return factory2.updateBinaryExpression(node, cacheExpression(Debug.checkDefined(visitNode(node.left, visitor, isExpression))), node.operatorToken, Debug.checkDefined(visitNode(node.right, visitor, isExpression)));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaExpression(node) {
                let pendingExpressions = [];
                visit(node.left);
                visit(node.right);
                return factory2.inlineExpressions(pendingExpressions);
                function visit(node2) {
                    if (isBinaryExpression(node2) && node2.operatorToken.kind === 27 /* CommaToken */) {
                        visit(node2.left);
                        visit(node2.right);
                    }
                    else {
                        if (containsYield(node2) && pendingExpressions.length > 0) {
                            emitWorker(1 /* Statement */, [factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions))]);
                            pendingExpressions = [];
                        }
                        pendingExpressions.push(Debug.checkDefined(visitNode(node2, visitor, isExpression)));
                    }
                }
            }
            function visitCommaListExpression(node) {
                let pendingExpressions = [];
                for (const elem of node.elements) {
                    if (isBinaryExpression(elem) && elem.operatorToken.kind === 27 /* CommaToken */) {
                        pendingExpressions.push(visitCommaExpression(elem));
                    }
                    else {
                        if (containsYield(elem) && pendingExpressions.length > 0) {
                            emitWorker(1 /* Statement */, [factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions))]);
                            pendingExpressions = [];
                        }
                        pendingExpressions.push(Debug.checkDefined(visitNode(elem, visitor, isExpression)));
                    }
                }
                return factory2.inlineExpressions(pendingExpressions);
            }
            function visitLogicalBinaryExpression(node) {
                const resultLabel = defineLabel();
                const resultLocal = declareLocal();
                emitAssignment(resultLocal, Debug.checkDefined(visitNode(node.left, visitor, isExpression)), 
                /*location*/
                node.left);
                if (node.operatorToken.kind === 55 /* AmpersandAmpersandToken */) {
                    emitBreakWhenFalse(resultLabel, resultLocal, 
                    /*location*/
                    node.left);
                }
                else {
                    emitBreakWhenTrue(resultLabel, resultLocal, 
                    /*location*/
                    node.left);
                }
                emitAssignment(resultLocal, Debug.checkDefined(visitNode(node.right, visitor, isExpression)), 
                /*location*/
                node.right);
                markLabel(resultLabel);
                return resultLocal;
            }
            function visitConditionalExpression(node) {
                if (containsYield(node.whenTrue) || containsYield(node.whenFalse)) {
                    const whenFalseLabel = defineLabel();
                    const resultLabel = defineLabel();
                    const resultLocal = declareLocal();
                    emitBreakWhenFalse(whenFalseLabel, Debug.checkDefined(visitNode(node.condition, visitor, isExpression)), 
                    /*location*/
                    node.condition);
                    emitAssignment(resultLocal, Debug.checkDefined(visitNode(node.whenTrue, visitor, isExpression)), 
                    /*location*/
                    node.whenTrue);
                    emitBreak(resultLabel);
                    markLabel(whenFalseLabel);
                    emitAssignment(resultLocal, Debug.checkDefined(visitNode(node.whenFalse, visitor, isExpression)), 
                    /*location*/
                    node.whenFalse);
                    markLabel(resultLabel);
                    return resultLocal;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitYieldExpression(node) {
                const resumeLabel = defineLabel();
                const expression = visitNode(node.expression, visitor, isExpression);
                if (node.asteriskToken) {
                    const iterator = (getEmitFlags(node.expression) & 16777216 /* Iterator */) === 0 ? setTextRange(emitHelpers().createValuesHelper(expression), node) : expression;
                    emitYieldStar(iterator, 
                    /*location*/
                    node);
                }
                else {
                    emitYield(expression, 
                    /*location*/
                    node);
                }
                markLabel(resumeLabel);
                return createGeneratorResume(
                /*location*/
                node);
            }
            function visitArrayLiteralExpression(node) {
                return visitElements(node.elements, 
                /*leadingElement*/
                void 0, 
                /*location*/
                void 0, node.multiLine);
            }
            function visitElements(elements, leadingElement, location, multiLine) {
                const numInitialElements = countInitialNodesWithoutYield(elements);
                let temp;
                if (numInitialElements > 0) {
                    temp = declareLocal();
                    const initialElements = visitNodes2(elements, visitor, isExpression, 0, numInitialElements);
                    emitAssignment(temp, factory2.createArrayLiteralExpression(leadingElement ? [leadingElement, ...initialElements] : initialElements));
                    leadingElement = void 0;
                }
                const expressions = reduceLeft(elements, reduceElement, [], numInitialElements);
                return temp ? factory2.createArrayConcatCall(temp, [factory2.createArrayLiteralExpression(expressions, multiLine)]) : setTextRange(factory2.createArrayLiteralExpression(leadingElement ? [leadingElement, ...expressions] : expressions, multiLine), location);
                function reduceElement(expressions2, element) {
                    if (containsYield(element) && expressions2.length > 0) {
                        const hasAssignedTemp = temp !== void 0;
                        if (!temp) {
                            temp = declareLocal();
                        }
                        emitAssignment(temp, hasAssignedTemp ? factory2.createArrayConcatCall(temp, [factory2.createArrayLiteralExpression(expressions2, multiLine)]) : factory2.createArrayLiteralExpression(leadingElement ? [leadingElement, ...expressions2] : expressions2, multiLine));
                        leadingElement = void 0;
                        expressions2 = [];
                    }
                    expressions2.push(Debug.checkDefined(visitNode(element, visitor, isExpression)));
                    return expressions2;
                }
            }
            function visitObjectLiteralExpression(node) {
                const properties = node.properties;
                const multiLine = node.multiLine;
                const numInitialProperties = countInitialNodesWithoutYield(properties);
                const temp = declareLocal();
                emitAssignment(temp, factory2.createObjectLiteralExpression(visitNodes2(properties, visitor, isObjectLiteralElementLike, 0, numInitialProperties), multiLine));
                const expressions = reduceLeft(properties, reduceProperty, [], numInitialProperties);
                expressions.push(multiLine ? startOnNewLine(setParent(setTextRange(factory2.cloneNode(temp), temp), temp.parent)) : temp);
                return factory2.inlineExpressions(expressions);
                function reduceProperty(expressions2, property) {
                    if (containsYield(property) && expressions2.length > 0) {
                        emitStatement(factory2.createExpressionStatement(factory2.inlineExpressions(expressions2)));
                        expressions2 = [];
                    }
                    const expression = createExpressionForObjectLiteralElementLike(factory2, node, property, temp);
                    const visited = visitNode(expression, visitor, isExpression);
                    if (visited) {
                        if (multiLine) {
                            startOnNewLine(visited);
                        }
                        expressions2.push(visited);
                    }
                    return expressions2;
                }
            }
            function visitElementAccessExpression(node) {
                if (containsYield(node.argumentExpression)) {
                    return factory2.updateElementAccessExpression(node, cacheExpression(Debug.checkDefined(visitNode(node.expression, visitor, isLeftHandSideExpression))), Debug.checkDefined(visitNode(node.argumentExpression, visitor, isExpression)));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCallExpression(node) {
                if (!isImportCall(node) && forEach(node.arguments, containsYield)) {
                    const { target, thisArg } = factory2.createCallBinding(node.expression, hoistVariableDeclaration, languageVersion, 
                    /*cacheIdentifiers*/
                    true);
                    return setOriginalNode(setTextRange(factory2.createFunctionApplyCall(cacheExpression(Debug.checkDefined(visitNode(target, visitor, isLeftHandSideExpression))), thisArg, visitElements(node.arguments)), node), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitNewExpression(node) {
                if (forEach(node.arguments, containsYield)) {
                    const { target, thisArg } = factory2.createCallBinding(factory2.createPropertyAccessExpression(node.expression, "bind"), hoistVariableDeclaration);
                    return setOriginalNode(setTextRange(factory2.createNewExpression(factory2.createFunctionApplyCall(cacheExpression(Debug.checkDefined(visitNode(target, visitor, isExpression))), thisArg, visitElements(node.arguments, 
                    /*leadingElement*/
                    factory2.createVoidZero())), 
                    /*typeArguments*/
                    void 0, []), node), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function transformAndEmitStatements(statements2, start = 0) {
                const numStatements = statements2.length;
                for (let i = start; i < numStatements; i++) {
                    transformAndEmitStatement(statements2[i]);
                }
            }
            function transformAndEmitEmbeddedStatement(node) {
                if (isBlock(node)) {
                    transformAndEmitStatements(node.statements);
                }
                else {
                    transformAndEmitStatement(node);
                }
            }
            function transformAndEmitStatement(node) {
                const savedInStatementContainingYield = inStatementContainingYield;
                if (!inStatementContainingYield) {
                    inStatementContainingYield = containsYield(node);
                }
                transformAndEmitStatementWorker(node);
                inStatementContainingYield = savedInStatementContainingYield;
            }
            function transformAndEmitStatementWorker(node) {
                switch (node.kind) {
                    case 238 /* Block */:
                        return transformAndEmitBlock(node);
                    case 241 /* ExpressionStatement */:
                        return transformAndEmitExpressionStatement(node);
                    case 242 /* IfStatement */:
                        return transformAndEmitIfStatement(node);
                    case 243 /* DoStatement */:
                        return transformAndEmitDoStatement(node);
                    case 244 /* WhileStatement */:
                        return transformAndEmitWhileStatement(node);
                    case 245 /* ForStatement */:
                        return transformAndEmitForStatement(node);
                    case 246 /* ForInStatement */:
                        return transformAndEmitForInStatement(node);
                    case 248 /* ContinueStatement */:
                        return transformAndEmitContinueStatement(node);
                    case 249 /* BreakStatement */:
                        return transformAndEmitBreakStatement(node);
                    case 250 /* ReturnStatement */:
                        return transformAndEmitReturnStatement(node);
                    case 251 /* WithStatement */:
                        return transformAndEmitWithStatement(node);
                    case 252 /* SwitchStatement */:
                        return transformAndEmitSwitchStatement(node);
                    case 253 /* LabeledStatement */:
                        return transformAndEmitLabeledStatement(node);
                    case 254 /* ThrowStatement */:
                        return transformAndEmitThrowStatement(node);
                    case 255 /* TryStatement */:
                        return transformAndEmitTryStatement(node);
                    default:
                        return emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function transformAndEmitBlock(node) {
                if (containsYield(node)) {
                    transformAndEmitStatements(node.statements);
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function transformAndEmitExpressionStatement(node) {
                emitStatement(visitNode(node, visitor, isStatement));
            }
            function transformAndEmitVariableDeclarationList(node) {
                for (const variable of node.declarations) {
                    const name = factory2.cloneNode(variable.name);
                    setCommentRange(name, variable.name);
                    hoistVariableDeclaration(name);
                }
                const variables = getInitializedVariables(node);
                const numVariables = variables.length;
                let variablesWritten = 0;
                let pendingExpressions = [];
                while (variablesWritten < numVariables) {
                    for (let i = variablesWritten; i < numVariables; i++) {
                        const variable = variables[i];
                        if (containsYield(variable.initializer) && pendingExpressions.length > 0) {
                            break;
                        }
                        pendingExpressions.push(transformInitializedVariable(variable));
                    }
                    if (pendingExpressions.length) {
                        emitStatement(factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions)));
                        variablesWritten += pendingExpressions.length;
                        pendingExpressions = [];
                    }
                }
                return void 0;
            }
            function transformInitializedVariable(node) {
                return setSourceMapRange(factory2.createAssignment(setSourceMapRange(factory2.cloneNode(node.name), node.name), Debug.checkDefined(visitNode(node.initializer, visitor, isExpression))), node);
            }
            function transformAndEmitIfStatement(node) {
                if (containsYield(node)) {
                    if (containsYield(node.thenStatement) || containsYield(node.elseStatement)) {
                        const endLabel = defineLabel();
                        const elseLabel = node.elseStatement ? defineLabel() : void 0;
                        emitBreakWhenFalse(node.elseStatement ? elseLabel : endLabel, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), 
                        /*location*/
                        node.expression);
                        transformAndEmitEmbeddedStatement(node.thenStatement);
                        if (node.elseStatement) {
                            emitBreak(endLabel);
                            markLabel(elseLabel);
                            transformAndEmitEmbeddedStatement(node.elseStatement);
                        }
                        markLabel(endLabel);
                    }
                    else {
                        emitStatement(visitNode(node, visitor, isStatement));
                    }
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function transformAndEmitDoStatement(node) {
                if (containsYield(node)) {
                    const conditionLabel = defineLabel();
                    const loopLabel = defineLabel();
                    beginLoopBlock(
                    /*continueLabel*/
                    conditionLabel);
                    markLabel(loopLabel);
                    transformAndEmitEmbeddedStatement(node.statement);
                    markLabel(conditionLabel);
                    emitBreakWhenTrue(loopLabel, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
                    endLoopBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitDoStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLoopBlock();
                    node = visitEachChild(node, visitor, context);
                    endLoopBlock();
                    return node;
                }
                else {
                    return visitEachChild(node, visitor, context);
                }
            }
            function transformAndEmitWhileStatement(node) {
                if (containsYield(node)) {
                    const loopLabel = defineLabel();
                    const endLabel = beginLoopBlock(loopLabel);
                    markLabel(loopLabel);
                    emitBreakWhenFalse(endLabel, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
                    transformAndEmitEmbeddedStatement(node.statement);
                    emitBreak(loopLabel);
                    endLoopBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitWhileStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLoopBlock();
                    node = visitEachChild(node, visitor, context);
                    endLoopBlock();
                    return node;
                }
                else {
                    return visitEachChild(node, visitor, context);
                }
            }
            function transformAndEmitForStatement(node) {
                if (containsYield(node)) {
                    const conditionLabel = defineLabel();
                    const incrementLabel = defineLabel();
                    const endLabel = beginLoopBlock(incrementLabel);
                    if (node.initializer) {
                        const initializer = node.initializer;
                        if (isVariableDeclarationList(initializer)) {
                            transformAndEmitVariableDeclarationList(initializer);
                        }
                        else {
                            emitStatement(setTextRange(factory2.createExpressionStatement(Debug.checkDefined(visitNode(initializer, visitor, isExpression))), initializer));
                        }
                    }
                    markLabel(conditionLabel);
                    if (node.condition) {
                        emitBreakWhenFalse(endLabel, Debug.checkDefined(visitNode(node.condition, visitor, isExpression)));
                    }
                    transformAndEmitEmbeddedStatement(node.statement);
                    markLabel(incrementLabel);
                    if (node.incrementor) {
                        emitStatement(setTextRange(factory2.createExpressionStatement(Debug.checkDefined(visitNode(node.incrementor, visitor, isExpression))), node.incrementor));
                    }
                    emitBreak(conditionLabel);
                    endLoopBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitForStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLoopBlock();
                }
                const initializer = node.initializer;
                if (initializer && isVariableDeclarationList(initializer)) {
                    for (const variable of initializer.declarations) {
                        hoistVariableDeclaration(variable.name);
                    }
                    const variables = getInitializedVariables(initializer);
                    node = factory2.updateForStatement(node, variables.length > 0 ? factory2.inlineExpressions(map(variables, transformInitializedVariable)) : void 0, visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, visitor, isExpression), visitIterationBody(node.statement, visitor, context));
                }
                else {
                    node = visitEachChild(node, visitor, context);
                }
                if (inStatementContainingYield) {
                    endLoopBlock();
                }
                return node;
            }
            function transformAndEmitForInStatement(node) {
                if (containsYield(node)) {
                    const obj = declareLocal();
                    const keysArray = declareLocal();
                    const key = declareLocal();
                    const keysIndex = factory2.createLoopVariable();
                    const initializer = node.initializer;
                    hoistVariableDeclaration(keysIndex);
                    emitAssignment(obj, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
                    emitAssignment(keysArray, factory2.createArrayLiteralExpression());
                    emitStatement(factory2.createForInStatement(key, obj, factory2.createExpressionStatement(factory2.createCallExpression(factory2.createPropertyAccessExpression(keysArray, "push"), 
                    /*typeArguments*/
                    void 0, [key]))));
                    emitAssignment(keysIndex, factory2.createNumericLiteral(0));
                    const conditionLabel = defineLabel();
                    const incrementLabel = defineLabel();
                    const endLoopLabel = beginLoopBlock(incrementLabel);
                    markLabel(conditionLabel);
                    emitBreakWhenFalse(endLoopLabel, factory2.createLessThan(keysIndex, factory2.createPropertyAccessExpression(keysArray, "length")));
                    emitAssignment(key, factory2.createElementAccessExpression(keysArray, keysIndex));
                    emitBreakWhenFalse(incrementLabel, factory2.createBinaryExpression(key, 101 /* InKeyword */, obj));
                    let variable;
                    if (isVariableDeclarationList(initializer)) {
                        for (const variable2 of initializer.declarations) {
                            hoistVariableDeclaration(variable2.name);
                        }
                        variable = factory2.cloneNode(initializer.declarations[0].name);
                    }
                    else {
                        variable = Debug.checkDefined(visitNode(initializer, visitor, isExpression));
                        Debug.assert(isLeftHandSideExpression(variable));
                    }
                    emitAssignment(variable, key);
                    transformAndEmitEmbeddedStatement(node.statement);
                    markLabel(incrementLabel);
                    emitStatement(factory2.createExpressionStatement(factory2.createPostfixIncrement(keysIndex)));
                    emitBreak(conditionLabel);
                    endLoopBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitForInStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLoopBlock();
                }
                const initializer = node.initializer;
                if (isVariableDeclarationList(initializer)) {
                    for (const variable of initializer.declarations) {
                        hoistVariableDeclaration(variable.name);
                    }
                    node = factory2.updateForInStatement(node, initializer.declarations[0].name, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), Debug.checkDefined(visitNode(node.statement, visitor, isStatement, factory2.liftToBlock)));
                }
                else {
                    node = visitEachChild(node, visitor, context);
                }
                if (inStatementContainingYield) {
                    endLoopBlock();
                }
                return node;
            }
            function transformAndEmitContinueStatement(node) {
                const label = findContinueTarget(node.label ? idText(node.label) : void 0);
                if (label > 0) {
                    emitBreak(label, 
                    /*location*/
                    node);
                }
                else {
                    emitStatement(node);
                }
            }
            function visitContinueStatement(node) {
                if (inStatementContainingYield) {
                    const label = findContinueTarget(node.label && idText(node.label));
                    if (label > 0) {
                        return createInlineBreak(label, 
                        /*location*/
                        node);
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function transformAndEmitBreakStatement(node) {
                const label = findBreakTarget(node.label ? idText(node.label) : void 0);
                if (label > 0) {
                    emitBreak(label, 
                    /*location*/
                    node);
                }
                else {
                    emitStatement(node);
                }
            }
            function visitBreakStatement(node) {
                if (inStatementContainingYield) {
                    const label = findBreakTarget(node.label && idText(node.label));
                    if (label > 0) {
                        return createInlineBreak(label, 
                        /*location*/
                        node);
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function transformAndEmitReturnStatement(node) {
                emitReturn(visitNode(node.expression, visitor, isExpression), 
                /*location*/
                node);
            }
            function visitReturnStatement(node) {
                return createInlineReturn(visitNode(node.expression, visitor, isExpression), 
                /*location*/
                node);
            }
            function transformAndEmitWithStatement(node) {
                if (containsYield(node)) {
                    beginWithBlock(cacheExpression(Debug.checkDefined(visitNode(node.expression, visitor, isExpression))));
                    transformAndEmitEmbeddedStatement(node.statement);
                    endWithBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function transformAndEmitSwitchStatement(node) {
                if (containsYield(node.caseBlock)) {
                    const caseBlock = node.caseBlock;
                    const numClauses = caseBlock.clauses.length;
                    const endLabel = beginSwitchBlock();
                    const expression = cacheExpression(Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
                    const clauseLabels = [];
                    let defaultClauseIndex = -1;
                    for (let i = 0; i < numClauses; i++) {
                        const clause = caseBlock.clauses[i];
                        clauseLabels.push(defineLabel());
                        if (clause.kind === 293 /* DefaultClause */ && defaultClauseIndex === -1) {
                            defaultClauseIndex = i;
                        }
                    }
                    let clausesWritten = 0;
                    let pendingClauses = [];
                    while (clausesWritten < numClauses) {
                        let defaultClausesSkipped = 0;
                        for (let i = clausesWritten; i < numClauses; i++) {
                            const clause = caseBlock.clauses[i];
                            if (clause.kind === 292 /* CaseClause */) {
                                if (containsYield(clause.expression) && pendingClauses.length > 0) {
                                    break;
                                }
                                pendingClauses.push(factory2.createCaseClause(Debug.checkDefined(visitNode(clause.expression, visitor, isExpression)), [
                                    createInlineBreak(clauseLabels[i], 
                                    /*location*/
                                    clause.expression)
                                ]));
                            }
                            else {
                                defaultClausesSkipped++;
                            }
                        }
                        if (pendingClauses.length) {
                            emitStatement(factory2.createSwitchStatement(expression, factory2.createCaseBlock(pendingClauses)));
                            clausesWritten += pendingClauses.length;
                            pendingClauses = [];
                        }
                        if (defaultClausesSkipped > 0) {
                            clausesWritten += defaultClausesSkipped;
                            defaultClausesSkipped = 0;
                        }
                    }
                    if (defaultClauseIndex >= 0) {
                        emitBreak(clauseLabels[defaultClauseIndex]);
                    }
                    else {
                        emitBreak(endLabel);
                    }
                    for (let i = 0; i < numClauses; i++) {
                        markLabel(clauseLabels[i]);
                        transformAndEmitStatements(caseBlock.clauses[i].statements);
                    }
                    endSwitchBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitSwitchStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptSwitchBlock();
                }
                node = visitEachChild(node, visitor, context);
                if (inStatementContainingYield) {
                    endSwitchBlock();
                }
                return node;
            }
            function transformAndEmitLabeledStatement(node) {
                if (containsYield(node)) {
                    beginLabeledBlock(idText(node.label));
                    transformAndEmitEmbeddedStatement(node.statement);
                    endLabeledBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitLabeledStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLabeledBlock(idText(node.label));
                }
                node = visitEachChild(node, visitor, context);
                if (inStatementContainingYield) {
                    endLabeledBlock();
                }
                return node;
            }
            function transformAndEmitThrowStatement(node) {
                var _a2;
                emitThrow(Debug.checkDefined(visitNode((_a2 = node.expression) != null ? _a2 : factory2.createVoidZero(), visitor, isExpression)), 
                /*location*/
                node);
            }
            function transformAndEmitTryStatement(node) {
                if (containsYield(node)) {
                    beginExceptionBlock();
                    transformAndEmitEmbeddedStatement(node.tryBlock);
                    if (node.catchClause) {
                        beginCatchBlock(node.catchClause.variableDeclaration);
                        transformAndEmitEmbeddedStatement(node.catchClause.block);
                    }
                    if (node.finallyBlock) {
                        beginFinallyBlock();
                        transformAndEmitEmbeddedStatement(node.finallyBlock);
                    }
                    endExceptionBlock();
                }
                else {
                    emitStatement(visitEachChild(node, visitor, context));
                }
            }
            function containsYield(node) {
                return !!node && (node.transformFlags & 1048576 /* ContainsYield */) !== 0;
            }
            function countInitialNodesWithoutYield(nodes) {
                const numNodes = nodes.length;
                for (let i = 0; i < numNodes; i++) {
                    if (containsYield(nodes[i])) {
                        return i;
                    }
                }
                return -1;
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                if (isIdentifier(node)) {
                    return substituteExpressionIdentifier(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                if (!isGeneratedIdentifier(node) && renamedCatchVariables && renamedCatchVariables.has(idText(node))) {
                    const original = getOriginalNode(node);
                    if (isIdentifier(original) && original.parent) {
                        const declaration = resolver.getReferencedValueDeclaration(original);
                        if (declaration) {
                            const name = renamedCatchVariableDeclarations[getOriginalNodeId(declaration)];
                            if (name) {
                                const clone2 = setParent(setTextRange(factory2.cloneNode(name), name), name.parent);
                                setSourceMapRange(clone2, node);
                                setCommentRange(clone2, node);
                                return clone2;
                            }
                        }
                    }
                }
                return node;
            }
            function cacheExpression(node) {
                if (isGeneratedIdentifier(node) || getEmitFlags(node) & 8192 /* HelperName */) {
                    return node;
                }
                const temp = factory2.createTempVariable(hoistVariableDeclaration);
                emitAssignment(temp, node, 
                /*location*/
                node);
                return temp;
            }
            function declareLocal(name) {
                const temp = name ? factory2.createUniqueName(name) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                hoistVariableDeclaration(temp);
                return temp;
            }
            function defineLabel() {
                if (!labelOffsets) {
                    labelOffsets = [];
                }
                const label = nextLabelId;
                nextLabelId++;
                labelOffsets[label] = -1;
                return label;
            }
            function markLabel(label) {
                Debug.assert(labelOffsets !== void 0, "No labels were defined.");
                labelOffsets[label] = operations ? operations.length : 0;
            }
            function beginBlock(block) {
                if (!blocks) {
                    blocks = [];
                    blockActions = [];
                    blockOffsets = [];
                    blockStack = [];
                }
                const index = blockActions.length;
                blockActions[index] = 0 /* Open */;
                blockOffsets[index] = operations ? operations.length : 0;
                blocks[index] = block;
                blockStack.push(block);
                return index;
            }
            function endBlock() {
                const block = peekBlock();
                if (block === void 0)
                    return Debug.fail("beginBlock was never called.");
                const index = blockActions.length;
                blockActions[index] = 1 /* Close */;
                blockOffsets[index] = operations ? operations.length : 0;
                blocks[index] = block;
                blockStack.pop();
                return block;
            }
            function peekBlock() {
                return lastOrUndefined(blockStack);
            }
            function peekBlockKind() {
                const block = peekBlock();
                return block && block.kind;
            }
            function beginWithBlock(expression) {
                const startLabel = defineLabel();
                const endLabel = defineLabel();
                markLabel(startLabel);
                beginBlock({
                    kind: 1 /* With */,
                    expression,
                    startLabel,
                    endLabel
                });
            }
            function endWithBlock() {
                Debug.assert(peekBlockKind() === 1 /* With */);
                const block = endBlock();
                markLabel(block.endLabel);
            }
            function beginExceptionBlock() {
                const startLabel = defineLabel();
                const endLabel = defineLabel();
                markLabel(startLabel);
                beginBlock({
                    kind: 0 /* Exception */,
                    state: 0 /* Try */,
                    startLabel,
                    endLabel
                });
                emitNop();
                return endLabel;
            }
            function beginCatchBlock(variable) {
                Debug.assert(peekBlockKind() === 0 /* Exception */);
                let name;
                if (isGeneratedIdentifier(variable.name)) {
                    name = variable.name;
                    hoistVariableDeclaration(variable.name);
                }
                else {
                    const text = idText(variable.name);
                    name = declareLocal(text);
                    if (!renamedCatchVariables) {
                        renamedCatchVariables = /* @__PURE__ */ new Map();
                        renamedCatchVariableDeclarations = [];
                        context.enableSubstitution(79 /* Identifier */);
                    }
                    renamedCatchVariables.set(text, true);
                    renamedCatchVariableDeclarations[getOriginalNodeId(variable)] = name;
                }
                const exception = peekBlock();
                Debug.assert(exception.state < 1 /* Catch */);
                const endLabel = exception.endLabel;
                emitBreak(endLabel);
                const catchLabel = defineLabel();
                markLabel(catchLabel);
                exception.state = 1 /* Catch */;
                exception.catchVariable = name;
                exception.catchLabel = catchLabel;
                emitAssignment(name, factory2.createCallExpression(factory2.createPropertyAccessExpression(state, "sent"), 
                /*typeArguments*/
                void 0, []));
                emitNop();
            }
            function beginFinallyBlock() {
                Debug.assert(peekBlockKind() === 0 /* Exception */);
                const exception = peekBlock();
                Debug.assert(exception.state < 2 /* Finally */);
                const endLabel = exception.endLabel;
                emitBreak(endLabel);
                const finallyLabel = defineLabel();
                markLabel(finallyLabel);
                exception.state = 2 /* Finally */;
                exception.finallyLabel = finallyLabel;
            }
            function endExceptionBlock() {
                Debug.assert(peekBlockKind() === 0 /* Exception */);
                const exception = endBlock();
                const state2 = exception.state;
                if (state2 < 2 /* Finally */) {
                    emitBreak(exception.endLabel);
                }
                else {
                    emitEndfinally();
                }
                markLabel(exception.endLabel);
                emitNop();
                exception.state = 3 /* Done */;
            }
            function beginScriptLoopBlock() {
                beginBlock({
                    kind: 3 /* Loop */,
                    isScript: true,
                    breakLabel: -1,
                    continueLabel: -1
                });
            }
            function beginLoopBlock(continueLabel) {
                const breakLabel = defineLabel();
                beginBlock({
                    kind: 3 /* Loop */,
                    isScript: false,
                    breakLabel,
                    continueLabel
                });
                return breakLabel;
            }
            function endLoopBlock() {
                Debug.assert(peekBlockKind() === 3 /* Loop */);
                const block = endBlock();
                const breakLabel = block.breakLabel;
                if (!block.isScript) {
                    markLabel(breakLabel);
                }
            }
            function beginScriptSwitchBlock() {
                beginBlock({
                    kind: 2 /* Switch */,
                    isScript: true,
                    breakLabel: -1
                });
            }
            function beginSwitchBlock() {
                const breakLabel = defineLabel();
                beginBlock({
                    kind: 2 /* Switch */,
                    isScript: false,
                    breakLabel
                });
                return breakLabel;
            }
            function endSwitchBlock() {
                Debug.assert(peekBlockKind() === 2 /* Switch */);
                const block = endBlock();
                const breakLabel = block.breakLabel;
                if (!block.isScript) {
                    markLabel(breakLabel);
                }
            }
            function beginScriptLabeledBlock(labelText) {
                beginBlock({
                    kind: 4 /* Labeled */,
                    isScript: true,
                    labelText,
                    breakLabel: -1
                });
            }
            function beginLabeledBlock(labelText) {
                const breakLabel = defineLabel();
                beginBlock({
                    kind: 4 /* Labeled */,
                    isScript: false,
                    labelText,
                    breakLabel
                });
            }
            function endLabeledBlock() {
                Debug.assert(peekBlockKind() === 4 /* Labeled */);
                const block = endBlock();
                if (!block.isScript) {
                    markLabel(block.breakLabel);
                }
            }
            function supportsUnlabeledBreak(block) {
                return block.kind === 2 /* Switch */ || block.kind === 3 /* Loop */;
            }
            function supportsLabeledBreakOrContinue(block) {
                return block.kind === 4 /* Labeled */;
            }
            function supportsUnlabeledContinue(block) {
                return block.kind === 3 /* Loop */;
            }
            function hasImmediateContainingLabeledBlock(labelText, start) {
                for (let j = start; j >= 0; j--) {
                    const containingBlock = blockStack[j];
                    if (supportsLabeledBreakOrContinue(containingBlock)) {
                        if (containingBlock.labelText === labelText) {
                            return true;
                        }
                    }
                    else {
                        break;
                    }
                }
                return false;
            }
            function findBreakTarget(labelText) {
                if (blockStack) {
                    if (labelText) {
                        for (let i = blockStack.length - 1; i >= 0; i--) {
                            const block = blockStack[i];
                            if (supportsLabeledBreakOrContinue(block) && block.labelText === labelText) {
                                return block.breakLabel;
                            }
                            else if (supportsUnlabeledBreak(block) && hasImmediateContainingLabeledBlock(labelText, i - 1)) {
                                return block.breakLabel;
                            }
                        }
                    }
                    else {
                        for (let i = blockStack.length - 1; i >= 0; i--) {
                            const block = blockStack[i];
                            if (supportsUnlabeledBreak(block)) {
                                return block.breakLabel;
                            }
                        }
                    }
                }
                return 0;
            }
            function findContinueTarget(labelText) {
                if (blockStack) {
                    if (labelText) {
                        for (let i = blockStack.length - 1; i >= 0; i--) {
                            const block = blockStack[i];
                            if (supportsUnlabeledContinue(block) && hasImmediateContainingLabeledBlock(labelText, i - 1)) {
                                return block.continueLabel;
                            }
                        }
                    }
                    else {
                        for (let i = blockStack.length - 1; i >= 0; i--) {
                            const block = blockStack[i];
                            if (supportsUnlabeledContinue(block)) {
                                return block.continueLabel;
                            }
                        }
                    }
                }
                return 0;
            }
            function createLabel(label) {
                if (label !== void 0 && label > 0) {
                    if (labelExpressions === void 0) {
                        labelExpressions = [];
                    }
                    const expression = factory2.createNumericLiteral(-1);
                    if (labelExpressions[label] === void 0) {
                        labelExpressions[label] = [expression];
                    }
                    else {
                        labelExpressions[label].push(expression);
                    }
                    return expression;
                }
                return factory2.createOmittedExpression();
            }
            function createInstruction(instruction) {
                const literal = factory2.createNumericLiteral(instruction);
                addSyntheticTrailingComment(literal, 3 /* MultiLineCommentTrivia */, getInstructionName(instruction));
                return literal;
            }
            function createInlineBreak(label, location) {
                Debug.assertLessThan(0, label, "Invalid label");
                return setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(3 /* Break */),
                    createLabel(label)
                ])), location);
            }
            function createInlineReturn(expression, location) {
                return setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression(expression ? [createInstruction(2 /* Return */), expression] : [createInstruction(2 /* Return */)])), location);
            }
            function createGeneratorResume(location) {
                return setTextRange(factory2.createCallExpression(factory2.createPropertyAccessExpression(state, "sent"), 
                /*typeArguments*/
                void 0, []), location);
            }
            function emitNop() {
                emitWorker(0 /* Nop */);
            }
            function emitStatement(node) {
                if (node) {
                    emitWorker(1 /* Statement */, [node]);
                }
                else {
                    emitNop();
                }
            }
            function emitAssignment(left, right, location) {
                emitWorker(2 /* Assign */, [left, right], location);
            }
            function emitBreak(label, location) {
                emitWorker(3 /* Break */, [label], location);
            }
            function emitBreakWhenTrue(label, condition, location) {
                emitWorker(4 /* BreakWhenTrue */, [label, condition], location);
            }
            function emitBreakWhenFalse(label, condition, location) {
                emitWorker(5 /* BreakWhenFalse */, [label, condition], location);
            }
            function emitYieldStar(expression, location) {
                emitWorker(7 /* YieldStar */, [expression], location);
            }
            function emitYield(expression, location) {
                emitWorker(6 /* Yield */, [expression], location);
            }
            function emitReturn(expression, location) {
                emitWorker(8 /* Return */, [expression], location);
            }
            function emitThrow(expression, location) {
                emitWorker(9 /* Throw */, [expression], location);
            }
            function emitEndfinally() {
                emitWorker(10 /* Endfinally */);
            }
            function emitWorker(code, args, location) {
                if (operations === void 0) {
                    operations = [];
                    operationArguments = [];
                    operationLocations = [];
                }
                if (labelOffsets === void 0) {
                    markLabel(defineLabel());
                }
                const operationIndex = operations.length;
                operations[operationIndex] = code;
                operationArguments[operationIndex] = args;
                operationLocations[operationIndex] = location;
            }
            function build2() {
                blockIndex = 0;
                labelNumber = 0;
                labelNumbers = void 0;
                lastOperationWasAbrupt = false;
                lastOperationWasCompletion = false;
                clauses = void 0;
                statements = void 0;
                exceptionBlockStack = void 0;
                currentExceptionBlock = void 0;
                withBlockStack = void 0;
                const buildResult = buildStatements();
                return emitHelpers().createGeneratorHelper(setEmitFlags(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, state)], 
                /*type*/
                void 0, factory2.createBlock(buildResult, 
                /*multiLine*/
                buildResult.length > 0)), 1048576 /* ReuseTempVariableScope */));
            }
            function buildStatements() {
                if (operations) {
                    for (let operationIndex = 0; operationIndex < operations.length; operationIndex++) {
                        writeOperation(operationIndex);
                    }
                    flushFinalLabel(operations.length);
                }
                else {
                    flushFinalLabel(0);
                }
                if (clauses) {
                    const labelExpression = factory2.createPropertyAccessExpression(state, "label");
                    const switchStatement = factory2.createSwitchStatement(labelExpression, factory2.createCaseBlock(clauses));
                    return [startOnNewLine(switchStatement)];
                }
                if (statements) {
                    return statements;
                }
                return [];
            }
            function flushLabel() {
                if (!statements) {
                    return;
                }
                appendLabel(
                /*markLabelEnd*/
                !lastOperationWasAbrupt);
                lastOperationWasAbrupt = false;
                lastOperationWasCompletion = false;
                labelNumber++;
            }
            function flushFinalLabel(operationIndex) {
                if (isFinalLabelReachable(operationIndex)) {
                    tryEnterLabel(operationIndex);
                    withBlockStack = void 0;
                    writeReturn(
                    /*expression*/
                    void 0, 
                    /*operationLocation*/
                    void 0);
                }
                if (statements && clauses) {
                    appendLabel(
                    /*markLabelEnd*/
                    false);
                }
                updateLabelExpressions();
            }
            function isFinalLabelReachable(operationIndex) {
                if (!lastOperationWasCompletion) {
                    return true;
                }
                if (!labelOffsets || !labelExpressions) {
                    return false;
                }
                for (let label = 0; label < labelOffsets.length; label++) {
                    if (labelOffsets[label] === operationIndex && labelExpressions[label]) {
                        return true;
                    }
                }
                return false;
            }
            function appendLabel(markLabelEnd) {
                if (!clauses) {
                    clauses = [];
                }
                if (statements) {
                    if (withBlockStack) {
                        for (let i = withBlockStack.length - 1; i >= 0; i--) {
                            const withBlock = withBlockStack[i];
                            statements = [factory2.createWithStatement(withBlock.expression, factory2.createBlock(statements))];
                        }
                    }
                    if (currentExceptionBlock) {
                        const { startLabel, catchLabel, finallyLabel, endLabel } = currentExceptionBlock;
                        statements.unshift(factory2.createExpressionStatement(factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createPropertyAccessExpression(state, "trys"), "push"), 
                        /*typeArguments*/
                        void 0, [
                            factory2.createArrayLiteralExpression([
                                createLabel(startLabel),
                                createLabel(catchLabel),
                                createLabel(finallyLabel),
                                createLabel(endLabel)
                            ])
                        ])));
                        currentExceptionBlock = void 0;
                    }
                    if (markLabelEnd) {
                        statements.push(factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(state, "label"), factory2.createNumericLiteral(labelNumber + 1))));
                    }
                }
                clauses.push(factory2.createCaseClause(factory2.createNumericLiteral(labelNumber), statements || []));
                statements = void 0;
            }
            function tryEnterLabel(operationIndex) {
                if (!labelOffsets) {
                    return;
                }
                for (let label = 0; label < labelOffsets.length; label++) {
                    if (labelOffsets[label] === operationIndex) {
                        flushLabel();
                        if (labelNumbers === void 0) {
                            labelNumbers = [];
                        }
                        if (labelNumbers[labelNumber] === void 0) {
                            labelNumbers[labelNumber] = [label];
                        }
                        else {
                            labelNumbers[labelNumber].push(label);
                        }
                    }
                }
            }
            function updateLabelExpressions() {
                if (labelExpressions !== void 0 && labelNumbers !== void 0) {
                    for (let labelNumber2 = 0; labelNumber2 < labelNumbers.length; labelNumber2++) {
                        const labels = labelNumbers[labelNumber2];
                        if (labels !== void 0) {
                            for (const label of labels) {
                                const expressions = labelExpressions[label];
                                if (expressions !== void 0) {
                                    for (const expression of expressions) {
                                        expression.text = String(labelNumber2);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            function tryEnterOrLeaveBlock(operationIndex) {
                if (blocks) {
                    for (; blockIndex < blockActions.length && blockOffsets[blockIndex] <= operationIndex; blockIndex++) {
                        const block = blocks[blockIndex];
                        const blockAction = blockActions[blockIndex];
                        switch (block.kind) {
                            case 0 /* Exception */:
                                if (blockAction === 0 /* Open */) {
                                    if (!exceptionBlockStack) {
                                        exceptionBlockStack = [];
                                    }
                                    if (!statements) {
                                        statements = [];
                                    }
                                    exceptionBlockStack.push(currentExceptionBlock);
                                    currentExceptionBlock = block;
                                }
                                else if (blockAction === 1 /* Close */) {
                                    currentExceptionBlock = exceptionBlockStack.pop();
                                }
                                break;
                            case 1 /* With */:
                                if (blockAction === 0 /* Open */) {
                                    if (!withBlockStack) {
                                        withBlockStack = [];
                                    }
                                    withBlockStack.push(block);
                                }
                                else if (blockAction === 1 /* Close */) {
                                    withBlockStack.pop();
                                }
                                break;
                        }
                    }
                }
            }
            function writeOperation(operationIndex) {
                tryEnterLabel(operationIndex);
                tryEnterOrLeaveBlock(operationIndex);
                if (lastOperationWasAbrupt) {
                    return;
                }
                lastOperationWasAbrupt = false;
                lastOperationWasCompletion = false;
                const opcode = operations[operationIndex];
                if (opcode === 0 /* Nop */) {
                    return;
                }
                else if (opcode === 10 /* Endfinally */) {
                    return writeEndfinally();
                }
                const args = operationArguments[operationIndex];
                if (opcode === 1 /* Statement */) {
                    return writeStatement(args[0]);
                }
                const location = operationLocations[operationIndex];
                switch (opcode) {
                    case 2 /* Assign */:
                        return writeAssign(args[0], args[1], location);
                    case 3 /* Break */:
                        return writeBreak(args[0], location);
                    case 4 /* BreakWhenTrue */:
                        return writeBreakWhenTrue(args[0], args[1], location);
                    case 5 /* BreakWhenFalse */:
                        return writeBreakWhenFalse(args[0], args[1], location);
                    case 6 /* Yield */:
                        return writeYield(args[0], location);
                    case 7 /* YieldStar */:
                        return writeYieldStar(args[0], location);
                    case 8 /* Return */:
                        return writeReturn(args[0], location);
                    case 9 /* Throw */:
                        return writeThrow(args[0], location);
                }
            }
            function writeStatement(statement) {
                if (statement) {
                    if (!statements) {
                        statements = [statement];
                    }
                    else {
                        statements.push(statement);
                    }
                }
            }
            function writeAssign(left, right, operationLocation) {
                writeStatement(setTextRange(factory2.createExpressionStatement(factory2.createAssignment(left, right)), operationLocation));
            }
            function writeThrow(expression, operationLocation) {
                lastOperationWasAbrupt = true;
                lastOperationWasCompletion = true;
                writeStatement(setTextRange(factory2.createThrowStatement(expression), operationLocation));
            }
            function writeReturn(expression, operationLocation) {
                lastOperationWasAbrupt = true;
                lastOperationWasCompletion = true;
                writeStatement(setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression(expression ? [createInstruction(2 /* Return */), expression] : [createInstruction(2 /* Return */)])), operationLocation), 768 /* NoTokenSourceMaps */));
            }
            function writeBreak(label, operationLocation) {
                lastOperationWasAbrupt = true;
                writeStatement(setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(3 /* Break */),
                    createLabel(label)
                ])), operationLocation), 768 /* NoTokenSourceMaps */));
            }
            function writeBreakWhenTrue(label, condition, operationLocation) {
                writeStatement(setEmitFlags(factory2.createIfStatement(condition, setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(3 /* Break */),
                    createLabel(label)
                ])), operationLocation), 768 /* NoTokenSourceMaps */)), 1 /* SingleLine */));
            }
            function writeBreakWhenFalse(label, condition, operationLocation) {
                writeStatement(setEmitFlags(factory2.createIfStatement(factory2.createLogicalNot(condition), setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(3 /* Break */),
                    createLabel(label)
                ])), operationLocation), 768 /* NoTokenSourceMaps */)), 1 /* SingleLine */));
            }
            function writeYield(expression, operationLocation) {
                lastOperationWasAbrupt = true;
                writeStatement(setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression(expression ? [createInstruction(4 /* Yield */), expression] : [createInstruction(4 /* Yield */)])), operationLocation), 768 /* NoTokenSourceMaps */));
            }
            function writeYieldStar(expression, operationLocation) {
                lastOperationWasAbrupt = true;
                writeStatement(setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(5 /* YieldStar */),
                    expression
                ])), operationLocation), 768 /* NoTokenSourceMaps */));
            }
            function writeEndfinally() {
                lastOperationWasAbrupt = true;
                writeStatement(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(7 /* Endfinally */)
                ])));
            }
        }
        var init_generators = __esm({
            "src/compiler/transformers/generators.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/module/module.ts
        function transformModule(context) {
            function getTransformModuleDelegate(moduleKind2) {
                switch (moduleKind2) {
                    case 2 /* AMD */:
                        return transformAMDModule;
                    case 3 /* UMD */:
                        return transformUMDModule;
                    default:
                        return transformCommonJSModule;
                }
            }
            const { factory: factory2, getEmitHelperFactory: emitHelpers, startLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const compilerOptions = context.getCompilerOptions();
            const resolver = context.getEmitResolver();
            const host = context.getEmitHost();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const moduleKind = getEmitModuleKind(compilerOptions);
            const previousOnSubstituteNode = context.onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.enableSubstitution(210 /* CallExpression */);
            context.enableSubstitution(212 /* TaggedTemplateExpression */);
            context.enableSubstitution(79 /* Identifier */);
            context.enableSubstitution(223 /* BinaryExpression */);
            context.enableSubstitution(300 /* ShorthandPropertyAssignment */);
            context.enableEmitNotification(308 /* SourceFile */);
            const moduleInfoMap = [];
            const deferredExports = [];
            let currentSourceFile;
            let currentModuleInfo;
            const noSubstitution = [];
            let needUMDDynamicImportHelper;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile || !(isEffectiveExternalModule(node, compilerOptions) || node.transformFlags & 8388608 /* ContainsDynamicImport */ || isJsonSourceFile(node) && hasJsonModuleEmitEnabled(compilerOptions) && outFile(compilerOptions))) {
                    return node;
                }
                currentSourceFile = node;
                currentModuleInfo = collectExternalModuleInfo(context, node, resolver, compilerOptions);
                moduleInfoMap[getOriginalNodeId(node)] = currentModuleInfo;
                const transformModule2 = getTransformModuleDelegate(moduleKind);
                const updated = transformModule2(node);
                currentSourceFile = void 0;
                currentModuleInfo = void 0;
                needUMDDynamicImportHelper = false;
                return updated;
            }
            function shouldEmitUnderscoreUnderscoreESModule() {
                if (!currentModuleInfo.exportEquals && isExternalModule(currentSourceFile)) {
                    return true;
                }
                return false;
            }
            function transformCommonJSModule(node) {
                startLexicalEnvironment();
                const statements = [];
                const ensureUseStrict = getStrictOptionValue(compilerOptions, "alwaysStrict") || !compilerOptions.noImplicitUseStrict && isExternalModule(currentSourceFile);
                const statementOffset = factory2.copyPrologue(node.statements, statements, ensureUseStrict && !isJsonSourceFile(node), topLevelVisitor);
                if (shouldEmitUnderscoreUnderscoreESModule()) {
                    append(statements, createUnderscoreUnderscoreESModule());
                }
                if (length(currentModuleInfo.exportedNames)) {
                    const chunkSize = 50;
                    for (let i = 0; i < currentModuleInfo.exportedNames.length; i += chunkSize) {
                        append(statements, factory2.createExpressionStatement(reduceLeft(currentModuleInfo.exportedNames.slice(i, i + chunkSize), (prev, nextId) => factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), factory2.createIdentifier(idText(nextId))), prev), factory2.createVoidZero())));
                    }
                }
                append(statements, visitNode(currentModuleInfo.externalHelpersImportDeclaration, topLevelVisitor, isStatement));
                addRange(statements, visitNodes2(node.statements, topLevelVisitor, isStatement, statementOffset));
                addExportEqualsIfNeeded(statements, 
                /*emitAsReturn*/
                false);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                const updated = factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray(statements), node.statements));
                addEmitHelpers(updated, context.readEmitHelpers());
                return updated;
            }
            function transformAMDModule(node) {
                const define = factory2.createIdentifier("define");
                const moduleName = tryGetModuleNameFromFile(factory2, node, host, compilerOptions);
                const jsonSourceFile = isJsonSourceFile(node) && node;
                const { aliasedModuleNames, unaliasedModuleNames, importAliasNames } = collectAsynchronousDependencies(node, 
                /*includeNonAmdDependencies*/
                true);
                const updated = factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray([
                    factory2.createExpressionStatement(factory2.createCallExpression(define, 
                    /*typeArguments*/
                    void 0, [
                        // Add the module name (if provided).
                        ...moduleName ? [moduleName] : [],
                        // Add the dependency array argument:
                        //
                        //     ["require", "exports", module1", "module2", ...]
                        factory2.createArrayLiteralExpression(jsonSourceFile ? emptyArray : [
                            factory2.createStringLiteral("require"),
                            factory2.createStringLiteral("exports"),
                            ...aliasedModuleNames,
                            ...unaliasedModuleNames
                        ]),
                        // Add the module body function argument:
                        //
                        //     function (require, exports, module1, module2) ...
                        jsonSourceFile ? jsonSourceFile.statements.length ? jsonSourceFile.statements[0].expression : factory2.createObjectLiteralExpression() : factory2.createFunctionExpression(
                        /*modifiers*/
                        void 0, 
                        /*asteriskToken*/
                        void 0, 
                        /*name*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [
                            factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "require"),
                            factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "exports"),
                            ...importAliasNames
                        ], 
                        /*type*/
                        void 0, transformAsynchronousModuleBody(node))
                    ]))
                ]), 
                /*location*/
                node.statements));
                addEmitHelpers(updated, context.readEmitHelpers());
                return updated;
            }
            function transformUMDModule(node) {
                const { aliasedModuleNames, unaliasedModuleNames, importAliasNames } = collectAsynchronousDependencies(node, 
                /*includeNonAmdDependencies*/
                false);
                const moduleName = tryGetModuleNameFromFile(factory2, node, host, compilerOptions);
                const umdHeader = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, "factory")], 
                /*type*/
                void 0, setTextRange(factory2.createBlock([
                    factory2.createIfStatement(factory2.createLogicalAnd(factory2.createTypeCheck(factory2.createIdentifier("module"), "object"), factory2.createTypeCheck(factory2.createPropertyAccessExpression(factory2.createIdentifier("module"), "exports"), "object")), factory2.createBlock([
                        factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, [
                            factory2.createVariableDeclaration("v", 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, factory2.createCallExpression(factory2.createIdentifier("factory"), 
                            /*typeArguments*/
                            void 0, [
                                factory2.createIdentifier("require"),
                                factory2.createIdentifier("exports")
                            ]))
                        ]),
                        setEmitFlags(factory2.createIfStatement(factory2.createStrictInequality(factory2.createIdentifier("v"), factory2.createIdentifier("undefined")), factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("module"), "exports"), factory2.createIdentifier("v")))), 1 /* SingleLine */)
                    ]), factory2.createIfStatement(factory2.createLogicalAnd(factory2.createTypeCheck(factory2.createIdentifier("define"), "function"), factory2.createPropertyAccessExpression(factory2.createIdentifier("define"), "amd")), factory2.createBlock([
                        factory2.createExpressionStatement(factory2.createCallExpression(factory2.createIdentifier("define"), 
                        /*typeArguments*/
                        void 0, [
                            // Add the module name (if provided).
                            ...moduleName ? [moduleName] : [],
                            factory2.createArrayLiteralExpression([
                                factory2.createStringLiteral("require"),
                                factory2.createStringLiteral("exports"),
                                ...aliasedModuleNames,
                                ...unaliasedModuleNames
                            ]),
                            factory2.createIdentifier("factory")
                        ]))
                    ])))
                ], 
                /*multiLine*/
                true), 
                /*location*/
                void 0));
                const updated = factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray([
                    factory2.createExpressionStatement(factory2.createCallExpression(umdHeader, 
                    /*typeArguments*/
                    void 0, [
                        // Add the module body function argument:
                        //
                        //     function (require, exports) ...
                        factory2.createFunctionExpression(
                        /*modifiers*/
                        void 0, 
                        /*asteriskToken*/
                        void 0, 
                        /*name*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [
                            factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "require"),
                            factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "exports"),
                            ...importAliasNames
                        ], 
                        /*type*/
                        void 0, transformAsynchronousModuleBody(node))
                    ]))
                ]), 
                /*location*/
                node.statements));
                addEmitHelpers(updated, context.readEmitHelpers());
                return updated;
            }
            function collectAsynchronousDependencies(node, includeNonAmdDependencies) {
                const aliasedModuleNames = [];
                const unaliasedModuleNames = [];
                const importAliasNames = [];
                for (const amdDependency of node.amdDependencies) {
                    if (amdDependency.name) {
                        aliasedModuleNames.push(factory2.createStringLiteral(amdDependency.path));
                        importAliasNames.push(factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, amdDependency.name));
                    }
                    else {
                        unaliasedModuleNames.push(factory2.createStringLiteral(amdDependency.path));
                    }
                }
                for (const importNode of currentModuleInfo.externalImports) {
                    const externalModuleName = getExternalModuleNameLiteral(factory2, importNode, currentSourceFile, host, resolver, compilerOptions);
                    const importAliasName = getLocalNameForExternalImport(factory2, importNode, currentSourceFile);
                    if (externalModuleName) {
                        if (includeNonAmdDependencies && importAliasName) {
                            setEmitFlags(importAliasName, 8 /* NoSubstitution */);
                            aliasedModuleNames.push(externalModuleName);
                            importAliasNames.push(factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, importAliasName));
                        }
                        else {
                            unaliasedModuleNames.push(externalModuleName);
                        }
                    }
                }
                return { aliasedModuleNames, unaliasedModuleNames, importAliasNames };
            }
            function getAMDImportExpressionForImport(node) {
                if (isImportEqualsDeclaration(node) || isExportDeclaration(node) || !getExternalModuleNameLiteral(factory2, node, currentSourceFile, host, resolver, compilerOptions)) {
                    return void 0;
                }
                const name = getLocalNameForExternalImport(factory2, node, currentSourceFile);
                const expr = getHelperExpressionForImport(node, name);
                if (expr === name) {
                    return void 0;
                }
                return factory2.createExpressionStatement(factory2.createAssignment(name, expr));
            }
            function transformAsynchronousModuleBody(node) {
                startLexicalEnvironment();
                const statements = [];
                const statementOffset = factory2.copyPrologue(node.statements, statements, 
                /*ensureUseStrict*/
                !compilerOptions.noImplicitUseStrict, topLevelVisitor);
                if (shouldEmitUnderscoreUnderscoreESModule()) {
                    append(statements, createUnderscoreUnderscoreESModule());
                }
                if (length(currentModuleInfo.exportedNames)) {
                    append(statements, factory2.createExpressionStatement(reduceLeft(currentModuleInfo.exportedNames, (prev, nextId) => factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), factory2.createIdentifier(idText(nextId))), prev), factory2.createVoidZero())));
                }
                append(statements, visitNode(currentModuleInfo.externalHelpersImportDeclaration, topLevelVisitor, isStatement));
                if (moduleKind === 2 /* AMD */) {
                    addRange(statements, mapDefined(currentModuleInfo.externalImports, getAMDImportExpressionForImport));
                }
                addRange(statements, visitNodes2(node.statements, topLevelVisitor, isStatement, statementOffset));
                addExportEqualsIfNeeded(statements, 
                /*emitAsReturn*/
                true);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                const body = factory2.createBlock(statements, 
                /*multiLine*/
                true);
                if (needUMDDynamicImportHelper) {
                    addEmitHelper(body, dynamicImportUMDHelper);
                }
                return body;
            }
            function addExportEqualsIfNeeded(statements, emitAsReturn) {
                if (currentModuleInfo.exportEquals) {
                    const expressionResult = visitNode(currentModuleInfo.exportEquals.expression, visitor, isExpression);
                    if (expressionResult) {
                        if (emitAsReturn) {
                            const statement = factory2.createReturnStatement(expressionResult);
                            setTextRange(statement, currentModuleInfo.exportEquals);
                            setEmitFlags(statement, 768 /* NoTokenSourceMaps */ | 3072 /* NoComments */);
                            statements.push(statement);
                        }
                        else {
                            const statement = factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("module"), "exports"), expressionResult));
                            setTextRange(statement, currentModuleInfo.exportEquals);
                            setEmitFlags(statement, 3072 /* NoComments */);
                            statements.push(statement);
                        }
                    }
                }
            }
            function topLevelVisitor(node) {
                switch (node.kind) {
                    case 269 /* ImportDeclaration */:
                        return visitImportDeclaration(node);
                    case 268 /* ImportEqualsDeclaration */:
                        return visitImportEqualsDeclaration(node);
                    case 275 /* ExportDeclaration */:
                        return visitExportDeclaration(node);
                    case 274 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    case 240 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 259 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 260 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 358 /* MergeDeclarationMarker */:
                        return visitMergeDeclarationMarker(node);
                    case 359 /* EndOfDeclarationMarker */:
                        return visitEndOfDeclarationMarker(node);
                    default:
                        return visitor(node);
                }
            }
            function visitorWorker(node, valueIsDiscarded) {
                if (!(node.transformFlags & (8388608 /* ContainsDynamicImport */ | 4096 /* ContainsDestructuringAssignment */ | 268435456 /* ContainsUpdateExpressionForIdentifier */))) {
                    return node;
                }
                switch (node.kind) {
                    case 245 /* ForStatement */:
                        return visitForStatement(node);
                    case 241 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, valueIsDiscarded);
                    case 356 /* PartiallyEmittedExpression */:
                        return visitPartiallyEmittedExpression(node, valueIsDiscarded);
                    case 210 /* CallExpression */:
                        if (isImportCall(node) && currentSourceFile.impliedNodeFormat === void 0) {
                            return visitImportCallExpression(node);
                        }
                        break;
                    case 223 /* BinaryExpression */:
                        if (isDestructuringAssignment(node)) {
                            return visitDestructuringAssignment(node, valueIsDiscarded);
                        }
                        break;
                    case 221 /* PrefixUnaryExpression */:
                    case 222 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, valueIsDiscarded);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                return visitorWorker(node, 
                /*valueIsDiscarded*/
                false);
            }
            function discardedValueVisitor(node) {
                return visitorWorker(node, 
                /*valueIsDiscarded*/
                true);
            }
            function destructuringNeedsFlattening(node) {
                if (isObjectLiteralExpression(node)) {
                    for (const elem of node.properties) {
                        switch (elem.kind) {
                            case 299 /* PropertyAssignment */:
                                if (destructuringNeedsFlattening(elem.initializer)) {
                                    return true;
                                }
                                break;
                            case 300 /* ShorthandPropertyAssignment */:
                                if (destructuringNeedsFlattening(elem.name)) {
                                    return true;
                                }
                                break;
                            case 301 /* SpreadAssignment */:
                                if (destructuringNeedsFlattening(elem.expression)) {
                                    return true;
                                }
                                break;
                            case 171 /* MethodDeclaration */:
                            case 174 /* GetAccessor */:
                            case 175 /* SetAccessor */:
                                return false;
                            default:
                                Debug.assertNever(elem, "Unhandled object member kind");
                        }
                    }
                }
                else if (isArrayLiteralExpression(node)) {
                    for (const elem of node.elements) {
                        if (isSpreadElement(elem)) {
                            if (destructuringNeedsFlattening(elem.expression)) {
                                return true;
                            }
                        }
                        else if (destructuringNeedsFlattening(elem)) {
                            return true;
                        }
                    }
                }
                else if (isIdentifier(node)) {
                    return length(getExports(node)) > (isExportName(node) ? 1 : 0);
                }
                return false;
            }
            function visitDestructuringAssignment(node, valueIsDiscarded) {
                if (destructuringNeedsFlattening(node.left)) {
                    return flattenDestructuringAssignment(node, visitor, context, 0 /* All */, !valueIsDiscarded, createAllExportExpressions);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForStatement(node) {
                return factory2.updateForStatement(node, visitNode(node.initializer, discardedValueVisitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, discardedValueVisitor, isExpression), visitIterationBody(node.statement, visitor, context));
            }
            function visitExpressionStatement(node) {
                return factory2.updateExpressionStatement(node, visitNode(node.expression, discardedValueVisitor, isExpression));
            }
            function visitParenthesizedExpression(node, valueIsDiscarded) {
                return factory2.updateParenthesizedExpression(node, visitNode(node.expression, valueIsDiscarded ? discardedValueVisitor : visitor, isExpression));
            }
            function visitPartiallyEmittedExpression(node, valueIsDiscarded) {
                return factory2.updatePartiallyEmittedExpression(node, visitNode(node.expression, valueIsDiscarded ? discardedValueVisitor : visitor, isExpression));
            }
            function visitPreOrPostfixUnaryExpression(node, valueIsDiscarded) {
                if ((node.operator === 45 /* PlusPlusToken */ || node.operator === 46 /* MinusMinusToken */) && isIdentifier(node.operand) && !isGeneratedIdentifier(node.operand) && !isLocalName(node.operand) && !isDeclarationNameOfEnumOrNamespace(node.operand)) {
                    const exportedNames = getExports(node.operand);
                    if (exportedNames) {
                        let temp;
                        let expression = visitNode(node.operand, visitor, isExpression);
                        if (isPrefixUnaryExpression(node)) {
                            expression = factory2.updatePrefixUnaryExpression(node, expression);
                        }
                        else {
                            expression = factory2.updatePostfixUnaryExpression(node, expression);
                            if (!valueIsDiscarded) {
                                temp = factory2.createTempVariable(hoistVariableDeclaration);
                                expression = factory2.createAssignment(temp, expression);
                                setTextRange(expression, node);
                            }
                            expression = factory2.createComma(expression, factory2.cloneNode(node.operand));
                            setTextRange(expression, node);
                        }
                        for (const exportName of exportedNames) {
                            noSubstitution[getNodeId(expression)] = true;
                            expression = createExportExpression(exportName, expression);
                            setTextRange(expression, node);
                        }
                        if (temp) {
                            noSubstitution[getNodeId(expression)] = true;
                            expression = factory2.createComma(expression, temp);
                            setTextRange(expression, node);
                        }
                        return expression;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitImportCallExpression(node) {
                if (moduleKind === 0 /* None */ && languageVersion >= 7 /* ES2020 */) {
                    return visitEachChild(node, visitor, context);
                }
                const externalModuleName = getExternalModuleNameLiteral(factory2, node, currentSourceFile, host, resolver, compilerOptions);
                const firstArgument = visitNode(firstOrUndefined(node.arguments), visitor, isExpression);
                const argument = externalModuleName && (!firstArgument || !isStringLiteral(firstArgument) || firstArgument.text !== externalModuleName.text) ? externalModuleName : firstArgument;
                const containsLexicalThis = !!(node.transformFlags & 16384 /* ContainsLexicalThis */);
                switch (compilerOptions.module) {
                    case 2 /* AMD */:
                        return createImportCallExpressionAMD(argument, containsLexicalThis);
                    case 3 /* UMD */:
                        return createImportCallExpressionUMD(argument != null ? argument : factory2.createVoidZero(), containsLexicalThis);
                    case 1 /* CommonJS */:
                    default:
                        return createImportCallExpressionCommonJS(argument);
                }
            }
            function createImportCallExpressionUMD(arg, containsLexicalThis) {
                needUMDDynamicImportHelper = true;
                if (isSimpleCopiableExpression(arg)) {
                    const argClone = isGeneratedIdentifier(arg) ? arg : isStringLiteral(arg) ? factory2.createStringLiteralFromNode(arg) : setEmitFlags(setTextRange(factory2.cloneNode(arg), arg), 3072 /* NoComments */);
                    return factory2.createConditionalExpression(
                    /*condition*/
                    factory2.createIdentifier("__syncRequire"), 
                    /*questionToken*/
                    void 0, 
                    /*whenTrue*/
                    createImportCallExpressionCommonJS(arg), 
                    /*colonToken*/
                    void 0, 
                    /*whenFalse*/
                    createImportCallExpressionAMD(argClone, containsLexicalThis));
                }
                else {
                    const temp = factory2.createTempVariable(hoistVariableDeclaration);
                    return factory2.createComma(factory2.createAssignment(temp, arg), factory2.createConditionalExpression(
                    /*condition*/
                    factory2.createIdentifier("__syncRequire"), 
                    /*questionToken*/
                    void 0, 
                    /*whenTrue*/
                    createImportCallExpressionCommonJS(temp, 
                    /* isInlineable */
                    true), 
                    /*colonToken*/
                    void 0, 
                    /*whenFalse*/
                    createImportCallExpressionAMD(temp, containsLexicalThis)));
                }
            }
            function createImportCallExpressionAMD(arg, containsLexicalThis) {
                const resolve = factory2.createUniqueName("resolve");
                const reject = factory2.createUniqueName("reject");
                const parameters = [
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, 
                    /*name*/
                    resolve),
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, 
                    /*name*/
                    reject)
                ];
                const body = factory2.createBlock([
                    factory2.createExpressionStatement(factory2.createCallExpression(factory2.createIdentifier("require"), 
                    /*typeArguments*/
                    void 0, [factory2.createArrayLiteralExpression([arg || factory2.createOmittedExpression()]), resolve, reject]))
                ]);
                let func;
                if (languageVersion >= 2 /* ES2015 */) {
                    func = factory2.createArrowFunction(
                    /*modifiers*/
                    void 0, 
                    /*typeParameters*/
                    void 0, parameters, 
                    /*type*/
                    void 0, 
                    /*equalsGreaterThanToken*/
                    void 0, body);
                }
                else {
                    func = factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, parameters, 
                    /*type*/
                    void 0, body);
                    if (containsLexicalThis) {
                        setEmitFlags(func, 16 /* CapturesThis */);
                    }
                }
                const promise = factory2.createNewExpression(factory2.createIdentifier("Promise"), 
                /*typeArguments*/
                void 0, [func]);
                if (getESModuleInterop(compilerOptions)) {
                    return factory2.createCallExpression(factory2.createPropertyAccessExpression(promise, factory2.createIdentifier("then")), 
                    /*typeArguments*/
                    void 0, [emitHelpers().createImportStarCallbackHelper()]);
                }
                return promise;
            }
            function createImportCallExpressionCommonJS(arg, isInlineable) {
                const needSyncEval = arg && !isSimpleInlineableExpression(arg) && !isInlineable;
                const promiseResolveCall = factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Promise"), "resolve"), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                needSyncEval ? languageVersion >= 2 /* ES2015 */ ? [
                    factory2.createTemplateExpression(factory2.createTemplateHead(""), [
                        factory2.createTemplateSpan(arg, factory2.createTemplateTail(""))
                    ])
                ] : [
                    factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createStringLiteral(""), "concat"), 
                    /*typeArguments*/
                    void 0, [arg])
                ] : []);
                let requireCall = factory2.createCallExpression(factory2.createIdentifier("require"), 
                /*typeArguments*/
                void 0, needSyncEval ? [factory2.createIdentifier("s")] : arg ? [arg] : []);
                if (getESModuleInterop(compilerOptions)) {
                    requireCall = emitHelpers().createImportStarHelper(requireCall);
                }
                const parameters = needSyncEval ? [
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, 
                    /*name*/
                    "s")
                ] : [];
                let func;
                if (languageVersion >= 2 /* ES2015 */) {
                    func = factory2.createArrowFunction(
                    /*modifiers*/
                    void 0, 
                    /*typeParameters*/
                    void 0, 
                    /*parameters*/
                    parameters, 
                    /*type*/
                    void 0, 
                    /*equalsGreaterThanToken*/
                    void 0, requireCall);
                }
                else {
                    func = factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, 
                    /*parameters*/
                    parameters, 
                    /*type*/
                    void 0, factory2.createBlock([factory2.createReturnStatement(requireCall)]));
                }
                const downleveledImport = factory2.createCallExpression(factory2.createPropertyAccessExpression(promiseResolveCall, "then"), 
                /*typeArguments*/
                void 0, [func]);
                return downleveledImport;
            }
            function getHelperExpressionForExport(node, innerExpr) {
                if (!getESModuleInterop(compilerOptions) || getInternalEmitFlags(node) & 2 /* NeverApplyImportHelper */) {
                    return innerExpr;
                }
                if (getExportNeedsImportStarHelper(node)) {
                    return emitHelpers().createImportStarHelper(innerExpr);
                }
                return innerExpr;
            }
            function getHelperExpressionForImport(node, innerExpr) {
                if (!getESModuleInterop(compilerOptions) || getInternalEmitFlags(node) & 2 /* NeverApplyImportHelper */) {
                    return innerExpr;
                }
                if (getImportNeedsImportStarHelper(node)) {
                    return emitHelpers().createImportStarHelper(innerExpr);
                }
                if (getImportNeedsImportDefaultHelper(node)) {
                    return emitHelpers().createImportDefaultHelper(innerExpr);
                }
                return innerExpr;
            }
            function visitImportDeclaration(node) {
                let statements;
                const namespaceDeclaration = getNamespaceDeclarationNode(node);
                if (moduleKind !== 2 /* AMD */) {
                    if (!node.importClause) {
                        return setOriginalNode(setTextRange(factory2.createExpressionStatement(createRequireCall2(node)), node), node);
                    }
                    else {
                        const variables = [];
                        if (namespaceDeclaration && !isDefaultImport(node)) {
                            variables.push(factory2.createVariableDeclaration(factory2.cloneNode(namespaceDeclaration.name), 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, getHelperExpressionForImport(node, createRequireCall2(node))));
                        }
                        else {
                            variables.push(factory2.createVariableDeclaration(factory2.getGeneratedNameForNode(node), 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, getHelperExpressionForImport(node, createRequireCall2(node))));
                            if (namespaceDeclaration && isDefaultImport(node)) {
                                variables.push(factory2.createVariableDeclaration(factory2.cloneNode(namespaceDeclaration.name), 
                                /*exclamationToken*/
                                void 0, 
                                /*type*/
                                void 0, factory2.getGeneratedNameForNode(node)));
                            }
                        }
                        statements = append(statements, setOriginalNode(setTextRange(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, factory2.createVariableDeclarationList(variables, languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */)), 
                        /*location*/
                        node), 
                        /*original*/
                        node));
                    }
                }
                else if (namespaceDeclaration && isDefaultImport(node)) {
                    statements = append(statements, factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([
                        setOriginalNode(setTextRange(factory2.createVariableDeclaration(factory2.cloneNode(namespaceDeclaration.name), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.getGeneratedNameForNode(node)), 
                        /*location*/
                        node), 
                        /*original*/
                        node)
                    ], languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */)));
                }
                if (hasAssociatedEndOfDeclarationMarker(node)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfImportDeclaration(deferredExports[id], node);
                }
                else {
                    statements = appendExportsOfImportDeclaration(statements, node);
                }
                return singleOrMany(statements);
            }
            function createRequireCall2(importNode) {
                const moduleName = getExternalModuleNameLiteral(factory2, importNode, currentSourceFile, host, resolver, compilerOptions);
                const args = [];
                if (moduleName) {
                    args.push(moduleName);
                }
                return factory2.createCallExpression(factory2.createIdentifier("require"), 
                /*typeArguments*/
                void 0, args);
            }
            function visitImportEqualsDeclaration(node) {
                Debug.assert(isExternalModuleImportEqualsDeclaration(node), "import= for internal module references should be handled in an earlier transformer.");
                let statements;
                if (moduleKind !== 2 /* AMD */) {
                    if (hasSyntacticModifier(node, 1 /* Export */)) {
                        statements = append(statements, setOriginalNode(setTextRange(factory2.createExpressionStatement(createExportExpression(node.name, createRequireCall2(node))), node), node));
                    }
                    else {
                        statements = append(statements, setOriginalNode(setTextRange(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, factory2.createVariableDeclarationList([
                            factory2.createVariableDeclaration(factory2.cloneNode(node.name), 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, createRequireCall2(node))
                        ], 
                        /*flags*/
                        languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */)), node), node));
                    }
                }
                else {
                    if (hasSyntacticModifier(node, 1 /* Export */)) {
                        statements = append(statements, setOriginalNode(setTextRange(factory2.createExpressionStatement(createExportExpression(factory2.getExportName(node), factory2.getLocalName(node))), node), node));
                    }
                }
                if (hasAssociatedEndOfDeclarationMarker(node)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfImportEqualsDeclaration(deferredExports[id], node);
                }
                else {
                    statements = appendExportsOfImportEqualsDeclaration(statements, node);
                }
                return singleOrMany(statements);
            }
            function visitExportDeclaration(node) {
                if (!node.moduleSpecifier) {
                    return void 0;
                }
                const generatedName = factory2.getGeneratedNameForNode(node);
                if (node.exportClause && isNamedExports(node.exportClause)) {
                    const statements = [];
                    if (moduleKind !== 2 /* AMD */) {
                        statements.push(setOriginalNode(setTextRange(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, factory2.createVariableDeclarationList([
                            factory2.createVariableDeclaration(generatedName, 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, createRequireCall2(node))
                        ])), 
                        /*location*/
                        node), 
                        /* original */
                        node));
                    }
                    for (const specifier of node.exportClause.elements) {
                        if (languageVersion === 0 /* ES3 */) {
                            statements.push(setOriginalNode(setTextRange(factory2.createExpressionStatement(emitHelpers().createCreateBindingHelper(generatedName, factory2.createStringLiteralFromNode(specifier.propertyName || specifier.name), specifier.propertyName ? factory2.createStringLiteralFromNode(specifier.name) : void 0)), specifier), specifier));
                        }
                        else {
                            const exportNeedsImportDefault = !!getESModuleInterop(compilerOptions) && !(getInternalEmitFlags(node) & 2 /* NeverApplyImportHelper */) && idText(specifier.propertyName || specifier.name) === "default";
                            const exportedValue = factory2.createPropertyAccessExpression(exportNeedsImportDefault ? emitHelpers().createImportDefaultHelper(generatedName) : generatedName, specifier.propertyName || specifier.name);
                            statements.push(setOriginalNode(setTextRange(factory2.createExpressionStatement(createExportExpression(factory2.getExportName(specifier), exportedValue, 
                            /* location */
                            void 0, 
                            /* liveBinding */
                            true)), specifier), specifier));
                        }
                    }
                    return singleOrMany(statements);
                }
                else if (node.exportClause) {
                    const statements = [];
                    statements.push(setOriginalNode(setTextRange(factory2.createExpressionStatement(createExportExpression(factory2.cloneNode(node.exportClause.name), getHelperExpressionForExport(node, moduleKind !== 2 /* AMD */ ? createRequireCall2(node) : isExportNamespaceAsDefaultDeclaration(node) ? generatedName : factory2.createIdentifier(idText(node.exportClause.name))))), node), node));
                    return singleOrMany(statements);
                }
                else {
                    return setOriginalNode(setTextRange(factory2.createExpressionStatement(emitHelpers().createExportStarHelper(moduleKind !== 2 /* AMD */ ? createRequireCall2(node) : generatedName)), node), node);
                }
            }
            function visitExportAssignment(node) {
                if (node.isExportEquals) {
                    return void 0;
                }
                let statements;
                const original = node.original;
                if (original && hasAssociatedEndOfDeclarationMarker(original)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportStatement(deferredExports[id], factory2.createIdentifier("default"), visitNode(node.expression, visitor, isExpression), 
                    /*location*/
                    node, 
                    /*allowComments*/
                    true);
                }
                else {
                    statements = appendExportStatement(statements, factory2.createIdentifier("default"), visitNode(node.expression, visitor, isExpression), 
                    /*location*/
                    node, 
                    /*allowComments*/
                    true);
                }
                return singleOrMany(statements);
            }
            function visitFunctionDeclaration(node) {
                let statements;
                if (hasSyntacticModifier(node, 1 /* Export */)) {
                    statements = append(statements, setOriginalNode(setTextRange(factory2.createFunctionDeclaration(visitNodes2(node.modifiers, modifierVisitor, isModifier), node.asteriskToken, factory2.getDeclarationName(node, 
                    /*allowComments*/
                    true, 
                    /*allowSourceMaps*/
                    true), 
                    /*typeParameters*/
                    void 0, visitNodes2(node.parameters, visitor, isParameter), 
                    /*type*/
                    void 0, visitEachChild(node.body, visitor, context)), 
                    /*location*/
                    node), 
                    /*original*/
                    node));
                }
                else {
                    statements = append(statements, visitEachChild(node, visitor, context));
                }
                if (hasAssociatedEndOfDeclarationMarker(node)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfHoistedDeclaration(deferredExports[id], node);
                }
                else {
                    statements = appendExportsOfHoistedDeclaration(statements, node);
                }
                return singleOrMany(statements);
            }
            function visitClassDeclaration(node) {
                let statements;
                if (hasSyntacticModifier(node, 1 /* Export */)) {
                    statements = append(statements, setOriginalNode(setTextRange(factory2.createClassDeclaration(visitNodes2(node.modifiers, modifierVisitor, isModifierLike), factory2.getDeclarationName(node, 
                    /*allowComments*/
                    true, 
                    /*allowSourceMaps*/
                    true), 
                    /*typeParameters*/
                    void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), visitNodes2(node.members, visitor, isClassElement)), node), node));
                }
                else {
                    statements = append(statements, visitEachChild(node, visitor, context));
                }
                if (hasAssociatedEndOfDeclarationMarker(node)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfHoistedDeclaration(deferredExports[id], node);
                }
                else {
                    statements = appendExportsOfHoistedDeclaration(statements, node);
                }
                return singleOrMany(statements);
            }
            function visitVariableStatement(node) {
                let statements;
                let variables;
                let expressions;
                if (hasSyntacticModifier(node, 1 /* Export */)) {
                    let modifiers;
                    let removeCommentsOnExpressions = false;
                    for (const variable of node.declarationList.declarations) {
                        if (isIdentifier(variable.name) && isLocalName(variable.name)) {
                            if (!modifiers) {
                                modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                            }
                            if (variable.initializer) {
                                const updatedVariable = factory2.updateVariableDeclaration(variable, variable.name, 
                                /*exclamationToken*/
                                void 0, 
                                /*type*/
                                void 0, createExportExpression(variable.name, visitNode(variable.initializer, visitor, isExpression)));
                                variables = append(variables, updatedVariable);
                            }
                            else {
                                variables = append(variables, variable);
                            }
                        }
                        else if (variable.initializer) {
                            if (!isBindingPattern(variable.name) && (isArrowFunction(variable.initializer) || isFunctionExpression(variable.initializer) || isClassExpression(variable.initializer))) {
                                const expression = factory2.createAssignment(setTextRange(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), variable.name), 
                                /*location*/
                                variable.name), factory2.createIdentifier(getTextOfIdentifierOrLiteral(variable.name)));
                                const updatedVariable = factory2.createVariableDeclaration(variable.name, variable.exclamationToken, variable.type, visitNode(variable.initializer, visitor, isExpression));
                                variables = append(variables, updatedVariable);
                                expressions = append(expressions, expression);
                                removeCommentsOnExpressions = true;
                            }
                            else {
                                expressions = append(expressions, transformInitializedVariable(variable));
                            }
                        }
                    }
                    if (variables) {
                        statements = append(statements, factory2.updateVariableStatement(node, modifiers, factory2.updateVariableDeclarationList(node.declarationList, variables)));
                    }
                    if (expressions) {
                        const statement = setOriginalNode(setTextRange(factory2.createExpressionStatement(factory2.inlineExpressions(expressions)), node), node);
                        if (removeCommentsOnExpressions) {
                            removeAllComments(statement);
                        }
                        statements = append(statements, statement);
                    }
                }
                else {
                    statements = append(statements, visitEachChild(node, visitor, context));
                }
                if (hasAssociatedEndOfDeclarationMarker(node)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfVariableStatement(deferredExports[id], node);
                }
                else {
                    statements = appendExportsOfVariableStatement(statements, node);
                }
                return singleOrMany(statements);
            }
            function createAllExportExpressions(name, value, location) {
                const exportedNames = getExports(name);
                if (exportedNames) {
                    let expression = isExportName(name) ? value : factory2.createAssignment(name, value);
                    for (const exportName of exportedNames) {
                        setEmitFlags(expression, 8 /* NoSubstitution */);
                        expression = createExportExpression(exportName, expression, 
                        /*location*/
                        location);
                    }
                    return expression;
                }
                return factory2.createAssignment(name, value);
            }
            function transformInitializedVariable(node) {
                if (isBindingPattern(node.name)) {
                    return flattenDestructuringAssignment(visitNode(node, visitor, isInitializedVariable), visitor, context, 0 /* All */, 
                    /*needsValue*/
                    false, createAllExportExpressions);
                }
                else {
                    return factory2.createAssignment(setTextRange(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), node.name), 
                    /*location*/
                    node.name), node.initializer ? visitNode(node.initializer, visitor, isExpression) : factory2.createVoidZero());
                }
            }
            function visitMergeDeclarationMarker(node) {
                if (hasAssociatedEndOfDeclarationMarker(node) && node.original.kind === 240 /* VariableStatement */) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfVariableStatement(deferredExports[id], node.original);
                }
                return node;
            }
            function hasAssociatedEndOfDeclarationMarker(node) {
                return (getEmitFlags(node) & 8388608 /* HasEndOfDeclarationMarker */) !== 0;
            }
            function visitEndOfDeclarationMarker(node) {
                const id = getOriginalNodeId(node);
                const statements = deferredExports[id];
                if (statements) {
                    delete deferredExports[id];
                    return append(statements, node);
                }
                return node;
            }
            function appendExportsOfImportDeclaration(statements, decl) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                const importClause = decl.importClause;
                if (!importClause) {
                    return statements;
                }
                if (importClause.name) {
                    statements = appendExportsOfDeclaration(statements, importClause);
                }
                const namedBindings = importClause.namedBindings;
                if (namedBindings) {
                    switch (namedBindings.kind) {
                        case 271 /* NamespaceImport */:
                            statements = appendExportsOfDeclaration(statements, namedBindings);
                            break;
                        case 272 /* NamedImports */:
                            for (const importBinding of namedBindings.elements) {
                                statements = appendExportsOfDeclaration(statements, importBinding, 
                                /* liveBinding */
                                true);
                            }
                            break;
                    }
                }
                return statements;
            }
            function appendExportsOfImportEqualsDeclaration(statements, decl) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                return appendExportsOfDeclaration(statements, decl);
            }
            function appendExportsOfVariableStatement(statements, node) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                for (const decl of node.declarationList.declarations) {
                    statements = appendExportsOfBindingElement(statements, decl);
                }
                return statements;
            }
            function appendExportsOfBindingElement(statements, decl) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                if (isBindingPattern(decl.name)) {
                    for (const element of decl.name.elements) {
                        if (!isOmittedExpression(element)) {
                            statements = appendExportsOfBindingElement(statements, element);
                        }
                    }
                }
                else if (!isGeneratedIdentifier(decl.name)) {
                    statements = appendExportsOfDeclaration(statements, decl);
                }
                return statements;
            }
            function appendExportsOfHoistedDeclaration(statements, decl) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                if (hasSyntacticModifier(decl, 1 /* Export */)) {
                    const exportName = hasSyntacticModifier(decl, 1024 /* Default */) ? factory2.createIdentifier("default") : factory2.getDeclarationName(decl);
                    statements = appendExportStatement(statements, exportName, factory2.getLocalName(decl), 
                    /*location*/
                    decl);
                }
                if (decl.name) {
                    statements = appendExportsOfDeclaration(statements, decl);
                }
                return statements;
            }
            function appendExportsOfDeclaration(statements, decl, liveBinding) {
                const name = factory2.getDeclarationName(decl);
                const exportSpecifiers = currentModuleInfo.exportSpecifiers.get(idText(name));
                if (exportSpecifiers) {
                    for (const exportSpecifier of exportSpecifiers) {
                        statements = appendExportStatement(statements, exportSpecifier.name, name, 
                        /*location*/
                        exportSpecifier.name, 
                        /* allowComments */
                        void 0, liveBinding);
                    }
                }
                return statements;
            }
            function appendExportStatement(statements, exportName, expression, location, allowComments, liveBinding) {
                statements = append(statements, createExportStatement(exportName, expression, location, allowComments, liveBinding));
                return statements;
            }
            function createUnderscoreUnderscoreESModule() {
                let statement;
                if (languageVersion === 0 /* ES3 */) {
                    statement = factory2.createExpressionStatement(createExportExpression(factory2.createIdentifier("__esModule"), factory2.createTrue()));
                }
                else {
                    statement = factory2.createExpressionStatement(factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "defineProperty"), 
                    /*typeArguments*/
                    void 0, [
                        factory2.createIdentifier("exports"),
                        factory2.createStringLiteral("__esModule"),
                        factory2.createObjectLiteralExpression([
                            factory2.createPropertyAssignment("value", factory2.createTrue())
                        ])
                    ]));
                }
                setEmitFlags(statement, 2097152 /* CustomPrologue */);
                return statement;
            }
            function createExportStatement(name, value, location, allowComments, liveBinding) {
                const statement = setTextRange(factory2.createExpressionStatement(createExportExpression(name, value, 
                /* location */
                void 0, liveBinding)), location);
                startOnNewLine(statement);
                if (!allowComments) {
                    setEmitFlags(statement, 3072 /* NoComments */);
                }
                return statement;
            }
            function createExportExpression(name, value, location, liveBinding) {
                return setTextRange(liveBinding && languageVersion !== 0 /* ES3 */ ? factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "defineProperty"), 
                /*typeArguments*/
                void 0, [
                    factory2.createIdentifier("exports"),
                    factory2.createStringLiteralFromNode(name),
                    factory2.createObjectLiteralExpression([
                        factory2.createPropertyAssignment("enumerable", factory2.createTrue()),
                        factory2.createPropertyAssignment("get", factory2.createFunctionExpression(
                        /*modifiers*/
                        void 0, 
                        /*asteriskToken*/
                        void 0, 
                        /*name*/
                        void 0, 
                        /*typeParameters*/
                        void 0, 
                        /*parameters*/
                        [], 
                        /*type*/
                        void 0, factory2.createBlock([factory2.createReturnStatement(value)])))
                    ])
                ]) : factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), factory2.cloneNode(name)), value), location);
            }
            function modifierVisitor(node) {
                switch (node.kind) {
                    case 93 /* ExportKeyword */:
                    case 88 /* DefaultKeyword */:
                        return void 0;
                }
                return node;
            }
            function onEmitNode(hint, node, emitCallback) {
                if (node.kind === 308 /* SourceFile */) {
                    currentSourceFile = node;
                    currentModuleInfo = moduleInfoMap[getOriginalNodeId(currentSourceFile)];
                    previousOnEmitNode(hint, node, emitCallback);
                    currentSourceFile = void 0;
                    currentModuleInfo = void 0;
                }
                else {
                    previousOnEmitNode(hint, node, emitCallback);
                }
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (node.id && noSubstitution[node.id]) {
                    return node;
                }
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                else if (isShorthandPropertyAssignment(node)) {
                    return substituteShorthandPropertyAssignment(node);
                }
                return node;
            }
            function substituteShorthandPropertyAssignment(node) {
                const name = node.name;
                const exportedOrImportedName = substituteExpressionIdentifier(name);
                if (exportedOrImportedName !== name) {
                    if (node.objectAssignmentInitializer) {
                        const initializer = factory2.createAssignment(exportedOrImportedName, node.objectAssignmentInitializer);
                        return setTextRange(factory2.createPropertyAssignment(name, initializer), node);
                    }
                    return setTextRange(factory2.createPropertyAssignment(name, exportedOrImportedName), node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 210 /* CallExpression */:
                        return substituteCallExpression(node);
                    case 212 /* TaggedTemplateExpression */:
                        return substituteTaggedTemplateExpression(node);
                    case 223 /* BinaryExpression */:
                        return substituteBinaryExpression(node);
                }
                return node;
            }
            function substituteCallExpression(node) {
                if (isIdentifier(node.expression)) {
                    const expression = substituteExpressionIdentifier(node.expression);
                    noSubstitution[getNodeId(expression)] = true;
                    if (!isIdentifier(expression) && !(getEmitFlags(node.expression) & 8192 /* HelperName */)) {
                        return addInternalEmitFlags(factory2.updateCallExpression(node, expression, 
                        /*typeArguments*/
                        void 0, node.arguments), 16 /* IndirectCall */);
                    }
                }
                return node;
            }
            function substituteTaggedTemplateExpression(node) {
                if (isIdentifier(node.tag)) {
                    const tag = substituteExpressionIdentifier(node.tag);
                    noSubstitution[getNodeId(tag)] = true;
                    if (!isIdentifier(tag) && !(getEmitFlags(node.tag) & 8192 /* HelperName */)) {
                        return addInternalEmitFlags(factory2.updateTaggedTemplateExpression(node, tag, 
                        /*typeArguments*/
                        void 0, node.template), 16 /* IndirectCall */);
                    }
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                var _a2, _b;
                if (getEmitFlags(node) & 8192 /* HelperName */) {
                    const externalHelpersModuleName = getExternalHelpersModuleName(currentSourceFile);
                    if (externalHelpersModuleName) {
                        return factory2.createPropertyAccessExpression(externalHelpersModuleName, node);
                    }
                    return node;
                }
                else if (!(isGeneratedIdentifier(node) && !(node.emitNode.autoGenerate.flags & 64 /* AllowNameSubstitution */)) && !isLocalName(node)) {
                    const exportContainer = resolver.getReferencedExportContainer(node, isExportName(node));
                    if (exportContainer && exportContainer.kind === 308 /* SourceFile */) {
                        return setTextRange(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), factory2.cloneNode(node)), 
                        /*location*/
                        node);
                    }
                    const importDeclaration = resolver.getReferencedImportDeclaration(node);
                    if (importDeclaration) {
                        if (isImportClause(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(importDeclaration.parent), factory2.createIdentifier("default")), 
                            /*location*/
                            node);
                        }
                        else if (isImportSpecifier(importDeclaration)) {
                            const name = importDeclaration.propertyName || importDeclaration.name;
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(((_b = (_a2 = importDeclaration.parent) == null ? void 0 : _a2.parent) == null ? void 0 : _b.parent) || importDeclaration), factory2.cloneNode(name)), 
                            /*location*/
                            node);
                        }
                    }
                }
                return node;
            }
            function substituteBinaryExpression(node) {
                if (isAssignmentOperator(node.operatorToken.kind) && isIdentifier(node.left) && !isGeneratedIdentifier(node.left) && !isLocalName(node.left) && !isDeclarationNameOfEnumOrNamespace(node.left)) {
                    const exportedNames = getExports(node.left);
                    if (exportedNames) {
                        let expression = node;
                        for (const exportName of exportedNames) {
                            noSubstitution[getNodeId(expression)] = true;
                            expression = createExportExpression(exportName, expression, 
                            /*location*/
                            node);
                        }
                        return expression;
                    }
                }
                return node;
            }
            function getExports(name) {
                if (!isGeneratedIdentifier(name)) {
                    const valueDeclaration = resolver.getReferencedImportDeclaration(name) || resolver.getReferencedValueDeclaration(name);
                    if (valueDeclaration) {
                        return currentModuleInfo && currentModuleInfo.exportedBindings[getOriginalNodeId(valueDeclaration)];
                    }
                }
            }
        }
        var dynamicImportUMDHelper;
        var init_module = __esm({
            "src/compiler/transformers/module/module.ts"() {
                "use strict";
                init_ts2();
                dynamicImportUMDHelper = {
                    name: "typescript:dynamicimport-sync-require",
                    scoped: true,
                    text: `
            var __syncRequire = typeof module === "object" && typeof module.exports === "object";`
                };
            }
        });
        // src/compiler/transformers/module/system.ts
        function transformSystemModule(context) {
            const { factory: factory2, startLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const compilerOptions = context.getCompilerOptions();
            const resolver = context.getEmitResolver();
            const host = context.getEmitHost();
            const previousOnSubstituteNode = context.onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.enableSubstitution(79 /* Identifier */);
            context.enableSubstitution(300 /* ShorthandPropertyAssignment */);
            context.enableSubstitution(223 /* BinaryExpression */);
            context.enableSubstitution(233 /* MetaProperty */);
            context.enableEmitNotification(308 /* SourceFile */);
            const moduleInfoMap = [];
            const deferredExports = [];
            const exportFunctionsMap = [];
            const noSubstitutionMap = [];
            const contextObjectMap = [];
            let currentSourceFile;
            let moduleInfo;
            let exportFunction;
            let contextObject;
            let hoistedStatements;
            let enclosingBlockScopedContainer;
            let noSubstitution;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile || !(isEffectiveExternalModule(node, compilerOptions) || node.transformFlags & 8388608 /* ContainsDynamicImport */)) {
                    return node;
                }
                const id = getOriginalNodeId(node);
                currentSourceFile = node;
                enclosingBlockScopedContainer = node;
                moduleInfo = moduleInfoMap[id] = collectExternalModuleInfo(context, node, resolver, compilerOptions);
                exportFunction = factory2.createUniqueName("exports");
                exportFunctionsMap[id] = exportFunction;
                contextObject = contextObjectMap[id] = factory2.createUniqueName("context");
                const dependencyGroups = collectDependencyGroups(moduleInfo.externalImports);
                const moduleBodyBlock = createSystemModuleBody(node, dependencyGroups);
                const moduleBodyFunction = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, exportFunction),
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, contextObject)
                ], 
                /*type*/
                void 0, moduleBodyBlock);
                const moduleName = tryGetModuleNameFromFile(factory2, node, host, compilerOptions);
                const dependencies = factory2.createArrayLiteralExpression(map(dependencyGroups, (dependencyGroup) => dependencyGroup.name));
                const updated = setEmitFlags(factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray([
                    factory2.createExpressionStatement(factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("System"), "register"), 
                    /*typeArguments*/
                    void 0, moduleName ? [moduleName, dependencies, moduleBodyFunction] : [dependencies, moduleBodyFunction]))
                ]), node.statements)), 2048 /* NoTrailingComments */);
                if (!outFile(compilerOptions)) {
                    moveEmitHelpers(updated, moduleBodyBlock, (helper) => !helper.scoped);
                }
                if (noSubstitution) {
                    noSubstitutionMap[id] = noSubstitution;
                    noSubstitution = void 0;
                }
                currentSourceFile = void 0;
                moduleInfo = void 0;
                exportFunction = void 0;
                contextObject = void 0;
                hoistedStatements = void 0;
                enclosingBlockScopedContainer = void 0;
                return updated;
            }
            function collectDependencyGroups(externalImports) {
                const groupIndices = /* @__PURE__ */ new Map();
                const dependencyGroups = [];
                for (const externalImport of externalImports) {
                    const externalModuleName = getExternalModuleNameLiteral(factory2, externalImport, currentSourceFile, host, resolver, compilerOptions);
                    if (externalModuleName) {
                        const text = externalModuleName.text;
                        const groupIndex = groupIndices.get(text);
                        if (groupIndex !== void 0) {
                            dependencyGroups[groupIndex].externalImports.push(externalImport);
                        }
                        else {
                            groupIndices.set(text, dependencyGroups.length);
                            dependencyGroups.push({
                                name: externalModuleName,
                                externalImports: [externalImport]
                            });
                        }
                    }
                }
                return dependencyGroups;
            }
            function createSystemModuleBody(node, dependencyGroups) {
                const statements = [];
                startLexicalEnvironment();
                const ensureUseStrict = getStrictOptionValue(compilerOptions, "alwaysStrict") || !compilerOptions.noImplicitUseStrict && isExternalModule(currentSourceFile);
                const statementOffset = factory2.copyPrologue(node.statements, statements, ensureUseStrict, topLevelVisitor);
                statements.push(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration("__moduleName", 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createLogicalAnd(contextObject, factory2.createPropertyAccessExpression(contextObject, "id")))
                ])));
                visitNode(moduleInfo.externalHelpersImportDeclaration, topLevelVisitor, isStatement);
                const executeStatements = visitNodes2(node.statements, topLevelVisitor, isStatement, statementOffset);
                addRange(statements, hoistedStatements);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                const exportStarFunction = addExportStarIfNeeded(statements);
                const modifiers = node.transformFlags & 2097152 /* ContainsAwait */ ? factory2.createModifiersFromModifierFlags(512 /* Async */) : void 0;
                const moduleObject = factory2.createObjectLiteralExpression([
                    factory2.createPropertyAssignment("setters", createSettersArray(exportStarFunction, dependencyGroups)),
                    factory2.createPropertyAssignment("execute", factory2.createFunctionExpression(modifiers, 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, 
                    /*parameters*/
                    [], 
                    /*type*/
                    void 0, factory2.createBlock(executeStatements, 
                    /*multiLine*/
                    true)))
                ], 
                /*multiLine*/
                true);
                statements.push(factory2.createReturnStatement(moduleObject));
                return factory2.createBlock(statements, 
                /*multiLine*/
                true);
            }
            function addExportStarIfNeeded(statements) {
                if (!moduleInfo.hasExportStarsToExportValues) {
                    return;
                }
                if (!moduleInfo.exportedNames && moduleInfo.exportSpecifiers.size === 0) {
                    let hasExportDeclarationWithExportClause = false;
                    for (const externalImport of moduleInfo.externalImports) {
                        if (externalImport.kind === 275 /* ExportDeclaration */ && externalImport.exportClause) {
                            hasExportDeclarationWithExportClause = true;
                            break;
                        }
                    }
                    if (!hasExportDeclarationWithExportClause) {
                        const exportStarFunction2 = createExportStarFunction(
                        /*localNames*/
                        void 0);
                        statements.push(exportStarFunction2);
                        return exportStarFunction2.name;
                    }
                }
                const exportedNames = [];
                if (moduleInfo.exportedNames) {
                    for (const exportedLocalName of moduleInfo.exportedNames) {
                        if (exportedLocalName.escapedText === "default") {
                            continue;
                        }
                        exportedNames.push(factory2.createPropertyAssignment(factory2.createStringLiteralFromNode(exportedLocalName), factory2.createTrue()));
                    }
                }
                const exportedNamesStorageRef = factory2.createUniqueName("exportedNames");
                statements.push(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(exportedNamesStorageRef, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createObjectLiteralExpression(exportedNames, 
                    /*multiline*/
                    true))
                ])));
                const exportStarFunction = createExportStarFunction(exportedNamesStorageRef);
                statements.push(exportStarFunction);
                return exportStarFunction.name;
            }
            function createExportStarFunction(localNames) {
                const exportStarFunction = factory2.createUniqueName("exportStar");
                const m = factory2.createIdentifier("m");
                const n = factory2.createIdentifier("n");
                const exports = factory2.createIdentifier("exports");
                let condition = factory2.createStrictInequality(n, factory2.createStringLiteral("default"));
                if (localNames) {
                    condition = factory2.createLogicalAnd(condition, factory2.createLogicalNot(factory2.createCallExpression(factory2.createPropertyAccessExpression(localNames, "hasOwnProperty"), 
                    /*typeArguments*/
                    void 0, [n])));
                }
                return factory2.createFunctionDeclaration(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, exportStarFunction, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, m)], 
                /*type*/
                void 0, factory2.createBlock([
                    factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(exports, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.createObjectLiteralExpression([]))
                    ])),
                    factory2.createForInStatement(factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(n)
                    ]), m, factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(condition, factory2.createExpressionStatement(factory2.createAssignment(factory2.createElementAccessExpression(exports, n), factory2.createElementAccessExpression(m, n)))), 1 /* SingleLine */)
                    ])),
                    factory2.createExpressionStatement(factory2.createCallExpression(exportFunction, 
                    /*typeArguments*/
                    void 0, [exports]))
                ], 
                /*multiline*/
                true));
            }
            function createSettersArray(exportStarFunction, dependencyGroups) {
                const setters = [];
                for (const group2 of dependencyGroups) {
                    const localName = forEach(group2.externalImports, (i) => getLocalNameForExternalImport(factory2, i, currentSourceFile));
                    const parameterName = localName ? factory2.getGeneratedNameForNode(localName) : factory2.createUniqueName("");
                    const statements = [];
                    for (const entry of group2.externalImports) {
                        const importVariableName = getLocalNameForExternalImport(factory2, entry, currentSourceFile);
                        switch (entry.kind) {
                            case 269 /* ImportDeclaration */:
                                if (!entry.importClause) {
                                    break;
                                }
                            case 268 /* ImportEqualsDeclaration */:
                                Debug.assert(importVariableName !== void 0);
                                statements.push(factory2.createExpressionStatement(factory2.createAssignment(importVariableName, parameterName)));
                                if (hasSyntacticModifier(entry, 1 /* Export */)) {
                                    statements.push(factory2.createExpressionStatement(factory2.createCallExpression(exportFunction, 
                                    /*typeArguments*/
                                    void 0, [
                                        factory2.createStringLiteral(idText(importVariableName)),
                                        parameterName
                                    ])));
                                }
                                break;
                            case 275 /* ExportDeclaration */:
                                Debug.assert(importVariableName !== void 0);
                                if (entry.exportClause) {
                                    if (isNamedExports(entry.exportClause)) {
                                        const properties = [];
                                        for (const e of entry.exportClause.elements) {
                                            properties.push(factory2.createPropertyAssignment(factory2.createStringLiteral(idText(e.name)), factory2.createElementAccessExpression(parameterName, factory2.createStringLiteral(idText(e.propertyName || e.name)))));
                                        }
                                        statements.push(factory2.createExpressionStatement(factory2.createCallExpression(exportFunction, 
                                        /*typeArguments*/
                                        void 0, [factory2.createObjectLiteralExpression(properties, 
                                            /*multiline*/
                                            true)])));
                                    }
                                    else {
                                        statements.push(factory2.createExpressionStatement(factory2.createCallExpression(exportFunction, 
                                        /*typeArguments*/
                                        void 0, [
                                            factory2.createStringLiteral(idText(entry.exportClause.name)),
                                            parameterName
                                        ])));
                                    }
                                }
                                else {
                                    statements.push(factory2.createExpressionStatement(factory2.createCallExpression(exportStarFunction, 
                                    /*typeArguments*/
                                    void 0, [parameterName])));
                                }
                                break;
                        }
                    }
                    setters.push(factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, [factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, parameterName)], 
                    /*type*/
                    void 0, factory2.createBlock(statements, 
                    /*multiLine*/
                    true)));
                }
                return factory2.createArrayLiteralExpression(setters, 
                /*multiLine*/
                true);
            }
            function topLevelVisitor(node) {
                switch (node.kind) {
                    case 269 /* ImportDeclaration */:
                        return visitImportDeclaration(node);
                    case 268 /* ImportEqualsDeclaration */:
                        return visitImportEqualsDeclaration(node);
                    case 275 /* ExportDeclaration */:
                        return visitExportDeclaration(node);
                    case 274 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    default:
                        return topLevelNestedVisitor(node);
                }
            }
            function visitImportDeclaration(node) {
                let statements;
                if (node.importClause) {
                    hoistVariableDeclaration(getLocalNameForExternalImport(factory2, node, currentSourceFile));
                }
                if (hasAssociatedEndOfDeclarationMarker(node)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfImportDeclaration(deferredExports[id], node);
                }
                else {
                    statements = appendExportsOfImportDeclaration(statements, node);
                }
                return singleOrMany(statements);
            }
            function visitExportDeclaration(node) {
                Debug.assertIsDefined(node);
                return void 0;
            }
            function visitImportEqualsDeclaration(node) {
                Debug.assert(isExternalModuleImportEqualsDeclaration(node), "import= for internal module references should be handled in an earlier transformer.");
                let statements;
                hoistVariableDeclaration(getLocalNameForExternalImport(factory2, node, currentSourceFile));
                if (hasAssociatedEndOfDeclarationMarker(node)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfImportEqualsDeclaration(deferredExports[id], node);
                }
                else {
                    statements = appendExportsOfImportEqualsDeclaration(statements, node);
                }
                return singleOrMany(statements);
            }
            function visitExportAssignment(node) {
                if (node.isExportEquals) {
                    return void 0;
                }
                const expression = visitNode(node.expression, visitor, isExpression);
                const original = node.original;
                if (original && hasAssociatedEndOfDeclarationMarker(original)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportStatement(deferredExports[id], factory2.createIdentifier("default"), expression, 
                    /*allowComments*/
                    true);
                }
                else {
                    return createExportStatement(factory2.createIdentifier("default"), expression, 
                    /*allowComments*/
                    true);
                }
            }
            function visitFunctionDeclaration(node) {
                if (hasSyntacticModifier(node, 1 /* Export */)) {
                    hoistedStatements = append(hoistedStatements, factory2.updateFunctionDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifierLike), node.asteriskToken, factory2.getDeclarationName(node, 
                    /*allowComments*/
                    true, 
                    /*allowSourceMaps*/
                    true), 
                    /*typeParameters*/
                    void 0, visitNodes2(node.parameters, visitor, isParameter), 
                    /*type*/
                    void 0, visitNode(node.body, visitor, isBlock)));
                }
                else {
                    hoistedStatements = append(hoistedStatements, visitEachChild(node, visitor, context));
                }
                if (hasAssociatedEndOfDeclarationMarker(node)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfHoistedDeclaration(deferredExports[id], node);
                }
                else {
                    hoistedStatements = appendExportsOfHoistedDeclaration(hoistedStatements, node);
                }
                return void 0;
            }
            function visitClassDeclaration(node) {
                let statements;
                const name = factory2.getLocalName(node);
                hoistVariableDeclaration(name);
                statements = append(statements, setTextRange(factory2.createExpressionStatement(factory2.createAssignment(name, setTextRange(factory2.createClassExpression(visitNodes2(node.modifiers, modifierVisitor, isModifierLike), node.name, 
                /*typeParameters*/
                void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), visitNodes2(node.members, visitor, isClassElement)), node))), node));
                if (hasAssociatedEndOfDeclarationMarker(node)) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfHoistedDeclaration(deferredExports[id], node);
                }
                else {
                    statements = appendExportsOfHoistedDeclaration(statements, node);
                }
                return singleOrMany(statements);
            }
            function visitVariableStatement(node) {
                if (!shouldHoistVariableDeclarationList(node.declarationList)) {
                    return visitNode(node, visitor, isStatement);
                }
                let expressions;
                const isExportedDeclaration = hasSyntacticModifier(node, 1 /* Export */);
                const isMarkedDeclaration = hasAssociatedEndOfDeclarationMarker(node);
                for (const variable of node.declarationList.declarations) {
                    if (variable.initializer) {
                        expressions = append(expressions, transformInitializedVariable(variable, isExportedDeclaration && !isMarkedDeclaration));
                    }
                    else {
                        hoistBindingElement(variable);
                    }
                }
                let statements;
                if (expressions) {
                    statements = append(statements, setTextRange(factory2.createExpressionStatement(factory2.inlineExpressions(expressions)), node));
                }
                if (isMarkedDeclaration) {
                    const id = getOriginalNodeId(node);
                    deferredExports[id] = appendExportsOfVariableStatement(deferredExports[id], node, isExportedDeclaration);
                }
                else {
                    statements = appendExportsOfVariableStatement(statements, node, 
                    /*exportSelf*/
                    false);
                }
                return singleOrMany(statements);
            }
            function hoistBindingElement(node) {
                if (isBindingPattern(node.name)) {
                    for (const element of node.name.elements) {
                        if (!isOmittedExpression(element)) {
                            hoistBindingElement(element);
                        }
                    }
                }
                else {
                    hoistVariableDeclaration(factory2.cloneNode(node.name));
                }
            }
            function shouldHoistVariableDeclarationList(node) {
                return (getEmitFlags(node) & 4194304 /* NoHoisting */) === 0 && (enclosingBlockScopedContainer.kind === 308 /* SourceFile */ || (getOriginalNode(node).flags & 3 /* BlockScoped */) === 0);
            }
            function transformInitializedVariable(node, isExportedDeclaration) {
                const createAssignment = isExportedDeclaration ? createExportedVariableAssignment : createNonExportedVariableAssignment;
                return isBindingPattern(node.name) ? flattenDestructuringAssignment(node, visitor, context, 0 /* All */, 
                /*needsValue*/
                false, createAssignment) : node.initializer ? createAssignment(node.name, visitNode(node.initializer, visitor, isExpression)) : node.name;
            }
            function createExportedVariableAssignment(name, value, location) {
                return createVariableAssignment(name, value, location, 
                /*isExportedDeclaration*/
                true);
            }
            function createNonExportedVariableAssignment(name, value, location) {
                return createVariableAssignment(name, value, location, 
                /*isExportedDeclaration*/
                false);
            }
            function createVariableAssignment(name, value, location, isExportedDeclaration) {
                hoistVariableDeclaration(factory2.cloneNode(name));
                return isExportedDeclaration ? createExportExpression(name, preventSubstitution(setTextRange(factory2.createAssignment(name, value), location))) : preventSubstitution(setTextRange(factory2.createAssignment(name, value), location));
            }
            function visitMergeDeclarationMarker(node) {
                if (hasAssociatedEndOfDeclarationMarker(node) && node.original.kind === 240 /* VariableStatement */) {
                    const id = getOriginalNodeId(node);
                    const isExportedDeclaration = hasSyntacticModifier(node.original, 1 /* Export */);
                    deferredExports[id] = appendExportsOfVariableStatement(deferredExports[id], node.original, isExportedDeclaration);
                }
                return node;
            }
            function hasAssociatedEndOfDeclarationMarker(node) {
                return (getEmitFlags(node) & 8388608 /* HasEndOfDeclarationMarker */) !== 0;
            }
            function visitEndOfDeclarationMarker(node) {
                const id = getOriginalNodeId(node);
                const statements = deferredExports[id];
                if (statements) {
                    delete deferredExports[id];
                    return append(statements, node);
                }
                else {
                    const original = getOriginalNode(node);
                    if (isModuleOrEnumDeclaration(original)) {
                        return append(appendExportsOfDeclaration(statements, original), node);
                    }
                }
                return node;
            }
            function appendExportsOfImportDeclaration(statements, decl) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                const importClause = decl.importClause;
                if (!importClause) {
                    return statements;
                }
                if (importClause.name) {
                    statements = appendExportsOfDeclaration(statements, importClause);
                }
                const namedBindings = importClause.namedBindings;
                if (namedBindings) {
                    switch (namedBindings.kind) {
                        case 271 /* NamespaceImport */:
                            statements = appendExportsOfDeclaration(statements, namedBindings);
                            break;
                        case 272 /* NamedImports */:
                            for (const importBinding of namedBindings.elements) {
                                statements = appendExportsOfDeclaration(statements, importBinding);
                            }
                            break;
                    }
                }
                return statements;
            }
            function appendExportsOfImportEqualsDeclaration(statements, decl) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                return appendExportsOfDeclaration(statements, decl);
            }
            function appendExportsOfVariableStatement(statements, node, exportSelf) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                for (const decl of node.declarationList.declarations) {
                    if (decl.initializer || exportSelf) {
                        statements = appendExportsOfBindingElement(statements, decl, exportSelf);
                    }
                }
                return statements;
            }
            function appendExportsOfBindingElement(statements, decl, exportSelf) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                if (isBindingPattern(decl.name)) {
                    for (const element of decl.name.elements) {
                        if (!isOmittedExpression(element)) {
                            statements = appendExportsOfBindingElement(statements, element, exportSelf);
                        }
                    }
                }
                else if (!isGeneratedIdentifier(decl.name)) {
                    let excludeName;
                    if (exportSelf) {
                        statements = appendExportStatement(statements, decl.name, factory2.getLocalName(decl));
                        excludeName = idText(decl.name);
                    }
                    statements = appendExportsOfDeclaration(statements, decl, excludeName);
                }
                return statements;
            }
            function appendExportsOfHoistedDeclaration(statements, decl) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                let excludeName;
                if (hasSyntacticModifier(decl, 1 /* Export */)) {
                    const exportName = hasSyntacticModifier(decl, 1024 /* Default */) ? factory2.createStringLiteral("default") : decl.name;
                    statements = appendExportStatement(statements, exportName, factory2.getLocalName(decl));
                    excludeName = getTextOfIdentifierOrLiteral(exportName);
                }
                if (decl.name) {
                    statements = appendExportsOfDeclaration(statements, decl, excludeName);
                }
                return statements;
            }
            function appendExportsOfDeclaration(statements, decl, excludeName) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                const name = factory2.getDeclarationName(decl);
                const exportSpecifiers = moduleInfo.exportSpecifiers.get(idText(name));
                if (exportSpecifiers) {
                    for (const exportSpecifier of exportSpecifiers) {
                        if (exportSpecifier.name.escapedText !== excludeName) {
                            statements = appendExportStatement(statements, exportSpecifier.name, name);
                        }
                    }
                }
                return statements;
            }
            function appendExportStatement(statements, exportName, expression, allowComments) {
                statements = append(statements, createExportStatement(exportName, expression, allowComments));
                return statements;
            }
            function createExportStatement(name, value, allowComments) {
                const statement = factory2.createExpressionStatement(createExportExpression(name, value));
                startOnNewLine(statement);
                if (!allowComments) {
                    setEmitFlags(statement, 3072 /* NoComments */);
                }
                return statement;
            }
            function createExportExpression(name, value) {
                const exportName = isIdentifier(name) ? factory2.createStringLiteralFromNode(name) : name;
                setEmitFlags(value, getEmitFlags(value) | 3072 /* NoComments */);
                return setCommentRange(factory2.createCallExpression(exportFunction, 
                /*typeArguments*/
                void 0, [exportName, value]), value);
            }
            function topLevelNestedVisitor(node) {
                switch (node.kind) {
                    case 240 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 259 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 260 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 245 /* ForStatement */:
                        return visitForStatement(node, 
                        /*isTopLevel*/
                        true);
                    case 246 /* ForInStatement */:
                        return visitForInStatement(node);
                    case 247 /* ForOfStatement */:
                        return visitForOfStatement(node);
                    case 243 /* DoStatement */:
                        return visitDoStatement(node);
                    case 244 /* WhileStatement */:
                        return visitWhileStatement(node);
                    case 253 /* LabeledStatement */:
                        return visitLabeledStatement(node);
                    case 251 /* WithStatement */:
                        return visitWithStatement(node);
                    case 252 /* SwitchStatement */:
                        return visitSwitchStatement(node);
                    case 266 /* CaseBlock */:
                        return visitCaseBlock(node);
                    case 292 /* CaseClause */:
                        return visitCaseClause(node);
                    case 293 /* DefaultClause */:
                        return visitDefaultClause(node);
                    case 255 /* TryStatement */:
                        return visitTryStatement(node);
                    case 295 /* CatchClause */:
                        return visitCatchClause(node);
                    case 238 /* Block */:
                        return visitBlock(node);
                    case 358 /* MergeDeclarationMarker */:
                        return visitMergeDeclarationMarker(node);
                    case 359 /* EndOfDeclarationMarker */:
                        return visitEndOfDeclarationMarker(node);
                    default:
                        return visitor(node);
                }
            }
            function visitForStatement(node, isTopLevel) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateForStatement(node, visitNode(node.initializer, isTopLevel ? visitForInitializer : discardedValueVisitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, discardedValueVisitor, isExpression), visitIterationBody(node.statement, isTopLevel ? topLevelNestedVisitor : visitor, context));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitForInStatement(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateForInStatement(node, visitForInitializer(node.initializer), visitNode(node.expression, visitor, isExpression), visitIterationBody(node.statement, topLevelNestedVisitor, context));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitForOfStatement(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateForOfStatement(node, node.awaitModifier, visitForInitializer(node.initializer), visitNode(node.expression, visitor, isExpression), visitIterationBody(node.statement, topLevelNestedVisitor, context));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function shouldHoistForInitializer(node) {
                return isVariableDeclarationList(node) && shouldHoistVariableDeclarationList(node);
            }
            function visitForInitializer(node) {
                if (shouldHoistForInitializer(node)) {
                    let expressions;
                    for (const variable of node.declarations) {
                        expressions = append(expressions, transformInitializedVariable(variable, 
                        /*isExportedDeclaration*/
                        false));
                        if (!variable.initializer) {
                            hoistBindingElement(variable);
                        }
                    }
                    return expressions ? factory2.inlineExpressions(expressions) : factory2.createOmittedExpression();
                }
                else {
                    return visitNode(node, discardedValueVisitor, isForInitializer);
                }
            }
            function visitDoStatement(node) {
                return factory2.updateDoStatement(node, visitIterationBody(node.statement, topLevelNestedVisitor, context), visitNode(node.expression, visitor, isExpression));
            }
            function visitWhileStatement(node) {
                return factory2.updateWhileStatement(node, visitNode(node.expression, visitor, isExpression), visitIterationBody(node.statement, topLevelNestedVisitor, context));
            }
            function visitLabeledStatement(node) {
                return factory2.updateLabeledStatement(node, node.label, Debug.checkDefined(visitNode(node.statement, topLevelNestedVisitor, isStatement, factory2.liftToBlock)));
            }
            function visitWithStatement(node) {
                return factory2.updateWithStatement(node, visitNode(node.expression, visitor, isExpression), Debug.checkDefined(visitNode(node.statement, topLevelNestedVisitor, isStatement, factory2.liftToBlock)));
            }
            function visitSwitchStatement(node) {
                return factory2.updateSwitchStatement(node, visitNode(node.expression, visitor, isExpression), Debug.checkDefined(visitNode(node.caseBlock, topLevelNestedVisitor, isCaseBlock)));
            }
            function visitCaseBlock(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateCaseBlock(node, visitNodes2(node.clauses, topLevelNestedVisitor, isCaseOrDefaultClause));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitCaseClause(node) {
                return factory2.updateCaseClause(node, visitNode(node.expression, visitor, isExpression), visitNodes2(node.statements, topLevelNestedVisitor, isStatement));
            }
            function visitDefaultClause(node) {
                return visitEachChild(node, topLevelNestedVisitor, context);
            }
            function visitTryStatement(node) {
                return visitEachChild(node, topLevelNestedVisitor, context);
            }
            function visitCatchClause(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateCatchClause(node, node.variableDeclaration, Debug.checkDefined(visitNode(node.block, topLevelNestedVisitor, isBlock)));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitBlock(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = visitEachChild(node, topLevelNestedVisitor, context);
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitorWorker(node, valueIsDiscarded) {
                if (!(node.transformFlags & (4096 /* ContainsDestructuringAssignment */ | 8388608 /* ContainsDynamicImport */ | 268435456 /* ContainsUpdateExpressionForIdentifier */))) {
                    return node;
                }
                switch (node.kind) {
                    case 245 /* ForStatement */:
                        return visitForStatement(node, 
                        /*isTopLevel*/
                        false);
                    case 241 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 214 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, valueIsDiscarded);
                    case 356 /* PartiallyEmittedExpression */:
                        return visitPartiallyEmittedExpression(node, valueIsDiscarded);
                    case 223 /* BinaryExpression */:
                        if (isDestructuringAssignment(node)) {
                            return visitDestructuringAssignment(node, valueIsDiscarded);
                        }
                        break;
                    case 210 /* CallExpression */:
                        if (isImportCall(node)) {
                            return visitImportCallExpression(node);
                        }
                        break;
                    case 221 /* PrefixUnaryExpression */:
                    case 222 /* PostfixUnaryExpression */:
                        return visitPrefixOrPostfixUnaryExpression(node, valueIsDiscarded);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                return visitorWorker(node, 
                /*valueIsDiscarded*/
                false);
            }
            function discardedValueVisitor(node) {
                return visitorWorker(node, 
                /*valueIsDiscarded*/
                true);
            }
            function visitExpressionStatement(node) {
                return factory2.updateExpressionStatement(node, visitNode(node.expression, discardedValueVisitor, isExpression));
            }
            function visitParenthesizedExpression(node, valueIsDiscarded) {
                return factory2.updateParenthesizedExpression(node, visitNode(node.expression, valueIsDiscarded ? discardedValueVisitor : visitor, isExpression));
            }
            function visitPartiallyEmittedExpression(node, valueIsDiscarded) {
                return factory2.updatePartiallyEmittedExpression(node, visitNode(node.expression, valueIsDiscarded ? discardedValueVisitor : visitor, isExpression));
            }
            function visitImportCallExpression(node) {
                const externalModuleName = getExternalModuleNameLiteral(factory2, node, currentSourceFile, host, resolver, compilerOptions);
                const firstArgument = visitNode(firstOrUndefined(node.arguments), visitor, isExpression);
                const argument = externalModuleName && (!firstArgument || !isStringLiteral(firstArgument) || firstArgument.text !== externalModuleName.text) ? externalModuleName : firstArgument;
                return factory2.createCallExpression(factory2.createPropertyAccessExpression(contextObject, factory2.createIdentifier("import")), 
                /*typeArguments*/
                void 0, argument ? [argument] : []);
            }
            function visitDestructuringAssignment(node, valueIsDiscarded) {
                if (hasExportedReferenceInDestructuringTarget(node.left)) {
                    return flattenDestructuringAssignment(node, visitor, context, 0 /* All */, !valueIsDiscarded);
                }
                return visitEachChild(node, visitor, context);
            }
            function hasExportedReferenceInDestructuringTarget(node) {
                if (isAssignmentExpression(node, 
                /*excludeCompoundAssignment*/
                true)) {
                    return hasExportedReferenceInDestructuringTarget(node.left);
                }
                else if (isSpreadElement(node)) {
                    return hasExportedReferenceInDestructuringTarget(node.expression);
                }
                else if (isObjectLiteralExpression(node)) {
                    return some(node.properties, hasExportedReferenceInDestructuringTarget);
                }
                else if (isArrayLiteralExpression(node)) {
                    return some(node.elements, hasExportedReferenceInDestructuringTarget);
                }
                else if (isShorthandPropertyAssignment(node)) {
                    return hasExportedReferenceInDestructuringTarget(node.name);
                }
                else if (isPropertyAssignment(node)) {
                    return hasExportedReferenceInDestructuringTarget(node.initializer);
                }
                else if (isIdentifier(node)) {
                    const container = resolver.getReferencedExportContainer(node);
                    return container !== void 0 && container.kind === 308 /* SourceFile */;
                }
                else {
                    return false;
                }
            }
            function visitPrefixOrPostfixUnaryExpression(node, valueIsDiscarded) {
                if ((node.operator === 45 /* PlusPlusToken */ || node.operator === 46 /* MinusMinusToken */) && isIdentifier(node.operand) && !isGeneratedIdentifier(node.operand) && !isLocalName(node.operand) && !isDeclarationNameOfEnumOrNamespace(node.operand)) {
                    const exportedNames = getExports(node.operand);
                    if (exportedNames) {
                        let temp;
                        let expression = visitNode(node.operand, visitor, isExpression);
                        if (isPrefixUnaryExpression(node)) {
                            expression = factory2.updatePrefixUnaryExpression(node, expression);
                        }
                        else {
                            expression = factory2.updatePostfixUnaryExpression(node, expression);
                            if (!valueIsDiscarded) {
                                temp = factory2.createTempVariable(hoistVariableDeclaration);
                                expression = factory2.createAssignment(temp, expression);
                                setTextRange(expression, node);
                            }
                            expression = factory2.createComma(expression, factory2.cloneNode(node.operand));
                            setTextRange(expression, node);
                        }
                        for (const exportName of exportedNames) {
                            expression = createExportExpression(exportName, preventSubstitution(expression));
                        }
                        if (temp) {
                            expression = factory2.createComma(expression, temp);
                            setTextRange(expression, node);
                        }
                        return expression;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function modifierVisitor(node) {
                switch (node.kind) {
                    case 93 /* ExportKeyword */:
                    case 88 /* DefaultKeyword */:
                        return void 0;
                }
                return node;
            }
            function onEmitNode(hint, node, emitCallback) {
                if (node.kind === 308 /* SourceFile */) {
                    const id = getOriginalNodeId(node);
                    currentSourceFile = node;
                    moduleInfo = moduleInfoMap[id];
                    exportFunction = exportFunctionsMap[id];
                    noSubstitution = noSubstitutionMap[id];
                    contextObject = contextObjectMap[id];
                    if (noSubstitution) {
                        delete noSubstitutionMap[id];
                    }
                    previousOnEmitNode(hint, node, emitCallback);
                    currentSourceFile = void 0;
                    moduleInfo = void 0;
                    exportFunction = void 0;
                    contextObject = void 0;
                    noSubstitution = void 0;
                }
                else {
                    previousOnEmitNode(hint, node, emitCallback);
                }
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (isSubstitutionPrevented(node)) {
                    return node;
                }
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                else if (hint === 4 /* Unspecified */) {
                    return substituteUnspecified(node);
                }
                return node;
            }
            function substituteUnspecified(node) {
                switch (node.kind) {
                    case 300 /* ShorthandPropertyAssignment */:
                        return substituteShorthandPropertyAssignment(node);
                }
                return node;
            }
            function substituteShorthandPropertyAssignment(node) {
                var _a2, _b;
                const name = node.name;
                if (!isGeneratedIdentifier(name) && !isLocalName(name)) {
                    const importDeclaration = resolver.getReferencedImportDeclaration(name);
                    if (importDeclaration) {
                        if (isImportClause(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAssignment(factory2.cloneNode(name), factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(importDeclaration.parent), factory2.createIdentifier("default"))), 
                            /*location*/
                            node);
                        }
                        else if (isImportSpecifier(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAssignment(factory2.cloneNode(name), factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(((_b = (_a2 = importDeclaration.parent) == null ? void 0 : _a2.parent) == null ? void 0 : _b.parent) || importDeclaration), factory2.cloneNode(importDeclaration.propertyName || importDeclaration.name))), 
                            /*location*/
                            node);
                        }
                    }
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 223 /* BinaryExpression */:
                        return substituteBinaryExpression(node);
                    case 233 /* MetaProperty */:
                        return substituteMetaProperty(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                var _a2, _b;
                if (getEmitFlags(node) & 8192 /* HelperName */) {
                    const externalHelpersModuleName = getExternalHelpersModuleName(currentSourceFile);
                    if (externalHelpersModuleName) {
                        return factory2.createPropertyAccessExpression(externalHelpersModuleName, node);
                    }
                    return node;
                }
                if (!isGeneratedIdentifier(node) && !isLocalName(node)) {
                    const importDeclaration = resolver.getReferencedImportDeclaration(node);
                    if (importDeclaration) {
                        if (isImportClause(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(importDeclaration.parent), factory2.createIdentifier("default")), 
                            /*location*/
                            node);
                        }
                        else if (isImportSpecifier(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(((_b = (_a2 = importDeclaration.parent) == null ? void 0 : _a2.parent) == null ? void 0 : _b.parent) || importDeclaration), factory2.cloneNode(importDeclaration.propertyName || importDeclaration.name)), 
                            /*location*/
                            node);
                        }
                    }
                }
                return node;
            }
            function substituteBinaryExpression(node) {
                if (isAssignmentOperator(node.operatorToken.kind) && isIdentifier(node.left) && !isGeneratedIdentifier(node.left) && !isLocalName(node.left) && !isDeclarationNameOfEnumOrNamespace(node.left)) {
                    const exportedNames = getExports(node.left);
                    if (exportedNames) {
                        let expression = node;
                        for (const exportName of exportedNames) {
                            expression = createExportExpression(exportName, preventSubstitution(expression));
                        }
                        return expression;
                    }
                }
                return node;
            }
            function substituteMetaProperty(node) {
                if (isImportMeta(node)) {
                    return factory2.createPropertyAccessExpression(contextObject, factory2.createIdentifier("meta"));
                }
                return node;
            }
            function getExports(name) {
                let exportedNames;
                if (!isGeneratedIdentifier(name)) {
                    const valueDeclaration = resolver.getReferencedImportDeclaration(name) || resolver.getReferencedValueDeclaration(name);
                    if (valueDeclaration) {
                        const exportContainer = resolver.getReferencedExportContainer(name, 
                        /*prefixLocals*/
                        false);
                        if (exportContainer && exportContainer.kind === 308 /* SourceFile */) {
                            exportedNames = append(exportedNames, factory2.getDeclarationName(valueDeclaration));
                        }
                        exportedNames = addRange(exportedNames, moduleInfo && moduleInfo.exportedBindings[getOriginalNodeId(valueDeclaration)]);
                    }
                }
                return exportedNames;
            }
            function preventSubstitution(node) {
                if (noSubstitution === void 0)
                    noSubstitution = [];
                noSubstitution[getNodeId(node)] = true;
                return node;
            }
            function isSubstitutionPrevented(node) {
                return noSubstitution && node.id && noSubstitution[node.id];
            }
        }
        var init_system = __esm({
            "src/compiler/transformers/module/system.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/module/esnextAnd2015.ts
        function transformECMAScriptModule(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers } = context;
            const host = context.getEmitHost();
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const previousOnEmitNode = context.onEmitNode;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.enableEmitNotification(308 /* SourceFile */);
            context.enableSubstitution(79 /* Identifier */);
            let helperNameSubstitutions;
            let currentSourceFile;
            let importRequireStatements;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                if (isExternalModule(node) || getIsolatedModules(compilerOptions)) {
                    currentSourceFile = node;
                    importRequireStatements = void 0;
                    let result = updateExternalModule(node);
                    currentSourceFile = void 0;
                    if (importRequireStatements) {
                        result = factory2.updateSourceFile(result, setTextRange(factory2.createNodeArray(insertStatementsAfterCustomPrologue(result.statements.slice(), importRequireStatements)), result.statements));
                    }
                    if (!isExternalModule(node) || some(result.statements, isExternalModuleIndicator)) {
                        return result;
                    }
                    return factory2.updateSourceFile(result, setTextRange(factory2.createNodeArray([...result.statements, createEmptyExports(factory2)]), result.statements));
                }
                return node;
            }
            function updateExternalModule(node) {
                const externalHelpersImportDeclaration = createExternalHelpersImportDeclarationIfNeeded(factory2, emitHelpers(), node, compilerOptions);
                if (externalHelpersImportDeclaration) {
                    const statements = [];
                    const statementOffset = factory2.copyPrologue(node.statements, statements);
                    append(statements, externalHelpersImportDeclaration);
                    addRange(statements, visitNodes2(node.statements, visitor, isStatement, statementOffset));
                    return factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray(statements), node.statements));
                }
                else {
                    return visitEachChild(node, visitor, context);
                }
            }
            function visitor(node) {
                switch (node.kind) {
                    case 268 /* ImportEqualsDeclaration */:
                        return getEmitModuleKind(compilerOptions) >= 100 /* Node16 */ ? visitImportEqualsDeclaration(node) : void 0;
                    case 274 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    case 275 /* ExportDeclaration */:
                        const exportDecl = node;
                        return visitExportDeclaration(exportDecl);
                }
                return node;
            }
            function createRequireCall2(importNode) {
                const moduleName = getExternalModuleNameLiteral(factory2, importNode, Debug.checkDefined(currentSourceFile), host, resolver, compilerOptions);
                const args = [];
                if (moduleName) {
                    args.push(moduleName);
                }
                if (!importRequireStatements) {
                    const createRequireName = factory2.createUniqueName("_createRequire", 16 /* Optimistic */ | 32 /* FileLevel */);
                    const importStatement = factory2.createImportDeclaration(
                    /*modifiers*/
                    void 0, factory2.createImportClause(
                    /*isTypeOnly*/
                    false, 
                    /*name*/
                    void 0, factory2.createNamedImports([
                        factory2.createImportSpecifier(
                        /*isTypeOnly*/
                        false, factory2.createIdentifier("createRequire"), createRequireName)
                    ])), factory2.createStringLiteral("module"));
                    const requireHelperName = factory2.createUniqueName("__require", 16 /* Optimistic */ | 32 /* FileLevel */);
                    const requireStatement = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(requireHelperName, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.createCallExpression(factory2.cloneNode(createRequireName), 
                        /*typeArguments*/
                        void 0, [
                            factory2.createPropertyAccessExpression(factory2.createMetaProperty(100 /* ImportKeyword */, factory2.createIdentifier("meta")), factory2.createIdentifier("url"))
                        ]))
                    ], 
                    /*flags*/
                    languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */));
                    importRequireStatements = [importStatement, requireStatement];
                }
                const name = importRequireStatements[1].declarationList.declarations[0].name;
                Debug.assertNode(name, isIdentifier);
                return factory2.createCallExpression(factory2.cloneNode(name), 
                /*typeArguments*/
                void 0, args);
            }
            function visitImportEqualsDeclaration(node) {
                Debug.assert(isExternalModuleImportEqualsDeclaration(node), "import= for internal module references should be handled in an earlier transformer.");
                let statements;
                statements = append(statements, setOriginalNode(setTextRange(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(factory2.cloneNode(node.name), 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, createRequireCall2(node))
                ], 
                /*flags*/
                languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */)), node), node));
                statements = appendExportsOfImportEqualsDeclaration(statements, node);
                return singleOrMany(statements);
            }
            function appendExportsOfImportEqualsDeclaration(statements, node) {
                if (hasSyntacticModifier(node, 1 /* Export */)) {
                    statements = append(statements, factory2.createExportDeclaration(
                    /*modifiers*/
                    void 0, node.isTypeOnly, factory2.createNamedExports([factory2.createExportSpecifier(
                        /*isTypeOnly*/
                        false, 
                        /*propertyName*/
                        void 0, idText(node.name))])));
                }
                return statements;
            }
            function visitExportAssignment(node) {
                return node.isExportEquals ? void 0 : node;
            }
            function visitExportDeclaration(node) {
                if (compilerOptions.module !== void 0 && compilerOptions.module > 5 /* ES2015 */) {
                    return node;
                }
                if (!node.exportClause || !isNamespaceExport(node.exportClause) || !node.moduleSpecifier) {
                    return node;
                }
                const oldIdentifier = node.exportClause.name;
                const synthName = factory2.getGeneratedNameForNode(oldIdentifier);
                const importDecl = factory2.createImportDeclaration(
                /*modifiers*/
                void 0, factory2.createImportClause(
                /*isTypeOnly*/
                false, 
                /*name*/
                void 0, factory2.createNamespaceImport(synthName)), node.moduleSpecifier, node.assertClause);
                setOriginalNode(importDecl, node.exportClause);
                const exportDecl = isExportNamespaceAsDefaultDeclaration(node) ? factory2.createExportDefault(synthName) : factory2.createExportDeclaration(
                /*modifiers*/
                void 0, 
                /*isTypeOnly*/
                false, factory2.createNamedExports([factory2.createExportSpecifier(
                    /*isTypeOnly*/
                    false, synthName, oldIdentifier)]));
                setOriginalNode(exportDecl, node);
                return [importDecl, exportDecl];
            }
            function onEmitNode(hint, node, emitCallback) {
                if (isSourceFile(node)) {
                    if ((isExternalModule(node) || getIsolatedModules(compilerOptions)) && compilerOptions.importHelpers) {
                        helperNameSubstitutions = /* @__PURE__ */ new Map();
                    }
                    previousOnEmitNode(hint, node, emitCallback);
                    helperNameSubstitutions = void 0;
                }
                else {
                    previousOnEmitNode(hint, node, emitCallback);
                }
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (helperNameSubstitutions && isIdentifier(node) && getEmitFlags(node) & 8192 /* HelperName */) {
                    return substituteHelperName(node);
                }
                return node;
            }
            function substituteHelperName(node) {
                const name = idText(node);
                let substitution = helperNameSubstitutions.get(name);
                if (!substitution) {
                    helperNameSubstitutions.set(name, substitution = factory2.createUniqueName(name, 16 /* Optimistic */ | 32 /* FileLevel */));
                }
                return substitution;
            }
        }
        var init_esnextAnd2015 = __esm({
            "src/compiler/transformers/module/esnextAnd2015.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/module/node.ts
        function transformNodeModule(context) {
            const previousOnSubstituteNode = context.onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            const esmTransform = transformECMAScriptModule(context);
            const esmOnSubstituteNode = context.onSubstituteNode;
            const esmOnEmitNode = context.onEmitNode;
            context.onSubstituteNode = previousOnSubstituteNode;
            context.onEmitNode = previousOnEmitNode;
            const cjsTransform = transformModule(context);
            const cjsOnSubstituteNode = context.onSubstituteNode;
            const cjsOnEmitNode = context.onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.enableSubstitution(308 /* SourceFile */);
            context.enableEmitNotification(308 /* SourceFile */);
            let currentSourceFile;
            return transformSourceFileOrBundle;
            function onSubstituteNode(hint, node) {
                if (isSourceFile(node)) {
                    currentSourceFile = node;
                    return previousOnSubstituteNode(hint, node);
                }
                else {
                    if (!currentSourceFile) {
                        return previousOnSubstituteNode(hint, node);
                    }
                    if (currentSourceFile.impliedNodeFormat === 99 /* ESNext */) {
                        return esmOnSubstituteNode(hint, node);
                    }
                    return cjsOnSubstituteNode(hint, node);
                }
            }
            function onEmitNode(hint, node, emitCallback) {
                if (isSourceFile(node)) {
                    currentSourceFile = node;
                }
                if (!currentSourceFile) {
                    return previousOnEmitNode(hint, node, emitCallback);
                }
                if (currentSourceFile.impliedNodeFormat === 99 /* ESNext */) {
                    return esmOnEmitNode(hint, node, emitCallback);
                }
                return cjsOnEmitNode(hint, node, emitCallback);
            }
            function getModuleTransformForFile(file) {
                return file.impliedNodeFormat === 99 /* ESNext */ ? esmTransform : cjsTransform;
            }
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                const result = getModuleTransformForFile(node)(node);
                currentSourceFile = void 0;
                Debug.assert(isSourceFile(result));
                return result;
            }
            function transformSourceFileOrBundle(node) {
                return node.kind === 308 /* SourceFile */ ? transformSourceFile(node) : transformBundle(node);
            }
            function transformBundle(node) {
                return context.factory.createBundle(map(node.sourceFiles, transformSourceFile), node.prepends);
            }
        }
        var init_node = __esm({
            "src/compiler/transformers/module/node.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/declarations/diagnostics.ts
        function canProduceDiagnostics(node) {
            return isVariableDeclaration(node) || isPropertyDeclaration(node) || isPropertySignature(node) || isBindingElement(node) || isSetAccessor(node) || isGetAccessor(node) || isConstructSignatureDeclaration(node) || isCallSignatureDeclaration(node) || isMethodDeclaration(node) || isMethodSignature(node) || isFunctionDeclaration(node) || isParameter(node) || isTypeParameterDeclaration(node) || isExpressionWithTypeArguments(node) || isImportEqualsDeclaration(node) || isTypeAliasDeclaration(node) || isConstructorDeclaration(node) || isIndexSignatureDeclaration(node) || isPropertyAccessExpression(node) || isJSDocTypeAlias(node);
        }
        function createGetSymbolAccessibilityDiagnosticForNodeName(node) {
            if (isSetAccessor(node) || isGetAccessor(node)) {
                return getAccessorNameVisibilityError;
            }
            else if (isMethodSignature(node) || isMethodDeclaration(node)) {
                return getMethodNameVisibilityError;
            }
            else {
                return createGetSymbolAccessibilityDiagnosticForNode(node);
            }
            function getAccessorNameVisibilityError(symbolAccessibilityResult) {
                const diagnosticMessage = getAccessorNameVisibilityDiagnosticMessage(symbolAccessibilityResult);
                return diagnosticMessage !== void 0 ? {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                } : void 0;
            }
            function getAccessorNameVisibilityDiagnosticMessage(symbolAccessibilityResult) {
                if (isStatic(node)) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_private_name_1;
                }
                else if (node.parent.kind === 260 /* ClassDeclaration */) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_property_0_of_exported_class_has_or_is_using_private_name_1;
                }
                else {
                    return symbolAccessibilityResult.errorModuleName ? Diagnostics.Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Property_0_of_exported_interface_has_or_is_using_private_name_1;
                }
            }
            function getMethodNameVisibilityError(symbolAccessibilityResult) {
                const diagnosticMessage = getMethodNameVisibilityDiagnosticMessage(symbolAccessibilityResult);
                return diagnosticMessage !== void 0 ? {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                } : void 0;
            }
            function getMethodNameVisibilityDiagnosticMessage(symbolAccessibilityResult) {
                if (isStatic(node)) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_static_method_0_of_exported_class_has_or_is_using_private_name_1;
                }
                else if (node.parent.kind === 260 /* ClassDeclaration */) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_method_0_of_exported_class_has_or_is_using_private_name_1;
                }
                else {
                    return symbolAccessibilityResult.errorModuleName ? Diagnostics.Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Method_0_of_exported_interface_has_or_is_using_private_name_1;
                }
            }
        }
        function createGetSymbolAccessibilityDiagnosticForNode(node) {
            if (isVariableDeclaration(node) || isPropertyDeclaration(node) || isPropertySignature(node) || isPropertyAccessExpression(node) || isBindingElement(node) || isConstructorDeclaration(node)) {
                return getVariableDeclarationTypeVisibilityError;
            }
            else if (isSetAccessor(node) || isGetAccessor(node)) {
                return getAccessorDeclarationTypeVisibilityError;
            }
            else if (isConstructSignatureDeclaration(node) || isCallSignatureDeclaration(node) || isMethodDeclaration(node) || isMethodSignature(node) || isFunctionDeclaration(node) || isIndexSignatureDeclaration(node)) {
                return getReturnTypeVisibilityError;
            }
            else if (isParameter(node)) {
                if (isParameterPropertyDeclaration(node, node.parent) && hasSyntacticModifier(node.parent, 8 /* Private */)) {
                    return getVariableDeclarationTypeVisibilityError;
                }
                return getParameterDeclarationTypeVisibilityError;
            }
            else if (isTypeParameterDeclaration(node)) {
                return getTypeParameterConstraintVisibilityError;
            }
            else if (isExpressionWithTypeArguments(node)) {
                return getHeritageClauseVisibilityError;
            }
            else if (isImportEqualsDeclaration(node)) {
                return getImportEntityNameVisibilityError;
            }
            else if (isTypeAliasDeclaration(node) || isJSDocTypeAlias(node)) {
                return getTypeAliasDeclarationVisibilityError;
            }
            else {
                return Debug.assertNever(node, `Attempted to set a declaration diagnostic context for unhandled node kind: ${Debug.formatSyntaxKind(node.kind)}`);
            }
            function getVariableDeclarationTypeVisibilityDiagnosticMessage(symbolAccessibilityResult) {
                if (node.kind === 257 /* VariableDeclaration */ || node.kind === 205 /* BindingElement */) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Exported_variable_0_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Exported_variable_0_has_or_is_using_private_name_1;
                }
                else if (node.kind === 169 /* PropertyDeclaration */ || node.kind === 208 /* PropertyAccessExpression */ || node.kind === 168 /* PropertySignature */ || node.kind === 166 /* Parameter */ && hasSyntacticModifier(node.parent, 8 /* Private */)) {
                    if (isStatic(node)) {
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_private_name_1;
                    }
                    else if (node.parent.kind === 260 /* ClassDeclaration */ || node.kind === 166 /* Parameter */) {
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_property_0_of_exported_class_has_or_is_using_private_name_1;
                    }
                    else {
                        return symbolAccessibilityResult.errorModuleName ? Diagnostics.Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Property_0_of_exported_interface_has_or_is_using_private_name_1;
                    }
                }
            }
            function getVariableDeclarationTypeVisibilityError(symbolAccessibilityResult) {
                const diagnosticMessage = getVariableDeclarationTypeVisibilityDiagnosticMessage(symbolAccessibilityResult);
                return diagnosticMessage !== void 0 ? {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                } : void 0;
            }
            function getAccessorDeclarationTypeVisibilityError(symbolAccessibilityResult) {
                let diagnosticMessage;
                if (node.kind === 175 /* SetAccessor */) {
                    if (isStatic(node)) {
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1;
                    }
                    else {
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1;
                    }
                }
                else {
                    if (isStatic(node)) {
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1;
                    }
                    else {
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1;
                    }
                }
                return {
                    diagnosticMessage,
                    errorNode: node.name,
                    typeName: node.name
                };
            }
            function getReturnTypeVisibilityError(symbolAccessibilityResult) {
                let diagnosticMessage;
                switch (node.kind) {
                    case 177 /* ConstructSignature */:
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0;
                        break;
                    case 176 /* CallSignature */:
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0;
                        break;
                    case 178 /* IndexSignature */:
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0;
                        break;
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                        if (isStatic(node)) {
                            diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named : Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0;
                        }
                        else if (node.parent.kind === 260 /* ClassDeclaration */) {
                            diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named : Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0;
                        }
                        else {
                            diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0;
                        }
                        break;
                    case 259 /* FunctionDeclaration */:
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named : Diagnostics.Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_exported_function_has_or_is_using_private_name_0;
                        break;
                    default:
                        return Debug.fail("This is unknown kind for signature: " + node.kind);
                }
                return {
                    diagnosticMessage,
                    errorNode: node.name || node
                };
            }
            function getParameterDeclarationTypeVisibilityError(symbolAccessibilityResult) {
                const diagnosticMessage = getParameterDeclarationTypeVisibilityDiagnosticMessage(symbolAccessibilityResult);
                return diagnosticMessage !== void 0 ? {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                } : void 0;
            }
            function getParameterDeclarationTypeVisibilityDiagnosticMessage(symbolAccessibilityResult) {
                switch (node.parent.kind) {
                    case 173 /* Constructor */:
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1;
                    case 177 /* ConstructSignature */:
                    case 182 /* ConstructorType */:
                        return symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1;
                    case 176 /* CallSignature */:
                        return symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1;
                    case 178 /* IndexSignature */:
                        return symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1;
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                        if (isStatic(node.parent)) {
                            return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1;
                        }
                        else if (node.parent.parent.kind === 260 /* ClassDeclaration */) {
                            return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1;
                        }
                        else {
                            return symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1;
                        }
                    case 259 /* FunctionDeclaration */:
                    case 181 /* FunctionType */:
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_exported_function_has_or_is_using_private_name_1;
                    case 175 /* SetAccessor */:
                    case 174 /* GetAccessor */:
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_accessor_has_or_is_using_private_name_1;
                    default:
                        return Debug.fail(`Unknown parent for parameter: ${Debug.formatSyntaxKind(node.parent.kind)}`);
                }
            }
            function getTypeParameterConstraintVisibilityError() {
                let diagnosticMessage;
                switch (node.parent.kind) {
                    case 260 /* ClassDeclaration */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_class_has_or_is_using_private_name_1;
                        break;
                    case 261 /* InterfaceDeclaration */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1;
                        break;
                    case 197 /* MappedType */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1;
                        break;
                    case 182 /* ConstructorType */:
                    case 177 /* ConstructSignature */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1;
                        break;
                    case 176 /* CallSignature */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1;
                        break;
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                        if (isStatic(node.parent)) {
                            diagnosticMessage = Diagnostics.Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1;
                        }
                        else if (node.parent.parent.kind === 260 /* ClassDeclaration */) {
                            diagnosticMessage = Diagnostics.Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1;
                        }
                        else {
                            diagnosticMessage = Diagnostics.Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1;
                        }
                        break;
                    case 181 /* FunctionType */:
                    case 259 /* FunctionDeclaration */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_function_has_or_is_using_private_name_1;
                        break;
                    case 192 /* InferType */:
                        diagnosticMessage = Diagnostics.Extends_clause_for_inferred_type_0_has_or_is_using_private_name_1;
                        break;
                    case 262 /* TypeAliasDeclaration */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1;
                        break;
                    default:
                        return Debug.fail("This is unknown parent for type parameter: " + node.parent.kind);
                }
                return {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                };
            }
            function getHeritageClauseVisibilityError() {
                let diagnosticMessage;
                if (isClassDeclaration(node.parent.parent)) {
                    diagnosticMessage = isHeritageClause(node.parent) && node.parent.token === 117 /* ImplementsKeyword */ ? Diagnostics.Implements_clause_of_exported_class_0_has_or_is_using_private_name_1 : node.parent.parent.name ? Diagnostics.extends_clause_of_exported_class_0_has_or_is_using_private_name_1 : Diagnostics.extends_clause_of_exported_class_has_or_is_using_private_name_0;
                }
                else {
                    diagnosticMessage = Diagnostics.extends_clause_of_exported_interface_0_has_or_is_using_private_name_1;
                }
                return {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: getNameOfDeclaration(node.parent.parent)
                };
            }
            function getImportEntityNameVisibilityError() {
                return {
                    diagnosticMessage: Diagnostics.Import_declaration_0_is_using_private_name_1,
                    errorNode: node,
                    typeName: node.name
                };
            }
            function getTypeAliasDeclarationVisibilityError(symbolAccessibilityResult) {
                return {
                    diagnosticMessage: symbolAccessibilityResult.errorModuleName ? Diagnostics.Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2 : Diagnostics.Exported_type_alias_0_has_or_is_using_private_name_1,
                    errorNode: isJSDocTypeAlias(node) ? Debug.checkDefined(node.typeExpression) : node.type,
                    typeName: isJSDocTypeAlias(node) ? getNameOfDeclaration(node) : node.name
                };
            }
        }
        var init_diagnostics = __esm({
            "src/compiler/transformers/declarations/diagnostics.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/declarations.ts
        function getDeclarationDiagnostics(host, resolver, file) {
            const compilerOptions = host.getCompilerOptions();
            const result = transformNodes(resolver, host, factory, compilerOptions, file ? [file] : filter(host.getSourceFiles(), isSourceFileNotJson), [transformDeclarations], 
            /*allowDtsFiles*/
            false);
            return result.diagnostics;
        }
        function hasInternalAnnotation(range, currentSourceFile) {
            const comment = currentSourceFile.text.substring(range.pos, range.end);
            return stringContains(comment, "@internal");
        }
        function isInternalDeclaration(node, currentSourceFile) {
            const parseTreeNode = getParseTreeNode(node);
            if (parseTreeNode && parseTreeNode.kind === 166 /* Parameter */) {
                const paramIdx = parseTreeNode.parent.parameters.indexOf(parseTreeNode);
                const previousSibling = paramIdx > 0 ? parseTreeNode.parent.parameters[paramIdx - 1] : void 0;
                const text = currentSourceFile.text;
                const commentRanges = previousSibling ? concatenate(
                // to handle
                // ... parameters, /** @internal */
                // public param: string
                getTrailingCommentRanges(text, skipTrivia(text, previousSibling.end + 1, 
                /* stopAfterLineBreak */
                false, 
                /* stopAtComments */
                true)), getLeadingCommentRanges(text, node.pos)) : getTrailingCommentRanges(text, skipTrivia(text, node.pos, 
                /* stopAfterLineBreak */
                false, 
                /* stopAtComments */
                true));
                return commentRanges && commentRanges.length && hasInternalAnnotation(last(commentRanges), currentSourceFile);
            }
            const leadingCommentRanges = parseTreeNode && getLeadingCommentRangesOfNode(parseTreeNode, currentSourceFile);
            return !!forEach(leadingCommentRanges, (range) => {
                return hasInternalAnnotation(range, currentSourceFile);
            });
        }
        function transformDeclarations(context) {
            const throwDiagnostic = () => Debug.fail("Diagnostic emitted without context");
            let getSymbolAccessibilityDiagnostic = throwDiagnostic;
            let needsDeclare = true;
            let isBundledEmit = false;
            let resultHasExternalModuleIndicator = false;
            let needsScopeFixMarker = false;
            let resultHasScopeMarker = false;
            let enclosingDeclaration;
            let necessaryTypeReferences;
            let lateMarkedStatements;
            let lateStatementReplacementMap;
            let suppressNewDiagnosticContexts;
            let exportedModulesFromDeclarationEmit;
            const { factory: factory2 } = context;
            const host = context.getEmitHost();
            const symbolTracker = {
                trackSymbol,
                reportInaccessibleThisError,
                reportInaccessibleUniqueSymbolError,
                reportCyclicStructureError,
                reportPrivateInBaseOfClassExpression,
                reportLikelyUnsafeImportRequiredError,
                reportTruncationError,
                moduleResolverHost: host,
                trackReferencedAmbientModule,
                trackExternalModuleSymbolOfImportTypeNode,
                reportNonlocalAugmentation,
                reportNonSerializableProperty,
                reportImportTypeNodeResolutionModeOverride
            };
            let errorNameNode;
            let errorFallbackNode;
            let currentSourceFile;
            let refs;
            let libs2;
            let emittedImports;
            const resolver = context.getEmitResolver();
            const options = context.getCompilerOptions();
            const { noResolve, stripInternal } = options;
            return transformRoot;
            function recordTypeReferenceDirectivesIfNecessary(typeReferenceDirectives) {
                if (!typeReferenceDirectives) {
                    return;
                }
                necessaryTypeReferences = necessaryTypeReferences || /* @__PURE__ */ new Set();
                for (const ref of typeReferenceDirectives) {
                    necessaryTypeReferences.add(ref);
                }
            }
            function trackReferencedAmbientModule(node, symbol) {
                const directives = resolver.getTypeReferenceDirectivesForSymbol(symbol, 67108863 /* All */);
                if (length(directives)) {
                    return recordTypeReferenceDirectivesIfNecessary(directives);
                }
                const container = getSourceFileOfNode(node);
                refs.set(getOriginalNodeId(container), container);
            }
            function handleSymbolAccessibilityError(symbolAccessibilityResult) {
                if (symbolAccessibilityResult.accessibility === 0 /* Accessible */) {
                    if (symbolAccessibilityResult && symbolAccessibilityResult.aliasesToMakeVisible) {
                        if (!lateMarkedStatements) {
                            lateMarkedStatements = symbolAccessibilityResult.aliasesToMakeVisible;
                        }
                        else {
                            for (const ref of symbolAccessibilityResult.aliasesToMakeVisible) {
                                pushIfUnique(lateMarkedStatements, ref);
                            }
                        }
                    }
                }
                else {
                    const errorInfo = getSymbolAccessibilityDiagnostic(symbolAccessibilityResult);
                    if (errorInfo) {
                        if (errorInfo.typeName) {
                            context.addDiagnostic(createDiagnosticForNode(symbolAccessibilityResult.errorNode || errorInfo.errorNode, errorInfo.diagnosticMessage, getTextOfNode(errorInfo.typeName), symbolAccessibilityResult.errorSymbolName, symbolAccessibilityResult.errorModuleName));
                        }
                        else {
                            context.addDiagnostic(createDiagnosticForNode(symbolAccessibilityResult.errorNode || errorInfo.errorNode, errorInfo.diagnosticMessage, symbolAccessibilityResult.errorSymbolName, symbolAccessibilityResult.errorModuleName));
                        }
                        return true;
                    }
                }
                return false;
            }
            function trackExternalModuleSymbolOfImportTypeNode(symbol) {
                if (!isBundledEmit) {
                    (exportedModulesFromDeclarationEmit || (exportedModulesFromDeclarationEmit = [])).push(symbol);
                }
            }
            function trackSymbol(symbol, enclosingDeclaration2, meaning) {
                if (symbol.flags & 262144 /* TypeParameter */)
                    return false;
                const issuedDiagnostic = handleSymbolAccessibilityError(resolver.isSymbolAccessible(symbol, enclosingDeclaration2, meaning, 
                /*shouldComputeAliasesToMakeVisible*/
                true));
                recordTypeReferenceDirectivesIfNecessary(resolver.getTypeReferenceDirectivesForSymbol(symbol, meaning));
                return issuedDiagnostic;
            }
            function reportPrivateInBaseOfClassExpression(propertyName) {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.Property_0_of_exported_class_expression_may_not_be_private_or_protected, propertyName));
                }
            }
            function errorDeclarationNameWithFallback() {
                return errorNameNode ? declarationNameToString(errorNameNode) : errorFallbackNode && getNameOfDeclaration(errorFallbackNode) ? declarationNameToString(getNameOfDeclaration(errorFallbackNode)) : errorFallbackNode && isExportAssignment(errorFallbackNode) ? errorFallbackNode.isExportEquals ? "export=" : "default" : "(Missing)";
            }
            function reportInaccessibleUniqueSymbolError() {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary, errorDeclarationNameWithFallback(), "unique symbol"));
                }
            }
            function reportCyclicStructureError() {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialized_A_type_annotation_is_necessary, errorDeclarationNameWithFallback()));
                }
            }
            function reportInaccessibleThisError() {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary, errorDeclarationNameWithFallback(), "this"));
                }
            }
            function reportLikelyUnsafeImportRequiredError(specifier) {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_annotation_is_necessary, errorDeclarationNameWithFallback(), specifier));
                }
            }
            function reportTruncationError() {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_type_annotation_is_needed));
                }
            }
            function reportNonlocalAugmentation(containingFile, parentSymbol, symbol) {
                var _a2;
                const primaryDeclaration = (_a2 = parentSymbol.declarations) == null ? void 0 : _a2.find((d) => getSourceFileOfNode(d) === containingFile);
                const augmentingDeclarations = filter(symbol.declarations, (d) => getSourceFileOfNode(d) !== containingFile);
                if (primaryDeclaration && augmentingDeclarations) {
                    for (const augmentations of augmentingDeclarations) {
                        context.addDiagnostic(addRelatedInfo(createDiagnosticForNode(augmentations, Diagnostics.Declaration_augments_declaration_in_another_file_This_cannot_be_serialized), createDiagnosticForNode(primaryDeclaration, Diagnostics.This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_file)));
                    }
                }
            }
            function reportNonSerializableProperty(propertyName) {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized, propertyName));
                }
            }
            function reportImportTypeNodeResolutionModeOverride() {
                if (!isNightly() && (errorNameNode || errorFallbackNode)) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_type_of_this_expression_cannot_be_named_without_a_resolution_mode_assertion_which_is_an_unstable_feature_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next));
                }
            }
            function transformDeclarationsForJS(sourceFile, bundled) {
                const oldDiag = getSymbolAccessibilityDiagnostic;
                getSymbolAccessibilityDiagnostic = (s) => s.errorNode && canProduceDiagnostics(s.errorNode) ? createGetSymbolAccessibilityDiagnosticForNode(s.errorNode)(s) : {
                    diagnosticMessage: s.errorModuleName ? Diagnostics.Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotation_may_unblock_declaration_emit : Diagnostics.Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_declaration_emit,
                    errorNode: s.errorNode || sourceFile
                };
                const result = resolver.getDeclarationStatementsForSourceFile(sourceFile, declarationEmitNodeBuilderFlags, symbolTracker, bundled);
                getSymbolAccessibilityDiagnostic = oldDiag;
                return result;
            }
            function transformRoot(node) {
                if (node.kind === 308 /* SourceFile */ && node.isDeclarationFile) {
                    return node;
                }
                if (node.kind === 309 /* Bundle */) {
                    isBundledEmit = true;
                    refs = /* @__PURE__ */ new Map();
                    libs2 = /* @__PURE__ */ new Map();
                    let hasNoDefaultLib = false;
                    const bundle = factory2.createBundle(map(node.sourceFiles, (sourceFile) => {
                        if (sourceFile.isDeclarationFile)
                            return void 0;
                        hasNoDefaultLib = hasNoDefaultLib || sourceFile.hasNoDefaultLib;
                        currentSourceFile = sourceFile;
                        enclosingDeclaration = sourceFile;
                        lateMarkedStatements = void 0;
                        suppressNewDiagnosticContexts = false;
                        lateStatementReplacementMap = /* @__PURE__ */ new Map();
                        getSymbolAccessibilityDiagnostic = throwDiagnostic;
                        needsScopeFixMarker = false;
                        resultHasScopeMarker = false;
                        collectReferences(sourceFile, refs);
                        collectLibs(sourceFile, libs2);
                        if (isExternalOrCommonJsModule(sourceFile) || isJsonSourceFile(sourceFile)) {
                            resultHasExternalModuleIndicator = false;
                            needsDeclare = false;
                            const statements = isSourceFileJS(sourceFile) ? factory2.createNodeArray(transformDeclarationsForJS(sourceFile, 
                            /*bundled*/
                            true)) : visitNodes2(sourceFile.statements, visitDeclarationStatements, isStatement);
                            const newFile = factory2.updateSourceFile(sourceFile, [factory2.createModuleDeclaration([factory2.createModifier(136 /* DeclareKeyword */)], factory2.createStringLiteral(getResolvedExternalModuleName(context.getEmitHost(), sourceFile)), factory2.createModuleBlock(setTextRange(factory2.createNodeArray(transformAndReplaceLatePaintedStatements(statements)), sourceFile.statements)))], 
                            /*isDeclarationFile*/
                            true, 
                            /*referencedFiles*/
                            [], 
                            /*typeReferences*/
                            [], 
                            /*hasNoDefaultLib*/
                            false, 
                            /*libReferences*/
                            []);
                            return newFile;
                        }
                        needsDeclare = true;
                        const updated2 = isSourceFileJS(sourceFile) ? factory2.createNodeArray(transformDeclarationsForJS(sourceFile)) : visitNodes2(sourceFile.statements, visitDeclarationStatements, isStatement);
                        return factory2.updateSourceFile(sourceFile, transformAndReplaceLatePaintedStatements(updated2), 
                        /*isDeclarationFile*/
                        true, 
                        /*referencedFiles*/
                        [], 
                        /*typeReferences*/
                        [], 
                        /*hasNoDefaultLib*/
                        false, 
                        /*libReferences*/
                        []);
                    }), mapDefined(node.prepends, (prepend) => {
                        if (prepend.kind === 311 /* InputFiles */) {
                            const sourceFile = createUnparsedSourceFile(prepend, "dts", stripInternal);
                            hasNoDefaultLib = hasNoDefaultLib || !!sourceFile.hasNoDefaultLib;
                            collectReferences(sourceFile, refs);
                            recordTypeReferenceDirectivesIfNecessary(map(sourceFile.typeReferenceDirectives, (ref) => [ref.fileName, ref.resolutionMode]));
                            collectLibs(sourceFile, libs2);
                            return sourceFile;
                        }
                        return prepend;
                    }));
                    bundle.syntheticFileReferences = [];
                    bundle.syntheticTypeReferences = getFileReferencesForUsedTypeReferences();
                    bundle.syntheticLibReferences = getLibReferences();
                    bundle.hasNoDefaultLib = hasNoDefaultLib;
                    const outputFilePath2 = getDirectoryPath(normalizeSlashes(getOutputPathsFor(node, host, 
                    /*forceDtsPaths*/
                    true).declarationFilePath));
                    const referenceVisitor2 = mapReferencesIntoArray(bundle.syntheticFileReferences, outputFilePath2);
                    refs.forEach(referenceVisitor2);
                    return bundle;
                }
                needsDeclare = true;
                needsScopeFixMarker = false;
                resultHasScopeMarker = false;
                enclosingDeclaration = node;
                currentSourceFile = node;
                getSymbolAccessibilityDiagnostic = throwDiagnostic;
                isBundledEmit = false;
                resultHasExternalModuleIndicator = false;
                suppressNewDiagnosticContexts = false;
                lateMarkedStatements = void 0;
                lateStatementReplacementMap = /* @__PURE__ */ new Map();
                necessaryTypeReferences = void 0;
                refs = collectReferences(currentSourceFile, /* @__PURE__ */ new Map());
                libs2 = collectLibs(currentSourceFile, /* @__PURE__ */ new Map());
                const references = [];
                const outputFilePath = getDirectoryPath(normalizeSlashes(getOutputPathsFor(node, host, 
                /*forceDtsPaths*/
                true).declarationFilePath));
                const referenceVisitor = mapReferencesIntoArray(references, outputFilePath);
                let combinedStatements;
                if (isSourceFileJS(currentSourceFile)) {
                    combinedStatements = factory2.createNodeArray(transformDeclarationsForJS(node));
                    refs.forEach(referenceVisitor);
                    emittedImports = filter(combinedStatements, isAnyImportSyntax);
                }
                else {
                    const statements = visitNodes2(node.statements, visitDeclarationStatements, isStatement);
                    combinedStatements = setTextRange(factory2.createNodeArray(transformAndReplaceLatePaintedStatements(statements)), node.statements);
                    refs.forEach(referenceVisitor);
                    emittedImports = filter(combinedStatements, isAnyImportSyntax);
                    if (isExternalModule(node) && (!resultHasExternalModuleIndicator || needsScopeFixMarker && !resultHasScopeMarker)) {
                        combinedStatements = setTextRange(factory2.createNodeArray([...combinedStatements, createEmptyExports(factory2)]), combinedStatements);
                    }
                }
                const updated = factory2.updateSourceFile(node, combinedStatements, 
                /*isDeclarationFile*/
                true, references, getFileReferencesForUsedTypeReferences(), node.hasNoDefaultLib, getLibReferences());
                updated.exportedModulesFromDeclarationEmit = exportedModulesFromDeclarationEmit;
                return updated;
                function getLibReferences() {
                    return arrayFrom(libs2.keys(), (lib) => ({ fileName: lib, pos: -1, end: -1 }));
                }
                function getFileReferencesForUsedTypeReferences() {
                    return necessaryTypeReferences ? mapDefined(arrayFrom(necessaryTypeReferences.keys()), getFileReferenceForSpecifierModeTuple) : [];
                }
                function getFileReferenceForSpecifierModeTuple([typeName, mode]) {
                    if (emittedImports) {
                        for (const importStatement of emittedImports) {
                            if (isImportEqualsDeclaration(importStatement) && isExternalModuleReference(importStatement.moduleReference)) {
                                const expr = importStatement.moduleReference.expression;
                                if (isStringLiteralLike(expr) && expr.text === typeName) {
                                    return void 0;
                                }
                            }
                            else if (isImportDeclaration(importStatement) && isStringLiteral(importStatement.moduleSpecifier) && importStatement.moduleSpecifier.text === typeName) {
                                return void 0;
                            }
                        }
                    }
                    return { fileName: typeName, pos: -1, end: -1, ...mode ? { resolutionMode: mode } : void 0 };
                }
                function mapReferencesIntoArray(references2, outputFilePath2) {
                    return (file) => {
                        let declFileName;
                        if (file.isDeclarationFile) {
                            declFileName = file.fileName;
                        }
                        else {
                            if (isBundledEmit && contains(node.sourceFiles, file))
                                return;
                            const paths = getOutputPathsFor(file, host, 
                            /*forceDtsPaths*/
                            true);
                            declFileName = paths.declarationFilePath || paths.jsFilePath || file.fileName;
                        }
                        if (declFileName) {
                            const specifier = getModuleSpecifier(options, currentSourceFile, toPath(outputFilePath2, host.getCurrentDirectory(), host.getCanonicalFileName), toPath(declFileName, host.getCurrentDirectory(), host.getCanonicalFileName), host);
                            if (!pathIsRelative(specifier)) {
                                recordTypeReferenceDirectivesIfNecessary([[
                                        specifier,
                                        /*mode*/
                                        void 0
                                    ]]);
                                return;
                            }
                            let fileName = getRelativePathToDirectoryOrUrl(outputFilePath2, declFileName, host.getCurrentDirectory(), host.getCanonicalFileName, 
                            /*isAbsolutePathAnUrl*/
                            false);
                            if (startsWith(fileName, "./") && hasExtension(fileName)) {
                                fileName = fileName.substring(2);
                            }
                            if (startsWith(fileName, "node_modules/") || pathContainsNodeModules(fileName)) {
                                return;
                            }
                            references2.push({ pos: -1, end: -1, fileName });
                        }
                    };
                }
            }
            function collectReferences(sourceFile, ret) {
                if (noResolve || !isUnparsedSource(sourceFile) && isSourceFileJS(sourceFile))
                    return ret;
                forEach(sourceFile.referencedFiles, (f) => {
                    const elem = host.getSourceFileFromReference(sourceFile, f);
                    if (elem) {
                        ret.set(getOriginalNodeId(elem), elem);
                    }
                });
                return ret;
            }
            function collectLibs(sourceFile, ret) {
                forEach(sourceFile.libReferenceDirectives, (ref) => {
                    const lib = host.getLibFileFromReference(ref);
                    if (lib) {
                        ret.set(toFileNameLowerCase(ref.fileName), true);
                    }
                });
                return ret;
            }
            function filterBindingPatternInitializersAndRenamings(name) {
                if (name.kind === 79 /* Identifier */) {
                    return name;
                }
                else {
                    if (name.kind === 204 /* ArrayBindingPattern */) {
                        return factory2.updateArrayBindingPattern(name, visitNodes2(name.elements, visitBindingElement, isArrayBindingElement));
                    }
                    else {
                        return factory2.updateObjectBindingPattern(name, visitNodes2(name.elements, visitBindingElement, isBindingElement));
                    }
                }
                function visitBindingElement(elem) {
                    if (elem.kind === 229 /* OmittedExpression */) {
                        return elem;
                    }
                    if (elem.propertyName && isIdentifier(elem.propertyName) && isIdentifier(elem.name) && !elem.symbol.isReferenced && !isIdentifierANonContextualKeyword(elem.propertyName)) {
                        return factory2.updateBindingElement(elem, elem.dotDotDotToken, 
                        /* propertyName */
                        void 0, elem.propertyName, shouldPrintWithInitializer(elem) ? elem.initializer : void 0);
                    }
                    return factory2.updateBindingElement(elem, elem.dotDotDotToken, elem.propertyName, filterBindingPatternInitializersAndRenamings(elem.name), shouldPrintWithInitializer(elem) ? elem.initializer : void 0);
                }
            }
            function ensureParameter(p, modifierMask, type) {
                let oldDiag;
                if (!suppressNewDiagnosticContexts) {
                    oldDiag = getSymbolAccessibilityDiagnostic;
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(p);
                }
                const newParam = factory2.updateParameterDeclaration(p, maskModifiers(p, modifierMask), p.dotDotDotToken, filterBindingPatternInitializersAndRenamings(p.name), resolver.isOptionalParameter(p) ? p.questionToken || factory2.createToken(57 /* QuestionToken */) : void 0, ensureType(p, type || p.type, 
                /*ignorePrivate*/
                true), 
                // Ignore private param props, since this type is going straight back into a param
                ensureNoInitializer(p));
                if (!suppressNewDiagnosticContexts) {
                    getSymbolAccessibilityDiagnostic = oldDiag;
                }
                return newParam;
            }
            function shouldPrintWithInitializer(node) {
                return canHaveLiteralInitializer(node) && resolver.isLiteralConstDeclaration(getParseTreeNode(node));
            }
            function ensureNoInitializer(node) {
                if (shouldPrintWithInitializer(node)) {
                    return resolver.createLiteralConstValue(getParseTreeNode(node), symbolTracker);
                }
                return void 0;
            }
            function ensureType(node, type, ignorePrivate) {
                if (!ignorePrivate && hasEffectiveModifier(node, 8 /* Private */)) {
                    return;
                }
                if (shouldPrintWithInitializer(node)) {
                    return;
                }
                const shouldUseResolverType = node.kind === 166 /* Parameter */ && (resolver.isRequiredInitializedParameter(node) || resolver.isOptionalUninitializedParameterProperty(node));
                if (type && !shouldUseResolverType) {
                    return visitNode(type, visitDeclarationSubtree, isTypeNode);
                }
                if (!getParseTreeNode(node)) {
                    return type ? visitNode(type, visitDeclarationSubtree, isTypeNode) : factory2.createKeywordTypeNode(131 /* AnyKeyword */);
                }
                if (node.kind === 175 /* SetAccessor */) {
                    return factory2.createKeywordTypeNode(131 /* AnyKeyword */);
                }
                errorNameNode = node.name;
                let oldDiag;
                if (!suppressNewDiagnosticContexts) {
                    oldDiag = getSymbolAccessibilityDiagnostic;
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(node);
                }
                if (node.kind === 257 /* VariableDeclaration */ || node.kind === 205 /* BindingElement */) {
                    return cleanup(resolver.createTypeOfDeclaration(node, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker));
                }
                if (node.kind === 166 /* Parameter */ || node.kind === 169 /* PropertyDeclaration */ || node.kind === 168 /* PropertySignature */) {
                    if (isPropertySignature(node) || !node.initializer)
                        return cleanup(resolver.createTypeOfDeclaration(node, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker, shouldUseResolverType));
                    return cleanup(resolver.createTypeOfDeclaration(node, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker, shouldUseResolverType) || resolver.createTypeOfExpression(node.initializer, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker));
                }
                return cleanup(resolver.createReturnTypeOfSignatureDeclaration(node, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker));
                function cleanup(returnValue) {
                    errorNameNode = void 0;
                    if (!suppressNewDiagnosticContexts) {
                        getSymbolAccessibilityDiagnostic = oldDiag;
                    }
                    return returnValue || factory2.createKeywordTypeNode(131 /* AnyKeyword */);
                }
            }
            function isDeclarationAndNotVisible(node) {
                node = getParseTreeNode(node);
                switch (node.kind) {
                    case 259 /* FunctionDeclaration */:
                    case 264 /* ModuleDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                    case 260 /* ClassDeclaration */:
                    case 262 /* TypeAliasDeclaration */:
                    case 263 /* EnumDeclaration */:
                        return !resolver.isDeclarationVisible(node);
                    case 257 /* VariableDeclaration */:
                        return !getBindingNameVisible(node);
                    case 268 /* ImportEqualsDeclaration */:
                    case 269 /* ImportDeclaration */:
                    case 275 /* ExportDeclaration */:
                    case 274 /* ExportAssignment */:
                        return false;
                    case 172 /* ClassStaticBlockDeclaration */:
                        return true;
                }
                return false;
            }
            function shouldEmitFunctionProperties(input) {
                var _a2;
                if (input.body) {
                    return true;
                }
                const overloadSignatures = (_a2 = input.symbol.declarations) == null ? void 0 : _a2.filter((decl) => isFunctionDeclaration(decl) && !decl.body);
                return !overloadSignatures || overloadSignatures.indexOf(input) === overloadSignatures.length - 1;
            }
            function getBindingNameVisible(elem) {
                if (isOmittedExpression(elem)) {
                    return false;
                }
                if (isBindingPattern(elem.name)) {
                    return some(elem.name.elements, getBindingNameVisible);
                }
                else {
                    return resolver.isDeclarationVisible(elem);
                }
            }
            function updateParamsList(node, params, modifierMask) {
                if (hasEffectiveModifier(node, 8 /* Private */)) {
                    return factory2.createNodeArray();
                }
                const newParams = map(params, (p) => ensureParameter(p, modifierMask));
                if (!newParams) {
                    return factory2.createNodeArray();
                }
                return factory2.createNodeArray(newParams, params.hasTrailingComma);
            }
            function updateAccessorParamsList(input, isPrivate) {
                let newParams;
                if (!isPrivate) {
                    const thisParameter = getThisParameter(input);
                    if (thisParameter) {
                        newParams = [ensureParameter(thisParameter)];
                    }
                }
                if (isSetAccessorDeclaration(input)) {
                    let newValueParameter;
                    if (!isPrivate) {
                        const valueParameter = getSetAccessorValueParameter(input);
                        if (valueParameter) {
                            const accessorType = getTypeAnnotationFromAllAccessorDeclarations(input, resolver.getAllAccessorDeclarations(input));
                            newValueParameter = ensureParameter(valueParameter, 
                            /*modifierMask*/
                            void 0, accessorType);
                        }
                    }
                    if (!newValueParameter) {
                        newValueParameter = factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, "value");
                    }
                    newParams = append(newParams, newValueParameter);
                }
                return factory2.createNodeArray(newParams || emptyArray);
            }
            function ensureTypeParams(node, params) {
                return hasEffectiveModifier(node, 8 /* Private */) ? void 0 : visitNodes2(params, visitDeclarationSubtree, isTypeParameterDeclaration);
            }
            function isEnclosingDeclaration(node) {
                return isSourceFile(node) || isTypeAliasDeclaration(node) || isModuleDeclaration(node) || isClassDeclaration(node) || isInterfaceDeclaration(node) || isFunctionLike(node) || isIndexSignatureDeclaration(node) || isMappedTypeNode(node);
            }
            function checkEntityNameVisibility(entityName, enclosingDeclaration2) {
                const visibilityResult = resolver.isEntityNameVisible(entityName, enclosingDeclaration2);
                handleSymbolAccessibilityError(visibilityResult);
                recordTypeReferenceDirectivesIfNecessary(resolver.getTypeReferenceDirectivesForEntityName(entityName));
            }
            function preserveJsDoc(updated, original) {
                if (hasJSDocNodes(updated) && hasJSDocNodes(original)) {
                    updated.jsDoc = original.jsDoc;
                }
                return setCommentRange(updated, getCommentRange(original));
            }
            function rewriteModuleSpecifier(parent2, input) {
                if (!input)
                    return void 0;
                resultHasExternalModuleIndicator = resultHasExternalModuleIndicator || parent2.kind !== 264 /* ModuleDeclaration */ && parent2.kind !== 202 /* ImportType */;
                if (isStringLiteralLike(input)) {
                    if (isBundledEmit) {
                        const newName = getExternalModuleNameFromDeclaration(context.getEmitHost(), resolver, parent2);
                        if (newName) {
                            return factory2.createStringLiteral(newName);
                        }
                    }
                    else {
                        const symbol = resolver.getSymbolOfExternalModuleSpecifier(input);
                        if (symbol) {
                            (exportedModulesFromDeclarationEmit || (exportedModulesFromDeclarationEmit = [])).push(symbol);
                        }
                    }
                }
                return input;
            }
            function transformImportEqualsDeclaration(decl) {
                if (!resolver.isDeclarationVisible(decl))
                    return;
                if (decl.moduleReference.kind === 280 /* ExternalModuleReference */) {
                    const specifier = getExternalModuleImportEqualsDeclarationExpression(decl);
                    return factory2.updateImportEqualsDeclaration(decl, decl.modifiers, decl.isTypeOnly, decl.name, factory2.updateExternalModuleReference(decl.moduleReference, rewriteModuleSpecifier(decl, specifier)));
                }
                else {
                    const oldDiag = getSymbolAccessibilityDiagnostic;
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(decl);
                    checkEntityNameVisibility(decl.moduleReference, enclosingDeclaration);
                    getSymbolAccessibilityDiagnostic = oldDiag;
                    return decl;
                }
            }
            function transformImportDeclaration(decl) {
                if (!decl.importClause) {
                    return factory2.updateImportDeclaration(decl, decl.modifiers, decl.importClause, rewriteModuleSpecifier(decl, decl.moduleSpecifier), getResolutionModeOverrideForClauseInNightly(decl.assertClause));
                }
                const visibleDefaultBinding = decl.importClause && decl.importClause.name && resolver.isDeclarationVisible(decl.importClause) ? decl.importClause.name : void 0;
                if (!decl.importClause.namedBindings) {
                    return visibleDefaultBinding && factory2.updateImportDeclaration(decl, decl.modifiers, factory2.updateImportClause(decl.importClause, decl.importClause.isTypeOnly, visibleDefaultBinding, 
                    /*namedBindings*/
                    void 0), rewriteModuleSpecifier(decl, decl.moduleSpecifier), getResolutionModeOverrideForClauseInNightly(decl.assertClause));
                }
                if (decl.importClause.namedBindings.kind === 271 /* NamespaceImport */) {
                    const namedBindings = resolver.isDeclarationVisible(decl.importClause.namedBindings) ? decl.importClause.namedBindings : (
                    /*namedBindings*/
                    void 0);
                    return visibleDefaultBinding || namedBindings ? factory2.updateImportDeclaration(decl, decl.modifiers, factory2.updateImportClause(decl.importClause, decl.importClause.isTypeOnly, visibleDefaultBinding, namedBindings), rewriteModuleSpecifier(decl, decl.moduleSpecifier), getResolutionModeOverrideForClauseInNightly(decl.assertClause)) : void 0;
                }
                const bindingList = mapDefined(decl.importClause.namedBindings.elements, (b) => resolver.isDeclarationVisible(b) ? b : void 0);
                if (bindingList && bindingList.length || visibleDefaultBinding) {
                    return factory2.updateImportDeclaration(decl, decl.modifiers, factory2.updateImportClause(decl.importClause, decl.importClause.isTypeOnly, visibleDefaultBinding, bindingList && bindingList.length ? factory2.updateNamedImports(decl.importClause.namedBindings, bindingList) : void 0), rewriteModuleSpecifier(decl, decl.moduleSpecifier), getResolutionModeOverrideForClauseInNightly(decl.assertClause));
                }
                if (resolver.isImportRequiredByAugmentation(decl)) {
                    return factory2.updateImportDeclaration(decl, decl.modifiers, 
                    /*importClause*/
                    void 0, rewriteModuleSpecifier(decl, decl.moduleSpecifier), getResolutionModeOverrideForClauseInNightly(decl.assertClause));
                }
            }
            function getResolutionModeOverrideForClauseInNightly(assertClause) {
                const mode = getResolutionModeOverrideForClause(assertClause);
                if (mode !== void 0) {
                    if (!isNightly()) {
                        context.addDiagnostic(createDiagnosticForNode(assertClause, Diagnostics.resolution_mode_assertions_are_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next));
                    }
                    return assertClause;
                }
                return void 0;
            }
            function transformAndReplaceLatePaintedStatements(statements) {
                while (length(lateMarkedStatements)) {
                    const i = lateMarkedStatements.shift();
                    if (!isLateVisibilityPaintedStatement(i)) {
                        return Debug.fail(`Late replaced statement was found which is not handled by the declaration transformer!: ${Debug.formatSyntaxKind(i.kind)}`);
                    }
                    const priorNeedsDeclare = needsDeclare;
                    needsDeclare = i.parent && isSourceFile(i.parent) && !(isExternalModule(i.parent) && isBundledEmit);
                    const result = transformTopLevelDeclaration(i);
                    needsDeclare = priorNeedsDeclare;
                    lateStatementReplacementMap.set(getOriginalNodeId(i), result);
                }
                return visitNodes2(statements, visitLateVisibilityMarkedStatements, isStatement);
                function visitLateVisibilityMarkedStatements(statement) {
                    if (isLateVisibilityPaintedStatement(statement)) {
                        const key = getOriginalNodeId(statement);
                        if (lateStatementReplacementMap.has(key)) {
                            const result = lateStatementReplacementMap.get(key);
                            lateStatementReplacementMap.delete(key);
                            if (result) {
                                if (isArray(result) ? some(result, needsScopeMarker) : needsScopeMarker(result)) {
                                    needsScopeFixMarker = true;
                                }
                                if (isSourceFile(statement.parent) && (isArray(result) ? some(result, isExternalModuleIndicator) : isExternalModuleIndicator(result))) {
                                    resultHasExternalModuleIndicator = true;
                                }
                            }
                            return result;
                        }
                    }
                    return statement;
                }
            }
            function visitDeclarationSubtree(input) {
                if (shouldStripInternal(input))
                    return;
                if (isDeclaration(input)) {
                    if (isDeclarationAndNotVisible(input))
                        return;
                    if (hasDynamicName(input) && !resolver.isLateBound(getParseTreeNode(input))) {
                        return;
                    }
                }
                if (isFunctionLike(input) && resolver.isImplementationOfOverload(input))
                    return;
                if (isSemicolonClassElement(input))
                    return;
                let previousEnclosingDeclaration;
                if (isEnclosingDeclaration(input)) {
                    previousEnclosingDeclaration = enclosingDeclaration;
                    enclosingDeclaration = input;
                }
                const oldDiag = getSymbolAccessibilityDiagnostic;
                const canProduceDiagnostic = canProduceDiagnostics(input);
                const oldWithinObjectLiteralType = suppressNewDiagnosticContexts;
                let shouldEnterSuppressNewDiagnosticsContextContext = (input.kind === 184 /* TypeLiteral */ || input.kind === 197 /* MappedType */) && input.parent.kind !== 262 /* TypeAliasDeclaration */;
                if (isMethodDeclaration(input) || isMethodSignature(input)) {
                    if (hasEffectiveModifier(input, 8 /* Private */)) {
                        if (input.symbol && input.symbol.declarations && input.symbol.declarations[0] !== input)
                            return;
                        return cleanup(factory2.createPropertyDeclaration(ensureModifiers(input), input.name, 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0));
                    }
                }
                if (canProduceDiagnostic && !suppressNewDiagnosticContexts) {
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(input);
                }
                if (isTypeQueryNode(input)) {
                    checkEntityNameVisibility(input.exprName, enclosingDeclaration);
                }
                if (shouldEnterSuppressNewDiagnosticsContextContext) {
                    suppressNewDiagnosticContexts = true;
                }
                if (isProcessedComponent(input)) {
                    switch (input.kind) {
                        case 230 /* ExpressionWithTypeArguments */: {
                            if (isEntityName(input.expression) || isEntityNameExpression(input.expression)) {
                                checkEntityNameVisibility(input.expression, enclosingDeclaration);
                            }
                            const node = visitEachChild(input, visitDeclarationSubtree, context);
                            return cleanup(factory2.updateExpressionWithTypeArguments(node, node.expression, node.typeArguments));
                        }
                        case 180 /* TypeReference */: {
                            checkEntityNameVisibility(input.typeName, enclosingDeclaration);
                            const node = visitEachChild(input, visitDeclarationSubtree, context);
                            return cleanup(factory2.updateTypeReferenceNode(node, node.typeName, node.typeArguments));
                        }
                        case 177 /* ConstructSignature */:
                            return cleanup(factory2.updateConstructSignature(input, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type)));
                        case 173 /* Constructor */: {
                            const ctor = factory2.createConstructorDeclaration(
                            /*modifiers*/
                            ensureModifiers(input), updateParamsList(input, input.parameters, 0 /* None */), 
                            /*body*/
                            void 0);
                            return cleanup(ctor);
                        }
                        case 171 /* MethodDeclaration */: {
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            const sig = factory2.createMethodDeclaration(ensureModifiers(input), 
                            /*asteriskToken*/
                            void 0, input.name, input.questionToken, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type), 
                            /*body*/
                            void 0);
                            return cleanup(sig);
                        }
                        case 174 /* GetAccessor */: {
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            const accessorType = getTypeAnnotationFromAllAccessorDeclarations(input, resolver.getAllAccessorDeclarations(input));
                            return cleanup(factory2.updateGetAccessorDeclaration(input, ensureModifiers(input), input.name, updateAccessorParamsList(input, hasEffectiveModifier(input, 8 /* Private */)), ensureType(input, accessorType), 
                            /*body*/
                            void 0));
                        }
                        case 175 /* SetAccessor */: {
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            return cleanup(factory2.updateSetAccessorDeclaration(input, ensureModifiers(input), input.name, updateAccessorParamsList(input, hasEffectiveModifier(input, 8 /* Private */)), 
                            /*body*/
                            void 0));
                        }
                        case 169 /* PropertyDeclaration */:
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            return cleanup(factory2.updatePropertyDeclaration(input, ensureModifiers(input), input.name, input.questionToken, ensureType(input, input.type), ensureNoInitializer(input)));
                        case 168 /* PropertySignature */:
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            return cleanup(factory2.updatePropertySignature(input, ensureModifiers(input), input.name, input.questionToken, ensureType(input, input.type)));
                        case 170 /* MethodSignature */: {
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            return cleanup(factory2.updateMethodSignature(input, ensureModifiers(input), input.name, input.questionToken, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type)));
                        }
                        case 176 /* CallSignature */: {
                            return cleanup(factory2.updateCallSignature(input, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type)));
                        }
                        case 178 /* IndexSignature */: {
                            return cleanup(factory2.updateIndexSignature(input, ensureModifiers(input), updateParamsList(input, input.parameters), visitNode(input.type, visitDeclarationSubtree, isTypeNode) || factory2.createKeywordTypeNode(131 /* AnyKeyword */)));
                        }
                        case 257 /* VariableDeclaration */: {
                            if (isBindingPattern(input.name)) {
                                return recreateBindingPattern(input.name);
                            }
                            shouldEnterSuppressNewDiagnosticsContextContext = true;
                            suppressNewDiagnosticContexts = true;
                            return cleanup(factory2.updateVariableDeclaration(input, input.name, 
                            /*exclamationToken*/
                            void 0, ensureType(input, input.type), ensureNoInitializer(input)));
                        }
                        case 165 /* TypeParameter */: {
                            if (isPrivateMethodTypeParameter(input) && (input.default || input.constraint)) {
                                return cleanup(factory2.updateTypeParameterDeclaration(input, input.modifiers, input.name, 
                                /*constraint*/
                                void 0, 
                                /*defaultType*/
                                void 0));
                            }
                            return cleanup(visitEachChild(input, visitDeclarationSubtree, context));
                        }
                        case 191 /* ConditionalType */: {
                            const checkType = visitNode(input.checkType, visitDeclarationSubtree, isTypeNode);
                            const extendsType = visitNode(input.extendsType, visitDeclarationSubtree, isTypeNode);
                            const oldEnclosingDecl = enclosingDeclaration;
                            enclosingDeclaration = input.trueType;
                            const trueType = visitNode(input.trueType, visitDeclarationSubtree, isTypeNode);
                            enclosingDeclaration = oldEnclosingDecl;
                            const falseType = visitNode(input.falseType, visitDeclarationSubtree, isTypeNode);
                            Debug.assert(checkType);
                            Debug.assert(extendsType);
                            Debug.assert(trueType);
                            Debug.assert(falseType);
                            return cleanup(factory2.updateConditionalTypeNode(input, checkType, extendsType, trueType, falseType));
                        }
                        case 181 /* FunctionType */: {
                            return cleanup(factory2.updateFunctionTypeNode(input, visitNodes2(input.typeParameters, visitDeclarationSubtree, isTypeParameterDeclaration), updateParamsList(input, input.parameters), Debug.checkDefined(visitNode(input.type, visitDeclarationSubtree, isTypeNode))));
                        }
                        case 182 /* ConstructorType */: {
                            return cleanup(factory2.updateConstructorTypeNode(input, ensureModifiers(input), visitNodes2(input.typeParameters, visitDeclarationSubtree, isTypeParameterDeclaration), updateParamsList(input, input.parameters), Debug.checkDefined(visitNode(input.type, visitDeclarationSubtree, isTypeNode))));
                        }
                        case 202 /* ImportType */: {
                            if (!isLiteralImportTypeNode(input))
                                return cleanup(input);
                            return cleanup(factory2.updateImportTypeNode(input, factory2.updateLiteralTypeNode(input.argument, rewriteModuleSpecifier(input, input.argument.literal)), input.assertions, input.qualifier, visitNodes2(input.typeArguments, visitDeclarationSubtree, isTypeNode), input.isTypeOf));
                        }
                        default:
                            Debug.assertNever(input, `Attempted to process unhandled node kind: ${Debug.formatSyntaxKind(input.kind)}`);
                    }
                }
                if (isTupleTypeNode(input) && getLineAndCharacterOfPosition(currentSourceFile, input.pos).line === getLineAndCharacterOfPosition(currentSourceFile, input.end).line) {
                    setEmitFlags(input, 1 /* SingleLine */);
                }
                return cleanup(visitEachChild(input, visitDeclarationSubtree, context));
                function cleanup(returnValue) {
                    if (returnValue && canProduceDiagnostic && hasDynamicName(input)) {
                        checkName(input);
                    }
                    if (isEnclosingDeclaration(input)) {
                        enclosingDeclaration = previousEnclosingDeclaration;
                    }
                    if (canProduceDiagnostic && !suppressNewDiagnosticContexts) {
                        getSymbolAccessibilityDiagnostic = oldDiag;
                    }
                    if (shouldEnterSuppressNewDiagnosticsContextContext) {
                        suppressNewDiagnosticContexts = oldWithinObjectLiteralType;
                    }
                    if (returnValue === input) {
                        return returnValue;
                    }
                    return returnValue && setOriginalNode(preserveJsDoc(returnValue, input), input);
                }
            }
            function isPrivateMethodTypeParameter(node) {
                return node.parent.kind === 171 /* MethodDeclaration */ && hasEffectiveModifier(node.parent, 8 /* Private */);
            }
            function visitDeclarationStatements(input) {
                if (!isPreservedDeclarationStatement(input)) {
                    return;
                }
                if (shouldStripInternal(input))
                    return;
                switch (input.kind) {
                    case 275 /* ExportDeclaration */: {
                        if (isSourceFile(input.parent)) {
                            resultHasExternalModuleIndicator = true;
                        }
                        resultHasScopeMarker = true;
                        return factory2.updateExportDeclaration(input, input.modifiers, input.isTypeOnly, input.exportClause, rewriteModuleSpecifier(input, input.moduleSpecifier), getResolutionModeOverrideForClause(input.assertClause) ? input.assertClause : void 0);
                    }
                    case 274 /* ExportAssignment */: {
                        if (isSourceFile(input.parent)) {
                            resultHasExternalModuleIndicator = true;
                        }
                        resultHasScopeMarker = true;
                        if (input.expression.kind === 79 /* Identifier */) {
                            return input;
                        }
                        else {
                            const newId = factory2.createUniqueName("_default", 16 /* Optimistic */);
                            getSymbolAccessibilityDiagnostic = () => ({
                                diagnosticMessage: Diagnostics.Default_export_of_the_module_has_or_is_using_private_name_0,
                                errorNode: input
                            });
                            errorFallbackNode = input;
                            const varDecl = factory2.createVariableDeclaration(newId, 
                            /*exclamationToken*/
                            void 0, resolver.createTypeOfExpression(input.expression, input, declarationEmitNodeBuilderFlags, symbolTracker), 
                            /*initializer*/
                            void 0);
                            errorFallbackNode = void 0;
                            const statement = factory2.createVariableStatement(needsDeclare ? [factory2.createModifier(136 /* DeclareKeyword */)] : [], factory2.createVariableDeclarationList([varDecl], 2 /* Const */));
                            preserveJsDoc(statement, input);
                            removeAllComments(input);
                            return [statement, factory2.updateExportAssignment(input, input.modifiers, newId)];
                        }
                    }
                }
                const result = transformTopLevelDeclaration(input);
                lateStatementReplacementMap.set(getOriginalNodeId(input), result);
                return input;
            }
            function stripExportModifiers(statement) {
                if (isImportEqualsDeclaration(statement) || hasEffectiveModifier(statement, 1024 /* Default */) || !canHaveModifiers(statement)) {
                    return statement;
                }
                const modifiers = factory2.createModifiersFromModifierFlags(getEffectiveModifierFlags(statement) & (258047 /* All */ ^ 1 /* Export */));
                return factory2.updateModifiers(statement, modifiers);
            }
            function transformTopLevelDeclaration(input) {
                if (lateMarkedStatements) {
                    while (orderedRemoveItem(lateMarkedStatements, input))
                        ;
                }
                if (shouldStripInternal(input))
                    return;
                switch (input.kind) {
                    case 268 /* ImportEqualsDeclaration */: {
                        return transformImportEqualsDeclaration(input);
                    }
                    case 269 /* ImportDeclaration */: {
                        return transformImportDeclaration(input);
                    }
                }
                if (isDeclaration(input) && isDeclarationAndNotVisible(input))
                    return;
                if (isFunctionLike(input) && resolver.isImplementationOfOverload(input))
                    return;
                let previousEnclosingDeclaration;
                if (isEnclosingDeclaration(input)) {
                    previousEnclosingDeclaration = enclosingDeclaration;
                    enclosingDeclaration = input;
                }
                const canProdiceDiagnostic = canProduceDiagnostics(input);
                const oldDiag = getSymbolAccessibilityDiagnostic;
                if (canProdiceDiagnostic) {
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(input);
                }
                const previousNeedsDeclare = needsDeclare;
                switch (input.kind) {
                    case 262 /* TypeAliasDeclaration */: {
                        needsDeclare = false;
                        const clean2 = cleanup(factory2.updateTypeAliasDeclaration(input, ensureModifiers(input), input.name, visitNodes2(input.typeParameters, visitDeclarationSubtree, isTypeParameterDeclaration), Debug.checkDefined(visitNode(input.type, visitDeclarationSubtree, isTypeNode))));
                        needsDeclare = previousNeedsDeclare;
                        return clean2;
                    }
                    case 261 /* InterfaceDeclaration */: {
                        return cleanup(factory2.updateInterfaceDeclaration(input, ensureModifiers(input), input.name, ensureTypeParams(input, input.typeParameters), transformHeritageClauses(input.heritageClauses), visitNodes2(input.members, visitDeclarationSubtree, isTypeElement)));
                    }
                    case 259 /* FunctionDeclaration */: {
                        const clean2 = cleanup(factory2.updateFunctionDeclaration(input, ensureModifiers(input), 
                        /*asteriskToken*/
                        void 0, input.name, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type), 
                        /*body*/
                        void 0));
                        if (clean2 && resolver.isExpandoFunctionDeclaration(input) && shouldEmitFunctionProperties(input)) {
                            const props = resolver.getPropertiesOfContainerFunction(input);
                            const fakespace = parseNodeFactory.createModuleDeclaration(
                            /*modifiers*/
                            void 0, clean2.name || factory2.createIdentifier("_default"), factory2.createModuleBlock([]), 16 /* Namespace */);
                            setParent(fakespace, enclosingDeclaration);
                            fakespace.locals = createSymbolTable(props);
                            fakespace.symbol = props[0].parent;
                            const exportMappings = [];
                            let declarations = mapDefined(props, (p) => {
                                if (!p.valueDeclaration || !isPropertyAccessExpression(p.valueDeclaration)) {
                                    return void 0;
                                }
                                getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(p.valueDeclaration);
                                const type = resolver.createTypeOfDeclaration(p.valueDeclaration, fakespace, declarationEmitNodeBuilderFlags, symbolTracker);
                                getSymbolAccessibilityDiagnostic = oldDiag;
                                const nameStr = unescapeLeadingUnderscores(p.escapedName);
                                const isNonContextualKeywordName = isStringANonContextualKeyword(nameStr);
                                const name = isNonContextualKeywordName ? factory2.getGeneratedNameForNode(p.valueDeclaration) : factory2.createIdentifier(nameStr);
                                if (isNonContextualKeywordName) {
                                    exportMappings.push([name, nameStr]);
                                }
                                const varDecl = factory2.createVariableDeclaration(name, 
                                /*exclamationToken*/
                                void 0, type, 
                                /*initializer*/
                                void 0);
                                return factory2.createVariableStatement(isNonContextualKeywordName ? void 0 : [factory2.createToken(93 /* ExportKeyword */)], factory2.createVariableDeclarationList([varDecl]));
                            });
                            if (!exportMappings.length) {
                                declarations = mapDefined(declarations, (declaration) => factory2.updateModifiers(declaration, 0 /* None */));
                            }
                            else {
                                declarations.push(factory2.createExportDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory2.createNamedExports(map(exportMappings, ([gen, exp]) => {
                                    return factory2.createExportSpecifier(
                                    /*isTypeOnly*/
                                    false, gen, exp);
                                }))));
                            }
                            const namespaceDecl = factory2.createModuleDeclaration(ensureModifiers(input), input.name, factory2.createModuleBlock(declarations), 16 /* Namespace */);
                            if (!hasEffectiveModifier(clean2, 1024 /* Default */)) {
                                return [clean2, namespaceDecl];
                            }
                            const modifiers = factory2.createModifiersFromModifierFlags(getEffectiveModifierFlags(clean2) & ~1025 /* ExportDefault */ | 2 /* Ambient */);
                            const cleanDeclaration = factory2.updateFunctionDeclaration(clean2, modifiers, 
                            /*asteriskToken*/
                            void 0, clean2.name, clean2.typeParameters, clean2.parameters, clean2.type, 
                            /*body*/
                            void 0);
                            const namespaceDeclaration = factory2.updateModuleDeclaration(namespaceDecl, modifiers, namespaceDecl.name, namespaceDecl.body);
                            const exportDefaultDeclaration = factory2.createExportAssignment(
                            /*modifiers*/
                            void 0, 
                            /*isExportEquals*/
                            false, namespaceDecl.name);
                            if (isSourceFile(input.parent)) {
                                resultHasExternalModuleIndicator = true;
                            }
                            resultHasScopeMarker = true;
                            return [cleanDeclaration, namespaceDeclaration, exportDefaultDeclaration];
                        }
                        else {
                            return clean2;
                        }
                    }
                    case 264 /* ModuleDeclaration */: {
                        needsDeclare = false;
                        const inner = input.body;
                        if (inner && inner.kind === 265 /* ModuleBlock */) {
                            const oldNeedsScopeFix = needsScopeFixMarker;
                            const oldHasScopeFix = resultHasScopeMarker;
                            resultHasScopeMarker = false;
                            needsScopeFixMarker = false;
                            const statements = visitNodes2(inner.statements, visitDeclarationStatements, isStatement);
                            let lateStatements = transformAndReplaceLatePaintedStatements(statements);
                            if (input.flags & 16777216 /* Ambient */) {
                                needsScopeFixMarker = false;
                            }
                            if (!isGlobalScopeAugmentation(input) && !hasScopeMarker2(lateStatements) && !resultHasScopeMarker) {
                                if (needsScopeFixMarker) {
                                    lateStatements = factory2.createNodeArray([...lateStatements, createEmptyExports(factory2)]);
                                }
                                else {
                                    lateStatements = visitNodes2(lateStatements, stripExportModifiers, isStatement);
                                }
                            }
                            const body = factory2.updateModuleBlock(inner, lateStatements);
                            needsDeclare = previousNeedsDeclare;
                            needsScopeFixMarker = oldNeedsScopeFix;
                            resultHasScopeMarker = oldHasScopeFix;
                            const mods = ensureModifiers(input);
                            return cleanup(factory2.updateModuleDeclaration(input, mods, isExternalModuleAugmentation(input) ? rewriteModuleSpecifier(input, input.name) : input.name, body));
                        }
                        else {
                            needsDeclare = previousNeedsDeclare;
                            const mods = ensureModifiers(input);
                            needsDeclare = false;
                            visitNode(inner, visitDeclarationStatements);
                            const id = getOriginalNodeId(inner);
                            const body = lateStatementReplacementMap.get(id);
                            lateStatementReplacementMap.delete(id);
                            return cleanup(factory2.updateModuleDeclaration(input, mods, input.name, body));
                        }
                    }
                    case 260 /* ClassDeclaration */: {
                        errorNameNode = input.name;
                        errorFallbackNode = input;
                        const modifiers = factory2.createNodeArray(ensureModifiers(input));
                        const typeParameters = ensureTypeParams(input, input.typeParameters);
                        const ctor = getFirstConstructorWithBody(input);
                        let parameterProperties;
                        if (ctor) {
                            const oldDiag2 = getSymbolAccessibilityDiagnostic;
                            parameterProperties = compact(flatMap(ctor.parameters, (param) => {
                                if (!hasSyntacticModifier(param, 16476 /* ParameterPropertyModifier */) || shouldStripInternal(param))
                                    return;
                                getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(param);
                                if (param.name.kind === 79 /* Identifier */) {
                                    return preserveJsDoc(factory2.createPropertyDeclaration(ensureModifiers(param), param.name, param.questionToken, ensureType(param, param.type), ensureNoInitializer(param)), param);
                                }
                                else {
                                    return walkBindingPattern(param.name);
                                }
                                function walkBindingPattern(pattern) {
                                    let elems;
                                    for (const elem of pattern.elements) {
                                        if (isOmittedExpression(elem))
                                            continue;
                                        if (isBindingPattern(elem.name)) {
                                            elems = concatenate(elems, walkBindingPattern(elem.name));
                                        }
                                        elems = elems || [];
                                        elems.push(factory2.createPropertyDeclaration(ensureModifiers(param), elem.name, 
                                        /*questionToken*/
                                        void 0, ensureType(elem, 
                                        /*type*/
                                        void 0), 
                                        /*initializer*/
                                        void 0));
                                    }
                                    return elems;
                                }
                            }));
                            getSymbolAccessibilityDiagnostic = oldDiag2;
                        }
                        const hasPrivateIdentifier = some(input.members, (member) => !!member.name && isPrivateIdentifier(member.name));
                        const privateIdentifier = hasPrivateIdentifier ? [
                            factory2.createPropertyDeclaration(
                            /*modifiers*/
                            void 0, factory2.createPrivateIdentifier("#private"), 
                            /*questionToken*/
                            void 0, 
                            /*type*/
                            void 0, 
                            /*initializer*/
                            void 0)
                        ] : void 0;
                        const memberNodes = concatenate(concatenate(privateIdentifier, parameterProperties), visitNodes2(input.members, visitDeclarationSubtree, isClassElement));
                        const members = factory2.createNodeArray(memberNodes);
                        const extendsClause = getEffectiveBaseTypeNode(input);
                        if (extendsClause && !isEntityNameExpression(extendsClause.expression) && extendsClause.expression.kind !== 104 /* NullKeyword */) {
                            const oldId = input.name ? unescapeLeadingUnderscores(input.name.escapedText) : "default";
                            const newId = factory2.createUniqueName(`${oldId}_base`, 16 /* Optimistic */);
                            getSymbolAccessibilityDiagnostic = () => ({
                                diagnosticMessage: Diagnostics.extends_clause_of_exported_class_0_has_or_is_using_private_name_1,
                                errorNode: extendsClause,
                                typeName: input.name
                            });
                            const varDecl = factory2.createVariableDeclaration(newId, 
                            /*exclamationToken*/
                            void 0, resolver.createTypeOfExpression(extendsClause.expression, input, declarationEmitNodeBuilderFlags, symbolTracker), 
                            /*initializer*/
                            void 0);
                            const statement = factory2.createVariableStatement(needsDeclare ? [factory2.createModifier(136 /* DeclareKeyword */)] : [], factory2.createVariableDeclarationList([varDecl], 2 /* Const */));
                            const heritageClauses = factory2.createNodeArray(map(input.heritageClauses, (clause) => {
                                if (clause.token === 94 /* ExtendsKeyword */) {
                                    const oldDiag2 = getSymbolAccessibilityDiagnostic;
                                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(clause.types[0]);
                                    const newClause = factory2.updateHeritageClause(clause, map(clause.types, (t) => factory2.updateExpressionWithTypeArguments(t, newId, visitNodes2(t.typeArguments, visitDeclarationSubtree, isTypeNode))));
                                    getSymbolAccessibilityDiagnostic = oldDiag2;
                                    return newClause;
                                }
                                return factory2.updateHeritageClause(clause, visitNodes2(factory2.createNodeArray(filter(clause.types, (t) => isEntityNameExpression(t.expression) || t.expression.kind === 104 /* NullKeyword */)), visitDeclarationSubtree, isExpressionWithTypeArguments));
                            }));
                            return [statement, cleanup(factory2.updateClassDeclaration(input, modifiers, input.name, typeParameters, heritageClauses, members))];
                        }
                        else {
                            const heritageClauses = transformHeritageClauses(input.heritageClauses);
                            return cleanup(factory2.updateClassDeclaration(input, modifiers, input.name, typeParameters, heritageClauses, members));
                        }
                    }
                    case 240 /* VariableStatement */: {
                        return cleanup(transformVariableStatement(input));
                    }
                    case 263 /* EnumDeclaration */: {
                        return cleanup(factory2.updateEnumDeclaration(input, factory2.createNodeArray(ensureModifiers(input)), input.name, factory2.createNodeArray(mapDefined(input.members, (m) => {
                            if (shouldStripInternal(m))
                                return;
                            const constValue = resolver.getConstantValue(m);
                            return preserveJsDoc(factory2.updateEnumMember(m, m.name, constValue !== void 0 ? typeof constValue === "string" ? factory2.createStringLiteral(constValue) : factory2.createNumericLiteral(constValue) : void 0), m);
                        }))));
                    }
                }
                return Debug.assertNever(input, `Unhandled top-level node in declaration emit: ${Debug.formatSyntaxKind(input.kind)}`);
                function cleanup(node) {
                    if (isEnclosingDeclaration(input)) {
                        enclosingDeclaration = previousEnclosingDeclaration;
                    }
                    if (canProdiceDiagnostic) {
                        getSymbolAccessibilityDiagnostic = oldDiag;
                    }
                    if (input.kind === 264 /* ModuleDeclaration */) {
                        needsDeclare = previousNeedsDeclare;
                    }
                    if (node === input) {
                        return node;
                    }
                    errorFallbackNode = void 0;
                    errorNameNode = void 0;
                    return node && setOriginalNode(preserveJsDoc(node, input), input);
                }
            }
            function transformVariableStatement(input) {
                if (!forEach(input.declarationList.declarations, getBindingNameVisible))
                    return;
                const nodes = visitNodes2(input.declarationList.declarations, visitDeclarationSubtree, isVariableDeclaration);
                if (!length(nodes))
                    return;
                return factory2.updateVariableStatement(input, factory2.createNodeArray(ensureModifiers(input)), factory2.updateVariableDeclarationList(input.declarationList, nodes));
            }
            function recreateBindingPattern(d) {
                return flatten(mapDefined(d.elements, (e) => recreateBindingElement(e)));
            }
            function recreateBindingElement(e) {
                if (e.kind === 229 /* OmittedExpression */) {
                    return;
                }
                if (e.name) {
                    if (!getBindingNameVisible(e))
                        return;
                    if (isBindingPattern(e.name)) {
                        return recreateBindingPattern(e.name);
                    }
                    else {
                        return factory2.createVariableDeclaration(e.name, 
                        /*exclamationToken*/
                        void 0, ensureType(e, 
                        /*type*/
                        void 0), 
                        /*initializer*/
                        void 0);
                    }
                }
            }
            function checkName(node) {
                let oldDiag;
                if (!suppressNewDiagnosticContexts) {
                    oldDiag = getSymbolAccessibilityDiagnostic;
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNodeName(node);
                }
                errorNameNode = node.name;
                Debug.assert(resolver.isLateBound(getParseTreeNode(node)));
                const decl = node;
                const entityName = decl.name.expression;
                checkEntityNameVisibility(entityName, enclosingDeclaration);
                if (!suppressNewDiagnosticContexts) {
                    getSymbolAccessibilityDiagnostic = oldDiag;
                }
                errorNameNode = void 0;
            }
            function shouldStripInternal(node) {
                return !!stripInternal && !!node && isInternalDeclaration(node, currentSourceFile);
            }
            function isScopeMarker2(node) {
                return isExportAssignment(node) || isExportDeclaration(node);
            }
            function hasScopeMarker2(statements) {
                return some(statements, isScopeMarker2);
            }
            function ensureModifiers(node) {
                const currentFlags = getEffectiveModifierFlags(node);
                const newFlags = ensureModifierFlags(node);
                if (currentFlags === newFlags) {
                    return visitArray(node.modifiers, (n) => tryCast(n, isModifier), isModifier);
                }
                return factory2.createModifiersFromModifierFlags(newFlags);
            }
            function ensureModifierFlags(node) {
                let mask2 = 258047 /* All */ ^ (4 /* Public */ | 512 /* Async */ | 16384 /* Override */);
                let additions = needsDeclare && !isAlwaysType(node) ? 2 /* Ambient */ : 0 /* None */;
                const parentIsFile = node.parent.kind === 308 /* SourceFile */;
                if (!parentIsFile || isBundledEmit && parentIsFile && isExternalModule(node.parent)) {
                    mask2 ^= 2 /* Ambient */;
                    additions = 0 /* None */;
                }
                return maskModifierFlags(node, mask2, additions);
            }
            function getTypeAnnotationFromAllAccessorDeclarations(node, accessors) {
                let accessorType = getTypeAnnotationFromAccessor(node);
                if (!accessorType && node !== accessors.firstAccessor) {
                    accessorType = getTypeAnnotationFromAccessor(accessors.firstAccessor);
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(accessors.firstAccessor);
                }
                if (!accessorType && accessors.secondAccessor && node !== accessors.secondAccessor) {
                    accessorType = getTypeAnnotationFromAccessor(accessors.secondAccessor);
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(accessors.secondAccessor);
                }
                return accessorType;
            }
            function transformHeritageClauses(nodes) {
                return factory2.createNodeArray(filter(map(nodes, (clause) => factory2.updateHeritageClause(clause, visitNodes2(factory2.createNodeArray(filter(clause.types, (t) => {
                    return isEntityNameExpression(t.expression) || clause.token === 94 /* ExtendsKeyword */ && t.expression.kind === 104 /* NullKeyword */;
                })), visitDeclarationSubtree, isExpressionWithTypeArguments))), (clause) => clause.types && !!clause.types.length));
            }
        }
        function isAlwaysType(node) {
            if (node.kind === 261 /* InterfaceDeclaration */) {
                return true;
            }
            return false;
        }
        function maskModifiers(node, modifierMask, modifierAdditions) {
            return factory.createModifiersFromModifierFlags(maskModifierFlags(node, modifierMask, modifierAdditions));
        }
        function maskModifierFlags(node, modifierMask = 258047 /* All */ ^ 4 /* Public */, modifierAdditions = 0 /* None */) {
            let flags = getEffectiveModifierFlags(node) & modifierMask | modifierAdditions;
            if (flags & 1024 /* Default */ && !(flags & 1 /* Export */)) {
                flags ^= 1 /* Export */;
            }
            if (flags & 1024 /* Default */ && flags & 2 /* Ambient */) {
                flags ^= 2 /* Ambient */;
            }
            return flags;
        }
        function getTypeAnnotationFromAccessor(accessor) {
            if (accessor) {
                return accessor.kind === 174 /* GetAccessor */ ? accessor.type : accessor.parameters.length > 0 ? accessor.parameters[0].type : void 0;
            }
        }
        function canHaveLiteralInitializer(node) {
            switch (node.kind) {
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                    return !hasEffectiveModifier(node, 8 /* Private */);
                case 166 /* Parameter */:
                case 257 /* VariableDeclaration */:
                    return true;
            }
            return false;
        }
        function isPreservedDeclarationStatement(node) {
            switch (node.kind) {
                case 259 /* FunctionDeclaration */:
                case 264 /* ModuleDeclaration */:
                case 268 /* ImportEqualsDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 260 /* ClassDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 263 /* EnumDeclaration */:
                case 240 /* VariableStatement */:
                case 269 /* ImportDeclaration */:
                case 275 /* ExportDeclaration */:
                case 274 /* ExportAssignment */:
                    return true;
            }
            return false;
        }
        function isProcessedComponent(node) {
            switch (node.kind) {
                case 177 /* ConstructSignature */:
                case 173 /* Constructor */:
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 170 /* MethodSignature */:
                case 176 /* CallSignature */:
                case 178 /* IndexSignature */:
                case 257 /* VariableDeclaration */:
                case 165 /* TypeParameter */:
                case 230 /* ExpressionWithTypeArguments */:
                case 180 /* TypeReference */:
                case 191 /* ConditionalType */:
                case 181 /* FunctionType */:
                case 182 /* ConstructorType */:
                case 202 /* ImportType */:
                    return true;
            }
            return false;
        }
        var declarationEmitNodeBuilderFlags;
        var init_declarations = __esm({
            "src/compiler/transformers/declarations.ts"() {
                "use strict";
                init_ts2();
                init_ts_moduleSpecifiers();
                declarationEmitNodeBuilderFlags = 1024 /* MultilineObjectLiterals */ | 2048 /* WriteClassExpressionAsTypeLiteral */ | 4096 /* UseTypeOfFunction */ | 8 /* UseStructuralFallback */ | 524288 /* AllowEmptyTuple */ | 4 /* GenerateNamesForShadowedTypeParams */ | 1 /* NoTruncation */;
            }
        });
        // src/compiler/transformer.ts
        function getModuleTransformer(moduleKind) {
            switch (moduleKind) {
                case 99 /* ESNext */:
                case 7 /* ES2022 */:
                case 6 /* ES2020 */:
                case 5 /* ES2015 */:
                    return transformECMAScriptModule;
                case 4 /* System */:
                    return transformSystemModule;
                case 100 /* Node16 */:
                case 199 /* NodeNext */:
                    return transformNodeModule;
                default:
                    return transformModule;
            }
        }
        function getTransformers(compilerOptions, customTransformers, emitOnly) {
            return {
                scriptTransformers: getScriptTransformers(compilerOptions, customTransformers, emitOnly),
                declarationTransformers: getDeclarationTransformers(customTransformers)
            };
        }
        function getScriptTransformers(compilerOptions, customTransformers, emitOnly) {
            if (emitOnly)
                return emptyArray;
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const moduleKind = getEmitModuleKind(compilerOptions);
            const useDefineForClassFields = getUseDefineForClassFields(compilerOptions);
            const transformers = [];
            addRange(transformers, customTransformers && map(customTransformers.before, wrapScriptTransformerFactory));
            transformers.push(transformTypeScript);
            if (compilerOptions.experimentalDecorators) {
                transformers.push(transformLegacyDecorators);
            }
            else if (languageVersion < 99 /* ESNext */ || !useDefineForClassFields) {
                transformers.push(transformESDecorators);
            }
            transformers.push(transformClassFields);
            if (getJSXTransformEnabled(compilerOptions)) {
                transformers.push(transformJsx);
            }
            if (languageVersion < 99 /* ESNext */) {
                transformers.push(transformESNext);
            }
            if (languageVersion < 8 /* ES2021 */) {
                transformers.push(transformES2021);
            }
            if (languageVersion < 7 /* ES2020 */) {
                transformers.push(transformES2020);
            }
            if (languageVersion < 6 /* ES2019 */) {
                transformers.push(transformES2019);
            }
            if (languageVersion < 5 /* ES2018 */) {
                transformers.push(transformES2018);
            }
            if (languageVersion < 4 /* ES2017 */) {
                transformers.push(transformES2017);
            }
            if (languageVersion < 3 /* ES2016 */) {
                transformers.push(transformES2016);
            }
            if (languageVersion < 2 /* ES2015 */) {
                transformers.push(transformES2015);
                transformers.push(transformGenerators);
            }
            transformers.push(getModuleTransformer(moduleKind));
            if (languageVersion < 1 /* ES5 */) {
                transformers.push(transformES5);
            }
            addRange(transformers, customTransformers && map(customTransformers.after, wrapScriptTransformerFactory));
            return transformers;
        }
        function getDeclarationTransformers(customTransformers) {
            const transformers = [];
            transformers.push(transformDeclarations);
            addRange(transformers, customTransformers && map(customTransformers.afterDeclarations, wrapDeclarationTransformerFactory));
            return transformers;
        }
        function wrapCustomTransformer(transformer) {
            return (node) => isBundle(node) ? transformer.transformBundle(node) : transformer.transformSourceFile(node);
        }
        function wrapCustomTransformerFactory(transformer, handleDefault) {
            return (context) => {
                const customTransformer = transformer(context);
                return typeof customTransformer === "function" ? handleDefault(context, customTransformer) : wrapCustomTransformer(customTransformer);
            };
        }
        function wrapScriptTransformerFactory(transformer) {
            return wrapCustomTransformerFactory(transformer, chainBundle);
        }
        function wrapDeclarationTransformerFactory(transformer) {
            return wrapCustomTransformerFactory(transformer, (_, node) => node);
        }
        function noEmitSubstitution(_hint, node) {
            return node;
        }
        function noEmitNotification(hint, node, callback) {
            callback(hint, node);
        }
        function transformNodes(resolver, host, factory2, options, nodes, transformers, allowDtsFiles) {
            var _a2, _b;
            const enabledSyntaxKindFeatures = new Array(361 /* Count */);
            let lexicalEnvironmentVariableDeclarations;
            let lexicalEnvironmentFunctionDeclarations;
            let lexicalEnvironmentStatements;
            let lexicalEnvironmentFlags = 0 /* None */;
            let lexicalEnvironmentVariableDeclarationsStack = [];
            let lexicalEnvironmentFunctionDeclarationsStack = [];
            let lexicalEnvironmentStatementsStack = [];
            let lexicalEnvironmentFlagsStack = [];
            let lexicalEnvironmentStackOffset = 0;
            let lexicalEnvironmentSuspended = false;
            let blockScopedVariableDeclarationsStack = [];
            let blockScopeStackOffset = 0;
            let blockScopedVariableDeclarations;
            let emitHelpers;
            let onSubstituteNode = noEmitSubstitution;
            let onEmitNode = noEmitNotification;
            let state = 0 /* Uninitialized */;
            const diagnostics = [];
            const context = {
                factory: factory2,
                getCompilerOptions: () => options,
                getEmitResolver: () => resolver,
                // TODO: GH#18217
                getEmitHost: () => host,
                // TODO: GH#18217
                getEmitHelperFactory: memoize(() => createEmitHelperFactory(context)),
                startLexicalEnvironment,
                suspendLexicalEnvironment,
                resumeLexicalEnvironment,
                endLexicalEnvironment,
                setLexicalEnvironmentFlags,
                getLexicalEnvironmentFlags,
                hoistVariableDeclaration,
                hoistFunctionDeclaration,
                addInitializationStatement,
                startBlockScope,
                endBlockScope,
                addBlockScopedVariable,
                requestEmitHelper,
                readEmitHelpers,
                enableSubstitution,
                enableEmitNotification,
                isSubstitutionEnabled,
                isEmitNotificationEnabled,
                get onSubstituteNode() {
                    return onSubstituteNode;
                },
                set onSubstituteNode(value) {
                    Debug.assert(state < 1 /* Initialized */, "Cannot modify transformation hooks after initialization has completed.");
                    Debug.assert(value !== void 0, "Value must not be 'undefined'");
                    onSubstituteNode = value;
                },
                get onEmitNode() {
                    return onEmitNode;
                },
                set onEmitNode(value) {
                    Debug.assert(state < 1 /* Initialized */, "Cannot modify transformation hooks after initialization has completed.");
                    Debug.assert(value !== void 0, "Value must not be 'undefined'");
                    onEmitNode = value;
                },
                addDiagnostic(diag2) {
                    diagnostics.push(diag2);
                }
            };
            for (const node of nodes) {
                disposeEmitNodes(getSourceFileOfNode(getParseTreeNode(node)));
            }
            mark("beforeTransform");
            const transformersWithContext = transformers.map((t) => t(context));
            const transformation = (node) => {
                for (const transform2 of transformersWithContext) {
                    node = transform2(node);
                }
                return node;
            };
            state = 1 /* Initialized */;
            const transformed = [];
            for (const node of nodes) {
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Emit, "transformNodes", node.kind === 308 /* SourceFile */ ? { path: node.path } : { kind: node.kind, pos: node.pos, end: node.end });
                transformed.push((allowDtsFiles ? transformation : transformRoot)(node));
                (_b = tracing) == null ? void 0 : _b.pop();
            }
            state = 2 /* Completed */;
            mark("afterTransform");
            measure("transformTime", "beforeTransform", "afterTransform");
            return {
                transformed,
                substituteNode,
                emitNodeWithNotification,
                isEmitNotificationEnabled,
                dispose,
                diagnostics
            };
            function transformRoot(node) {
                return node && (!isSourceFile(node) || !node.isDeclarationFile) ? transformation(node) : node;
            }
            function enableSubstitution(kind) {
                Debug.assert(state < 2 /* Completed */, "Cannot modify the transformation context after transformation has completed.");
                enabledSyntaxKindFeatures[kind] |= 1 /* Substitution */;
            }
            function isSubstitutionEnabled(node) {
                return (enabledSyntaxKindFeatures[node.kind] & 1 /* Substitution */) !== 0 && (getEmitFlags(node) & 8 /* NoSubstitution */) === 0;
            }
            function substituteNode(hint, node) {
                Debug.assert(state < 3 /* Disposed */, "Cannot substitute a node after the result is disposed.");
                return node && isSubstitutionEnabled(node) && onSubstituteNode(hint, node) || node;
            }
            function enableEmitNotification(kind) {
                Debug.assert(state < 2 /* Completed */, "Cannot modify the transformation context after transformation has completed.");
                enabledSyntaxKindFeatures[kind] |= 2 /* EmitNotifications */;
            }
            function isEmitNotificationEnabled(node) {
                return (enabledSyntaxKindFeatures[node.kind] & 2 /* EmitNotifications */) !== 0 || (getEmitFlags(node) & 4 /* AdviseOnEmitNode */) !== 0;
            }
            function emitNodeWithNotification(hint, node, emitCallback) {
                Debug.assert(state < 3 /* Disposed */, "Cannot invoke TransformationResult callbacks after the result is disposed.");
                if (node) {
                    if (isEmitNotificationEnabled(node)) {
                        onEmitNode(hint, node, emitCallback);
                    }
                    else {
                        emitCallback(hint, node);
                    }
                }
            }
            function hoistVariableDeclaration(name) {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                const decl = setEmitFlags(factory2.createVariableDeclaration(name), 128 /* NoNestedSourceMaps */);
                if (!lexicalEnvironmentVariableDeclarations) {
                    lexicalEnvironmentVariableDeclarations = [decl];
                }
                else {
                    lexicalEnvironmentVariableDeclarations.push(decl);
                }
                if (lexicalEnvironmentFlags & 1 /* InParameters */) {
                    lexicalEnvironmentFlags |= 2 /* VariablesHoistedInParameters */;
                }
            }
            function hoistFunctionDeclaration(func) {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                setEmitFlags(func, 2097152 /* CustomPrologue */);
                if (!lexicalEnvironmentFunctionDeclarations) {
                    lexicalEnvironmentFunctionDeclarations = [func];
                }
                else {
                    lexicalEnvironmentFunctionDeclarations.push(func);
                }
            }
            function addInitializationStatement(node) {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                setEmitFlags(node, 2097152 /* CustomPrologue */);
                if (!lexicalEnvironmentStatements) {
                    lexicalEnvironmentStatements = [node];
                }
                else {
                    lexicalEnvironmentStatements.push(node);
                }
            }
            function startLexicalEnvironment() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                Debug.assert(!lexicalEnvironmentSuspended, "Lexical environment is suspended.");
                lexicalEnvironmentVariableDeclarationsStack[lexicalEnvironmentStackOffset] = lexicalEnvironmentVariableDeclarations;
                lexicalEnvironmentFunctionDeclarationsStack[lexicalEnvironmentStackOffset] = lexicalEnvironmentFunctionDeclarations;
                lexicalEnvironmentStatementsStack[lexicalEnvironmentStackOffset] = lexicalEnvironmentStatements;
                lexicalEnvironmentFlagsStack[lexicalEnvironmentStackOffset] = lexicalEnvironmentFlags;
                lexicalEnvironmentStackOffset++;
                lexicalEnvironmentVariableDeclarations = void 0;
                lexicalEnvironmentFunctionDeclarations = void 0;
                lexicalEnvironmentStatements = void 0;
                lexicalEnvironmentFlags = 0 /* None */;
            }
            function suspendLexicalEnvironment() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                Debug.assert(!lexicalEnvironmentSuspended, "Lexical environment is already suspended.");
                lexicalEnvironmentSuspended = true;
            }
            function resumeLexicalEnvironment() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                Debug.assert(lexicalEnvironmentSuspended, "Lexical environment is not suspended.");
                lexicalEnvironmentSuspended = false;
            }
            function endLexicalEnvironment() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                Debug.assert(!lexicalEnvironmentSuspended, "Lexical environment is suspended.");
                let statements;
                if (lexicalEnvironmentVariableDeclarations || lexicalEnvironmentFunctionDeclarations || lexicalEnvironmentStatements) {
                    if (lexicalEnvironmentFunctionDeclarations) {
                        statements = [...lexicalEnvironmentFunctionDeclarations];
                    }
                    if (lexicalEnvironmentVariableDeclarations) {
                        const statement = factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, factory2.createVariableDeclarationList(lexicalEnvironmentVariableDeclarations));
                        setEmitFlags(statement, 2097152 /* CustomPrologue */);
                        if (!statements) {
                            statements = [statement];
                        }
                        else {
                            statements.push(statement);
                        }
                    }
                    if (lexicalEnvironmentStatements) {
                        if (!statements) {
                            statements = [...lexicalEnvironmentStatements];
                        }
                        else {
                            statements = [...statements, ...lexicalEnvironmentStatements];
                        }
                    }
                }
                lexicalEnvironmentStackOffset--;
                lexicalEnvironmentVariableDeclarations = lexicalEnvironmentVariableDeclarationsStack[lexicalEnvironmentStackOffset];
                lexicalEnvironmentFunctionDeclarations = lexicalEnvironmentFunctionDeclarationsStack[lexicalEnvironmentStackOffset];
                lexicalEnvironmentStatements = lexicalEnvironmentStatementsStack[lexicalEnvironmentStackOffset];
                lexicalEnvironmentFlags = lexicalEnvironmentFlagsStack[lexicalEnvironmentStackOffset];
                if (lexicalEnvironmentStackOffset === 0) {
                    lexicalEnvironmentVariableDeclarationsStack = [];
                    lexicalEnvironmentFunctionDeclarationsStack = [];
                    lexicalEnvironmentStatementsStack = [];
                    lexicalEnvironmentFlagsStack = [];
                }
                return statements;
            }
            function setLexicalEnvironmentFlags(flags, value) {
                lexicalEnvironmentFlags = value ? lexicalEnvironmentFlags | flags : lexicalEnvironmentFlags & ~flags;
            }
            function getLexicalEnvironmentFlags() {
                return lexicalEnvironmentFlags;
            }
            function startBlockScope() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot start a block scope during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot start a block scope after transformation has completed.");
                blockScopedVariableDeclarationsStack[blockScopeStackOffset] = blockScopedVariableDeclarations;
                blockScopeStackOffset++;
                blockScopedVariableDeclarations = void 0;
            }
            function endBlockScope() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot end a block scope during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot end a block scope after transformation has completed.");
                const statements = some(blockScopedVariableDeclarations) ? [
                    factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(blockScopedVariableDeclarations.map((identifier) => factory2.createVariableDeclaration(identifier)), 1 /* Let */))
                ] : void 0;
                blockScopeStackOffset--;
                blockScopedVariableDeclarations = blockScopedVariableDeclarationsStack[blockScopeStackOffset];
                if (blockScopeStackOffset === 0) {
                    blockScopedVariableDeclarationsStack = [];
                }
                return statements;
            }
            function addBlockScopedVariable(name) {
                Debug.assert(blockScopeStackOffset > 0, "Cannot add a block scoped variable outside of an iteration body.");
                (blockScopedVariableDeclarations || (blockScopedVariableDeclarations = [])).push(name);
            }
            function requestEmitHelper(helper) {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the transformation context during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the transformation context after transformation has completed.");
                Debug.assert(!helper.scoped, "Cannot request a scoped emit helper.");
                if (helper.dependencies) {
                    for (const h of helper.dependencies) {
                        requestEmitHelper(h);
                    }
                }
                emitHelpers = append(emitHelpers, helper);
            }
            function readEmitHelpers() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the transformation context during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the transformation context after transformation has completed.");
                const helpers = emitHelpers;
                emitHelpers = void 0;
                return helpers;
            }
            function dispose() {
                if (state < 3 /* Disposed */) {
                    for (const node of nodes) {
                        disposeEmitNodes(getSourceFileOfNode(getParseTreeNode(node)));
                    }
                    lexicalEnvironmentVariableDeclarations = void 0;
                    lexicalEnvironmentVariableDeclarationsStack = void 0;
                    lexicalEnvironmentFunctionDeclarations = void 0;
                    lexicalEnvironmentFunctionDeclarationsStack = void 0;
                    onSubstituteNode = void 0;
                    onEmitNode = void 0;
                    emitHelpers = void 0;
                    state = 3 /* Disposed */;
                }
            }
        }
        var noTransformers, nullTransformationContext;
        var init_transformer = __esm({
            "src/compiler/transformer.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                noTransformers = { scriptTransformers: emptyArray, declarationTransformers: emptyArray };
                nullTransformationContext = {
                    factory,
                    // eslint-disable-line object-shorthand
                    getCompilerOptions: () => ({}),
                    getEmitResolver: notImplemented,
                    getEmitHost: notImplemented,
                    getEmitHelperFactory: notImplemented,
                    startLexicalEnvironment: noop,
                    resumeLexicalEnvironment: noop,
                    suspendLexicalEnvironment: noop,
                    endLexicalEnvironment: returnUndefined,
                    setLexicalEnvironmentFlags: noop,
                    getLexicalEnvironmentFlags: () => 0,
                    hoistVariableDeclaration: noop,
                    hoistFunctionDeclaration: noop,
                    addInitializationStatement: noop,
                    startBlockScope: noop,
                    endBlockScope: returnUndefined,
                    addBlockScopedVariable: noop,
                    requestEmitHelper: noop,
                    readEmitHelpers: notImplemented,
                    enableSubstitution: noop,
                    enableEmitNotification: noop,
                    isSubstitutionEnabled: notImplemented,
                    isEmitNotificationEnabled: notImplemented,
                    onSubstituteNode: noEmitSubstitution,
                    onEmitNode: noEmitNotification,
                    addDiagnostic: noop
                };
            }
        });
        // src/compiler/emitter.ts
        function isBuildInfoFile(file) {
            return fileExtensionIs(file, ".tsbuildinfo" /* TsBuildInfo */);
        }
        function forEachEmittedFile(host, action, sourceFilesOrTargetSourceFile, forceDtsEmit = false, onlyBuildInfo, includeBuildInfo) {
            const sourceFiles = isArray(sourceFilesOrTargetSourceFile) ? sourceFilesOrTargetSourceFile : getSourceFilesToEmit(host, sourceFilesOrTargetSourceFile, forceDtsEmit);
            const options = host.getCompilerOptions();
            if (outFile(options)) {
                const prepends = host.getPrependNodes();
                if (sourceFiles.length || prepends.length) {
                    const bundle = factory.createBundle(sourceFiles, prepends);
                    const result = action(getOutputPathsFor(bundle, host, forceDtsEmit), bundle);
                    if (result) {
                        return result;
                    }
                }
            }
            else {
                if (!onlyBuildInfo) {
                    for (const sourceFile of sourceFiles) {
                        const result = action(getOutputPathsFor(sourceFile, host, forceDtsEmit), sourceFile);
                        if (result) {
                            return result;
                        }
                    }
                }
                if (includeBuildInfo) {
                    const buildInfoPath = getTsBuildInfoEmitOutputFilePath(options);
                    if (buildInfoPath)
                        return action({ buildInfoPath }, 
                        /*sourceFileOrBundle*/
                        void 0);
                }
            }
        }
        function getTsBuildInfoEmitOutputFilePath(options) {
            const configFile = options.configFilePath;
            if (!isIncrementalCompilation(options))
                return void 0;
            if (options.tsBuildInfoFile)
                return options.tsBuildInfoFile;
            const outPath = outFile(options);
            let buildInfoExtensionLess;
            if (outPath) {
                buildInfoExtensionLess = removeFileExtension(outPath);
            }
            else {
                if (!configFile)
                    return void 0;
                const configFileExtensionLess = removeFileExtension(configFile);
                buildInfoExtensionLess = options.outDir ? options.rootDir ? resolvePath(options.outDir, getRelativePathFromDirectory(options.rootDir, configFileExtensionLess, 
                /*ignoreCase*/
                true)) : combinePaths(options.outDir, getBaseFileName(configFileExtensionLess)) : configFileExtensionLess;
            }
            return buildInfoExtensionLess + ".tsbuildinfo" /* TsBuildInfo */;
        }
        function getOutputPathsForBundle(options, forceDtsPaths) {
            const outPath = outFile(options);
            const jsFilePath = options.emitDeclarationOnly ? void 0 : outPath;
            const sourceMapFilePath = jsFilePath && getSourceMapFilePath(jsFilePath, options);
            const declarationFilePath = forceDtsPaths || getEmitDeclarations(options) ? removeFileExtension(outPath) + ".d.ts" /* Dts */ : void 0;
            const declarationMapPath = declarationFilePath && getAreDeclarationMapsEnabled(options) ? declarationFilePath + ".map" : void 0;
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(options);
            return { jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath };
        }
        function getOutputPathsFor(sourceFile, host, forceDtsPaths) {
            const options = host.getCompilerOptions();
            if (sourceFile.kind === 309 /* Bundle */) {
                return getOutputPathsForBundle(options, forceDtsPaths);
            }
            else {
                const ownOutputFilePath = getOwnEmitOutputFilePath(sourceFile.fileName, host, getOutputExtension(sourceFile.fileName, options));
                const isJsonFile = isJsonSourceFile(sourceFile);
                const isJsonEmittedToSameLocation = isJsonFile && comparePaths(sourceFile.fileName, ownOutputFilePath, host.getCurrentDirectory(), !host.useCaseSensitiveFileNames()) === 0 /* EqualTo */;
                const jsFilePath = options.emitDeclarationOnly || isJsonEmittedToSameLocation ? void 0 : ownOutputFilePath;
                const sourceMapFilePath = !jsFilePath || isJsonSourceFile(sourceFile) ? void 0 : getSourceMapFilePath(jsFilePath, options);
                const declarationFilePath = forceDtsPaths || getEmitDeclarations(options) && !isJsonFile ? getDeclarationEmitOutputFilePath(sourceFile.fileName, host) : void 0;
                const declarationMapPath = declarationFilePath && getAreDeclarationMapsEnabled(options) ? declarationFilePath + ".map" : void 0;
                return { jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath: void 0 };
            }
        }
        function getSourceMapFilePath(jsFilePath, options) {
            return options.sourceMap && !options.inlineSourceMap ? jsFilePath + ".map" : void 0;
        }
        function getOutputExtension(fileName, options) {
            return fileExtensionIs(fileName, ".json" /* Json */) ? ".json" /* Json */ : options.jsx === 1 /* Preserve */ && fileExtensionIsOneOf(fileName, [".jsx" /* Jsx */, ".tsx" /* Tsx */]) ? ".jsx" /* Jsx */ : fileExtensionIsOneOf(fileName, [".mts" /* Mts */, ".mjs" /* Mjs */]) ? ".mjs" /* Mjs */ : fileExtensionIsOneOf(fileName, [".cts" /* Cts */, ".cjs" /* Cjs */]) ? ".cjs" /* Cjs */ : ".js" /* Js */;
        }
        function getOutputPathWithoutChangingExt(inputFileName, configFile, ignoreCase, outputDir, getCommonSourceDirectory2) {
            return outputDir ? resolvePath(outputDir, getRelativePathFromDirectory(getCommonSourceDirectory2 ? getCommonSourceDirectory2() : getCommonSourceDirectoryOfConfig(configFile, ignoreCase), inputFileName, ignoreCase)) : inputFileName;
        }
        function getOutputDeclarationFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2) {
            return changeExtension(getOutputPathWithoutChangingExt(inputFileName, configFile, ignoreCase, configFile.options.declarationDir || configFile.options.outDir, getCommonSourceDirectory2), getDeclarationEmitExtensionForPath(inputFileName));
        }
        function getOutputJSFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2) {
            if (configFile.options.emitDeclarationOnly)
                return void 0;
            const isJsonFile = fileExtensionIs(inputFileName, ".json" /* Json */);
            const outputFileName = changeExtension(getOutputPathWithoutChangingExt(inputFileName, configFile, ignoreCase, configFile.options.outDir, getCommonSourceDirectory2), getOutputExtension(inputFileName, configFile.options));
            return !isJsonFile || comparePaths(inputFileName, outputFileName, Debug.checkDefined(configFile.options.configFilePath), ignoreCase) !== 0 /* EqualTo */ ? outputFileName : void 0;
        }
        function createAddOutput() {
            let outputs;
            return { addOutput, getOutputs };
            function addOutput(path) {
                if (path) {
                    (outputs || (outputs = [])).push(path);
                }
            }
            function getOutputs() {
                return outputs || emptyArray;
            }
        }
        function getSingleOutputFileNames(configFile, addOutput) {
            const { jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath } = getOutputPathsForBundle(configFile.options, 
            /*forceDtsPaths*/
            false);
            addOutput(jsFilePath);
            addOutput(sourceMapFilePath);
            addOutput(declarationFilePath);
            addOutput(declarationMapPath);
            addOutput(buildInfoPath);
        }
        function getOwnOutputFileNames(configFile, inputFileName, ignoreCase, addOutput, getCommonSourceDirectory2) {
            if (isDeclarationFileName(inputFileName))
                return;
            const js = getOutputJSFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2);
            addOutput(js);
            if (fileExtensionIs(inputFileName, ".json" /* Json */))
                return;
            if (js && configFile.options.sourceMap) {
                addOutput(`${js}.map`);
            }
            if (getEmitDeclarations(configFile.options)) {
                const dts = getOutputDeclarationFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2);
                addOutput(dts);
                if (configFile.options.declarationMap) {
                    addOutput(`${dts}.map`);
                }
            }
        }
        function getCommonSourceDirectory(options, emittedFiles, currentDirectory, getCanonicalFileName, checkSourceFilesBelongToPath) {
            let commonSourceDirectory;
            if (options.rootDir) {
                commonSourceDirectory = getNormalizedAbsolutePath(options.rootDir, currentDirectory);
                checkSourceFilesBelongToPath == null ? void 0 : checkSourceFilesBelongToPath(options.rootDir);
            }
            else if (options.composite && options.configFilePath) {
                commonSourceDirectory = getDirectoryPath(normalizeSlashes(options.configFilePath));
                checkSourceFilesBelongToPath == null ? void 0 : checkSourceFilesBelongToPath(commonSourceDirectory);
            }
            else {
                commonSourceDirectory = computeCommonSourceDirectoryOfFilenames(emittedFiles(), currentDirectory, getCanonicalFileName);
            }
            if (commonSourceDirectory && commonSourceDirectory[commonSourceDirectory.length - 1] !== directorySeparator) {
                commonSourceDirectory += directorySeparator;
            }
            return commonSourceDirectory;
        }
        function getCommonSourceDirectoryOfConfig({ options, fileNames }, ignoreCase) {
            return getCommonSourceDirectory(options, () => filter(fileNames, (file) => !(options.noEmitForJsFiles && fileExtensionIsOneOf(file, supportedJSExtensionsFlat)) && !isDeclarationFileName(file)), getDirectoryPath(normalizeSlashes(Debug.checkDefined(options.configFilePath))), createGetCanonicalFileName(!ignoreCase));
        }
        function getAllProjectOutputs(configFile, ignoreCase) {
            const { addOutput, getOutputs } = createAddOutput();
            if (outFile(configFile.options)) {
                getSingleOutputFileNames(configFile, addOutput);
            }
            else {
                const getCommonSourceDirectory2 = memoize(() => getCommonSourceDirectoryOfConfig(configFile, ignoreCase));
                for (const inputFileName of configFile.fileNames) {
                    getOwnOutputFileNames(configFile, inputFileName, ignoreCase, addOutput, getCommonSourceDirectory2);
                }
                addOutput(getTsBuildInfoEmitOutputFilePath(configFile.options));
            }
            return getOutputs();
        }
        function getOutputFileNames(commandLine, inputFileName, ignoreCase) {
            inputFileName = normalizePath(inputFileName);
            Debug.assert(contains(commandLine.fileNames, inputFileName), `Expected fileName to be present in command line`);
            const { addOutput, getOutputs } = createAddOutput();
            if (outFile(commandLine.options)) {
                getSingleOutputFileNames(commandLine, addOutput);
            }
            else {
                getOwnOutputFileNames(commandLine, inputFileName, ignoreCase, addOutput);
            }
            return getOutputs();
        }
        function getFirstProjectOutput(configFile, ignoreCase) {
            if (outFile(configFile.options)) {
                const { jsFilePath, declarationFilePath } = getOutputPathsForBundle(configFile.options, 
                /*forceDtsPaths*/
                false);
                return Debug.checkDefined(jsFilePath || declarationFilePath, `project ${configFile.options.configFilePath} expected to have at least one output`);
            }
            const getCommonSourceDirectory2 = memoize(() => getCommonSourceDirectoryOfConfig(configFile, ignoreCase));
            for (const inputFileName of configFile.fileNames) {
                if (isDeclarationFileName(inputFileName))
                    continue;
                const jsFilePath = getOutputJSFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2);
                if (jsFilePath)
                    return jsFilePath;
                if (fileExtensionIs(inputFileName, ".json" /* Json */))
                    continue;
                if (getEmitDeclarations(configFile.options)) {
                    return getOutputDeclarationFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2);
                }
            }
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(configFile.options);
            if (buildInfoPath)
                return buildInfoPath;
            return Debug.fail(`project ${configFile.options.configFilePath} expected to have at least one output`);
        }
        function emitFiles(resolver, host, targetSourceFile, { scriptTransformers, declarationTransformers }, emitOnly, onlyBuildInfo, forceDtsEmit) {
            var compilerOptions = host.getCompilerOptions();
            var sourceMapDataList = compilerOptions.sourceMap || compilerOptions.inlineSourceMap || getAreDeclarationMapsEnabled(compilerOptions) ? [] : void 0;
            var emittedFilesList = compilerOptions.listEmittedFiles ? [] : void 0;
            var emitterDiagnostics = createDiagnosticCollection();
            var newLine = getNewLineCharacter(compilerOptions);
            var writer = createTextWriter(newLine);
            var { enter, exit } = createTimer("printTime", "beforePrint", "afterPrint");
            var bundleBuildInfo;
            var emitSkipped = false;
            enter();
            forEachEmittedFile(host, emitSourceFileOrBundle, getSourceFilesToEmit(host, targetSourceFile, forceDtsEmit), forceDtsEmit, onlyBuildInfo, !targetSourceFile);
            exit();
            return {
                emitSkipped,
                diagnostics: emitterDiagnostics.getDiagnostics(),
                emittedFiles: emittedFilesList,
                sourceMaps: sourceMapDataList
            };
            function emitSourceFileOrBundle({ jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath }, sourceFileOrBundle) {
                var _a2, _b, _c, _d, _e, _f;
                let buildInfoDirectory;
                if (buildInfoPath && sourceFileOrBundle && isBundle(sourceFileOrBundle)) {
                    buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(buildInfoPath, host.getCurrentDirectory()));
                    bundleBuildInfo = {
                        commonSourceDirectory: relativeToBuildInfo(host.getCommonSourceDirectory()),
                        sourceFiles: sourceFileOrBundle.sourceFiles.map((file) => relativeToBuildInfo(getNormalizedAbsolutePath(file.fileName, host.getCurrentDirectory())))
                    };
                }
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Emit, "emitJsFileOrBundle", { jsFilePath });
                emitJsFileOrBundle(sourceFileOrBundle, jsFilePath, sourceMapFilePath, relativeToBuildInfo);
                (_b = tracing) == null ? void 0 : _b.pop();
                (_c = tracing) == null ? void 0 : _c.push(tracing.Phase.Emit, "emitDeclarationFileOrBundle", { declarationFilePath });
                emitDeclarationFileOrBundle(sourceFileOrBundle, declarationFilePath, declarationMapPath, relativeToBuildInfo);
                (_d = tracing) == null ? void 0 : _d.pop();
                (_e = tracing) == null ? void 0 : _e.push(tracing.Phase.Emit, "emitBuildInfo", { buildInfoPath });
                emitBuildInfo(bundleBuildInfo, buildInfoPath);
                (_f = tracing) == null ? void 0 : _f.pop();
                if (!emitSkipped && emittedFilesList) {
                    if (!emitOnly) {
                        if (jsFilePath) {
                            emittedFilesList.push(jsFilePath);
                        }
                        if (sourceMapFilePath) {
                            emittedFilesList.push(sourceMapFilePath);
                        }
                        if (buildInfoPath) {
                            emittedFilesList.push(buildInfoPath);
                        }
                    }
                    if (emitOnly !== 0 /* Js */) {
                        if (declarationFilePath) {
                            emittedFilesList.push(declarationFilePath);
                        }
                        if (declarationMapPath) {
                            emittedFilesList.push(declarationMapPath);
                        }
                    }
                }
                function relativeToBuildInfo(path) {
                    return ensurePathIsNonModuleName(getRelativePathFromDirectory(buildInfoDirectory, path, host.getCanonicalFileName));
                }
            }
            function emitBuildInfo(bundle, buildInfoPath) {
                if (!buildInfoPath || targetSourceFile || emitSkipped)
                    return;
                if (host.isEmitBlocked(buildInfoPath)) {
                    emitSkipped = true;
                    return;
                }
                const buildInfo = host.getBuildInfo(bundle) || createBuildInfo(
                /*program*/
                void 0, bundle);
                writeFile(host, emitterDiagnostics, buildInfoPath, getBuildInfoText(buildInfo), 
                /*writeByteOrderMark*/
                false, 
                /*sourceFiles*/
                void 0, { buildInfo });
            }
            function emitJsFileOrBundle(sourceFileOrBundle, jsFilePath, sourceMapFilePath, relativeToBuildInfo) {
                if (!sourceFileOrBundle || emitOnly || !jsFilePath) {
                    return;
                }
                if (host.isEmitBlocked(jsFilePath) || compilerOptions.noEmit) {
                    emitSkipped = true;
                    return;
                }
                const transform2 = transformNodes(resolver, host, factory, compilerOptions, [sourceFileOrBundle], scriptTransformers, 
                /*allowDtsFiles*/
                false);
                const printerOptions = {
                    removeComments: compilerOptions.removeComments,
                    newLine: compilerOptions.newLine,
                    noEmitHelpers: compilerOptions.noEmitHelpers,
                    module: compilerOptions.module,
                    target: compilerOptions.target,
                    sourceMap: compilerOptions.sourceMap,
                    inlineSourceMap: compilerOptions.inlineSourceMap,
                    inlineSources: compilerOptions.inlineSources,
                    extendedDiagnostics: compilerOptions.extendedDiagnostics,
                    writeBundleFileInfo: !!bundleBuildInfo,
                    relativeToBuildInfo
                };
                const printer = createPrinter(printerOptions, {
                    // resolver hooks
                    hasGlobalName: resolver.hasGlobalName,
                    // transform hooks
                    onEmitNode: transform2.emitNodeWithNotification,
                    isEmitNotificationEnabled: transform2.isEmitNotificationEnabled,
                    substituteNode: transform2.substituteNode
                });
                Debug.assert(transform2.transformed.length === 1, "Should only see one output from the transform");
                printSourceFileOrBundle(jsFilePath, sourceMapFilePath, transform2, printer, compilerOptions);
                transform2.dispose();
                if (bundleBuildInfo)
                    bundleBuildInfo.js = printer.bundleFileInfo;
            }
            function emitDeclarationFileOrBundle(sourceFileOrBundle, declarationFilePath, declarationMapPath, relativeToBuildInfo) {
                if (!sourceFileOrBundle || emitOnly === 0 /* Js */)
                    return;
                if (!declarationFilePath) {
                    if (emitOnly || compilerOptions.emitDeclarationOnly)
                        emitSkipped = true;
                    return;
                }
                const sourceFiles = isSourceFile(sourceFileOrBundle) ? [sourceFileOrBundle] : sourceFileOrBundle.sourceFiles;
                const filesForEmit = forceDtsEmit ? sourceFiles : filter(sourceFiles, isSourceFileNotJson);
                const inputListOrBundle = outFile(compilerOptions) ? [factory.createBundle(filesForEmit, !isSourceFile(sourceFileOrBundle) ? sourceFileOrBundle.prepends : void 0)] : filesForEmit;
                if (emitOnly && !getEmitDeclarations(compilerOptions)) {
                    filesForEmit.forEach(collectLinkedAliases);
                }
                const declarationTransform = transformNodes(resolver, host, factory, compilerOptions, inputListOrBundle, declarationTransformers, 
                /*allowDtsFiles*/
                false);
                if (length(declarationTransform.diagnostics)) {
                    for (const diagnostic of declarationTransform.diagnostics) {
                        emitterDiagnostics.add(diagnostic);
                    }
                }
                const printerOptions = {
                    removeComments: compilerOptions.removeComments,
                    newLine: compilerOptions.newLine,
                    noEmitHelpers: true,
                    module: compilerOptions.module,
                    target: compilerOptions.target,
                    sourceMap: !forceDtsEmit && compilerOptions.declarationMap,
                    inlineSourceMap: compilerOptions.inlineSourceMap,
                    extendedDiagnostics: compilerOptions.extendedDiagnostics,
                    onlyPrintJsDocStyle: true,
                    writeBundleFileInfo: !!bundleBuildInfo,
                    recordInternalSection: !!bundleBuildInfo,
                    relativeToBuildInfo
                };
                const declarationPrinter = createPrinter(printerOptions, {
                    // resolver hooks
                    hasGlobalName: resolver.hasGlobalName,
                    // transform hooks
                    onEmitNode: declarationTransform.emitNodeWithNotification,
                    isEmitNotificationEnabled: declarationTransform.isEmitNotificationEnabled,
                    substituteNode: declarationTransform.substituteNode
                });
                const declBlocked = !!declarationTransform.diagnostics && !!declarationTransform.diagnostics.length || !!host.isEmitBlocked(declarationFilePath) || !!compilerOptions.noEmit;
                emitSkipped = emitSkipped || declBlocked;
                if (!declBlocked || forceDtsEmit) {
                    Debug.assert(declarationTransform.transformed.length === 1, "Should only see one output from the decl transform");
                    printSourceFileOrBundle(declarationFilePath, declarationMapPath, declarationTransform, declarationPrinter, {
                        sourceMap: printerOptions.sourceMap,
                        sourceRoot: compilerOptions.sourceRoot,
                        mapRoot: compilerOptions.mapRoot,
                        extendedDiagnostics: compilerOptions.extendedDiagnostics
                        // Explicitly do not passthru either `inline` option
                    });
                }
                declarationTransform.dispose();
                if (bundleBuildInfo)
                    bundleBuildInfo.dts = declarationPrinter.bundleFileInfo;
            }
            function collectLinkedAliases(node) {
                if (isExportAssignment(node)) {
                    if (node.expression.kind === 79 /* Identifier */) {
                        resolver.collectLinkedAliases(node.expression, 
                        /*setVisibility*/
                        true);
                    }
                    return;
                }
                else if (isExportSpecifier(node)) {
                    resolver.collectLinkedAliases(node.propertyName || node.name, 
                    /*setVisibility*/
                    true);
                    return;
                }
                forEachChild(node, collectLinkedAliases);
            }
            function printSourceFileOrBundle(jsFilePath, sourceMapFilePath, transform2, printer, mapOptions) {
                const sourceFileOrBundle = transform2.transformed[0];
                const bundle = sourceFileOrBundle.kind === 309 /* Bundle */ ? sourceFileOrBundle : void 0;
                const sourceFile = sourceFileOrBundle.kind === 308 /* SourceFile */ ? sourceFileOrBundle : void 0;
                const sourceFiles = bundle ? bundle.sourceFiles : [sourceFile];
                let sourceMapGenerator;
                if (shouldEmitSourceMaps(mapOptions, sourceFileOrBundle)) {
                    sourceMapGenerator = createSourceMapGenerator(host, getBaseFileName(normalizeSlashes(jsFilePath)), getSourceRoot(mapOptions), getSourceMapDirectory(mapOptions, jsFilePath, sourceFile), mapOptions);
                }
                if (bundle) {
                    printer.writeBundle(bundle, writer, sourceMapGenerator);
                }
                else {
                    printer.writeFile(sourceFile, writer, sourceMapGenerator);
                }
                let sourceMapUrlPos;
                if (sourceMapGenerator) {
                    if (sourceMapDataList) {
                        sourceMapDataList.push({
                            inputSourceFileNames: sourceMapGenerator.getSources(),
                            sourceMap: sourceMapGenerator.toJSON()
                        });
                    }
                    const sourceMappingURL = getSourceMappingURL(mapOptions, sourceMapGenerator, jsFilePath, sourceMapFilePath, sourceFile);
                    if (sourceMappingURL) {
                        if (!writer.isAtStartOfLine())
                            writer.rawWrite(newLine);
                        sourceMapUrlPos = writer.getTextPos();
                        writer.writeComment(`//# ${"sourceMappingURL"}=${sourceMappingURL}`);
                    }
                    if (sourceMapFilePath) {
                        const sourceMap = sourceMapGenerator.toString();
                        writeFile(host, emitterDiagnostics, sourceMapFilePath, sourceMap, 
                        /*writeByteOrderMark*/
                        false, sourceFiles);
                        if (printer.bundleFileInfo)
                            printer.bundleFileInfo.mapHash = computeSignature(sourceMap, host);
                    }
                }
                else {
                    writer.writeLine();
                }
                const text = writer.getText();
                writeFile(host, emitterDiagnostics, jsFilePath, text, !!compilerOptions.emitBOM, sourceFiles, { sourceMapUrlPos, diagnostics: transform2.diagnostics });
                if (printer.bundleFileInfo)
                    printer.bundleFileInfo.hash = computeSignature(text, host);
                writer.clear();
            }
            function shouldEmitSourceMaps(mapOptions, sourceFileOrBundle) {
                return (mapOptions.sourceMap || mapOptions.inlineSourceMap) && (sourceFileOrBundle.kind !== 308 /* SourceFile */ || !fileExtensionIs(sourceFileOrBundle.fileName, ".json" /* Json */));
            }
            function getSourceRoot(mapOptions) {
                const sourceRoot = normalizeSlashes(mapOptions.sourceRoot || "");
                return sourceRoot ? ensureTrailingDirectorySeparator(sourceRoot) : sourceRoot;
            }
            function getSourceMapDirectory(mapOptions, filePath, sourceFile) {
                if (mapOptions.sourceRoot)
                    return host.getCommonSourceDirectory();
                if (mapOptions.mapRoot) {
                    let sourceMapDir = normalizeSlashes(mapOptions.mapRoot);
                    if (sourceFile) {
                        sourceMapDir = getDirectoryPath(getSourceFilePathInNewDir(sourceFile.fileName, host, sourceMapDir));
                    }
                    if (getRootLength(sourceMapDir) === 0) {
                        sourceMapDir = combinePaths(host.getCommonSourceDirectory(), sourceMapDir);
                    }
                    return sourceMapDir;
                }
                return getDirectoryPath(normalizePath(filePath));
            }
            function getSourceMappingURL(mapOptions, sourceMapGenerator, filePath, sourceMapFilePath, sourceFile) {
                if (mapOptions.inlineSourceMap) {
                    const sourceMapText = sourceMapGenerator.toString();
                    const base64SourceMapText = base64encode(sys, sourceMapText);
                    return `data:application/json;base64,${base64SourceMapText}`;
                }
                const sourceMapFile = getBaseFileName(normalizeSlashes(Debug.checkDefined(sourceMapFilePath)));
                if (mapOptions.mapRoot) {
                    let sourceMapDir = normalizeSlashes(mapOptions.mapRoot);
                    if (sourceFile) {
                        sourceMapDir = getDirectoryPath(getSourceFilePathInNewDir(sourceFile.fileName, host, sourceMapDir));
                    }
                    if (getRootLength(sourceMapDir) === 0) {
                        sourceMapDir = combinePaths(host.getCommonSourceDirectory(), sourceMapDir);
                        return encodeURI(getRelativePathToDirectoryOrUrl(getDirectoryPath(normalizePath(filePath)), 
                        // get the relative sourceMapDir path based on jsFilePath
                        combinePaths(sourceMapDir, sourceMapFile), 
                        // this is where user expects to see sourceMap
                        host.getCurrentDirectory(), host.getCanonicalFileName, 
                        /*isAbsolutePathAnUrl*/
                        true));
                    }
                    else {
                        return encodeURI(combinePaths(sourceMapDir, sourceMapFile));
                    }
                }
                return encodeURI(sourceMapFile);
            }
        }
        function createBuildInfo(program, bundle) {
            const version2 = version;
            return { bundle, program, version: version2 };
        }
        function getBuildInfoText(buildInfo) {
            return JSON.stringify(buildInfo);
        }
        function getBuildInfo(buildInfoFile, buildInfoText) {
            return readJsonOrUndefined(buildInfoFile, buildInfoText);
        }
        function createSourceFilesFromBundleBuildInfo(bundle, buildInfoDirectory, host) {
            var _a2;
            const jsBundle = Debug.checkDefined(bundle.js);
            const prologueMap = ((_a2 = jsBundle.sources) == null ? void 0 : _a2.prologues) && arrayToMap(jsBundle.sources.prologues, (prologueInfo) => prologueInfo.file);
            return bundle.sourceFiles.map((fileName, index) => {
                var _a3, _b;
                const prologueInfo = prologueMap == null ? void 0 : prologueMap.get(index);
                const statements = prologueInfo == null ? void 0 : prologueInfo.directives.map((directive) => {
                    const literal = setTextRange(factory.createStringLiteral(directive.expression.text), directive.expression);
                    const statement = setTextRange(factory.createExpressionStatement(literal), directive);
                    setParent(literal, statement);
                    return statement;
                });
                const eofToken = factory.createToken(1 /* EndOfFileToken */);
                const sourceFile = factory.createSourceFile(statements != null ? statements : [], eofToken, 0 /* None */);
                sourceFile.fileName = getRelativePathFromDirectory(host.getCurrentDirectory(), getNormalizedAbsolutePath(fileName, buildInfoDirectory), !host.useCaseSensitiveFileNames());
                sourceFile.text = (_a3 = prologueInfo == null ? void 0 : prologueInfo.text) != null ? _a3 : "";
                setTextRangePosWidth(sourceFile, 0, (_b = prologueInfo == null ? void 0 : prologueInfo.text.length) != null ? _b : 0);
                setEachParent(sourceFile.statements, sourceFile);
                setTextRangePosWidth(eofToken, sourceFile.end, 0);
                setParent(eofToken, sourceFile);
                return sourceFile;
            });
        }
        function emitUsingBuildInfo(config, host, getCommandLine, customTransformers) {
            var _a2, _b;
            (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Emit, "emitUsingBuildInfo", {}, 
            /*separateBeginAndEnd*/
            true);
            ts_performance_exports.mark("beforeEmit");
            const result = emitUsingBuildInfoWorker(config, host, getCommandLine, customTransformers);
            ts_performance_exports.mark("afterEmit");
            ts_performance_exports.measure("Emit", "beforeEmit", "afterEmit");
            (_b = tracing) == null ? void 0 : _b.pop();
            return result;
        }
        function emitUsingBuildInfoWorker(config, host, getCommandLine, customTransformers) {
            const { buildInfoPath, jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath } = getOutputPathsForBundle(config.options, 
            /*forceDtsPaths*/
            false);
            const buildInfo = host.getBuildInfo(buildInfoPath, config.options.configFilePath);
            if (!buildInfo)
                return buildInfoPath;
            if (!buildInfo.bundle || !buildInfo.bundle.js || declarationFilePath && !buildInfo.bundle.dts)
                return buildInfoPath;
            const jsFileText = host.readFile(Debug.checkDefined(jsFilePath));
            if (!jsFileText)
                return jsFilePath;
            if (computeSignature(jsFileText, host) !== buildInfo.bundle.js.hash)
                return jsFilePath;
            const sourceMapText = sourceMapFilePath && host.readFile(sourceMapFilePath);
            if (sourceMapFilePath && !sourceMapText || config.options.inlineSourceMap)
                return sourceMapFilePath || "inline sourcemap decoding";
            if (sourceMapFilePath && computeSignature(sourceMapText, host) !== buildInfo.bundle.js.mapHash)
                return sourceMapFilePath;
            const declarationText = declarationFilePath && host.readFile(declarationFilePath);
            if (declarationFilePath && !declarationText)
                return declarationFilePath;
            if (declarationFilePath && computeSignature(declarationText, host) !== buildInfo.bundle.dts.hash)
                return declarationFilePath;
            const declarationMapText = declarationMapPath && host.readFile(declarationMapPath);
            if (declarationMapPath && !declarationMapText || config.options.inlineSourceMap)
                return declarationMapPath || "inline sourcemap decoding";
            if (declarationMapPath && computeSignature(declarationMapText, host) !== buildInfo.bundle.dts.mapHash)
                return declarationMapPath;
            const buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(buildInfoPath, host.getCurrentDirectory()));
            const ownPrependInput = createInputFilesWithFileTexts(jsFilePath, jsFileText, sourceMapFilePath, sourceMapText, declarationFilePath, declarationText, declarationMapPath, declarationMapText, buildInfoPath, buildInfo, 
            /*onlyOwnText*/
            true);
            const outputFiles = [];
            const prependNodes = createPrependNodes(config.projectReferences, getCommandLine, (f) => host.readFile(f), host);
            const sourceFilesForJsEmit = createSourceFilesFromBundleBuildInfo(buildInfo.bundle, buildInfoDirectory, host);
            let changedDtsText;
            let changedDtsData;
            const emitHost = {
                getPrependNodes: memoize(() => [...prependNodes, ownPrependInput]),
                getCanonicalFileName: host.getCanonicalFileName,
                getCommonSourceDirectory: () => getNormalizedAbsolutePath(buildInfo.bundle.commonSourceDirectory, buildInfoDirectory),
                getCompilerOptions: () => config.options,
                getCurrentDirectory: () => host.getCurrentDirectory(),
                getSourceFile: returnUndefined,
                getSourceFileByPath: returnUndefined,
                getSourceFiles: () => sourceFilesForJsEmit,
                getLibFileFromReference: notImplemented,
                isSourceFileFromExternalLibrary: returnFalse,
                getResolvedProjectReferenceToRedirect: returnUndefined,
                getProjectReferenceRedirect: returnUndefined,
                isSourceOfProjectReferenceRedirect: returnFalse,
                writeFile: (name, text, writeByteOrderMark, _onError, _sourceFiles, data) => {
                    switch (name) {
                        case jsFilePath:
                            if (jsFileText === text)
                                return;
                            break;
                        case sourceMapFilePath:
                            if (sourceMapText === text)
                                return;
                            break;
                        case buildInfoPath:
                            break;
                        case declarationFilePath:
                            if (declarationText === text)
                                return;
                            changedDtsText = text;
                            changedDtsData = data;
                            break;
                        case declarationMapPath:
                            if (declarationMapText === text)
                                return;
                            break;
                        default:
                            Debug.fail(`Unexpected path: ${name}`);
                    }
                    outputFiles.push({ name, text, writeByteOrderMark, data });
                },
                isEmitBlocked: returnFalse,
                readFile: (f) => host.readFile(f),
                fileExists: (f) => host.fileExists(f),
                useCaseSensitiveFileNames: () => host.useCaseSensitiveFileNames(),
                getBuildInfo: (bundle) => {
                    const program = buildInfo.program;
                    if (program && changedDtsText !== void 0 && config.options.composite) {
                        program.outSignature = computeSignature(changedDtsText, host, changedDtsData);
                    }
                    const { js, dts, sourceFiles } = buildInfo.bundle;
                    bundle.js.sources = js.sources;
                    if (dts) {
                        bundle.dts.sources = dts.sources;
                    }
                    bundle.sourceFiles = sourceFiles;
                    return createBuildInfo(program, bundle);
                },
                getSourceFileFromReference: returnUndefined,
                redirectTargetsMap: createMultiMap(),
                getFileIncludeReasons: notImplemented,
                createHash: maybeBind(host, host.createHash)
            };
            emitFiles(notImplementedResolver, emitHost, 
            /*targetSourceFile*/
            void 0, getTransformers(config.options, customTransformers));
            return outputFiles;
        }
        function createPrinter(printerOptions = {}, handlers = {}) {
            var { hasGlobalName, onEmitNode = noEmitNotification, isEmitNotificationEnabled, substituteNode = noEmitSubstitution, onBeforeEmitNode, onAfterEmitNode, onBeforeEmitNodeArray, onAfterEmitNodeArray, onBeforeEmitToken, onAfterEmitToken } = handlers;
            var extendedDiagnostics = !!printerOptions.extendedDiagnostics;
            var newLine = getNewLineCharacter(printerOptions);
            var moduleKind = getEmitModuleKind(printerOptions);
            var bundledHelpers = /* @__PURE__ */ new Map();
            var currentSourceFile;
            var nodeIdToGeneratedName;
            var nodeIdToGeneratedPrivateName;
            var autoGeneratedIdToGeneratedName;
            var generatedNames;
            var formattedNameTempFlagsStack;
            var formattedNameTempFlags;
            var privateNameTempFlagsStack;
            var privateNameTempFlags;
            var tempFlagsStack;
            var tempFlags;
            var reservedNamesStack;
            var reservedNames;
            var reservedPrivateNamesStack;
            var reservedPrivateNames;
            var preserveSourceNewlines = printerOptions.preserveSourceNewlines;
            var nextListElementPos;
            var writer;
            var ownWriter;
            var write = writeBase;
            var isOwnFileEmit;
            var bundleFileInfo = printerOptions.writeBundleFileInfo ? { sections: [] } : void 0;
            var relativeToBuildInfo = bundleFileInfo ? Debug.checkDefined(printerOptions.relativeToBuildInfo) : void 0;
            var recordInternalSection = printerOptions.recordInternalSection;
            var sourceFileTextPos = 0;
            var sourceFileTextKind = "text" /* Text */;
            var sourceMapsDisabled = true;
            var sourceMapGenerator;
            var sourceMapSource;
            var sourceMapSourceIndex = -1;
            var mostRecentlyAddedSourceMapSource;
            var mostRecentlyAddedSourceMapSourceIndex = -1;
            var containerPos = -1;
            var containerEnd = -1;
            var declarationListContainerEnd = -1;
            var currentLineMap;
            var detachedCommentsInfo;
            var hasWrittenComment = false;
            var commentsDisabled = !!printerOptions.removeComments;
            var lastSubstitution;
            var currentParenthesizerRule;
            var { enter: enterComment, exit: exitComment } = createTimerIf(extendedDiagnostics, "commentTime", "beforeComment", "afterComment");
            var parenthesizer = factory.parenthesizer;
            var typeArgumentParenthesizerRuleSelector = {
                select: (index) => index === 0 ? parenthesizer.parenthesizeLeadingTypeArgument : void 0
            };
            var emitBinaryExpression = createEmitBinaryExpression();
            reset2();
            return {
                // public API
                printNode,
                printList,
                printFile,
                printBundle,
                // internal API
                writeNode,
                writeList,
                writeFile: writeFile2,
                writeBundle,
                bundleFileInfo
            };
            function printNode(hint, node, sourceFile) {
                switch (hint) {
                    case 0 /* SourceFile */:
                        Debug.assert(isSourceFile(node), "Expected a SourceFile node.");
                        break;
                    case 2 /* IdentifierName */:
                        Debug.assert(isIdentifier(node), "Expected an Identifier node.");
                        break;
                    case 1 /* Expression */:
                        Debug.assert(isExpression(node), "Expected an Expression node.");
                        break;
                }
                switch (node.kind) {
                    case 308 /* SourceFile */:
                        return printFile(node);
                    case 309 /* Bundle */:
                        return printBundle(node);
                    case 310 /* UnparsedSource */:
                        return printUnparsedSource(node);
                }
                writeNode(hint, node, sourceFile, beginPrint());
                return endPrint();
            }
            function printList(format, nodes, sourceFile) {
                writeList(format, nodes, sourceFile, beginPrint());
                return endPrint();
            }
            function printBundle(bundle) {
                writeBundle(bundle, beginPrint(), 
                /*sourceMapEmitter*/
                void 0);
                return endPrint();
            }
            function printFile(sourceFile) {
                writeFile2(sourceFile, beginPrint(), 
                /*sourceMapEmitter*/
                void 0);
                return endPrint();
            }
            function printUnparsedSource(unparsed) {
                writeUnparsedSource(unparsed, beginPrint());
                return endPrint();
            }
            function writeNode(hint, node, sourceFile, output) {
                const previousWriter = writer;
                setWriter(output, 
                /*_sourceMapGenerator*/
                void 0);
                print(hint, node, sourceFile);
                reset2();
                writer = previousWriter;
            }
            function writeList(format, nodes, sourceFile, output) {
                const previousWriter = writer;
                setWriter(output, 
                /*_sourceMapGenerator*/
                void 0);
                if (sourceFile) {
                    setSourceFile(sourceFile);
                }
                emitList(
                /*parentNode*/
                void 0, nodes, format);
                reset2();
                writer = previousWriter;
            }
            function getTextPosWithWriteLine() {
                return writer.getTextPosWithWriteLine ? writer.getTextPosWithWriteLine() : writer.getTextPos();
            }
            function updateOrPushBundleFileTextLike(pos, end, kind) {
                const last2 = lastOrUndefined(bundleFileInfo.sections);
                if (last2 && last2.kind === kind) {
                    last2.end = end;
                }
                else {
                    bundleFileInfo.sections.push({ pos, end, kind });
                }
            }
            function recordBundleFileInternalSectionStart(node) {
                if (recordInternalSection && bundleFileInfo && currentSourceFile && (isDeclaration(node) || isVariableStatement(node)) && isInternalDeclaration(node, currentSourceFile) && sourceFileTextKind !== "internal" /* Internal */) {
                    const prevSourceFileTextKind = sourceFileTextKind;
                    recordBundleFileTextLikeSection(writer.getTextPos());
                    sourceFileTextPos = getTextPosWithWriteLine();
                    sourceFileTextKind = "internal" /* Internal */;
                    return prevSourceFileTextKind;
                }
                return void 0;
            }
            function recordBundleFileInternalSectionEnd(prevSourceFileTextKind) {
                if (prevSourceFileTextKind) {
                    recordBundleFileTextLikeSection(writer.getTextPos());
                    sourceFileTextPos = getTextPosWithWriteLine();
                    sourceFileTextKind = prevSourceFileTextKind;
                }
            }
            function recordBundleFileTextLikeSection(end) {
                if (sourceFileTextPos < end) {
                    updateOrPushBundleFileTextLike(sourceFileTextPos, end, sourceFileTextKind);
                    return true;
                }
                return false;
            }
            function writeBundle(bundle, output, sourceMapGenerator2) {
                isOwnFileEmit = false;
                const previousWriter = writer;
                setWriter(output, sourceMapGenerator2);
                emitShebangIfNeeded(bundle);
                emitPrologueDirectivesIfNeeded(bundle);
                emitHelpers(bundle);
                emitSyntheticTripleSlashReferencesIfNeeded(bundle);
                for (const prepend of bundle.prepends) {
                    writeLine();
                    const pos = writer.getTextPos();
                    const savedSections = bundleFileInfo && bundleFileInfo.sections;
                    if (savedSections)
                        bundleFileInfo.sections = [];
                    print(4 /* Unspecified */, prepend, 
                    /*sourceFile*/
                    void 0);
                    if (bundleFileInfo) {
                        const newSections = bundleFileInfo.sections;
                        bundleFileInfo.sections = savedSections;
                        if (prepend.oldFileOfCurrentEmit)
                            bundleFileInfo.sections.push(...newSections);
                        else {
                            newSections.forEach((section) => Debug.assert(isBundleFileTextLike(section)));
                            bundleFileInfo.sections.push({
                                pos,
                                end: writer.getTextPos(),
                                kind: "prepend" /* Prepend */,
                                data: relativeToBuildInfo(prepend.fileName),
                                texts: newSections
                            });
                        }
                    }
                }
                sourceFileTextPos = getTextPosWithWriteLine();
                for (const sourceFile of bundle.sourceFiles) {
                    print(0 /* SourceFile */, sourceFile, sourceFile);
                }
                if (bundleFileInfo && bundle.sourceFiles.length) {
                    const end = writer.getTextPos();
                    if (recordBundleFileTextLikeSection(end)) {
                        const prologues = getPrologueDirectivesFromBundledSourceFiles(bundle);
                        if (prologues) {
                            if (!bundleFileInfo.sources)
                                bundleFileInfo.sources = {};
                            bundleFileInfo.sources.prologues = prologues;
                        }
                        const helpers = getHelpersFromBundledSourceFiles(bundle);
                        if (helpers) {
                            if (!bundleFileInfo.sources)
                                bundleFileInfo.sources = {};
                            bundleFileInfo.sources.helpers = helpers;
                        }
                    }
                }
                reset2();
                writer = previousWriter;
            }
            function writeUnparsedSource(unparsed, output) {
                const previousWriter = writer;
                setWriter(output, 
                /*_sourceMapGenerator*/
                void 0);
                print(4 /* Unspecified */, unparsed, 
                /*sourceFile*/
                void 0);
                reset2();
                writer = previousWriter;
            }
            function writeFile2(sourceFile, output, sourceMapGenerator2) {
                isOwnFileEmit = true;
                const previousWriter = writer;
                setWriter(output, sourceMapGenerator2);
                emitShebangIfNeeded(sourceFile);
                emitPrologueDirectivesIfNeeded(sourceFile);
                print(0 /* SourceFile */, sourceFile, sourceFile);
                reset2();
                writer = previousWriter;
            }
            function beginPrint() {
                return ownWriter || (ownWriter = createTextWriter(newLine));
            }
            function endPrint() {
                const text = ownWriter.getText();
                ownWriter.clear();
                return text;
            }
            function print(hint, node, sourceFile) {
                if (sourceFile) {
                    setSourceFile(sourceFile);
                }
                pipelineEmit(hint, node, 
                /*parenthesizerRule*/
                void 0);
            }
            function setSourceFile(sourceFile) {
                currentSourceFile = sourceFile;
                currentLineMap = void 0;
                detachedCommentsInfo = void 0;
                if (sourceFile) {
                    setSourceMapSource(sourceFile);
                }
            }
            function setWriter(_writer, _sourceMapGenerator) {
                if (_writer && printerOptions.omitTrailingSemicolon) {
                    _writer = getTrailingSemicolonDeferringWriter(_writer);
                }
                writer = _writer;
                sourceMapGenerator = _sourceMapGenerator;
                sourceMapsDisabled = !writer || !sourceMapGenerator;
            }
            function reset2() {
                nodeIdToGeneratedName = [];
                nodeIdToGeneratedPrivateName = [];
                autoGeneratedIdToGeneratedName = [];
                generatedNames = /* @__PURE__ */ new Set();
                formattedNameTempFlagsStack = [];
                formattedNameTempFlags = /* @__PURE__ */ new Map();
                privateNameTempFlagsStack = [];
                privateNameTempFlags = 0 /* Auto */;
                tempFlagsStack = [];
                tempFlags = 0 /* Auto */;
                reservedNamesStack = [];
                reservedNames = void 0;
                reservedPrivateNamesStack = [];
                reservedPrivateNames = void 0;
                currentSourceFile = void 0;
                currentLineMap = void 0;
                detachedCommentsInfo = void 0;
                setWriter(
                /*output*/
                void 0, 
                /*_sourceMapGenerator*/
                void 0);
            }
            function getCurrentLineMap() {
                return currentLineMap || (currentLineMap = getLineStarts(Debug.checkDefined(currentSourceFile)));
            }
            function emit(node, parenthesizerRule) {
                if (node === void 0)
                    return;
                const prevSourceFileTextKind = recordBundleFileInternalSectionStart(node);
                pipelineEmit(4 /* Unspecified */, node, parenthesizerRule);
                recordBundleFileInternalSectionEnd(prevSourceFileTextKind);
            }
            function emitIdentifierName(node) {
                if (node === void 0)
                    return;
                pipelineEmit(2 /* IdentifierName */, node, 
                /*parenthesizerRule*/
                void 0);
            }
            function emitExpression(node, parenthesizerRule) {
                if (node === void 0)
                    return;
                pipelineEmit(1 /* Expression */, node, parenthesizerRule);
            }
            function emitJsxAttributeValue(node) {
                pipelineEmit(isStringLiteral(node) ? 6 /* JsxAttributeValue */ : 4 /* Unspecified */, node);
            }
            function beforeEmitNode(node) {
                if (preserveSourceNewlines && getInternalEmitFlags(node) & 4 /* IgnoreSourceNewlines */) {
                    preserveSourceNewlines = false;
                }
            }
            function afterEmitNode(savedPreserveSourceNewlines) {
                preserveSourceNewlines = savedPreserveSourceNewlines;
            }
            function pipelineEmit(emitHint, node, parenthesizerRule) {
                currentParenthesizerRule = parenthesizerRule;
                const pipelinePhase = getPipelinePhase(0 /* Notification */, emitHint, node);
                pipelinePhase(emitHint, node);
                currentParenthesizerRule = void 0;
            }
            function shouldEmitComments(node) {
                return !commentsDisabled && !isSourceFile(node);
            }
            function shouldEmitSourceMaps(node) {
                return !sourceMapsDisabled && !isSourceFile(node) && !isInJsonFile(node) && !isUnparsedSource(node) && !isUnparsedPrepend(node);
            }
            function getPipelinePhase(phase, emitHint, node) {
                switch (phase) {
                    case 0 /* Notification */:
                        if (onEmitNode !== noEmitNotification && (!isEmitNotificationEnabled || isEmitNotificationEnabled(node))) {
                            return pipelineEmitWithNotification;
                        }
                    case 1 /* Substitution */:
                        if (substituteNode !== noEmitSubstitution && (lastSubstitution = substituteNode(emitHint, node) || node) !== node) {
                            if (currentParenthesizerRule) {
                                lastSubstitution = currentParenthesizerRule(lastSubstitution);
                            }
                            return pipelineEmitWithSubstitution;
                        }
                    case 2 /* Comments */:
                        if (shouldEmitComments(node)) {
                            return pipelineEmitWithComments;
                        }
                    case 3 /* SourceMaps */:
                        if (shouldEmitSourceMaps(node)) {
                            return pipelineEmitWithSourceMaps;
                        }
                    case 4 /* Emit */:
                        return pipelineEmitWithHint;
                    default:
                        return Debug.assertNever(phase);
                }
            }
            function getNextPipelinePhase(currentPhase, emitHint, node) {
                return getPipelinePhase(currentPhase + 1, emitHint, node);
            }
            function pipelineEmitWithNotification(hint, node) {
                const pipelinePhase = getNextPipelinePhase(0 /* Notification */, hint, node);
                onEmitNode(hint, node, pipelinePhase);
            }
            function pipelineEmitWithHint(hint, node) {
                onBeforeEmitNode == null ? void 0 : onBeforeEmitNode(node);
                if (preserveSourceNewlines) {
                    const savedPreserveSourceNewlines = preserveSourceNewlines;
                    beforeEmitNode(node);
                    pipelineEmitWithHintWorker(hint, node);
                    afterEmitNode(savedPreserveSourceNewlines);
                }
                else {
                    pipelineEmitWithHintWorker(hint, node);
                }
                onAfterEmitNode == null ? void 0 : onAfterEmitNode(node);
                currentParenthesizerRule = void 0;
            }
            function pipelineEmitWithHintWorker(hint, node, allowSnippets = true) {
                if (allowSnippets) {
                    const snippet = getSnippetElement(node);
                    if (snippet) {
                        return emitSnippetNode(hint, node, snippet);
                    }
                }
                if (hint === 0 /* SourceFile */)
                    return emitSourceFile(cast(node, isSourceFile));
                if (hint === 2 /* IdentifierName */)
                    return emitIdentifier(cast(node, isIdentifier));
                if (hint === 6 /* JsxAttributeValue */)
                    return emitLiteral(cast(node, isStringLiteral), 
                    /*jsxAttributeEscape*/
                    true);
                if (hint === 3 /* MappedTypeParameter */)
                    return emitMappedTypeParameter(cast(node, isTypeParameterDeclaration));
                if (hint === 5 /* EmbeddedStatement */) {
                    Debug.assertNode(node, isEmptyStatement);
                    return emitEmptyStatement(
                    /*isEmbeddedStatement*/
                    true);
                }
                if (hint === 4 /* Unspecified */) {
                    switch (node.kind) {
                        case 15 /* TemplateHead */:
                        case 16 /* TemplateMiddle */:
                        case 17 /* TemplateTail */:
                            return emitLiteral(node, 
                            /*jsxAttributeEscape*/
                            false);
                        case 79 /* Identifier */:
                            return emitIdentifier(node);
                        case 80 /* PrivateIdentifier */:
                            return emitPrivateIdentifier(node);
                        case 163 /* QualifiedName */:
                            return emitQualifiedName(node);
                        case 164 /* ComputedPropertyName */:
                            return emitComputedPropertyName(node);
                        case 165 /* TypeParameter */:
                            return emitTypeParameter(node);
                        case 166 /* Parameter */:
                            return emitParameter(node);
                        case 167 /* Decorator */:
                            return emitDecorator(node);
                        case 168 /* PropertySignature */:
                            return emitPropertySignature(node);
                        case 169 /* PropertyDeclaration */:
                            return emitPropertyDeclaration(node);
                        case 170 /* MethodSignature */:
                            return emitMethodSignature(node);
                        case 171 /* MethodDeclaration */:
                            return emitMethodDeclaration(node);
                        case 172 /* ClassStaticBlockDeclaration */:
                            return emitClassStaticBlockDeclaration(node);
                        case 173 /* Constructor */:
                            return emitConstructor(node);
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            return emitAccessorDeclaration(node);
                        case 176 /* CallSignature */:
                            return emitCallSignature(node);
                        case 177 /* ConstructSignature */:
                            return emitConstructSignature(node);
                        case 178 /* IndexSignature */:
                            return emitIndexSignature(node);
                        case 179 /* TypePredicate */:
                            return emitTypePredicate(node);
                        case 180 /* TypeReference */:
                            return emitTypeReference(node);
                        case 181 /* FunctionType */:
                            return emitFunctionType(node);
                        case 182 /* ConstructorType */:
                            return emitConstructorType(node);
                        case 183 /* TypeQuery */:
                            return emitTypeQuery(node);
                        case 184 /* TypeLiteral */:
                            return emitTypeLiteral(node);
                        case 185 /* ArrayType */:
                            return emitArrayType(node);
                        case 186 /* TupleType */:
                            return emitTupleType(node);
                        case 187 /* OptionalType */:
                            return emitOptionalType(node);
                        case 189 /* UnionType */:
                            return emitUnionType(node);
                        case 190 /* IntersectionType */:
                            return emitIntersectionType(node);
                        case 191 /* ConditionalType */:
                            return emitConditionalType(node);
                        case 192 /* InferType */:
                            return emitInferType(node);
                        case 193 /* ParenthesizedType */:
                            return emitParenthesizedType(node);
                        case 230 /* ExpressionWithTypeArguments */:
                            return emitExpressionWithTypeArguments(node);
                        case 194 /* ThisType */:
                            return emitThisType();
                        case 195 /* TypeOperator */:
                            return emitTypeOperator(node);
                        case 196 /* IndexedAccessType */:
                            return emitIndexedAccessType(node);
                        case 197 /* MappedType */:
                            return emitMappedType(node);
                        case 198 /* LiteralType */:
                            return emitLiteralType(node);
                        case 199 /* NamedTupleMember */:
                            return emitNamedTupleMember(node);
                        case 200 /* TemplateLiteralType */:
                            return emitTemplateType(node);
                        case 201 /* TemplateLiteralTypeSpan */:
                            return emitTemplateTypeSpan(node);
                        case 202 /* ImportType */:
                            return emitImportTypeNode(node);
                        case 203 /* ObjectBindingPattern */:
                            return emitObjectBindingPattern(node);
                        case 204 /* ArrayBindingPattern */:
                            return emitArrayBindingPattern(node);
                        case 205 /* BindingElement */:
                            return emitBindingElement(node);
                        case 236 /* TemplateSpan */:
                            return emitTemplateSpan(node);
                        case 237 /* SemicolonClassElement */:
                            return emitSemicolonClassElement();
                        case 238 /* Block */:
                            return emitBlock(node);
                        case 240 /* VariableStatement */:
                            return emitVariableStatement(node);
                        case 239 /* EmptyStatement */:
                            return emitEmptyStatement(
                            /*isEmbeddedStatement*/
                            false);
                        case 241 /* ExpressionStatement */:
                            return emitExpressionStatement(node);
                        case 242 /* IfStatement */:
                            return emitIfStatement(node);
                        case 243 /* DoStatement */:
                            return emitDoStatement(node);
                        case 244 /* WhileStatement */:
                            return emitWhileStatement(node);
                        case 245 /* ForStatement */:
                            return emitForStatement(node);
                        case 246 /* ForInStatement */:
                            return emitForInStatement(node);
                        case 247 /* ForOfStatement */:
                            return emitForOfStatement(node);
                        case 248 /* ContinueStatement */:
                            return emitContinueStatement(node);
                        case 249 /* BreakStatement */:
                            return emitBreakStatement(node);
                        case 250 /* ReturnStatement */:
                            return emitReturnStatement(node);
                        case 251 /* WithStatement */:
                            return emitWithStatement(node);
                        case 252 /* SwitchStatement */:
                            return emitSwitchStatement(node);
                        case 253 /* LabeledStatement */:
                            return emitLabeledStatement(node);
                        case 254 /* ThrowStatement */:
                            return emitThrowStatement(node);
                        case 255 /* TryStatement */:
                            return emitTryStatement(node);
                        case 256 /* DebuggerStatement */:
                            return emitDebuggerStatement(node);
                        case 257 /* VariableDeclaration */:
                            return emitVariableDeclaration(node);
                        case 258 /* VariableDeclarationList */:
                            return emitVariableDeclarationList(node);
                        case 259 /* FunctionDeclaration */:
                            return emitFunctionDeclaration(node);
                        case 260 /* ClassDeclaration */:
                            return emitClassDeclaration(node);
                        case 261 /* InterfaceDeclaration */:
                            return emitInterfaceDeclaration(node);
                        case 262 /* TypeAliasDeclaration */:
                            return emitTypeAliasDeclaration(node);
                        case 263 /* EnumDeclaration */:
                            return emitEnumDeclaration(node);
                        case 264 /* ModuleDeclaration */:
                            return emitModuleDeclaration(node);
                        case 265 /* ModuleBlock */:
                            return emitModuleBlock(node);
                        case 266 /* CaseBlock */:
                            return emitCaseBlock(node);
                        case 267 /* NamespaceExportDeclaration */:
                            return emitNamespaceExportDeclaration(node);
                        case 268 /* ImportEqualsDeclaration */:
                            return emitImportEqualsDeclaration(node);
                        case 269 /* ImportDeclaration */:
                            return emitImportDeclaration(node);
                        case 270 /* ImportClause */:
                            return emitImportClause(node);
                        case 271 /* NamespaceImport */:
                            return emitNamespaceImport(node);
                        case 277 /* NamespaceExport */:
                            return emitNamespaceExport(node);
                        case 272 /* NamedImports */:
                            return emitNamedImports(node);
                        case 273 /* ImportSpecifier */:
                            return emitImportSpecifier(node);
                        case 274 /* ExportAssignment */:
                            return emitExportAssignment(node);
                        case 275 /* ExportDeclaration */:
                            return emitExportDeclaration(node);
                        case 276 /* NamedExports */:
                            return emitNamedExports(node);
                        case 278 /* ExportSpecifier */:
                            return emitExportSpecifier(node);
                        case 296 /* AssertClause */:
                            return emitAssertClause(node);
                        case 297 /* AssertEntry */:
                            return emitAssertEntry(node);
                        case 279 /* MissingDeclaration */:
                            return;
                        case 280 /* ExternalModuleReference */:
                            return emitExternalModuleReference(node);
                        case 11 /* JsxText */:
                            return emitJsxText(node);
                        case 283 /* JsxOpeningElement */:
                        case 286 /* JsxOpeningFragment */:
                            return emitJsxOpeningElementOrFragment(node);
                        case 284 /* JsxClosingElement */:
                        case 287 /* JsxClosingFragment */:
                            return emitJsxClosingElementOrFragment(node);
                        case 288 /* JsxAttribute */:
                            return emitJsxAttribute(node);
                        case 289 /* JsxAttributes */:
                            return emitJsxAttributes(node);
                        case 290 /* JsxSpreadAttribute */:
                            return emitJsxSpreadAttribute(node);
                        case 291 /* JsxExpression */:
                            return emitJsxExpression(node);
                        case 292 /* CaseClause */:
                            return emitCaseClause(node);
                        case 293 /* DefaultClause */:
                            return emitDefaultClause(node);
                        case 294 /* HeritageClause */:
                            return emitHeritageClause(node);
                        case 295 /* CatchClause */:
                            return emitCatchClause(node);
                        case 299 /* PropertyAssignment */:
                            return emitPropertyAssignment(node);
                        case 300 /* ShorthandPropertyAssignment */:
                            return emitShorthandPropertyAssignment(node);
                        case 301 /* SpreadAssignment */:
                            return emitSpreadAssignment(node);
                        case 302 /* EnumMember */:
                            return emitEnumMember(node);
                        case 303 /* UnparsedPrologue */:
                            return writeUnparsedNode(node);
                        case 310 /* UnparsedSource */:
                        case 304 /* UnparsedPrepend */:
                            return emitUnparsedSourceOrPrepend(node);
                        case 305 /* UnparsedText */:
                        case 306 /* UnparsedInternalText */:
                            return emitUnparsedTextLike(node);
                        case 307 /* UnparsedSyntheticReference */:
                            return emitUnparsedSyntheticReference(node);
                        case 308 /* SourceFile */:
                            return emitSourceFile(node);
                        case 309 /* Bundle */:
                            return Debug.fail("Bundles should be printed using printBundle");
                        case 311 /* InputFiles */:
                            return Debug.fail("InputFiles should not be printed");
                        case 312 /* JSDocTypeExpression */:
                            return emitJSDocTypeExpression(node);
                        case 313 /* JSDocNameReference */:
                            return emitJSDocNameReference(node);
                        case 315 /* JSDocAllType */:
                            return writePunctuation("*");
                        case 316 /* JSDocUnknownType */:
                            return writePunctuation("?");
                        case 317 /* JSDocNullableType */:
                            return emitJSDocNullableType(node);
                        case 318 /* JSDocNonNullableType */:
                            return emitJSDocNonNullableType(node);
                        case 319 /* JSDocOptionalType */:
                            return emitJSDocOptionalType(node);
                        case 320 /* JSDocFunctionType */:
                            return emitJSDocFunctionType(node);
                        case 188 /* RestType */:
                        case 321 /* JSDocVariadicType */:
                            return emitRestOrJSDocVariadicType(node);
                        case 322 /* JSDocNamepathType */:
                            return;
                        case 323 /* JSDoc */:
                            return emitJSDoc(node);
                        case 325 /* JSDocTypeLiteral */:
                            return emitJSDocTypeLiteral(node);
                        case 326 /* JSDocSignature */:
                            return emitJSDocSignature(node);
                        case 330 /* JSDocTag */:
                        case 335 /* JSDocClassTag */:
                        case 340 /* JSDocOverrideTag */:
                            return emitJSDocSimpleTag(node);
                        case 331 /* JSDocAugmentsTag */:
                        case 332 /* JSDocImplementsTag */:
                            return emitJSDocHeritageTag(node);
                        case 333 /* JSDocAuthorTag */:
                        case 334 /* JSDocDeprecatedTag */:
                            return;
                        case 336 /* JSDocPublicTag */:
                        case 337 /* JSDocPrivateTag */:
                        case 338 /* JSDocProtectedTag */:
                        case 339 /* JSDocReadonlyTag */:
                            return;
                        case 341 /* JSDocCallbackTag */:
                            return emitJSDocCallbackTag(node);
                        case 342 /* JSDocOverloadTag */:
                            return emitJSDocOverloadTag(node);
                        case 344 /* JSDocParameterTag */:
                        case 351 /* JSDocPropertyTag */:
                            return emitJSDocPropertyLikeTag(node);
                        case 343 /* JSDocEnumTag */:
                        case 345 /* JSDocReturnTag */:
                        case 346 /* JSDocThisTag */:
                        case 347 /* JSDocTypeTag */:
                        case 352 /* JSDocThrowsTag */:
                        case 353 /* JSDocSatisfiesTag */:
                            return emitJSDocSimpleTypedTag(node);
                        case 348 /* JSDocTemplateTag */:
                            return emitJSDocTemplateTag(node);
                        case 349 /* JSDocTypedefTag */:
                            return emitJSDocTypedefTag(node);
                        case 350 /* JSDocSeeTag */:
                            return emitJSDocSeeTag(node);
                        case 355 /* NotEmittedStatement */:
                        case 359 /* EndOfDeclarationMarker */:
                        case 358 /* MergeDeclarationMarker */:
                            return;
                    }
                    if (isExpression(node)) {
                        hint = 1 /* Expression */;
                        if (substituteNode !== noEmitSubstitution) {
                            const substitute = substituteNode(hint, node) || node;
                            if (substitute !== node) {
                                node = substitute;
                                if (currentParenthesizerRule) {
                                    node = currentParenthesizerRule(node);
                                }
                            }
                        }
                    }
                }
                if (hint === 1 /* Expression */) {
                    switch (node.kind) {
                        case 8 /* NumericLiteral */:
                        case 9 /* BigIntLiteral */:
                            return emitNumericOrBigIntLiteral(node);
                        case 10 /* StringLiteral */:
                        case 13 /* RegularExpressionLiteral */:
                        case 14 /* NoSubstitutionTemplateLiteral */:
                            return emitLiteral(node, 
                            /*jsxAttributeEscape*/
                            false);
                        case 79 /* Identifier */:
                            return emitIdentifier(node);
                        case 80 /* PrivateIdentifier */:
                            return emitPrivateIdentifier(node);
                        case 206 /* ArrayLiteralExpression */:
                            return emitArrayLiteralExpression(node);
                        case 207 /* ObjectLiteralExpression */:
                            return emitObjectLiteralExpression(node);
                        case 208 /* PropertyAccessExpression */:
                            return emitPropertyAccessExpression(node);
                        case 209 /* ElementAccessExpression */:
                            return emitElementAccessExpression(node);
                        case 210 /* CallExpression */:
                            return emitCallExpression(node);
                        case 211 /* NewExpression */:
                            return emitNewExpression(node);
                        case 212 /* TaggedTemplateExpression */:
                            return emitTaggedTemplateExpression(node);
                        case 213 /* TypeAssertionExpression */:
                            return emitTypeAssertionExpression(node);
                        case 214 /* ParenthesizedExpression */:
                            return emitParenthesizedExpression(node);
                        case 215 /* FunctionExpression */:
                            return emitFunctionExpression(node);
                        case 216 /* ArrowFunction */:
                            return emitArrowFunction(node);
                        case 217 /* DeleteExpression */:
                            return emitDeleteExpression(node);
                        case 218 /* TypeOfExpression */:
                            return emitTypeOfExpression(node);
                        case 219 /* VoidExpression */:
                            return emitVoidExpression(node);
                        case 220 /* AwaitExpression */:
                            return emitAwaitExpression(node);
                        case 221 /* PrefixUnaryExpression */:
                            return emitPrefixUnaryExpression(node);
                        case 222 /* PostfixUnaryExpression */:
                            return emitPostfixUnaryExpression(node);
                        case 223 /* BinaryExpression */:
                            return emitBinaryExpression(node);
                        case 224 /* ConditionalExpression */:
                            return emitConditionalExpression(node);
                        case 225 /* TemplateExpression */:
                            return emitTemplateExpression(node);
                        case 226 /* YieldExpression */:
                            return emitYieldExpression(node);
                        case 227 /* SpreadElement */:
                            return emitSpreadElement(node);
                        case 228 /* ClassExpression */:
                            return emitClassExpression(node);
                        case 229 /* OmittedExpression */:
                            return;
                        case 231 /* AsExpression */:
                            return emitAsExpression(node);
                        case 232 /* NonNullExpression */:
                            return emitNonNullExpression(node);
                        case 230 /* ExpressionWithTypeArguments */:
                            return emitExpressionWithTypeArguments(node);
                        case 235 /* SatisfiesExpression */:
                            return emitSatisfiesExpression(node);
                        case 233 /* MetaProperty */:
                            return emitMetaProperty(node);
                        case 234 /* SyntheticExpression */:
                            return Debug.fail("SyntheticExpression should never be printed.");
                        case 279 /* MissingDeclaration */:
                            return;
                        case 281 /* JsxElement */:
                            return emitJsxElement(node);
                        case 282 /* JsxSelfClosingElement */:
                            return emitJsxSelfClosingElement(node);
                        case 285 /* JsxFragment */:
                            return emitJsxFragment(node);
                        case 354 /* SyntaxList */:
                            return Debug.fail("SyntaxList should not be printed");
                        case 355 /* NotEmittedStatement */:
                            return;
                        case 356 /* PartiallyEmittedExpression */:
                            return emitPartiallyEmittedExpression(node);
                        case 357 /* CommaListExpression */:
                            return emitCommaList(node);
                        case 358 /* MergeDeclarationMarker */:
                        case 359 /* EndOfDeclarationMarker */:
                            return;
                        case 360 /* SyntheticReferenceExpression */:
                            return Debug.fail("SyntheticReferenceExpression should not be printed");
                    }
                }
                if (isKeyword(node.kind))
                    return writeTokenNode(node, writeKeyword);
                if (isTokenKind(node.kind))
                    return writeTokenNode(node, writePunctuation);
                Debug.fail(`Unhandled SyntaxKind: ${Debug.formatSyntaxKind(node.kind)}.`);
            }
            function emitMappedTypeParameter(node) {
                emit(node.name);
                writeSpace();
                writeKeyword("in");
                writeSpace();
                emit(node.constraint);
            }
            function pipelineEmitWithSubstitution(hint, node) {
                const pipelinePhase = getNextPipelinePhase(1 /* Substitution */, hint, node);
                Debug.assertIsDefined(lastSubstitution);
                node = lastSubstitution;
                lastSubstitution = void 0;
                pipelinePhase(hint, node);
            }
            function getHelpersFromBundledSourceFiles(bundle) {
                let result;
                if (moduleKind === 0 /* None */ || printerOptions.noEmitHelpers) {
                    return void 0;
                }
                const bundledHelpers2 = /* @__PURE__ */ new Map();
                for (const sourceFile of bundle.sourceFiles) {
                    const shouldSkip = getExternalHelpersModuleName(sourceFile) !== void 0;
                    const helpers = getSortedEmitHelpers(sourceFile);
                    if (!helpers)
                        continue;
                    for (const helper of helpers) {
                        if (!helper.scoped && !shouldSkip && !bundledHelpers2.get(helper.name)) {
                            bundledHelpers2.set(helper.name, true);
                            (result || (result = [])).push(helper.name);
                        }
                    }
                }
                return result;
            }
            function emitHelpers(node) {
                let helpersEmitted = false;
                const bundle = node.kind === 309 /* Bundle */ ? node : void 0;
                if (bundle && moduleKind === 0 /* None */) {
                    return;
                }
                const numPrepends = bundle ? bundle.prepends.length : 0;
                const numNodes = bundle ? bundle.sourceFiles.length + numPrepends : 1;
                for (let i = 0; i < numNodes; i++) {
                    const currentNode = bundle ? i < numPrepends ? bundle.prepends[i] : bundle.sourceFiles[i - numPrepends] : node;
                    const sourceFile = isSourceFile(currentNode) ? currentNode : isUnparsedSource(currentNode) ? void 0 : currentSourceFile;
                    const shouldSkip = printerOptions.noEmitHelpers || !!sourceFile && hasRecordedExternalHelpers(sourceFile);
                    const shouldBundle = (isSourceFile(currentNode) || isUnparsedSource(currentNode)) && !isOwnFileEmit;
                    const helpers = isUnparsedSource(currentNode) ? currentNode.helpers : getSortedEmitHelpers(currentNode);
                    if (helpers) {
                        for (const helper of helpers) {
                            if (!helper.scoped) {
                                if (shouldSkip)
                                    continue;
                                if (shouldBundle) {
                                    if (bundledHelpers.get(helper.name)) {
                                        continue;
                                    }
                                    bundledHelpers.set(helper.name, true);
                                }
                            }
                            else if (bundle) {
                                continue;
                            }
                            const pos = getTextPosWithWriteLine();
                            if (typeof helper.text === "string") {
                                writeLines(helper.text);
                            }
                            else {
                                writeLines(helper.text(makeFileLevelOptimisticUniqueName));
                            }
                            if (bundleFileInfo)
                                bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "emitHelpers" /* EmitHelpers */, data: helper.name });
                            helpersEmitted = true;
                        }
                    }
                }
                return helpersEmitted;
            }
            function getSortedEmitHelpers(node) {
                const helpers = getEmitHelpers(node);
                return helpers && stableSort(helpers, compareEmitHelpers);
            }
            function emitNumericOrBigIntLiteral(node) {
                emitLiteral(node, 
                /*jsxAttributeEscape*/
                false);
            }
            function emitLiteral(node, jsxAttributeEscape) {
                const text = getLiteralTextOfNode(node, printerOptions.neverAsciiEscape, jsxAttributeEscape);
                if ((printerOptions.sourceMap || printerOptions.inlineSourceMap) && (node.kind === 10 /* StringLiteral */ || isTemplateLiteralKind(node.kind))) {
                    writeLiteral(text);
                }
                else {
                    writeStringLiteral(text);
                }
            }
            function emitUnparsedSourceOrPrepend(unparsed) {
                for (const text of unparsed.texts) {
                    writeLine();
                    emit(text);
                }
            }
            function writeUnparsedNode(unparsed) {
                writer.rawWrite(unparsed.parent.text.substring(unparsed.pos, unparsed.end));
            }
            function emitUnparsedTextLike(unparsed) {
                const pos = getTextPosWithWriteLine();
                writeUnparsedNode(unparsed);
                if (bundleFileInfo) {
                    updateOrPushBundleFileTextLike(pos, writer.getTextPos(), unparsed.kind === 305 /* UnparsedText */ ? "text" /* Text */ : "internal" /* Internal */);
                }
            }
            function emitUnparsedSyntheticReference(unparsed) {
                const pos = getTextPosWithWriteLine();
                writeUnparsedNode(unparsed);
                if (bundleFileInfo) {
                    const section = clone(unparsed.section);
                    section.pos = pos;
                    section.end = writer.getTextPos();
                    bundleFileInfo.sections.push(section);
                }
            }
            function emitSnippetNode(hint, node, snippet) {
                switch (snippet.kind) {
                    case 1 /* Placeholder */:
                        emitPlaceholder(hint, node, snippet);
                        break;
                    case 0 /* TabStop */:
                        emitTabStop(hint, node, snippet);
                        break;
                }
            }
            function emitPlaceholder(hint, node, snippet) {
                nonEscapingWrite(`\${${snippet.order}:`);
                pipelineEmitWithHintWorker(hint, node, 
                /*allowSnippets*/
                false);
                nonEscapingWrite(`}`);
            }
            function emitTabStop(hint, node, snippet) {
                Debug.assert(node.kind === 239 /* EmptyStatement */, `A tab stop cannot be attached to a node of kind ${Debug.formatSyntaxKind(node.kind)}.`);
                Debug.assert(hint !== 5 /* EmbeddedStatement */, `A tab stop cannot be attached to an embedded statement.`);
                nonEscapingWrite(`$${snippet.order}`);
            }
            function emitIdentifier(node) {
                const writeText = node.symbol ? writeSymbol : write;
                writeText(getTextOfNode2(node, 
                /*includeTrivia*/
                false), node.symbol);
                emitList(node, getIdentifierTypeArguments(node), 53776 /* TypeParameters */);
            }
            function emitPrivateIdentifier(node) {
                write(getTextOfNode2(node, 
                /*includeTrivia*/
                false));
            }
            function emitQualifiedName(node) {
                emitEntityName(node.left);
                writePunctuation(".");
                emit(node.right);
            }
            function emitEntityName(node) {
                if (node.kind === 79 /* Identifier */) {
                    emitExpression(node);
                }
                else {
                    emit(node);
                }
            }
            function emitComputedPropertyName(node) {
                const savedPrivateNameTempFlags = privateNameTempFlags;
                const savedReservedMemberNames = reservedPrivateNames;
                popPrivateNameGenerationScope();
                writePunctuation("[");
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionOfComputedPropertyName);
                writePunctuation("]");
                pushPrivateNameGenerationScope(savedPrivateNameTempFlags, savedReservedMemberNames);
            }
            function emitTypeParameter(node) {
                emitModifierList(node, node.modifiers);
                emit(node.name);
                if (node.constraint) {
                    writeSpace();
                    writeKeyword("extends");
                    writeSpace();
                    emit(node.constraint);
                }
                if (node.default) {
                    writeSpace();
                    writeOperator("=");
                    writeSpace();
                    emit(node.default);
                }
            }
            function emitParameter(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                emit(node.dotDotDotToken);
                emitNodeWithWriter(node.name, writeParameter);
                emit(node.questionToken);
                if (node.parent && node.parent.kind === 320 /* JSDocFunctionType */ && !node.name) {
                    emit(node.type);
                }
                else {
                    emitTypeAnnotation(node.type);
                }
                emitInitializer(node.initializer, node.type ? node.type.end : node.questionToken ? node.questionToken.end : node.name ? node.name.end : node.modifiers ? node.modifiers.end : node.pos, node, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitDecorator(decorator) {
                writePunctuation("@");
                emitExpression(decorator.expression, parenthesizer.parenthesizeLeftSideOfAccess);
            }
            function emitPropertySignature(node) {
                emitModifierList(node, node.modifiers);
                emitNodeWithWriter(node.name, writeProperty);
                emit(node.questionToken);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
            }
            function emitPropertyDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                emit(node.name);
                emit(node.questionToken);
                emit(node.exclamationToken);
                emitTypeAnnotation(node.type);
                emitInitializer(node.initializer, node.type ? node.type.end : node.questionToken ? node.questionToken.end : node.name.end, node);
                writeTrailingSemicolon();
            }
            function emitMethodSignature(node) {
                pushNameGenerationScope(node);
                emitModifierList(node, node.modifiers);
                emit(node.name);
                emit(node.questionToken);
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
                popNameGenerationScope(node);
            }
            function emitMethodDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                emit(node.asteriskToken);
                emit(node.name);
                emit(node.questionToken);
                emitSignatureAndBody(node, emitSignatureHead);
            }
            function emitClassStaticBlockDeclaration(node) {
                writeKeyword("static");
                emitBlockFunctionBody(node.body);
            }
            function emitConstructor(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("constructor");
                emitSignatureAndBody(node, emitSignatureHead);
            }
            function emitAccessorDeclaration(node) {
                const pos = emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                const token = node.kind === 174 /* GetAccessor */ ? 137 /* GetKeyword */ : 151 /* SetKeyword */;
                emitTokenWithComment(token, pos, writeKeyword, node);
                writeSpace();
                emit(node.name);
                emitSignatureAndBody(node, emitSignatureHead);
            }
            function emitCallSignature(node) {
                pushNameGenerationScope(node);
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
                popNameGenerationScope(node);
            }
            function emitConstructSignature(node) {
                pushNameGenerationScope(node);
                writeKeyword("new");
                writeSpace();
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
                popNameGenerationScope(node);
            }
            function emitIndexSignature(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                emitParametersForIndexSignature(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
            }
            function emitTemplateTypeSpan(node) {
                emit(node.type);
                emit(node.literal);
            }
            function emitSemicolonClassElement() {
                writeTrailingSemicolon();
            }
            function emitTypePredicate(node) {
                if (node.assertsModifier) {
                    emit(node.assertsModifier);
                    writeSpace();
                }
                emit(node.parameterName);
                if (node.type) {
                    writeSpace();
                    writeKeyword("is");
                    writeSpace();
                    emit(node.type);
                }
            }
            function emitTypeReference(node) {
                emit(node.typeName);
                emitTypeArguments(node, node.typeArguments);
            }
            function emitFunctionType(node) {
                pushNameGenerationScope(node);
                emitTypeParameters(node, node.typeParameters);
                emitParametersForArrow(node, node.parameters);
                writeSpace();
                writePunctuation("=>");
                writeSpace();
                emit(node.type);
                popNameGenerationScope(node);
            }
            function emitJSDocFunctionType(node) {
                writeKeyword("function");
                emitParameters(node, node.parameters);
                writePunctuation(":");
                emit(node.type);
            }
            function emitJSDocNullableType(node) {
                writePunctuation("?");
                emit(node.type);
            }
            function emitJSDocNonNullableType(node) {
                writePunctuation("!");
                emit(node.type);
            }
            function emitJSDocOptionalType(node) {
                emit(node.type);
                writePunctuation("=");
            }
            function emitConstructorType(node) {
                pushNameGenerationScope(node);
                emitModifierList(node, node.modifiers);
                writeKeyword("new");
                writeSpace();
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                writeSpace();
                writePunctuation("=>");
                writeSpace();
                emit(node.type);
                popNameGenerationScope(node);
            }
            function emitTypeQuery(node) {
                writeKeyword("typeof");
                writeSpace();
                emit(node.exprName);
                emitTypeArguments(node, node.typeArguments);
            }
            function emitTypeLiteral(node) {
                pushPrivateNameGenerationScope(0 /* Auto */, 
                /*newReservedMemberNames*/
                void 0);
                writePunctuation("{");
                const flags = getEmitFlags(node) & 1 /* SingleLine */ ? 768 /* SingleLineTypeLiteralMembers */ : 32897 /* MultiLineTypeLiteralMembers */;
                emitList(node, node.members, flags | 524288 /* NoSpaceIfEmpty */);
                writePunctuation("}");
                popPrivateNameGenerationScope();
            }
            function emitArrayType(node) {
                emit(node.elementType, parenthesizer.parenthesizeNonArrayTypeOfPostfixType);
                writePunctuation("[");
                writePunctuation("]");
            }
            function emitRestOrJSDocVariadicType(node) {
                writePunctuation("...");
                emit(node.type);
            }
            function emitTupleType(node) {
                emitTokenWithComment(22 /* OpenBracketToken */, node.pos, writePunctuation, node);
                const flags = getEmitFlags(node) & 1 /* SingleLine */ ? 528 /* SingleLineTupleTypeElements */ : 657 /* MultiLineTupleTypeElements */;
                emitList(node, node.elements, flags | 524288 /* NoSpaceIfEmpty */, parenthesizer.parenthesizeElementTypeOfTupleType);
                emitTokenWithComment(23 /* CloseBracketToken */, node.elements.end, writePunctuation, node);
            }
            function emitNamedTupleMember(node) {
                emit(node.dotDotDotToken);
                emit(node.name);
                emit(node.questionToken);
                emitTokenWithComment(58 /* ColonToken */, node.name.end, writePunctuation, node);
                writeSpace();
                emit(node.type);
            }
            function emitOptionalType(node) {
                emit(node.type, parenthesizer.parenthesizeTypeOfOptionalType);
                writePunctuation("?");
            }
            function emitUnionType(node) {
                emitList(node, node.types, 516 /* UnionTypeConstituents */, parenthesizer.parenthesizeConstituentTypeOfUnionType);
            }
            function emitIntersectionType(node) {
                emitList(node, node.types, 520 /* IntersectionTypeConstituents */, parenthesizer.parenthesizeConstituentTypeOfIntersectionType);
            }
            function emitConditionalType(node) {
                emit(node.checkType, parenthesizer.parenthesizeCheckTypeOfConditionalType);
                writeSpace();
                writeKeyword("extends");
                writeSpace();
                emit(node.extendsType, parenthesizer.parenthesizeExtendsTypeOfConditionalType);
                writeSpace();
                writePunctuation("?");
                writeSpace();
                emit(node.trueType);
                writeSpace();
                writePunctuation(":");
                writeSpace();
                emit(node.falseType);
            }
            function emitInferType(node) {
                writeKeyword("infer");
                writeSpace();
                emit(node.typeParameter);
            }
            function emitParenthesizedType(node) {
                writePunctuation("(");
                emit(node.type);
                writePunctuation(")");
            }
            function emitThisType() {
                writeKeyword("this");
            }
            function emitTypeOperator(node) {
                writeTokenText(node.operator, writeKeyword);
                writeSpace();
                const parenthesizerRule = node.operator === 146 /* ReadonlyKeyword */ ? parenthesizer.parenthesizeOperandOfReadonlyTypeOperator : parenthesizer.parenthesizeOperandOfTypeOperator;
                emit(node.type, parenthesizerRule);
            }
            function emitIndexedAccessType(node) {
                emit(node.objectType, parenthesizer.parenthesizeNonArrayTypeOfPostfixType);
                writePunctuation("[");
                emit(node.indexType);
                writePunctuation("]");
            }
            function emitMappedType(node) {
                const emitFlags = getEmitFlags(node);
                writePunctuation("{");
                if (emitFlags & 1 /* SingleLine */) {
                    writeSpace();
                }
                else {
                    writeLine();
                    increaseIndent();
                }
                if (node.readonlyToken) {
                    emit(node.readonlyToken);
                    if (node.readonlyToken.kind !== 146 /* ReadonlyKeyword */) {
                        writeKeyword("readonly");
                    }
                    writeSpace();
                }
                writePunctuation("[");
                pipelineEmit(3 /* MappedTypeParameter */, node.typeParameter);
                if (node.nameType) {
                    writeSpace();
                    writeKeyword("as");
                    writeSpace();
                    emit(node.nameType);
                }
                writePunctuation("]");
                if (node.questionToken) {
                    emit(node.questionToken);
                    if (node.questionToken.kind !== 57 /* QuestionToken */) {
                        writePunctuation("?");
                    }
                }
                writePunctuation(":");
                writeSpace();
                emit(node.type);
                writeTrailingSemicolon();
                if (emitFlags & 1 /* SingleLine */) {
                    writeSpace();
                }
                else {
                    writeLine();
                    decreaseIndent();
                }
                emitList(node, node.members, 2 /* PreserveLines */);
                writePunctuation("}");
            }
            function emitLiteralType(node) {
                emitExpression(node.literal);
            }
            function emitTemplateType(node) {
                emit(node.head);
                emitList(node, node.templateSpans, 262144 /* TemplateExpressionSpans */);
            }
            function emitImportTypeNode(node) {
                if (node.isTypeOf) {
                    writeKeyword("typeof");
                    writeSpace();
                }
                writeKeyword("import");
                writePunctuation("(");
                emit(node.argument);
                if (node.assertions) {
                    writePunctuation(",");
                    writeSpace();
                    writePunctuation("{");
                    writeSpace();
                    writeKeyword("assert");
                    writePunctuation(":");
                    writeSpace();
                    const elements = node.assertions.assertClause.elements;
                    emitList(node.assertions.assertClause, elements, 526226 /* ImportClauseEntries */);
                    writeSpace();
                    writePunctuation("}");
                }
                writePunctuation(")");
                if (node.qualifier) {
                    writePunctuation(".");
                    emit(node.qualifier);
                }
                emitTypeArguments(node, node.typeArguments);
            }
            function emitObjectBindingPattern(node) {
                writePunctuation("{");
                emitList(node, node.elements, 525136 /* ObjectBindingPatternElements */);
                writePunctuation("}");
            }
            function emitArrayBindingPattern(node) {
                writePunctuation("[");
                emitList(node, node.elements, 524880 /* ArrayBindingPatternElements */);
                writePunctuation("]");
            }
            function emitBindingElement(node) {
                emit(node.dotDotDotToken);
                if (node.propertyName) {
                    emit(node.propertyName);
                    writePunctuation(":");
                    writeSpace();
                }
                emit(node.name);
                emitInitializer(node.initializer, node.name.end, node, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitArrayLiteralExpression(node) {
                const elements = node.elements;
                const preferNewLine = node.multiLine ? 65536 /* PreferNewLine */ : 0 /* None */;
                emitExpressionList(node, elements, 8914 /* ArrayLiteralExpressionElements */ | preferNewLine, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitObjectLiteralExpression(node) {
                pushPrivateNameGenerationScope(0 /* Auto */, 
                /*newReservedMemberNames*/
                void 0);
                forEach(node.properties, generateMemberNames);
                const indentedFlag = getEmitFlags(node) & 131072 /* Indented */;
                if (indentedFlag) {
                    increaseIndent();
                }
                const preferNewLine = node.multiLine ? 65536 /* PreferNewLine */ : 0 /* None */;
                const allowTrailingComma = currentSourceFile && currentSourceFile.languageVersion >= 1 /* ES5 */ && !isJsonSourceFile(currentSourceFile) ? 64 /* AllowTrailingComma */ : 0 /* None */;
                emitList(node, node.properties, 526226 /* ObjectLiteralExpressionProperties */ | allowTrailingComma | preferNewLine);
                if (indentedFlag) {
                    decreaseIndent();
                }
                popPrivateNameGenerationScope();
            }
            function emitPropertyAccessExpression(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                const token = node.questionDotToken || setTextRangePosEnd(factory.createToken(24 /* DotToken */), node.expression.end, node.name.pos);
                const linesBeforeDot = getLinesBetweenNodes(node, node.expression, token);
                const linesAfterDot = getLinesBetweenNodes(node, token, node.name);
                writeLinesAndIndent(linesBeforeDot, 
                /*writeSpaceIfNotIndenting*/
                false);
                const shouldEmitDotDot = token.kind !== 28 /* QuestionDotToken */ && mayNeedDotDotForPropertyAccess(node.expression) && !writer.hasTrailingComment() && !writer.hasTrailingWhitespace();
                if (shouldEmitDotDot) {
                    writePunctuation(".");
                }
                if (node.questionDotToken) {
                    emit(token);
                }
                else {
                    emitTokenWithComment(token.kind, node.expression.end, writePunctuation, node);
                }
                writeLinesAndIndent(linesAfterDot, 
                /*writeSpaceIfNotIndenting*/
                false);
                emit(node.name);
                decreaseIndentIf(linesBeforeDot, linesAfterDot);
            }
            function mayNeedDotDotForPropertyAccess(expression) {
                expression = skipPartiallyEmittedExpressions(expression);
                if (isNumericLiteral(expression)) {
                    const text = getLiteralTextOfNode(expression, 
                    /*neverAsciiEscape*/
                    true, 
                    /*jsxAttributeEscape*/
                    false);
                    return !expression.numericLiteralFlags && !stringContains(text, tokenToString(24 /* DotToken */));
                }
                else if (isAccessExpression(expression)) {
                    const constantValue = getConstantValue(expression);
                    return typeof constantValue === "number" && isFinite(constantValue) && Math.floor(constantValue) === constantValue;
                }
            }
            function emitElementAccessExpression(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                emit(node.questionDotToken);
                emitTokenWithComment(22 /* OpenBracketToken */, node.expression.end, writePunctuation, node);
                emitExpression(node.argumentExpression);
                emitTokenWithComment(23 /* CloseBracketToken */, node.argumentExpression.end, writePunctuation, node);
            }
            function emitCallExpression(node) {
                const indirectCall = getInternalEmitFlags(node) & 16 /* IndirectCall */;
                if (indirectCall) {
                    writePunctuation("(");
                    writeLiteral("0");
                    writePunctuation(",");
                    writeSpace();
                }
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                if (indirectCall) {
                    writePunctuation(")");
                }
                emit(node.questionDotToken);
                emitTypeArguments(node, node.typeArguments);
                emitExpressionList(node, node.arguments, 2576 /* CallExpressionArguments */, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitNewExpression(node) {
                emitTokenWithComment(103 /* NewKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionOfNew);
                emitTypeArguments(node, node.typeArguments);
                emitExpressionList(node, node.arguments, 18960 /* NewExpressionArguments */, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitTaggedTemplateExpression(node) {
                const indirectCall = getInternalEmitFlags(node) & 16 /* IndirectCall */;
                if (indirectCall) {
                    writePunctuation("(");
                    writeLiteral("0");
                    writePunctuation(",");
                    writeSpace();
                }
                emitExpression(node.tag, parenthesizer.parenthesizeLeftSideOfAccess);
                if (indirectCall) {
                    writePunctuation(")");
                }
                emitTypeArguments(node, node.typeArguments);
                writeSpace();
                emitExpression(node.template);
            }
            function emitTypeAssertionExpression(node) {
                writePunctuation("<");
                emit(node.type);
                writePunctuation(">");
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitParenthesizedExpression(node) {
                const openParenPos = emitTokenWithComment(20 /* OpenParenToken */, node.pos, writePunctuation, node);
                const indented = writeLineSeparatorsAndIndentBefore(node.expression, node);
                emitExpression(node.expression, 
                /*parenthesizerRules*/
                void 0);
                writeLineSeparatorsAfter(node.expression, node);
                decreaseIndentIf(indented);
                emitTokenWithComment(21 /* CloseParenToken */, node.expression ? node.expression.end : openParenPos, writePunctuation, node);
            }
            function emitFunctionExpression(node) {
                generateNameIfNeeded(node.name);
                emitFunctionDeclarationOrExpression(node);
            }
            function emitArrowFunction(node) {
                emitModifierList(node, node.modifiers);
                emitSignatureAndBody(node, emitArrowFunctionHead);
            }
            function emitArrowFunctionHead(node) {
                emitTypeParameters(node, node.typeParameters);
                emitParametersForArrow(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeSpace();
                emit(node.equalsGreaterThanToken);
            }
            function emitDeleteExpression(node) {
                emitTokenWithComment(89 /* DeleteKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitTypeOfExpression(node) {
                emitTokenWithComment(112 /* TypeOfKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitVoidExpression(node) {
                emitTokenWithComment(114 /* VoidKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitAwaitExpression(node) {
                emitTokenWithComment(133 /* AwaitKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitPrefixUnaryExpression(node) {
                writeTokenText(node.operator, writeOperator);
                if (shouldEmitWhitespaceBeforeOperand(node)) {
                    writeSpace();
                }
                emitExpression(node.operand, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function shouldEmitWhitespaceBeforeOperand(node) {
                const operand = node.operand;
                return operand.kind === 221 /* PrefixUnaryExpression */ && (node.operator === 39 /* PlusToken */ && (operand.operator === 39 /* PlusToken */ || operand.operator === 45 /* PlusPlusToken */) || node.operator === 40 /* MinusToken */ && (operand.operator === 40 /* MinusToken */ || operand.operator === 46 /* MinusMinusToken */));
            }
            function emitPostfixUnaryExpression(node) {
                emitExpression(node.operand, parenthesizer.parenthesizeOperandOfPostfixUnary);
                writeTokenText(node.operator, writeOperator);
            }
            function createEmitBinaryExpression() {
                return createBinaryExpressionTrampoline(onEnter, onLeft, onOperator, onRight, onExit, 
                /*foldState*/
                void 0);
                function onEnter(node, state) {
                    if (state) {
                        state.stackIndex++;
                        state.preserveSourceNewlinesStack[state.stackIndex] = preserveSourceNewlines;
                        state.containerPosStack[state.stackIndex] = containerPos;
                        state.containerEndStack[state.stackIndex] = containerEnd;
                        state.declarationListContainerEndStack[state.stackIndex] = declarationListContainerEnd;
                        const emitComments2 = state.shouldEmitCommentsStack[state.stackIndex] = shouldEmitComments(node);
                        const emitSourceMaps = state.shouldEmitSourceMapsStack[state.stackIndex] = shouldEmitSourceMaps(node);
                        onBeforeEmitNode == null ? void 0 : onBeforeEmitNode(node);
                        if (emitComments2)
                            emitCommentsBeforeNode(node);
                        if (emitSourceMaps)
                            emitSourceMapsBeforeNode(node);
                        beforeEmitNode(node);
                    }
                    else {
                        state = {
                            stackIndex: 0,
                            preserveSourceNewlinesStack: [void 0],
                            containerPosStack: [-1],
                            containerEndStack: [-1],
                            declarationListContainerEndStack: [-1],
                            shouldEmitCommentsStack: [false],
                            shouldEmitSourceMapsStack: [false]
                        };
                    }
                    return state;
                }
                function onLeft(next, _workArea, parent2) {
                    return maybeEmitExpression(next, parent2, "left");
                }
                function onOperator(operatorToken, _state, node) {
                    const isCommaOperator = operatorToken.kind !== 27 /* CommaToken */;
                    const linesBeforeOperator = getLinesBetweenNodes(node, node.left, operatorToken);
                    const linesAfterOperator = getLinesBetweenNodes(node, operatorToken, node.right);
                    writeLinesAndIndent(linesBeforeOperator, isCommaOperator);
                    emitLeadingCommentsOfPosition(operatorToken.pos);
                    writeTokenNode(operatorToken, operatorToken.kind === 101 /* InKeyword */ ? writeKeyword : writeOperator);
                    emitTrailingCommentsOfPosition(operatorToken.end, 
                    /*prefixSpace*/
                    true);
                    writeLinesAndIndent(linesAfterOperator, 
                    /*writeSpaceIfNotIndenting*/
                    true);
                }
                function onRight(next, _workArea, parent2) {
                    return maybeEmitExpression(next, parent2, "right");
                }
                function onExit(node, state) {
                    const linesBeforeOperator = getLinesBetweenNodes(node, node.left, node.operatorToken);
                    const linesAfterOperator = getLinesBetweenNodes(node, node.operatorToken, node.right);
                    decreaseIndentIf(linesBeforeOperator, linesAfterOperator);
                    if (state.stackIndex > 0) {
                        const savedPreserveSourceNewlines = state.preserveSourceNewlinesStack[state.stackIndex];
                        const savedContainerPos = state.containerPosStack[state.stackIndex];
                        const savedContainerEnd = state.containerEndStack[state.stackIndex];
                        const savedDeclarationListContainerEnd = state.declarationListContainerEndStack[state.stackIndex];
                        const shouldEmitComments2 = state.shouldEmitCommentsStack[state.stackIndex];
                        const shouldEmitSourceMaps2 = state.shouldEmitSourceMapsStack[state.stackIndex];
                        afterEmitNode(savedPreserveSourceNewlines);
                        if (shouldEmitSourceMaps2)
                            emitSourceMapsAfterNode(node);
                        if (shouldEmitComments2)
                            emitCommentsAfterNode(node, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd);
                        onAfterEmitNode == null ? void 0 : onAfterEmitNode(node);
                        state.stackIndex--;
                    }
                }
                function maybeEmitExpression(next, parent2, side) {
                    const parenthesizerRule = side === "left" ? parenthesizer.getParenthesizeLeftSideOfBinaryForOperator(parent2.operatorToken.kind) : parenthesizer.getParenthesizeRightSideOfBinaryForOperator(parent2.operatorToken.kind);
                    let pipelinePhase = getPipelinePhase(0 /* Notification */, 1 /* Expression */, next);
                    if (pipelinePhase === pipelineEmitWithSubstitution) {
                        Debug.assertIsDefined(lastSubstitution);
                        next = parenthesizerRule(cast(lastSubstitution, isExpression));
                        pipelinePhase = getNextPipelinePhase(1 /* Substitution */, 1 /* Expression */, next);
                        lastSubstitution = void 0;
                    }
                    if (pipelinePhase === pipelineEmitWithComments || pipelinePhase === pipelineEmitWithSourceMaps || pipelinePhase === pipelineEmitWithHint) {
                        if (isBinaryExpression(next)) {
                            return next;
                        }
                    }
                    currentParenthesizerRule = parenthesizerRule;
                    pipelinePhase(1 /* Expression */, next);
                }
            }
            function emitConditionalExpression(node) {
                const linesBeforeQuestion = getLinesBetweenNodes(node, node.condition, node.questionToken);
                const linesAfterQuestion = getLinesBetweenNodes(node, node.questionToken, node.whenTrue);
                const linesBeforeColon = getLinesBetweenNodes(node, node.whenTrue, node.colonToken);
                const linesAfterColon = getLinesBetweenNodes(node, node.colonToken, node.whenFalse);
                emitExpression(node.condition, parenthesizer.parenthesizeConditionOfConditionalExpression);
                writeLinesAndIndent(linesBeforeQuestion, 
                /*writeSpaceIfNotIndenting*/
                true);
                emit(node.questionToken);
                writeLinesAndIndent(linesAfterQuestion, 
                /*writeSpaceIfNotIndenting*/
                true);
                emitExpression(node.whenTrue, parenthesizer.parenthesizeBranchOfConditionalExpression);
                decreaseIndentIf(linesBeforeQuestion, linesAfterQuestion);
                writeLinesAndIndent(linesBeforeColon, 
                /*writeSpaceIfNotIndenting*/
                true);
                emit(node.colonToken);
                writeLinesAndIndent(linesAfterColon, 
                /*writeSpaceIfNotIndenting*/
                true);
                emitExpression(node.whenFalse, parenthesizer.parenthesizeBranchOfConditionalExpression);
                decreaseIndentIf(linesBeforeColon, linesAfterColon);
            }
            function emitTemplateExpression(node) {
                emit(node.head);
                emitList(node, node.templateSpans, 262144 /* TemplateExpressionSpans */);
            }
            function emitYieldExpression(node) {
                emitTokenWithComment(125 /* YieldKeyword */, node.pos, writeKeyword, node);
                emit(node.asteriskToken);
                emitExpressionWithLeadingSpace(node.expression && parenthesizeExpressionForNoAsi(node.expression), parenthesizeExpressionForNoAsiAndDisallowedComma);
            }
            function emitSpreadElement(node) {
                emitTokenWithComment(25 /* DotDotDotToken */, node.pos, writePunctuation, node);
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitClassExpression(node) {
                generateNameIfNeeded(node.name);
                emitClassDeclarationOrExpression(node);
            }
            function emitExpressionWithTypeArguments(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                emitTypeArguments(node, node.typeArguments);
            }
            function emitAsExpression(node) {
                emitExpression(node.expression, 
                /*parenthesizerRules*/
                void 0);
                if (node.type) {
                    writeSpace();
                    writeKeyword("as");
                    writeSpace();
                    emit(node.type);
                }
            }
            function emitNonNullExpression(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                writeOperator("!");
            }
            function emitSatisfiesExpression(node) {
                emitExpression(node.expression, 
                /*parenthesizerRules*/
                void 0);
                if (node.type) {
                    writeSpace();
                    writeKeyword("satisfies");
                    writeSpace();
                    emit(node.type);
                }
            }
            function emitMetaProperty(node) {
                writeToken(node.keywordToken, node.pos, writePunctuation);
                writePunctuation(".");
                emit(node.name);
            }
            function emitTemplateSpan(node) {
                emitExpression(node.expression);
                emit(node.literal);
            }
            function emitBlock(node) {
                emitBlockStatements(node, 
                /*forceSingleLine*/
                !node.multiLine && isEmptyBlock(node));
            }
            function emitBlockStatements(node, forceSingleLine) {
                emitTokenWithComment(18 /* OpenBraceToken */, node.pos, writePunctuation, 
                /*contextNode*/
                node);
                const format = forceSingleLine || getEmitFlags(node) & 1 /* SingleLine */ ? 768 /* SingleLineBlockStatements */ : 129 /* MultiLineBlockStatements */;
                emitList(node, node.statements, format);
                emitTokenWithComment(19 /* CloseBraceToken */, node.statements.end, writePunctuation, 
                /*contextNode*/
                node, 
                /*indentLeading*/
                !!(format & 1 /* MultiLine */));
            }
            function emitVariableStatement(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                emit(node.declarationList);
                writeTrailingSemicolon();
            }
            function emitEmptyStatement(isEmbeddedStatement) {
                if (isEmbeddedStatement) {
                    writePunctuation(";");
                }
                else {
                    writeTrailingSemicolon();
                }
            }
            function emitExpressionStatement(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionOfExpressionStatement);
                if (!currentSourceFile || !isJsonSourceFile(currentSourceFile) || nodeIsSynthesized(node.expression)) {
                    writeTrailingSemicolon();
                }
            }
            function emitIfStatement(node) {
                const openParenPos = emitTokenWithComment(99 /* IfKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(20 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitExpression(node.expression);
                emitTokenWithComment(21 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                emitEmbeddedStatement(node, node.thenStatement);
                if (node.elseStatement) {
                    writeLineOrSpace(node, node.thenStatement, node.elseStatement);
                    emitTokenWithComment(91 /* ElseKeyword */, node.thenStatement.end, writeKeyword, node);
                    if (node.elseStatement.kind === 242 /* IfStatement */) {
                        writeSpace();
                        emit(node.elseStatement);
                    }
                    else {
                        emitEmbeddedStatement(node, node.elseStatement);
                    }
                }
            }
            function emitWhileClause(node, startPos) {
                const openParenPos = emitTokenWithComment(115 /* WhileKeyword */, startPos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(20 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitExpression(node.expression);
                emitTokenWithComment(21 /* CloseParenToken */, node.expression.end, writePunctuation, node);
            }
            function emitDoStatement(node) {
                emitTokenWithComment(90 /* DoKeyword */, node.pos, writeKeyword, node);
                emitEmbeddedStatement(node, node.statement);
                if (isBlock(node.statement) && !preserveSourceNewlines) {
                    writeSpace();
                }
                else {
                    writeLineOrSpace(node, node.statement, node.expression);
                }
                emitWhileClause(node, node.statement.end);
                writeTrailingSemicolon();
            }
            function emitWhileStatement(node) {
                emitWhileClause(node, node.pos);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitForStatement(node) {
                const openParenPos = emitTokenWithComment(97 /* ForKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                let pos = emitTokenWithComment(20 /* OpenParenToken */, openParenPos, writePunctuation, 
                /*contextNode*/
                node);
                emitForBinding(node.initializer);
                pos = emitTokenWithComment(26 /* SemicolonToken */, node.initializer ? node.initializer.end : pos, writePunctuation, node);
                emitExpressionWithLeadingSpace(node.condition);
                pos = emitTokenWithComment(26 /* SemicolonToken */, node.condition ? node.condition.end : pos, writePunctuation, node);
                emitExpressionWithLeadingSpace(node.incrementor);
                emitTokenWithComment(21 /* CloseParenToken */, node.incrementor ? node.incrementor.end : pos, writePunctuation, node);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitForInStatement(node) {
                const openParenPos = emitTokenWithComment(97 /* ForKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(20 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitForBinding(node.initializer);
                writeSpace();
                emitTokenWithComment(101 /* InKeyword */, node.initializer.end, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression);
                emitTokenWithComment(21 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitForOfStatement(node) {
                const openParenPos = emitTokenWithComment(97 /* ForKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitWithTrailingSpace(node.awaitModifier);
                emitTokenWithComment(20 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitForBinding(node.initializer);
                writeSpace();
                emitTokenWithComment(162 /* OfKeyword */, node.initializer.end, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression);
                emitTokenWithComment(21 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitForBinding(node) {
                if (node !== void 0) {
                    if (node.kind === 258 /* VariableDeclarationList */) {
                        emit(node);
                    }
                    else {
                        emitExpression(node);
                    }
                }
            }
            function emitContinueStatement(node) {
                emitTokenWithComment(86 /* ContinueKeyword */, node.pos, writeKeyword, node);
                emitWithLeadingSpace(node.label);
                writeTrailingSemicolon();
            }
            function emitBreakStatement(node) {
                emitTokenWithComment(81 /* BreakKeyword */, node.pos, writeKeyword, node);
                emitWithLeadingSpace(node.label);
                writeTrailingSemicolon();
            }
            function emitTokenWithComment(token, pos, writer2, contextNode, indentLeading) {
                const node = getParseTreeNode(contextNode);
                const isSimilarNode = node && node.kind === contextNode.kind;
                const startPos = pos;
                if (isSimilarNode && currentSourceFile) {
                    pos = skipTrivia(currentSourceFile.text, pos);
                }
                if (isSimilarNode && contextNode.pos !== startPos) {
                    const needsIndent = indentLeading && currentSourceFile && !positionsAreOnSameLine(startPos, pos, currentSourceFile);
                    if (needsIndent) {
                        increaseIndent();
                    }
                    emitLeadingCommentsOfPosition(startPos);
                    if (needsIndent) {
                        decreaseIndent();
                    }
                }
                pos = writeTokenText(token, writer2, pos);
                if (isSimilarNode && contextNode.end !== pos) {
                    const isJsxExprContext = contextNode.kind === 291 /* JsxExpression */;
                    emitTrailingCommentsOfPosition(pos, 
                    /*prefixSpace*/
                    !isJsxExprContext, 
                    /*forceNoNewline*/
                    isJsxExprContext);
                }
                return pos;
            }
            function commentWillEmitNewLine(node) {
                return node.kind === 2 /* SingleLineCommentTrivia */ || !!node.hasTrailingNewLine;
            }
            function willEmitLeadingNewLine(node) {
                if (!currentSourceFile)
                    return false;
                if (some(getLeadingCommentRanges(currentSourceFile.text, node.pos), commentWillEmitNewLine))
                    return true;
                if (some(getSyntheticLeadingComments(node), commentWillEmitNewLine))
                    return true;
                if (isPartiallyEmittedExpression(node)) {
                    if (node.pos !== node.expression.pos) {
                        if (some(getTrailingCommentRanges(currentSourceFile.text, node.expression.pos), commentWillEmitNewLine))
                            return true;
                    }
                    return willEmitLeadingNewLine(node.expression);
                }
                return false;
            }
            function parenthesizeExpressionForNoAsi(node) {
                if (!commentsDisabled && isPartiallyEmittedExpression(node) && willEmitLeadingNewLine(node)) {
                    const parseNode = getParseTreeNode(node);
                    if (parseNode && isParenthesizedExpression(parseNode)) {
                        const parens = factory.createParenthesizedExpression(node.expression);
                        setOriginalNode(parens, node);
                        setTextRange(parens, parseNode);
                        return parens;
                    }
                    return factory.createParenthesizedExpression(node);
                }
                return node;
            }
            function parenthesizeExpressionForNoAsiAndDisallowedComma(node) {
                return parenthesizeExpressionForNoAsi(parenthesizer.parenthesizeExpressionForDisallowedComma(node));
            }
            function emitReturnStatement(node) {
                emitTokenWithComment(105 /* ReturnKeyword */, node.pos, writeKeyword, 
                /*contextNode*/
                node);
                emitExpressionWithLeadingSpace(node.expression && parenthesizeExpressionForNoAsi(node.expression), parenthesizeExpressionForNoAsi);
                writeTrailingSemicolon();
            }
            function emitWithStatement(node) {
                const openParenPos = emitTokenWithComment(116 /* WithKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(20 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitExpression(node.expression);
                emitTokenWithComment(21 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitSwitchStatement(node) {
                const openParenPos = emitTokenWithComment(107 /* SwitchKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(20 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitExpression(node.expression);
                emitTokenWithComment(21 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                writeSpace();
                emit(node.caseBlock);
            }
            function emitLabeledStatement(node) {
                emit(node.label);
                emitTokenWithComment(58 /* ColonToken */, node.label.end, writePunctuation, node);
                writeSpace();
                emit(node.statement);
            }
            function emitThrowStatement(node) {
                emitTokenWithComment(109 /* ThrowKeyword */, node.pos, writeKeyword, node);
                emitExpressionWithLeadingSpace(parenthesizeExpressionForNoAsi(node.expression), parenthesizeExpressionForNoAsi);
                writeTrailingSemicolon();
            }
            function emitTryStatement(node) {
                emitTokenWithComment(111 /* TryKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emit(node.tryBlock);
                if (node.catchClause) {
                    writeLineOrSpace(node, node.tryBlock, node.catchClause);
                    emit(node.catchClause);
                }
                if (node.finallyBlock) {
                    writeLineOrSpace(node, node.catchClause || node.tryBlock, node.finallyBlock);
                    emitTokenWithComment(96 /* FinallyKeyword */, (node.catchClause || node.tryBlock).end, writeKeyword, node);
                    writeSpace();
                    emit(node.finallyBlock);
                }
            }
            function emitDebuggerStatement(node) {
                writeToken(87 /* DebuggerKeyword */, node.pos, writeKeyword);
                writeTrailingSemicolon();
            }
            function emitVariableDeclaration(node) {
                var _a2, _b, _c, _d, _e;
                emit(node.name);
                emit(node.exclamationToken);
                emitTypeAnnotation(node.type);
                emitInitializer(node.initializer, (_e = (_d = (_a2 = node.type) == null ? void 0 : _a2.end) != null ? _d : (_c = (_b = node.name.emitNode) == null ? void 0 : _b.typeNode) == null ? void 0 : _c.end) != null ? _e : node.name.end, node, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitVariableDeclarationList(node) {
                writeKeyword(isLet(node) ? "let" : isVarConst(node) ? "const" : "var");
                writeSpace();
                emitList(node, node.declarations, 528 /* VariableDeclarationList */);
            }
            function emitFunctionDeclaration(node) {
                emitFunctionDeclarationOrExpression(node);
            }
            function emitFunctionDeclarationOrExpression(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("function");
                emit(node.asteriskToken);
                writeSpace();
                emitIdentifierName(node.name);
                emitSignatureAndBody(node, emitSignatureHead);
            }
            function emitSignatureAndBody(node, emitSignatureHead2) {
                const body = node.body;
                if (body) {
                    if (isBlock(body)) {
                        const indentedFlag = getEmitFlags(node) & 131072 /* Indented */;
                        if (indentedFlag) {
                            increaseIndent();
                        }
                        pushNameGenerationScope(node);
                        forEach(node.parameters, generateNames);
                        generateNames(node.body);
                        emitSignatureHead2(node);
                        emitBlockFunctionBody(body);
                        popNameGenerationScope(node);
                        if (indentedFlag) {
                            decreaseIndent();
                        }
                    }
                    else {
                        emitSignatureHead2(node);
                        writeSpace();
                        emitExpression(body, parenthesizer.parenthesizeConciseBodyOfArrowFunction);
                    }
                }
                else {
                    emitSignatureHead2(node);
                    writeTrailingSemicolon();
                }
            }
            function emitSignatureHead(node) {
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                emitTypeAnnotation(node.type);
            }
            function shouldEmitBlockFunctionBodyOnSingleLine(body) {
                if (getEmitFlags(body) & 1 /* SingleLine */) {
                    return true;
                }
                if (body.multiLine) {
                    return false;
                }
                if (!nodeIsSynthesized(body) && currentSourceFile && !rangeIsOnSingleLine(body, currentSourceFile)) {
                    return false;
                }
                if (getLeadingLineTerminatorCount(body, firstOrUndefined(body.statements), 2 /* PreserveLines */) || getClosingLineTerminatorCount(body, lastOrUndefined(body.statements), 2 /* PreserveLines */, body.statements)) {
                    return false;
                }
                let previousStatement;
                for (const statement of body.statements) {
                    if (getSeparatingLineTerminatorCount(previousStatement, statement, 2 /* PreserveLines */) > 0) {
                        return false;
                    }
                    previousStatement = statement;
                }
                return true;
            }
            function emitBlockFunctionBody(body) {
                onBeforeEmitNode == null ? void 0 : onBeforeEmitNode(body);
                writeSpace();
                writePunctuation("{");
                increaseIndent();
                const emitBlockFunctionBody2 = shouldEmitBlockFunctionBodyOnSingleLine(body) ? emitBlockFunctionBodyOnSingleLine : emitBlockFunctionBodyWorker;
                emitBodyWithDetachedComments(body, body.statements, emitBlockFunctionBody2);
                decreaseIndent();
                writeToken(19 /* CloseBraceToken */, body.statements.end, writePunctuation, body);
                onAfterEmitNode == null ? void 0 : onAfterEmitNode(body);
            }
            function emitBlockFunctionBodyOnSingleLine(body) {
                emitBlockFunctionBodyWorker(body, 
                /*emitBlockFunctionBodyOnSingleLine*/
                true);
            }
            function emitBlockFunctionBodyWorker(body, emitBlockFunctionBodyOnSingleLine2) {
                const statementOffset = emitPrologueDirectives(body.statements);
                const pos = writer.getTextPos();
                emitHelpers(body);
                if (statementOffset === 0 && pos === writer.getTextPos() && emitBlockFunctionBodyOnSingleLine2) {
                    decreaseIndent();
                    emitList(body, body.statements, 768 /* SingleLineFunctionBodyStatements */);
                    increaseIndent();
                }
                else {
                    emitList(body, body.statements, 1 /* MultiLineFunctionBodyStatements */, 
                    /*parenthesizerRule*/
                    void 0, statementOffset);
                }
            }
            function emitClassDeclaration(node) {
                emitClassDeclarationOrExpression(node);
            }
            function emitClassDeclarationOrExpression(node) {
                pushPrivateNameGenerationScope(0 /* Auto */, 
                /*newReservedMemberNames*/
                void 0);
                forEach(node.members, generateMemberNames);
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                emitTokenWithComment(84 /* ClassKeyword */, moveRangePastModifiers(node).pos, writeKeyword, node);
                if (node.name) {
                    writeSpace();
                    emitIdentifierName(node.name);
                }
                const indentedFlag = getEmitFlags(node) & 131072 /* Indented */;
                if (indentedFlag) {
                    increaseIndent();
                }
                emitTypeParameters(node, node.typeParameters);
                emitList(node, node.heritageClauses, 0 /* ClassHeritageClauses */);
                writeSpace();
                writePunctuation("{");
                emitList(node, node.members, 129 /* ClassMembers */);
                writePunctuation("}");
                if (indentedFlag) {
                    decreaseIndent();
                }
                popPrivateNameGenerationScope();
            }
            function emitInterfaceDeclaration(node) {
                pushPrivateNameGenerationScope(0 /* Auto */, 
                /*newReservedMemberNames*/
                void 0);
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("interface");
                writeSpace();
                emit(node.name);
                emitTypeParameters(node, node.typeParameters);
                emitList(node, node.heritageClauses, 512 /* HeritageClauses */);
                writeSpace();
                writePunctuation("{");
                emitList(node, node.members, 129 /* InterfaceMembers */);
                writePunctuation("}");
                popPrivateNameGenerationScope();
            }
            function emitTypeAliasDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("type");
                writeSpace();
                emit(node.name);
                emitTypeParameters(node, node.typeParameters);
                writeSpace();
                writePunctuation("=");
                writeSpace();
                emit(node.type);
                writeTrailingSemicolon();
            }
            function emitEnumDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("enum");
                writeSpace();
                emit(node.name);
                writeSpace();
                writePunctuation("{");
                emitList(node, node.members, 145 /* EnumMembers */);
                writePunctuation("}");
            }
            function emitModuleDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                if (~node.flags & 1024 /* GlobalAugmentation */) {
                    writeKeyword(node.flags & 16 /* Namespace */ ? "namespace" : "module");
                    writeSpace();
                }
                emit(node.name);
                let body = node.body;
                if (!body)
                    return writeTrailingSemicolon();
                while (body && isModuleDeclaration(body)) {
                    writePunctuation(".");
                    emit(body.name);
                    body = body.body;
                }
                writeSpace();
                emit(body);
            }
            function emitModuleBlock(node) {
                pushNameGenerationScope(node);
                forEach(node.statements, generateNames);
                emitBlockStatements(node, 
                /*forceSingleLine*/
                isEmptyBlock(node));
                popNameGenerationScope(node);
            }
            function emitCaseBlock(node) {
                emitTokenWithComment(18 /* OpenBraceToken */, node.pos, writePunctuation, node);
                emitList(node, node.clauses, 129 /* CaseBlockClauses */);
                emitTokenWithComment(19 /* CloseBraceToken */, node.clauses.end, writePunctuation, node, 
                /*indentLeading*/
                true);
            }
            function emitImportEqualsDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                emitTokenWithComment(100 /* ImportKeyword */, node.modifiers ? node.modifiers.end : node.pos, writeKeyword, node);
                writeSpace();
                if (node.isTypeOnly) {
                    emitTokenWithComment(154 /* TypeKeyword */, node.pos, writeKeyword, node);
                    writeSpace();
                }
                emit(node.name);
                writeSpace();
                emitTokenWithComment(63 /* EqualsToken */, node.name.end, writePunctuation, node);
                writeSpace();
                emitModuleReference(node.moduleReference);
                writeTrailingSemicolon();
            }
            function emitModuleReference(node) {
                if (node.kind === 79 /* Identifier */) {
                    emitExpression(node);
                }
                else {
                    emit(node);
                }
            }
            function emitImportDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                emitTokenWithComment(100 /* ImportKeyword */, node.modifiers ? node.modifiers.end : node.pos, writeKeyword, node);
                writeSpace();
                if (node.importClause) {
                    emit(node.importClause);
                    writeSpace();
                    emitTokenWithComment(158 /* FromKeyword */, node.importClause.end, writeKeyword, node);
                    writeSpace();
                }
                emitExpression(node.moduleSpecifier);
                if (node.assertClause) {
                    emitWithLeadingSpace(node.assertClause);
                }
                writeTrailingSemicolon();
            }
            function emitImportClause(node) {
                if (node.isTypeOnly) {
                    emitTokenWithComment(154 /* TypeKeyword */, node.pos, writeKeyword, node);
                    writeSpace();
                }
                emit(node.name);
                if (node.name && node.namedBindings) {
                    emitTokenWithComment(27 /* CommaToken */, node.name.end, writePunctuation, node);
                    writeSpace();
                }
                emit(node.namedBindings);
            }
            function emitNamespaceImport(node) {
                const asPos = emitTokenWithComment(41 /* AsteriskToken */, node.pos, writePunctuation, node);
                writeSpace();
                emitTokenWithComment(128 /* AsKeyword */, asPos, writeKeyword, node);
                writeSpace();
                emit(node.name);
            }
            function emitNamedImports(node) {
                emitNamedImportsOrExports(node);
            }
            function emitImportSpecifier(node) {
                emitImportOrExportSpecifier(node);
            }
            function emitExportAssignment(node) {
                const nextPos = emitTokenWithComment(93 /* ExportKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                if (node.isExportEquals) {
                    emitTokenWithComment(63 /* EqualsToken */, nextPos, writeOperator, node);
                }
                else {
                    emitTokenWithComment(88 /* DefaultKeyword */, nextPos, writeKeyword, node);
                }
                writeSpace();
                emitExpression(node.expression, node.isExportEquals ? parenthesizer.getParenthesizeRightSideOfBinaryForOperator(63 /* EqualsToken */) : parenthesizer.parenthesizeExpressionOfExportDefault);
                writeTrailingSemicolon();
            }
            function emitExportDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                let nextPos = emitTokenWithComment(93 /* ExportKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                if (node.isTypeOnly) {
                    nextPos = emitTokenWithComment(154 /* TypeKeyword */, nextPos, writeKeyword, node);
                    writeSpace();
                }
                if (node.exportClause) {
                    emit(node.exportClause);
                }
                else {
                    nextPos = emitTokenWithComment(41 /* AsteriskToken */, nextPos, writePunctuation, node);
                }
                if (node.moduleSpecifier) {
                    writeSpace();
                    const fromPos = node.exportClause ? node.exportClause.end : nextPos;
                    emitTokenWithComment(158 /* FromKeyword */, fromPos, writeKeyword, node);
                    writeSpace();
                    emitExpression(node.moduleSpecifier);
                }
                if (node.assertClause) {
                    emitWithLeadingSpace(node.assertClause);
                }
                writeTrailingSemicolon();
            }
            function emitAssertClause(node) {
                emitTokenWithComment(130 /* AssertKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                const elements = node.elements;
                emitList(node, elements, 526226 /* ImportClauseEntries */);
            }
            function emitAssertEntry(node) {
                emit(node.name);
                writePunctuation(":");
                writeSpace();
                const value = node.value;
                if ((getEmitFlags(value) & 1024 /* NoLeadingComments */) === 0) {
                    const commentRange = getCommentRange(value);
                    emitTrailingCommentsOfPosition(commentRange.pos);
                }
                emit(value);
            }
            function emitNamespaceExportDeclaration(node) {
                let nextPos = emitTokenWithComment(93 /* ExportKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                nextPos = emitTokenWithComment(128 /* AsKeyword */, nextPos, writeKeyword, node);
                writeSpace();
                nextPos = emitTokenWithComment(143 /* NamespaceKeyword */, nextPos, writeKeyword, node);
                writeSpace();
                emit(node.name);
                writeTrailingSemicolon();
            }
            function emitNamespaceExport(node) {
                const asPos = emitTokenWithComment(41 /* AsteriskToken */, node.pos, writePunctuation, node);
                writeSpace();
                emitTokenWithComment(128 /* AsKeyword */, asPos, writeKeyword, node);
                writeSpace();
                emit(node.name);
            }
            function emitNamedExports(node) {
                emitNamedImportsOrExports(node);
            }
            function emitExportSpecifier(node) {
                emitImportOrExportSpecifier(node);
            }
            function emitNamedImportsOrExports(node) {
                writePunctuation("{");
                emitList(node, node.elements, 525136 /* NamedImportsOrExportsElements */);
                writePunctuation("}");
            }
            function emitImportOrExportSpecifier(node) {
                if (node.isTypeOnly) {
                    writeKeyword("type");
                    writeSpace();
                }
                if (node.propertyName) {
                    emit(node.propertyName);
                    writeSpace();
                    emitTokenWithComment(128 /* AsKeyword */, node.propertyName.end, writeKeyword, node);
                    writeSpace();
                }
                emit(node.name);
            }
            function emitExternalModuleReference(node) {
                writeKeyword("require");
                writePunctuation("(");
                emitExpression(node.expression);
                writePunctuation(")");
            }
            function emitJsxElement(node) {
                emit(node.openingElement);
                emitList(node, node.children, 262144 /* JsxElementOrFragmentChildren */);
                emit(node.closingElement);
            }
            function emitJsxSelfClosingElement(node) {
                writePunctuation("<");
                emitJsxTagName(node.tagName);
                emitTypeArguments(node, node.typeArguments);
                writeSpace();
                emit(node.attributes);
                writePunctuation("/>");
            }
            function emitJsxFragment(node) {
                emit(node.openingFragment);
                emitList(node, node.children, 262144 /* JsxElementOrFragmentChildren */);
                emit(node.closingFragment);
            }
            function emitJsxOpeningElementOrFragment(node) {
                writePunctuation("<");
                if (isJsxOpeningElement(node)) {
                    const indented = writeLineSeparatorsAndIndentBefore(node.tagName, node);
                    emitJsxTagName(node.tagName);
                    emitTypeArguments(node, node.typeArguments);
                    if (node.attributes.properties && node.attributes.properties.length > 0) {
                        writeSpace();
                    }
                    emit(node.attributes);
                    writeLineSeparatorsAfter(node.attributes, node);
                    decreaseIndentIf(indented);
                }
                writePunctuation(">");
            }
            function emitJsxText(node) {
                writer.writeLiteral(node.text);
            }
            function emitJsxClosingElementOrFragment(node) {
                writePunctuation("</");
                if (isJsxClosingElement(node)) {
                    emitJsxTagName(node.tagName);
                }
                writePunctuation(">");
            }
            function emitJsxAttributes(node) {
                emitList(node, node.properties, 262656 /* JsxElementAttributes */);
            }
            function emitJsxAttribute(node) {
                emit(node.name);
                emitNodeWithPrefix("=", writePunctuation, node.initializer, emitJsxAttributeValue);
            }
            function emitJsxSpreadAttribute(node) {
                writePunctuation("{...");
                emitExpression(node.expression);
                writePunctuation("}");
            }
            function hasTrailingCommentsAtPosition(pos) {
                let result = false;
                forEachTrailingCommentRange((currentSourceFile == null ? void 0 : currentSourceFile.text) || "", pos + 1, () => result = true);
                return result;
            }
            function hasLeadingCommentsAtPosition(pos) {
                let result = false;
                forEachLeadingCommentRange((currentSourceFile == null ? void 0 : currentSourceFile.text) || "", pos + 1, () => result = true);
                return result;
            }
            function hasCommentsAtPosition(pos) {
                return hasTrailingCommentsAtPosition(pos) || hasLeadingCommentsAtPosition(pos);
            }
            function emitJsxExpression(node) {
                var _a2;
                if (node.expression || !commentsDisabled && !nodeIsSynthesized(node) && hasCommentsAtPosition(node.pos)) {
                    const isMultiline = currentSourceFile && !nodeIsSynthesized(node) && getLineAndCharacterOfPosition(currentSourceFile, node.pos).line !== getLineAndCharacterOfPosition(currentSourceFile, node.end).line;
                    if (isMultiline) {
                        writer.increaseIndent();
                    }
                    const end = emitTokenWithComment(18 /* OpenBraceToken */, node.pos, writePunctuation, node);
                    emit(node.dotDotDotToken);
                    emitExpression(node.expression);
                    emitTokenWithComment(19 /* CloseBraceToken */, ((_a2 = node.expression) == null ? void 0 : _a2.end) || end, writePunctuation, node);
                    if (isMultiline) {
                        writer.decreaseIndent();
                    }
                }
            }
            function emitJsxTagName(node) {
                if (node.kind === 79 /* Identifier */) {
                    emitExpression(node);
                }
                else {
                    emit(node);
                }
            }
            function emitCaseClause(node) {
                emitTokenWithComment(82 /* CaseKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionForDisallowedComma);
                emitCaseOrDefaultClauseRest(node, node.statements, node.expression.end);
            }
            function emitDefaultClause(node) {
                const pos = emitTokenWithComment(88 /* DefaultKeyword */, node.pos, writeKeyword, node);
                emitCaseOrDefaultClauseRest(node, node.statements, pos);
            }
            function emitCaseOrDefaultClauseRest(parentNode, statements, colonPos) {
                const emitAsSingleStatement = statements.length === 1 && // treat synthesized nodes as located on the same line for emit purposes
                    (!currentSourceFile || nodeIsSynthesized(parentNode) || nodeIsSynthesized(statements[0]) || rangeStartPositionsAreOnSameLine(parentNode, statements[0], currentSourceFile));
                let format = 163969 /* CaseOrDefaultClauseStatements */;
                if (emitAsSingleStatement) {
                    writeToken(58 /* ColonToken */, colonPos, writePunctuation, parentNode);
                    writeSpace();
                    format &= ~(1 /* MultiLine */ | 128 /* Indented */);
                }
                else {
                    emitTokenWithComment(58 /* ColonToken */, colonPos, writePunctuation, parentNode);
                }
                emitList(parentNode, statements, format);
            }
            function emitHeritageClause(node) {
                writeSpace();
                writeTokenText(node.token, writeKeyword);
                writeSpace();
                emitList(node, node.types, 528 /* HeritageClauseTypes */);
            }
            function emitCatchClause(node) {
                const openParenPos = emitTokenWithComment(83 /* CatchKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                if (node.variableDeclaration) {
                    emitTokenWithComment(20 /* OpenParenToken */, openParenPos, writePunctuation, node);
                    emit(node.variableDeclaration);
                    emitTokenWithComment(21 /* CloseParenToken */, node.variableDeclaration.end, writePunctuation, node);
                    writeSpace();
                }
                emit(node.block);
            }
            function emitPropertyAssignment(node) {
                emit(node.name);
                writePunctuation(":");
                writeSpace();
                const initializer = node.initializer;
                if ((getEmitFlags(initializer) & 1024 /* NoLeadingComments */) === 0) {
                    const commentRange = getCommentRange(initializer);
                    emitTrailingCommentsOfPosition(commentRange.pos);
                }
                emitExpression(initializer, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitShorthandPropertyAssignment(node) {
                emit(node.name);
                if (node.objectAssignmentInitializer) {
                    writeSpace();
                    writePunctuation("=");
                    writeSpace();
                    emitExpression(node.objectAssignmentInitializer, parenthesizer.parenthesizeExpressionForDisallowedComma);
                }
            }
            function emitSpreadAssignment(node) {
                if (node.expression) {
                    emitTokenWithComment(25 /* DotDotDotToken */, node.pos, writePunctuation, node);
                    emitExpression(node.expression, parenthesizer.parenthesizeExpressionForDisallowedComma);
                }
            }
            function emitEnumMember(node) {
                emit(node.name);
                emitInitializer(node.initializer, node.name.end, node, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitJSDoc(node) {
                write("/**");
                if (node.comment) {
                    const text = getTextOfJSDocComment(node.comment);
                    if (text) {
                        const lines = text.split(/\r\n?|\n/g);
                        for (const line of lines) {
                            writeLine();
                            writeSpace();
                            writePunctuation("*");
                            writeSpace();
                            write(line);
                        }
                    }
                }
                if (node.tags) {
                    if (node.tags.length === 1 && node.tags[0].kind === 347 /* JSDocTypeTag */ && !node.comment) {
                        writeSpace();
                        emit(node.tags[0]);
                    }
                    else {
                        emitList(node, node.tags, 33 /* JSDocComment */);
                    }
                }
                writeSpace();
                write("*/");
            }
            function emitJSDocSimpleTypedTag(tag) {
                emitJSDocTagName(tag.tagName);
                emitJSDocTypeExpression(tag.typeExpression);
                emitJSDocComment(tag.comment);
            }
            function emitJSDocSeeTag(tag) {
                emitJSDocTagName(tag.tagName);
                emit(tag.name);
                emitJSDocComment(tag.comment);
            }
            function emitJSDocNameReference(node) {
                writeSpace();
                writePunctuation("{");
                emit(node.name);
                writePunctuation("}");
            }
            function emitJSDocHeritageTag(tag) {
                emitJSDocTagName(tag.tagName);
                writeSpace();
                writePunctuation("{");
                emit(tag.class);
                writePunctuation("}");
                emitJSDocComment(tag.comment);
            }
            function emitJSDocTemplateTag(tag) {
                emitJSDocTagName(tag.tagName);
                emitJSDocTypeExpression(tag.constraint);
                writeSpace();
                emitList(tag, tag.typeParameters, 528 /* CommaListElements */);
                emitJSDocComment(tag.comment);
            }
            function emitJSDocTypedefTag(tag) {
                emitJSDocTagName(tag.tagName);
                if (tag.typeExpression) {
                    if (tag.typeExpression.kind === 312 /* JSDocTypeExpression */) {
                        emitJSDocTypeExpression(tag.typeExpression);
                    }
                    else {
                        writeSpace();
                        writePunctuation("{");
                        write("Object");
                        if (tag.typeExpression.isArrayType) {
                            writePunctuation("[");
                            writePunctuation("]");
                        }
                        writePunctuation("}");
                    }
                }
                if (tag.fullName) {
                    writeSpace();
                    emit(tag.fullName);
                }
                emitJSDocComment(tag.comment);
                if (tag.typeExpression && tag.typeExpression.kind === 325 /* JSDocTypeLiteral */) {
                    emitJSDocTypeLiteral(tag.typeExpression);
                }
            }
            function emitJSDocCallbackTag(tag) {
                emitJSDocTagName(tag.tagName);
                if (tag.name) {
                    writeSpace();
                    emit(tag.name);
                }
                emitJSDocComment(tag.comment);
                emitJSDocSignature(tag.typeExpression);
            }
            function emitJSDocOverloadTag(tag) {
                emitJSDocComment(tag.comment);
                emitJSDocSignature(tag.typeExpression);
            }
            function emitJSDocSimpleTag(tag) {
                emitJSDocTagName(tag.tagName);
                emitJSDocComment(tag.comment);
            }
            function emitJSDocTypeLiteral(lit) {
                emitList(lit, factory.createNodeArray(lit.jsDocPropertyTags), 33 /* JSDocComment */);
            }
            function emitJSDocSignature(sig) {
                if (sig.typeParameters) {
                    emitList(sig, factory.createNodeArray(sig.typeParameters), 33 /* JSDocComment */);
                }
                if (sig.parameters) {
                    emitList(sig, factory.createNodeArray(sig.parameters), 33 /* JSDocComment */);
                }
                if (sig.type) {
                    writeLine();
                    writeSpace();
                    writePunctuation("*");
                    writeSpace();
                    emit(sig.type);
                }
            }
            function emitJSDocPropertyLikeTag(param) {
                emitJSDocTagName(param.tagName);
                emitJSDocTypeExpression(param.typeExpression);
                writeSpace();
                if (param.isBracketed) {
                    writePunctuation("[");
                }
                emit(param.name);
                if (param.isBracketed) {
                    writePunctuation("]");
                }
                emitJSDocComment(param.comment);
            }
            function emitJSDocTagName(tagName) {
                writePunctuation("@");
                emit(tagName);
            }
            function emitJSDocComment(comment) {
                const text = getTextOfJSDocComment(comment);
                if (text) {
                    writeSpace();
                    write(text);
                }
            }
            function emitJSDocTypeExpression(typeExpression) {
                if (typeExpression) {
                    writeSpace();
                    writePunctuation("{");
                    emit(typeExpression.type);
                    writePunctuation("}");
                }
            }
            function emitSourceFile(node) {
                writeLine();
                const statements = node.statements;
                const shouldEmitDetachedComment = statements.length === 0 || !isPrologueDirective(statements[0]) || nodeIsSynthesized(statements[0]);
                if (shouldEmitDetachedComment) {
                    emitBodyWithDetachedComments(node, statements, emitSourceFileWorker);
                    return;
                }
                emitSourceFileWorker(node);
            }
            function emitSyntheticTripleSlashReferencesIfNeeded(node) {
                emitTripleSlashDirectives(!!node.hasNoDefaultLib, node.syntheticFileReferences || [], node.syntheticTypeReferences || [], node.syntheticLibReferences || []);
                for (const prepend of node.prepends) {
                    if (isUnparsedSource(prepend) && prepend.syntheticReferences) {
                        for (const ref of prepend.syntheticReferences) {
                            emit(ref);
                            writeLine();
                        }
                    }
                }
            }
            function emitTripleSlashDirectivesIfNeeded(node) {
                if (node.isDeclarationFile)
                    emitTripleSlashDirectives(node.hasNoDefaultLib, node.referencedFiles, node.typeReferenceDirectives, node.libReferenceDirectives);
            }
            function emitTripleSlashDirectives(hasNoDefaultLib, files, types, libs2) {
                if (hasNoDefaultLib) {
                    const pos = writer.getTextPos();
                    writeComment(`/// <reference no-default-lib="true"/>`);
                    if (bundleFileInfo)
                        bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "no-default-lib" /* NoDefaultLib */ });
                    writeLine();
                }
                if (currentSourceFile && currentSourceFile.moduleName) {
                    writeComment(`/// <amd-module name="${currentSourceFile.moduleName}" />`);
                    writeLine();
                }
                if (currentSourceFile && currentSourceFile.amdDependencies) {
                    for (const dep of currentSourceFile.amdDependencies) {
                        if (dep.name) {
                            writeComment(`/// <amd-dependency name="${dep.name}" path="${dep.path}" />`);
                        }
                        else {
                            writeComment(`/// <amd-dependency path="${dep.path}" />`);
                        }
                        writeLine();
                    }
                }
                for (const directive of files) {
                    const pos = writer.getTextPos();
                    writeComment(`/// <reference path="${directive.fileName}" />`);
                    if (bundleFileInfo)
                        bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "reference" /* Reference */, data: directive.fileName });
                    writeLine();
                }
                for (const directive of types) {
                    const pos = writer.getTextPos();
                    const resolutionMode = directive.resolutionMode && directive.resolutionMode !== (currentSourceFile == null ? void 0 : currentSourceFile.impliedNodeFormat) ? `resolution-mode="${directive.resolutionMode === 99 /* ESNext */ ? "import" : "require"}"` : "";
                    writeComment(`/// <reference types="${directive.fileName}" ${resolutionMode}/>`);
                    if (bundleFileInfo)
                        bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: !directive.resolutionMode ? "type" /* Type */ : directive.resolutionMode === 99 /* ESNext */ ? "type-import" /* TypeResolutionModeImport */ : "type-require" /* TypeResolutionModeRequire */, data: directive.fileName });
                    writeLine();
                }
                for (const directive of libs2) {
                    const pos = writer.getTextPos();
                    writeComment(`/// <reference lib="${directive.fileName}" />`);
                    if (bundleFileInfo)
                        bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "lib" /* Lib */, data: directive.fileName });
                    writeLine();
                }
            }
            function emitSourceFileWorker(node) {
                const statements = node.statements;
                pushNameGenerationScope(node);
                forEach(node.statements, generateNames);
                emitHelpers(node);
                const index = findIndex(statements, (statement) => !isPrologueDirective(statement));
                emitTripleSlashDirectivesIfNeeded(node);
                emitList(node, statements, 1 /* MultiLine */, 
                /*parenthesizerRule*/
                void 0, index === -1 ? statements.length : index);
                popNameGenerationScope(node);
            }
            function emitPartiallyEmittedExpression(node) {
                const emitFlags = getEmitFlags(node);
                if (!(emitFlags & 1024 /* NoLeadingComments */) && node.pos !== node.expression.pos) {
                    emitTrailingCommentsOfPosition(node.expression.pos);
                }
                emitExpression(node.expression);
                if (!(emitFlags & 2048 /* NoTrailingComments */) && node.end !== node.expression.end) {
                    emitLeadingCommentsOfPosition(node.expression.end);
                }
            }
            function emitCommaList(node) {
                emitExpressionList(node, node.elements, 528 /* CommaListElements */, 
                /*parenthesizerRule*/
                void 0);
            }
            function emitPrologueDirectives(statements, sourceFile, seenPrologueDirectives, recordBundleFileSection) {
                let needsToSetSourceFile = !!sourceFile;
                for (let i = 0; i < statements.length; i++) {
                    const statement = statements[i];
                    if (isPrologueDirective(statement)) {
                        const shouldEmitPrologueDirective = seenPrologueDirectives ? !seenPrologueDirectives.has(statement.expression.text) : true;
                        if (shouldEmitPrologueDirective) {
                            if (needsToSetSourceFile) {
                                needsToSetSourceFile = false;
                                setSourceFile(sourceFile);
                            }
                            writeLine();
                            const pos = writer.getTextPos();
                            emit(statement);
                            if (recordBundleFileSection && bundleFileInfo)
                                bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "prologue" /* Prologue */, data: statement.expression.text });
                            if (seenPrologueDirectives) {
                                seenPrologueDirectives.add(statement.expression.text);
                            }
                        }
                    }
                    else {
                        return i;
                    }
                }
                return statements.length;
            }
            function emitUnparsedPrologues(prologues, seenPrologueDirectives) {
                for (const prologue of prologues) {
                    if (!seenPrologueDirectives.has(prologue.data)) {
                        writeLine();
                        const pos = writer.getTextPos();
                        emit(prologue);
                        if (bundleFileInfo)
                            bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "prologue" /* Prologue */, data: prologue.data });
                        if (seenPrologueDirectives) {
                            seenPrologueDirectives.add(prologue.data);
                        }
                    }
                }
            }
            function emitPrologueDirectivesIfNeeded(sourceFileOrBundle) {
                if (isSourceFile(sourceFileOrBundle)) {
                    emitPrologueDirectives(sourceFileOrBundle.statements, sourceFileOrBundle);
                }
                else {
                    const seenPrologueDirectives = /* @__PURE__ */ new Set();
                    for (const prepend of sourceFileOrBundle.prepends) {
                        emitUnparsedPrologues(prepend.prologues, seenPrologueDirectives);
                    }
                    for (const sourceFile of sourceFileOrBundle.sourceFiles) {
                        emitPrologueDirectives(sourceFile.statements, sourceFile, seenPrologueDirectives, 
                        /*recordBundleFileSection*/
                        true);
                    }
                    setSourceFile(void 0);
                }
            }
            function getPrologueDirectivesFromBundledSourceFiles(bundle) {
                const seenPrologueDirectives = /* @__PURE__ */ new Set();
                let prologues;
                for (let index = 0; index < bundle.sourceFiles.length; index++) {
                    const sourceFile = bundle.sourceFiles[index];
                    let directives;
                    let end = 0;
                    for (const statement of sourceFile.statements) {
                        if (!isPrologueDirective(statement))
                            break;
                        if (seenPrologueDirectives.has(statement.expression.text))
                            continue;
                        seenPrologueDirectives.add(statement.expression.text);
                        (directives || (directives = [])).push({
                            pos: statement.pos,
                            end: statement.end,
                            expression: {
                                pos: statement.expression.pos,
                                end: statement.expression.end,
                                text: statement.expression.text
                            }
                        });
                        end = end < statement.end ? statement.end : end;
                    }
                    if (directives)
                        (prologues || (prologues = [])).push({ file: index, text: sourceFile.text.substring(0, end), directives });
                }
                return prologues;
            }
            function emitShebangIfNeeded(sourceFileOrBundle) {
                if (isSourceFile(sourceFileOrBundle) || isUnparsedSource(sourceFileOrBundle)) {
                    const shebang = getShebang(sourceFileOrBundle.text);
                    if (shebang) {
                        writeComment(shebang);
                        writeLine();
                        return true;
                    }
                }
                else {
                    for (const prepend of sourceFileOrBundle.prepends) {
                        Debug.assertNode(prepend, isUnparsedSource);
                        if (emitShebangIfNeeded(prepend)) {
                            return true;
                        }
                    }
                    for (const sourceFile of sourceFileOrBundle.sourceFiles) {
                        if (emitShebangIfNeeded(sourceFile)) {
                            return true;
                        }
                    }
                }
            }
            function emitNodeWithWriter(node, writer2) {
                if (!node)
                    return;
                const savedWrite = write;
                write = writer2;
                emit(node);
                write = savedWrite;
            }
            function emitDecoratorsAndModifiers(node, modifiers, allowDecorators) {
                if (modifiers == null ? void 0 : modifiers.length) {
                    if (every(modifiers, isModifier)) {
                        return emitModifierList(node, modifiers);
                    }
                    if (every(modifiers, isDecorator)) {
                        if (allowDecorators) {
                            return emitDecoratorList(node, modifiers);
                        }
                        return node.pos;
                    }
                    onBeforeEmitNodeArray == null ? void 0 : onBeforeEmitNodeArray(modifiers);
                    let lastMode;
                    let mode;
                    let start = 0;
                    let pos = 0;
                    let lastModifier;
                    while (start < modifiers.length) {
                        while (pos < modifiers.length) {
                            lastModifier = modifiers[pos];
                            mode = isDecorator(lastModifier) ? "decorators" : "modifiers";
                            if (lastMode === void 0) {
                                lastMode = mode;
                            }
                            else if (mode !== lastMode) {
                                break;
                            }
                            pos++;
                        }
                        const textRange = { pos: -1, end: -1 };
                        if (start === 0)
                            textRange.pos = modifiers.pos;
                        if (pos === modifiers.length - 1)
                            textRange.end = modifiers.end;
                        if (lastMode === "modifiers" || allowDecorators) {
                            emitNodeListItems(emit, node, modifiers, lastMode === "modifiers" ? 2359808 /* Modifiers */ : 2146305 /* Decorators */, 
                            /*parenthesizerRule*/
                            void 0, start, pos - start, 
                            /*hasTrailingComma*/
                            false, textRange);
                        }
                        start = pos;
                        lastMode = mode;
                        pos++;
                    }
                    onAfterEmitNodeArray == null ? void 0 : onAfterEmitNodeArray(modifiers);
                    if (lastModifier && !positionIsSynthesized(lastModifier.end)) {
                        return lastModifier.end;
                    }
                }
                return node.pos;
            }
            function emitModifierList(node, modifiers) {
                emitList(node, modifiers, 2359808 /* Modifiers */);
                const lastModifier = lastOrUndefined(modifiers);
                return lastModifier && !positionIsSynthesized(lastModifier.end) ? lastModifier.end : node.pos;
            }
            function emitTypeAnnotation(node) {
                if (node) {
                    writePunctuation(":");
                    writeSpace();
                    emit(node);
                }
            }
            function emitInitializer(node, equalCommentStartPos, container, parenthesizerRule) {
                if (node) {
                    writeSpace();
                    emitTokenWithComment(63 /* EqualsToken */, equalCommentStartPos, writeOperator, container);
                    writeSpace();
                    emitExpression(node, parenthesizerRule);
                }
            }
            function emitNodeWithPrefix(prefix, prefixWriter, node, emit2) {
                if (node) {
                    prefixWriter(prefix);
                    emit2(node);
                }
            }
            function emitWithLeadingSpace(node) {
                if (node) {
                    writeSpace();
                    emit(node);
                }
            }
            function emitExpressionWithLeadingSpace(node, parenthesizerRule) {
                if (node) {
                    writeSpace();
                    emitExpression(node, parenthesizerRule);
                }
            }
            function emitWithTrailingSpace(node) {
                if (node) {
                    emit(node);
                    writeSpace();
                }
            }
            function emitEmbeddedStatement(parent2, node) {
                if (isBlock(node) || getEmitFlags(parent2) & 1 /* SingleLine */) {
                    writeSpace();
                    emit(node);
                }
                else {
                    writeLine();
                    increaseIndent();
                    if (isEmptyStatement(node)) {
                        pipelineEmit(5 /* EmbeddedStatement */, node);
                    }
                    else {
                        emit(node);
                    }
                    decreaseIndent();
                }
            }
            function emitDecoratorList(parentNode, decorators) {
                emitList(parentNode, decorators, 2146305 /* Decorators */);
                const lastDecorator = lastOrUndefined(decorators);
                return lastDecorator && !positionIsSynthesized(lastDecorator.end) ? lastDecorator.end : parentNode.pos;
            }
            function emitTypeArguments(parentNode, typeArguments) {
                emitList(parentNode, typeArguments, 53776 /* TypeArguments */, typeArgumentParenthesizerRuleSelector);
            }
            function emitTypeParameters(parentNode, typeParameters) {
                if (isFunctionLike(parentNode) && parentNode.typeArguments) {
                    return emitTypeArguments(parentNode, parentNode.typeArguments);
                }
                emitList(parentNode, typeParameters, 53776 /* TypeParameters */);
            }
            function emitParameters(parentNode, parameters) {
                emitList(parentNode, parameters, 2576 /* Parameters */);
            }
            function canEmitSimpleArrowHead(parentNode, parameters) {
                const parameter = singleOrUndefined(parameters);
                return parameter && parameter.pos === parentNode.pos && isArrowFunction(parentNode) && !parentNode.type && !some(parentNode.modifiers) && !some(parentNode.typeParameters) && !some(parameter.modifiers) && !parameter.dotDotDotToken && !parameter.questionToken && !parameter.type && !parameter.initializer && isIdentifier(parameter.name);
            }
            function emitParametersForArrow(parentNode, parameters) {
                if (canEmitSimpleArrowHead(parentNode, parameters)) {
                    emitList(parentNode, parameters, 2576 /* Parameters */ & ~2048 /* Parenthesis */);
                }
                else {
                    emitParameters(parentNode, parameters);
                }
            }
            function emitParametersForIndexSignature(parentNode, parameters) {
                emitList(parentNode, parameters, 8848 /* IndexSignatureParameters */);
            }
            function writeDelimiter(format) {
                switch (format & 60 /* DelimitersMask */) {
                    case 0 /* None */:
                        break;
                    case 16 /* CommaDelimited */:
                        writePunctuation(",");
                        break;
                    case 4 /* BarDelimited */:
                        writeSpace();
                        writePunctuation("|");
                        break;
                    case 32 /* AsteriskDelimited */:
                        writeSpace();
                        writePunctuation("*");
                        writeSpace();
                        break;
                    case 8 /* AmpersandDelimited */:
                        writeSpace();
                        writePunctuation("&");
                        break;
                }
            }
            function emitList(parentNode, children, format, parenthesizerRule, start, count) {
                emitNodeList(emit, parentNode, children, format | (parentNode && getEmitFlags(parentNode) & 2 /* MultiLine */ ? 65536 /* PreferNewLine */ : 0), parenthesizerRule, start, count);
            }
            function emitExpressionList(parentNode, children, format, parenthesizerRule, start, count) {
                emitNodeList(emitExpression, parentNode, children, format, parenthesizerRule, start, count);
            }
            function emitNodeList(emit2, parentNode, children, format, parenthesizerRule, start = 0, count = children ? children.length - start : 0) {
                const isUndefined = children === void 0;
                if (isUndefined && format & 16384 /* OptionalIfUndefined */) {
                    return;
                }
                const isEmpty = children === void 0 || start >= children.length || count === 0;
                if (isEmpty && format & 32768 /* OptionalIfEmpty */) {
                    onBeforeEmitNodeArray == null ? void 0 : onBeforeEmitNodeArray(children);
                    onAfterEmitNodeArray == null ? void 0 : onAfterEmitNodeArray(children);
                    return;
                }
                if (format & 15360 /* BracketsMask */) {
                    writePunctuation(getOpeningBracket(format));
                    if (isEmpty && children) {
                        emitTrailingCommentsOfPosition(children.pos, 
                        /*prefixSpace*/
                        true);
                    }
                }
                onBeforeEmitNodeArray == null ? void 0 : onBeforeEmitNodeArray(children);
                if (isEmpty) {
                    if (format & 1 /* MultiLine */ && !(preserveSourceNewlines && (!parentNode || currentSourceFile && rangeIsOnSingleLine(parentNode, currentSourceFile)))) {
                        writeLine();
                    }
                    else if (format & 256 /* SpaceBetweenBraces */ && !(format & 524288 /* NoSpaceIfEmpty */)) {
                        writeSpace();
                    }
                }
                else {
                    emitNodeListItems(emit2, parentNode, children, format, parenthesizerRule, start, count, children.hasTrailingComma, children);
                }
                onAfterEmitNodeArray == null ? void 0 : onAfterEmitNodeArray(children);
                if (format & 15360 /* BracketsMask */) {
                    if (isEmpty && children) {
                        emitLeadingCommentsOfPosition(children.end);
                    }
                    writePunctuation(getClosingBracket(format));
                }
            }
            function emitNodeListItems(emit2, parentNode, children, format, parenthesizerRule, start, count, hasTrailingComma, childrenTextRange) {
                const mayEmitInterveningComments = (format & 262144 /* NoInterveningComments */) === 0;
                let shouldEmitInterveningComments = mayEmitInterveningComments;
                const leadingLineTerminatorCount = getLeadingLineTerminatorCount(parentNode, children[start], format);
                if (leadingLineTerminatorCount) {
                    writeLine(leadingLineTerminatorCount);
                    shouldEmitInterveningComments = false;
                }
                else if (format & 256 /* SpaceBetweenBraces */) {
                    writeSpace();
                }
                if (format & 128 /* Indented */) {
                    increaseIndent();
                }
                const emitListItem = getEmitListItem(emit2, parenthesizerRule);
                let previousSibling;
                let previousSourceFileTextKind;
                let shouldDecreaseIndentAfterEmit = false;
                for (let i = 0; i < count; i++) {
                    const child = children[start + i];
                    if (format & 32 /* AsteriskDelimited */) {
                        writeLine();
                        writeDelimiter(format);
                    }
                    else if (previousSibling) {
                        if (format & 60 /* DelimitersMask */ && previousSibling.end !== (parentNode ? parentNode.end : -1)) {
                            const previousSiblingEmitFlags = getEmitFlags(previousSibling);
                            if (!(previousSiblingEmitFlags & 2048 /* NoTrailingComments */)) {
                                emitLeadingCommentsOfPosition(previousSibling.end);
                            }
                        }
                        writeDelimiter(format);
                        recordBundleFileInternalSectionEnd(previousSourceFileTextKind);
                        const separatingLineTerminatorCount = getSeparatingLineTerminatorCount(previousSibling, child, format);
                        if (separatingLineTerminatorCount > 0) {
                            if ((format & (3 /* LinesMask */ | 128 /* Indented */)) === 0 /* SingleLine */) {
                                increaseIndent();
                                shouldDecreaseIndentAfterEmit = true;
                            }
                            writeLine(separatingLineTerminatorCount);
                            shouldEmitInterveningComments = false;
                        }
                        else if (previousSibling && format & 512 /* SpaceBetweenSiblings */) {
                            writeSpace();
                        }
                    }
                    previousSourceFileTextKind = recordBundleFileInternalSectionStart(child);
                    if (shouldEmitInterveningComments) {
                        const commentRange = getCommentRange(child);
                        emitTrailingCommentsOfPosition(commentRange.pos);
                    }
                    else {
                        shouldEmitInterveningComments = mayEmitInterveningComments;
                    }
                    nextListElementPos = child.pos;
                    emitListItem(child, emit2, parenthesizerRule, i);
                    if (shouldDecreaseIndentAfterEmit) {
                        decreaseIndent();
                        shouldDecreaseIndentAfterEmit = false;
                    }
                    previousSibling = child;
                }
                const emitFlags = previousSibling ? getEmitFlags(previousSibling) : 0;
                const skipTrailingComments = commentsDisabled || !!(emitFlags & 2048 /* NoTrailingComments */);
                const emitTrailingComma = hasTrailingComma && format & 64 /* AllowTrailingComma */ && format & 16 /* CommaDelimited */;
                if (emitTrailingComma) {
                    if (previousSibling && !skipTrailingComments) {
                        emitTokenWithComment(27 /* CommaToken */, previousSibling.end, writePunctuation, previousSibling);
                    }
                    else {
                        writePunctuation(",");
                    }
                }
                if (previousSibling && (parentNode ? parentNode.end : -1) !== previousSibling.end && format & 60 /* DelimitersMask */ && !skipTrailingComments) {
                    emitLeadingCommentsOfPosition(emitTrailingComma && (childrenTextRange == null ? void 0 : childrenTextRange.end) ? childrenTextRange.end : previousSibling.end);
                }
                if (format & 128 /* Indented */) {
                    decreaseIndent();
                }
                recordBundleFileInternalSectionEnd(previousSourceFileTextKind);
                const closingLineTerminatorCount = getClosingLineTerminatorCount(parentNode, children[start + count - 1], format, childrenTextRange);
                if (closingLineTerminatorCount) {
                    writeLine(closingLineTerminatorCount);
                }
                else if (format & (2097152 /* SpaceAfterList */ | 256 /* SpaceBetweenBraces */)) {
                    writeSpace();
                }
            }
            function writeLiteral(s) {
                writer.writeLiteral(s);
            }
            function writeStringLiteral(s) {
                writer.writeStringLiteral(s);
            }
            function writeBase(s) {
                writer.write(s);
            }
            function writeSymbol(s, sym) {
                writer.writeSymbol(s, sym);
            }
            function writePunctuation(s) {
                writer.writePunctuation(s);
            }
            function writeTrailingSemicolon() {
                writer.writeTrailingSemicolon(";");
            }
            function writeKeyword(s) {
                writer.writeKeyword(s);
            }
            function writeOperator(s) {
                writer.writeOperator(s);
            }
            function writeParameter(s) {
                writer.writeParameter(s);
            }
            function writeComment(s) {
                writer.writeComment(s);
            }
            function writeSpace() {
                writer.writeSpace(" ");
            }
            function writeProperty(s) {
                writer.writeProperty(s);
            }
            function nonEscapingWrite(s) {
                if (writer.nonEscapingWrite) {
                    writer.nonEscapingWrite(s);
                }
                else {
                    writer.write(s);
                }
            }
            function writeLine(count = 1) {
                for (let i = 0; i < count; i++) {
                    writer.writeLine(i > 0);
                }
            }
            function increaseIndent() {
                writer.increaseIndent();
            }
            function decreaseIndent() {
                writer.decreaseIndent();
            }
            function writeToken(token, pos, writer2, contextNode) {
                return !sourceMapsDisabled ? emitTokenWithSourceMap(contextNode, token, writer2, pos, writeTokenText) : writeTokenText(token, writer2, pos);
            }
            function writeTokenNode(node, writer2) {
                if (onBeforeEmitToken) {
                    onBeforeEmitToken(node);
                }
                writer2(tokenToString(node.kind));
                if (onAfterEmitToken) {
                    onAfterEmitToken(node);
                }
            }
            function writeTokenText(token, writer2, pos) {
                const tokenString = tokenToString(token);
                writer2(tokenString);
                return pos < 0 ? pos : pos + tokenString.length;
            }
            function writeLineOrSpace(parentNode, prevChildNode, nextChildNode) {
                if (getEmitFlags(parentNode) & 1 /* SingleLine */) {
                    writeSpace();
                }
                else if (preserveSourceNewlines) {
                    const lines = getLinesBetweenNodes(parentNode, prevChildNode, nextChildNode);
                    if (lines) {
                        writeLine(lines);
                    }
                    else {
                        writeSpace();
                    }
                }
                else {
                    writeLine();
                }
            }
            function writeLines(text) {
                const lines = text.split(/\r\n?|\n/g);
                const indentation = guessIndentation(lines);
                for (const lineText of lines) {
                    const line = indentation ? lineText.slice(indentation) : lineText;
                    if (line.length) {
                        writeLine();
                        write(line);
                    }
                }
            }
            function writeLinesAndIndent(lineCount, writeSpaceIfNotIndenting) {
                if (lineCount) {
                    increaseIndent();
                    writeLine(lineCount);
                }
                else if (writeSpaceIfNotIndenting) {
                    writeSpace();
                }
            }
            function decreaseIndentIf(value1, value2) {
                if (value1) {
                    decreaseIndent();
                }
                if (value2) {
                    decreaseIndent();
                }
            }
            function getLeadingLineTerminatorCount(parentNode, firstChild, format) {
                if (format & 2 /* PreserveLines */ || preserveSourceNewlines) {
                    if (format & 65536 /* PreferNewLine */) {
                        return 1;
                    }
                    if (firstChild === void 0) {
                        return !parentNode || currentSourceFile && rangeIsOnSingleLine(parentNode, currentSourceFile) ? 0 : 1;
                    }
                    if (firstChild.pos === nextListElementPos) {
                        return 0;
                    }
                    if (firstChild.kind === 11 /* JsxText */) {
                        return 0;
                    }
                    if (currentSourceFile && parentNode && !positionIsSynthesized(parentNode.pos) && !nodeIsSynthesized(firstChild) && (!firstChild.parent || getOriginalNode(firstChild.parent) === getOriginalNode(parentNode))) {
                        if (preserveSourceNewlines) {
                            return getEffectiveLines((includeComments) => getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter(firstChild.pos, parentNode.pos, currentSourceFile, includeComments));
                        }
                        return rangeStartPositionsAreOnSameLine(parentNode, firstChild, currentSourceFile) ? 0 : 1;
                    }
                    if (synthesizedNodeStartsOnNewLine(firstChild, format)) {
                        return 1;
                    }
                }
                return format & 1 /* MultiLine */ ? 1 : 0;
            }
            function getSeparatingLineTerminatorCount(previousNode, nextNode, format) {
                if (format & 2 /* PreserveLines */ || preserveSourceNewlines) {
                    if (previousNode === void 0 || nextNode === void 0) {
                        return 0;
                    }
                    if (nextNode.kind === 11 /* JsxText */) {
                        return 0;
                    }
                    else if (currentSourceFile && !nodeIsSynthesized(previousNode) && !nodeIsSynthesized(nextNode)) {
                        if (preserveSourceNewlines && siblingNodePositionsAreComparable(previousNode, nextNode)) {
                            return getEffectiveLines((includeComments) => getLinesBetweenRangeEndAndRangeStart(previousNode, nextNode, currentSourceFile, includeComments));
                        }
                        else if (!preserveSourceNewlines && originalNodesHaveSameParent(previousNode, nextNode)) {
                            return rangeEndIsOnSameLineAsRangeStart(previousNode, nextNode, currentSourceFile) ? 0 : 1;
                        }
                        return format & 65536 /* PreferNewLine */ ? 1 : 0;
                    }
                    else if (synthesizedNodeStartsOnNewLine(previousNode, format) || synthesizedNodeStartsOnNewLine(nextNode, format)) {
                        return 1;
                    }
                }
                else if (getStartsOnNewLine(nextNode)) {
                    return 1;
                }
                return format & 1 /* MultiLine */ ? 1 : 0;
            }
            function getClosingLineTerminatorCount(parentNode, lastChild, format, childrenTextRange) {
                if (format & 2 /* PreserveLines */ || preserveSourceNewlines) {
                    if (format & 65536 /* PreferNewLine */) {
                        return 1;
                    }
                    if (lastChild === void 0) {
                        return !parentNode || currentSourceFile && rangeIsOnSingleLine(parentNode, currentSourceFile) ? 0 : 1;
                    }
                    if (currentSourceFile && parentNode && !positionIsSynthesized(parentNode.pos) && !nodeIsSynthesized(lastChild) && (!lastChild.parent || lastChild.parent === parentNode)) {
                        if (preserveSourceNewlines) {
                            const end = childrenTextRange && !positionIsSynthesized(childrenTextRange.end) ? childrenTextRange.end : lastChild.end;
                            return getEffectiveLines((includeComments) => getLinesBetweenPositionAndNextNonWhitespaceCharacter(end, parentNode.end, currentSourceFile, includeComments));
                        }
                        return rangeEndPositionsAreOnSameLine(parentNode, lastChild, currentSourceFile) ? 0 : 1;
                    }
                    if (synthesizedNodeStartsOnNewLine(lastChild, format)) {
                        return 1;
                    }
                }
                if (format & 1 /* MultiLine */ && !(format & 131072 /* NoTrailingNewLine */)) {
                    return 1;
                }
                return 0;
            }
            function getEffectiveLines(getLineDifference) {
                Debug.assert(!!preserveSourceNewlines);
                const lines = getLineDifference(
                /*includeComments*/
                true);
                if (lines === 0) {
                    return getLineDifference(
                    /*includeComments*/
                    false);
                }
                return lines;
            }
            function writeLineSeparatorsAndIndentBefore(node, parent2) {
                const leadingNewlines = preserveSourceNewlines && getLeadingLineTerminatorCount(parent2, node, 0 /* None */);
                if (leadingNewlines) {
                    writeLinesAndIndent(leadingNewlines, 
                    /*writeSpaceIfNotIndenting*/
                    false);
                }
                return !!leadingNewlines;
            }
            function writeLineSeparatorsAfter(node, parent2) {
                const trailingNewlines = preserveSourceNewlines && getClosingLineTerminatorCount(parent2, node, 0 /* None */, 
                /*childrenTextRange*/
                void 0);
                if (trailingNewlines) {
                    writeLine(trailingNewlines);
                }
            }
            function synthesizedNodeStartsOnNewLine(node, format) {
                if (nodeIsSynthesized(node)) {
                    const startsOnNewLine = getStartsOnNewLine(node);
                    if (startsOnNewLine === void 0) {
                        return (format & 65536 /* PreferNewLine */) !== 0;
                    }
                    return startsOnNewLine;
                }
                return (format & 65536 /* PreferNewLine */) !== 0;
            }
            function getLinesBetweenNodes(parent2, node1, node2) {
                if (getEmitFlags(parent2) & 262144 /* NoIndentation */) {
                    return 0;
                }
                parent2 = skipSynthesizedParentheses(parent2);
                node1 = skipSynthesizedParentheses(node1);
                node2 = skipSynthesizedParentheses(node2);
                if (getStartsOnNewLine(node2)) {
                    return 1;
                }
                if (currentSourceFile && !nodeIsSynthesized(parent2) && !nodeIsSynthesized(node1) && !nodeIsSynthesized(node2)) {
                    if (preserveSourceNewlines) {
                        return getEffectiveLines((includeComments) => getLinesBetweenRangeEndAndRangeStart(node1, node2, currentSourceFile, includeComments));
                    }
                    return rangeEndIsOnSameLineAsRangeStart(node1, node2, currentSourceFile) ? 0 : 1;
                }
                return 0;
            }
            function isEmptyBlock(block) {
                return block.statements.length === 0 && (!currentSourceFile || rangeEndIsOnSameLineAsRangeStart(block, block, currentSourceFile));
            }
            function skipSynthesizedParentheses(node) {
                while (node.kind === 214 /* ParenthesizedExpression */ && nodeIsSynthesized(node)) {
                    node = node.expression;
                }
                return node;
            }
            function getTextOfNode2(node, includeTrivia) {
                if (isGeneratedIdentifier(node) || isGeneratedPrivateIdentifier(node)) {
                    return generateName(node);
                }
                if (isStringLiteral(node) && node.textSourceNode) {
                    return getTextOfNode2(node.textSourceNode, includeTrivia);
                }
                const sourceFile = currentSourceFile;
                const canUseSourceFile = !!sourceFile && !!node.parent && !nodeIsSynthesized(node);
                if (isMemberName(node)) {
                    if (!canUseSourceFile || getSourceFileOfNode(node) !== getOriginalNode(sourceFile)) {
                        return idText(node);
                    }
                }
                else {
                    Debug.assertNode(node, isLiteralExpression);
                    if (!canUseSourceFile) {
                        return node.text;
                    }
                }
                return getSourceTextOfNodeFromSourceFile(sourceFile, node, includeTrivia);
            }
            function getLiteralTextOfNode(node, neverAsciiEscape, jsxAttributeEscape) {
                if (node.kind === 10 /* StringLiteral */ && node.textSourceNode) {
                    const textSourceNode = node.textSourceNode;
                    if (isIdentifier(textSourceNode) || isPrivateIdentifier(textSourceNode) || isNumericLiteral(textSourceNode)) {
                        const text = isNumericLiteral(textSourceNode) ? textSourceNode.text : getTextOfNode2(textSourceNode);
                        return jsxAttributeEscape ? `"${escapeJsxAttributeString(text)}"` : neverAsciiEscape || getEmitFlags(node) & 33554432 /* NoAsciiEscaping */ ? `"${escapeString(text)}"` : `"${escapeNonAsciiString(text)}"`;
                    }
                    else {
                        return getLiteralTextOfNode(textSourceNode, neverAsciiEscape, jsxAttributeEscape);
                    }
                }
                const flags = (neverAsciiEscape ? 1 /* NeverAsciiEscape */ : 0) | (jsxAttributeEscape ? 2 /* JsxAttributeEscape */ : 0) | (printerOptions.terminateUnterminatedLiterals ? 4 /* TerminateUnterminatedLiterals */ : 0) | (printerOptions.target && printerOptions.target === 99 /* ESNext */ ? 8 /* AllowNumericSeparator */ : 0);
                return getLiteralText(node, currentSourceFile, flags);
            }
            function pushNameGenerationScope(node) {
                if (node && getEmitFlags(node) & 1048576 /* ReuseTempVariableScope */) {
                    return;
                }
                tempFlagsStack.push(tempFlags);
                tempFlags = 0 /* Auto */;
                formattedNameTempFlagsStack.push(formattedNameTempFlags);
                formattedNameTempFlags = void 0;
                reservedNamesStack.push(reservedNames);
            }
            function popNameGenerationScope(node) {
                if (node && getEmitFlags(node) & 1048576 /* ReuseTempVariableScope */) {
                    return;
                }
                tempFlags = tempFlagsStack.pop();
                formattedNameTempFlags = formattedNameTempFlagsStack.pop();
                reservedNames = reservedNamesStack.pop();
            }
            function reserveNameInNestedScopes(name) {
                if (!reservedNames || reservedNames === lastOrUndefined(reservedNamesStack)) {
                    reservedNames = /* @__PURE__ */ new Set();
                }
                reservedNames.add(name);
            }
            function pushPrivateNameGenerationScope(newPrivateNameTempFlags, newReservedMemberNames) {
                privateNameTempFlagsStack.push(privateNameTempFlags);
                privateNameTempFlags = newPrivateNameTempFlags;
                reservedPrivateNamesStack.push(reservedNames);
                reservedPrivateNames = newReservedMemberNames;
            }
            function popPrivateNameGenerationScope() {
                privateNameTempFlags = privateNameTempFlagsStack.pop();
                reservedPrivateNames = reservedPrivateNamesStack.pop();
            }
            function reservePrivateNameInNestedScopes(name) {
                if (!reservedPrivateNames || reservedPrivateNames === lastOrUndefined(reservedPrivateNamesStack)) {
                    reservedPrivateNames = /* @__PURE__ */ new Set();
                }
                reservedPrivateNames.add(name);
            }
            function generateNames(node) {
                if (!node)
                    return;
                switch (node.kind) {
                    case 238 /* Block */:
                        forEach(node.statements, generateNames);
                        break;
                    case 253 /* LabeledStatement */:
                    case 251 /* WithStatement */:
                    case 243 /* DoStatement */:
                    case 244 /* WhileStatement */:
                        generateNames(node.statement);
                        break;
                    case 242 /* IfStatement */:
                        generateNames(node.thenStatement);
                        generateNames(node.elseStatement);
                        break;
                    case 245 /* ForStatement */:
                    case 247 /* ForOfStatement */:
                    case 246 /* ForInStatement */:
                        generateNames(node.initializer);
                        generateNames(node.statement);
                        break;
                    case 252 /* SwitchStatement */:
                        generateNames(node.caseBlock);
                        break;
                    case 266 /* CaseBlock */:
                        forEach(node.clauses, generateNames);
                        break;
                    case 292 /* CaseClause */:
                    case 293 /* DefaultClause */:
                        forEach(node.statements, generateNames);
                        break;
                    case 255 /* TryStatement */:
                        generateNames(node.tryBlock);
                        generateNames(node.catchClause);
                        generateNames(node.finallyBlock);
                        break;
                    case 295 /* CatchClause */:
                        generateNames(node.variableDeclaration);
                        generateNames(node.block);
                        break;
                    case 240 /* VariableStatement */:
                        generateNames(node.declarationList);
                        break;
                    case 258 /* VariableDeclarationList */:
                        forEach(node.declarations, generateNames);
                        break;
                    case 257 /* VariableDeclaration */:
                    case 166 /* Parameter */:
                    case 205 /* BindingElement */:
                    case 260 /* ClassDeclaration */:
                        generateNameIfNeeded(node.name);
                        break;
                    case 259 /* FunctionDeclaration */:
                        generateNameIfNeeded(node.name);
                        if (getEmitFlags(node) & 1048576 /* ReuseTempVariableScope */) {
                            forEach(node.parameters, generateNames);
                            generateNames(node.body);
                        }
                        break;
                    case 203 /* ObjectBindingPattern */:
                    case 204 /* ArrayBindingPattern */:
                        forEach(node.elements, generateNames);
                        break;
                    case 269 /* ImportDeclaration */:
                        generateNames(node.importClause);
                        break;
                    case 270 /* ImportClause */:
                        generateNameIfNeeded(node.name);
                        generateNames(node.namedBindings);
                        break;
                    case 271 /* NamespaceImport */:
                        generateNameIfNeeded(node.name);
                        break;
                    case 277 /* NamespaceExport */:
                        generateNameIfNeeded(node.name);
                        break;
                    case 272 /* NamedImports */:
                        forEach(node.elements, generateNames);
                        break;
                    case 273 /* ImportSpecifier */:
                        generateNameIfNeeded(node.propertyName || node.name);
                        break;
                }
            }
            function generateMemberNames(node) {
                if (!node)
                    return;
                switch (node.kind) {
                    case 299 /* PropertyAssignment */:
                    case 300 /* ShorthandPropertyAssignment */:
                    case 169 /* PropertyDeclaration */:
                    case 171 /* MethodDeclaration */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        generateNameIfNeeded(node.name);
                        break;
                }
            }
            function generateNameIfNeeded(name) {
                if (name) {
                    if (isGeneratedIdentifier(name) || isGeneratedPrivateIdentifier(name)) {
                        generateName(name);
                    }
                    else if (isBindingPattern(name)) {
                        generateNames(name);
                    }
                }
            }
            function generateName(name) {
                const autoGenerate = name.emitNode.autoGenerate;
                if ((autoGenerate.flags & 7 /* KindMask */) === 4 /* Node */) {
                    return generateNameCached(getNodeForGeneratedName(name), isPrivateIdentifier(name), autoGenerate.flags, autoGenerate.prefix, autoGenerate.suffix);
                }
                else {
                    const autoGenerateId = autoGenerate.id;
                    return autoGeneratedIdToGeneratedName[autoGenerateId] || (autoGeneratedIdToGeneratedName[autoGenerateId] = makeName(name));
                }
            }
            function generateNameCached(node, privateName, flags, prefix, suffix) {
                const nodeId = getNodeId(node);
                const cache = privateName ? nodeIdToGeneratedPrivateName : nodeIdToGeneratedName;
                return cache[nodeId] || (cache[nodeId] = generateNameForNode(node, privateName, flags != null ? flags : 0 /* None */, formatGeneratedNamePart(prefix, generateName), formatGeneratedNamePart(suffix)));
            }
            function isUniqueName(name, privateName) {
                return isFileLevelUniqueName2(name, privateName) && !isReservedName(name, privateName) && !generatedNames.has(name);
            }
            function isReservedName(name, privateName) {
                return privateName ? !!(reservedPrivateNames == null ? void 0 : reservedPrivateNames.has(name)) : !!(reservedNames == null ? void 0 : reservedNames.has(name));
            }
            function isFileLevelUniqueName2(name, _isPrivate) {
                return currentSourceFile ? isFileLevelUniqueName(currentSourceFile, name, hasGlobalName) : true;
            }
            function isUniqueLocalName(name, container) {
                for (let node = container; node && isNodeDescendantOf(node, container); node = node.nextContainer) {
                    if (canHaveLocals(node) && node.locals) {
                        const local = node.locals.get(escapeLeadingUnderscores(name));
                        if (local && local.flags & (111551 /* Value */ | 1048576 /* ExportValue */ | 2097152 /* Alias */)) {
                            return false;
                        }
                    }
                }
                return true;
            }
            function getTempFlags(formattedNameKey) {
                var _a2;
                switch (formattedNameKey) {
                    case "":
                        return tempFlags;
                    case "#":
                        return privateNameTempFlags;
                    default:
                        return (_a2 = formattedNameTempFlags == null ? void 0 : formattedNameTempFlags.get(formattedNameKey)) != null ? _a2 : 0 /* Auto */;
                }
            }
            function setTempFlags(formattedNameKey, flags) {
                switch (formattedNameKey) {
                    case "":
                        tempFlags = flags;
                        break;
                    case "#":
                        privateNameTempFlags = flags;
                        break;
                    default:
                        formattedNameTempFlags != null ? formattedNameTempFlags : formattedNameTempFlags = /* @__PURE__ */ new Map();
                        formattedNameTempFlags.set(formattedNameKey, flags);
                        break;
                }
            }
            function makeTempVariableName(flags, reservedInNestedScopes, privateName, prefix, suffix) {
                if (prefix.length > 0 && prefix.charCodeAt(0) === 35 /* hash */) {
                    prefix = prefix.slice(1);
                }
                const key = formatGeneratedName(privateName, prefix, "", suffix);
                let tempFlags2 = getTempFlags(key);
                if (flags && !(tempFlags2 & flags)) {
                    const name = flags === 268435456 /* _i */ ? "_i" : "_n";
                    const fullName = formatGeneratedName(privateName, prefix, name, suffix);
                    if (isUniqueName(fullName, privateName)) {
                        tempFlags2 |= flags;
                        if (privateName) {
                            reservePrivateNameInNestedScopes(fullName);
                        }
                        else if (reservedInNestedScopes) {
                            reserveNameInNestedScopes(fullName);
                        }
                        setTempFlags(key, tempFlags2);
                        return fullName;
                    }
                }
                while (true) {
                    const count = tempFlags2 & 268435455 /* CountMask */;
                    tempFlags2++;
                    if (count !== 8 && count !== 13) {
                        const name = count < 26 ? "_" + String.fromCharCode(97 /* a */ + count) : "_" + (count - 26);
                        const fullName = formatGeneratedName(privateName, prefix, name, suffix);
                        if (isUniqueName(fullName, privateName)) {
                            if (privateName) {
                                reservePrivateNameInNestedScopes(fullName);
                            }
                            else if (reservedInNestedScopes) {
                                reserveNameInNestedScopes(fullName);
                            }
                            setTempFlags(key, tempFlags2);
                            return fullName;
                        }
                    }
                }
            }
            function makeUniqueName2(baseName, checkFn = isUniqueName, optimistic, scoped, privateName, prefix, suffix) {
                if (baseName.length > 0 && baseName.charCodeAt(0) === 35 /* hash */) {
                    baseName = baseName.slice(1);
                }
                if (prefix.length > 0 && prefix.charCodeAt(0) === 35 /* hash */) {
                    prefix = prefix.slice(1);
                }
                if (optimistic) {
                    const fullName = formatGeneratedName(privateName, prefix, baseName, suffix);
                    if (checkFn(fullName, privateName)) {
                        if (privateName) {
                            reservePrivateNameInNestedScopes(fullName);
                        }
                        else if (scoped) {
                            reserveNameInNestedScopes(fullName);
                        }
                        else {
                            generatedNames.add(fullName);
                        }
                        return fullName;
                    }
                }
                if (baseName.charCodeAt(baseName.length - 1) !== 95 /* _ */) {
                    baseName += "_";
                }
                let i = 1;
                while (true) {
                    const fullName = formatGeneratedName(privateName, prefix, baseName + i, suffix);
                    if (checkFn(fullName, privateName)) {
                        if (privateName) {
                            reservePrivateNameInNestedScopes(fullName);
                        }
                        else if (scoped) {
                            reserveNameInNestedScopes(fullName);
                        }
                        else {
                            generatedNames.add(fullName);
                        }
                        return fullName;
                    }
                    i++;
                }
            }
            function makeFileLevelOptimisticUniqueName(name) {
                return makeUniqueName2(name, isFileLevelUniqueName2, 
                /*optimistic*/
                true, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForModuleOrEnum(node) {
                const name = getTextOfNode2(node.name);
                return isUniqueLocalName(name, tryCast(node, canHaveLocals)) ? name : makeUniqueName2(name, isUniqueName, 
                /*optimistic*/
                false, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForImportOrExportDeclaration(node) {
                const expr = getExternalModuleName(node);
                const baseName = isStringLiteral(expr) ? makeIdentifierFromModuleName(expr.text) : "module";
                return makeUniqueName2(baseName, isUniqueName, 
                /*optimistic*/
                false, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForExportDefault() {
                return makeUniqueName2("default", isUniqueName, 
                /*optimistic*/
                false, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForClassExpression() {
                return makeUniqueName2("class", isUniqueName, 
                /*optimistic*/
                false, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForMethodOrAccessor(node, privateName, prefix, suffix) {
                if (isIdentifier(node.name)) {
                    return generateNameCached(node.name, privateName);
                }
                return makeTempVariableName(0 /* Auto */, 
                /*reservedInNestedScopes*/
                false, privateName, prefix, suffix);
            }
            function generateNameForNode(node, privateName, flags, prefix, suffix) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                    case 80 /* PrivateIdentifier */:
                        return makeUniqueName2(getTextOfNode2(node), isUniqueName, !!(flags & 16 /* Optimistic */), !!(flags & 8 /* ReservedInNestedScopes */), privateName, prefix, suffix);
                    case 264 /* ModuleDeclaration */:
                    case 263 /* EnumDeclaration */:
                        Debug.assert(!prefix && !suffix && !privateName);
                        return generateNameForModuleOrEnum(node);
                    case 269 /* ImportDeclaration */:
                    case 275 /* ExportDeclaration */:
                        Debug.assert(!prefix && !suffix && !privateName);
                        return generateNameForImportOrExportDeclaration(node);
                    case 259 /* FunctionDeclaration */:
                    case 260 /* ClassDeclaration */: {
                        Debug.assert(!prefix && !suffix && !privateName);
                        const name = node.name;
                        if (name && !isGeneratedIdentifier(name)) {
                            return generateNameForNode(name, 
                            /*privateName*/
                            false, flags, prefix, suffix);
                        }
                        return generateNameForExportDefault();
                    }
                    case 274 /* ExportAssignment */:
                        Debug.assert(!prefix && !suffix && !privateName);
                        return generateNameForExportDefault();
                    case 228 /* ClassExpression */:
                        Debug.assert(!prefix && !suffix && !privateName);
                        return generateNameForClassExpression();
                    case 171 /* MethodDeclaration */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                        return generateNameForMethodOrAccessor(node, privateName, prefix, suffix);
                    case 164 /* ComputedPropertyName */:
                        return makeTempVariableName(0 /* Auto */, 
                        /*reserveInNestedScopes*/
                        true, privateName, prefix, suffix);
                    default:
                        return makeTempVariableName(0 /* Auto */, 
                        /*reserveInNestedScopes*/
                        false, privateName, prefix, suffix);
                }
            }
            function makeName(name) {
                const autoGenerate = name.emitNode.autoGenerate;
                const prefix = formatGeneratedNamePart(autoGenerate.prefix, generateName);
                const suffix = formatGeneratedNamePart(autoGenerate.suffix);
                switch (autoGenerate.flags & 7 /* KindMask */) {
                    case 1 /* Auto */:
                        return makeTempVariableName(0 /* Auto */, !!(autoGenerate.flags & 8 /* ReservedInNestedScopes */), isPrivateIdentifier(name), prefix, suffix);
                    case 2 /* Loop */:
                        Debug.assertNode(name, isIdentifier);
                        return makeTempVariableName(268435456 /* _i */, !!(autoGenerate.flags & 8 /* ReservedInNestedScopes */), 
                        /*privateName*/
                        false, prefix, suffix);
                    case 3 /* Unique */:
                        return makeUniqueName2(idText(name), autoGenerate.flags & 32 /* FileLevel */ ? isFileLevelUniqueName2 : isUniqueName, !!(autoGenerate.flags & 16 /* Optimistic */), !!(autoGenerate.flags & 8 /* ReservedInNestedScopes */), isPrivateIdentifier(name), prefix, suffix);
                }
                return Debug.fail(`Unsupported GeneratedIdentifierKind: ${Debug.formatEnum(autoGenerate.flags & 7 /* KindMask */, GeneratedIdentifierFlags, 
                /*isFlags*/
                true)}.`);
            }
            function pipelineEmitWithComments(hint, node) {
                const pipelinePhase = getNextPipelinePhase(2 /* Comments */, hint, node);
                const savedContainerPos = containerPos;
                const savedContainerEnd = containerEnd;
                const savedDeclarationListContainerEnd = declarationListContainerEnd;
                emitCommentsBeforeNode(node);
                pipelinePhase(hint, node);
                emitCommentsAfterNode(node, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd);
            }
            function emitCommentsBeforeNode(node) {
                const emitFlags = getEmitFlags(node);
                const commentRange = getCommentRange(node);
                emitLeadingCommentsOfNode(node, emitFlags, commentRange.pos, commentRange.end);
                if (emitFlags & 4096 /* NoNestedComments */) {
                    commentsDisabled = true;
                }
            }
            function emitCommentsAfterNode(node, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd) {
                const emitFlags = getEmitFlags(node);
                const commentRange = getCommentRange(node);
                if (emitFlags & 4096 /* NoNestedComments */) {
                    commentsDisabled = false;
                }
                emitTrailingCommentsOfNode(node, emitFlags, commentRange.pos, commentRange.end, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd);
                const typeNode = getTypeNode(node);
                if (typeNode) {
                    emitTrailingCommentsOfNode(node, emitFlags, typeNode.pos, typeNode.end, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd);
                }
            }
            function emitLeadingCommentsOfNode(node, emitFlags, pos, end) {
                enterComment();
                hasWrittenComment = false;
                const skipLeadingComments = pos < 0 || (emitFlags & 1024 /* NoLeadingComments */) !== 0 || node.kind === 11 /* JsxText */;
                const skipTrailingComments = end < 0 || (emitFlags & 2048 /* NoTrailingComments */) !== 0 || node.kind === 11 /* JsxText */;
                if ((pos > 0 || end > 0) && pos !== end) {
                    if (!skipLeadingComments) {
                        emitLeadingComments(pos, 
                        /*isEmittedNode*/
                        node.kind !== 355 /* NotEmittedStatement */);
                    }
                    if (!skipLeadingComments || pos >= 0 && (emitFlags & 1024 /* NoLeadingComments */) !== 0) {
                        containerPos = pos;
                    }
                    if (!skipTrailingComments || end >= 0 && (emitFlags & 2048 /* NoTrailingComments */) !== 0) {
                        containerEnd = end;
                        if (node.kind === 258 /* VariableDeclarationList */) {
                            declarationListContainerEnd = end;
                        }
                    }
                }
                forEach(getSyntheticLeadingComments(node), emitLeadingSynthesizedComment);
                exitComment();
            }
            function emitTrailingCommentsOfNode(node, emitFlags, pos, end, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd) {
                enterComment();
                const skipTrailingComments = end < 0 || (emitFlags & 2048 /* NoTrailingComments */) !== 0 || node.kind === 11 /* JsxText */;
                forEach(getSyntheticTrailingComments(node), emitTrailingSynthesizedComment);
                if ((pos > 0 || end > 0) && pos !== end) {
                    containerPos = savedContainerPos;
                    containerEnd = savedContainerEnd;
                    declarationListContainerEnd = savedDeclarationListContainerEnd;
                    if (!skipTrailingComments && node.kind !== 355 /* NotEmittedStatement */) {
                        emitTrailingComments(end);
                    }
                }
                exitComment();
            }
            function emitLeadingSynthesizedComment(comment) {
                if (comment.hasLeadingNewline || comment.kind === 2 /* SingleLineCommentTrivia */) {
                    writer.writeLine();
                }
                writeSynthesizedComment(comment);
                if (comment.hasTrailingNewLine || comment.kind === 2 /* SingleLineCommentTrivia */) {
                    writer.writeLine();
                }
                else {
                    writer.writeSpace(" ");
                }
            }
            function emitTrailingSynthesizedComment(comment) {
                if (!writer.isAtStartOfLine()) {
                    writer.writeSpace(" ");
                }
                writeSynthesizedComment(comment);
                if (comment.hasTrailingNewLine) {
                    writer.writeLine();
                }
            }
            function writeSynthesizedComment(comment) {
                const text = formatSynthesizedComment(comment);
                const lineMap = comment.kind === 3 /* MultiLineCommentTrivia */ ? computeLineStarts(text) : void 0;
                writeCommentRange(text, lineMap, writer, 0, text.length, newLine);
            }
            function formatSynthesizedComment(comment) {
                return comment.kind === 3 /* MultiLineCommentTrivia */ ? `/*${comment.text}*/` : `//${comment.text}`;
            }
            function emitBodyWithDetachedComments(node, detachedRange, emitCallback) {
                enterComment();
                const { pos, end } = detachedRange;
                const emitFlags = getEmitFlags(node);
                const skipLeadingComments = pos < 0 || (emitFlags & 1024 /* NoLeadingComments */) !== 0;
                const skipTrailingComments = commentsDisabled || end < 0 || (emitFlags & 2048 /* NoTrailingComments */) !== 0;
                if (!skipLeadingComments) {
                    emitDetachedCommentsAndUpdateCommentsInfo(detachedRange);
                }
                exitComment();
                if (emitFlags & 4096 /* NoNestedComments */ && !commentsDisabled) {
                    commentsDisabled = true;
                    emitCallback(node);
                    commentsDisabled = false;
                }
                else {
                    emitCallback(node);
                }
                enterComment();
                if (!skipTrailingComments) {
                    emitLeadingComments(detachedRange.end, 
                    /*isEmittedNode*/
                    true);
                    if (hasWrittenComment && !writer.isAtStartOfLine()) {
                        writer.writeLine();
                    }
                }
                exitComment();
            }
            function originalNodesHaveSameParent(nodeA, nodeB) {
                nodeA = getOriginalNode(nodeA);
                return nodeA.parent && nodeA.parent === getOriginalNode(nodeB).parent;
            }
            function siblingNodePositionsAreComparable(previousNode, nextNode) {
                if (nextNode.pos < previousNode.end) {
                    return false;
                }
                previousNode = getOriginalNode(previousNode);
                nextNode = getOriginalNode(nextNode);
                const parent2 = previousNode.parent;
                if (!parent2 || parent2 !== nextNode.parent) {
                    return false;
                }
                const parentNodeArray = getContainingNodeArray(previousNode);
                const prevNodeIndex = parentNodeArray == null ? void 0 : parentNodeArray.indexOf(previousNode);
                return prevNodeIndex !== void 0 && prevNodeIndex > -1 && parentNodeArray.indexOf(nextNode) === prevNodeIndex + 1;
            }
            function emitLeadingComments(pos, isEmittedNode) {
                hasWrittenComment = false;
                if (isEmittedNode) {
                    if (pos === 0 && (currentSourceFile == null ? void 0 : currentSourceFile.isDeclarationFile)) {
                        forEachLeadingCommentToEmit(pos, emitNonTripleSlashLeadingComment);
                    }
                    else {
                        forEachLeadingCommentToEmit(pos, emitLeadingComment);
                    }
                }
                else if (pos === 0) {
                    forEachLeadingCommentToEmit(pos, emitTripleSlashLeadingComment);
                }
            }
            function emitTripleSlashLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos) {
                if (isTripleSlashComment(commentPos, commentEnd)) {
                    emitLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos);
                }
            }
            function emitNonTripleSlashLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos) {
                if (!isTripleSlashComment(commentPos, commentEnd)) {
                    emitLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos);
                }
            }
            function shouldWriteComment(text, pos) {
                if (printerOptions.onlyPrintJsDocStyle) {
                    return isJSDocLikeText(text, pos) || isPinnedComment(text, pos);
                }
                return true;
            }
            function emitLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos) {
                if (!currentSourceFile || !shouldWriteComment(currentSourceFile.text, commentPos))
                    return;
                if (!hasWrittenComment) {
                    emitNewLineBeforeLeadingCommentOfPosition(getCurrentLineMap(), writer, rangePos, commentPos);
                    hasWrittenComment = true;
                }
                emitPos(commentPos);
                writeCommentRange(currentSourceFile.text, getCurrentLineMap(), writer, commentPos, commentEnd, newLine);
                emitPos(commentEnd);
                if (hasTrailingNewLine) {
                    writer.writeLine();
                }
                else if (kind === 3 /* MultiLineCommentTrivia */) {
                    writer.writeSpace(" ");
                }
            }
            function emitLeadingCommentsOfPosition(pos) {
                if (commentsDisabled || pos === -1) {
                    return;
                }
                emitLeadingComments(pos, 
                /*isEmittedNode*/
                true);
            }
            function emitTrailingComments(pos) {
                forEachTrailingCommentToEmit(pos, emitTrailingComment);
            }
            function emitTrailingComment(commentPos, commentEnd, _kind, hasTrailingNewLine) {
                if (!currentSourceFile || !shouldWriteComment(currentSourceFile.text, commentPos))
                    return;
                if (!writer.isAtStartOfLine()) {
                    writer.writeSpace(" ");
                }
                emitPos(commentPos);
                writeCommentRange(currentSourceFile.text, getCurrentLineMap(), writer, commentPos, commentEnd, newLine);
                emitPos(commentEnd);
                if (hasTrailingNewLine) {
                    writer.writeLine();
                }
            }
            function emitTrailingCommentsOfPosition(pos, prefixSpace, forceNoNewline) {
                if (commentsDisabled) {
                    return;
                }
                enterComment();
                forEachTrailingCommentToEmit(pos, prefixSpace ? emitTrailingComment : forceNoNewline ? emitTrailingCommentOfPositionNoNewline : emitTrailingCommentOfPosition);
                exitComment();
            }
            function emitTrailingCommentOfPositionNoNewline(commentPos, commentEnd, kind) {
                if (!currentSourceFile)
                    return;
                emitPos(commentPos);
                writeCommentRange(currentSourceFile.text, getCurrentLineMap(), writer, commentPos, commentEnd, newLine);
                emitPos(commentEnd);
                if (kind === 2 /* SingleLineCommentTrivia */) {
                    writer.writeLine();
                }
            }
            function emitTrailingCommentOfPosition(commentPos, commentEnd, _kind, hasTrailingNewLine) {
                if (!currentSourceFile)
                    return;
                emitPos(commentPos);
                writeCommentRange(currentSourceFile.text, getCurrentLineMap(), writer, commentPos, commentEnd, newLine);
                emitPos(commentEnd);
                if (hasTrailingNewLine) {
                    writer.writeLine();
                }
                else {
                    writer.writeSpace(" ");
                }
            }
            function forEachLeadingCommentToEmit(pos, cb) {
                if (currentSourceFile && (containerPos === -1 || pos !== containerPos)) {
                    if (hasDetachedComments(pos)) {
                        forEachLeadingCommentWithoutDetachedComments(cb);
                    }
                    else {
                        forEachLeadingCommentRange(currentSourceFile.text, pos, cb, 
                        /*state*/
                        pos);
                    }
                }
            }
            function forEachTrailingCommentToEmit(end, cb) {
                if (currentSourceFile && (containerEnd === -1 || end !== containerEnd && end !== declarationListContainerEnd)) {
                    forEachTrailingCommentRange(currentSourceFile.text, end, cb);
                }
            }
            function hasDetachedComments(pos) {
                return detachedCommentsInfo !== void 0 && last(detachedCommentsInfo).nodePos === pos;
            }
            function forEachLeadingCommentWithoutDetachedComments(cb) {
                if (!currentSourceFile)
                    return;
                const pos = last(detachedCommentsInfo).detachedCommentEndPos;
                if (detachedCommentsInfo.length - 1) {
                    detachedCommentsInfo.pop();
                }
                else {
                    detachedCommentsInfo = void 0;
                }
                forEachLeadingCommentRange(currentSourceFile.text, pos, cb, 
                /*state*/
                pos);
            }
            function emitDetachedCommentsAndUpdateCommentsInfo(range) {
                const currentDetachedCommentInfo = currentSourceFile && emitDetachedComments(currentSourceFile.text, getCurrentLineMap(), writer, emitComment, range, newLine, commentsDisabled);
                if (currentDetachedCommentInfo) {
                    if (detachedCommentsInfo) {
                        detachedCommentsInfo.push(currentDetachedCommentInfo);
                    }
                    else {
                        detachedCommentsInfo = [currentDetachedCommentInfo];
                    }
                }
            }
            function emitComment(text, lineMap, writer2, commentPos, commentEnd, newLine2) {
                if (!currentSourceFile || !shouldWriteComment(currentSourceFile.text, commentPos))
                    return;
                emitPos(commentPos);
                writeCommentRange(text, lineMap, writer2, commentPos, commentEnd, newLine2);
                emitPos(commentEnd);
            }
            function isTripleSlashComment(commentPos, commentEnd) {
                return !!currentSourceFile && isRecognizedTripleSlashComment(currentSourceFile.text, commentPos, commentEnd);
            }
            function getParsedSourceMap(node) {
                if (node.parsedSourceMap === void 0 && node.sourceMapText !== void 0) {
                    node.parsedSourceMap = tryParseRawSourceMap(node.sourceMapText) || false;
                }
                return node.parsedSourceMap || void 0;
            }
            function pipelineEmitWithSourceMaps(hint, node) {
                const pipelinePhase = getNextPipelinePhase(3 /* SourceMaps */, hint, node);
                emitSourceMapsBeforeNode(node);
                pipelinePhase(hint, node);
                emitSourceMapsAfterNode(node);
            }
            function emitSourceMapsBeforeNode(node) {
                const emitFlags = getEmitFlags(node);
                const sourceMapRange = getSourceMapRange(node);
                if (isUnparsedNode(node)) {
                    Debug.assertIsDefined(node.parent, "UnparsedNodes must have parent pointers");
                    const parsed = getParsedSourceMap(node.parent);
                    if (parsed && sourceMapGenerator) {
                        sourceMapGenerator.appendSourceMap(writer.getLine(), writer.getColumn(), parsed, node.parent.sourceMapPath, node.parent.getLineAndCharacterOfPosition(node.pos), node.parent.getLineAndCharacterOfPosition(node.end));
                    }
                }
                else {
                    const source = sourceMapRange.source || sourceMapSource;
                    if (node.kind !== 355 /* NotEmittedStatement */ && (emitFlags & 32 /* NoLeadingSourceMap */) === 0 && sourceMapRange.pos >= 0) {
                        emitSourcePos(sourceMapRange.source || sourceMapSource, skipSourceTrivia(source, sourceMapRange.pos));
                    }
                    if (emitFlags & 128 /* NoNestedSourceMaps */) {
                        sourceMapsDisabled = true;
                    }
                }
            }
            function emitSourceMapsAfterNode(node) {
                const emitFlags = getEmitFlags(node);
                const sourceMapRange = getSourceMapRange(node);
                if (!isUnparsedNode(node)) {
                    if (emitFlags & 128 /* NoNestedSourceMaps */) {
                        sourceMapsDisabled = false;
                    }
                    if (node.kind !== 355 /* NotEmittedStatement */ && (emitFlags & 64 /* NoTrailingSourceMap */) === 0 && sourceMapRange.end >= 0) {
                        emitSourcePos(sourceMapRange.source || sourceMapSource, sourceMapRange.end);
                    }
                }
            }
            function skipSourceTrivia(source, pos) {
                return source.skipTrivia ? source.skipTrivia(pos) : skipTrivia(source.text, pos);
            }
            function emitPos(pos) {
                if (sourceMapsDisabled || positionIsSynthesized(pos) || isJsonSourceMapSource(sourceMapSource)) {
                    return;
                }
                const { line: sourceLine, character: sourceCharacter } = getLineAndCharacterOfPosition(sourceMapSource, pos);
                sourceMapGenerator.addMapping(writer.getLine(), writer.getColumn(), sourceMapSourceIndex, sourceLine, sourceCharacter, 
                /*nameIndex*/
                void 0);
            }
            function emitSourcePos(source, pos) {
                if (source !== sourceMapSource) {
                    const savedSourceMapSource = sourceMapSource;
                    const savedSourceMapSourceIndex = sourceMapSourceIndex;
                    setSourceMapSource(source);
                    emitPos(pos);
                    resetSourceMapSource(savedSourceMapSource, savedSourceMapSourceIndex);
                }
                else {
                    emitPos(pos);
                }
            }
            function emitTokenWithSourceMap(node, token, writer2, tokenPos, emitCallback) {
                if (sourceMapsDisabled || node && isInJsonFile(node)) {
                    return emitCallback(token, writer2, tokenPos);
                }
                const emitNode = node && node.emitNode;
                const emitFlags = emitNode && emitNode.flags || 0 /* None */;
                const range = emitNode && emitNode.tokenSourceMapRanges && emitNode.tokenSourceMapRanges[token];
                const source = range && range.source || sourceMapSource;
                tokenPos = skipSourceTrivia(source, range ? range.pos : tokenPos);
                if ((emitFlags & 256 /* NoTokenLeadingSourceMaps */) === 0 && tokenPos >= 0) {
                    emitSourcePos(source, tokenPos);
                }
                tokenPos = emitCallback(token, writer2, tokenPos);
                if (range)
                    tokenPos = range.end;
                if ((emitFlags & 512 /* NoTokenTrailingSourceMaps */) === 0 && tokenPos >= 0) {
                    emitSourcePos(source, tokenPos);
                }
                return tokenPos;
            }
            function setSourceMapSource(source) {
                if (sourceMapsDisabled) {
                    return;
                }
                sourceMapSource = source;
                if (source === mostRecentlyAddedSourceMapSource) {
                    sourceMapSourceIndex = mostRecentlyAddedSourceMapSourceIndex;
                    return;
                }
                if (isJsonSourceMapSource(source)) {
                    return;
                }
                sourceMapSourceIndex = sourceMapGenerator.addSource(source.fileName);
                if (printerOptions.inlineSources) {
                    sourceMapGenerator.setSourceContent(sourceMapSourceIndex, source.text);
                }
                mostRecentlyAddedSourceMapSource = source;
                mostRecentlyAddedSourceMapSourceIndex = sourceMapSourceIndex;
            }
            function resetSourceMapSource(source, sourceIndex) {
                sourceMapSource = source;
                sourceMapSourceIndex = sourceIndex;
            }
            function isJsonSourceMapSource(sourceFile) {
                return fileExtensionIs(sourceFile.fileName, ".json" /* Json */);
            }
        }
        function createBracketsMap() {
            const brackets2 = [];
            brackets2[1024 /* Braces */] = ["{", "}"];
            brackets2[2048 /* Parenthesis */] = ["(", ")"];
            brackets2[4096 /* AngleBrackets */] = ["<", ">"];
            brackets2[8192 /* SquareBrackets */] = ["[", "]"];
            return brackets2;
        }
        function getOpeningBracket(format) {
            return brackets[format & 15360 /* BracketsMask */][0];
        }
        function getClosingBracket(format) {
            return brackets[format & 15360 /* BracketsMask */][1];
        }
        function emitListItemNoParenthesizer(node, emit, _parenthesizerRule, _index) {
            emit(node);
        }
        function emitListItemWithParenthesizerRuleSelector(node, emit, parenthesizerRuleSelector, index) {
            emit(node, parenthesizerRuleSelector.select(index));
        }
        function emitListItemWithParenthesizerRule(node, emit, parenthesizerRule, _index) {
            emit(node, parenthesizerRule);
        }
        function getEmitListItem(emit, parenthesizerRule) {
            return emit.length === 1 ? emitListItemNoParenthesizer : typeof parenthesizerRule === "object" ? emitListItemWithParenthesizerRuleSelector : emitListItemWithParenthesizerRule;
        }
        var brackets, notImplementedResolver, createPrinterWithDefaults, createPrinterWithRemoveComments, createPrinterWithRemoveCommentsNeverAsciiEscape, createPrinterWithRemoveCommentsOmitTrailingSemicolon;
        var init_emitter = __esm({
            "src/compiler/emitter.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
                init_ts_performance();
                brackets = createBracketsMap();
                notImplementedResolver = {
                    hasGlobalName: notImplemented,
                    getReferencedExportContainer: notImplemented,
                    getReferencedImportDeclaration: notImplemented,
                    getReferencedDeclarationWithCollidingName: notImplemented,
                    isDeclarationWithCollidingName: notImplemented,
                    isValueAliasDeclaration: notImplemented,
                    isReferencedAliasDeclaration: notImplemented,
                    isTopLevelValueImportEqualsWithEntityName: notImplemented,
                    getNodeCheckFlags: notImplemented,
                    isDeclarationVisible: notImplemented,
                    isLateBound: (_node) => false,
                    collectLinkedAliases: notImplemented,
                    isImplementationOfOverload: notImplemented,
                    isRequiredInitializedParameter: notImplemented,
                    isOptionalUninitializedParameterProperty: notImplemented,
                    isExpandoFunctionDeclaration: notImplemented,
                    getPropertiesOfContainerFunction: notImplemented,
                    createTypeOfDeclaration: notImplemented,
                    createReturnTypeOfSignatureDeclaration: notImplemented,
                    createTypeOfExpression: notImplemented,
                    createLiteralConstValue: notImplemented,
                    isSymbolAccessible: notImplemented,
                    isEntityNameVisible: notImplemented,
                    // Returns the constant value this property access resolves to: notImplemented, or 'undefined' for a non-constant
                    getConstantValue: notImplemented,
                    getReferencedValueDeclaration: notImplemented,
                    getTypeReferenceSerializationKind: notImplemented,
                    isOptionalParameter: notImplemented,
                    moduleExportsSomeValue: notImplemented,
                    isArgumentsLocalBinding: notImplemented,
                    getExternalModuleFileFromDeclaration: notImplemented,
                    getTypeReferenceDirectivesForEntityName: notImplemented,
                    getTypeReferenceDirectivesForSymbol: notImplemented,
                    isLiteralConstDeclaration: notImplemented,
                    getJsxFactoryEntity: notImplemented,
                    getJsxFragmentFactoryEntity: notImplemented,
                    getAllAccessorDeclarations: notImplemented,
                    getSymbolOfExternalModuleSpecifier: notImplemented,
                    isBindingCapturedByNode: notImplemented,
                    getDeclarationStatementsForSourceFile: notImplemented,
                    isImportRequiredByAugmentation: notImplemented
                };
                createPrinterWithDefaults = /* @__PURE__ */ memoize(() => createPrinter({}));
                createPrinterWithRemoveComments = /* @__PURE__ */ memoize(() => createPrinter({ removeComments: true }));
                createPrinterWithRemoveCommentsNeverAsciiEscape = /* @__PURE__ */ memoize(() => createPrinter({ removeComments: true, neverAsciiEscape: true }));
                createPrinterWithRemoveCommentsOmitTrailingSemicolon = /* @__PURE__ */ memoize(() => createPrinter({ removeComments: true, omitTrailingSemicolon: true }));
            }
        });
        // src/compiler/watchUtilities.ts
        function createCachedDirectoryStructureHost(host, currentDirectory, useCaseSensitiveFileNames) {
            if (!host.getDirectories || !host.readDirectory) {
                return void 0;
            }
            const cachedReadDirectoryResult = /* @__PURE__ */ new Map();
            const getCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames);
            return {
                useCaseSensitiveFileNames,
                fileExists,
                readFile: (path, encoding) => host.readFile(path, encoding),
                directoryExists: host.directoryExists && directoryExists,
                getDirectories,
                readDirectory,
                createDirectory: host.createDirectory && createDirectory,
                writeFile: host.writeFile && writeFile2,
                addOrDeleteFileOrDirectory,
                addOrDeleteFile,
                clearCache,
                realpath: host.realpath && realpath
            };
            function toPath3(fileName) {
                return toPath(fileName, currentDirectory, getCanonicalFileName);
            }
            function getCachedFileSystemEntries(rootDirPath) {
                return cachedReadDirectoryResult.get(ensureTrailingDirectorySeparator(rootDirPath));
            }
            function getCachedFileSystemEntriesForBaseDir(path) {
                const entries = getCachedFileSystemEntries(getDirectoryPath(path));
                if (!entries) {
                    return entries;
                }
                if (!entries.sortedAndCanonicalizedFiles) {
                    entries.sortedAndCanonicalizedFiles = entries.files.map(getCanonicalFileName).sort();
                    entries.sortedAndCanonicalizedDirectories = entries.directories.map(getCanonicalFileName).sort();
                }
                return entries;
            }
            function getBaseNameOfFileName(fileName) {
                return getBaseFileName(normalizePath(fileName));
            }
            function createCachedFileSystemEntries(rootDir, rootDirPath) {
                var _a2;
                if (!host.realpath || ensureTrailingDirectorySeparator(toPath3(host.realpath(rootDir))) === rootDirPath) {
                    const resultFromHost = {
                        files: map(host.readDirectory(rootDir, 
                        /*extensions*/
                        void 0, 
                        /*exclude*/
                        void 0, 
                        /*include*/
                        ["*.*"]), getBaseNameOfFileName) || [],
                        directories: host.getDirectories(rootDir) || []
                    };
                    cachedReadDirectoryResult.set(ensureTrailingDirectorySeparator(rootDirPath), resultFromHost);
                    return resultFromHost;
                }
                if ((_a2 = host.directoryExists) == null ? void 0 : _a2.call(host, rootDir)) {
                    cachedReadDirectoryResult.set(rootDirPath, false);
                    return false;
                }
                return void 0;
            }
            function tryReadDirectory2(rootDir, rootDirPath) {
                rootDirPath = ensureTrailingDirectorySeparator(rootDirPath);
                const cachedResult = getCachedFileSystemEntries(rootDirPath);
                if (cachedResult) {
                    return cachedResult;
                }
                try {
                    return createCachedFileSystemEntries(rootDir, rootDirPath);
                }
                catch (_e) {
                    Debug.assert(!cachedReadDirectoryResult.has(ensureTrailingDirectorySeparator(rootDirPath)));
                    return void 0;
                }
            }
            function hasEntry(entries, name) {
                const index = binarySearch(entries, name, identity, compareStringsCaseSensitive);
                return index >= 0;
            }
            function writeFile2(fileName, data, writeByteOrderMark) {
                const path = toPath3(fileName);
                const result = getCachedFileSystemEntriesForBaseDir(path);
                if (result) {
                    updateFilesOfFileSystemEntry(result, getBaseNameOfFileName(fileName), 
                    /*fileExists*/
                    true);
                }
                return host.writeFile(fileName, data, writeByteOrderMark);
            }
            function fileExists(fileName) {
                const path = toPath3(fileName);
                const result = getCachedFileSystemEntriesForBaseDir(path);
                return result && hasEntry(result.sortedAndCanonicalizedFiles, getCanonicalFileName(getBaseNameOfFileName(fileName))) || host.fileExists(fileName);
            }
            function directoryExists(dirPath) {
                const path = toPath3(dirPath);
                return cachedReadDirectoryResult.has(ensureTrailingDirectorySeparator(path)) || host.directoryExists(dirPath);
            }
            function createDirectory(dirPath) {
                const path = toPath3(dirPath);
                const result = getCachedFileSystemEntriesForBaseDir(path);
                if (result) {
                    const baseName = getBaseNameOfFileName(dirPath);
                    const canonicalizedBaseName = getCanonicalFileName(baseName);
                    const canonicalizedDirectories = result.sortedAndCanonicalizedDirectories;
                    if (insertSorted(canonicalizedDirectories, canonicalizedBaseName, compareStringsCaseSensitive)) {
                        result.directories.push(baseName);
                    }
                }
                host.createDirectory(dirPath);
            }
            function getDirectories(rootDir) {
                const rootDirPath = toPath3(rootDir);
                const result = tryReadDirectory2(rootDir, rootDirPath);
                if (result) {
                    return result.directories.slice();
                }
                return host.getDirectories(rootDir);
            }
            function readDirectory(rootDir, extensions, excludes, includes, depth) {
                const rootDirPath = toPath3(rootDir);
                const rootResult = tryReadDirectory2(rootDir, rootDirPath);
                let rootSymLinkResult;
                if (rootResult !== void 0) {
                    return matchFiles(rootDir, extensions, excludes, includes, useCaseSensitiveFileNames, currentDirectory, depth, getFileSystemEntries, realpath);
                }
                return host.readDirectory(rootDir, extensions, excludes, includes, depth);
                function getFileSystemEntries(dir) {
                    const path = toPath3(dir);
                    if (path === rootDirPath) {
                        return rootResult || getFileSystemEntriesFromHost(dir, path);
                    }
                    const result = tryReadDirectory2(dir, path);
                    return result !== void 0 ? result || getFileSystemEntriesFromHost(dir, path) : emptyFileSystemEntries;
                }
                function getFileSystemEntriesFromHost(dir, path) {
                    if (rootSymLinkResult && path === rootDirPath)
                        return rootSymLinkResult;
                    const result = {
                        files: map(host.readDirectory(dir, 
                        /*extensions*/
                        void 0, 
                        /*exclude*/
                        void 0, 
                        /*include*/
                        ["*.*"]), getBaseNameOfFileName) || emptyArray,
                        directories: host.getDirectories(dir) || emptyArray
                    };
                    if (path === rootDirPath)
                        rootSymLinkResult = result;
                    return result;
                }
            }
            function realpath(s) {
                return host.realpath ? host.realpath(s) : s;
            }
            function addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath) {
                const existingResult = getCachedFileSystemEntries(fileOrDirectoryPath);
                if (existingResult !== void 0) {
                    clearCache();
                    return void 0;
                }
                const parentResult = getCachedFileSystemEntriesForBaseDir(fileOrDirectoryPath);
                if (!parentResult) {
                    return void 0;
                }
                if (!host.directoryExists) {
                    clearCache();
                    return void 0;
                }
                const baseName = getBaseNameOfFileName(fileOrDirectory);
                const fsQueryResult = {
                    fileExists: host.fileExists(fileOrDirectoryPath),
                    directoryExists: host.directoryExists(fileOrDirectoryPath)
                };
                if (fsQueryResult.directoryExists || hasEntry(parentResult.sortedAndCanonicalizedDirectories, getCanonicalFileName(baseName))) {
                    clearCache();
                }
                else {
                    updateFilesOfFileSystemEntry(parentResult, baseName, fsQueryResult.fileExists);
                }
                return fsQueryResult;
            }
            function addOrDeleteFile(fileName, filePath, eventKind) {
                if (eventKind === 1 /* Changed */) {
                    return;
                }
                const parentResult = getCachedFileSystemEntriesForBaseDir(filePath);
                if (parentResult) {
                    updateFilesOfFileSystemEntry(parentResult, getBaseNameOfFileName(fileName), eventKind === 0 /* Created */);
                }
            }
            function updateFilesOfFileSystemEntry(parentResult, baseName, fileExists2) {
                const canonicalizedFiles = parentResult.sortedAndCanonicalizedFiles;
                const canonicalizedBaseName = getCanonicalFileName(baseName);
                if (fileExists2) {
                    if (insertSorted(canonicalizedFiles, canonicalizedBaseName, compareStringsCaseSensitive)) {
                        parentResult.files.push(baseName);
                    }
                }
                else {
                    const sortedIndex = binarySearch(canonicalizedFiles, canonicalizedBaseName, identity, compareStringsCaseSensitive);
                    if (sortedIndex >= 0) {
                        canonicalizedFiles.splice(sortedIndex, 1);
                        const unsortedIndex = parentResult.files.findIndex((entry) => getCanonicalFileName(entry) === canonicalizedBaseName);
                        parentResult.files.splice(unsortedIndex, 1);
                    }
                }
            }
            function clearCache() {
                cachedReadDirectoryResult.clear();
            }
        }
        function updateSharedExtendedConfigFileWatcher(projectPath, options, extendedConfigFilesMap, createExtendedConfigFileWatch, toPath3) {
            var _a2;
            const extendedConfigs = arrayToMap(((_a2 = options == null ? void 0 : options.configFile) == null ? void 0 : _a2.extendedSourceFiles) || emptyArray, toPath3);
            extendedConfigFilesMap.forEach((watcher, extendedConfigFilePath) => {
                if (!extendedConfigs.has(extendedConfigFilePath)) {
                    watcher.projects.delete(projectPath);
                    watcher.close();
                }
            });
            extendedConfigs.forEach((extendedConfigFileName, extendedConfigFilePath) => {
                const existing = extendedConfigFilesMap.get(extendedConfigFilePath);
                if (existing) {
                    existing.projects.add(projectPath);
                }
                else {
                    extendedConfigFilesMap.set(extendedConfigFilePath, {
                        projects: /* @__PURE__ */ new Set([projectPath]),
                        watcher: createExtendedConfigFileWatch(extendedConfigFileName, extendedConfigFilePath),
                        close: () => {
                            const existing2 = extendedConfigFilesMap.get(extendedConfigFilePath);
                            if (!existing2 || existing2.projects.size !== 0)
                                return;
                            existing2.watcher.close();
                            extendedConfigFilesMap.delete(extendedConfigFilePath);
                        }
                    });
                }
            });
        }
        function clearSharedExtendedConfigFileWatcher(projectPath, extendedConfigFilesMap) {
            extendedConfigFilesMap.forEach((watcher) => {
                if (watcher.projects.delete(projectPath))
                    watcher.close();
            });
        }
        function cleanExtendedConfigCache(extendedConfigCache, extendedConfigFilePath, toPath3) {
            if (!extendedConfigCache.delete(extendedConfigFilePath))
                return;
            extendedConfigCache.forEach(({ extendedResult }, key) => {
                var _a2;
                if ((_a2 = extendedResult.extendedSourceFiles) == null ? void 0 : _a2.some((extendedFile) => toPath3(extendedFile) === extendedConfigFilePath)) {
                    cleanExtendedConfigCache(extendedConfigCache, key, toPath3);
                }
            });
        }
        function updatePackageJsonWatch(lookups, packageJsonWatches, createPackageJsonWatch) {
            const newMap = new Map(lookups);
            mutateMap(packageJsonWatches, newMap, {
                createNewValue: createPackageJsonWatch,
                onDeleteValue: closeFileWatcher
            });
        }
        function updateMissingFilePathsWatch(program, missingFileWatches, createMissingFileWatch) {
            const missingFilePaths = program.getMissingFilePaths();
            const newMissingFilePathMap = arrayToMap(missingFilePaths, identity, returnTrue);
            mutateMap(missingFileWatches, newMissingFilePathMap, {
                // Watch the missing files
                createNewValue: createMissingFileWatch,
                // Files that are no longer missing (e.g. because they are no longer required)
                // should no longer be watched.
                onDeleteValue: closeFileWatcher
            });
        }
        function updateWatchingWildcardDirectories(existingWatchedForWildcards, wildcardDirectories, watchDirectory) {
            mutateMap(existingWatchedForWildcards, wildcardDirectories, {
                // Create new watch and recursive info
                createNewValue: createWildcardDirectoryWatcher,
                // Close existing watch thats not needed any more
                onDeleteValue: closeFileWatcherOf,
                // Close existing watch that doesnt match in the flags
                onExistingValue: updateWildcardDirectoryWatcher
            });
            function createWildcardDirectoryWatcher(directory, flags) {
                return {
                    watcher: watchDirectory(directory, flags),
                    flags
                };
            }
            function updateWildcardDirectoryWatcher(existingWatcher, flags, directory) {
                if (existingWatcher.flags === flags) {
                    return;
                }
                existingWatcher.watcher.close();
                existingWatchedForWildcards.set(directory, createWildcardDirectoryWatcher(directory, flags));
            }
        }
        function isIgnoredFileFromWildCardWatching({ watchedDirPath, fileOrDirectory, fileOrDirectoryPath, configFileName, options, program, extraFileExtensions, currentDirectory, useCaseSensitiveFileNames, writeLog, toPath: toPath3 }) {
            const newPath = removeIgnoredPath(fileOrDirectoryPath);
            if (!newPath) {
                writeLog(`Project: ${configFileName} Detected ignored path: ${fileOrDirectory}`);
                return true;
            }
            fileOrDirectoryPath = newPath;
            if (fileOrDirectoryPath === watchedDirPath)
                return false;
            if (hasExtension(fileOrDirectoryPath) && !isSupportedSourceFileName(fileOrDirectory, options, extraFileExtensions)) {
                writeLog(`Project: ${configFileName} Detected file add/remove of non supported extension: ${fileOrDirectory}`);
                return true;
            }
            if (isExcludedFile(fileOrDirectory, options.configFile.configFileSpecs, getNormalizedAbsolutePath(getDirectoryPath(configFileName), currentDirectory), useCaseSensitiveFileNames, currentDirectory)) {
                writeLog(`Project: ${configFileName} Detected excluded file: ${fileOrDirectory}`);
                return true;
            }
            if (!program)
                return false;
            if (outFile(options) || options.outDir)
                return false;
            if (isDeclarationFileName(fileOrDirectoryPath)) {
                if (options.declarationDir)
                    return false;
            }
            else if (!fileExtensionIsOneOf(fileOrDirectoryPath, supportedJSExtensionsFlat)) {
                return false;
            }
            const filePathWithoutExtension = removeFileExtension(fileOrDirectoryPath);
            const realProgram = isArray(program) ? void 0 : isBuilderProgram(program) ? program.getProgramOrUndefined() : program;
            const builderProgram = !realProgram && !isArray(program) ? program : void 0;
            if (hasSourceFile(filePathWithoutExtension + ".ts" /* Ts */) || hasSourceFile(filePathWithoutExtension + ".tsx" /* Tsx */)) {
                writeLog(`Project: ${configFileName} Detected output file: ${fileOrDirectory}`);
                return true;
            }
            return false;
            function hasSourceFile(file) {
                return realProgram ? !!realProgram.getSourceFileByPath(file) : builderProgram ? builderProgram.getState().fileInfos.has(file) : !!find(program, (rootFile) => toPath3(rootFile) === file);
            }
        }
        function isBuilderProgram(program) {
            return !!program.getState;
        }
        function isEmittedFileOfProgram(program, file) {
            if (!program) {
                return false;
            }
            return program.isEmittedFile(file);
        }
        function getWatchFactory(host, watchLogLevel, log, getDetailWatchInfo) {
            setSysLog(watchLogLevel === 2 /* Verbose */ ? log : noop);
            const plainInvokeFactory = {
                watchFile: (file, callback, pollingInterval, options) => host.watchFile(file, callback, pollingInterval, options),
                watchDirectory: (directory, callback, flags, options) => host.watchDirectory(directory, callback, (flags & 1 /* Recursive */) !== 0, options)
            };
            const triggerInvokingFactory = watchLogLevel !== 0 /* None */ ? {
                watchFile: createTriggerLoggingAddWatch("watchFile"),
                watchDirectory: createTriggerLoggingAddWatch("watchDirectory")
            } : void 0;
            const factory2 = watchLogLevel === 2 /* Verbose */ ? {
                watchFile: createFileWatcherWithLogging,
                watchDirectory: createDirectoryWatcherWithLogging
            } : triggerInvokingFactory || plainInvokeFactory;
            const excludeWatcherFactory = watchLogLevel === 2 /* Verbose */ ? createExcludeWatcherWithLogging : returnNoopFileWatcher;
            return {
                watchFile: createExcludeHandlingAddWatch("watchFile"),
                watchDirectory: createExcludeHandlingAddWatch("watchDirectory")
            };
            function createExcludeHandlingAddWatch(key) {
                return (file, cb, flags, options, detailInfo1, detailInfo2) => {
                    var _a2;
                    return !matchesExclude(file, key === "watchFile" ? options == null ? void 0 : options.excludeFiles : options == null ? void 0 : options.excludeDirectories, useCaseSensitiveFileNames(), ((_a2 = host.getCurrentDirectory) == null ? void 0 : _a2.call(host)) || "") ? factory2[key].call(
                    /*thisArgs*/
                    void 0, file, cb, flags, options, detailInfo1, detailInfo2) : excludeWatcherFactory(file, flags, options, detailInfo1, detailInfo2);
                };
            }
            function useCaseSensitiveFileNames() {
                return typeof host.useCaseSensitiveFileNames === "boolean" ? host.useCaseSensitiveFileNames : host.useCaseSensitiveFileNames();
            }
            function createExcludeWatcherWithLogging(file, flags, options, detailInfo1, detailInfo2) {
                log(`ExcludeWatcher:: Added:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo)}`);
                return {
                    close: () => log(`ExcludeWatcher:: Close:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo)}`)
                };
            }
            function createFileWatcherWithLogging(file, cb, flags, options, detailInfo1, detailInfo2) {
                log(`FileWatcher:: Added:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo)}`);
                const watcher = triggerInvokingFactory.watchFile(file, cb, flags, options, detailInfo1, detailInfo2);
                return {
                    close: () => {
                        log(`FileWatcher:: Close:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo)}`);
                        watcher.close();
                    }
                };
            }
            function createDirectoryWatcherWithLogging(file, cb, flags, options, detailInfo1, detailInfo2) {
                const watchInfo = `DirectoryWatcher:: Added:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo)}`;
                log(watchInfo);
                const start = timestamp();
                const watcher = triggerInvokingFactory.watchDirectory(file, cb, flags, options, detailInfo1, detailInfo2);
                const elapsed = timestamp() - start;
                log(`Elapsed:: ${elapsed}ms ${watchInfo}`);
                return {
                    close: () => {
                        const watchInfo2 = `DirectoryWatcher:: Close:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo)}`;
                        log(watchInfo2);
                        const start2 = timestamp();
                        watcher.close();
                        const elapsed2 = timestamp() - start2;
                        log(`Elapsed:: ${elapsed2}ms ${watchInfo2}`);
                    }
                };
            }
            function createTriggerLoggingAddWatch(key) {
                return (file, cb, flags, options, detailInfo1, detailInfo2) => plainInvokeFactory[key].call(
                /*thisArgs*/
                void 0, file, (...args) => {
                    const triggerredInfo = `${key === "watchFile" ? "FileWatcher" : "DirectoryWatcher"}:: Triggered with ${args[0]} ${args[1] !== void 0 ? args[1] : ""}:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo)}`;
                    log(triggerredInfo);
                    const start = timestamp();
                    cb.call(
                    /*thisArg*/
                    void 0, ...args);
                    const elapsed = timestamp() - start;
                    log(`Elapsed:: ${elapsed}ms ${triggerredInfo}`);
                }, flags, options, detailInfo1, detailInfo2);
            }
            function getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo2) {
                return `WatchInfo: ${file} ${flags} ${JSON.stringify(options)} ${getDetailWatchInfo2 ? getDetailWatchInfo2(detailInfo1, detailInfo2) : detailInfo2 === void 0 ? detailInfo1 : `${detailInfo1} ${detailInfo2}`}`;
            }
        }
        function getFallbackOptions(options) {
            const fallbackPolling = options == null ? void 0 : options.fallbackPolling;
            return {
                watchFile: fallbackPolling !== void 0 ? fallbackPolling : 1 /* PriorityPollingInterval */
            };
        }
        function closeFileWatcherOf(objWithWatcher) {
            objWithWatcher.watcher.close();
        }
        var ConfigFileProgramReloadLevel, WatchLogLevel;
        var init_watchUtilities = __esm({
            "src/compiler/watchUtilities.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
                ConfigFileProgramReloadLevel = /* @__PURE__ */ ((ConfigFileProgramReloadLevel2) => {
                    ConfigFileProgramReloadLevel2[ConfigFileProgramReloadLevel2["None"] = 0] = "None";
                    ConfigFileProgramReloadLevel2[ConfigFileProgramReloadLevel2["Partial"] = 1] = "Partial";
                    ConfigFileProgramReloadLevel2[ConfigFileProgramReloadLevel2["Full"] = 2] = "Full";
                    return ConfigFileProgramReloadLevel2;
                })(ConfigFileProgramReloadLevel || {});
                WatchLogLevel = /* @__PURE__ */ ((WatchLogLevel2) => {
                    WatchLogLevel2[WatchLogLevel2["None"] = 0] = "None";
                    WatchLogLevel2[WatchLogLevel2["TriggerOnly"] = 1] = "TriggerOnly";
                    WatchLogLevel2[WatchLogLevel2["Verbose"] = 2] = "Verbose";
                    return WatchLogLevel2;
                })(WatchLogLevel || {});
            }
        });
        // src/compiler/program.ts
        function findConfigFile(searchPath, fileExists, configName = "tsconfig.json") {
            return forEachAncestorDirectory(searchPath, (ancestor) => {
                const fileName = combinePaths(ancestor, configName);
                return fileExists(fileName) ? fileName : void 0;
            });
        }
        function resolveTripleslashReference(moduleName, containingFile) {
            const basePath = getDirectoryPath(containingFile);
            const referencedFileName = isRootedDiskPath(moduleName) ? moduleName : combinePaths(basePath, moduleName);
            return normalizePath(referencedFileName);
        }
        function computeCommonSourceDirectoryOfFilenames(fileNames, currentDirectory, getCanonicalFileName) {
            let commonPathComponents;
            const failed = forEach(fileNames, (sourceFile) => {
                const sourcePathComponents = getNormalizedPathComponents(sourceFile, currentDirectory);
                sourcePathComponents.pop();
                if (!commonPathComponents) {
                    commonPathComponents = sourcePathComponents;
                    return;
                }
                const n = Math.min(commonPathComponents.length, sourcePathComponents.length);
                for (let i = 0; i < n; i++) {
                    if (getCanonicalFileName(commonPathComponents[i]) !== getCanonicalFileName(sourcePathComponents[i])) {
                        if (i === 0) {
                            return true;
                        }
                        commonPathComponents.length = i;
                        break;
                    }
                }
                if (sourcePathComponents.length < commonPathComponents.length) {
                    commonPathComponents.length = sourcePathComponents.length;
                }
            });
            if (failed) {
                return "";
            }
            if (!commonPathComponents) {
                return currentDirectory;
            }
            return getPathFromPathComponents(commonPathComponents);
        }
        function createCompilerHost(options, setParentNodes) {
            return createCompilerHostWorker(options, setParentNodes);
        }
        function createGetSourceFile(readFile, getCompilerOptions, setParentNodes) {
            return (fileName, languageVersionOrOptions, onError) => {
                let text;
                try {
                    mark("beforeIORead");
                    text = readFile(fileName, getCompilerOptions().charset);
                    mark("afterIORead");
                    measure("I/O Read", "beforeIORead", "afterIORead");
                }
                catch (e) {
                    if (onError) {
                        onError(e.message);
                    }
                    text = "";
                }
                return text !== void 0 ? createSourceFile(fileName, text, languageVersionOrOptions, setParentNodes) : void 0;
            };
        }
        function createWriteFileMeasuringIO(actualWriteFile, createDirectory, directoryExists) {
            return (fileName, data, writeByteOrderMark, onError) => {
                try {
                    mark("beforeIOWrite");
                    writeFileEnsuringDirectories(fileName, data, writeByteOrderMark, actualWriteFile, createDirectory, directoryExists);
                    mark("afterIOWrite");
                    measure("I/O Write", "beforeIOWrite", "afterIOWrite");
                }
                catch (e) {
                    if (onError) {
                        onError(e.message);
                    }
                }
            };
        }
        function createCompilerHostWorker(options, setParentNodes, system = sys) {
            const existingDirectories = /* @__PURE__ */ new Map();
            const getCanonicalFileName = createGetCanonicalFileName(system.useCaseSensitiveFileNames);
            function directoryExists(directoryPath) {
                if (existingDirectories.has(directoryPath)) {
                    return true;
                }
                if ((compilerHost.directoryExists || system.directoryExists)(directoryPath)) {
                    existingDirectories.set(directoryPath, true);
                    return true;
                }
                return false;
            }
            function getDefaultLibLocation() {
                return getDirectoryPath(normalizePath(system.getExecutingFilePath()));
            }
            const newLine = getNewLineCharacter(options);
            const realpath = system.realpath && ((path) => system.realpath(path));
            const compilerHost = {
                getSourceFile: createGetSourceFile((fileName) => compilerHost.readFile(fileName), () => options, setParentNodes),
                getDefaultLibLocation,
                getDefaultLibFileName: (options2) => combinePaths(getDefaultLibLocation(), getDefaultLibFileName(options2)),
                writeFile: createWriteFileMeasuringIO((path, data, writeByteOrderMark) => system.writeFile(path, data, writeByteOrderMark), (path) => (compilerHost.createDirectory || system.createDirectory)(path), (path) => directoryExists(path)),
                getCurrentDirectory: memoize(() => system.getCurrentDirectory()),
                useCaseSensitiveFileNames: () => system.useCaseSensitiveFileNames,
                getCanonicalFileName,
                getNewLine: () => newLine,
                fileExists: (fileName) => system.fileExists(fileName),
                readFile: (fileName) => system.readFile(fileName),
                trace: (s) => system.write(s + newLine),
                directoryExists: (directoryName) => system.directoryExists(directoryName),
                getEnvironmentVariable: (name) => system.getEnvironmentVariable ? system.getEnvironmentVariable(name) : "",
                getDirectories: (path) => system.getDirectories(path),
                realpath,
                readDirectory: (path, extensions, include, exclude, depth) => system.readDirectory(path, extensions, include, exclude, depth),
                createDirectory: (d) => system.createDirectory(d),
                createHash: maybeBind(system, system.createHash)
            };
            return compilerHost;
        }
        function changeCompilerHostLikeToUseCache(host, toPath3, getSourceFile) {
            const originalReadFile = host.readFile;
            const originalFileExists = host.fileExists;
            const originalDirectoryExists = host.directoryExists;
            const originalCreateDirectory = host.createDirectory;
            const originalWriteFile = host.writeFile;
            const readFileCache = /* @__PURE__ */ new Map();
            const fileExistsCache = /* @__PURE__ */ new Map();
            const directoryExistsCache = /* @__PURE__ */ new Map();
            const sourceFileCache = /* @__PURE__ */ new Map();
            const readFileWithCache = (fileName) => {
                const key = toPath3(fileName);
                const value = readFileCache.get(key);
                if (value !== void 0)
                    return value !== false ? value : void 0;
                return setReadFileCache(key, fileName);
            };
            const setReadFileCache = (key, fileName) => {
                const newValue = originalReadFile.call(host, fileName);
                readFileCache.set(key, newValue !== void 0 ? newValue : false);
                return newValue;
            };
            host.readFile = (fileName) => {
                const key = toPath3(fileName);
                const value = readFileCache.get(key);
                if (value !== void 0)
                    return value !== false ? value : void 0;
                if (!fileExtensionIs(fileName, ".json" /* Json */) && !isBuildInfoFile(fileName)) {
                    return originalReadFile.call(host, fileName);
                }
                return setReadFileCache(key, fileName);
            };
            const getSourceFileWithCache = getSourceFile ? (fileName, languageVersionOrOptions, onError, shouldCreateNewSourceFile) => {
                const key = toPath3(fileName);
                const impliedNodeFormat = typeof languageVersionOrOptions === "object" ? languageVersionOrOptions.impliedNodeFormat : void 0;
                const forImpliedNodeFormat = sourceFileCache.get(impliedNodeFormat);
                const value = forImpliedNodeFormat == null ? void 0 : forImpliedNodeFormat.get(key);
                if (value)
                    return value;
                const sourceFile = getSourceFile(fileName, languageVersionOrOptions, onError, shouldCreateNewSourceFile);
                if (sourceFile && (isDeclarationFileName(fileName) || fileExtensionIs(fileName, ".json" /* Json */))) {
                    sourceFileCache.set(impliedNodeFormat, (forImpliedNodeFormat || /* @__PURE__ */ new Map()).set(key, sourceFile));
                }
                return sourceFile;
            } : void 0;
            host.fileExists = (fileName) => {
                const key = toPath3(fileName);
                const value = fileExistsCache.get(key);
                if (value !== void 0)
                    return value;
                const newValue = originalFileExists.call(host, fileName);
                fileExistsCache.set(key, !!newValue);
                return newValue;
            };
            if (originalWriteFile) {
                host.writeFile = (fileName, data, ...rest) => {
                    const key = toPath3(fileName);
                    fileExistsCache.delete(key);
                    const value = readFileCache.get(key);
                    if (value !== void 0 && value !== data) {
                        readFileCache.delete(key);
                        sourceFileCache.forEach((map2) => map2.delete(key));
                    }
                    else if (getSourceFileWithCache) {
                        sourceFileCache.forEach((map2) => {
                            const sourceFile = map2.get(key);
                            if (sourceFile && sourceFile.text !== data) {
                                map2.delete(key);
                            }
                        });
                    }
                    originalWriteFile.call(host, fileName, data, ...rest);
                };
            }
            if (originalDirectoryExists) {
                host.directoryExists = (directory) => {
                    const key = toPath3(directory);
                    const value = directoryExistsCache.get(key);
                    if (value !== void 0)
                        return value;
                    const newValue = originalDirectoryExists.call(host, directory);
                    directoryExistsCache.set(key, !!newValue);
                    return newValue;
                };
                if (originalCreateDirectory) {
                    host.createDirectory = (directory) => {
                        const key = toPath3(directory);
                        directoryExistsCache.delete(key);
                        originalCreateDirectory.call(host, directory);
                    };
                }
            }
            return {
                originalReadFile,
                originalFileExists,
                originalDirectoryExists,
                originalCreateDirectory,
                originalWriteFile,
                getSourceFileWithCache,
                readFileWithCache
            };
        }
        function getPreEmitDiagnostics(program, sourceFile, cancellationToken) {
            let diagnostics;
            diagnostics = addRange(diagnostics, program.getConfigFileParsingDiagnostics());
            diagnostics = addRange(diagnostics, program.getOptionsDiagnostics(cancellationToken));
            diagnostics = addRange(diagnostics, program.getSyntacticDiagnostics(sourceFile, cancellationToken));
            diagnostics = addRange(diagnostics, program.getGlobalDiagnostics(cancellationToken));
            diagnostics = addRange(diagnostics, program.getSemanticDiagnostics(sourceFile, cancellationToken));
            if (getEmitDeclarations(program.getCompilerOptions())) {
                diagnostics = addRange(diagnostics, program.getDeclarationDiagnostics(sourceFile, cancellationToken));
            }
            return sortAndDeduplicateDiagnostics(diagnostics || emptyArray);
        }
        function formatDiagnostics(diagnostics, host) {
            let output = "";
            for (const diagnostic of diagnostics) {
                output += formatDiagnostic(diagnostic, host);
            }
            return output;
        }
        function formatDiagnostic(diagnostic, host) {
            const errorMessage = `${diagnosticCategoryName(diagnostic)} TS${diagnostic.code}: ${flattenDiagnosticMessageText(diagnostic.messageText, host.getNewLine())}${host.getNewLine()}`;
            if (diagnostic.file) {
                const { line, character } = getLineAndCharacterOfPosition(diagnostic.file, diagnostic.start);
                const fileName = diagnostic.file.fileName;
                const relativeFileName = convertToRelativePath(fileName, host.getCurrentDirectory(), (fileName2) => host.getCanonicalFileName(fileName2));
                return `${relativeFileName}(${line + 1},${character + 1}): ` + errorMessage;
            }
            return errorMessage;
        }
        function getCategoryFormat(category) {
            switch (category) {
                case 1 /* Error */:
                    return "\x1B[91m" /* Red */;
                case 0 /* Warning */:
                    return "\x1B[93m" /* Yellow */;
                case 2 /* Suggestion */:
                    return Debug.fail("Should never get an Info diagnostic on the command line.");
                case 3 /* Message */:
                    return "\x1B[94m" /* Blue */;
            }
        }
        function formatColorAndReset(text, formatStyle) {
            return formatStyle + text + resetEscapeSequence;
        }
        function formatCodeSpan(file, start, length2, indent2, squiggleColor, host) {
            const { line: firstLine, character: firstLineChar } = getLineAndCharacterOfPosition(file, start);
            const { line: lastLine, character: lastLineChar } = getLineAndCharacterOfPosition(file, start + length2);
            const lastLineInFile = getLineAndCharacterOfPosition(file, file.text.length).line;
            const hasMoreThanFiveLines = lastLine - firstLine >= 4;
            let gutterWidth = (lastLine + 1 + "").length;
            if (hasMoreThanFiveLines) {
                gutterWidth = Math.max(ellipsis.length, gutterWidth);
            }
            let context = "";
            for (let i = firstLine; i <= lastLine; i++) {
                context += host.getNewLine();
                if (hasMoreThanFiveLines && firstLine + 1 < i && i < lastLine - 1) {
                    context += indent2 + formatColorAndReset(padLeft(ellipsis, gutterWidth), gutterStyleSequence) + gutterSeparator + host.getNewLine();
                    i = lastLine - 1;
                }
                const lineStart = getPositionOfLineAndCharacter(file, i, 0);
                const lineEnd = i < lastLineInFile ? getPositionOfLineAndCharacter(file, i + 1, 0) : file.text.length;
                let lineContent = file.text.slice(lineStart, lineEnd);
                lineContent = trimStringEnd(lineContent);
                lineContent = lineContent.replace(/\t/g, " ");
                context += indent2 + formatColorAndReset(padLeft(i + 1 + "", gutterWidth), gutterStyleSequence) + gutterSeparator;
                context += lineContent + host.getNewLine();
                context += indent2 + formatColorAndReset(padLeft("", gutterWidth), gutterStyleSequence) + gutterSeparator;
                context += squiggleColor;
                if (i === firstLine) {
                    const lastCharForLine = i === lastLine ? lastLineChar : void 0;
                    context += lineContent.slice(0, firstLineChar).replace(/\S/g, " ");
                    context += lineContent.slice(firstLineChar, lastCharForLine).replace(/./g, "~");
                }
                else if (i === lastLine) {
                    context += lineContent.slice(0, lastLineChar).replace(/./g, "~");
                }
                else {
                    context += lineContent.replace(/./g, "~");
                }
                context += resetEscapeSequence;
            }
            return context;
        }
        function formatLocation(file, start, host, color = formatColorAndReset) {
            const { line: firstLine, character: firstLineChar } = getLineAndCharacterOfPosition(file, start);
            const relativeFileName = host ? convertToRelativePath(file.fileName, host.getCurrentDirectory(), (fileName) => host.getCanonicalFileName(fileName)) : file.fileName;
            let output = "";
            output += color(relativeFileName, "\x1B[96m" /* Cyan */);
            output += ":";
            output += color(`${firstLine + 1}`, "\x1B[93m" /* Yellow */);
            output += ":";
            output += color(`${firstLineChar + 1}`, "\x1B[93m" /* Yellow */);
            return output;
        }
        function formatDiagnosticsWithColorAndContext(diagnostics, host) {
            let output = "";
            for (const diagnostic of diagnostics) {
                if (diagnostic.file) {
                    const { file, start } = diagnostic;
                    output += formatLocation(file, start, host);
                    output += " - ";
                }
                output += formatColorAndReset(diagnosticCategoryName(diagnostic), getCategoryFormat(diagnostic.category));
                output += formatColorAndReset(` TS${diagnostic.code}: `, "\x1B[90m" /* Grey */);
                output += flattenDiagnosticMessageText(diagnostic.messageText, host.getNewLine());
                if (diagnostic.file) {
                    output += host.getNewLine();
                    output += formatCodeSpan(diagnostic.file, diagnostic.start, diagnostic.length, "", getCategoryFormat(diagnostic.category), host);
                }
                if (diagnostic.relatedInformation) {
                    output += host.getNewLine();
                    for (const { file, start, length: length2, messageText } of diagnostic.relatedInformation) {
                        if (file) {
                            output += host.getNewLine();
                            output += halfIndent + formatLocation(file, start, host);
                            output += formatCodeSpan(file, start, length2, indent, "\x1B[96m" /* Cyan */, host);
                        }
                        output += host.getNewLine();
                        output += indent + flattenDiagnosticMessageText(messageText, host.getNewLine());
                    }
                }
                output += host.getNewLine();
            }
            return output;
        }
        function flattenDiagnosticMessageText(diag2, newLine, indent2 = 0) {
            if (isString(diag2)) {
                return diag2;
            }
            else if (diag2 === void 0) {
                return "";
            }
            let result = "";
            if (indent2) {
                result += newLine;
                for (let i = 0; i < indent2; i++) {
                    result += "  ";
                }
            }
            result += diag2.messageText;
            indent2++;
            if (diag2.next) {
                for (const kid of diag2.next) {
                    result += flattenDiagnosticMessageText(kid, newLine, indent2);
                }
            }
            return result;
        }
        function getModeForFileReference(ref, containingFileMode) {
            return (isString(ref) ? containingFileMode : ref.resolutionMode) || containingFileMode;
        }
        function getModeForResolutionAtIndex(file, index) {
            if (file.impliedNodeFormat === void 0)
                return void 0;
            return getModeForUsageLocation(file, getModuleNameStringLiteralAt(file, index));
        }
        function isExclusivelyTypeOnlyImportOrExport(decl) {
            var _a2;
            if (isExportDeclaration(decl)) {
                return decl.isTypeOnly;
            }
            if ((_a2 = decl.importClause) == null ? void 0 : _a2.isTypeOnly) {
                return true;
            }
            return false;
        }
        function getModeForUsageLocation(file, usage) {
            var _a2, _b;
            if (file.impliedNodeFormat === void 0)
                return void 0;
            if (isImportDeclaration(usage.parent) || isExportDeclaration(usage.parent)) {
                const isTypeOnly = isExclusivelyTypeOnlyImportOrExport(usage.parent);
                if (isTypeOnly) {
                    const override = getResolutionModeOverrideForClause(usage.parent.assertClause);
                    if (override) {
                        return override;
                    }
                }
            }
            if (usage.parent.parent && isImportTypeNode(usage.parent.parent)) {
                const override = getResolutionModeOverrideForClause((_a2 = usage.parent.parent.assertions) == null ? void 0 : _a2.assertClause);
                if (override) {
                    return override;
                }
            }
            if (file.impliedNodeFormat !== 99 /* ESNext */) {
                return isImportCall(walkUpParenthesizedExpressions(usage.parent)) ? 99 /* ESNext */ : 1 /* CommonJS */;
            }
            const exprParentParent = (_b = walkUpParenthesizedExpressions(usage.parent)) == null ? void 0 : _b.parent;
            return exprParentParent && isImportEqualsDeclaration(exprParentParent) ? 1 /* CommonJS */ : 99 /* ESNext */;
        }
        function getResolutionModeOverrideForClause(clause, grammarErrorOnNode) {
            if (!clause)
                return void 0;
            if (length(clause.elements) !== 1) {
                grammarErrorOnNode == null ? void 0 : grammarErrorOnNode(clause, Diagnostics.Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require);
                return void 0;
            }
            const elem = clause.elements[0];
            if (!isStringLiteralLike(elem.name))
                return void 0;
            if (elem.name.text !== "resolution-mode") {
                grammarErrorOnNode == null ? void 0 : grammarErrorOnNode(elem.name, Diagnostics.resolution_mode_is_the_only_valid_key_for_type_import_assertions);
                return void 0;
            }
            if (!isStringLiteralLike(elem.value))
                return void 0;
            if (elem.value.text !== "import" && elem.value.text !== "require") {
                grammarErrorOnNode == null ? void 0 : grammarErrorOnNode(elem.value, Diagnostics.resolution_mode_should_be_either_require_or_import);
                return void 0;
            }
            return elem.value.text === "import" ? 99 /* ESNext */ : 1 /* CommonJS */;
        }
        function getModuleResolutionName(literal) {
            return literal.text;
        }
        function createModuleResolutionLoader(containingFile, redirectedReference, options, host, cache) {
            return {
                nameAndMode: moduleResolutionNameAndModeGetter,
                resolve: (moduleName, resolutionMode) => resolveModuleName(moduleName, containingFile, options, host, cache, redirectedReference, resolutionMode)
            };
        }
        function getTypeReferenceResolutionName(entry) {
            return !isString(entry) ? toFileNameLowerCase(entry.fileName) : entry;
        }
        function createTypeReferenceResolutionLoader(containingFile, redirectedReference, options, host, cache) {
            return {
                nameAndMode: typeReferenceResolutionNameAndModeGetter,
                resolve: (typeRef, resoluionMode) => resolveTypeReferenceDirective(typeRef, containingFile, options, host, redirectedReference, cache, resoluionMode)
            };
        }
        function loadWithModeAwareCache(entries, containingFile, redirectedReference, options, containingSourceFile, host, resolutionCache, createLoader) {
            if (entries.length === 0)
                return emptyArray;
            const resolutions = [];
            const cache = /* @__PURE__ */ new Map();
            const loader = createLoader(containingFile, redirectedReference, options, host, resolutionCache);
            for (const entry of entries) {
                const name = loader.nameAndMode.getName(entry);
                const mode = loader.nameAndMode.getMode(entry, containingSourceFile);
                const key = createModeAwareCacheKey(name, mode);
                let result = cache.get(key);
                if (!result) {
                    cache.set(key, result = loader.resolve(name, mode));
                }
                resolutions.push(result);
            }
            return resolutions;
        }
        function forEachResolvedProjectReference(resolvedProjectReferences, cb) {
            return forEachProjectReference(
            /*projectReferences*/
            void 0, resolvedProjectReferences, (resolvedRef, parent2) => resolvedRef && cb(resolvedRef, parent2));
        }
        function forEachProjectReference(projectReferences, resolvedProjectReferences, cbResolvedRef, cbRef) {
            let seenResolvedRefs;
            return worker(projectReferences, resolvedProjectReferences, 
            /*parent*/
            void 0);
            function worker(projectReferences2, resolvedProjectReferences2, parent2) {
                if (cbRef) {
                    const result = cbRef(projectReferences2, parent2);
                    if (result)
                        return result;
                }
                return forEach(resolvedProjectReferences2, (resolvedRef, index) => {
                    if (resolvedRef && (seenResolvedRefs == null ? void 0 : seenResolvedRefs.has(resolvedRef.sourceFile.path))) {
                        return void 0;
                    }
                    const result = cbResolvedRef(resolvedRef, parent2, index);
                    if (result || !resolvedRef)
                        return result;
                    (seenResolvedRefs || (seenResolvedRefs = /* @__PURE__ */ new Set())).add(resolvedRef.sourceFile.path);
                    return worker(resolvedRef.commandLine.projectReferences, resolvedRef.references, resolvedRef);
                });
            }
        }
        function isReferencedFile(reason) {
            switch (reason == null ? void 0 : reason.kind) {
                case 3 /* Import */:
                case 4 /* ReferenceFile */:
                case 5 /* TypeReferenceDirective */:
                case 7 /* LibReferenceDirective */:
                    return true;
                default:
                    return false;
            }
        }
        function isReferenceFileLocation(location) {
            return location.pos !== void 0;
        }
        function getReferencedFileLocation(getSourceFileByPath, ref) {
            var _a2, _b, _c, _d, _e, _f;
            const file = Debug.checkDefined(getSourceFileByPath(ref.file));
            const { kind, index } = ref;
            let pos, end, packageId, resolutionMode;
            switch (kind) {
                case 3 /* Import */:
                    const importLiteral = getModuleNameStringLiteralAt(file, index);
                    packageId = (_c = (_b = (_a2 = file.resolvedModules) == null ? void 0 : _a2.get(importLiteral.text, getModeForResolutionAtIndex(file, index))) == null ? void 0 : _b.resolvedModule) == null ? void 0 : _c.packageId;
                    if (importLiteral.pos === -1)
                        return { file, packageId, text: importLiteral.text };
                    pos = skipTrivia(file.text, importLiteral.pos);
                    end = importLiteral.end;
                    break;
                case 4 /* ReferenceFile */:
                    ({ pos, end } = file.referencedFiles[index]);
                    break;
                case 5 /* TypeReferenceDirective */:
                    ({ pos, end, resolutionMode } = file.typeReferenceDirectives[index]);
                    packageId = (_f = (_e = (_d = file.resolvedTypeReferenceDirectiveNames) == null ? void 0 : _d.get(toFileNameLowerCase(file.typeReferenceDirectives[index].fileName), resolutionMode || file.impliedNodeFormat)) == null ? void 0 : _e.resolvedTypeReferenceDirective) == null ? void 0 : _f.packageId;
                    break;
                case 7 /* LibReferenceDirective */:
                    ({ pos, end } = file.libReferenceDirectives[index]);
                    break;
                default:
                    return Debug.assertNever(kind);
            }
            return { file, pos, end, packageId };
        }
        function isProgramUptoDate(program, rootFileNames, newOptions, getSourceVersion, fileExists, hasInvalidatedResolutions, hasChangedAutomaticTypeDirectiveNames, getParsedCommandLine, projectReferences) {
            if (!program || (hasChangedAutomaticTypeDirectiveNames == null ? void 0 : hasChangedAutomaticTypeDirectiveNames()))
                return false;
            if (!arrayIsEqualTo(program.getRootFileNames(), rootFileNames))
                return false;
            let seenResolvedRefs;
            if (!arrayIsEqualTo(program.getProjectReferences(), projectReferences, projectReferenceUptoDate))
                return false;
            if (program.getSourceFiles().some(sourceFileNotUptoDate))
                return false;
            if (program.getMissingFilePaths().some(fileExists))
                return false;
            const currentOptions = program.getCompilerOptions();
            if (!compareDataObjects(currentOptions, newOptions))
                return false;
            if (currentOptions.configFile && newOptions.configFile)
                return currentOptions.configFile.text === newOptions.configFile.text;
            return true;
            function sourceFileNotUptoDate(sourceFile) {
                return !sourceFileVersionUptoDate(sourceFile) || hasInvalidatedResolutions(sourceFile.path);
            }
            function sourceFileVersionUptoDate(sourceFile) {
                return sourceFile.version === getSourceVersion(sourceFile.resolvedPath, sourceFile.fileName);
            }
            function projectReferenceUptoDate(oldRef, newRef, index) {
                return projectReferenceIsEqualTo(oldRef, newRef) && resolvedProjectReferenceUptoDate(program.getResolvedProjectReferences()[index], oldRef);
            }
            function resolvedProjectReferenceUptoDate(oldResolvedRef, oldRef) {
                if (oldResolvedRef) {
                    if (contains(seenResolvedRefs, oldResolvedRef))
                        return true;
                    const refPath2 = resolveProjectReferencePath(oldRef);
                    const newParsedCommandLine = getParsedCommandLine(refPath2);
                    if (!newParsedCommandLine)
                        return false;
                    if (oldResolvedRef.commandLine.options.configFile !== newParsedCommandLine.options.configFile)
                        return false;
                    if (!arrayIsEqualTo(oldResolvedRef.commandLine.fileNames, newParsedCommandLine.fileNames))
                        return false;
                    (seenResolvedRefs || (seenResolvedRefs = [])).push(oldResolvedRef);
                    return !forEach(oldResolvedRef.references, (childResolvedRef, index) => !resolvedProjectReferenceUptoDate(childResolvedRef, oldResolvedRef.commandLine.projectReferences[index]));
                }
                const refPath = resolveProjectReferencePath(oldRef);
                return !getParsedCommandLine(refPath);
            }
        }
        function getConfigFileParsingDiagnostics(configFileParseResult) {
            return configFileParseResult.options.configFile ? [...configFileParseResult.options.configFile.parseDiagnostics, ...configFileParseResult.errors] : configFileParseResult.errors;
        }
        function getImpliedNodeFormatForFile(fileName, packageJsonInfoCache, host, options) {
            const result = getImpliedNodeFormatForFileWorker(fileName, packageJsonInfoCache, host, options);
            return typeof result === "object" ? result.impliedNodeFormat : result;
        }
        function getImpliedNodeFormatForFileWorker(fileName, packageJsonInfoCache, host, options) {
            switch (getEmitModuleResolutionKind(options)) {
                case 3 /* Node16 */:
                case 99 /* NodeNext */:
                    return fileExtensionIsOneOf(fileName, [".d.mts" /* Dmts */, ".mts" /* Mts */, ".mjs" /* Mjs */]) ? 99 /* ESNext */ : fileExtensionIsOneOf(fileName, [".d.cts" /* Dcts */, ".cts" /* Cts */, ".cjs" /* Cjs */]) ? 1 /* CommonJS */ : fileExtensionIsOneOf(fileName, [".d.ts" /* Dts */, ".ts" /* Ts */, ".tsx" /* Tsx */, ".js" /* Js */, ".jsx" /* Jsx */]) ? lookupFromPackageJson() : void 0;
                default:
                    return void 0;
            }
            function lookupFromPackageJson() {
                const state = getTemporaryModuleResolutionState(packageJsonInfoCache, host, options);
                const packageJsonLocations = [];
                state.failedLookupLocations = packageJsonLocations;
                state.affectingLocations = packageJsonLocations;
                const packageJsonScope = getPackageScopeForPath(fileName, state);
                const impliedNodeFormat = (packageJsonScope == null ? void 0 : packageJsonScope.contents.packageJsonContent.type) === "module" ? 99 /* ESNext */ : 1 /* CommonJS */;
                return { impliedNodeFormat, packageJsonLocations, packageJsonScope };
            }
        }
        function shouldProgramCreateNewSourceFiles(program, newOptions) {
            if (!program)
                return false;
            return optionsHaveChanges(program.getCompilerOptions(), newOptions, sourceFileAffectingCompilerOptions);
        }
        function createCreateProgramOptions(rootNames, options, host, oldProgram, configFileParsingDiagnostics, typeScriptVersion3) {
            return {
                rootNames,
                options,
                host,
                oldProgram,
                configFileParsingDiagnostics,
                typeScriptVersion: typeScriptVersion3
            };
        }
        function createProgram(rootNamesOrOptions, _options, _host, _oldProgram, _configFileParsingDiagnostics) {
            var _a2, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n, _o, _p;
            const createProgramOptions = isArray(rootNamesOrOptions) ? createCreateProgramOptions(rootNamesOrOptions, _options, _host, _oldProgram, _configFileParsingDiagnostics) : rootNamesOrOptions;
            const { rootNames, options, configFileParsingDiagnostics, projectReferences, typeScriptVersion: typeScriptVersion3 } = createProgramOptions;
            let { oldProgram } = createProgramOptions;
            const reportInvalidIgnoreDeprecations = memoize(() => createOptionValueDiagnostic("ignoreDeprecations", Diagnostics.Invalid_value_for_ignoreDeprecations));
            let processingDefaultLibFiles;
            let processingOtherFiles;
            let files;
            let symlinks;
            let commonSourceDirectory;
            let typeChecker;
            let classifiableNames;
            const ambientModuleNameToUnmodifiedFileName = /* @__PURE__ */ new Map();
            let fileReasons = createMultiMap();
            const cachedBindAndCheckDiagnosticsForFile = {};
            const cachedDeclarationDiagnosticsForFile = {};
            let resolvedTypeReferenceDirectives = createModeAwareCache();
            let fileProcessingDiagnostics;
            let automaticTypeDirectiveNames;
            let automaticTypeDirectiveResolutions;
            const maxNodeModuleJsDepth = typeof options.maxNodeModuleJsDepth === "number" ? options.maxNodeModuleJsDepth : 0;
            let currentNodeModulesDepth = 0;
            const modulesWithElidedImports = /* @__PURE__ */ new Map();
            const sourceFilesFoundSearchingNodeModules = /* @__PURE__ */ new Map();
            (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Program, "createProgram", { configFilePath: options.configFilePath, rootDir: options.rootDir }, 
            /*separateBeginAndEnd*/
            true);
            mark("beforeProgram");
            const host = createProgramOptions.host || createCompilerHost(options);
            const configParsingHost = parseConfigHostFromCompilerHostLike(host);
            let skipDefaultLib = options.noLib;
            const getDefaultLibraryFileName = memoize(() => host.getDefaultLibFileName(options));
            const defaultLibraryPath = host.getDefaultLibLocation ? host.getDefaultLibLocation() : getDirectoryPath(getDefaultLibraryFileName());
            const programDiagnostics = createDiagnosticCollection();
            const currentDirectory = host.getCurrentDirectory();
            const supportedExtensions = getSupportedExtensions(options);
            const supportedExtensionsWithJsonIfResolveJsonModule = getSupportedExtensionsWithJsonIfResolveJsonModule(options, supportedExtensions);
            const hasEmitBlockingDiagnostics = /* @__PURE__ */ new Map();
            let _compilerOptionsObjectLiteralSyntax;
            let moduleResolutionCache;
            let actualResolveModuleNamesWorker;
            const hasInvalidatedResolutions = host.hasInvalidatedResolutions || returnFalse;
            if (host.resolveModuleNameLiterals) {
                actualResolveModuleNamesWorker = host.resolveModuleNameLiterals.bind(host);
                moduleResolutionCache = (_b = host.getModuleResolutionCache) == null ? void 0 : _b.call(host);
            }
            else if (host.resolveModuleNames) {
                actualResolveModuleNamesWorker = (moduleNames, containingFile, redirectedReference, options2, containingSourceFile, reusedNames) => host.resolveModuleNames(moduleNames.map(getModuleResolutionName), containingFile, reusedNames == null ? void 0 : reusedNames.map(getModuleResolutionName), redirectedReference, options2, containingSourceFile).map((resolved) => resolved ? resolved.extension !== void 0 ? { resolvedModule: resolved } : (
                // An older host may have omitted extension, in which case we should infer it from the file extension of resolvedFileName.
                { resolvedModule: { ...resolved, extension: extensionFromPath(resolved.resolvedFileName) } }) : emptyResolution);
                moduleResolutionCache = (_c = host.getModuleResolutionCache) == null ? void 0 : _c.call(host);
            }
            else {
                moduleResolutionCache = createModuleResolutionCache(currentDirectory, getCanonicalFileName, options);
                actualResolveModuleNamesWorker = (moduleNames, containingFile, redirectedReference, options2, containingSourceFile) => loadWithModeAwareCache(moduleNames, containingFile, redirectedReference, options2, containingSourceFile, host, moduleResolutionCache, createModuleResolutionLoader);
            }
            let actualResolveTypeReferenceDirectiveNamesWorker;
            if (host.resolveTypeReferenceDirectiveReferences) {
                actualResolveTypeReferenceDirectiveNamesWorker = host.resolveTypeReferenceDirectiveReferences.bind(host);
            }
            else if (host.resolveTypeReferenceDirectives) {
                actualResolveTypeReferenceDirectiveNamesWorker = (typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile) => host.resolveTypeReferenceDirectives(typeDirectiveNames.map(getTypeReferenceResolutionName), containingFile, redirectedReference, options2, containingSourceFile == null ? void 0 : containingSourceFile.impliedNodeFormat).map((resolvedTypeReferenceDirective) => ({ resolvedTypeReferenceDirective }));
            }
            else {
                const typeReferenceDirectiveResolutionCache = createTypeReferenceDirectiveResolutionCache(currentDirectory, getCanonicalFileName, 
                /*options*/
                void 0, moduleResolutionCache == null ? void 0 : moduleResolutionCache.getPackageJsonInfoCache());
                actualResolveTypeReferenceDirectiveNamesWorker = (typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile) => loadWithModeAwareCache(typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile, host, typeReferenceDirectiveResolutionCache, createTypeReferenceResolutionLoader);
            }
            const packageIdToSourceFile = /* @__PURE__ */ new Map();
            let sourceFileToPackageName = /* @__PURE__ */ new Map();
            let redirectTargetsMap = createMultiMap();
            let usesUriStyleNodeCoreModules = false;
            const filesByName = /* @__PURE__ */ new Map();
            let missingFilePaths;
            const filesByNameIgnoreCase = host.useCaseSensitiveFileNames() ? /* @__PURE__ */ new Map() : void 0;
            let resolvedProjectReferences;
            let projectReferenceRedirects;
            let mapFromFileToProjectReferenceRedirects;
            let mapFromToProjectReferenceRedirectSource;
            const useSourceOfProjectReferenceRedirect = !!((_d = host.useSourceOfProjectReferenceRedirect) == null ? void 0 : _d.call(host)) && !options.disableSourceOfProjectReferenceRedirect;
            const { onProgramCreateComplete, fileExists, directoryExists } = updateHostForUseSourceOfProjectReferenceRedirect({
                compilerHost: host,
                getSymlinkCache,
                useSourceOfProjectReferenceRedirect,
                toPath: toPath3,
                getResolvedProjectReferences,
                getSourceOfProjectReferenceRedirect,
                forEachResolvedProjectReference: forEachResolvedProjectReference2
            });
            const readFile = host.readFile.bind(host);
            (_e = tracing) == null ? void 0 : _e.push(tracing.Phase.Program, "shouldProgramCreateNewSourceFiles", { hasOldProgram: !!oldProgram });
            const shouldCreateNewSourceFile = shouldProgramCreateNewSourceFiles(oldProgram, options);
            (_f = tracing) == null ? void 0 : _f.pop();
            let structureIsReused;
            (_g = tracing) == null ? void 0 : _g.push(tracing.Phase.Program, "tryReuseStructureFromOldProgram", {});
            structureIsReused = tryReuseStructureFromOldProgram();
            (_h = tracing) == null ? void 0 : _h.pop();
            if (structureIsReused !== 2 /* Completely */) {
                processingDefaultLibFiles = [];
                processingOtherFiles = [];
                if (projectReferences) {
                    if (!resolvedProjectReferences) {
                        resolvedProjectReferences = projectReferences.map(parseProjectReferenceConfigFile);
                    }
                    if (rootNames.length) {
                        resolvedProjectReferences == null ? void 0 : resolvedProjectReferences.forEach((parsedRef, index) => {
                            if (!parsedRef)
                                return;
                            const out = outFile(parsedRef.commandLine.options);
                            if (useSourceOfProjectReferenceRedirect) {
                                if (out || getEmitModuleKind(parsedRef.commandLine.options) === 0 /* None */) {
                                    for (const fileName of parsedRef.commandLine.fileNames) {
                                        processProjectReferenceFile(fileName, { kind: 1 /* SourceFromProjectReference */, index });
                                    }
                                }
                            }
                            else {
                                if (out) {
                                    processProjectReferenceFile(changeExtension(out, ".d.ts"), { kind: 2 /* OutputFromProjectReference */, index });
                                }
                                else if (getEmitModuleKind(parsedRef.commandLine.options) === 0 /* None */) {
                                    const getCommonSourceDirectory3 = memoize(() => getCommonSourceDirectoryOfConfig(parsedRef.commandLine, !host.useCaseSensitiveFileNames()));
                                    for (const fileName of parsedRef.commandLine.fileNames) {
                                        if (!isDeclarationFileName(fileName) && !fileExtensionIs(fileName, ".json" /* Json */)) {
                                            processProjectReferenceFile(getOutputDeclarationFileName(fileName, parsedRef.commandLine, !host.useCaseSensitiveFileNames(), getCommonSourceDirectory3), { kind: 2 /* OutputFromProjectReference */, index });
                                        }
                                    }
                                }
                            }
                        });
                    }
                }
                (_i = tracing) == null ? void 0 : _i.push(tracing.Phase.Program, "processRootFiles", { count: rootNames.length });
                forEach(rootNames, (name, index) => processRootFile(name, 
                /*isDefaultLib*/
                false, 
                /*ignoreNoDefaultLib*/
                false, { kind: 0 /* RootFile */, index }));
                (_j = tracing) == null ? void 0 : _j.pop();
                automaticTypeDirectiveNames != null ? automaticTypeDirectiveNames : automaticTypeDirectiveNames = rootNames.length ? getAutomaticTypeDirectiveNames(options, host) : emptyArray;
                automaticTypeDirectiveResolutions = createModeAwareCache();
                if (automaticTypeDirectiveNames.length) {
                    (_k = tracing) == null ? void 0 : _k.push(tracing.Phase.Program, "processTypeReferences", { count: automaticTypeDirectiveNames.length });
                    const containingDirectory = options.configFilePath ? getDirectoryPath(options.configFilePath) : host.getCurrentDirectory();
                    const containingFilename = combinePaths(containingDirectory, inferredTypesContainingFile);
                    const resolutions = resolveTypeReferenceDirectiveNamesReusingOldState(automaticTypeDirectiveNames, containingFilename);
                    for (let i = 0; i < automaticTypeDirectiveNames.length; i++) {
                        automaticTypeDirectiveResolutions.set(automaticTypeDirectiveNames[i], 
                        /*mode*/
                        void 0, resolutions[i]);
                        processTypeReferenceDirective(automaticTypeDirectiveNames[i], 
                        /*mode*/
                        void 0, resolutions[i], {
                            kind: 8 /* AutomaticTypeDirectiveFile */,
                            typeReference: automaticTypeDirectiveNames[i],
                            packageId: (_m = (_l = resolutions[i]) == null ? void 0 : _l.resolvedTypeReferenceDirective) == null ? void 0 : _m.packageId
                        });
                    }
                    (_n = tracing) == null ? void 0 : _n.pop();
                }
                if (rootNames.length && !skipDefaultLib) {
                    const defaultLibraryFileName = getDefaultLibraryFileName();
                    if (!options.lib && defaultLibraryFileName) {
                        processRootFile(defaultLibraryFileName, 
                        /*isDefaultLib*/
                        true, 
                        /*ignoreNoDefaultLib*/
                        false, { kind: 6 /* LibFile */ });
                    }
                    else {
                        forEach(options.lib, (libFileName, index) => {
                            processRootFile(pathForLibFile(libFileName), 
                            /*isDefaultLib*/
                            true, 
                            /*ignoreNoDefaultLib*/
                            false, { kind: 6 /* LibFile */, index });
                        });
                    }
                }
                missingFilePaths = arrayFrom(mapDefinedIterator(filesByName.entries(), ([path, file]) => file === void 0 ? path : void 0));
                files = stableSort(processingDefaultLibFiles, compareDefaultLibFiles).concat(processingOtherFiles);
                processingDefaultLibFiles = void 0;
                processingOtherFiles = void 0;
            }
            Debug.assert(!!missingFilePaths);
            if (oldProgram && host.onReleaseOldSourceFile) {
                const oldSourceFiles = oldProgram.getSourceFiles();
                for (const oldSourceFile of oldSourceFiles) {
                    const newFile = getSourceFileByPath(oldSourceFile.resolvedPath);
                    if (shouldCreateNewSourceFile || !newFile || newFile.impliedNodeFormat !== oldSourceFile.impliedNodeFormat || // old file wasn't redirect but new file is
                        oldSourceFile.resolvedPath === oldSourceFile.path && newFile.resolvedPath !== oldSourceFile.path) {
                        host.onReleaseOldSourceFile(oldSourceFile, oldProgram.getCompilerOptions(), !!getSourceFileByPath(oldSourceFile.path));
                    }
                }
                if (!host.getParsedCommandLine) {
                    oldProgram.forEachResolvedProjectReference((resolvedProjectReference) => {
                        if (!getResolvedProjectReferenceByPath(resolvedProjectReference.sourceFile.path)) {
                            host.onReleaseOldSourceFile(resolvedProjectReference.sourceFile, oldProgram.getCompilerOptions(), 
                            /*hasSourceFileByPath*/
                            false);
                        }
                    });
                }
            }
            if (oldProgram && host.onReleaseParsedCommandLine) {
                forEachProjectReference(oldProgram.getProjectReferences(), oldProgram.getResolvedProjectReferences(), (oldResolvedRef, parent2, index) => {
                    const oldReference = (parent2 == null ? void 0 : parent2.commandLine.projectReferences[index]) || oldProgram.getProjectReferences()[index];
                    const oldRefPath = resolveProjectReferencePath(oldReference);
                    if (!(projectReferenceRedirects == null ? void 0 : projectReferenceRedirects.has(toPath3(oldRefPath)))) {
                        host.onReleaseParsedCommandLine(oldRefPath, oldResolvedRef, oldProgram.getCompilerOptions());
                    }
                });
            }
            oldProgram = void 0;
            const program = {
                getRootFileNames: () => rootNames,
                getSourceFile,
                getSourceFileByPath,
                getSourceFiles: () => files,
                getMissingFilePaths: () => missingFilePaths,
                // TODO: GH#18217
                getModuleResolutionCache: () => moduleResolutionCache,
                getFilesByNameMap: () => filesByName,
                getCompilerOptions: () => options,
                getSyntacticDiagnostics,
                getOptionsDiagnostics,
                getGlobalDiagnostics,
                getSemanticDiagnostics,
                getCachedSemanticDiagnostics,
                getSuggestionDiagnostics,
                getDeclarationDiagnostics: getDeclarationDiagnostics2,
                getBindAndCheckDiagnostics,
                getProgramDiagnostics,
                getTypeChecker,
                getClassifiableNames,
                getCommonSourceDirectory: getCommonSourceDirectory2,
                emit,
                getCurrentDirectory: () => currentDirectory,
                getNodeCount: () => getTypeChecker().getNodeCount(),
                getIdentifierCount: () => getTypeChecker().getIdentifierCount(),
                getSymbolCount: () => getTypeChecker().getSymbolCount(),
                getTypeCount: () => getTypeChecker().getTypeCount(),
                getInstantiationCount: () => getTypeChecker().getInstantiationCount(),
                getRelationCacheSizes: () => getTypeChecker().getRelationCacheSizes(),
                getFileProcessingDiagnostics: () => fileProcessingDiagnostics,
                getResolvedTypeReferenceDirectives: () => resolvedTypeReferenceDirectives,
                getAutomaticTypeDirectiveNames: () => automaticTypeDirectiveNames,
                getAutomaticTypeDirectiveResolutions: () => automaticTypeDirectiveResolutions,
                isSourceFileFromExternalLibrary,
                isSourceFileDefaultLibrary,
                getSourceFileFromReference,
                getLibFileFromReference,
                sourceFileToPackageName,
                redirectTargetsMap,
                usesUriStyleNodeCoreModules,
                isEmittedFile,
                getConfigFileParsingDiagnostics: getConfigFileParsingDiagnostics2,
                getProjectReferences,
                getResolvedProjectReferences,
                getProjectReferenceRedirect,
                getResolvedProjectReferenceToRedirect,
                getResolvedProjectReferenceByPath,
                forEachResolvedProjectReference: forEachResolvedProjectReference2,
                isSourceOfProjectReferenceRedirect,
                emitBuildInfo,
                fileExists,
                readFile,
                directoryExists,
                getSymlinkCache,
                realpath: (_o = host.realpath) == null ? void 0 : _o.bind(host),
                useCaseSensitiveFileNames: () => host.useCaseSensitiveFileNames(),
                getCanonicalFileName,
                getFileIncludeReasons: () => fileReasons,
                structureIsReused,
                writeFile: writeFile2
            };
            onProgramCreateComplete();
            fileProcessingDiagnostics == null ? void 0 : fileProcessingDiagnostics.forEach((diagnostic) => {
                switch (diagnostic.kind) {
                    case 1 /* FilePreprocessingFileExplainingDiagnostic */:
                        return programDiagnostics.add(createDiagnosticExplainingFile(diagnostic.file && getSourceFileByPath(diagnostic.file), diagnostic.fileProcessingReason, diagnostic.diagnostic, diagnostic.args || emptyArray));
                    case 0 /* FilePreprocessingReferencedDiagnostic */:
                        const { file, pos, end } = getReferencedFileLocation(getSourceFileByPath, diagnostic.reason);
                        return programDiagnostics.add(createFileDiagnostic(file, Debug.checkDefined(pos), Debug.checkDefined(end) - pos, diagnostic.diagnostic, ...diagnostic.args || emptyArray));
                    case 2 /* ResolutionDiagnostics */:
                        return diagnostic.diagnostics.forEach((d) => programDiagnostics.add(d));
                    default:
                        Debug.assertNever(diagnostic);
                }
            });
            verifyCompilerOptions();
            mark("afterProgram");
            measure("Program", "beforeProgram", "afterProgram");
            (_p = tracing) == null ? void 0 : _p.pop();
            return program;
            function addResolutionDiagnostics(resolution) {
                var _a3;
                if (!((_a3 = resolution.resolutionDiagnostics) == null ? void 0 : _a3.length))
                    return;
                (fileProcessingDiagnostics != null ? fileProcessingDiagnostics : fileProcessingDiagnostics = []).push({
                    kind: 2 /* ResolutionDiagnostics */,
                    diagnostics: resolution.resolutionDiagnostics
                });
            }
            function addResolutionDiagnosticsFromResolutionOrCache(containingFile, name, resolution, mode) {
                if (host.resolveModuleNameLiterals || !host.resolveModuleNames)
                    return addResolutionDiagnostics(resolution);
                if (!moduleResolutionCache || isExternalModuleNameRelative(name))
                    return;
                const containingFileName = getNormalizedAbsolutePath(containingFile.originalFileName, currentDirectory);
                const containingDir = getDirectoryPath(containingFileName);
                const redirectedReference = getRedirectReferenceForResolution(containingFile);
                const fromCache = moduleResolutionCache.getFromNonRelativeNameCache(name, mode, containingDir, redirectedReference);
                if (fromCache)
                    addResolutionDiagnostics(fromCache);
            }
            function resolveModuleNamesWorker(moduleNames, containingFile, reusedNames) {
                var _a3, _b2;
                if (!moduleNames.length)
                    return emptyArray;
                const containingFileName = getNormalizedAbsolutePath(containingFile.originalFileName, currentDirectory);
                const redirectedReference = getRedirectReferenceForResolution(containingFile);
                (_a3 = tracing) == null ? void 0 : _a3.push(tracing.Phase.Program, "resolveModuleNamesWorker", { containingFileName });
                mark("beforeResolveModule");
                const result = actualResolveModuleNamesWorker(moduleNames, containingFileName, redirectedReference, options, containingFile, reusedNames);
                mark("afterResolveModule");
                measure("ResolveModule", "beforeResolveModule", "afterResolveModule");
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return result;
            }
            function resolveTypeReferenceDirectiveNamesWorker(typeDirectiveNames, containingFile, reusedNames) {
                var _a3, _b2;
                if (!typeDirectiveNames.length)
                    return [];
                const containingSourceFile = !isString(containingFile) ? containingFile : void 0;
                const containingFileName = !isString(containingFile) ? getNormalizedAbsolutePath(containingFile.originalFileName, currentDirectory) : containingFile;
                const redirectedReference = containingSourceFile && getRedirectReferenceForResolution(containingSourceFile);
                (_a3 = tracing) == null ? void 0 : _a3.push(tracing.Phase.Program, "resolveTypeReferenceDirectiveNamesWorker", { containingFileName });
                mark("beforeResolveTypeReference");
                const result = actualResolveTypeReferenceDirectiveNamesWorker(typeDirectiveNames, containingFileName, redirectedReference, options, containingSourceFile, reusedNames);
                mark("afterResolveTypeReference");
                measure("ResolveTypeReference", "beforeResolveTypeReference", "afterResolveTypeReference");
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return result;
            }
            function getRedirectReferenceForResolution(file) {
                const redirect = getResolvedProjectReferenceToRedirect(file.originalFileName);
                if (redirect || !isDeclarationFileName(file.originalFileName))
                    return redirect;
                const resultFromDts = getRedirectReferenceForResolutionFromSourceOfProject(file.path);
                if (resultFromDts)
                    return resultFromDts;
                if (!host.realpath || !options.preserveSymlinks || !stringContains(file.originalFileName, nodeModulesPathPart))
                    return void 0;
                const realDeclarationPath = toPath3(host.realpath(file.originalFileName));
                return realDeclarationPath === file.path ? void 0 : getRedirectReferenceForResolutionFromSourceOfProject(realDeclarationPath);
            }
            function getRedirectReferenceForResolutionFromSourceOfProject(filePath) {
                const source = getSourceOfProjectReferenceRedirect(filePath);
                if (isString(source))
                    return getResolvedProjectReferenceToRedirect(source);
                if (!source)
                    return void 0;
                return forEachResolvedProjectReference2((resolvedRef) => {
                    const out = outFile(resolvedRef.commandLine.options);
                    if (!out)
                        return void 0;
                    return toPath3(out) === filePath ? resolvedRef : void 0;
                });
            }
            function compareDefaultLibFiles(a, b) {
                return compareValues(getDefaultLibFilePriority(a), getDefaultLibFilePriority(b));
            }
            function getDefaultLibFilePriority(a) {
                if (containsPath(defaultLibraryPath, a.fileName, 
                /*ignoreCase*/
                false)) {
                    const basename = getBaseFileName(a.fileName);
                    if (basename === "lib.d.ts" || basename === "lib.es6.d.ts")
                        return 0;
                    const name = removeSuffix(removePrefix(basename, "lib."), ".d.ts");
                    const index = libs.indexOf(name);
                    if (index !== -1)
                        return index + 1;
                }
                return libs.length + 2;
            }
            function toPath3(fileName) {
                return toPath(fileName, currentDirectory, getCanonicalFileName);
            }
            function getCommonSourceDirectory2() {
                if (commonSourceDirectory === void 0) {
                    const emittedFiles = filter(files, (file) => sourceFileMayBeEmitted(file, program));
                    commonSourceDirectory = getCommonSourceDirectory(options, () => mapDefined(emittedFiles, (file) => file.isDeclarationFile ? void 0 : file.fileName), currentDirectory, getCanonicalFileName, (commonSourceDirectory2) => checkSourceFilesBelongToPath(emittedFiles, commonSourceDirectory2));
                }
                return commonSourceDirectory;
            }
            function getClassifiableNames() {
                var _a3;
                if (!classifiableNames) {
                    getTypeChecker();
                    classifiableNames = /* @__PURE__ */ new Set();
                    for (const sourceFile of files) {
                        (_a3 = sourceFile.classifiableNames) == null ? void 0 : _a3.forEach((value) => classifiableNames.add(value));
                    }
                }
                return classifiableNames;
            }
            function resolveModuleNamesReusingOldState(moduleNames, file) {
                var _a3;
                if (structureIsReused === 0 /* Not */ && !file.ambientModuleNames.length) {
                    return resolveModuleNamesWorker(moduleNames, file, 
                    /*reusedNames*/
                    void 0);
                }
                const oldSourceFile = oldProgram && oldProgram.getSourceFile(file.fileName);
                if (oldSourceFile !== file && file.resolvedModules) {
                    const result2 = [];
                    for (const moduleName of moduleNames) {
                        const resolvedModule = file.resolvedModules.get(moduleName.text, getModeForUsageLocation(file, moduleName));
                        result2.push(resolvedModule);
                    }
                    return result2;
                }
                let unknownModuleNames;
                let result;
                let reusedNames;
                const predictedToResolveToAmbientModuleMarker = emptyResolution;
                for (let i = 0; i < moduleNames.length; i++) {
                    const moduleName = moduleNames[i];
                    if (file === oldSourceFile && !hasInvalidatedResolutions(oldSourceFile.path)) {
                        const mode = getModeForUsageLocation(file, moduleName);
                        const oldResolution = (_a3 = oldSourceFile.resolvedModules) == null ? void 0 : _a3.get(moduleName.text, mode);
                        if (oldResolution == null ? void 0 : oldResolution.resolvedModule) {
                            if (isTraceEnabled(options, host)) {
                                trace(host, oldResolution.resolvedModule.packageId ? Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2, moduleName.text, getNormalizedAbsolutePath(file.originalFileName, currentDirectory), oldResolution.resolvedModule.resolvedFileName, oldResolution.resolvedModule.packageId && packageIdToString(oldResolution.resolvedModule.packageId));
                            }
                            (result != null ? result : result = new Array(moduleNames.length))[i] = oldResolution;
                            (reusedNames != null ? reusedNames : reusedNames = []).push(moduleName);
                            continue;
                        }
                    }
                    let resolvesToAmbientModuleInNonModifiedFile = false;
                    if (contains(file.ambientModuleNames, moduleName.text)) {
                        resolvesToAmbientModuleInNonModifiedFile = true;
                        if (isTraceEnabled(options, host)) {
                            trace(host, Diagnostics.Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1, moduleName.text, getNormalizedAbsolutePath(file.originalFileName, currentDirectory));
                        }
                    }
                    else {
                        resolvesToAmbientModuleInNonModifiedFile = moduleNameResolvesToAmbientModuleInNonModifiedFile(moduleName);
                    }
                    if (resolvesToAmbientModuleInNonModifiedFile) {
                        (result || (result = new Array(moduleNames.length)))[i] = predictedToResolveToAmbientModuleMarker;
                    }
                    else {
                        (unknownModuleNames != null ? unknownModuleNames : unknownModuleNames = []).push(moduleName);
                    }
                }
                const resolutions = unknownModuleNames && unknownModuleNames.length ? resolveModuleNamesWorker(unknownModuleNames, file, reusedNames) : emptyArray;
                if (!result) {
                    Debug.assert(resolutions.length === moduleNames.length);
                    return resolutions;
                }
                let j = 0;
                for (let i = 0; i < result.length; i++) {
                    if (!result[i]) {
                        result[i] = resolutions[j];
                        j++;
                    }
                }
                Debug.assert(j === resolutions.length);
                return result;
                function moduleNameResolvesToAmbientModuleInNonModifiedFile(moduleName) {
                    const resolutionToFile = getResolvedModule(oldSourceFile, moduleName.text, getModeForUsageLocation(file, moduleName));
                    const resolvedFile = resolutionToFile && oldProgram.getSourceFile(resolutionToFile.resolvedFileName);
                    if (resolutionToFile && resolvedFile) {
                        return false;
                    }
                    const unmodifiedFile = ambientModuleNameToUnmodifiedFileName.get(moduleName.text);
                    if (!unmodifiedFile) {
                        return false;
                    }
                    if (isTraceEnabled(options, host)) {
                        trace(host, Diagnostics.Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified, moduleName.text, unmodifiedFile);
                    }
                    return true;
                }
            }
            function resolveTypeReferenceDirectiveNamesReusingOldState(typeDirectiveNames, containingFile) {
                var _a3;
                if (structureIsReused === 0 /* Not */) {
                    return resolveTypeReferenceDirectiveNamesWorker(typeDirectiveNames, containingFile, 
                    /*resuedNames*/
                    void 0);
                }
                const oldSourceFile = !isString(containingFile) ? oldProgram && oldProgram.getSourceFile(containingFile.fileName) : void 0;
                if (!isString(containingFile)) {
                    if (oldSourceFile !== containingFile && containingFile.resolvedTypeReferenceDirectiveNames) {
                        const result2 = [];
                        for (const typeDirectiveName of typeDirectiveNames) {
                            const resolvedTypeReferenceDirective = containingFile.resolvedTypeReferenceDirectiveNames.get(getTypeReferenceResolutionName(typeDirectiveName), getModeForFileReference(typeDirectiveName, containingFile.impliedNodeFormat));
                            result2.push(resolvedTypeReferenceDirective);
                        }
                        return result2;
                    }
                }
                let unknownTypeReferenceDirectiveNames;
                let result;
                let reusedNames;
                const containingSourceFile = !isString(containingFile) ? containingFile : void 0;
                const canReuseResolutions = !isString(containingFile) ? containingFile === oldSourceFile && !hasInvalidatedResolutions(oldSourceFile.path) : !hasInvalidatedResolutions(toPath3(containingFile));
                for (let i = 0; i < typeDirectiveNames.length; i++) {
                    const entry = typeDirectiveNames[i];
                    if (canReuseResolutions) {
                        const typeDirectiveName = getTypeReferenceResolutionName(entry);
                        const mode = getModeForFileReference(entry, containingSourceFile == null ? void 0 : containingSourceFile.impliedNodeFormat);
                        const oldResolution = (_a3 = !isString(containingFile) ? oldSourceFile == null ? void 0 : oldSourceFile.resolvedTypeReferenceDirectiveNames : oldProgram == null ? void 0 : oldProgram.getAutomaticTypeDirectiveResolutions()) == null ? void 0 : _a3.get(typeDirectiveName, mode);
                        if (oldResolution == null ? void 0 : oldResolution.resolvedTypeReferenceDirective) {
                            if (isTraceEnabled(options, host)) {
                                trace(host, oldResolution.resolvedTypeReferenceDirective.packageId ? Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2, typeDirectiveName, !isString(containingFile) ? getNormalizedAbsolutePath(containingFile.originalFileName, currentDirectory) : containingFile, oldResolution.resolvedTypeReferenceDirective.resolvedFileName, oldResolution.resolvedTypeReferenceDirective.packageId && packageIdToString(oldResolution.resolvedTypeReferenceDirective.packageId));
                            }
                            (result != null ? result : result = new Array(typeDirectiveNames.length))[i] = oldResolution;
                            (reusedNames != null ? reusedNames : reusedNames = []).push(entry);
                            continue;
                        }
                    }
                    (unknownTypeReferenceDirectiveNames != null ? unknownTypeReferenceDirectiveNames : unknownTypeReferenceDirectiveNames = []).push(entry);
                }
                if (!unknownTypeReferenceDirectiveNames)
                    return result || emptyArray;
                const resolutions = resolveTypeReferenceDirectiveNamesWorker(unknownTypeReferenceDirectiveNames, containingFile, reusedNames);
                if (!result) {
                    Debug.assert(resolutions.length === typeDirectiveNames.length);
                    return resolutions;
                }
                let j = 0;
                for (let i = 0; i < result.length; i++) {
                    if (!result[i]) {
                        result[i] = resolutions[j];
                        j++;
                    }
                }
                Debug.assert(j === resolutions.length);
                return result;
            }
            function canReuseProjectReferences() {
                return !forEachProjectReference(oldProgram.getProjectReferences(), oldProgram.getResolvedProjectReferences(), (oldResolvedRef, parent2, index) => {
                    const newRef = (parent2 ? parent2.commandLine.projectReferences : projectReferences)[index];
                    const newResolvedRef = parseProjectReferenceConfigFile(newRef);
                    if (oldResolvedRef) {
                        return !newResolvedRef || newResolvedRef.sourceFile !== oldResolvedRef.sourceFile || !arrayIsEqualTo(oldResolvedRef.commandLine.fileNames, newResolvedRef.commandLine.fileNames);
                    }
                    else {
                        return newResolvedRef !== void 0;
                    }
                }, (oldProjectReferences, parent2) => {
                    const newReferences = parent2 ? getResolvedProjectReferenceByPath(parent2.sourceFile.path).commandLine.projectReferences : projectReferences;
                    return !arrayIsEqualTo(oldProjectReferences, newReferences, projectReferenceIsEqualTo);
                });
            }
            function tryReuseStructureFromOldProgram() {
                var _a3;
                if (!oldProgram) {
                    return 0 /* Not */;
                }
                const oldOptions = oldProgram.getCompilerOptions();
                if (changesAffectModuleResolution(oldOptions, options)) {
                    return 0 /* Not */;
                }
                const oldRootNames = oldProgram.getRootFileNames();
                if (!arrayIsEqualTo(oldRootNames, rootNames)) {
                    return 0 /* Not */;
                }
                if (!canReuseProjectReferences()) {
                    return 0 /* Not */;
                }
                if (projectReferences) {
                    resolvedProjectReferences = projectReferences.map(parseProjectReferenceConfigFile);
                }
                const newSourceFiles = [];
                const modifiedSourceFiles = [];
                structureIsReused = 2 /* Completely */;
                if (oldProgram.getMissingFilePaths().some((missingFilePath) => host.fileExists(missingFilePath))) {
                    return 0 /* Not */;
                }
                const oldSourceFiles = oldProgram.getSourceFiles();
                let SeenPackageName;
                ((SeenPackageName2) => {
                    SeenPackageName2[SeenPackageName2["Exists"] = 0] = "Exists";
                    SeenPackageName2[SeenPackageName2["Modified"] = 1] = "Modified";
                })(SeenPackageName || (SeenPackageName = {}));
                const seenPackageNames = /* @__PURE__ */ new Map();
                for (const oldSourceFile of oldSourceFiles) {
                    const sourceFileOptions = getCreateSourceFileOptions(oldSourceFile.fileName, moduleResolutionCache, host, options);
                    let newSourceFile = host.getSourceFileByPath ? host.getSourceFileByPath(oldSourceFile.fileName, oldSourceFile.resolvedPath, sourceFileOptions, 
                    /*onError*/
                    void 0, shouldCreateNewSourceFile || sourceFileOptions.impliedNodeFormat !== oldSourceFile.impliedNodeFormat) : host.getSourceFile(oldSourceFile.fileName, sourceFileOptions, 
                    /*onError*/
                    void 0, shouldCreateNewSourceFile || sourceFileOptions.impliedNodeFormat !== oldSourceFile.impliedNodeFormat);
                    if (!newSourceFile) {
                        return 0 /* Not */;
                    }
                    newSourceFile.packageJsonLocations = ((_a3 = sourceFileOptions.packageJsonLocations) == null ? void 0 : _a3.length) ? sourceFileOptions.packageJsonLocations : void 0;
                    newSourceFile.packageJsonScope = sourceFileOptions.packageJsonScope;
                    Debug.assert(!newSourceFile.redirectInfo, "Host should not return a redirect source file from `getSourceFile`");
                    let fileChanged;
                    if (oldSourceFile.redirectInfo) {
                        if (newSourceFile !== oldSourceFile.redirectInfo.unredirected) {
                            return 0 /* Not */;
                        }
                        fileChanged = false;
                        newSourceFile = oldSourceFile;
                    }
                    else if (oldProgram.redirectTargetsMap.has(oldSourceFile.path)) {
                        if (newSourceFile !== oldSourceFile) {
                            return 0 /* Not */;
                        }
                        fileChanged = false;
                    }
                    else {
                        fileChanged = newSourceFile !== oldSourceFile;
                    }
                    newSourceFile.path = oldSourceFile.path;
                    newSourceFile.originalFileName = oldSourceFile.originalFileName;
                    newSourceFile.resolvedPath = oldSourceFile.resolvedPath;
                    newSourceFile.fileName = oldSourceFile.fileName;
                    const packageName = oldProgram.sourceFileToPackageName.get(oldSourceFile.path);
                    if (packageName !== void 0) {
                        const prevKind = seenPackageNames.get(packageName);
                        const newKind = fileChanged ? 1 /* Modified */ : 0 /* Exists */;
                        if (prevKind !== void 0 && newKind === 1 /* Modified */ || prevKind === 1 /* Modified */) {
                            return 0 /* Not */;
                        }
                        seenPackageNames.set(packageName, newKind);
                    }
                    if (fileChanged) {
                        if (oldSourceFile.impliedNodeFormat !== newSourceFile.impliedNodeFormat) {
                            structureIsReused = 1 /* SafeModules */;
                        }
                        else if (!arrayIsEqualTo(oldSourceFile.libReferenceDirectives, newSourceFile.libReferenceDirectives, fileReferenceIsEqualTo)) {
                            structureIsReused = 1 /* SafeModules */;
                        }
                        else if (oldSourceFile.hasNoDefaultLib !== newSourceFile.hasNoDefaultLib) {
                            structureIsReused = 1 /* SafeModules */;
                        }
                        else if (!arrayIsEqualTo(oldSourceFile.referencedFiles, newSourceFile.referencedFiles, fileReferenceIsEqualTo)) {
                            structureIsReused = 1 /* SafeModules */;
                        }
                        else {
                            collectExternalModuleReferences(newSourceFile);
                            if (!arrayIsEqualTo(oldSourceFile.imports, newSourceFile.imports, moduleNameIsEqualTo)) {
                                structureIsReused = 1 /* SafeModules */;
                            }
                            else if (!arrayIsEqualTo(oldSourceFile.moduleAugmentations, newSourceFile.moduleAugmentations, moduleNameIsEqualTo)) {
                                structureIsReused = 1 /* SafeModules */;
                            }
                            else if ((oldSourceFile.flags & 6291456 /* PermanentlySetIncrementalFlags */) !== (newSourceFile.flags & 6291456 /* PermanentlySetIncrementalFlags */)) {
                                structureIsReused = 1 /* SafeModules */;
                            }
                            else if (!arrayIsEqualTo(oldSourceFile.typeReferenceDirectives, newSourceFile.typeReferenceDirectives, fileReferenceIsEqualTo)) {
                                structureIsReused = 1 /* SafeModules */;
                            }
                        }
                        modifiedSourceFiles.push({ oldFile: oldSourceFile, newFile: newSourceFile });
                    }
                    else if (hasInvalidatedResolutions(oldSourceFile.path)) {
                        structureIsReused = 1 /* SafeModules */;
                        modifiedSourceFiles.push({ oldFile: oldSourceFile, newFile: newSourceFile });
                    }
                    newSourceFiles.push(newSourceFile);
                }
                if (structureIsReused !== 2 /* Completely */) {
                    return structureIsReused;
                }
                const modifiedFiles = modifiedSourceFiles.map((f) => f.oldFile);
                for (const oldFile of oldSourceFiles) {
                    if (!contains(modifiedFiles, oldFile)) {
                        for (const moduleName of oldFile.ambientModuleNames) {
                            ambientModuleNameToUnmodifiedFileName.set(moduleName, oldFile.fileName);
                        }
                    }
                }
                for (const { oldFile: oldSourceFile, newFile: newSourceFile } of modifiedSourceFiles) {
                    const moduleNames = getModuleNames(newSourceFile);
                    const resolutions = resolveModuleNamesReusingOldState(moduleNames, newSourceFile);
                    const resolutionsChanged = hasChangesInResolutions(moduleNames, newSourceFile, resolutions, oldSourceFile.resolvedModules, moduleResolutionIsEqualTo, moduleResolutionNameAndModeGetter);
                    if (resolutionsChanged) {
                        structureIsReused = 1 /* SafeModules */;
                        newSourceFile.resolvedModules = zipToModeAwareCache(newSourceFile, moduleNames, resolutions, moduleResolutionNameAndModeGetter);
                    }
                    else {
                        newSourceFile.resolvedModules = oldSourceFile.resolvedModules;
                    }
                    const typesReferenceDirectives = newSourceFile.typeReferenceDirectives;
                    const typeReferenceResolutions = resolveTypeReferenceDirectiveNamesReusingOldState(typesReferenceDirectives, newSourceFile);
                    const typeReferenceResolutionsChanged = hasChangesInResolutions(typesReferenceDirectives, newSourceFile, typeReferenceResolutions, oldSourceFile.resolvedTypeReferenceDirectiveNames, typeDirectiveIsEqualTo, typeReferenceResolutionNameAndModeGetter);
                    if (typeReferenceResolutionsChanged) {
                        structureIsReused = 1 /* SafeModules */;
                        newSourceFile.resolvedTypeReferenceDirectiveNames = zipToModeAwareCache(newSourceFile, typesReferenceDirectives, typeReferenceResolutions, typeReferenceResolutionNameAndModeGetter);
                    }
                    else {
                        newSourceFile.resolvedTypeReferenceDirectiveNames = oldSourceFile.resolvedTypeReferenceDirectiveNames;
                    }
                }
                if (structureIsReused !== 2 /* Completely */) {
                    return structureIsReused;
                }
                if (changesAffectingProgramStructure(oldOptions, options)) {
                    return 1 /* SafeModules */;
                }
                if (host.hasChangedAutomaticTypeDirectiveNames) {
                    if (host.hasChangedAutomaticTypeDirectiveNames())
                        return 1 /* SafeModules */;
                }
                else {
                    automaticTypeDirectiveNames = getAutomaticTypeDirectiveNames(options, host);
                    if (!arrayIsEqualTo(oldProgram.getAutomaticTypeDirectiveNames(), automaticTypeDirectiveNames))
                        return 1 /* SafeModules */;
                }
                missingFilePaths = oldProgram.getMissingFilePaths();
                Debug.assert(newSourceFiles.length === oldProgram.getSourceFiles().length);
                for (const newSourceFile of newSourceFiles) {
                    filesByName.set(newSourceFile.path, newSourceFile);
                }
                const oldFilesByNameMap = oldProgram.getFilesByNameMap();
                oldFilesByNameMap.forEach((oldFile, path) => {
                    if (!oldFile) {
                        filesByName.set(path, oldFile);
                        return;
                    }
                    if (oldFile.path === path) {
                        if (oldProgram.isSourceFileFromExternalLibrary(oldFile)) {
                            sourceFilesFoundSearchingNodeModules.set(oldFile.path, true);
                        }
                        return;
                    }
                    filesByName.set(path, filesByName.get(oldFile.path));
                });
                files = newSourceFiles;
                fileReasons = oldProgram.getFileIncludeReasons();
                fileProcessingDiagnostics = oldProgram.getFileProcessingDiagnostics();
                resolvedTypeReferenceDirectives = oldProgram.getResolvedTypeReferenceDirectives();
                automaticTypeDirectiveNames = oldProgram.getAutomaticTypeDirectiveNames();
                automaticTypeDirectiveResolutions = oldProgram.getAutomaticTypeDirectiveResolutions();
                sourceFileToPackageName = oldProgram.sourceFileToPackageName;
                redirectTargetsMap = oldProgram.redirectTargetsMap;
                usesUriStyleNodeCoreModules = oldProgram.usesUriStyleNodeCoreModules;
                return 2 /* Completely */;
            }
            function getEmitHost(writeFileCallback) {
                return {
                    getPrependNodes,
                    getCanonicalFileName,
                    getCommonSourceDirectory: program.getCommonSourceDirectory,
                    getCompilerOptions: program.getCompilerOptions,
                    getCurrentDirectory: () => currentDirectory,
                    getSourceFile: program.getSourceFile,
                    getSourceFileByPath: program.getSourceFileByPath,
                    getSourceFiles: program.getSourceFiles,
                    getLibFileFromReference: program.getLibFileFromReference,
                    isSourceFileFromExternalLibrary,
                    getResolvedProjectReferenceToRedirect,
                    getProjectReferenceRedirect,
                    isSourceOfProjectReferenceRedirect,
                    getSymlinkCache,
                    writeFile: writeFileCallback || writeFile2,
                    isEmitBlocked,
                    readFile: (f) => host.readFile(f),
                    fileExists: (f) => {
                        const path = toPath3(f);
                        if (getSourceFileByPath(path))
                            return true;
                        if (contains(missingFilePaths, path))
                            return false;
                        return host.fileExists(f);
                    },
                    useCaseSensitiveFileNames: () => host.useCaseSensitiveFileNames(),
                    getBuildInfo: (bundle) => {
                        var _a3;
                        return (_a3 = program.getBuildInfo) == null ? void 0 : _a3.call(program, bundle);
                    },
                    getSourceFileFromReference: (file, ref) => program.getSourceFileFromReference(file, ref),
                    redirectTargetsMap,
                    getFileIncludeReasons: program.getFileIncludeReasons,
                    createHash: maybeBind(host, host.createHash)
                };
            }
            function writeFile2(fileName, text, writeByteOrderMark, onError, sourceFiles, data) {
                host.writeFile(fileName, text, writeByteOrderMark, onError, sourceFiles, data);
            }
            function emitBuildInfo(writeFileCallback) {
                var _a3, _b2;
                Debug.assert(!outFile(options));
                (_a3 = tracing) == null ? void 0 : _a3.push(tracing.Phase.Emit, "emitBuildInfo", {}, 
                /*separateBeginAndEnd*/
                true);
                mark("beforeEmit");
                const emitResult = emitFiles(notImplementedResolver, getEmitHost(writeFileCallback), 
                /*targetSourceFile*/
                void 0, 
                /*transformers*/
                noTransformers, 
                /*emitOnlyDtsFiles*/
                false, 
                /*onlyBuildInfo*/
                true);
                mark("afterEmit");
                measure("Emit", "beforeEmit", "afterEmit");
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return emitResult;
            }
            function getResolvedProjectReferences() {
                return resolvedProjectReferences;
            }
            function getProjectReferences() {
                return projectReferences;
            }
            function getPrependNodes() {
                return createPrependNodes(projectReferences, (_ref, index) => {
                    var _a3;
                    return (_a3 = resolvedProjectReferences[index]) == null ? void 0 : _a3.commandLine;
                }, (fileName) => {
                    const path = toPath3(fileName);
                    const sourceFile = getSourceFileByPath(path);
                    return sourceFile ? sourceFile.text : filesByName.has(path) ? void 0 : host.readFile(path);
                }, host);
            }
            function isSourceFileFromExternalLibrary(file) {
                return !!sourceFilesFoundSearchingNodeModules.get(file.path);
            }
            function isSourceFileDefaultLibrary(file) {
                if (!file.isDeclarationFile) {
                    return false;
                }
                if (file.hasNoDefaultLib) {
                    return true;
                }
                if (!options.noLib) {
                    return false;
                }
                const equalityComparer = host.useCaseSensitiveFileNames() ? equateStringsCaseSensitive : equateStringsCaseInsensitive;
                if (!options.lib) {
                    return equalityComparer(file.fileName, getDefaultLibraryFileName());
                }
                else {
                    return some(options.lib, (libFileName) => equalityComparer(file.fileName, pathForLibFile(libFileName)));
                }
            }
            function getTypeChecker() {
                return typeChecker || (typeChecker = createTypeChecker(program));
            }
            function emit(sourceFile, writeFileCallback, cancellationToken, emitOnly, transformers, forceDtsEmit) {
                var _a3, _b2;
                (_a3 = tracing) == null ? void 0 : _a3.push(tracing.Phase.Emit, "emit", { path: sourceFile == null ? void 0 : sourceFile.path }, 
                /*separateBeginAndEnd*/
                true);
                const result = runWithCancellationToken(() => emitWorker(program, sourceFile, writeFileCallback, cancellationToken, emitOnly, transformers, forceDtsEmit));
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return result;
            }
            function isEmitBlocked(emitFileName) {
                return hasEmitBlockingDiagnostics.has(toPath3(emitFileName));
            }
            function emitWorker(program2, sourceFile, writeFileCallback, cancellationToken, emitOnly, customTransformers, forceDtsEmit) {
                if (!forceDtsEmit) {
                    const result = handleNoEmitOptions(program2, sourceFile, writeFileCallback, cancellationToken);
                    if (result)
                        return result;
                }
                const emitResolver = getTypeChecker().getEmitResolver(outFile(options) ? void 0 : sourceFile, cancellationToken);
                mark("beforeEmit");
                const emitResult = emitFiles(emitResolver, getEmitHost(writeFileCallback), sourceFile, getTransformers(options, customTransformers, emitOnly), emitOnly, 
                /*onlyBuildInfo*/
                false, forceDtsEmit);
                mark("afterEmit");
                measure("Emit", "beforeEmit", "afterEmit");
                return emitResult;
            }
            function getSourceFile(fileName) {
                return getSourceFileByPath(toPath3(fileName));
            }
            function getSourceFileByPath(path) {
                return filesByName.get(path) || void 0;
            }
            function getDiagnosticsHelper(sourceFile, getDiagnostics2, cancellationToken) {
                if (sourceFile) {
                    return sortAndDeduplicateDiagnostics(getDiagnostics2(sourceFile, cancellationToken));
                }
                return sortAndDeduplicateDiagnostics(flatMap(program.getSourceFiles(), (sourceFile2) => {
                    if (cancellationToken) {
                        cancellationToken.throwIfCancellationRequested();
                    }
                    return getDiagnostics2(sourceFile2, cancellationToken);
                }));
            }
            function getSyntacticDiagnostics(sourceFile, cancellationToken) {
                return getDiagnosticsHelper(sourceFile, getSyntacticDiagnosticsForFile, cancellationToken);
            }
            function getSemanticDiagnostics(sourceFile, cancellationToken) {
                return getDiagnosticsHelper(sourceFile, getSemanticDiagnosticsForFile, cancellationToken);
            }
            function getCachedSemanticDiagnostics(sourceFile) {
                var _a3;
                return sourceFile ? (_a3 = cachedBindAndCheckDiagnosticsForFile.perFile) == null ? void 0 : _a3.get(sourceFile.path) : cachedBindAndCheckDiagnosticsForFile.allDiagnostics;
            }
            function getBindAndCheckDiagnostics(sourceFile, cancellationToken) {
                return getBindAndCheckDiagnosticsForFile(sourceFile, cancellationToken);
            }
            function getProgramDiagnostics(sourceFile) {
                var _a3;
                if (skipTypeChecking(sourceFile, options, program)) {
                    return emptyArray;
                }
                const programDiagnosticsInFile = programDiagnostics.getDiagnostics(sourceFile.fileName);
                if (!((_a3 = sourceFile.commentDirectives) == null ? void 0 : _a3.length)) {
                    return programDiagnosticsInFile;
                }
                return getDiagnosticsWithPrecedingDirectives(sourceFile, sourceFile.commentDirectives, programDiagnosticsInFile).diagnostics;
            }
            function getDeclarationDiagnostics2(sourceFile, cancellationToken) {
                const options2 = program.getCompilerOptions();
                if (!sourceFile || outFile(options2)) {
                    return getDeclarationDiagnosticsWorker(sourceFile, cancellationToken);
                }
                else {
                    return getDiagnosticsHelper(sourceFile, getDeclarationDiagnosticsForFile, cancellationToken);
                }
            }
            function getSyntacticDiagnosticsForFile(sourceFile) {
                if (isSourceFileJS(sourceFile)) {
                    if (!sourceFile.additionalSyntacticDiagnostics) {
                        sourceFile.additionalSyntacticDiagnostics = getJSSyntacticDiagnosticsForFile(sourceFile);
                    }
                    return concatenate(sourceFile.additionalSyntacticDiagnostics, sourceFile.parseDiagnostics);
                }
                return sourceFile.parseDiagnostics;
            }
            function runWithCancellationToken(func) {
                try {
                    return func();
                }
                catch (e) {
                    if (e instanceof OperationCanceledException) {
                        typeChecker = void 0;
                    }
                    throw e;
                }
            }
            function getSemanticDiagnosticsForFile(sourceFile, cancellationToken) {
                return concatenate(filterSemanticDiagnostics(getBindAndCheckDiagnosticsForFile(sourceFile, cancellationToken), options), getProgramDiagnostics(sourceFile));
            }
            function getBindAndCheckDiagnosticsForFile(sourceFile, cancellationToken) {
                return getAndCacheDiagnostics(sourceFile, cancellationToken, cachedBindAndCheckDiagnosticsForFile, getBindAndCheckDiagnosticsForFileNoCache);
            }
            function getBindAndCheckDiagnosticsForFileNoCache(sourceFile, cancellationToken) {
                return runWithCancellationToken(() => {
                    if (skipTypeChecking(sourceFile, options, program)) {
                        return emptyArray;
                    }
                    const typeChecker2 = getTypeChecker();
                    Debug.assert(!!sourceFile.bindDiagnostics);
                    const isJs = sourceFile.scriptKind === 1 /* JS */ || sourceFile.scriptKind === 2 /* JSX */;
                    const isCheckJs = isJs && isCheckJsEnabledForFile(sourceFile, options);
                    const isPlainJs = isPlainJsFile(sourceFile, options.checkJs);
                    const isTsNoCheck = !!sourceFile.checkJsDirective && sourceFile.checkJsDirective.enabled === false;
                    const includeBindAndCheckDiagnostics = !isTsNoCheck && (sourceFile.scriptKind === 3 /* TS */ || sourceFile.scriptKind === 4 /* TSX */ || sourceFile.scriptKind === 5 /* External */ || isPlainJs || isCheckJs || sourceFile.scriptKind === 7 /* Deferred */);
                    let bindDiagnostics = includeBindAndCheckDiagnostics ? sourceFile.bindDiagnostics : emptyArray;
                    let checkDiagnostics = includeBindAndCheckDiagnostics ? typeChecker2.getDiagnostics(sourceFile, cancellationToken) : emptyArray;
                    if (isPlainJs) {
                        bindDiagnostics = filter(bindDiagnostics, (d) => plainJSErrors.has(d.code));
                        checkDiagnostics = filter(checkDiagnostics, (d) => plainJSErrors.has(d.code));
                    }
                    return getMergedBindAndCheckDiagnostics(sourceFile, includeBindAndCheckDiagnostics && !isPlainJs, bindDiagnostics, checkDiagnostics, isCheckJs ? sourceFile.jsDocDiagnostics : void 0);
                });
            }
            function getMergedBindAndCheckDiagnostics(sourceFile, includeBindAndCheckDiagnostics, ...allDiagnostics) {
                var _a3;
                const flatDiagnostics = flatten(allDiagnostics);
                if (!includeBindAndCheckDiagnostics || !((_a3 = sourceFile.commentDirectives) == null ? void 0 : _a3.length)) {
                    return flatDiagnostics;
                }
                const { diagnostics, directives } = getDiagnosticsWithPrecedingDirectives(sourceFile, sourceFile.commentDirectives, flatDiagnostics);
                for (const errorExpectation of directives.getUnusedExpectations()) {
                    diagnostics.push(createDiagnosticForRange(sourceFile, errorExpectation.range, Diagnostics.Unused_ts_expect_error_directive));
                }
                return diagnostics;
            }
            function getDiagnosticsWithPrecedingDirectives(sourceFile, commentDirectives, flatDiagnostics) {
                const directives = createCommentDirectivesMap(sourceFile, commentDirectives);
                const diagnostics = flatDiagnostics.filter((diagnostic) => markPrecedingCommentDirectiveLine(diagnostic, directives) === -1);
                return { diagnostics, directives };
            }
            function getSuggestionDiagnostics(sourceFile, cancellationToken) {
                return runWithCancellationToken(() => {
                    return getTypeChecker().getSuggestionDiagnostics(sourceFile, cancellationToken);
                });
            }
            function markPrecedingCommentDirectiveLine(diagnostic, directives) {
                const { file, start } = diagnostic;
                if (!file) {
                    return -1;
                }
                const lineStarts = getLineStarts(file);
                let line = computeLineAndCharacterOfPosition(lineStarts, start).line - 1;
                while (line >= 0) {
                    if (directives.markUsed(line)) {
                        return line;
                    }
                    const lineText = file.text.slice(lineStarts[line], lineStarts[line + 1]).trim();
                    if (lineText !== "" && !/^(\s*)\/\/(.*)$/.test(lineText)) {
                        return -1;
                    }
                    line--;
                }
                return -1;
            }
            function getJSSyntacticDiagnosticsForFile(sourceFile) {
                return runWithCancellationToken(() => {
                    const diagnostics = [];
                    walk(sourceFile, sourceFile);
                    forEachChildRecursively(sourceFile, walk, walkArray);
                    return diagnostics;
                    function walk(node, parent2) {
                        switch (parent2.kind) {
                            case 166 /* Parameter */:
                            case 169 /* PropertyDeclaration */:
                            case 171 /* MethodDeclaration */:
                                if (parent2.questionToken === node) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files, "?"));
                                    return "skip";
                                }
                            case 170 /* MethodSignature */:
                            case 173 /* Constructor */:
                            case 174 /* GetAccessor */:
                            case 175 /* SetAccessor */:
                            case 215 /* FunctionExpression */:
                            case 259 /* FunctionDeclaration */:
                            case 216 /* ArrowFunction */:
                            case 257 /* VariableDeclaration */:
                                if (parent2.type === node) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics.Type_annotations_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                        }
                        switch (node.kind) {
                            case 270 /* ImportClause */:
                                if (node.isTypeOnly) {
                                    diagnostics.push(createDiagnosticForNode2(parent2, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, "import type"));
                                    return "skip";
                                }
                                break;
                            case 275 /* ExportDeclaration */:
                                if (node.isTypeOnly) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, "export type"));
                                    return "skip";
                                }
                                break;
                            case 273 /* ImportSpecifier */:
                            case 278 /* ExportSpecifier */:
                                if (node.isTypeOnly) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, isImportSpecifier(node) ? "import...type" : "export...type"));
                                    return "skip";
                                }
                                break;
                            case 268 /* ImportEqualsDeclaration */:
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics.import_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 274 /* ExportAssignment */:
                                if (node.isExportEquals) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics.export_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                                break;
                            case 294 /* HeritageClause */:
                                const heritageClause = node;
                                if (heritageClause.token === 117 /* ImplementsKeyword */) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics.implements_clauses_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                                break;
                            case 261 /* InterfaceDeclaration */:
                                const interfaceKeyword = tokenToString(118 /* InterfaceKeyword */);
                                Debug.assertIsDefined(interfaceKeyword);
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, interfaceKeyword));
                                return "skip";
                            case 264 /* ModuleDeclaration */:
                                const moduleKeyword = node.flags & 16 /* Namespace */ ? tokenToString(143 /* NamespaceKeyword */) : tokenToString(142 /* ModuleKeyword */);
                                Debug.assertIsDefined(moduleKeyword);
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, moduleKeyword));
                                return "skip";
                            case 262 /* TypeAliasDeclaration */:
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics.Type_aliases_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 263 /* EnumDeclaration */:
                                const enumKeyword = Debug.checkDefined(tokenToString(92 /* EnumKeyword */));
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, enumKeyword));
                                return "skip";
                            case 232 /* NonNullExpression */:
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics.Non_null_assertions_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 231 /* AsExpression */:
                                diagnostics.push(createDiagnosticForNode2(node.type, Diagnostics.Type_assertion_expressions_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 235 /* SatisfiesExpression */:
                                diagnostics.push(createDiagnosticForNode2(node.type, Diagnostics.Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 213 /* TypeAssertionExpression */:
                                Debug.fail();
                        }
                    }
                    function walkArray(nodes, parent2) {
                        if (canHaveIllegalDecorators(parent2)) {
                            const decorator = find(parent2.modifiers, isDecorator);
                            if (decorator) {
                                diagnostics.push(createDiagnosticForNode2(decorator, Diagnostics.Decorators_are_not_valid_here));
                            }
                        }
                        else if (canHaveDecorators(parent2) && parent2.modifiers) {
                            const decoratorIndex = findIndex(parent2.modifiers, isDecorator);
                            if (decoratorIndex >= 0) {
                                if (isParameter(parent2) && !options.experimentalDecorators) {
                                    diagnostics.push(createDiagnosticForNode2(parent2.modifiers[decoratorIndex], Diagnostics.Decorators_are_not_valid_here));
                                }
                                else if (isClassDeclaration(parent2)) {
                                    const exportIndex = findIndex(parent2.modifiers, isExportModifier);
                                    if (exportIndex >= 0) {
                                        const defaultIndex = findIndex(parent2.modifiers, isDefaultModifier);
                                        if (decoratorIndex > exportIndex && defaultIndex >= 0 && decoratorIndex < defaultIndex) {
                                            diagnostics.push(createDiagnosticForNode2(parent2.modifiers[decoratorIndex], Diagnostics.Decorators_are_not_valid_here));
                                        }
                                        else if (exportIndex >= 0 && decoratorIndex < exportIndex) {
                                            const trailingDecoratorIndex = findIndex(parent2.modifiers, isDecorator, exportIndex);
                                            if (trailingDecoratorIndex >= 0) {
                                                diagnostics.push(addRelatedInfo(createDiagnosticForNode2(parent2.modifiers[trailingDecoratorIndex], Diagnostics.Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export), createDiagnosticForNode2(parent2.modifiers[decoratorIndex], Diagnostics.Decorator_used_before_export_here)));
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        switch (parent2.kind) {
                            case 260 /* ClassDeclaration */:
                            case 228 /* ClassExpression */:
                            case 171 /* MethodDeclaration */:
                            case 173 /* Constructor */:
                            case 174 /* GetAccessor */:
                            case 175 /* SetAccessor */:
                            case 215 /* FunctionExpression */:
                            case 259 /* FunctionDeclaration */:
                            case 216 /* ArrowFunction */:
                                if (nodes === parent2.typeParameters) {
                                    diagnostics.push(createDiagnosticForNodeArray2(nodes, Diagnostics.Type_parameter_declarations_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                            case 240 /* VariableStatement */:
                                if (nodes === parent2.modifiers) {
                                    checkModifiers(parent2.modifiers, parent2.kind === 240 /* VariableStatement */);
                                    return "skip";
                                }
                                break;
                            case 169 /* PropertyDeclaration */:
                                if (nodes === parent2.modifiers) {
                                    for (const modifier of nodes) {
                                        if (isModifier(modifier) && modifier.kind !== 124 /* StaticKeyword */ && modifier.kind !== 127 /* AccessorKeyword */) {
                                            diagnostics.push(createDiagnosticForNode2(modifier, Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files, tokenToString(modifier.kind)));
                                        }
                                    }
                                    return "skip";
                                }
                                break;
                            case 166 /* Parameter */:
                                if (nodes === parent2.modifiers && some(nodes, isModifier)) {
                                    diagnostics.push(createDiagnosticForNodeArray2(nodes, Diagnostics.Parameter_modifiers_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                                break;
                            case 210 /* CallExpression */:
                            case 211 /* NewExpression */:
                            case 230 /* ExpressionWithTypeArguments */:
                            case 282 /* JsxSelfClosingElement */:
                            case 283 /* JsxOpeningElement */:
                            case 212 /* TaggedTemplateExpression */:
                                if (nodes === parent2.typeArguments) {
                                    diagnostics.push(createDiagnosticForNodeArray2(nodes, Diagnostics.Type_arguments_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                                break;
                        }
                    }
                    function checkModifiers(modifiers, isConstValid) {
                        for (const modifier of modifiers) {
                            switch (modifier.kind) {
                                case 85 /* ConstKeyword */:
                                    if (isConstValid) {
                                        continue;
                                    }
                                case 123 /* PublicKeyword */:
                                case 121 /* PrivateKeyword */:
                                case 122 /* ProtectedKeyword */:
                                case 146 /* ReadonlyKeyword */:
                                case 136 /* DeclareKeyword */:
                                case 126 /* AbstractKeyword */:
                                case 161 /* OverrideKeyword */:
                                case 101 /* InKeyword */:
                                case 145 /* OutKeyword */:
                                    diagnostics.push(createDiagnosticForNode2(modifier, Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files, tokenToString(modifier.kind)));
                                    break;
                                case 124 /* StaticKeyword */:
                                case 93 /* ExportKeyword */:
                                case 88 /* DefaultKeyword */:
                                case 127 /* AccessorKeyword */:
                            }
                        }
                    }
                    function createDiagnosticForNodeArray2(nodes, message, arg0, arg1, arg2) {
                        const start = nodes.pos;
                        return createFileDiagnostic(sourceFile, start, nodes.end - start, message, arg0, arg1, arg2);
                    }
                    function createDiagnosticForNode2(node, message, arg0, arg1, arg2) {
                        return createDiagnosticForNodeInSourceFile(sourceFile, node, message, arg0, arg1, arg2);
                    }
                });
            }
            function getDeclarationDiagnosticsWorker(sourceFile, cancellationToken) {
                return getAndCacheDiagnostics(sourceFile, cancellationToken, cachedDeclarationDiagnosticsForFile, getDeclarationDiagnosticsForFileNoCache);
            }
            function getDeclarationDiagnosticsForFileNoCache(sourceFile, cancellationToken) {
                return runWithCancellationToken(() => {
                    const resolver = getTypeChecker().getEmitResolver(sourceFile, cancellationToken);
                    return getDeclarationDiagnostics(getEmitHost(noop), resolver, sourceFile) || emptyArray;
                });
            }
            function getAndCacheDiagnostics(sourceFile, cancellationToken, cache, getDiagnostics2) {
                var _a3;
                const cachedResult = sourceFile ? (_a3 = cache.perFile) == null ? void 0 : _a3.get(sourceFile.path) : cache.allDiagnostics;
                if (cachedResult) {
                    return cachedResult;
                }
                const result = getDiagnostics2(sourceFile, cancellationToken);
                if (sourceFile) {
                    (cache.perFile || (cache.perFile = /* @__PURE__ */ new Map())).set(sourceFile.path, result);
                }
                else {
                    cache.allDiagnostics = result;
                }
                return result;
            }
            function getDeclarationDiagnosticsForFile(sourceFile, cancellationToken) {
                return sourceFile.isDeclarationFile ? [] : getDeclarationDiagnosticsWorker(sourceFile, cancellationToken);
            }
            function getOptionsDiagnostics() {
                return sortAndDeduplicateDiagnostics(concatenate(programDiagnostics.getGlobalDiagnostics(), getOptionsDiagnosticsOfConfigFile()));
            }
            function getOptionsDiagnosticsOfConfigFile() {
                if (!options.configFile)
                    return emptyArray;
                let diagnostics = programDiagnostics.getDiagnostics(options.configFile.fileName);
                forEachResolvedProjectReference2((resolvedRef) => {
                    diagnostics = concatenate(diagnostics, programDiagnostics.getDiagnostics(resolvedRef.sourceFile.fileName));
                });
                return diagnostics;
            }
            function getGlobalDiagnostics() {
                return rootNames.length ? sortAndDeduplicateDiagnostics(getTypeChecker().getGlobalDiagnostics().slice()) : emptyArray;
            }
            function getConfigFileParsingDiagnostics2() {
                return configFileParsingDiagnostics || emptyArray;
            }
            function processRootFile(fileName, isDefaultLib, ignoreNoDefaultLib, reason) {
                processSourceFile(normalizePath(fileName), isDefaultLib, ignoreNoDefaultLib, 
                /*packageId*/
                void 0, reason);
            }
            function fileReferenceIsEqualTo(a, b) {
                return a.fileName === b.fileName;
            }
            function moduleNameIsEqualTo(a, b) {
                return a.kind === 79 /* Identifier */ ? b.kind === 79 /* Identifier */ && a.escapedText === b.escapedText : b.kind === 10 /* StringLiteral */ && a.text === b.text;
            }
            function createSyntheticImport(text, file) {
                const externalHelpersModuleReference = factory.createStringLiteral(text);
                const importDecl = factory.createImportDeclaration(
                /*modifiers*/
                void 0, 
                /*importClause*/
                void 0, externalHelpersModuleReference, 
                /*assertClause*/
                void 0);
                addInternalEmitFlags(importDecl, 2 /* NeverApplyImportHelper */);
                setParent(externalHelpersModuleReference, importDecl);
                setParent(importDecl, file);
                externalHelpersModuleReference.flags &= ~8 /* Synthesized */;
                importDecl.flags &= ~8 /* Synthesized */;
                return externalHelpersModuleReference;
            }
            function collectExternalModuleReferences(file) {
                if (file.imports) {
                    return;
                }
                const isJavaScriptFile = isSourceFileJS(file);
                const isExternalModuleFile = isExternalModule(file);
                let imports;
                let moduleAugmentations;
                let ambientModules;
                if ((getIsolatedModules(options) || isExternalModuleFile) && !file.isDeclarationFile) {
                    if (options.importHelpers) {
                        imports = [createSyntheticImport(externalHelpersModuleNameText, file)];
                    }
                    const jsxImport = getJSXRuntimeImport(getJSXImplicitImportBase(options, file), options);
                    if (jsxImport) {
                        (imports || (imports = [])).push(createSyntheticImport(jsxImport, file));
                    }
                }
                for (const node of file.statements) {
                    collectModuleReferences(node, 
                    /*inAmbientModule*/
                    false);
                }
                const shouldProcessRequires = isJavaScriptFile && shouldResolveJsRequire(options);
                if (file.flags & 2097152 /* PossiblyContainsDynamicImport */ || shouldProcessRequires) {
                    collectDynamicImportOrRequireCalls(file);
                }
                file.imports = imports || emptyArray;
                file.moduleAugmentations = moduleAugmentations || emptyArray;
                file.ambientModuleNames = ambientModules || emptyArray;
                return;
                function collectModuleReferences(node, inAmbientModule) {
                    if (isAnyImportOrReExport(node)) {
                        const moduleNameExpr = getExternalModuleName(node);
                        if (moduleNameExpr && isStringLiteral(moduleNameExpr) && moduleNameExpr.text && (!inAmbientModule || !isExternalModuleNameRelative(moduleNameExpr.text))) {
                            setParentRecursive(node, 
                            /*incremental*/
                            false);
                            imports = append(imports, moduleNameExpr);
                            if (!usesUriStyleNodeCoreModules && currentNodeModulesDepth === 0 && !file.isDeclarationFile) {
                                usesUriStyleNodeCoreModules = startsWith(moduleNameExpr.text, "node:");
                            }
                        }
                    }
                    else if (isModuleDeclaration(node)) {
                        if (isAmbientModule(node) && (inAmbientModule || hasSyntacticModifier(node, 2 /* Ambient */) || file.isDeclarationFile)) {
                            node.name.parent = node;
                            const nameText = getTextOfIdentifierOrLiteral(node.name);
                            if (isExternalModuleFile || inAmbientModule && !isExternalModuleNameRelative(nameText)) {
                                (moduleAugmentations || (moduleAugmentations = [])).push(node.name);
                            }
                            else if (!inAmbientModule) {
                                if (file.isDeclarationFile) {
                                    (ambientModules || (ambientModules = [])).push(nameText);
                                }
                                const body = node.body;
                                if (body) {
                                    for (const statement of body.statements) {
                                        collectModuleReferences(statement, 
                                        /*inAmbientModule*/
                                        true);
                                    }
                                }
                            }
                        }
                    }
                }
                function collectDynamicImportOrRequireCalls(file2) {
                    const r = /import|require/g;
                    while (r.exec(file2.text) !== null) {
                        const node = getNodeAtPosition(file2, r.lastIndex);
                        if (shouldProcessRequires && isRequireCall(node, 
                        /*checkArgumentIsStringLiteralLike*/
                        true)) {
                            setParentRecursive(node, 
                            /*incremental*/
                            false);
                            imports = append(imports, node.arguments[0]);
                        }
                        else if (isImportCall(node) && node.arguments.length >= 1 && isStringLiteralLike(node.arguments[0])) {
                            setParentRecursive(node, 
                            /*incremental*/
                            false);
                            imports = append(imports, node.arguments[0]);
                        }
                        else if (isLiteralImportTypeNode(node)) {
                            setParentRecursive(node, 
                            /*incremental*/
                            false);
                            imports = append(imports, node.argument.literal);
                        }
                    }
                }
                function getNodeAtPosition(sourceFile, position) {
                    let current = sourceFile;
                    const getContainingChild = (child) => {
                        if (child.pos <= position && (position < child.end || position === child.end && child.kind === 1 /* EndOfFileToken */)) {
                            return child;
                        }
                    };
                    while (true) {
                        const child = isJavaScriptFile && hasJSDocNodes(current) && forEach(current.jsDoc, getContainingChild) || forEachChild(current, getContainingChild);
                        if (!child) {
                            return current;
                        }
                        current = child;
                    }
                }
            }
            function getLibFileFromReference(ref) {
                const libName = toFileNameLowerCase(ref.fileName);
                const libFileName = libMap.get(libName);
                if (libFileName) {
                    return getSourceFile(pathForLibFile(libFileName));
                }
            }
            function getSourceFileFromReference(referencingFile, ref) {
                return getSourceFileFromReferenceWorker(resolveTripleslashReference(ref.fileName, referencingFile.fileName), getSourceFile);
            }
            function getSourceFileFromReferenceWorker(fileName, getSourceFile2, fail, reason) {
                if (hasExtension(fileName)) {
                    const canonicalFileName = host.getCanonicalFileName(fileName);
                    if (!options.allowNonTsExtensions && !forEach(flatten(supportedExtensionsWithJsonIfResolveJsonModule), (extension) => fileExtensionIs(canonicalFileName, extension))) {
                        if (fail) {
                            if (hasJSFileExtension(canonicalFileName)) {
                                fail(Diagnostics.File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option, fileName);
                            }
                            else {
                                fail(Diagnostics.File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1, fileName, "'" + flatten(supportedExtensions).join("', '") + "'");
                            }
                        }
                        return void 0;
                    }
                    const sourceFile = getSourceFile2(fileName);
                    if (fail) {
                        if (!sourceFile) {
                            const redirect = getProjectReferenceRedirect(fileName);
                            if (redirect) {
                                fail(Diagnostics.Output_file_0_has_not_been_built_from_source_file_1, redirect, fileName);
                            }
                            else {
                                fail(Diagnostics.File_0_not_found, fileName);
                            }
                        }
                        else if (isReferencedFile(reason) && canonicalFileName === host.getCanonicalFileName(getSourceFileByPath(reason.file).fileName)) {
                            fail(Diagnostics.A_file_cannot_have_a_reference_to_itself);
                        }
                    }
                    return sourceFile;
                }
                else {
                    const sourceFileNoExtension = options.allowNonTsExtensions && getSourceFile2(fileName);
                    if (sourceFileNoExtension)
                        return sourceFileNoExtension;
                    if (fail && options.allowNonTsExtensions) {
                        fail(Diagnostics.File_0_not_found, fileName);
                        return void 0;
                    }
                    const sourceFileWithAddedExtension = forEach(supportedExtensions[0], (extension) => getSourceFile2(fileName + extension));
                    if (fail && !sourceFileWithAddedExtension)
                        fail(Diagnostics.Could_not_resolve_the_path_0_with_the_extensions_Colon_1, fileName, "'" + flatten(supportedExtensions).join("', '") + "'");
                    return sourceFileWithAddedExtension;
                }
            }
            function processSourceFile(fileName, isDefaultLib, ignoreNoDefaultLib, packageId, reason) {
                getSourceFileFromReferenceWorker(fileName, (fileName2) => findSourceFile(fileName2, isDefaultLib, ignoreNoDefaultLib, reason, packageId), 
                // TODO: GH#18217
                (diagnostic, ...args) => addFilePreprocessingFileExplainingDiagnostic(
                /*file*/
                void 0, reason, diagnostic, args), reason);
            }
            function processProjectReferenceFile(fileName, reason) {
                return processSourceFile(fileName, 
                /*isDefaultLib*/
                false, 
                /*ignoreNoDefaultLib*/
                false, 
                /*packageId*/
                void 0, reason);
            }
            function reportFileNamesDifferOnlyInCasingError(fileName, existingFile, reason) {
                const hasExistingReasonToReportErrorOn = !isReferencedFile(reason) && some(fileReasons.get(existingFile.path), isReferencedFile);
                if (hasExistingReasonToReportErrorOn) {
                    addFilePreprocessingFileExplainingDiagnostic(existingFile, reason, Diagnostics.Already_included_file_name_0_differs_from_file_name_1_only_in_casing, [existingFile.fileName, fileName]);
                }
                else {
                    addFilePreprocessingFileExplainingDiagnostic(existingFile, reason, Diagnostics.File_name_0_differs_from_already_included_file_name_1_only_in_casing, [fileName, existingFile.fileName]);
                }
            }
            function createRedirectedSourceFile(redirectTarget, unredirected, fileName, path, resolvedPath, originalFileName, sourceFileOptions) {
                var _a3;
                const redirect = parseNodeFactory.createRedirectedSourceFile({ redirectTarget, unredirected });
                redirect.fileName = fileName;
                redirect.path = path;
                redirect.resolvedPath = resolvedPath;
                redirect.originalFileName = originalFileName;
                redirect.packageJsonLocations = ((_a3 = sourceFileOptions.packageJsonLocations) == null ? void 0 : _a3.length) ? sourceFileOptions.packageJsonLocations : void 0;
                redirect.packageJsonScope = sourceFileOptions.packageJsonScope;
                sourceFilesFoundSearchingNodeModules.set(path, currentNodeModulesDepth > 0);
                return redirect;
            }
            function findSourceFile(fileName, isDefaultLib, ignoreNoDefaultLib, reason, packageId) {
                var _a3, _b2;
                (_a3 = tracing) == null ? void 0 : _a3.push(tracing.Phase.Program, "findSourceFile", {
                    fileName,
                    isDefaultLib: isDefaultLib || void 0,
                    fileIncludeKind: FileIncludeKind[reason.kind]
                });
                const result = findSourceFileWorker(fileName, isDefaultLib, ignoreNoDefaultLib, reason, packageId);
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return result;
            }
            function getCreateSourceFileOptions(fileName, moduleResolutionCache2, host2, options2) {
                const result = getImpliedNodeFormatForFileWorker(getNormalizedAbsolutePath(fileName, currentDirectory), moduleResolutionCache2 == null ? void 0 : moduleResolutionCache2.getPackageJsonInfoCache(), host2, options2);
                const languageVersion = getEmitScriptTarget(options2);
                const setExternalModuleIndicator2 = getSetExternalModuleIndicator(options2);
                return typeof result === "object" ? { ...result, languageVersion, setExternalModuleIndicator: setExternalModuleIndicator2 } : { languageVersion, impliedNodeFormat: result, setExternalModuleIndicator: setExternalModuleIndicator2 };
            }
            function findSourceFileWorker(fileName, isDefaultLib, ignoreNoDefaultLib, reason, packageId) {
                var _a3, _b2;
                const path = toPath3(fileName);
                if (useSourceOfProjectReferenceRedirect) {
                    let source = getSourceOfProjectReferenceRedirect(path);
                    if (!source && host.realpath && options.preserveSymlinks && isDeclarationFileName(fileName) && stringContains(fileName, nodeModulesPathPart)) {
                        const realPath2 = toPath3(host.realpath(fileName));
                        if (realPath2 !== path)
                            source = getSourceOfProjectReferenceRedirect(realPath2);
                    }
                    if (source) {
                        const file2 = isString(source) ? findSourceFile(source, isDefaultLib, ignoreNoDefaultLib, reason, packageId) : void 0;
                        if (file2)
                            addFileToFilesByName(file2, path, 
                            /*redirectedPath*/
                            void 0);
                        return file2;
                    }
                }
                const originalFileName = fileName;
                if (filesByName.has(path)) {
                    const file2 = filesByName.get(path);
                    addFileIncludeReason(file2 || void 0, reason);
                    if (file2 && !(options.forceConsistentCasingInFileNames === false)) {
                        const checkedName = file2.fileName;
                        const isRedirect = toPath3(checkedName) !== toPath3(fileName);
                        if (isRedirect) {
                            fileName = getProjectReferenceRedirect(fileName) || fileName;
                        }
                        const checkedAbsolutePath = getNormalizedAbsolutePathWithoutRoot(checkedName, currentDirectory);
                        const inputAbsolutePath = getNormalizedAbsolutePathWithoutRoot(fileName, currentDirectory);
                        if (checkedAbsolutePath !== inputAbsolutePath) {
                            reportFileNamesDifferOnlyInCasingError(fileName, file2, reason);
                        }
                    }
                    if (file2 && sourceFilesFoundSearchingNodeModules.get(file2.path) && currentNodeModulesDepth === 0) {
                        sourceFilesFoundSearchingNodeModules.set(file2.path, false);
                        if (!options.noResolve) {
                            processReferencedFiles(file2, isDefaultLib);
                            processTypeReferenceDirectives(file2);
                        }
                        if (!options.noLib) {
                            processLibReferenceDirectives(file2);
                        }
                        modulesWithElidedImports.set(file2.path, false);
                        processImportedModules(file2);
                    }
                    else if (file2 && modulesWithElidedImports.get(file2.path)) {
                        if (currentNodeModulesDepth < maxNodeModuleJsDepth) {
                            modulesWithElidedImports.set(file2.path, false);
                            processImportedModules(file2);
                        }
                    }
                    return file2 || void 0;
                }
                let redirectedPath;
                if (isReferencedFile(reason) && !useSourceOfProjectReferenceRedirect) {
                    const redirectProject = getProjectReferenceRedirectProject(fileName);
                    if (redirectProject) {
                        if (outFile(redirectProject.commandLine.options)) {
                            return void 0;
                        }
                        const redirect = getProjectReferenceOutputName(redirectProject, fileName);
                        fileName = redirect;
                        redirectedPath = toPath3(redirect);
                    }
                }
                const sourceFileOptions = getCreateSourceFileOptions(fileName, moduleResolutionCache, host, options);
                const file = host.getSourceFile(fileName, sourceFileOptions, (hostErrorMessage) => addFilePreprocessingFileExplainingDiagnostic(
                /*file*/
                void 0, reason, Diagnostics.Cannot_read_file_0_Colon_1, [fileName, hostErrorMessage]), shouldCreateNewSourceFile || ((_a3 = oldProgram == null ? void 0 : oldProgram.getSourceFileByPath(toPath3(fileName))) == null ? void 0 : _a3.impliedNodeFormat) !== sourceFileOptions.impliedNodeFormat);
                if (packageId) {
                    const packageIdKey = packageIdToString(packageId);
                    const fileFromPackageId = packageIdToSourceFile.get(packageIdKey);
                    if (fileFromPackageId) {
                        const dupFile = createRedirectedSourceFile(fileFromPackageId, file, fileName, path, toPath3(fileName), originalFileName, sourceFileOptions);
                        redirectTargetsMap.add(fileFromPackageId.path, fileName);
                        addFileToFilesByName(dupFile, path, redirectedPath);
                        addFileIncludeReason(dupFile, reason);
                        sourceFileToPackageName.set(path, packageIdToPackageName(packageId));
                        processingOtherFiles.push(dupFile);
                        return dupFile;
                    }
                    else if (file) {
                        packageIdToSourceFile.set(packageIdKey, file);
                        sourceFileToPackageName.set(path, packageIdToPackageName(packageId));
                    }
                }
                addFileToFilesByName(file, path, redirectedPath);
                if (file) {
                    sourceFilesFoundSearchingNodeModules.set(path, currentNodeModulesDepth > 0);
                    file.fileName = fileName;
                    file.path = path;
                    file.resolvedPath = toPath3(fileName);
                    file.originalFileName = originalFileName;
                    file.packageJsonLocations = ((_b2 = sourceFileOptions.packageJsonLocations) == null ? void 0 : _b2.length) ? sourceFileOptions.packageJsonLocations : void 0;
                    file.packageJsonScope = sourceFileOptions.packageJsonScope;
                    addFileIncludeReason(file, reason);
                    if (host.useCaseSensitiveFileNames()) {
                        const pathLowerCase = toFileNameLowerCase(path);
                        const existingFile = filesByNameIgnoreCase.get(pathLowerCase);
                        if (existingFile) {
                            reportFileNamesDifferOnlyInCasingError(fileName, existingFile, reason);
                        }
                        else {
                            filesByNameIgnoreCase.set(pathLowerCase, file);
                        }
                    }
                    skipDefaultLib = skipDefaultLib || file.hasNoDefaultLib && !ignoreNoDefaultLib;
                    if (!options.noResolve) {
                        processReferencedFiles(file, isDefaultLib);
                        processTypeReferenceDirectives(file);
                    }
                    if (!options.noLib) {
                        processLibReferenceDirectives(file);
                    }
                    processImportedModules(file);
                    if (isDefaultLib) {
                        processingDefaultLibFiles.push(file);
                    }
                    else {
                        processingOtherFiles.push(file);
                    }
                }
                return file;
            }
            function addFileIncludeReason(file, reason) {
                if (file)
                    fileReasons.add(file.path, reason);
            }
            function addFileToFilesByName(file, path, redirectedPath) {
                if (redirectedPath) {
                    filesByName.set(redirectedPath, file);
                    filesByName.set(path, file || false);
                }
                else {
                    filesByName.set(path, file);
                }
            }
            function getProjectReferenceRedirect(fileName) {
                const referencedProject = getProjectReferenceRedirectProject(fileName);
                return referencedProject && getProjectReferenceOutputName(referencedProject, fileName);
            }
            function getProjectReferenceRedirectProject(fileName) {
                if (!resolvedProjectReferences || !resolvedProjectReferences.length || isDeclarationFileName(fileName) || fileExtensionIs(fileName, ".json" /* Json */)) {
                    return void 0;
                }
                return getResolvedProjectReferenceToRedirect(fileName);
            }
            function getProjectReferenceOutputName(referencedProject, fileName) {
                const out = outFile(referencedProject.commandLine.options);
                return out ? changeExtension(out, ".d.ts" /* Dts */) : getOutputDeclarationFileName(fileName, referencedProject.commandLine, !host.useCaseSensitiveFileNames());
            }
            function getResolvedProjectReferenceToRedirect(fileName) {
                if (mapFromFileToProjectReferenceRedirects === void 0) {
                    mapFromFileToProjectReferenceRedirects = /* @__PURE__ */ new Map();
                    forEachResolvedProjectReference2((referencedProject) => {
                        if (toPath3(options.configFilePath) !== referencedProject.sourceFile.path) {
                            referencedProject.commandLine.fileNames.forEach((f) => mapFromFileToProjectReferenceRedirects.set(toPath3(f), referencedProject.sourceFile.path));
                        }
                    });
                }
                const referencedProjectPath = mapFromFileToProjectReferenceRedirects.get(toPath3(fileName));
                return referencedProjectPath && getResolvedProjectReferenceByPath(referencedProjectPath);
            }
            function forEachResolvedProjectReference2(cb) {
                return forEachResolvedProjectReference(resolvedProjectReferences, cb);
            }
            function getSourceOfProjectReferenceRedirect(path) {
                if (!isDeclarationFileName(path))
                    return void 0;
                if (mapFromToProjectReferenceRedirectSource === void 0) {
                    mapFromToProjectReferenceRedirectSource = /* @__PURE__ */ new Map();
                    forEachResolvedProjectReference2((resolvedRef) => {
                        const out = outFile(resolvedRef.commandLine.options);
                        if (out) {
                            const outputDts = changeExtension(out, ".d.ts" /* Dts */);
                            mapFromToProjectReferenceRedirectSource.set(toPath3(outputDts), true);
                        }
                        else {
                            const getCommonSourceDirectory3 = memoize(() => getCommonSourceDirectoryOfConfig(resolvedRef.commandLine, !host.useCaseSensitiveFileNames()));
                            forEach(resolvedRef.commandLine.fileNames, (fileName) => {
                                if (!isDeclarationFileName(fileName) && !fileExtensionIs(fileName, ".json" /* Json */)) {
                                    const outputDts = getOutputDeclarationFileName(fileName, resolvedRef.commandLine, !host.useCaseSensitiveFileNames(), getCommonSourceDirectory3);
                                    mapFromToProjectReferenceRedirectSource.set(toPath3(outputDts), fileName);
                                }
                            });
                        }
                    });
                }
                return mapFromToProjectReferenceRedirectSource.get(path);
            }
            function isSourceOfProjectReferenceRedirect(fileName) {
                return useSourceOfProjectReferenceRedirect && !!getResolvedProjectReferenceToRedirect(fileName);
            }
            function getResolvedProjectReferenceByPath(projectReferencePath) {
                if (!projectReferenceRedirects) {
                    return void 0;
                }
                return projectReferenceRedirects.get(projectReferencePath) || void 0;
            }
            function processReferencedFiles(file, isDefaultLib) {
                forEach(file.referencedFiles, (ref, index) => {
                    processSourceFile(resolveTripleslashReference(ref.fileName, file.fileName), isDefaultLib, 
                    /*ignoreNoDefaultLib*/
                    false, 
                    /*packageId*/
                    void 0, { kind: 4 /* ReferenceFile */, file: file.path, index });
                });
            }
            function processTypeReferenceDirectives(file) {
                const typeDirectives = file.typeReferenceDirectives;
                if (!typeDirectives.length) {
                    file.resolvedTypeReferenceDirectiveNames = void 0;
                    return;
                }
                const resolutions = resolveTypeReferenceDirectiveNamesReusingOldState(typeDirectives, file);
                for (let index = 0; index < typeDirectives.length; index++) {
                    const ref = file.typeReferenceDirectives[index];
                    const resolvedTypeReferenceDirective = resolutions[index];
                    const fileName = toFileNameLowerCase(ref.fileName);
                    setResolvedTypeReferenceDirective(file, fileName, resolvedTypeReferenceDirective, getModeForFileReference(ref, file.impliedNodeFormat));
                    const mode = ref.resolutionMode || file.impliedNodeFormat;
                    if (mode && getEmitModuleResolutionKind(options) !== 3 /* Node16 */ && getEmitModuleResolutionKind(options) !== 99 /* NodeNext */) {
                        (fileProcessingDiagnostics != null ? fileProcessingDiagnostics : fileProcessingDiagnostics = []).push({
                            kind: 2 /* ResolutionDiagnostics */,
                            diagnostics: [
                                createDiagnosticForRange(file, ref, Diagnostics.resolution_mode_assertions_are_only_supported_when_moduleResolution_is_node16_or_nodenext)
                            ]
                        });
                    }
                    processTypeReferenceDirective(fileName, mode, resolvedTypeReferenceDirective, { kind: 5 /* TypeReferenceDirective */, file: file.path, index });
                }
            }
            function processTypeReferenceDirective(typeReferenceDirective, mode, resolution, reason) {
                var _a3, _b2;
                (_a3 = tracing) == null ? void 0 : _a3.push(tracing.Phase.Program, "processTypeReferenceDirective", { directive: typeReferenceDirective, hasResolved: !!resolution.resolvedTypeReferenceDirective, refKind: reason.kind, refPath: isReferencedFile(reason) ? reason.file : void 0 });
                processTypeReferenceDirectiveWorker(typeReferenceDirective, mode, resolution, reason);
                (_b2 = tracing) == null ? void 0 : _b2.pop();
            }
            function processTypeReferenceDirectiveWorker(typeReferenceDirective, mode, resolution, reason) {
                var _a3;
                addResolutionDiagnostics(resolution);
                const previousResolution = (_a3 = resolvedTypeReferenceDirectives.get(typeReferenceDirective, mode)) == null ? void 0 : _a3.resolvedTypeReferenceDirective;
                if (previousResolution && previousResolution.primary) {
                    return;
                }
                let saveResolution = true;
                const { resolvedTypeReferenceDirective } = resolution;
                if (resolvedTypeReferenceDirective) {
                    if (resolvedTypeReferenceDirective.isExternalLibraryImport)
                        currentNodeModulesDepth++;
                    if (resolvedTypeReferenceDirective.primary) {
                        processSourceFile(resolvedTypeReferenceDirective.resolvedFileName, 
                        /*isDefaultLib*/
                        false, 
                        /*ignoreNoDefaultLib*/
                        false, resolvedTypeReferenceDirective.packageId, reason);
                    }
                    else {
                        if (previousResolution) {
                            if (resolvedTypeReferenceDirective.resolvedFileName !== previousResolution.resolvedFileName) {
                                const otherFileText = host.readFile(resolvedTypeReferenceDirective.resolvedFileName);
                                const existingFile = getSourceFile(previousResolution.resolvedFileName);
                                if (otherFileText !== existingFile.text) {
                                    addFilePreprocessingFileExplainingDiagnostic(existingFile, reason, Diagnostics.Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_library_to_resolve_the_conflict, [typeReferenceDirective, resolvedTypeReferenceDirective.resolvedFileName, previousResolution.resolvedFileName]);
                                }
                            }
                            saveResolution = false;
                        }
                        else {
                            processSourceFile(resolvedTypeReferenceDirective.resolvedFileName, 
                            /*isDefaultLib*/
                            false, 
                            /*ignoreNoDefaultLib*/
                            false, resolvedTypeReferenceDirective.packageId, reason);
                        }
                    }
                    if (resolvedTypeReferenceDirective.isExternalLibraryImport)
                        currentNodeModulesDepth--;
                }
                else {
                    addFilePreprocessingFileExplainingDiagnostic(
                    /*file*/
                    void 0, reason, Diagnostics.Cannot_find_type_definition_file_for_0, [typeReferenceDirective]);
                }
                if (saveResolution) {
                    resolvedTypeReferenceDirectives.set(typeReferenceDirective, mode, resolution);
                }
            }
            function pathForLibFile(libFileName) {
                const components = libFileName.split(".");
                let path = components[1];
                let i = 2;
                while (components[i] && components[i] !== "d") {
                    path += (i === 2 ? "/" : "-") + components[i];
                    i++;
                }
                const resolveFrom = combinePaths(currentDirectory, `__lib_node_modules_lookup_${libFileName}__.ts`);
                const localOverrideModuleResult = resolveModuleName("@typescript/lib-" + path, resolveFrom, { moduleResolution: 2 /* Node10 */ }, host, moduleResolutionCache);
                if (localOverrideModuleResult == null ? void 0 : localOverrideModuleResult.resolvedModule) {
                    return localOverrideModuleResult.resolvedModule.resolvedFileName;
                }
                return combinePaths(defaultLibraryPath, libFileName);
            }
            function processLibReferenceDirectives(file) {
                forEach(file.libReferenceDirectives, (libReference, index) => {
                    const libName = toFileNameLowerCase(libReference.fileName);
                    const libFileName = libMap.get(libName);
                    if (libFileName) {
                        processRootFile(pathForLibFile(libFileName), 
                        /*isDefaultLib*/
                        true, 
                        /*ignoreNoDefaultLib*/
                        true, { kind: 7 /* LibReferenceDirective */, file: file.path, index });
                    }
                    else {
                        const unqualifiedLibName = removeSuffix(removePrefix(libName, "lib."), ".d.ts");
                        const suggestion = getSpellingSuggestion(unqualifiedLibName, libs, identity);
                        const diagnostic = suggestion ? Diagnostics.Cannot_find_lib_definition_for_0_Did_you_mean_1 : Diagnostics.Cannot_find_lib_definition_for_0;
                        (fileProcessingDiagnostics || (fileProcessingDiagnostics = [])).push({
                            kind: 0 /* FilePreprocessingReferencedDiagnostic */,
                            reason: { kind: 7 /* LibReferenceDirective */, file: file.path, index },
                            diagnostic,
                            args: [libName, suggestion]
                        });
                    }
                });
            }
            function getCanonicalFileName(fileName) {
                return host.getCanonicalFileName(fileName);
            }
            function processImportedModules(file) {
                var _a3;
                collectExternalModuleReferences(file);
                if (file.imports.length || file.moduleAugmentations.length) {
                    const moduleNames = getModuleNames(file);
                    const resolutions = resolveModuleNamesReusingOldState(moduleNames, file);
                    Debug.assert(resolutions.length === moduleNames.length);
                    const optionsForFile = (useSourceOfProjectReferenceRedirect ? (_a3 = getRedirectReferenceForResolution(file)) == null ? void 0 : _a3.commandLine.options : void 0) || options;
                    for (let index = 0; index < moduleNames.length; index++) {
                        const resolution = resolutions[index].resolvedModule;
                        const moduleName = moduleNames[index].text;
                        const mode = getModeForUsageLocation(file, moduleNames[index]);
                        setResolvedModule(file, moduleName, resolutions[index], mode);
                        addResolutionDiagnosticsFromResolutionOrCache(file, moduleName, resolutions[index], mode);
                        if (!resolution) {
                            continue;
                        }
                        const isFromNodeModulesSearch = resolution.isExternalLibraryImport;
                        const isJsFile = !resolutionExtensionIsTSOrJson(resolution.extension);
                        const isJsFileFromNodeModules = isFromNodeModulesSearch && isJsFile;
                        const resolvedFileName = resolution.resolvedFileName;
                        if (isFromNodeModulesSearch) {
                            currentNodeModulesDepth++;
                        }
                        const elideImport = isJsFileFromNodeModules && currentNodeModulesDepth > maxNodeModuleJsDepth;
                        const shouldAddFile = resolvedFileName && !getResolutionDiagnostic(optionsForFile, resolution, file) && !optionsForFile.noResolve && index < file.imports.length && !elideImport && !(isJsFile && !getAllowJSCompilerOption(optionsForFile)) && (isInJSFile(file.imports[index]) || !(file.imports[index].flags & 8388608 /* JSDoc */));
                        if (elideImport) {
                            modulesWithElidedImports.set(file.path, true);
                        }
                        else if (shouldAddFile) {
                            findSourceFile(resolvedFileName, 
                            /*isDefaultLib*/
                            false, 
                            /*ignoreNoDefaultLib*/
                            false, { kind: 3 /* Import */, file: file.path, index }, resolution.packageId);
                        }
                        if (isFromNodeModulesSearch) {
                            currentNodeModulesDepth--;
                        }
                    }
                }
                else {
                    file.resolvedModules = void 0;
                }
            }
            function checkSourceFilesBelongToPath(sourceFiles, rootDirectory) {
                let allFilesBelongToPath = true;
                const absoluteRootDirectoryPath = host.getCanonicalFileName(getNormalizedAbsolutePath(rootDirectory, currentDirectory));
                for (const sourceFile of sourceFiles) {
                    if (!sourceFile.isDeclarationFile) {
                        const absoluteSourceFilePath = host.getCanonicalFileName(getNormalizedAbsolutePath(sourceFile.fileName, currentDirectory));
                        if (absoluteSourceFilePath.indexOf(absoluteRootDirectoryPath) !== 0) {
                            addProgramDiagnosticExplainingFile(sourceFile, Diagnostics.File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files, [sourceFile.fileName, rootDirectory]);
                            allFilesBelongToPath = false;
                        }
                    }
                }
                return allFilesBelongToPath;
            }
            function parseProjectReferenceConfigFile(ref) {
                if (!projectReferenceRedirects) {
                    projectReferenceRedirects = /* @__PURE__ */ new Map();
                }
                const refPath = resolveProjectReferencePath(ref);
                const sourceFilePath = toPath3(refPath);
                const fromCache = projectReferenceRedirects.get(sourceFilePath);
                if (fromCache !== void 0) {
                    return fromCache || void 0;
                }
                let commandLine;
                let sourceFile;
                if (host.getParsedCommandLine) {
                    commandLine = host.getParsedCommandLine(refPath);
                    if (!commandLine) {
                        addFileToFilesByName(
                        /*sourceFile*/
                        void 0, sourceFilePath, 
                        /*redirectedPath*/
                        void 0);
                        projectReferenceRedirects.set(sourceFilePath, false);
                        return void 0;
                    }
                    sourceFile = Debug.checkDefined(commandLine.options.configFile);
                    Debug.assert(!sourceFile.path || sourceFile.path === sourceFilePath);
                    addFileToFilesByName(sourceFile, sourceFilePath, 
                    /*redirectedPath*/
                    void 0);
                }
                else {
                    const basePath = getNormalizedAbsolutePath(getDirectoryPath(refPath), host.getCurrentDirectory());
                    sourceFile = host.getSourceFile(refPath, 100 /* JSON */);
                    addFileToFilesByName(sourceFile, sourceFilePath, 
                    /*redirectedPath*/
                    void 0);
                    if (sourceFile === void 0) {
                        projectReferenceRedirects.set(sourceFilePath, false);
                        return void 0;
                    }
                    commandLine = parseJsonSourceFileConfigFileContent(sourceFile, configParsingHost, basePath, 
                    /*existingOptions*/
                    void 0, refPath);
                }
                sourceFile.fileName = refPath;
                sourceFile.path = sourceFilePath;
                sourceFile.resolvedPath = sourceFilePath;
                sourceFile.originalFileName = refPath;
                const resolvedRef = { commandLine, sourceFile };
                projectReferenceRedirects.set(sourceFilePath, resolvedRef);
                if (commandLine.projectReferences) {
                    resolvedRef.references = commandLine.projectReferences.map(parseProjectReferenceConfigFile);
                }
                return resolvedRef;
            }
            function verifyCompilerOptions() {
                if (options.strictPropertyInitialization && !getStrictOptionValue(options, "strictNullChecks")) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "strictPropertyInitialization", "strictNullChecks");
                }
                if (options.exactOptionalPropertyTypes && !getStrictOptionValue(options, "strictNullChecks")) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "exactOptionalPropertyTypes", "strictNullChecks");
                }
                if (options.isolatedModules || options.verbatimModuleSyntax) {
                    if (options.out) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "out", options.verbatimModuleSyntax ? "verbatimModuleSyntax" : "isolatedModules");
                    }
                    if (options.outFile) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "outFile", options.verbatimModuleSyntax ? "verbatimModuleSyntax" : "isolatedModules");
                    }
                }
                if (options.inlineSourceMap) {
                    if (options.sourceMap) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "sourceMap", "inlineSourceMap");
                    }
                    if (options.mapRoot) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "mapRoot", "inlineSourceMap");
                    }
                }
                if (options.composite) {
                    if (options.declaration === false) {
                        createDiagnosticForOptionName(Diagnostics.Composite_projects_may_not_disable_declaration_emit, "declaration");
                    }
                    if (options.incremental === false) {
                        createDiagnosticForOptionName(Diagnostics.Composite_projects_may_not_disable_incremental_compilation, "declaration");
                    }
                }
                const outputFile = outFile(options);
                if (options.tsBuildInfoFile) {
                    if (!isIncrementalCompilation(options)) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "tsBuildInfoFile", "incremental", "composite");
                    }
                }
                else if (options.incremental && !outputFile && !options.configFilePath) {
                    programDiagnostics.add(createCompilerDiagnostic(Diagnostics.Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBuildInfoFile_is_specified));
                }
                verifyDeprecatedCompilerOptions();
                verifyProjectReferences();
                if (options.composite) {
                    const rootPaths = new Set(rootNames.map(toPath3));
                    for (const file of files) {
                        if (sourceFileMayBeEmitted(file, program) && !rootPaths.has(file.path)) {
                            addProgramDiagnosticExplainingFile(file, Diagnostics.File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_include_pattern, [file.fileName, options.configFilePath || ""]);
                        }
                    }
                }
                if (options.paths) {
                    for (const key in options.paths) {
                        if (!hasProperty(options.paths, key)) {
                            continue;
                        }
                        if (!hasZeroOrOneAsteriskCharacter(key)) {
                            createDiagnosticForOptionPaths(
                            /*onKey*/
                            true, key, Diagnostics.Pattern_0_can_have_at_most_one_Asterisk_character, key);
                        }
                        if (isArray(options.paths[key])) {
                            const len = options.paths[key].length;
                            if (len === 0) {
                                createDiagnosticForOptionPaths(
                                /*onKey*/
                                false, key, Diagnostics.Substitutions_for_pattern_0_shouldn_t_be_an_empty_array, key);
                            }
                            for (let i = 0; i < len; i++) {
                                const subst = options.paths[key][i];
                                const typeOfSubst = typeof subst;
                                if (typeOfSubst === "string") {
                                    if (!hasZeroOrOneAsteriskCharacter(subst)) {
                                        createDiagnosticForOptionPathKeyValue(key, i, Diagnostics.Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character, subst, key);
                                    }
                                    if (!options.baseUrl && !pathIsRelative(subst) && !pathIsAbsolute(subst)) {
                                        createDiagnosticForOptionPathKeyValue(key, i, Diagnostics.Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash);
                                    }
                                }
                                else {
                                    createDiagnosticForOptionPathKeyValue(key, i, Diagnostics.Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2, subst, key, typeOfSubst);
                                }
                            }
                        }
                        else {
                            createDiagnosticForOptionPaths(
                            /*onKey*/
                            false, key, Diagnostics.Substitutions_for_pattern_0_should_be_an_array, key);
                        }
                    }
                }
                if (!options.sourceMap && !options.inlineSourceMap) {
                    if (options.inlineSources) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided, "inlineSources");
                    }
                    if (options.sourceRoot) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided, "sourceRoot");
                    }
                }
                if (options.out && options.outFile) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "out", "outFile");
                }
                if (options.mapRoot && !(options.sourceMap || options.declarationMap)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "mapRoot", "sourceMap", "declarationMap");
                }
                if (options.declarationDir) {
                    if (!getEmitDeclarations(options)) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "declarationDir", "declaration", "composite");
                    }
                    if (outputFile) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "declarationDir", options.out ? "out" : "outFile");
                    }
                }
                if (options.declarationMap && !getEmitDeclarations(options)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "declarationMap", "declaration", "composite");
                }
                if (options.lib && options.noLib) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "lib", "noLib");
                }
                if (options.noImplicitUseStrict && getStrictOptionValue(options, "alwaysStrict")) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "noImplicitUseStrict", "alwaysStrict");
                }
                const languageVersion = getEmitScriptTarget(options);
                const firstNonAmbientExternalModuleSourceFile = find(files, (f) => isExternalModule(f) && !f.isDeclarationFile);
                if (options.isolatedModules || options.verbatimModuleSyntax) {
                    if (options.module === 0 /* None */ && languageVersion < 2 /* ES2015 */ && options.isolatedModules) {
                        createDiagnosticForOptionName(Diagnostics.Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher, "isolatedModules", "target");
                    }
                    if (options.preserveConstEnums === false) {
                        createDiagnosticForOptionName(Diagnostics.Option_preserveConstEnums_cannot_be_disabled_when_0_is_enabled, options.verbatimModuleSyntax ? "verbatimModuleSyntax" : "isolatedModules", "preserveConstEnums");
                    }
                }
                else if (firstNonAmbientExternalModuleSourceFile && languageVersion < 2 /* ES2015 */ && options.module === 0 /* None */) {
                    const span = getErrorSpanForNode(firstNonAmbientExternalModuleSourceFile, typeof firstNonAmbientExternalModuleSourceFile.externalModuleIndicator === "boolean" ? firstNonAmbientExternalModuleSourceFile : firstNonAmbientExternalModuleSourceFile.externalModuleIndicator);
                    programDiagnostics.add(createFileDiagnostic(firstNonAmbientExternalModuleSourceFile, span.start, span.length, Diagnostics.Cannot_use_imports_exports_or_module_augmentations_when_module_is_none));
                }
                if (outputFile && !options.emitDeclarationOnly) {
                    if (options.module && !(options.module === 2 /* AMD */ || options.module === 4 /* System */)) {
                        createDiagnosticForOptionName(Diagnostics.Only_amd_and_system_modules_are_supported_alongside_0, options.out ? "out" : "outFile", "module");
                    }
                    else if (options.module === void 0 && firstNonAmbientExternalModuleSourceFile) {
                        const span = getErrorSpanForNode(firstNonAmbientExternalModuleSourceFile, typeof firstNonAmbientExternalModuleSourceFile.externalModuleIndicator === "boolean" ? firstNonAmbientExternalModuleSourceFile : firstNonAmbientExternalModuleSourceFile.externalModuleIndicator);
                        programDiagnostics.add(createFileDiagnostic(firstNonAmbientExternalModuleSourceFile, span.start, span.length, Diagnostics.Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system, options.out ? "out" : "outFile"));
                    }
                }
                if (getResolveJsonModule(options)) {
                    if (getEmitModuleResolutionKind(options) === 1 /* Classic */) {
                        createDiagnosticForOptionName(Diagnostics.Option_resolveJsonModule_cannot_be_specified_when_moduleResolution_is_set_to_classic, "resolveJsonModule");
                    }
                    else if (!hasJsonModuleEmitEnabled(options)) {
                        createDiagnosticForOptionName(Diagnostics.Option_resolveJsonModule_can_only_be_specified_when_module_code_generation_is_commonjs_amd_es2015_or_esNext, "resolveJsonModule", "module");
                    }
                }
                if (options.outDir || // there is --outDir specified
                    options.rootDir || // there is --rootDir specified
                    options.sourceRoot || // there is --sourceRoot specified
                    options.mapRoot) {
                    const dir = getCommonSourceDirectory2();
                    if (options.outDir && dir === "" && files.some((file) => getRootLength(file.fileName) > 1)) {
                        createDiagnosticForOptionName(Diagnostics.Cannot_find_the_common_subdirectory_path_for_the_input_files, "outDir");
                    }
                }
                if (options.useDefineForClassFields && languageVersion === 0 /* ES3 */) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_target_is_ES3, "useDefineForClassFields");
                }
                if (options.checkJs && !getAllowJSCompilerOption(options)) {
                    programDiagnostics.add(createCompilerDiagnostic(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "checkJs", "allowJs"));
                }
                if (options.emitDeclarationOnly) {
                    if (!getEmitDeclarations(options)) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "emitDeclarationOnly", "declaration", "composite");
                    }
                    if (options.noEmit) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "emitDeclarationOnly", "noEmit");
                    }
                }
                if (options.emitDecoratorMetadata && !options.experimentalDecorators) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "emitDecoratorMetadata", "experimentalDecorators");
                }
                if (options.jsxFactory) {
                    if (options.reactNamespace) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "reactNamespace", "jsxFactory");
                    }
                    if (options.jsx === 4 /* ReactJSX */ || options.jsx === 5 /* ReactJSXDev */) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1, "jsxFactory", inverseJsxOptionMap.get("" + options.jsx));
                    }
                    if (!parseIsolatedEntityName(options.jsxFactory, languageVersion)) {
                        createOptionValueDiagnostic("jsxFactory", Diagnostics.Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name, options.jsxFactory);
                    }
                }
                else if (options.reactNamespace && !isIdentifierText(options.reactNamespace, languageVersion)) {
                    createOptionValueDiagnostic("reactNamespace", Diagnostics.Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier, options.reactNamespace);
                }
                if (options.jsxFragmentFactory) {
                    if (!options.jsxFactory) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "jsxFragmentFactory", "jsxFactory");
                    }
                    if (options.jsx === 4 /* ReactJSX */ || options.jsx === 5 /* ReactJSXDev */) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1, "jsxFragmentFactory", inverseJsxOptionMap.get("" + options.jsx));
                    }
                    if (!parseIsolatedEntityName(options.jsxFragmentFactory, languageVersion)) {
                        createOptionValueDiagnostic("jsxFragmentFactory", Diagnostics.Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name, options.jsxFragmentFactory);
                    }
                }
                if (options.reactNamespace) {
                    if (options.jsx === 4 /* ReactJSX */ || options.jsx === 5 /* ReactJSXDev */) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1, "reactNamespace", inverseJsxOptionMap.get("" + options.jsx));
                    }
                }
                if (options.jsxImportSource) {
                    if (options.jsx === 2 /* React */) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1, "jsxImportSource", inverseJsxOptionMap.get("" + options.jsx));
                    }
                }
                if (options.preserveValueImports && getEmitModuleKind(options) < 5 /* ES2015 */) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_module_is_set_to_es2015_or_later, "preserveValueImports");
                }
                const moduleKind = getEmitModuleKind(options);
                if (options.verbatimModuleSyntax) {
                    if (moduleKind === 2 /* AMD */ || moduleKind === 3 /* UMD */ || moduleKind === 4 /* System */) {
                        createDiagnosticForOptionName(Diagnostics.Option_verbatimModuleSyntax_cannot_be_used_when_module_is_set_to_UMD_AMD_or_System, "verbatimModuleSyntax");
                    }
                    if (options.preserveValueImports) {
                        createRedundantOptionDiagnostic("preserveValueImports", "verbatimModuleSyntax");
                    }
                    if (options.importsNotUsedAsValues) {
                        createRedundantOptionDiagnostic("importsNotUsedAsValues", "verbatimModuleSyntax");
                    }
                }
                if (options.allowImportingTsExtensions && !(options.noEmit || options.emitDeclarationOnly)) {
                    createOptionValueDiagnostic("allowImportingTsExtensions", Diagnostics.Option_allowImportingTsExtensions_can_only_be_used_when_either_noEmit_or_emitDeclarationOnly_is_set);
                }
                const moduleResolution = getEmitModuleResolutionKind(options);
                if (options.resolvePackageJsonExports && !moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler, "resolvePackageJsonExports");
                }
                if (options.resolvePackageJsonImports && !moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler, "resolvePackageJsonImports");
                }
                if (options.customConditions && !moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler, "customConditions");
                }
                if (moduleResolution === 100 /* Bundler */ && !emitModuleKindIsNonNodeESM(moduleKind)) {
                    createOptionValueDiagnostic("moduleResolution", Diagnostics.Option_0_can_only_be_used_when_module_is_set_to_es2015_or_later, "bundler");
                }
                if (!options.noEmit && !options.suppressOutputPathCheck) {
                    const emitHost = getEmitHost();
                    const emitFilesSeen = /* @__PURE__ */ new Set();
                    forEachEmittedFile(emitHost, (emitFileNames) => {
                        if (!options.emitDeclarationOnly) {
                            verifyEmitFilePath(emitFileNames.jsFilePath, emitFilesSeen);
                        }
                        verifyEmitFilePath(emitFileNames.declarationFilePath, emitFilesSeen);
                    });
                }
                function verifyEmitFilePath(emitFileName, emitFilesSeen) {
                    if (emitFileName) {
                        const emitFilePath = toPath3(emitFileName);
                        if (filesByName.has(emitFilePath)) {
                            let chain;
                            if (!options.configFilePath) {
                                chain = chainDiagnosticMessages(
                                /*details*/
                                void 0, Diagnostics.Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript_files_Learn_more_at_https_Colon_Slash_Slashaka_ms_Slashtsconfig);
                            }
                            chain = chainDiagnosticMessages(chain, Diagnostics.Cannot_write_file_0_because_it_would_overwrite_input_file, emitFileName);
                            blockEmittingOfFile(emitFileName, createCompilerDiagnosticFromMessageChain(chain));
                        }
                        const emitFileKey = !host.useCaseSensitiveFileNames() ? toFileNameLowerCase(emitFilePath) : emitFilePath;
                        if (emitFilesSeen.has(emitFileKey)) {
                            blockEmittingOfFile(emitFileName, createCompilerDiagnostic(Diagnostics.Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files, emitFileName));
                        }
                        else {
                            emitFilesSeen.add(emitFileKey);
                        }
                    }
                }
            }
            function getIgnoreDeprecationsVersion() {
                const ignoreDeprecations = options.ignoreDeprecations;
                if (ignoreDeprecations) {
                    if (ignoreDeprecations === "5.0") {
                        return new Version(ignoreDeprecations);
                    }
                    reportInvalidIgnoreDeprecations();
                }
                return Version.zero;
            }
            function checkDeprecations(deprecatedIn, removedIn, createDiagnostic, fn) {
                const deprecatedInVersion = new Version(deprecatedIn);
                const removedInVersion = new Version(removedIn);
                const typescriptVersion = new Version(typeScriptVersion3 || versionMajorMinor);
                const ignoreDeprecationsVersion = getIgnoreDeprecationsVersion();
                const mustBeRemoved = !(removedInVersion.compareTo(typescriptVersion) === 1 /* GreaterThan */);
                const canBeSilenced = !mustBeRemoved && ignoreDeprecationsVersion.compareTo(deprecatedInVersion) === -1 /* LessThan */;
                if (mustBeRemoved || canBeSilenced) {
                    fn((name, value, useInstead) => {
                        if (mustBeRemoved) {
                            if (value === void 0) {
                                createDiagnostic(name, value, useInstead, Diagnostics.Option_0_has_been_removed_Please_remove_it_from_your_configuration, name);
                            }
                            else {
                                createDiagnostic(name, value, useInstead, Diagnostics.Option_0_1_has_been_removed_Please_remove_it_from_your_configuration, name, value);
                            }
                        }
                        else {
                            if (value === void 0) {
                                createDiagnostic(name, value, useInstead, Diagnostics.Option_0_is_deprecated_and_will_stop_functioning_in_TypeScript_1_Specify_compilerOption_ignoreDeprecations_Colon_2_to_silence_this_error, name, removedIn, deprecatedIn);
                            }
                            else {
                                createDiagnostic(name, value, useInstead, Diagnostics.Option_0_1_is_deprecated_and_will_stop_functioning_in_TypeScript_2_Specify_compilerOption_ignoreDeprecations_Colon_3_to_silence_this_error, name, value, removedIn, deprecatedIn);
                            }
                        }
                    });
                }
            }
            function verifyDeprecatedCompilerOptions() {
                function createDiagnostic(name, value, useInstead, message, arg0, arg1, arg2, arg3) {
                    if (useInstead) {
                        const details = chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Use_0_instead, useInstead);
                        const chain = chainDiagnosticMessages(details, message, arg0, arg1, arg2, arg3);
                        createDiagnosticForOption(
                        /*onKey*/
                        !value, name, 
                        /*option2*/
                        void 0, chain);
                    }
                    else {
                        createDiagnosticForOption(
                        /*onKey*/
                        !value, name, 
                        /*option2*/
                        void 0, message, arg0, arg1, arg2, arg3);
                    }
                }
                checkDeprecations("5.0", "5.5", createDiagnostic, (createDeprecatedDiagnostic) => {
                    if (options.target === 0 /* ES3 */) {
                        createDeprecatedDiagnostic("target", "ES3");
                    }
                    if (options.noImplicitUseStrict) {
                        createDeprecatedDiagnostic("noImplicitUseStrict");
                    }
                    if (options.keyofStringsOnly) {
                        createDeprecatedDiagnostic("keyofStringsOnly");
                    }
                    if (options.suppressExcessPropertyErrors) {
                        createDeprecatedDiagnostic("suppressExcessPropertyErrors");
                    }
                    if (options.suppressImplicitAnyIndexErrors) {
                        createDeprecatedDiagnostic("suppressImplicitAnyIndexErrors");
                    }
                    if (options.noStrictGenericChecks) {
                        createDeprecatedDiagnostic("noStrictGenericChecks");
                    }
                    if (options.charset) {
                        createDeprecatedDiagnostic("charset");
                    }
                    if (options.out) {
                        createDeprecatedDiagnostic("out", 
                        /*value*/
                        void 0, "outFile");
                    }
                    if (options.importsNotUsedAsValues) {
                        createDeprecatedDiagnostic("importsNotUsedAsValues", 
                        /*value*/
                        void 0, "verbatimModuleSyntax");
                    }
                    if (options.preserveValueImports) {
                        createDeprecatedDiagnostic("preserveValueImports", 
                        /*value*/
                        void 0, "verbatimModuleSyntax");
                    }
                });
            }
            function verifyDeprecatedProjectReference(ref, parentFile, index) {
                function createDiagnostic(_name, _value, _useInstead, message, arg0, arg1, arg2, arg3) {
                    createDiagnosticForReference(parentFile, index, message, arg0, arg1, arg2, arg3);
                }
                checkDeprecations("5.0", "5.5", createDiagnostic, (createDeprecatedDiagnostic) => {
                    if (ref.prepend) {
                        createDeprecatedDiagnostic("prepend");
                    }
                });
            }
            function createDiagnosticExplainingFile(file, fileProcessingReason, diagnostic, args) {
                var _a3;
                let fileIncludeReasons;
                let relatedInfo;
                let locationReason = isReferencedFile(fileProcessingReason) ? fileProcessingReason : void 0;
                if (file)
                    (_a3 = fileReasons.get(file.path)) == null ? void 0 : _a3.forEach(processReason);
                if (fileProcessingReason)
                    processReason(fileProcessingReason);
                if (locationReason && (fileIncludeReasons == null ? void 0 : fileIncludeReasons.length) === 1)
                    fileIncludeReasons = void 0;
                const location = locationReason && getReferencedFileLocation(getSourceFileByPath, locationReason);
                const fileIncludeReasonDetails = fileIncludeReasons && chainDiagnosticMessages(fileIncludeReasons, Diagnostics.The_file_is_in_the_program_because_Colon);
                const redirectInfo = file && explainIfFileIsRedirectAndImpliedFormat(file);
                const chain = chainDiagnosticMessages(redirectInfo ? fileIncludeReasonDetails ? [fileIncludeReasonDetails, ...redirectInfo] : redirectInfo : fileIncludeReasonDetails, diagnostic, ...args || emptyArray);
                return location && isReferenceFileLocation(location) ? createFileDiagnosticFromMessageChain(location.file, location.pos, location.end - location.pos, chain, relatedInfo) : createCompilerDiagnosticFromMessageChain(chain, relatedInfo);
                function processReason(reason) {
                    (fileIncludeReasons || (fileIncludeReasons = [])).push(fileIncludeReasonToDiagnostics(program, reason));
                    if (!locationReason && isReferencedFile(reason)) {
                        locationReason = reason;
                    }
                    else if (locationReason !== reason) {
                        relatedInfo = append(relatedInfo, fileIncludeReasonToRelatedInformation(reason));
                    }
                    if (reason === fileProcessingReason)
                        fileProcessingReason = void 0;
                }
            }
            function addFilePreprocessingFileExplainingDiagnostic(file, fileProcessingReason, diagnostic, args) {
                (fileProcessingDiagnostics || (fileProcessingDiagnostics = [])).push({
                    kind: 1 /* FilePreprocessingFileExplainingDiagnostic */,
                    file: file && file.path,
                    fileProcessingReason,
                    diagnostic,
                    args
                });
            }
            function addProgramDiagnosticExplainingFile(file, diagnostic, args) {
                programDiagnostics.add(createDiagnosticExplainingFile(file, 
                /*fileProcessingReason*/
                void 0, diagnostic, args));
            }
            function fileIncludeReasonToRelatedInformation(reason) {
                if (isReferencedFile(reason)) {
                    const referenceLocation = getReferencedFileLocation(getSourceFileByPath, reason);
                    let message2;
                    switch (reason.kind) {
                        case 3 /* Import */:
                            message2 = Diagnostics.File_is_included_via_import_here;
                            break;
                        case 4 /* ReferenceFile */:
                            message2 = Diagnostics.File_is_included_via_reference_here;
                            break;
                        case 5 /* TypeReferenceDirective */:
                            message2 = Diagnostics.File_is_included_via_type_library_reference_here;
                            break;
                        case 7 /* LibReferenceDirective */:
                            message2 = Diagnostics.File_is_included_via_library_reference_here;
                            break;
                        default:
                            Debug.assertNever(reason);
                    }
                    return isReferenceFileLocation(referenceLocation) ? createFileDiagnostic(referenceLocation.file, referenceLocation.pos, referenceLocation.end - referenceLocation.pos, message2) : void 0;
                }
                if (!options.configFile)
                    return void 0;
                let configFileNode;
                let message;
                switch (reason.kind) {
                    case 0 /* RootFile */:
                        if (!options.configFile.configFileSpecs)
                            return void 0;
                        const fileName = getNormalizedAbsolutePath(rootNames[reason.index], currentDirectory);
                        const matchedByFiles = getMatchedFileSpec(program, fileName);
                        if (matchedByFiles) {
                            configFileNode = getTsConfigPropArrayElementValue(options.configFile, "files", matchedByFiles);
                            message = Diagnostics.File_is_matched_by_files_list_specified_here;
                            break;
                        }
                        const matchedByInclude = getMatchedIncludeSpec(program, fileName);
                        if (!matchedByInclude || !isString(matchedByInclude))
                            return void 0;
                        configFileNode = getTsConfigPropArrayElementValue(options.configFile, "include", matchedByInclude);
                        message = Diagnostics.File_is_matched_by_include_pattern_specified_here;
                        break;
                    case 1 /* SourceFromProjectReference */:
                    case 2 /* OutputFromProjectReference */:
                        const referencedResolvedRef = Debug.checkDefined(resolvedProjectReferences == null ? void 0 : resolvedProjectReferences[reason.index]);
                        const referenceInfo = forEachProjectReference(projectReferences, resolvedProjectReferences, (resolvedRef, parent2, index2) => resolvedRef === referencedResolvedRef ? { sourceFile: (parent2 == null ? void 0 : parent2.sourceFile) || options.configFile, index: index2 } : void 0);
                        if (!referenceInfo)
                            return void 0;
                        const { sourceFile, index } = referenceInfo;
                        const referencesSyntax = firstDefined(getTsConfigPropArray(sourceFile, "references"), (property) => isArrayLiteralExpression(property.initializer) ? property.initializer : void 0);
                        return referencesSyntax && referencesSyntax.elements.length > index ? createDiagnosticForNodeInSourceFile(sourceFile, referencesSyntax.elements[index], reason.kind === 2 /* OutputFromProjectReference */ ? Diagnostics.File_is_output_from_referenced_project_specified_here : Diagnostics.File_is_source_from_referenced_project_specified_here) : void 0;
                    case 8 /* AutomaticTypeDirectiveFile */:
                        if (!options.types)
                            return void 0;
                        configFileNode = getOptionsSyntaxByArrayElementValue("types", reason.typeReference);
                        message = Diagnostics.File_is_entry_point_of_type_library_specified_here;
                        break;
                    case 6 /* LibFile */:
                        if (reason.index !== void 0) {
                            configFileNode = getOptionsSyntaxByArrayElementValue("lib", options.lib[reason.index]);
                            message = Diagnostics.File_is_library_specified_here;
                            break;
                        }
                        const target = forEachEntry(targetOptionDeclaration.type, (value, key) => value === getEmitScriptTarget(options) ? key : void 0);
                        configFileNode = target ? getOptionsSyntaxByValue("target", target) : void 0;
                        message = Diagnostics.File_is_default_library_for_target_specified_here;
                        break;
                    default:
                        Debug.assertNever(reason);
                }
                return configFileNode && createDiagnosticForNodeInSourceFile(options.configFile, configFileNode, message);
            }
            function verifyProjectReferences() {
                const buildInfoPath = !options.suppressOutputPathCheck ? getTsBuildInfoEmitOutputFilePath(options) : void 0;
                forEachProjectReference(projectReferences, resolvedProjectReferences, (resolvedRef, parent2, index) => {
                    const ref = (parent2 ? parent2.commandLine.projectReferences : projectReferences)[index];
                    const parentFile = parent2 && parent2.sourceFile;
                    verifyDeprecatedProjectReference(ref, parentFile, index);
                    if (!resolvedRef) {
                        createDiagnosticForReference(parentFile, index, Diagnostics.File_0_not_found, ref.path);
                        return;
                    }
                    const options2 = resolvedRef.commandLine.options;
                    if (!options2.composite || options2.noEmit) {
                        const inputs = parent2 ? parent2.commandLine.fileNames : rootNames;
                        if (inputs.length) {
                            if (!options2.composite)
                                createDiagnosticForReference(parentFile, index, Diagnostics.Referenced_project_0_must_have_setting_composite_Colon_true, ref.path);
                            if (options2.noEmit)
                                createDiagnosticForReference(parentFile, index, Diagnostics.Referenced_project_0_may_not_disable_emit, ref.path);
                        }
                    }
                    if (ref.prepend) {
                        const out = outFile(options2);
                        if (out) {
                            if (!host.fileExists(out)) {
                                createDiagnosticForReference(parentFile, index, Diagnostics.Output_file_0_from_project_1_does_not_exist, out, ref.path);
                            }
                        }
                        else {
                            createDiagnosticForReference(parentFile, index, Diagnostics.Cannot_prepend_project_0_because_it_does_not_have_outFile_set, ref.path);
                        }
                    }
                    if (!parent2 && buildInfoPath && buildInfoPath === getTsBuildInfoEmitOutputFilePath(options2)) {
                        createDiagnosticForReference(parentFile, index, Diagnostics.Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1, buildInfoPath, ref.path);
                        hasEmitBlockingDiagnostics.set(toPath3(buildInfoPath), true);
                    }
                });
            }
            function createDiagnosticForOptionPathKeyValue(key, valueIndex, message, arg0, arg1, arg2) {
                let needCompilerDiagnostic = true;
                const pathsSyntax = getOptionPathsSyntax();
                for (const pathProp of pathsSyntax) {
                    if (isObjectLiteralExpression(pathProp.initializer)) {
                        for (const keyProps of getPropertyAssignment(pathProp.initializer, key)) {
                            const initializer = keyProps.initializer;
                            if (isArrayLiteralExpression(initializer) && initializer.elements.length > valueIndex) {
                                programDiagnostics.add(createDiagnosticForNodeInSourceFile(options.configFile, initializer.elements[valueIndex], message, arg0, arg1, arg2));
                                needCompilerDiagnostic = false;
                            }
                        }
                    }
                }
                if (needCompilerDiagnostic) {
                    programDiagnostics.add(createCompilerDiagnostic(message, arg0, arg1, arg2));
                }
            }
            function createDiagnosticForOptionPaths(onKey, key, message, arg0) {
                let needCompilerDiagnostic = true;
                const pathsSyntax = getOptionPathsSyntax();
                for (const pathProp of pathsSyntax) {
                    if (isObjectLiteralExpression(pathProp.initializer) && createOptionDiagnosticInObjectLiteralSyntax(pathProp.initializer, onKey, key, 
                    /*key2*/
                    void 0, message, arg0)) {
                        needCompilerDiagnostic = false;
                    }
                }
                if (needCompilerDiagnostic) {
                    programDiagnostics.add(createCompilerDiagnostic(message, arg0));
                }
            }
            function getOptionsSyntaxByName(name) {
                const compilerOptionsObjectLiteralSyntax = getCompilerOptionsObjectLiteralSyntax();
                return compilerOptionsObjectLiteralSyntax && getPropertyAssignment(compilerOptionsObjectLiteralSyntax, name);
            }
            function getOptionPathsSyntax() {
                return getOptionsSyntaxByName("paths") || emptyArray;
            }
            function getOptionsSyntaxByValue(name, value) {
                const syntaxByName = getOptionsSyntaxByName(name);
                return syntaxByName && firstDefined(syntaxByName, (property) => isStringLiteral(property.initializer) && property.initializer.text === value ? property.initializer : void 0);
            }
            function getOptionsSyntaxByArrayElementValue(name, value) {
                const compilerOptionsObjectLiteralSyntax = getCompilerOptionsObjectLiteralSyntax();
                return compilerOptionsObjectLiteralSyntax && getPropertyArrayElementValue(compilerOptionsObjectLiteralSyntax, name, value);
            }
            function createDiagnosticForOptionName(message, option1, option2, option3) {
                createDiagnosticForOption(
                /*onKey*/
                true, option1, option2, message, option1, option2, option3);
            }
            function createOptionValueDiagnostic(option1, message, arg0, arg1) {
                createDiagnosticForOption(
                /*onKey*/
                false, option1, 
                /*option2*/
                void 0, message, arg0, arg1);
            }
            function createDiagnosticForReference(sourceFile, index, message, arg0, arg1, arg2, arg3) {
                const referencesSyntax = firstDefined(getTsConfigPropArray(sourceFile || options.configFile, "references"), (property) => isArrayLiteralExpression(property.initializer) ? property.initializer : void 0);
                if (referencesSyntax && referencesSyntax.elements.length > index) {
                    programDiagnostics.add(createDiagnosticForNodeInSourceFile(sourceFile || options.configFile, referencesSyntax.elements[index], message, arg0, arg1, arg2, arg3));
                }
                else {
                    programDiagnostics.add(createCompilerDiagnostic(message, arg0, arg1, arg2, arg3));
                }
            }
            function createDiagnosticForOption(onKey, option1, option2, message, arg0, arg1, arg2, arg3) {
                const compilerOptionsObjectLiteralSyntax = getCompilerOptionsObjectLiteralSyntax();
                const needCompilerDiagnostic = !compilerOptionsObjectLiteralSyntax || !createOptionDiagnosticInObjectLiteralSyntax(compilerOptionsObjectLiteralSyntax, onKey, option1, option2, message, arg0, arg1, arg2, arg3);
                if (needCompilerDiagnostic) {
                    if ("messageText" in message) {
                        programDiagnostics.add(createCompilerDiagnosticFromMessageChain(message));
                    }
                    else {
                        programDiagnostics.add(createCompilerDiagnostic(message, arg0, arg1, arg2, arg3));
                    }
                }
            }
            function getCompilerOptionsObjectLiteralSyntax() {
                if (_compilerOptionsObjectLiteralSyntax === void 0) {
                    _compilerOptionsObjectLiteralSyntax = false;
                    const jsonObjectLiteral = getTsConfigObjectLiteralExpression(options.configFile);
                    if (jsonObjectLiteral) {
                        for (const prop of getPropertyAssignment(jsonObjectLiteral, "compilerOptions")) {
                            if (isObjectLiteralExpression(prop.initializer)) {
                                _compilerOptionsObjectLiteralSyntax = prop.initializer;
                                break;
                            }
                        }
                    }
                }
                return _compilerOptionsObjectLiteralSyntax || void 0;
            }
            function createOptionDiagnosticInObjectLiteralSyntax(objectLiteral, onKey, key1, key2, message, arg0, arg1, arg2, arg3) {
                const props = getPropertyAssignment(objectLiteral, key1, key2);
                for (const prop of props) {
                    if ("messageText" in message) {
                        programDiagnostics.add(createDiagnosticForNodeFromMessageChain(options.configFile, onKey ? prop.name : prop.initializer, message));
                    }
                    else {
                        programDiagnostics.add(createDiagnosticForNodeInSourceFile(options.configFile, onKey ? prop.name : prop.initializer, message, arg0, arg1, arg2, arg3));
                    }
                }
                return !!props.length;
            }
            function createRedundantOptionDiagnostic(errorOnOption, redundantWithOption) {
                const compilerOptionsObjectLiteralSyntax = getCompilerOptionsObjectLiteralSyntax();
                if (compilerOptionsObjectLiteralSyntax) {
                    createOptionDiagnosticInObjectLiteralSyntax(compilerOptionsObjectLiteralSyntax, 
                    /*onKey*/
                    true, errorOnOption, 
                    /*key2*/
                    void 0, Diagnostics.Option_0_is_redundant_and_cannot_be_specified_with_option_1, errorOnOption, redundantWithOption);
                }
                else {
                    createDiagnosticForOptionName(Diagnostics.Option_0_is_redundant_and_cannot_be_specified_with_option_1, errorOnOption, redundantWithOption);
                }
            }
            function blockEmittingOfFile(emitFileName, diag2) {
                hasEmitBlockingDiagnostics.set(toPath3(emitFileName), true);
                programDiagnostics.add(diag2);
            }
            function isEmittedFile(file) {
                if (options.noEmit) {
                    return false;
                }
                const filePath = toPath3(file);
                if (getSourceFileByPath(filePath)) {
                    return false;
                }
                const out = outFile(options);
                if (out) {
                    return isSameFile(filePath, out) || isSameFile(filePath, removeFileExtension(out) + ".d.ts" /* Dts */);
                }
                if (options.declarationDir && containsPath(options.declarationDir, filePath, currentDirectory, !host.useCaseSensitiveFileNames())) {
                    return true;
                }
                if (options.outDir) {
                    return containsPath(options.outDir, filePath, currentDirectory, !host.useCaseSensitiveFileNames());
                }
                if (fileExtensionIsOneOf(filePath, supportedJSExtensionsFlat) || isDeclarationFileName(filePath)) {
                    const filePathWithoutExtension = removeFileExtension(filePath);
                    return !!getSourceFileByPath(filePathWithoutExtension + ".ts" /* Ts */) || !!getSourceFileByPath(filePathWithoutExtension + ".tsx" /* Tsx */);
                }
                return false;
            }
            function isSameFile(file1, file2) {
                return comparePaths(file1, file2, currentDirectory, !host.useCaseSensitiveFileNames()) === 0 /* EqualTo */;
            }
            function getSymlinkCache() {
                if (host.getSymlinkCache) {
                    return host.getSymlinkCache();
                }
                if (!symlinks) {
                    symlinks = createSymlinkCache(currentDirectory, getCanonicalFileName);
                }
                if (files && automaticTypeDirectiveResolutions && !symlinks.hasProcessedResolutions()) {
                    symlinks.setSymlinksFromResolutions(files, automaticTypeDirectiveResolutions);
                }
                return symlinks;
            }
        }
        function updateHostForUseSourceOfProjectReferenceRedirect(host) {
            let setOfDeclarationDirectories;
            const originalFileExists = host.compilerHost.fileExists;
            const originalDirectoryExists = host.compilerHost.directoryExists;
            const originalGetDirectories = host.compilerHost.getDirectories;
            const originalRealpath = host.compilerHost.realpath;
            if (!host.useSourceOfProjectReferenceRedirect)
                return { onProgramCreateComplete: noop, fileExists };
            host.compilerHost.fileExists = fileExists;
            let directoryExists;
            if (originalDirectoryExists) {
                directoryExists = host.compilerHost.directoryExists = (path) => {
                    if (originalDirectoryExists.call(host.compilerHost, path)) {
                        handleDirectoryCouldBeSymlink(path);
                        return true;
                    }
                    if (!host.getResolvedProjectReferences())
                        return false;
                    if (!setOfDeclarationDirectories) {
                        setOfDeclarationDirectories = /* @__PURE__ */ new Set();
                        host.forEachResolvedProjectReference((ref) => {
                            const out = outFile(ref.commandLine.options);
                            if (out) {
                                setOfDeclarationDirectories.add(getDirectoryPath(host.toPath(out)));
                            }
                            else {
                                const declarationDir = ref.commandLine.options.declarationDir || ref.commandLine.options.outDir;
                                if (declarationDir) {
                                    setOfDeclarationDirectories.add(host.toPath(declarationDir));
                                }
                            }
                        });
                    }
                    return fileOrDirectoryExistsUsingSource(path, 
                    /*isFile*/
                    false);
                };
            }
            if (originalGetDirectories) {
                host.compilerHost.getDirectories = (path) => !host.getResolvedProjectReferences() || originalDirectoryExists && originalDirectoryExists.call(host.compilerHost, path) ? originalGetDirectories.call(host.compilerHost, path) : [];
            }
            if (originalRealpath) {
                host.compilerHost.realpath = (s) => {
                    var _a2;
                    return ((_a2 = host.getSymlinkCache().getSymlinkedFiles()) == null ? void 0 : _a2.get(host.toPath(s))) || originalRealpath.call(host.compilerHost, s);
                };
            }
            return { onProgramCreateComplete, fileExists, directoryExists };
            function onProgramCreateComplete() {
                host.compilerHost.fileExists = originalFileExists;
                host.compilerHost.directoryExists = originalDirectoryExists;
                host.compilerHost.getDirectories = originalGetDirectories;
            }
            function fileExists(file) {
                if (originalFileExists.call(host.compilerHost, file))
                    return true;
                if (!host.getResolvedProjectReferences())
                    return false;
                if (!isDeclarationFileName(file))
                    return false;
                return fileOrDirectoryExistsUsingSource(file, 
                /*isFile*/
                true);
            }
            function fileExistsIfProjectReferenceDts(file) {
                const source = host.getSourceOfProjectReferenceRedirect(host.toPath(file));
                return source !== void 0 ? isString(source) ? originalFileExists.call(host.compilerHost, source) : true : void 0;
            }
            function directoryExistsIfProjectReferenceDeclDir(dir) {
                const dirPath = host.toPath(dir);
                const dirPathWithTrailingDirectorySeparator = `${dirPath}${directorySeparator}`;
                return forEachKey(setOfDeclarationDirectories, (declDirPath) => dirPath === declDirPath || // Any parent directory of declaration dir
                    startsWith(declDirPath, dirPathWithTrailingDirectorySeparator) || // Any directory inside declaration dir
                    startsWith(dirPath, `${declDirPath}/`));
            }
            function handleDirectoryCouldBeSymlink(directory) {
                var _a2;
                if (!host.getResolvedProjectReferences() || containsIgnoredPath(directory))
                    return;
                if (!originalRealpath || !stringContains(directory, nodeModulesPathPart))
                    return;
                const symlinkCache = host.getSymlinkCache();
                const directoryPath = ensureTrailingDirectorySeparator(host.toPath(directory));
                if ((_a2 = symlinkCache.getSymlinkedDirectories()) == null ? void 0 : _a2.has(directoryPath))
                    return;
                const real = normalizePath(originalRealpath.call(host.compilerHost, directory));
                let realPath2;
                if (real === directory || (realPath2 = ensureTrailingDirectorySeparator(host.toPath(real))) === directoryPath) {
                    symlinkCache.setSymlinkedDirectory(directoryPath, false);
                    return;
                }
                symlinkCache.setSymlinkedDirectory(directory, {
                    real: ensureTrailingDirectorySeparator(real),
                    realPath: realPath2
                });
            }
            function fileOrDirectoryExistsUsingSource(fileOrDirectory, isFile) {
                var _a2;
                const fileOrDirectoryExistsUsingSource2 = isFile ? (file) => fileExistsIfProjectReferenceDts(file) : (dir) => directoryExistsIfProjectReferenceDeclDir(dir);
                const result = fileOrDirectoryExistsUsingSource2(fileOrDirectory);
                if (result !== void 0)
                    return result;
                const symlinkCache = host.getSymlinkCache();
                const symlinkedDirectories = symlinkCache.getSymlinkedDirectories();
                if (!symlinkedDirectories)
                    return false;
                const fileOrDirectoryPath = host.toPath(fileOrDirectory);
                if (!stringContains(fileOrDirectoryPath, nodeModulesPathPart))
                    return false;
                if (isFile && ((_a2 = symlinkCache.getSymlinkedFiles()) == null ? void 0 : _a2.has(fileOrDirectoryPath)))
                    return true;
                return firstDefinedIterator(symlinkedDirectories.entries(), ([directoryPath, symlinkedDirectory]) => {
                    if (!symlinkedDirectory || !startsWith(fileOrDirectoryPath, directoryPath))
                        return void 0;
                    const result2 = fileOrDirectoryExistsUsingSource2(fileOrDirectoryPath.replace(directoryPath, symlinkedDirectory.realPath));
                    if (isFile && result2) {
                        const absolutePath = getNormalizedAbsolutePath(fileOrDirectory, host.compilerHost.getCurrentDirectory());
                        symlinkCache.setSymlinkedFile(fileOrDirectoryPath, `${symlinkedDirectory.real}${absolutePath.replace(new RegExp(directoryPath, "i"), "")}`);
                    }
                    return result2;
                }) || false;
            }
        }
        function handleNoEmitOptions(program, sourceFile, writeFile2, cancellationToken) {
            const options = program.getCompilerOptions();
            if (options.noEmit) {
                program.getSemanticDiagnostics(sourceFile, cancellationToken);
                return sourceFile || outFile(options) ? emitSkippedWithNoDiagnostics : program.emitBuildInfo(writeFile2, cancellationToken);
            }
            if (!options.noEmitOnError)
                return void 0;
            let diagnostics = [
                ...program.getOptionsDiagnostics(cancellationToken),
                ...program.getSyntacticDiagnostics(sourceFile, cancellationToken),
                ...program.getGlobalDiagnostics(cancellationToken),
                ...program.getSemanticDiagnostics(sourceFile, cancellationToken)
            ];
            if (diagnostics.length === 0 && getEmitDeclarations(program.getCompilerOptions())) {
                diagnostics = program.getDeclarationDiagnostics(
                /*sourceFile*/
                void 0, cancellationToken);
            }
            if (!diagnostics.length)
                return void 0;
            let emittedFiles;
            if (!sourceFile && !outFile(options)) {
                const emitResult = program.emitBuildInfo(writeFile2, cancellationToken);
                if (emitResult.diagnostics)
                    diagnostics = [...diagnostics, ...emitResult.diagnostics];
                emittedFiles = emitResult.emittedFiles;
            }
            return { diagnostics, sourceMaps: void 0, emittedFiles, emitSkipped: true };
        }
        function filterSemanticDiagnostics(diagnostic, option) {
            return filter(diagnostic, (d) => !d.skippedOn || !option[d.skippedOn]);
        }
        function parseConfigHostFromCompilerHostLike(host, directoryStructureHost = host) {
            return {
                fileExists: (f) => directoryStructureHost.fileExists(f),
                readDirectory(root, extensions, excludes, includes, depth) {
                    Debug.assertIsDefined(directoryStructureHost.readDirectory, "'CompilerHost.readDirectory' must be implemented to correctly process 'projectReferences'");
                    return directoryStructureHost.readDirectory(root, extensions, excludes, includes, depth);
                },
                readFile: (f) => directoryStructureHost.readFile(f),
                useCaseSensitiveFileNames: host.useCaseSensitiveFileNames(),
                getCurrentDirectory: () => host.getCurrentDirectory(),
                onUnRecoverableConfigFileDiagnostic: host.onUnRecoverableConfigFileDiagnostic || returnUndefined,
                trace: host.trace ? (s) => host.trace(s) : void 0
            };
        }
        function createPrependNodes(projectReferences, getCommandLine, readFile, host) {
            if (!projectReferences)
                return emptyArray;
            let nodes;
            for (let i = 0; i < projectReferences.length; i++) {
                const ref = projectReferences[i];
                const resolvedRefOpts = getCommandLine(ref, i);
                if (ref.prepend && resolvedRefOpts && resolvedRefOpts.options) {
                    const out = outFile(resolvedRefOpts.options);
                    if (!out)
                        continue;
                    const { jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath } = getOutputPathsForBundle(resolvedRefOpts.options, 
                    /*forceDtsPaths*/
                    true);
                    const node = createInputFilesWithFilePaths(readFile, jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath, host, resolvedRefOpts.options);
                    (nodes || (nodes = [])).push(node);
                }
            }
            return nodes || emptyArray;
        }
        function resolveProjectReferencePath(ref) {
            return resolveConfigFileProjectName(ref.path);
        }
        function getResolutionDiagnostic(options, { extension }, { isDeclarationFile }) {
            switch (extension) {
                case ".ts" /* Ts */:
                case ".d.ts" /* Dts */:
                case ".mts" /* Mts */:
                case ".d.mts" /* Dmts */:
                case ".cts" /* Cts */:
                case ".d.cts" /* Dcts */:
                    return void 0;
                case ".tsx" /* Tsx */:
                    return needJsx();
                case ".jsx" /* Jsx */:
                    return needJsx() || needAllowJs();
                case ".js" /* Js */:
                case ".mjs" /* Mjs */:
                case ".cjs" /* Cjs */:
                    return needAllowJs();
                case ".json" /* Json */:
                    return needResolveJsonModule();
                default:
                    return needAllowArbitraryExtensions();
            }
            function needJsx() {
                return options.jsx ? void 0 : Diagnostics.Module_0_was_resolved_to_1_but_jsx_is_not_set;
            }
            function needAllowJs() {
                return getAllowJSCompilerOption(options) || !getStrictOptionValue(options, "noImplicitAny") ? void 0 : Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type;
            }
            function needResolveJsonModule() {
                return getResolveJsonModule(options) ? void 0 : Diagnostics.Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used;
            }
            function needAllowArbitraryExtensions() {
                return isDeclarationFile || options.allowArbitraryExtensions ? void 0 : Diagnostics.Module_0_was_resolved_to_1_but_allowArbitraryExtensions_is_not_set;
            }
        }
        function getModuleNames({ imports, moduleAugmentations }) {
            const res = imports.map((i) => i);
            for (const aug of moduleAugmentations) {
                if (aug.kind === 10 /* StringLiteral */) {
                    res.push(aug);
                }
            }
            return res;
        }
        function getModuleNameStringLiteralAt({ imports, moduleAugmentations }, index) {
            if (index < imports.length)
                return imports[index];
            let augIndex = imports.length;
            for (const aug of moduleAugmentations) {
                if (aug.kind === 10 /* StringLiteral */) {
                    if (index === augIndex)
                        return aug;
                    augIndex++;
                }
            }
            Debug.fail("should never ask for module name at index higher than possible module name");
        }
        var ForegroundColorEscapeSequences, gutterStyleSequence, gutterSeparator, resetEscapeSequence, ellipsis, halfIndent, indent, emptyResolution, moduleResolutionNameAndModeGetter, typeReferenceResolutionNameAndModeGetter, inferredTypesContainingFile, plainJSErrors, emitSkippedWithNoDiagnostics;
        var init_program = __esm({
            "src/compiler/program.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
                init_ts_performance();
                ForegroundColorEscapeSequences = /* @__PURE__ */ ((ForegroundColorEscapeSequences2) => {
                    ForegroundColorEscapeSequences2["Grey"] = "\x1B[90m";
                    ForegroundColorEscapeSequences2["Red"] = "\x1B[91m";
                    ForegroundColorEscapeSequences2["Yellow"] = "\x1B[93m";
                    ForegroundColorEscapeSequences2["Blue"] = "\x1B[94m";
                    ForegroundColorEscapeSequences2["Cyan"] = "\x1B[96m";
                    return ForegroundColorEscapeSequences2;
                })(ForegroundColorEscapeSequences || {});
                gutterStyleSequence = "\x1B[7m";
                gutterSeparator = " ";
                resetEscapeSequence = "\x1B[0m";
                ellipsis = "...";
                halfIndent = "  ";
                indent = "    ";
                emptyResolution = {
                    resolvedModule: void 0,
                    resolvedTypeReferenceDirective: void 0
                };
                moduleResolutionNameAndModeGetter = {
                    getName: getModuleResolutionName,
                    getMode: (entry, file) => getModeForUsageLocation(file, entry)
                };
                typeReferenceResolutionNameAndModeGetter = {
                    getName: getTypeReferenceResolutionName,
                    getMode: (entry, file) => getModeForFileReference(entry, file == null ? void 0 : file.impliedNodeFormat)
                };
                inferredTypesContainingFile = "__inferred type names__.ts";
                plainJSErrors = /* @__PURE__ */ new Set([
                    // binder errors
                    Diagnostics.Cannot_redeclare_block_scoped_variable_0.code,
                    Diagnostics.A_module_cannot_have_multiple_default_exports.code,
                    Diagnostics.Another_export_default_is_here.code,
                    Diagnostics.The_first_export_default_is_here.code,
                    Diagnostics.Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module.code,
                    Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode.code,
                    Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here.code,
                    Diagnostics.constructor_is_a_reserved_word.code,
                    Diagnostics.delete_cannot_be_called_on_an_identifier_in_strict_mode.code,
                    Diagnostics.Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of_0_For_more_information_see_https_Colon_Slash_Slashdeveloper_mozilla_org_Slashen_US_Slashdocs_SlashWeb_SlashJavaScript_SlashReference_SlashStrict_mode.code,
                    Diagnostics.Invalid_use_of_0_Modules_are_automatically_in_strict_mode.code,
                    Diagnostics.Invalid_use_of_0_in_strict_mode.code,
                    Diagnostics.A_label_is_not_allowed_here.code,
                    Diagnostics.Octal_literals_are_not_allowed_in_strict_mode.code,
                    Diagnostics.with_statements_are_not_allowed_in_strict_mode.code,
                    // grammar errors
                    Diagnostics.A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement.code,
                    Diagnostics.A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement.code,
                    Diagnostics.A_class_declaration_without_the_default_modifier_must_have_a_name.code,
                    Diagnostics.A_class_member_cannot_have_the_0_keyword.code,
                    Diagnostics.A_comma_expression_is_not_allowed_in_a_computed_property_name.code,
                    Diagnostics.A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement.code,
                    Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement.code,
                    Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement.code,
                    Diagnostics.A_default_clause_cannot_appear_more_than_once_in_a_switch_statement.code,
                    Diagnostics.A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration.code,
                    Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context.code,
                    Diagnostics.A_destructuring_declaration_must_have_an_initializer.code,
                    Diagnostics.A_get_accessor_cannot_have_parameters.code,
                    Diagnostics.A_rest_element_cannot_contain_a_binding_pattern.code,
                    Diagnostics.A_rest_element_cannot_have_a_property_name.code,
                    Diagnostics.A_rest_element_cannot_have_an_initializer.code,
                    Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern.code,
                    Diagnostics.A_rest_parameter_cannot_have_an_initializer.code,
                    Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list.code,
                    Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma.code,
                    Diagnostics.A_return_statement_cannot_be_used_inside_a_class_static_block.code,
                    Diagnostics.A_set_accessor_cannot_have_rest_parameter.code,
                    Diagnostics.A_set_accessor_must_have_exactly_one_parameter.code,
                    Diagnostics.An_export_declaration_can_only_be_used_at_the_top_level_of_a_module.code,
                    Diagnostics.An_export_declaration_cannot_have_modifiers.code,
                    Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_module.code,
                    Diagnostics.An_import_declaration_cannot_have_modifiers.code,
                    Diagnostics.An_object_member_cannot_be_declared_optional.code,
                    Diagnostics.Argument_of_dynamic_import_cannot_be_spread_element.code,
                    Diagnostics.Cannot_assign_to_private_method_0_Private_methods_are_not_writable.code,
                    Diagnostics.Cannot_redeclare_identifier_0_in_catch_clause.code,
                    Diagnostics.Catch_clause_variable_cannot_have_an_initializer.code,
                    Diagnostics.Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator.code,
                    Diagnostics.Classes_can_only_extend_a_single_class.code,
                    Diagnostics.Classes_may_not_have_a_field_named_constructor.code,
                    Diagnostics.Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern.code,
                    Diagnostics.Duplicate_label_0.code,
                    Diagnostics.Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_assertion_as_arguments.code,
                    Diagnostics.For_await_loops_cannot_be_used_inside_a_class_static_block.code,
                    Diagnostics.JSX_attributes_must_only_be_assigned_a_non_empty_expression.code,
                    Diagnostics.JSX_elements_cannot_have_multiple_attributes_with_the_same_name.code,
                    Diagnostics.JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array.code,
                    Diagnostics.JSX_property_access_expressions_cannot_include_JSX_namespace_names.code,
                    Diagnostics.Jump_target_cannot_cross_function_boundary.code,
                    Diagnostics.Line_terminator_not_permitted_before_arrow.code,
                    Diagnostics.Modifiers_cannot_appear_here.code,
                    Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement.code,
                    Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement.code,
                    Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies.code,
                    Diagnostics.Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression.code,
                    Diagnostics.Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier.code,
                    Diagnostics.Tagged_template_expressions_are_not_permitted_in_an_optional_chain.code,
                    Diagnostics.The_left_hand_side_of_a_for_of_statement_may_not_be_async.code,
                    Diagnostics.The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer.code,
                    Diagnostics.The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer.code,
                    Diagnostics.Trailing_comma_not_allowed.code,
                    Diagnostics.Variable_declaration_list_cannot_be_empty.code,
                    Diagnostics._0_and_1_operations_cannot_be_mixed_without_parentheses.code,
                    Diagnostics._0_expected.code,
                    Diagnostics._0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2.code,
                    Diagnostics._0_list_cannot_be_empty.code,
                    Diagnostics._0_modifier_already_seen.code,
                    Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration.code,
                    Diagnostics._0_modifier_cannot_appear_on_a_module_or_namespace_element.code,
                    Diagnostics._0_modifier_cannot_appear_on_a_parameter.code,
                    Diagnostics._0_modifier_cannot_appear_on_class_elements_of_this_kind.code,
                    Diagnostics._0_modifier_cannot_be_used_here.code,
                    Diagnostics._0_modifier_must_precede_1_modifier.code,
                    Diagnostics.const_declarations_can_only_be_declared_inside_a_block.code,
                    Diagnostics.const_declarations_must_be_initialized.code,
                    Diagnostics.extends_clause_already_seen.code,
                    Diagnostics.let_declarations_can_only_be_declared_inside_a_block.code,
                    Diagnostics.let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations.code,
                    Diagnostics.Class_constructor_may_not_be_a_generator.code,
                    Diagnostics.Class_constructor_may_not_be_an_accessor.code,
                    Diagnostics.await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code
                ]);
                emitSkippedWithNoDiagnostics = { diagnostics: emptyArray, sourceMaps: void 0, emittedFiles: void 0, emitSkipped: true };
            }
        });
        // src/compiler/builderStatePublic.ts
        var init_builderStatePublic = __esm({
            "src/compiler/builderStatePublic.ts"() {
                "use strict";
            }
        });
        // src/compiler/builderState.ts
        function getFileEmitOutput(program, sourceFile, emitOnlyDtsFiles, cancellationToken, customTransformers, forceDtsEmit) {
            const outputFiles = [];
            const { emitSkipped, diagnostics } = program.emit(sourceFile, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers, forceDtsEmit);
            return { outputFiles, emitSkipped, diagnostics };
            function writeFile2(fileName, text, writeByteOrderMark) {
                outputFiles.push({ name: fileName, writeByteOrderMark, text });
            }
        }
        var BuilderState;
        var init_builderState = __esm({
            "src/compiler/builderState.ts"() {
                "use strict";
                init_ts2();
                ((BuilderState2) => {
                    function createManyToManyPathMap() {
                        function create2(forward, reverse, deleted) {
                            const map2 = {
                                getKeys: (v) => reverse.get(v),
                                getValues: (k) => forward.get(k),
                                keys: () => forward.keys(),
                                deleteKey: (k) => {
                                    (deleted || (deleted = /* @__PURE__ */ new Set())).add(k);
                                    const set = forward.get(k);
                                    if (!set) {
                                        return false;
                                    }
                                    set.forEach((v) => deleteFromMultimap(reverse, v, k));
                                    forward.delete(k);
                                    return true;
                                },
                                set: (k, vSet) => {
                                    deleted == null ? void 0 : deleted.delete(k);
                                    const existingVSet = forward.get(k);
                                    forward.set(k, vSet);
                                    existingVSet == null ? void 0 : existingVSet.forEach((v) => {
                                        if (!vSet.has(v)) {
                                            deleteFromMultimap(reverse, v, k);
                                        }
                                    });
                                    vSet.forEach((v) => {
                                        if (!(existingVSet == null ? void 0 : existingVSet.has(v))) {
                                            addToMultimap(reverse, v, k);
                                        }
                                    });
                                    return map2;
                                }
                            };
                            return map2;
                        }
                        return create2(
                        /* @__PURE__ */ new Map(), 
                        /* @__PURE__ */ new Map(), 
                        /*deleted*/
                        void 0);
                    }
                    BuilderState2.createManyToManyPathMap = createManyToManyPathMap;
                    function addToMultimap(map2, k, v) {
                        let set = map2.get(k);
                        if (!set) {
                            set = /* @__PURE__ */ new Set();
                            map2.set(k, set);
                        }
                        set.add(v);
                    }
                    function deleteFromMultimap(map2, k, v) {
                        const set = map2.get(k);
                        if (set == null ? void 0 : set.delete(v)) {
                            if (!set.size) {
                                map2.delete(k);
                            }
                            return true;
                        }
                        return false;
                    }
                    function getReferencedFilesFromImportedModuleSymbol(symbol) {
                        return mapDefined(symbol.declarations, (declaration) => {
                            var _a2;
                            return (_a2 = getSourceFileOfNode(declaration)) == null ? void 0 : _a2.resolvedPath;
                        });
                    }
                    function getReferencedFilesFromImportLiteral(checker, importName) {
                        const symbol = checker.getSymbolAtLocation(importName);
                        return symbol && getReferencedFilesFromImportedModuleSymbol(symbol);
                    }
                    function getReferencedFileFromFileName(program, fileName, sourceFileDirectory, getCanonicalFileName) {
                        return toPath(program.getProjectReferenceRedirect(fileName) || fileName, sourceFileDirectory, getCanonicalFileName);
                    }
                    function getReferencedFiles(program, sourceFile, getCanonicalFileName) {
                        let referencedFiles;
                        if (sourceFile.imports && sourceFile.imports.length > 0) {
                            const checker = program.getTypeChecker();
                            for (const importName of sourceFile.imports) {
                                const declarationSourceFilePaths = getReferencedFilesFromImportLiteral(checker, importName);
                                declarationSourceFilePaths == null ? void 0 : declarationSourceFilePaths.forEach(addReferencedFile);
                            }
                        }
                        const sourceFileDirectory = getDirectoryPath(sourceFile.resolvedPath);
                        if (sourceFile.referencedFiles && sourceFile.referencedFiles.length > 0) {
                            for (const referencedFile of sourceFile.referencedFiles) {
                                const referencedPath = getReferencedFileFromFileName(program, referencedFile.fileName, sourceFileDirectory, getCanonicalFileName);
                                addReferencedFile(referencedPath);
                            }
                        }
                        if (sourceFile.resolvedTypeReferenceDirectiveNames) {
                            sourceFile.resolvedTypeReferenceDirectiveNames.forEach(({ resolvedTypeReferenceDirective }) => {
                                if (!resolvedTypeReferenceDirective) {
                                    return;
                                }
                                const fileName = resolvedTypeReferenceDirective.resolvedFileName;
                                const typeFilePath = getReferencedFileFromFileName(program, fileName, sourceFileDirectory, getCanonicalFileName);
                                addReferencedFile(typeFilePath);
                            });
                        }
                        if (sourceFile.moduleAugmentations.length) {
                            const checker = program.getTypeChecker();
                            for (const moduleName of sourceFile.moduleAugmentations) {
                                if (!isStringLiteral(moduleName))
                                    continue;
                                const symbol = checker.getSymbolAtLocation(moduleName);
                                if (!symbol)
                                    continue;
                                addReferenceFromAmbientModule(symbol);
                            }
                        }
                        for (const ambientModule of program.getTypeChecker().getAmbientModules()) {
                            if (ambientModule.declarations && ambientModule.declarations.length > 1) {
                                addReferenceFromAmbientModule(ambientModule);
                            }
                        }
                        return referencedFiles;
                        function addReferenceFromAmbientModule(symbol) {
                            if (!symbol.declarations) {
                                return;
                            }
                            for (const declaration of symbol.declarations) {
                                const declarationSourceFile = getSourceFileOfNode(declaration);
                                if (declarationSourceFile && declarationSourceFile !== sourceFile) {
                                    addReferencedFile(declarationSourceFile.resolvedPath);
                                }
                            }
                        }
                        function addReferencedFile(referencedPath) {
                            (referencedFiles || (referencedFiles = /* @__PURE__ */ new Set())).add(referencedPath);
                        }
                    }
                    function canReuseOldState(newReferencedMap, oldState) {
                        return oldState && !oldState.referencedMap === !newReferencedMap;
                    }
                    BuilderState2.canReuseOldState = canReuseOldState;
                    function create(newProgram, oldState, disableUseFileVersionAsSignature) {
                        var _a2, _b, _c;
                        const fileInfos = /* @__PURE__ */ new Map();
                        const options = newProgram.getCompilerOptions();
                        const isOutFile = outFile(options);
                        const referencedMap = options.module !== 0 /* None */ && !isOutFile ? createManyToManyPathMap() : void 0;
                        const exportedModulesMap = referencedMap ? createManyToManyPathMap() : void 0;
                        const useOldState = canReuseOldState(referencedMap, oldState);
                        newProgram.getTypeChecker();
                        for (const sourceFile of newProgram.getSourceFiles()) {
                            const version2 = Debug.checkDefined(sourceFile.version, "Program intended to be used with Builder should have source files with versions set");
                            const oldUncommittedSignature = useOldState ? (_a2 = oldState.oldSignatures) == null ? void 0 : _a2.get(sourceFile.resolvedPath) : void 0;
                            const signature = oldUncommittedSignature === void 0 ? useOldState ? (_b = oldState.fileInfos.get(sourceFile.resolvedPath)) == null ? void 0 : _b.signature : void 0 : oldUncommittedSignature || void 0;
                            if (referencedMap) {
                                const newReferences = getReferencedFiles(newProgram, sourceFile, newProgram.getCanonicalFileName);
                                if (newReferences) {
                                    referencedMap.set(sourceFile.resolvedPath, newReferences);
                                }
                                if (useOldState) {
                                    const oldUncommittedExportedModules = (_c = oldState.oldExportedModulesMap) == null ? void 0 : _c.get(sourceFile.resolvedPath);
                                    const exportedModules = oldUncommittedExportedModules === void 0 ? oldState.exportedModulesMap.getValues(sourceFile.resolvedPath) : oldUncommittedExportedModules || void 0;
                                    if (exportedModules) {
                                        exportedModulesMap.set(sourceFile.resolvedPath, exportedModules);
                                    }
                                }
                            }
                            fileInfos.set(sourceFile.resolvedPath, {
                                version: version2,
                                signature,
                                // No need to calculate affectsGlobalScope with --out since its not used at all
                                affectsGlobalScope: !isOutFile ? isFileAffectingGlobalScope(sourceFile) || void 0 : void 0,
                                impliedFormat: sourceFile.impliedNodeFormat
                            });
                        }
                        return {
                            fileInfos,
                            referencedMap,
                            exportedModulesMap,
                            useFileVersionAsSignature: !disableUseFileVersionAsSignature && !useOldState
                        };
                    }
                    BuilderState2.create = create;
                    function releaseCache2(state) {
                        state.allFilesExcludingDefaultLibraryFile = void 0;
                        state.allFileNames = void 0;
                    }
                    BuilderState2.releaseCache = releaseCache2;
                    function getFilesAffectedBy(state, programOfThisState, path, cancellationToken, host) {
                        var _a2, _b;
                        const result = getFilesAffectedByWithOldState(state, programOfThisState, path, cancellationToken, host);
                        (_a2 = state.oldSignatures) == null ? void 0 : _a2.clear();
                        (_b = state.oldExportedModulesMap) == null ? void 0 : _b.clear();
                        return result;
                    }
                    BuilderState2.getFilesAffectedBy = getFilesAffectedBy;
                    function getFilesAffectedByWithOldState(state, programOfThisState, path, cancellationToken, host) {
                        const sourceFile = programOfThisState.getSourceFileByPath(path);
                        if (!sourceFile) {
                            return emptyArray;
                        }
                        if (!updateShapeSignature(state, programOfThisState, sourceFile, cancellationToken, host)) {
                            return [sourceFile];
                        }
                        return (state.referencedMap ? getFilesAffectedByUpdatedShapeWhenModuleEmit : getFilesAffectedByUpdatedShapeWhenNonModuleEmit)(state, programOfThisState, sourceFile, cancellationToken, host);
                    }
                    BuilderState2.getFilesAffectedByWithOldState = getFilesAffectedByWithOldState;
                    function updateSignatureOfFile(state, signature, path) {
                        state.fileInfos.get(path).signature = signature;
                        (state.hasCalledUpdateShapeSignature || (state.hasCalledUpdateShapeSignature = /* @__PURE__ */ new Set())).add(path);
                    }
                    BuilderState2.updateSignatureOfFile = updateSignatureOfFile;
                    function computeDtsSignature(programOfThisState, sourceFile, cancellationToken, host, onNewSignature) {
                        programOfThisState.emit(sourceFile, (fileName, text, _writeByteOrderMark, _onError, sourceFiles, data) => {
                            Debug.assert(isDeclarationFileName(fileName), `File extension for signature expected to be dts: Got:: ${fileName}`);
                            onNewSignature(computeSignatureWithDiagnostics(programOfThisState, sourceFile, text, host, data), sourceFiles);
                        }, cancellationToken, 
                        /*emitOnlyDtsFiles*/
                        true, 
                        /*customTransformers*/
                        void 0, 
                        /*forceDtsEmit*/
                        true);
                    }
                    BuilderState2.computeDtsSignature = computeDtsSignature;
                    function updateShapeSignature(state, programOfThisState, sourceFile, cancellationToken, host, useFileVersionAsSignature = state.useFileVersionAsSignature) {
                        var _a2;
                        if ((_a2 = state.hasCalledUpdateShapeSignature) == null ? void 0 : _a2.has(sourceFile.resolvedPath))
                            return false;
                        const info = state.fileInfos.get(sourceFile.resolvedPath);
                        const prevSignature = info.signature;
                        let latestSignature;
                        if (!sourceFile.isDeclarationFile && !useFileVersionAsSignature) {
                            computeDtsSignature(programOfThisState, sourceFile, cancellationToken, host, (signature, sourceFiles) => {
                                latestSignature = signature;
                                if (latestSignature !== prevSignature) {
                                    updateExportedModules(state, sourceFile, sourceFiles[0].exportedModulesFromDeclarationEmit);
                                }
                            });
                        }
                        if (latestSignature === void 0) {
                            latestSignature = sourceFile.version;
                            if (state.exportedModulesMap && latestSignature !== prevSignature) {
                                (state.oldExportedModulesMap || (state.oldExportedModulesMap = /* @__PURE__ */ new Map())).set(sourceFile.resolvedPath, state.exportedModulesMap.getValues(sourceFile.resolvedPath) || false);
                                const references = state.referencedMap ? state.referencedMap.getValues(sourceFile.resolvedPath) : void 0;
                                if (references) {
                                    state.exportedModulesMap.set(sourceFile.resolvedPath, references);
                                }
                                else {
                                    state.exportedModulesMap.deleteKey(sourceFile.resolvedPath);
                                }
                            }
                        }
                        (state.oldSignatures || (state.oldSignatures = /* @__PURE__ */ new Map())).set(sourceFile.resolvedPath, prevSignature || false);
                        (state.hasCalledUpdateShapeSignature || (state.hasCalledUpdateShapeSignature = /* @__PURE__ */ new Set())).add(sourceFile.resolvedPath);
                        info.signature = latestSignature;
                        return latestSignature !== prevSignature;
                    }
                    BuilderState2.updateShapeSignature = updateShapeSignature;
                    function updateExportedModules(state, sourceFile, exportedModulesFromDeclarationEmit) {
                        if (!state.exportedModulesMap)
                            return;
                        (state.oldExportedModulesMap || (state.oldExportedModulesMap = /* @__PURE__ */ new Map())).set(sourceFile.resolvedPath, state.exportedModulesMap.getValues(sourceFile.resolvedPath) || false);
                        const exportedModules = getExportedModules(exportedModulesFromDeclarationEmit);
                        if (exportedModules) {
                            state.exportedModulesMap.set(sourceFile.resolvedPath, exportedModules);
                        }
                        else {
                            state.exportedModulesMap.deleteKey(sourceFile.resolvedPath);
                        }
                    }
                    BuilderState2.updateExportedModules = updateExportedModules;
                    function getExportedModules(exportedModulesFromDeclarationEmit) {
                        let exportedModules;
                        exportedModulesFromDeclarationEmit == null ? void 0 : exportedModulesFromDeclarationEmit.forEach((symbol) => getReferencedFilesFromImportedModuleSymbol(symbol).forEach((path) => (exportedModules != null ? exportedModules : exportedModules = /* @__PURE__ */ new Set()).add(path)));
                        return exportedModules;
                    }
                    BuilderState2.getExportedModules = getExportedModules;
                    function getAllDependencies(state, programOfThisState, sourceFile) {
                        const compilerOptions = programOfThisState.getCompilerOptions();
                        if (outFile(compilerOptions)) {
                            return getAllFileNames(state, programOfThisState);
                        }
                        if (!state.referencedMap || isFileAffectingGlobalScope(sourceFile)) {
                            return getAllFileNames(state, programOfThisState);
                        }
                        const seenMap = /* @__PURE__ */ new Set();
                        const queue = [sourceFile.resolvedPath];
                        while (queue.length) {
                            const path = queue.pop();
                            if (!seenMap.has(path)) {
                                seenMap.add(path);
                                const references = state.referencedMap.getValues(path);
                                if (references) {
                                    for (const key of references.keys()) {
                                        queue.push(key);
                                    }
                                }
                            }
                        }
                        return arrayFrom(mapDefinedIterator(seenMap.keys(), (path) => {
                            var _a2, _b;
                            return (_b = (_a2 = programOfThisState.getSourceFileByPath(path)) == null ? void 0 : _a2.fileName) != null ? _b : path;
                        }));
                    }
                    BuilderState2.getAllDependencies = getAllDependencies;
                    function getAllFileNames(state, programOfThisState) {
                        if (!state.allFileNames) {
                            const sourceFiles = programOfThisState.getSourceFiles();
                            state.allFileNames = sourceFiles === emptyArray ? emptyArray : sourceFiles.map((file) => file.fileName);
                        }
                        return state.allFileNames;
                    }
                    function getReferencedByPaths(state, referencedFilePath) {
                        const keys = state.referencedMap.getKeys(referencedFilePath);
                        return keys ? arrayFrom(keys.keys()) : [];
                    }
                    BuilderState2.getReferencedByPaths = getReferencedByPaths;
                    function containsOnlyAmbientModules(sourceFile) {
                        for (const statement of sourceFile.statements) {
                            if (!isModuleWithStringLiteralName(statement)) {
                                return false;
                            }
                        }
                        return true;
                    }
                    function containsGlobalScopeAugmentation(sourceFile) {
                        return some(sourceFile.moduleAugmentations, (augmentation) => isGlobalScopeAugmentation(augmentation.parent));
                    }
                    function isFileAffectingGlobalScope(sourceFile) {
                        return containsGlobalScopeAugmentation(sourceFile) || !isExternalOrCommonJsModule(sourceFile) && !isJsonSourceFile(sourceFile) && !containsOnlyAmbientModules(sourceFile);
                    }
                    function getAllFilesExcludingDefaultLibraryFile(state, programOfThisState, firstSourceFile) {
                        if (state.allFilesExcludingDefaultLibraryFile) {
                            return state.allFilesExcludingDefaultLibraryFile;
                        }
                        let result;
                        if (firstSourceFile)
                            addSourceFile(firstSourceFile);
                        for (const sourceFile of programOfThisState.getSourceFiles()) {
                            if (sourceFile !== firstSourceFile) {
                                addSourceFile(sourceFile);
                            }
                        }
                        state.allFilesExcludingDefaultLibraryFile = result || emptyArray;
                        return state.allFilesExcludingDefaultLibraryFile;
                        function addSourceFile(sourceFile) {
                            if (!programOfThisState.isSourceFileDefaultLibrary(sourceFile)) {
                                (result || (result = [])).push(sourceFile);
                            }
                        }
                    }
                    BuilderState2.getAllFilesExcludingDefaultLibraryFile = getAllFilesExcludingDefaultLibraryFile;
                    function getFilesAffectedByUpdatedShapeWhenNonModuleEmit(state, programOfThisState, sourceFileWithUpdatedShape) {
                        const compilerOptions = programOfThisState.getCompilerOptions();
                        if (compilerOptions && outFile(compilerOptions)) {
                            return [sourceFileWithUpdatedShape];
                        }
                        return getAllFilesExcludingDefaultLibraryFile(state, programOfThisState, sourceFileWithUpdatedShape);
                    }
                    function getFilesAffectedByUpdatedShapeWhenModuleEmit(state, programOfThisState, sourceFileWithUpdatedShape, cancellationToken, host) {
                        if (isFileAffectingGlobalScope(sourceFileWithUpdatedShape)) {
                            return getAllFilesExcludingDefaultLibraryFile(state, programOfThisState, sourceFileWithUpdatedShape);
                        }
                        const compilerOptions = programOfThisState.getCompilerOptions();
                        if (compilerOptions && (getIsolatedModules(compilerOptions) || outFile(compilerOptions))) {
                            return [sourceFileWithUpdatedShape];
                        }
                        const seenFileNamesMap = /* @__PURE__ */ new Map();
                        seenFileNamesMap.set(sourceFileWithUpdatedShape.resolvedPath, sourceFileWithUpdatedShape);
                        const queue = getReferencedByPaths(state, sourceFileWithUpdatedShape.resolvedPath);
                        while (queue.length > 0) {
                            const currentPath = queue.pop();
                            if (!seenFileNamesMap.has(currentPath)) {
                                const currentSourceFile = programOfThisState.getSourceFileByPath(currentPath);
                                seenFileNamesMap.set(currentPath, currentSourceFile);
                                if (currentSourceFile && updateShapeSignature(state, programOfThisState, currentSourceFile, cancellationToken, host)) {
                                    queue.push(...getReferencedByPaths(state, currentSourceFile.resolvedPath));
                                }
                            }
                        }
                        return arrayFrom(mapDefinedIterator(seenFileNamesMap.values(), (value) => value));
                    }
                })(BuilderState || (BuilderState = {}));
            }
        });
        // src/compiler/builder.ts
        function getBuilderFileEmit(options) {
            let result = 1 /* Js */;
            if (options.sourceMap)
                result = result | 2 /* JsMap */;
            if (options.inlineSourceMap)
                result = result | 4 /* JsInlineMap */;
            if (getEmitDeclarations(options))
                result = result | 8 /* Dts */;
            if (options.declarationMap)
                result = result | 16 /* DtsMap */;
            if (options.emitDeclarationOnly)
                result = result & 24 /* AllDts */;
            return result;
        }
        function getPendingEmitKind(optionsOrEmitKind, oldOptionsOrEmitKind) {
            const oldEmitKind = oldOptionsOrEmitKind && (isNumber(oldOptionsOrEmitKind) ? oldOptionsOrEmitKind : getBuilderFileEmit(oldOptionsOrEmitKind));
            const emitKind = isNumber(optionsOrEmitKind) ? optionsOrEmitKind : getBuilderFileEmit(optionsOrEmitKind);
            if (oldEmitKind === emitKind)
                return 0 /* None */;
            if (!oldEmitKind || !emitKind)
                return emitKind;
            const diff = oldEmitKind ^ emitKind;
            let result = 0 /* None */;
            if (diff & 7 /* AllJs */)
                result = emitKind & 7 /* AllJs */;
            if (diff & 24 /* AllDts */)
                result = result | emitKind & 24 /* AllDts */;
            return result;
        }
        function hasSameKeys(map1, map2) {
            return map1 === map2 || map1 !== void 0 && map2 !== void 0 && map1.size === map2.size && !forEachKey(map1, (key) => !map2.has(key));
        }
        function createBuilderProgramState(newProgram, oldState) {
            var _a2, _b;
            const state = BuilderState.create(newProgram, oldState, 
            /*disableUseFileVersionAsSignature*/
            false);
            state.program = newProgram;
            const compilerOptions = newProgram.getCompilerOptions();
            state.compilerOptions = compilerOptions;
            const outFilePath = outFile(compilerOptions);
            if (!outFilePath) {
                state.semanticDiagnosticsPerFile = /* @__PURE__ */ new Map();
            }
            else if (compilerOptions.composite && (oldState == null ? void 0 : oldState.outSignature) && outFilePath === outFile(oldState == null ? void 0 : oldState.compilerOptions)) {
                state.outSignature = oldState.outSignature && getEmitSignatureFromOldSignature(compilerOptions, oldState.compilerOptions, oldState.outSignature);
            }
            state.changedFilesSet = /* @__PURE__ */ new Set();
            state.latestChangedDtsFile = compilerOptions.composite ? oldState == null ? void 0 : oldState.latestChangedDtsFile : void 0;
            const useOldState = BuilderState.canReuseOldState(state.referencedMap, oldState);
            const oldCompilerOptions = useOldState ? oldState.compilerOptions : void 0;
            const canCopySemanticDiagnostics = useOldState && oldState.semanticDiagnosticsPerFile && !!state.semanticDiagnosticsPerFile && !compilerOptionsAffectSemanticDiagnostics(compilerOptions, oldCompilerOptions);
            const canCopyEmitSignatures = compilerOptions.composite && (oldState == null ? void 0 : oldState.emitSignatures) && !outFilePath && !compilerOptionsAffectDeclarationPath(compilerOptions, oldState.compilerOptions);
            if (useOldState) {
                (_a2 = oldState.changedFilesSet) == null ? void 0 : _a2.forEach((value) => state.changedFilesSet.add(value));
                if (!outFilePath && ((_b = oldState.affectedFilesPendingEmit) == null ? void 0 : _b.size)) {
                    state.affectedFilesPendingEmit = new Map(oldState.affectedFilesPendingEmit);
                    state.seenAffectedFiles = /* @__PURE__ */ new Set();
                }
                state.programEmitPending = oldState.programEmitPending;
            }
            else {
                state.buildInfoEmitPending = true;
            }
            const referencedMap = state.referencedMap;
            const oldReferencedMap = useOldState ? oldState.referencedMap : void 0;
            const copyDeclarationFileDiagnostics = canCopySemanticDiagnostics && !compilerOptions.skipLibCheck === !oldCompilerOptions.skipLibCheck;
            const copyLibFileDiagnostics = copyDeclarationFileDiagnostics && !compilerOptions.skipDefaultLibCheck === !oldCompilerOptions.skipDefaultLibCheck;
            state.fileInfos.forEach((info, sourceFilePath) => {
                var _a3;
                let oldInfo;
                let newReferences;
                if (!useOldState || // File wasn't present in old state
                    !(oldInfo = oldState.fileInfos.get(sourceFilePath)) || // versions dont match
                    oldInfo.version !== info.version || // Implied formats dont match
                    oldInfo.impliedFormat !== info.impliedFormat || // Referenced files changed
                    !hasSameKeys(newReferences = referencedMap && referencedMap.getValues(sourceFilePath), oldReferencedMap && oldReferencedMap.getValues(sourceFilePath)) || // Referenced file was deleted in the new program
                    newReferences && forEachKey(newReferences, (path) => !state.fileInfos.has(path) && oldState.fileInfos.has(path))) {
                    addFileToChangeSet(state, sourceFilePath);
                }
                else if (canCopySemanticDiagnostics) {
                    const sourceFile = newProgram.getSourceFileByPath(sourceFilePath);
                    if (sourceFile.isDeclarationFile && !copyDeclarationFileDiagnostics)
                        return;
                    if (sourceFile.hasNoDefaultLib && !copyLibFileDiagnostics)
                        return;
                    const diagnostics = oldState.semanticDiagnosticsPerFile.get(sourceFilePath);
                    if (diagnostics) {
                        state.semanticDiagnosticsPerFile.set(sourceFilePath, oldState.hasReusableDiagnostic ? convertToDiagnostics(diagnostics, newProgram) : diagnostics);
                        if (!state.semanticDiagnosticsFromOldState) {
                            state.semanticDiagnosticsFromOldState = /* @__PURE__ */ new Set();
                        }
                        state.semanticDiagnosticsFromOldState.add(sourceFilePath);
                    }
                }
                if (canCopyEmitSignatures) {
                    const oldEmitSignature = oldState.emitSignatures.get(sourceFilePath);
                    if (oldEmitSignature) {
                        ((_a3 = state.emitSignatures) != null ? _a3 : state.emitSignatures = /* @__PURE__ */ new Map()).set(sourceFilePath, getEmitSignatureFromOldSignature(compilerOptions, oldState.compilerOptions, oldEmitSignature));
                    }
                }
            });
            if (useOldState && forEachEntry(oldState.fileInfos, (info, sourceFilePath) => {
                if (state.fileInfos.has(sourceFilePath))
                    return false;
                if (outFilePath || info.affectsGlobalScope)
                    return true;
                state.buildInfoEmitPending = true;
                return false;
            })) {
                BuilderState.getAllFilesExcludingDefaultLibraryFile(state, newProgram, 
                /*firstSourceFile*/
                void 0).forEach((file) => addFileToChangeSet(state, file.resolvedPath));
            }
            else if (oldCompilerOptions) {
                const pendingEmitKind = compilerOptionsAffectEmit(compilerOptions, oldCompilerOptions) ? getBuilderFileEmit(compilerOptions) : getPendingEmitKind(compilerOptions, oldCompilerOptions);
                if (pendingEmitKind !== 0 /* None */) {
                    if (!outFilePath) {
                        newProgram.getSourceFiles().forEach((f) => {
                            if (!state.changedFilesSet.has(f.resolvedPath)) {
                                addToAffectedFilesPendingEmit(state, f.resolvedPath, pendingEmitKind);
                            }
                        });
                        Debug.assert(!state.seenAffectedFiles || !state.seenAffectedFiles.size);
                        state.seenAffectedFiles = state.seenAffectedFiles || /* @__PURE__ */ new Set();
                        state.buildInfoEmitPending = true;
                    }
                    else {
                        state.programEmitPending = state.programEmitPending ? state.programEmitPending | pendingEmitKind : pendingEmitKind;
                    }
                }
            }
            if (outFilePath && !state.changedFilesSet.size) {
                if (useOldState)
                    state.bundle = oldState.bundle;
                if (some(newProgram.getProjectReferences(), (ref) => !!ref.prepend))
                    state.programEmitPending = getBuilderFileEmit(compilerOptions);
            }
            return state;
        }
        function addFileToChangeSet(state, path) {
            state.changedFilesSet.add(path);
            state.buildInfoEmitPending = true;
            state.programEmitPending = void 0;
        }
        function getEmitSignatureFromOldSignature(options, oldOptions, oldEmitSignature) {
            return !!options.declarationMap === !!oldOptions.declarationMap ? (
            // Use same format of signature
            oldEmitSignature) : (
            // Convert to different format
            isString(oldEmitSignature) ? [oldEmitSignature] : oldEmitSignature[0]);
        }
        function convertToDiagnostics(diagnostics, newProgram) {
            if (!diagnostics.length)
                return emptyArray;
            let buildInfoDirectory;
            return diagnostics.map((diagnostic) => {
                const result = convertToDiagnosticRelatedInformation(diagnostic, newProgram, toPath3);
                result.reportsUnnecessary = diagnostic.reportsUnnecessary;
                result.reportsDeprecated = diagnostic.reportDeprecated;
                result.source = diagnostic.source;
                result.skippedOn = diagnostic.skippedOn;
                const { relatedInformation } = diagnostic;
                result.relatedInformation = relatedInformation ? relatedInformation.length ? relatedInformation.map((r) => convertToDiagnosticRelatedInformation(r, newProgram, toPath3)) : [] : void 0;
                return result;
            });
            function toPath3(path) {
                buildInfoDirectory != null ? buildInfoDirectory : buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(getTsBuildInfoEmitOutputFilePath(newProgram.getCompilerOptions()), newProgram.getCurrentDirectory()));
                return toPath(path, buildInfoDirectory, newProgram.getCanonicalFileName);
            }
        }
        function convertToDiagnosticRelatedInformation(diagnostic, newProgram, toPath3) {
            const { file } = diagnostic;
            return {
                ...diagnostic,
                file: file ? newProgram.getSourceFileByPath(toPath3(file)) : void 0
            };
        }
        function releaseCache(state) {
            BuilderState.releaseCache(state);
            state.program = void 0;
        }
        function backupBuilderProgramEmitState(state) {
            const outFilePath = outFile(state.compilerOptions);
            Debug.assert(!state.changedFilesSet.size || outFilePath);
            return {
                affectedFilesPendingEmit: state.affectedFilesPendingEmit && new Map(state.affectedFilesPendingEmit),
                seenEmittedFiles: state.seenEmittedFiles && new Map(state.seenEmittedFiles),
                programEmitPending: state.programEmitPending,
                emitSignatures: state.emitSignatures && new Map(state.emitSignatures),
                outSignature: state.outSignature,
                latestChangedDtsFile: state.latestChangedDtsFile,
                hasChangedEmitSignature: state.hasChangedEmitSignature,
                changedFilesSet: outFilePath ? new Set(state.changedFilesSet) : void 0
            };
        }
        function restoreBuilderProgramEmitState(state, savedEmitState) {
            state.affectedFilesPendingEmit = savedEmitState.affectedFilesPendingEmit;
            state.seenEmittedFiles = savedEmitState.seenEmittedFiles;
            state.programEmitPending = savedEmitState.programEmitPending;
            state.emitSignatures = savedEmitState.emitSignatures;
            state.outSignature = savedEmitState.outSignature;
            state.latestChangedDtsFile = savedEmitState.latestChangedDtsFile;
            state.hasChangedEmitSignature = savedEmitState.hasChangedEmitSignature;
            if (savedEmitState.changedFilesSet)
                state.changedFilesSet = savedEmitState.changedFilesSet;
        }
        function assertSourceFileOkWithoutNextAffectedCall(state, sourceFile) {
            Debug.assert(!sourceFile || !state.affectedFiles || state.affectedFiles[state.affectedFilesIndex - 1] !== sourceFile || !state.semanticDiagnosticsPerFile.has(sourceFile.resolvedPath));
        }
        function getNextAffectedFile(state, cancellationToken, host) {
            var _a2, _b;
            while (true) {
                const { affectedFiles } = state;
                if (affectedFiles) {
                    const seenAffectedFiles = state.seenAffectedFiles;
                    let affectedFilesIndex = state.affectedFilesIndex;
                    while (affectedFilesIndex < affectedFiles.length) {
                        const affectedFile = affectedFiles[affectedFilesIndex];
                        if (!seenAffectedFiles.has(affectedFile.resolvedPath)) {
                            state.affectedFilesIndex = affectedFilesIndex;
                            addToAffectedFilesPendingEmit(state, affectedFile.resolvedPath, getBuilderFileEmit(state.compilerOptions));
                            handleDtsMayChangeOfAffectedFile(state, affectedFile, cancellationToken, host);
                            return affectedFile;
                        }
                        affectedFilesIndex++;
                    }
                    state.changedFilesSet.delete(state.currentChangedFilePath);
                    state.currentChangedFilePath = void 0;
                    (_a2 = state.oldSignatures) == null ? void 0 : _a2.clear();
                    (_b = state.oldExportedModulesMap) == null ? void 0 : _b.clear();
                    state.affectedFiles = void 0;
                }
                const nextKey = state.changedFilesSet.keys().next();
                if (nextKey.done) {
                    return void 0;
                }
                const program = Debug.checkDefined(state.program);
                const compilerOptions = program.getCompilerOptions();
                if (outFile(compilerOptions)) {
                    Debug.assert(!state.semanticDiagnosticsPerFile);
                    return program;
                }
                state.affectedFiles = BuilderState.getFilesAffectedByWithOldState(state, program, nextKey.value, cancellationToken, host);
                state.currentChangedFilePath = nextKey.value;
                state.affectedFilesIndex = 0;
                if (!state.seenAffectedFiles)
                    state.seenAffectedFiles = /* @__PURE__ */ new Set();
            }
        }
        function clearAffectedFilesPendingEmit(state, emitOnlyDtsFiles) {
            var _a2;
            if (!((_a2 = state.affectedFilesPendingEmit) == null ? void 0 : _a2.size))
                return;
            if (!emitOnlyDtsFiles)
                return state.affectedFilesPendingEmit = void 0;
            state.affectedFilesPendingEmit.forEach((emitKind, path) => {
                const pending = emitKind & 7 /* AllJs */;
                if (!pending)
                    state.affectedFilesPendingEmit.delete(path);
                else
                    state.affectedFilesPendingEmit.set(path, pending);
            });
        }
        function getNextAffectedFilePendingEmit(state, emitOnlyDtsFiles) {
            var _a2;
            if (!((_a2 = state.affectedFilesPendingEmit) == null ? void 0 : _a2.size))
                return void 0;
            return forEachEntry(state.affectedFilesPendingEmit, (emitKind, path) => {
                var _a3;
                const affectedFile = state.program.getSourceFileByPath(path);
                if (!affectedFile || !sourceFileMayBeEmitted(affectedFile, state.program)) {
                    state.affectedFilesPendingEmit.delete(path);
                    return void 0;
                }
                const seenKind = (_a3 = state.seenEmittedFiles) == null ? void 0 : _a3.get(affectedFile.resolvedPath);
                let pendingKind = getPendingEmitKind(emitKind, seenKind);
                if (emitOnlyDtsFiles)
                    pendingKind = pendingKind & 24 /* AllDts */;
                if (pendingKind)
                    return { affectedFile, emitKind: pendingKind };
            });
        }
        function removeDiagnosticsOfLibraryFiles(state) {
            if (!state.cleanedDiagnosticsOfLibFiles) {
                state.cleanedDiagnosticsOfLibFiles = true;
                const program = Debug.checkDefined(state.program);
                const options = program.getCompilerOptions();
                forEach(program.getSourceFiles(), (f) => program.isSourceFileDefaultLibrary(f) && !skipTypeChecking(f, options, program) && removeSemanticDiagnosticsOf(state, f.resolvedPath));
            }
        }
        function handleDtsMayChangeOfAffectedFile(state, affectedFile, cancellationToken, host) {
            removeSemanticDiagnosticsOf(state, affectedFile.resolvedPath);
            if (state.allFilesExcludingDefaultLibraryFile === state.affectedFiles) {
                removeDiagnosticsOfLibraryFiles(state);
                BuilderState.updateShapeSignature(state, Debug.checkDefined(state.program), affectedFile, cancellationToken, host);
                return;
            }
            if (state.compilerOptions.assumeChangesOnlyAffectDirectDependencies)
                return;
            handleDtsMayChangeOfReferencingExportOfAffectedFile(state, affectedFile, cancellationToken, host);
        }
        function handleDtsMayChangeOf(state, path, cancellationToken, host) {
            removeSemanticDiagnosticsOf(state, path);
            if (!state.changedFilesSet.has(path)) {
                const program = Debug.checkDefined(state.program);
                const sourceFile = program.getSourceFileByPath(path);
                if (sourceFile) {
                    BuilderState.updateShapeSignature(state, program, sourceFile, cancellationToken, host, 
                    /*useFileVersionAsSignature*/
                    true);
                    if (getEmitDeclarations(state.compilerOptions)) {
                        addToAffectedFilesPendingEmit(state, path, state.compilerOptions.declarationMap ? 24 /* AllDts */ : 8 /* Dts */);
                    }
                }
            }
        }
        function removeSemanticDiagnosticsOf(state, path) {
            if (!state.semanticDiagnosticsFromOldState) {
                return true;
            }
            state.semanticDiagnosticsFromOldState.delete(path);
            state.semanticDiagnosticsPerFile.delete(path);
            return !state.semanticDiagnosticsFromOldState.size;
        }
        function isChangedSignature(state, path) {
            const oldSignature = Debug.checkDefined(state.oldSignatures).get(path) || void 0;
            const newSignature = Debug.checkDefined(state.fileInfos.get(path)).signature;
            return newSignature !== oldSignature;
        }
        function handleDtsMayChangeOfGlobalScope(state, filePath, cancellationToken, host) {
            var _a2;
            if (!((_a2 = state.fileInfos.get(filePath)) == null ? void 0 : _a2.affectsGlobalScope))
                return false;
            BuilderState.getAllFilesExcludingDefaultLibraryFile(state, state.program, 
            /*firstSourceFile*/
            void 0).forEach((file) => handleDtsMayChangeOf(state, file.resolvedPath, cancellationToken, host));
            removeDiagnosticsOfLibraryFiles(state);
            return true;
        }
        function handleDtsMayChangeOfReferencingExportOfAffectedFile(state, affectedFile, cancellationToken, host) {
            var _a2;
            if (!state.exportedModulesMap || !state.changedFilesSet.has(affectedFile.resolvedPath))
                return;
            if (!isChangedSignature(state, affectedFile.resolvedPath))
                return;
            if (getIsolatedModules(state.compilerOptions)) {
                const seenFileNamesMap = /* @__PURE__ */ new Map();
                seenFileNamesMap.set(affectedFile.resolvedPath, true);
                const queue = BuilderState.getReferencedByPaths(state, affectedFile.resolvedPath);
                while (queue.length > 0) {
                    const currentPath = queue.pop();
                    if (!seenFileNamesMap.has(currentPath)) {
                        seenFileNamesMap.set(currentPath, true);
                        if (handleDtsMayChangeOfGlobalScope(state, currentPath, cancellationToken, host))
                            return;
                        handleDtsMayChangeOf(state, currentPath, cancellationToken, host);
                        if (isChangedSignature(state, currentPath)) {
                            const currentSourceFile = Debug.checkDefined(state.program).getSourceFileByPath(currentPath);
                            queue.push(...BuilderState.getReferencedByPaths(state, currentSourceFile.resolvedPath));
                        }
                    }
                }
            }
            const seenFileAndExportsOfFile = /* @__PURE__ */ new Set();
            (_a2 = state.exportedModulesMap.getKeys(affectedFile.resolvedPath)) == null ? void 0 : _a2.forEach((exportedFromPath) => {
                if (handleDtsMayChangeOfGlobalScope(state, exportedFromPath, cancellationToken, host))
                    return true;
                const references = state.referencedMap.getKeys(exportedFromPath);
                return references && forEachKey(references, (filePath) => handleDtsMayChangeOfFileAndExportsOfFile(state, filePath, seenFileAndExportsOfFile, cancellationToken, host));
            });
        }
        function handleDtsMayChangeOfFileAndExportsOfFile(state, filePath, seenFileAndExportsOfFile, cancellationToken, host) {
            var _a2, _b;
            if (!tryAddToSet(seenFileAndExportsOfFile, filePath))
                return void 0;
            if (handleDtsMayChangeOfGlobalScope(state, filePath, cancellationToken, host))
                return true;
            handleDtsMayChangeOf(state, filePath, cancellationToken, host);
            (_a2 = state.exportedModulesMap.getKeys(filePath)) == null ? void 0 : _a2.forEach((exportedFromPath) => handleDtsMayChangeOfFileAndExportsOfFile(state, exportedFromPath, seenFileAndExportsOfFile, cancellationToken, host));
            (_b = state.referencedMap.getKeys(filePath)) == null ? void 0 : _b.forEach((referencingFilePath) => !seenFileAndExportsOfFile.has(referencingFilePath) && // Not already removed diagnostic file
                handleDtsMayChangeOf(
                // Dont add to seen since this is not yet done with the export removal
                state, referencingFilePath, cancellationToken, host));
            return void 0;
        }
        function getSemanticDiagnosticsOfFile(state, sourceFile, cancellationToken) {
            return concatenate(getBinderAndCheckerDiagnosticsOfFile(state, sourceFile, cancellationToken), Debug.checkDefined(state.program).getProgramDiagnostics(sourceFile));
        }
        function getBinderAndCheckerDiagnosticsOfFile(state, sourceFile, cancellationToken) {
            const path = sourceFile.resolvedPath;
            if (state.semanticDiagnosticsPerFile) {
                const cachedDiagnostics = state.semanticDiagnosticsPerFile.get(path);
                if (cachedDiagnostics) {
                    return filterSemanticDiagnostics(cachedDiagnostics, state.compilerOptions);
                }
            }
            const diagnostics = Debug.checkDefined(state.program).getBindAndCheckDiagnostics(sourceFile, cancellationToken);
            if (state.semanticDiagnosticsPerFile) {
                state.semanticDiagnosticsPerFile.set(path, diagnostics);
            }
            return filterSemanticDiagnostics(diagnostics, state.compilerOptions);
        }
        function isProgramBundleEmitBuildInfo(info) {
            return !!outFile(info.options || {});
        }
        function getBuildInfo2(state, bundle) {
            var _a2, _b, _c;
            const currentDirectory = Debug.checkDefined(state.program).getCurrentDirectory();
            const buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(getTsBuildInfoEmitOutputFilePath(state.compilerOptions), currentDirectory));
            const latestChangedDtsFile = state.latestChangedDtsFile ? relativeToBuildInfoEnsuringAbsolutePath(state.latestChangedDtsFile) : void 0;
            const fileNames = [];
            const fileNameToFileId = /* @__PURE__ */ new Map();
            const root = [];
            if (outFile(state.compilerOptions)) {
                const fileInfos2 = arrayFrom(state.fileInfos.entries(), ([key, value]) => {
                    const fileId = toFileId(key);
                    tryAddRoot(key, fileId);
                    return value.impliedFormat ? { version: value.version, impliedFormat: value.impliedFormat, signature: void 0, affectsGlobalScope: void 0 } : value.version;
                });
                const program2 = {
                    fileNames,
                    fileInfos: fileInfos2,
                    root,
                    options: convertToProgramBuildInfoCompilerOptions(state.compilerOptions),
                    outSignature: state.outSignature,
                    latestChangedDtsFile,
                    pendingEmit: !state.programEmitPending ? void 0 : (
                    // Pending is undefined or None is encoded as undefined
                    state.programEmitPending === getBuilderFileEmit(state.compilerOptions) ? false : (
                    // Pending emit is same as deteremined by compilerOptions
                    state.programEmitPending))
                    // Actual value
                };
                const { js, dts, commonSourceDirectory, sourceFiles } = bundle;
                state.bundle = bundle = {
                    commonSourceDirectory,
                    sourceFiles,
                    js: js || (!state.compilerOptions.emitDeclarationOnly ? (_a2 = state.bundle) == null ? void 0 : _a2.js : void 0),
                    dts: dts || (getEmitDeclarations(state.compilerOptions) ? (_b = state.bundle) == null ? void 0 : _b.dts : void 0)
                };
                return createBuildInfo(program2, bundle);
            }
            let fileIdsList;
            let fileNamesToFileIdListId;
            let emitSignatures;
            const fileInfos = arrayFrom(state.fileInfos.entries(), ([key, value]) => {
                var _a3, _b2;
                const fileId = toFileId(key);
                tryAddRoot(key, fileId);
                Debug.assert(fileNames[fileId - 1] === relativeToBuildInfo(key));
                const oldSignature = (_a3 = state.oldSignatures) == null ? void 0 : _a3.get(key);
                const actualSignature = oldSignature !== void 0 ? oldSignature || void 0 : value.signature;
                if (state.compilerOptions.composite) {
                    const file = state.program.getSourceFileByPath(key);
                    if (!isJsonSourceFile(file) && sourceFileMayBeEmitted(file, state.program)) {
                        const emitSignature = (_b2 = state.emitSignatures) == null ? void 0 : _b2.get(key);
                        if (emitSignature !== actualSignature) {
                            (emitSignatures || (emitSignatures = [])).push(emitSignature === void 0 ? fileId : (
                            // There is no emit, encode as false
                            // fileId, signature: emptyArray if signature only differs in dtsMap option than our own compilerOptions otherwise EmitSignature
                            [fileId, !isString(emitSignature) && emitSignature[0] === actualSignature ? emptyArray : emitSignature]));
                        }
                    }
                }
                return value.version === actualSignature ? value.affectsGlobalScope || value.impliedFormat ? (
                // If file version is same as signature, dont serialize signature
                { version: value.version, signature: void 0, affectsGlobalScope: value.affectsGlobalScope, impliedFormat: value.impliedFormat }) : (
                // If file info only contains version and signature and both are same we can just write string
                value.version) : actualSignature !== void 0 ? (
                // If signature is not same as version, encode signature in the fileInfo
                oldSignature === void 0 ? (
                // If we havent computed signature, use fileInfo as is
                value) : (
                // Serialize fileInfo with new updated signature
                { version: value.version, signature: actualSignature, affectsGlobalScope: value.affectsGlobalScope, impliedFormat: value.impliedFormat })) : (
                // Signature of the FileInfo is undefined, serialize it as false
                { version: value.version, signature: false, affectsGlobalScope: value.affectsGlobalScope, impliedFormat: value.impliedFormat });
            });
            let referencedMap;
            if (state.referencedMap) {
                referencedMap = arrayFrom(state.referencedMap.keys()).sort(compareStringsCaseSensitive).map((key) => [
                    toFileId(key),
                    toFileIdListId(state.referencedMap.getValues(key))
                ]);
            }
            let exportedModulesMap;
            if (state.exportedModulesMap) {
                exportedModulesMap = mapDefined(arrayFrom(state.exportedModulesMap.keys()).sort(compareStringsCaseSensitive), (key) => {
                    var _a3;
                    const oldValue = (_a3 = state.oldExportedModulesMap) == null ? void 0 : _a3.get(key);
                    if (oldValue === void 0)
                        return [toFileId(key), toFileIdListId(state.exportedModulesMap.getValues(key))];
                    if (oldValue)
                        return [toFileId(key), toFileIdListId(oldValue)];
                    return void 0;
                });
            }
            let semanticDiagnosticsPerFile;
            if (state.semanticDiagnosticsPerFile) {
                for (const key of arrayFrom(state.semanticDiagnosticsPerFile.keys()).sort(compareStringsCaseSensitive)) {
                    const value = state.semanticDiagnosticsPerFile.get(key);
                    (semanticDiagnosticsPerFile || (semanticDiagnosticsPerFile = [])).push(value.length ? [
                        toFileId(key),
                        convertToReusableDiagnostics(value, relativeToBuildInfo)
                    ] : toFileId(key));
                }
            }
            let affectedFilesPendingEmit;
            if ((_c = state.affectedFilesPendingEmit) == null ? void 0 : _c.size) {
                const fullEmitForOptions = getBuilderFileEmit(state.compilerOptions);
                const seenFiles = /* @__PURE__ */ new Set();
                for (const path of arrayFrom(state.affectedFilesPendingEmit.keys()).sort(compareStringsCaseSensitive)) {
                    if (tryAddToSet(seenFiles, path)) {
                        const file = state.program.getSourceFileByPath(path);
                        if (!file || !sourceFileMayBeEmitted(file, state.program))
                            continue;
                        const fileId = toFileId(path), pendingEmit = state.affectedFilesPendingEmit.get(path);
                        (affectedFilesPendingEmit || (affectedFilesPendingEmit = [])).push(pendingEmit === fullEmitForOptions ? fileId : (
                        // Pending full emit per options
                        pendingEmit === 8 /* Dts */ ? [fileId] : (
                        // Pending on Dts only
                        [fileId, pendingEmit]))
                        // Anything else
                        );
                    }
                }
            }
            let changeFileSet;
            if (state.changedFilesSet.size) {
                for (const path of arrayFrom(state.changedFilesSet.keys()).sort(compareStringsCaseSensitive)) {
                    (changeFileSet || (changeFileSet = [])).push(toFileId(path));
                }
            }
            const program = {
                fileNames,
                fileInfos,
                root,
                options: convertToProgramBuildInfoCompilerOptions(state.compilerOptions),
                fileIdsList,
                referencedMap,
                exportedModulesMap,
                semanticDiagnosticsPerFile,
                affectedFilesPendingEmit,
                changeFileSet,
                emitSignatures,
                latestChangedDtsFile
            };
            return createBuildInfo(program, bundle);
            function relativeToBuildInfoEnsuringAbsolutePath(path) {
                return relativeToBuildInfo(getNormalizedAbsolutePath(path, currentDirectory));
            }
            function relativeToBuildInfo(path) {
                return ensurePathIsNonModuleName(getRelativePathFromDirectory(buildInfoDirectory, path, state.program.getCanonicalFileName));
            }
            function toFileId(path) {
                let fileId = fileNameToFileId.get(path);
                if (fileId === void 0) {
                    fileNames.push(relativeToBuildInfo(path));
                    fileNameToFileId.set(path, fileId = fileNames.length);
                }
                return fileId;
            }
            function toFileIdListId(set) {
                const fileIds = arrayFrom(set.keys(), toFileId).sort(compareValues);
                const key = fileIds.join();
                let fileIdListId = fileNamesToFileIdListId == null ? void 0 : fileNamesToFileIdListId.get(key);
                if (fileIdListId === void 0) {
                    (fileIdsList || (fileIdsList = [])).push(fileIds);
                    (fileNamesToFileIdListId || (fileNamesToFileIdListId = /* @__PURE__ */ new Map())).set(key, fileIdListId = fileIdsList.length);
                }
                return fileIdListId;
            }
            function tryAddRoot(path, fileId) {
                const file = state.program.getSourceFile(path);
                if (!state.program.getFileIncludeReasons().get(file.path).some((r) => r.kind === 0 /* RootFile */))
                    return;
                if (!root.length)
                    return root.push(fileId);
                const last2 = root[root.length - 1];
                const isLastStartEnd = isArray(last2);
                if (isLastStartEnd && last2[1] === fileId - 1)
                    return last2[1] = fileId;
                if (isLastStartEnd || root.length === 1 || last2 !== fileId - 1)
                    return root.push(fileId);
                const lastButOne = root[root.length - 2];
                if (!isNumber(lastButOne) || lastButOne !== last2 - 1)
                    return root.push(fileId);
                root[root.length - 2] = [lastButOne, fileId];
                return root.length = root.length - 1;
            }
            function convertToProgramBuildInfoCompilerOptions(options) {
                let result;
                const { optionsNameMap } = getOptionsNameMap();
                for (const name of getOwnKeys(options).sort(compareStringsCaseSensitive)) {
                    const optionInfo = optionsNameMap.get(name.toLowerCase());
                    if (optionInfo == null ? void 0 : optionInfo.affectsBuildInfo) {
                        (result || (result = {}))[name] = convertToReusableCompilerOptionValue(optionInfo, options[name], relativeToBuildInfoEnsuringAbsolutePath);
                    }
                }
                return result;
            }
        }
        function convertToReusableCompilerOptionValue(option, value, relativeToBuildInfo) {
            if (option) {
                Debug.assert(option.type !== "listOrElement");
                if (option.type === "list") {
                    const values = value;
                    if (option.element.isFilePath && values.length) {
                        return values.map(relativeToBuildInfo);
                    }
                }
                else if (option.isFilePath) {
                    return relativeToBuildInfo(value);
                }
            }
            return value;
        }
        function convertToReusableDiagnostics(diagnostics, relativeToBuildInfo) {
            Debug.assert(!!diagnostics.length);
            return diagnostics.map((diagnostic) => {
                const result = convertToReusableDiagnosticRelatedInformation(diagnostic, relativeToBuildInfo);
                result.reportsUnnecessary = diagnostic.reportsUnnecessary;
                result.reportDeprecated = diagnostic.reportsDeprecated;
                result.source = diagnostic.source;
                result.skippedOn = diagnostic.skippedOn;
                const { relatedInformation } = diagnostic;
                result.relatedInformation = relatedInformation ? relatedInformation.length ? relatedInformation.map((r) => convertToReusableDiagnosticRelatedInformation(r, relativeToBuildInfo)) : [] : void 0;
                return result;
            });
        }
        function convertToReusableDiagnosticRelatedInformation(diagnostic, relativeToBuildInfo) {
            const { file } = diagnostic;
            return {
                ...diagnostic,
                file: file ? relativeToBuildInfo(file.resolvedPath) : void 0
            };
        }
        function getBuilderCreationParameters(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences) {
            let host;
            let newProgram;
            let oldProgram;
            if (newProgramOrRootNames === void 0) {
                Debug.assert(hostOrOptions === void 0);
                host = oldProgramOrHost;
                oldProgram = configFileParsingDiagnosticsOrOldProgram;
                Debug.assert(!!oldProgram);
                newProgram = oldProgram.getProgram();
            }
            else if (isArray(newProgramOrRootNames)) {
                oldProgram = configFileParsingDiagnosticsOrOldProgram;
                newProgram = createProgram({
                    rootNames: newProgramOrRootNames,
                    options: hostOrOptions,
                    host: oldProgramOrHost,
                    oldProgram: oldProgram && oldProgram.getProgramOrUndefined(),
                    configFileParsingDiagnostics,
                    projectReferences
                });
                host = oldProgramOrHost;
            }
            else {
                newProgram = newProgramOrRootNames;
                host = hostOrOptions;
                oldProgram = oldProgramOrHost;
                configFileParsingDiagnostics = configFileParsingDiagnosticsOrOldProgram;
            }
            return { host, newProgram, oldProgram, configFileParsingDiagnostics: configFileParsingDiagnostics || emptyArray };
        }
        function getTextHandlingSourceMapForSignature(text, data) {
            return (data == null ? void 0 : data.sourceMapUrlPos) !== void 0 ? text.substring(0, data.sourceMapUrlPos) : text;
        }
        function computeSignatureWithDiagnostics(program, sourceFile, text, host, data) {
            var _a2, _b;
            text = getTextHandlingSourceMapForSignature(text, data);
            let sourceFileDirectory;
            if ((_a2 = data == null ? void 0 : data.diagnostics) == null ? void 0 : _a2.length) {
                text += data.diagnostics.map((diagnostic) => `${locationInfo(diagnostic)}${DiagnosticCategory[diagnostic.category]}${diagnostic.code}: ${flattenDiagnosticMessageText2(diagnostic.messageText)}`).join("\n");
            }
            return ((_b = host.createHash) != null ? _b : generateDjb2Hash)(text);
            function flattenDiagnosticMessageText2(diagnostic) {
                return isString(diagnostic) ? diagnostic : diagnostic === void 0 ? "" : !diagnostic.next ? diagnostic.messageText : diagnostic.messageText + diagnostic.next.map(flattenDiagnosticMessageText2).join("\n");
            }
            function locationInfo(diagnostic) {
                if (diagnostic.file.resolvedPath === sourceFile.resolvedPath)
                    return `(${diagnostic.start},${diagnostic.length})`;
                if (sourceFileDirectory === void 0)
                    sourceFileDirectory = getDirectoryPath(sourceFile.resolvedPath);
                return `${ensurePathIsNonModuleName(getRelativePathFromDirectory(sourceFileDirectory, diagnostic.file.resolvedPath, program.getCanonicalFileName))}(${diagnostic.start},${diagnostic.length})`;
            }
        }
        function computeSignature(text, host, data) {
            var _a2;
            return ((_a2 = host.createHash) != null ? _a2 : generateDjb2Hash)(getTextHandlingSourceMapForSignature(text, data));
        }
        function createBuilderProgram(kind, { newProgram, host, oldProgram, configFileParsingDiagnostics }) {
            let oldState = oldProgram && oldProgram.getState();
            if (oldState && newProgram === oldState.program && configFileParsingDiagnostics === newProgram.getConfigFileParsingDiagnostics()) {
                newProgram = void 0;
                oldState = void 0;
                return oldProgram;
            }
            const state = createBuilderProgramState(newProgram, oldState);
            newProgram.getBuildInfo = (bundle) => getBuildInfo2(state, bundle);
            newProgram = void 0;
            oldProgram = void 0;
            oldState = void 0;
            const getState = () => state;
            const builderProgram = createRedirectedBuilderProgram(getState, configFileParsingDiagnostics);
            builderProgram.getState = getState;
            builderProgram.saveEmitState = () => backupBuilderProgramEmitState(state);
            builderProgram.restoreEmitState = (saved) => restoreBuilderProgramEmitState(state, saved);
            builderProgram.hasChangedEmitSignature = () => !!state.hasChangedEmitSignature;
            builderProgram.getAllDependencies = (sourceFile) => BuilderState.getAllDependencies(state, Debug.checkDefined(state.program), sourceFile);
            builderProgram.getSemanticDiagnostics = getSemanticDiagnostics;
            builderProgram.emit = emit;
            builderProgram.releaseProgram = () => releaseCache(state);
            if (kind === 0 /* SemanticDiagnosticsBuilderProgram */) {
                builderProgram.getSemanticDiagnosticsOfNextAffectedFile = getSemanticDiagnosticsOfNextAffectedFile;
            }
            else if (kind === 1 /* EmitAndSemanticDiagnosticsBuilderProgram */) {
                builderProgram.getSemanticDiagnosticsOfNextAffectedFile = getSemanticDiagnosticsOfNextAffectedFile;
                builderProgram.emitNextAffectedFile = emitNextAffectedFile;
                builderProgram.emitBuildInfo = emitBuildInfo;
            }
            else {
                notImplemented();
            }
            return builderProgram;
            function emitBuildInfo(writeFile2, cancellationToken) {
                if (state.buildInfoEmitPending) {
                    const result = Debug.checkDefined(state.program).emitBuildInfo(writeFile2 || maybeBind(host, host.writeFile), cancellationToken);
                    state.buildInfoEmitPending = false;
                    return result;
                }
                return emitSkippedWithNoDiagnostics;
            }
            function emitNextAffectedFile(writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) {
                var _a2, _b, _c, _d, _e;
                let affected = getNextAffectedFile(state, cancellationToken, host);
                const programEmitKind = getBuilderFileEmit(state.compilerOptions);
                let emitKind = emitOnlyDtsFiles ? programEmitKind & 24 /* AllDts */ : programEmitKind;
                if (!affected) {
                    if (!outFile(state.compilerOptions)) {
                        const pendingAffectedFile = getNextAffectedFilePendingEmit(state, emitOnlyDtsFiles);
                        if (!pendingAffectedFile) {
                            if (!state.buildInfoEmitPending)
                                return void 0;
                            const affected2 = state.program;
                            const result2 = affected2.emitBuildInfo(writeFile2 || maybeBind(host, host.writeFile), cancellationToken);
                            state.buildInfoEmitPending = false;
                            return { result: result2, affected: affected2 };
                        }
                        ({ affectedFile: affected, emitKind } = pendingAffectedFile);
                    }
                    else {
                        if (!state.programEmitPending)
                            return void 0;
                        emitKind = state.programEmitPending;
                        if (emitOnlyDtsFiles)
                            emitKind = emitKind & 24 /* AllDts */;
                        if (!emitKind)
                            return void 0;
                        affected = state.program;
                    }
                }
                let emitOnly;
                if (emitKind & 7 /* AllJs */)
                    emitOnly = 0 /* Js */;
                if (emitKind & 24 /* AllDts */)
                    emitOnly = emitOnly === void 0 ? 1 /* Dts */ : void 0;
                if (affected === state.program) {
                    state.programEmitPending = state.changedFilesSet.size ? getPendingEmitKind(programEmitKind, emitKind) : state.programEmitPending ? getPendingEmitKind(state.programEmitPending, emitKind) : void 0;
                }
                const result = state.program.emit(affected === state.program ? void 0 : affected, getWriteFileCallback(writeFile2, customTransformers), cancellationToken, emitOnly, customTransformers);
                if (affected !== state.program) {
                    const affectedSourceFile = affected;
                    state.seenAffectedFiles.add(affectedSourceFile.resolvedPath);
                    if (state.affectedFilesIndex !== void 0)
                        state.affectedFilesIndex++;
                    state.buildInfoEmitPending = true;
                    const existing = ((_a2 = state.seenEmittedFiles) == null ? void 0 : _a2.get(affectedSourceFile.resolvedPath)) || 0 /* None */;
                    ((_b = state.seenEmittedFiles) != null ? _b : state.seenEmittedFiles = /* @__PURE__ */ new Map()).set(affectedSourceFile.resolvedPath, emitKind | existing);
                    const existingPending = ((_c = state.affectedFilesPendingEmit) == null ? void 0 : _c.get(affectedSourceFile.resolvedPath)) || programEmitKind;
                    const pendingKind = getPendingEmitKind(existingPending, emitKind | existing);
                    if (pendingKind)
                        ((_d = state.affectedFilesPendingEmit) != null ? _d : state.affectedFilesPendingEmit = /* @__PURE__ */ new Map()).set(affectedSourceFile.resolvedPath, pendingKind);
                    else
                        (_e = state.affectedFilesPendingEmit) == null ? void 0 : _e.delete(affectedSourceFile.resolvedPath);
                }
                else {
                    state.changedFilesSet.clear();
                }
                return { result, affected };
            }
            function getWriteFileCallback(writeFile2, customTransformers) {
                if (!getEmitDeclarations(state.compilerOptions))
                    return writeFile2 || maybeBind(host, host.writeFile);
                return (fileName, text, writeByteOrderMark, onError, sourceFiles, data) => {
                    var _a2, _b, _c, _d, _e, _f, _g;
                    if (isDeclarationFileName(fileName)) {
                        if (!outFile(state.compilerOptions)) {
                            Debug.assert((sourceFiles == null ? void 0 : sourceFiles.length) === 1);
                            let emitSignature;
                            if (!customTransformers) {
                                const file = sourceFiles[0];
                                const info = state.fileInfos.get(file.resolvedPath);
                                if (info.signature === file.version) {
                                    const signature = computeSignatureWithDiagnostics(state.program, file, text, host, data);
                                    if (!((_a2 = data == null ? void 0 : data.diagnostics) == null ? void 0 : _a2.length))
                                        emitSignature = signature;
                                    if (signature !== file.version) {
                                        if (host.storeFilesChangingSignatureDuringEmit)
                                            ((_b = state.filesChangingSignature) != null ? _b : state.filesChangingSignature = /* @__PURE__ */ new Set()).add(file.resolvedPath);
                                        if (state.exportedModulesMap)
                                            BuilderState.updateExportedModules(state, file, file.exportedModulesFromDeclarationEmit);
                                        if (state.affectedFiles) {
                                            const existing = (_c = state.oldSignatures) == null ? void 0 : _c.get(file.resolvedPath);
                                            if (existing === void 0)
                                                ((_d = state.oldSignatures) != null ? _d : state.oldSignatures = /* @__PURE__ */ new Map()).set(file.resolvedPath, info.signature || false);
                                            info.signature = signature;
                                        }
                                        else {
                                            info.signature = signature;
                                            (_e = state.oldExportedModulesMap) == null ? void 0 : _e.clear();
                                        }
                                    }
                                }
                            }
                            if (state.compilerOptions.composite) {
                                const filePath = sourceFiles[0].resolvedPath;
                                emitSignature = handleNewSignature((_f = state.emitSignatures) == null ? void 0 : _f.get(filePath), emitSignature);
                                if (!emitSignature)
                                    return;
                                ((_g = state.emitSignatures) != null ? _g : state.emitSignatures = /* @__PURE__ */ new Map()).set(filePath, emitSignature);
                            }
                        }
                        else if (state.compilerOptions.composite) {
                            const newSignature = handleNewSignature(state.outSignature, 
                            /*newSignature*/
                            void 0);
                            if (!newSignature)
                                return;
                            state.outSignature = newSignature;
                        }
                    }
                    if (writeFile2)
                        writeFile2(fileName, text, writeByteOrderMark, onError, sourceFiles, data);
                    else if (host.writeFile)
                        host.writeFile(fileName, text, writeByteOrderMark, onError, sourceFiles, data);
                    else
                        state.program.writeFile(fileName, text, writeByteOrderMark, onError, sourceFiles, data);
                    function handleNewSignature(oldSignatureFormat, newSignature) {
                        const oldSignature = !oldSignatureFormat || isString(oldSignatureFormat) ? oldSignatureFormat : oldSignatureFormat[0];
                        newSignature != null ? newSignature : newSignature = computeSignature(text, host, data);
                        if (newSignature === oldSignature) {
                            if (oldSignatureFormat === oldSignature)
                                return void 0;
                            else if (data)
                                data.differsOnlyInMap = true;
                            else
                                data = { differsOnlyInMap: true };
                        }
                        else {
                            state.hasChangedEmitSignature = true;
                            state.latestChangedDtsFile = fileName;
                        }
                        return newSignature;
                    }
                };
            }
            function emit(targetSourceFile, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) {
                if (kind === 1 /* EmitAndSemanticDiagnosticsBuilderProgram */) {
                    assertSourceFileOkWithoutNextAffectedCall(state, targetSourceFile);
                }
                const result = handleNoEmitOptions(builderProgram, targetSourceFile, writeFile2, cancellationToken);
                if (result)
                    return result;
                if (!targetSourceFile) {
                    if (kind === 1 /* EmitAndSemanticDiagnosticsBuilderProgram */) {
                        let sourceMaps = [];
                        let emitSkipped = false;
                        let diagnostics;
                        let emittedFiles = [];
                        let affectedEmitResult;
                        while (affectedEmitResult = emitNextAffectedFile(writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers)) {
                            emitSkipped = emitSkipped || affectedEmitResult.result.emitSkipped;
                            diagnostics = addRange(diagnostics, affectedEmitResult.result.diagnostics);
                            emittedFiles = addRange(emittedFiles, affectedEmitResult.result.emittedFiles);
                            sourceMaps = addRange(sourceMaps, affectedEmitResult.result.sourceMaps);
                        }
                        return {
                            emitSkipped,
                            diagnostics: diagnostics || emptyArray,
                            emittedFiles,
                            sourceMaps
                        };
                    }
                    else {
                        clearAffectedFilesPendingEmit(state, emitOnlyDtsFiles);
                    }
                }
                return Debug.checkDefined(state.program).emit(targetSourceFile, getWriteFileCallback(writeFile2, customTransformers), cancellationToken, emitOnlyDtsFiles, customTransformers);
            }
            function getSemanticDiagnosticsOfNextAffectedFile(cancellationToken, ignoreSourceFile) {
                while (true) {
                    const affected = getNextAffectedFile(state, cancellationToken, host);
                    let result;
                    if (!affected)
                        return void 0;
                    else if (affected !== state.program) {
                        const affectedSourceFile = affected;
                        if (!ignoreSourceFile || !ignoreSourceFile(affectedSourceFile)) {
                            result = getSemanticDiagnosticsOfFile(state, affectedSourceFile, cancellationToken);
                        }
                        state.seenAffectedFiles.add(affectedSourceFile.resolvedPath);
                        state.affectedFilesIndex++;
                        state.buildInfoEmitPending = true;
                        if (!result)
                            continue;
                    }
                    else {
                        result = state.program.getSemanticDiagnostics(
                        /*targetSourceFile*/
                        void 0, cancellationToken);
                        state.changedFilesSet.clear();
                        state.programEmitPending = getBuilderFileEmit(state.compilerOptions);
                    }
                    return { result, affected };
                }
            }
            function getSemanticDiagnostics(sourceFile, cancellationToken) {
                assertSourceFileOkWithoutNextAffectedCall(state, sourceFile);
                const compilerOptions = Debug.checkDefined(state.program).getCompilerOptions();
                if (outFile(compilerOptions)) {
                    Debug.assert(!state.semanticDiagnosticsPerFile);
                    return Debug.checkDefined(state.program).getSemanticDiagnostics(sourceFile, cancellationToken);
                }
                if (sourceFile) {
                    return getSemanticDiagnosticsOfFile(state, sourceFile, cancellationToken);
                }
                while (getSemanticDiagnosticsOfNextAffectedFile(cancellationToken)) {
                }
                let diagnostics;
                for (const sourceFile2 of Debug.checkDefined(state.program).getSourceFiles()) {
                    diagnostics = addRange(diagnostics, getSemanticDiagnosticsOfFile(state, sourceFile2, cancellationToken));
                }
                return diagnostics || emptyArray;
            }
        }
        function addToAffectedFilesPendingEmit(state, affectedFilePendingEmit, kind) {
            var _a2, _b;
            const existingKind = ((_a2 = state.affectedFilesPendingEmit) == null ? void 0 : _a2.get(affectedFilePendingEmit)) || 0 /* None */;
            ((_b = state.affectedFilesPendingEmit) != null ? _b : state.affectedFilesPendingEmit = /* @__PURE__ */ new Map()).set(affectedFilePendingEmit, existingKind | kind);
        }
        function toBuilderStateFileInfoForMultiEmit(fileInfo) {
            return isString(fileInfo) ? { version: fileInfo, signature: fileInfo, affectsGlobalScope: void 0, impliedFormat: void 0 } : isString(fileInfo.signature) ? fileInfo : { version: fileInfo.version, signature: fileInfo.signature === false ? void 0 : fileInfo.version, affectsGlobalScope: fileInfo.affectsGlobalScope, impliedFormat: fileInfo.impliedFormat };
        }
        function toBuilderFileEmit(value, fullEmitForOptions) {
            return isNumber(value) ? fullEmitForOptions : value[1] || 8 /* Dts */;
        }
        function toProgramEmitPending(value, options) {
            return !value ? getBuilderFileEmit(options || {}) : value;
        }
        function createBuilderProgramUsingProgramBuildInfo(buildInfo, buildInfoPath, host) {
            var _a2, _b, _c, _d;
            const program = buildInfo.program;
            const buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(buildInfoPath, host.getCurrentDirectory()));
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames());
            let state;
            const filePaths = (_a2 = program.fileNames) == null ? void 0 : _a2.map(toPath3);
            let filePathsSetList;
            const latestChangedDtsFile = program.latestChangedDtsFile ? toAbsolutePath(program.latestChangedDtsFile) : void 0;
            if (isProgramBundleEmitBuildInfo(program)) {
                const fileInfos = /* @__PURE__ */ new Map();
                program.fileInfos.forEach((fileInfo, index) => {
                    const path = toFilePath(index + 1);
                    fileInfos.set(path, isString(fileInfo) ? { version: fileInfo, signature: void 0, affectsGlobalScope: void 0, impliedFormat: void 0 } : fileInfo);
                });
                state = {
                    fileInfos,
                    compilerOptions: program.options ? convertToOptionsWithAbsolutePaths(program.options, toAbsolutePath) : {},
                    latestChangedDtsFile,
                    outSignature: program.outSignature,
                    programEmitPending: program.pendingEmit === void 0 ? void 0 : toProgramEmitPending(program.pendingEmit, program.options),
                    bundle: buildInfo.bundle
                };
            }
            else {
                filePathsSetList = (_b = program.fileIdsList) == null ? void 0 : _b.map((fileIds) => new Set(fileIds.map(toFilePath)));
                const fileInfos = /* @__PURE__ */ new Map();
                const emitSignatures = ((_c = program.options) == null ? void 0 : _c.composite) && !outFile(program.options) ? /* @__PURE__ */ new Map() : void 0;
                program.fileInfos.forEach((fileInfo, index) => {
                    const path = toFilePath(index + 1);
                    const stateFileInfo = toBuilderStateFileInfoForMultiEmit(fileInfo);
                    fileInfos.set(path, stateFileInfo);
                    if (emitSignatures && stateFileInfo.signature)
                        emitSignatures.set(path, stateFileInfo.signature);
                });
                (_d = program.emitSignatures) == null ? void 0 : _d.forEach((value) => {
                    if (isNumber(value))
                        emitSignatures.delete(toFilePath(value));
                    else {
                        const key = toFilePath(value[0]);
                        emitSignatures.set(key, !isString(value[1]) && !value[1].length ? (
                        // File signature is emit signature but differs in map
                        [emitSignatures.get(key)]) : value[1]);
                    }
                });
                const fullEmitForOptions = program.affectedFilesPendingEmit ? getBuilderFileEmit(program.options || {}) : void 0;
                state = {
                    fileInfos,
                    compilerOptions: program.options ? convertToOptionsWithAbsolutePaths(program.options, toAbsolutePath) : {},
                    referencedMap: toManyToManyPathMap(program.referencedMap),
                    exportedModulesMap: toManyToManyPathMap(program.exportedModulesMap),
                    semanticDiagnosticsPerFile: program.semanticDiagnosticsPerFile && arrayToMap(program.semanticDiagnosticsPerFile, (value) => toFilePath(isNumber(value) ? value : value[0]), (value) => isNumber(value) ? emptyArray : value[1]),
                    hasReusableDiagnostic: true,
                    affectedFilesPendingEmit: program.affectedFilesPendingEmit && arrayToMap(program.affectedFilesPendingEmit, (value) => toFilePath(isNumber(value) ? value : value[0]), (value) => toBuilderFileEmit(value, fullEmitForOptions)),
                    changedFilesSet: new Set(map(program.changeFileSet, toFilePath)),
                    latestChangedDtsFile,
                    emitSignatures: (emitSignatures == null ? void 0 : emitSignatures.size) ? emitSignatures : void 0
                };
            }
            return {
                getState: () => state,
                saveEmitState: noop,
                restoreEmitState: noop,
                getProgram: notImplemented,
                getProgramOrUndefined: returnUndefined,
                releaseProgram: noop,
                getCompilerOptions: () => state.compilerOptions,
                getSourceFile: notImplemented,
                getSourceFiles: notImplemented,
                getOptionsDiagnostics: notImplemented,
                getGlobalDiagnostics: notImplemented,
                getConfigFileParsingDiagnostics: notImplemented,
                getSyntacticDiagnostics: notImplemented,
                getDeclarationDiagnostics: notImplemented,
                getSemanticDiagnostics: notImplemented,
                emit: notImplemented,
                getAllDependencies: notImplemented,
                getCurrentDirectory: notImplemented,
                emitNextAffectedFile: notImplemented,
                getSemanticDiagnosticsOfNextAffectedFile: notImplemented,
                emitBuildInfo: notImplemented,
                close: noop,
                hasChangedEmitSignature: returnFalse
            };
            function toPath3(path) {
                return toPath(path, buildInfoDirectory, getCanonicalFileName);
            }
            function toAbsolutePath(path) {
                return getNormalizedAbsolutePath(path, buildInfoDirectory);
            }
            function toFilePath(fileId) {
                return filePaths[fileId - 1];
            }
            function toFilePathsSet(fileIdsListId) {
                return filePathsSetList[fileIdsListId - 1];
            }
            function toManyToManyPathMap(referenceMap) {
                if (!referenceMap) {
                    return void 0;
                }
                const map2 = BuilderState.createManyToManyPathMap();
                referenceMap.forEach(([fileId, fileIdListId]) => map2.set(toFilePath(fileId), toFilePathsSet(fileIdListId)));
                return map2;
            }
        }
        function getBuildInfoFileVersionMap(program, buildInfoPath, host) {
            const buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(buildInfoPath, host.getCurrentDirectory()));
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames());
            const fileInfos = /* @__PURE__ */ new Map();
            let rootIndex = 0;
            const roots = [];
            program.fileInfos.forEach((fileInfo, index) => {
                const path = toPath(program.fileNames[index], buildInfoDirectory, getCanonicalFileName);
                const version2 = isString(fileInfo) ? fileInfo : fileInfo.version;
                fileInfos.set(path, version2);
                if (rootIndex < program.root.length) {
                    const current = program.root[rootIndex];
                    const fileId = index + 1;
                    if (isArray(current)) {
                        if (current[0] <= fileId && fileId <= current[1]) {
                            roots.push(path);
                            if (current[1] === fileId)
                                rootIndex++;
                        }
                    }
                    else if (current === fileId) {
                        roots.push(path);
                        rootIndex++;
                    }
                }
            });
            return { fileInfos, roots };
        }
        function createRedirectedBuilderProgram(getState, configFileParsingDiagnostics) {
            return {
                getState: notImplemented,
                saveEmitState: noop,
                restoreEmitState: noop,
                getProgram,
                getProgramOrUndefined: () => getState().program,
                releaseProgram: () => getState().program = void 0,
                getCompilerOptions: () => getState().compilerOptions,
                getSourceFile: (fileName) => getProgram().getSourceFile(fileName),
                getSourceFiles: () => getProgram().getSourceFiles(),
                getOptionsDiagnostics: (cancellationToken) => getProgram().getOptionsDiagnostics(cancellationToken),
                getGlobalDiagnostics: (cancellationToken) => getProgram().getGlobalDiagnostics(cancellationToken),
                getConfigFileParsingDiagnostics: () => configFileParsingDiagnostics,
                getSyntacticDiagnostics: (sourceFile, cancellationToken) => getProgram().getSyntacticDiagnostics(sourceFile, cancellationToken),
                getDeclarationDiagnostics: (sourceFile, cancellationToken) => getProgram().getDeclarationDiagnostics(sourceFile, cancellationToken),
                getSemanticDiagnostics: (sourceFile, cancellationToken) => getProgram().getSemanticDiagnostics(sourceFile, cancellationToken),
                emit: (sourceFile, writeFile2, cancellationToken, emitOnlyDts, customTransformers) => getProgram().emit(sourceFile, writeFile2, cancellationToken, emitOnlyDts, customTransformers),
                emitBuildInfo: (writeFile2, cancellationToken) => getProgram().emitBuildInfo(writeFile2, cancellationToken),
                getAllDependencies: notImplemented,
                getCurrentDirectory: () => getProgram().getCurrentDirectory(),
                close: noop
            };
            function getProgram() {
                return Debug.checkDefined(getState().program);
            }
        }
        var BuilderFileEmit, BuilderProgramKind;
        var init_builder = __esm({
            "src/compiler/builder.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
                BuilderFileEmit = /* @__PURE__ */ ((BuilderFileEmit2) => {
                    BuilderFileEmit2[BuilderFileEmit2["None"] = 0] = "None";
                    BuilderFileEmit2[BuilderFileEmit2["Js"] = 1] = "Js";
                    BuilderFileEmit2[BuilderFileEmit2["JsMap"] = 2] = "JsMap";
                    BuilderFileEmit2[BuilderFileEmit2["JsInlineMap"] = 4] = "JsInlineMap";
                    BuilderFileEmit2[BuilderFileEmit2["Dts"] = 8] = "Dts";
                    BuilderFileEmit2[BuilderFileEmit2["DtsMap"] = 16] = "DtsMap";
                    BuilderFileEmit2[BuilderFileEmit2["AllJs"] = 7] = "AllJs";
                    BuilderFileEmit2[BuilderFileEmit2["AllDts"] = 24] = "AllDts";
                    BuilderFileEmit2[BuilderFileEmit2["All"] = 31] = "All";
                    return BuilderFileEmit2;
                })(BuilderFileEmit || {});
                BuilderProgramKind = /* @__PURE__ */ ((BuilderProgramKind2) => {
                    BuilderProgramKind2[BuilderProgramKind2["SemanticDiagnosticsBuilderProgram"] = 0] = "SemanticDiagnosticsBuilderProgram";
                    BuilderProgramKind2[BuilderProgramKind2["EmitAndSemanticDiagnosticsBuilderProgram"] = 1] = "EmitAndSemanticDiagnosticsBuilderProgram";
                    return BuilderProgramKind2;
                })(BuilderProgramKind || {});
            }
        });
        // src/compiler/builderPublic.ts
        function createSemanticDiagnosticsBuilderProgram(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences) {
            return createBuilderProgram(0 /* SemanticDiagnosticsBuilderProgram */, getBuilderCreationParameters(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences));
        }
        function createEmitAndSemanticDiagnosticsBuilderProgram(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences) {
            return createBuilderProgram(1 /* EmitAndSemanticDiagnosticsBuilderProgram */, getBuilderCreationParameters(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences));
        }
        function createAbstractBuilder(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences) {
            const { newProgram, configFileParsingDiagnostics: newConfigFileParsingDiagnostics } = getBuilderCreationParameters(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences);
            return createRedirectedBuilderProgram(() => ({ program: newProgram, compilerOptions: newProgram.getCompilerOptions() }), newConfigFileParsingDiagnostics);
        }
        var init_builderPublic = __esm({
            "src/compiler/builderPublic.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/resolutionCache.ts
        function removeIgnoredPath(path) {
            if (endsWith(path, "/node_modules/.staging")) {
                return removeSuffix(path, "/.staging");
            }
            return some(ignoredPaths, (searchPath) => stringContains(path, searchPath)) ? void 0 : path;
        }
        function canWatchDirectoryOrFile(dirPath) {
            const rootLength = getRootLength(dirPath);
            if (dirPath.length === rootLength) {
                return false;
            }
            let nextDirectorySeparator = dirPath.indexOf(directorySeparator, rootLength);
            if (nextDirectorySeparator === -1) {
                return false;
            }
            let pathPartForUserCheck = dirPath.substring(rootLength, nextDirectorySeparator + 1);
            const isNonDirectorySeparatorRoot = rootLength > 1 || dirPath.charCodeAt(0) !== 47 /* slash */;
            if (isNonDirectorySeparatorRoot && dirPath.search(/[a-zA-Z]:/) !== 0 && // Non dos style paths
                pathPartForUserCheck.search(/[a-zA-Z]\$\//) === 0) {
                nextDirectorySeparator = dirPath.indexOf(directorySeparator, nextDirectorySeparator + 1);
                if (nextDirectorySeparator === -1) {
                    return false;
                }
                pathPartForUserCheck = dirPath.substring(rootLength + pathPartForUserCheck.length, nextDirectorySeparator + 1);
            }
            if (isNonDirectorySeparatorRoot && pathPartForUserCheck.search(/users\//i) !== 0) {
                return true;
            }
            for (let searchIndex = nextDirectorySeparator + 1, searchLevels = 2; searchLevels > 0; searchLevels--) {
                searchIndex = dirPath.indexOf(directorySeparator, searchIndex) + 1;
                if (searchIndex === 0) {
                    return false;
                }
            }
            return true;
        }
        function createResolutionCache(resolutionHost, rootDirForResolution, logChangesWhenResolvingModule) {
            let filesWithChangedSetOfUnresolvedImports;
            let filesWithInvalidatedResolutions;
            let filesWithInvalidatedNonRelativeUnresolvedImports;
            const nonRelativeExternalModuleResolutions = createMultiMap();
            const resolutionsWithFailedLookups = /* @__PURE__ */ new Set();
            const resolutionsWithOnlyAffectingLocations = /* @__PURE__ */ new Set();
            const resolvedFileToResolution = /* @__PURE__ */ new Map();
            const impliedFormatPackageJsons = /* @__PURE__ */ new Map();
            let hasChangedAutomaticTypeDirectiveNames = false;
            let affectingPathChecksForFile;
            let affectingPathChecks;
            let failedLookupChecks;
            let startsWithPathChecks;
            let isInDirectoryChecks;
            const getCurrentDirectory = memoize(() => resolutionHost.getCurrentDirectory());
            const cachedDirectoryStructureHost = resolutionHost.getCachedDirectoryStructureHost();
            const resolvedModuleNames = /* @__PURE__ */ new Map();
            const moduleResolutionCache = createModuleResolutionCache(getCurrentDirectory(), resolutionHost.getCanonicalFileName, resolutionHost.getCompilationSettings());
            const resolvedTypeReferenceDirectives = /* @__PURE__ */ new Map();
            const typeReferenceDirectiveResolutionCache = createTypeReferenceDirectiveResolutionCache(getCurrentDirectory(), resolutionHost.getCanonicalFileName, resolutionHost.getCompilationSettings(), moduleResolutionCache.getPackageJsonInfoCache());
            const failedLookupDefaultExtensions = [".ts" /* Ts */, ".tsx" /* Tsx */, ".js" /* Js */, ".jsx" /* Jsx */, ".json" /* Json */];
            const customFailedLookupPaths = /* @__PURE__ */ new Map();
            const directoryWatchesOfFailedLookups = /* @__PURE__ */ new Map();
            const fileWatchesOfAffectingLocations = /* @__PURE__ */ new Map();
            const rootDir = rootDirForResolution && removeTrailingDirectorySeparator(getNormalizedAbsolutePath(rootDirForResolution, getCurrentDirectory()));
            const rootPath = rootDir && resolutionHost.toPath(rootDir);
            const rootSplitLength = rootPath !== void 0 ? rootPath.split(directorySeparator).length : 0;
            const typeRootsWatches = /* @__PURE__ */ new Map();
            return {
                getModuleResolutionCache: () => moduleResolutionCache,
                startRecordingFilesWithChangedResolutions,
                finishRecordingFilesWithChangedResolutions,
                // perDirectoryResolvedModuleNames and perDirectoryResolvedTypeReferenceDirectives could be non empty if there was exception during program update
                // (between startCachingPerDirectoryResolution and finishCachingPerDirectoryResolution)
                startCachingPerDirectoryResolution,
                finishCachingPerDirectoryResolution,
                resolveModuleNameLiterals,
                resolveTypeReferenceDirectiveReferences,
                resolveSingleModuleNameWithoutWatching,
                removeResolutionsFromProjectReferenceRedirects,
                removeResolutionsOfFile,
                hasChangedAutomaticTypeDirectiveNames: () => hasChangedAutomaticTypeDirectiveNames,
                invalidateResolutionOfFile,
                invalidateResolutionsOfFailedLookupLocations,
                setFilesWithInvalidatedNonRelativeUnresolvedImports,
                createHasInvalidatedResolutions,
                isFileWithInvalidatedNonRelativeUnresolvedImports,
                updateTypeRootsWatch,
                closeTypeRootsWatch,
                clear: clear2
            };
            function getResolvedModule2(resolution) {
                return resolution.resolvedModule;
            }
            function getResolvedTypeReferenceDirective2(resolution) {
                return resolution.resolvedTypeReferenceDirective;
            }
            function isInDirectoryPath(dir, file) {
                if (dir === void 0 || file.length <= dir.length) {
                    return false;
                }
                return startsWith(file, dir) && file[dir.length] === directorySeparator;
            }
            function clear2() {
                clearMap(directoryWatchesOfFailedLookups, closeFileWatcherOf);
                clearMap(fileWatchesOfAffectingLocations, closeFileWatcherOf);
                customFailedLookupPaths.clear();
                nonRelativeExternalModuleResolutions.clear();
                closeTypeRootsWatch();
                resolvedModuleNames.clear();
                resolvedTypeReferenceDirectives.clear();
                resolvedFileToResolution.clear();
                resolutionsWithFailedLookups.clear();
                resolutionsWithOnlyAffectingLocations.clear();
                failedLookupChecks = void 0;
                startsWithPathChecks = void 0;
                isInDirectoryChecks = void 0;
                affectingPathChecks = void 0;
                affectingPathChecksForFile = void 0;
                moduleResolutionCache.clear();
                typeReferenceDirectiveResolutionCache.clear();
                moduleResolutionCache.update(resolutionHost.getCompilationSettings());
                typeReferenceDirectiveResolutionCache.update(resolutionHost.getCompilationSettings());
                impliedFormatPackageJsons.clear();
                hasChangedAutomaticTypeDirectiveNames = false;
            }
            function startRecordingFilesWithChangedResolutions() {
                filesWithChangedSetOfUnresolvedImports = [];
            }
            function finishRecordingFilesWithChangedResolutions() {
                const collected = filesWithChangedSetOfUnresolvedImports;
                filesWithChangedSetOfUnresolvedImports = void 0;
                return collected;
            }
            function isFileWithInvalidatedNonRelativeUnresolvedImports(path) {
                if (!filesWithInvalidatedNonRelativeUnresolvedImports) {
                    return false;
                }
                const value = filesWithInvalidatedNonRelativeUnresolvedImports.get(path);
                return !!value && !!value.length;
            }
            function createHasInvalidatedResolutions(customHasInvalidatedResolutions) {
                invalidateResolutionsOfFailedLookupLocations();
                const collected = filesWithInvalidatedResolutions;
                filesWithInvalidatedResolutions = void 0;
                return (path) => customHasInvalidatedResolutions(path) || !!(collected == null ? void 0 : collected.has(path)) || isFileWithInvalidatedNonRelativeUnresolvedImports(path);
            }
            function startCachingPerDirectoryResolution() {
                moduleResolutionCache.clearAllExceptPackageJsonInfoCache();
                typeReferenceDirectiveResolutionCache.clearAllExceptPackageJsonInfoCache();
                nonRelativeExternalModuleResolutions.forEach(watchFailedLookupLocationOfNonRelativeModuleResolutions);
                nonRelativeExternalModuleResolutions.clear();
            }
            function finishCachingPerDirectoryResolution(newProgram, oldProgram) {
                filesWithInvalidatedNonRelativeUnresolvedImports = void 0;
                nonRelativeExternalModuleResolutions.forEach(watchFailedLookupLocationOfNonRelativeModuleResolutions);
                nonRelativeExternalModuleResolutions.clear();
                if (newProgram !== oldProgram) {
                    newProgram == null ? void 0 : newProgram.getSourceFiles().forEach((newFile) => {
                        var _a2, _b, _c;
                        const expected = isExternalOrCommonJsModule(newFile) ? (_b = (_a2 = newFile.packageJsonLocations) == null ? void 0 : _a2.length) != null ? _b : 0 : 0;
                        const existing = (_c = impliedFormatPackageJsons.get(newFile.path)) != null ? _c : emptyArray;
                        for (let i = existing.length; i < expected; i++) {
                            createFileWatcherOfAffectingLocation(newFile.packageJsonLocations[i], 
                            /*forResolution*/
                            false);
                        }
                        if (existing.length > expected) {
                            for (let i = expected; i < existing.length; i++) {
                                fileWatchesOfAffectingLocations.get(existing[i]).files--;
                            }
                        }
                        if (expected)
                            impliedFormatPackageJsons.set(newFile.path, newFile.packageJsonLocations);
                        else
                            impliedFormatPackageJsons.delete(newFile.path);
                    });
                    impliedFormatPackageJsons.forEach((existing, path) => {
                        if (!(newProgram == null ? void 0 : newProgram.getSourceFileByPath(path))) {
                            existing.forEach((location) => fileWatchesOfAffectingLocations.get(location).files--);
                            impliedFormatPackageJsons.delete(path);
                        }
                    });
                }
                directoryWatchesOfFailedLookups.forEach((watcher, path) => {
                    if (watcher.refCount === 0) {
                        directoryWatchesOfFailedLookups.delete(path);
                        watcher.watcher.close();
                    }
                });
                fileWatchesOfAffectingLocations.forEach((watcher, path) => {
                    if (watcher.files === 0 && watcher.resolutions === 0) {
                        fileWatchesOfAffectingLocations.delete(path);
                        watcher.watcher.close();
                    }
                });
                hasChangedAutomaticTypeDirectiveNames = false;
            }
            function resolveModuleName2(moduleName, containingFile, compilerOptions, redirectedReference, mode) {
                var _a2;
                const host = ((_a2 = resolutionHost.getCompilerHost) == null ? void 0 : _a2.call(resolutionHost)) || resolutionHost;
                const primaryResult = resolveModuleName(moduleName, containingFile, compilerOptions, host, moduleResolutionCache, redirectedReference, mode);
                if (!resolutionHost.getGlobalCache) {
                    return primaryResult;
                }
                const globalCache = resolutionHost.getGlobalCache();
                if (globalCache !== void 0 && !isExternalModuleNameRelative(moduleName) && !(primaryResult.resolvedModule && extensionIsTS(primaryResult.resolvedModule.extension))) {
                    const { resolvedModule, failedLookupLocations, affectingLocations, resolutionDiagnostics } = loadModuleFromGlobalCache(Debug.checkDefined(resolutionHost.globalCacheResolutionModuleName)(moduleName), resolutionHost.projectName, compilerOptions, host, globalCache, moduleResolutionCache);
                    if (resolvedModule) {
                        primaryResult.resolvedModule = resolvedModule;
                        primaryResult.failedLookupLocations = updateResolutionField(primaryResult.failedLookupLocations, failedLookupLocations);
                        primaryResult.affectingLocations = updateResolutionField(primaryResult.affectingLocations, affectingLocations);
                        primaryResult.resolutionDiagnostics = updateResolutionField(primaryResult.resolutionDiagnostics, resolutionDiagnostics);
                        return primaryResult;
                    }
                }
                return primaryResult;
            }
            function createModuleResolutionLoader2(containingFile, redirectedReference, options) {
                return {
                    nameAndMode: moduleResolutionNameAndModeGetter,
                    resolve: (moduleName, resoluionMode) => resolveModuleName2(moduleName, containingFile, options, redirectedReference, resoluionMode)
                };
            }
            function resolveNamesWithLocalCache({ entries, containingFile, containingSourceFile, redirectedReference, options, perFileCache, reusedNames, loader, getResolutionWithResolvedFileName, shouldRetryResolution, logChanges }) {
                var _a2;
                const path = resolutionHost.toPath(containingFile);
                const resolutionsInFile = perFileCache.get(path) || perFileCache.set(path, createModeAwareCache()).get(path);
                const resolvedModules = [];
                const hasInvalidatedNonRelativeUnresolvedImport = logChanges && isFileWithInvalidatedNonRelativeUnresolvedImports(path);
                const program = resolutionHost.getCurrentProgram();
                const oldRedirect = program && program.getResolvedProjectReferenceToRedirect(containingFile);
                const unmatchedRedirects = oldRedirect ? !redirectedReference || redirectedReference.sourceFile.path !== oldRedirect.sourceFile.path : !!redirectedReference;
                const seenNamesInFile = createModeAwareCache();
                for (const entry of entries) {
                    const name = loader.nameAndMode.getName(entry);
                    const mode = loader.nameAndMode.getMode(entry, containingSourceFile);
                    let resolution = resolutionsInFile.get(name, mode);
                    if (!seenNamesInFile.has(name, mode) && unmatchedRedirects || !resolution || resolution.isInvalidated || // If the name is unresolved import that was invalidated, recalculate
                        hasInvalidatedNonRelativeUnresolvedImport && !isExternalModuleNameRelative(name) && shouldRetryResolution(resolution)) {
                        const existingResolution = resolution;
                        resolution = loader.resolve(name, mode);
                        if (resolutionHost.onDiscoveredSymlink && resolutionIsSymlink(resolution)) {
                            resolutionHost.onDiscoveredSymlink();
                        }
                        resolutionsInFile.set(name, mode, resolution);
                        watchFailedLookupLocationsOfExternalModuleResolutions(name, resolution, path, getResolutionWithResolvedFileName);
                        if (existingResolution) {
                            stopWatchFailedLookupLocationOfResolution(existingResolution, path, getResolutionWithResolvedFileName);
                        }
                        if (logChanges && filesWithChangedSetOfUnresolvedImports && !resolutionIsEqualTo(existingResolution, resolution)) {
                            filesWithChangedSetOfUnresolvedImports.push(path);
                            logChanges = false;
                        }
                    }
                    else {
                        const host = ((_a2 = resolutionHost.getCompilerHost) == null ? void 0 : _a2.call(resolutionHost)) || resolutionHost;
                        if (isTraceEnabled(options, host) && !seenNamesInFile.has(name, mode)) {
                            const resolved = getResolutionWithResolvedFileName(resolution);
                            trace(host, perFileCache === resolvedModuleNames ? (resolved == null ? void 0 : resolved.resolvedFileName) ? resolved.packageId ? Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved : (resolved == null ? void 0 : resolved.resolvedFileName) ? resolved.packageId ? Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2 : Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved, name, containingFile, resolved == null ? void 0 : resolved.resolvedFileName, (resolved == null ? void 0 : resolved.packageId) && packageIdToString(resolved.packageId));
                        }
                    }
                    Debug.assert(resolution !== void 0 && !resolution.isInvalidated);
                    seenNamesInFile.set(name, mode, true);
                    resolvedModules.push(resolution);
                }
                reusedNames == null ? void 0 : reusedNames.forEach((entry) => seenNamesInFile.set(loader.nameAndMode.getName(entry), loader.nameAndMode.getMode(entry, containingSourceFile), true));
                if (resolutionsInFile.size() !== seenNamesInFile.size()) {
                    resolutionsInFile.forEach((resolution, name, mode) => {
                        if (!seenNamesInFile.has(name, mode)) {
                            stopWatchFailedLookupLocationOfResolution(resolution, path, getResolutionWithResolvedFileName);
                            resolutionsInFile.delete(name, mode);
                        }
                    });
                }
                return resolvedModules;
                function resolutionIsEqualTo(oldResolution, newResolution) {
                    if (oldResolution === newResolution) {
                        return true;
                    }
                    if (!oldResolution || !newResolution) {
                        return false;
                    }
                    const oldResult = getResolutionWithResolvedFileName(oldResolution);
                    const newResult = getResolutionWithResolvedFileName(newResolution);
                    if (oldResult === newResult) {
                        return true;
                    }
                    if (!oldResult || !newResult) {
                        return false;
                    }
                    return oldResult.resolvedFileName === newResult.resolvedFileName;
                }
            }
            function resolveTypeReferenceDirectiveReferences(typeDirectiveReferences, containingFile, redirectedReference, options, containingSourceFile, reusedNames) {
                var _a2;
                return resolveNamesWithLocalCache({
                    entries: typeDirectiveReferences,
                    containingFile,
                    containingSourceFile,
                    redirectedReference,
                    options,
                    reusedNames,
                    perFileCache: resolvedTypeReferenceDirectives,
                    loader: createTypeReferenceResolutionLoader(containingFile, redirectedReference, options, ((_a2 = resolutionHost.getCompilerHost) == null ? void 0 : _a2.call(resolutionHost)) || resolutionHost, typeReferenceDirectiveResolutionCache),
                    getResolutionWithResolvedFileName: getResolvedTypeReferenceDirective2,
                    shouldRetryResolution: (resolution) => resolution.resolvedTypeReferenceDirective === void 0
                });
            }
            function resolveModuleNameLiterals(moduleLiterals, containingFile, redirectedReference, options, containingSourceFile, reusedNames) {
                return resolveNamesWithLocalCache({
                    entries: moduleLiterals,
                    containingFile,
                    containingSourceFile,
                    redirectedReference,
                    options,
                    reusedNames,
                    perFileCache: resolvedModuleNames,
                    loader: createModuleResolutionLoader2(containingFile, redirectedReference, options),
                    getResolutionWithResolvedFileName: getResolvedModule2,
                    shouldRetryResolution: (resolution) => !resolution.resolvedModule || !resolutionExtensionIsTSOrJson(resolution.resolvedModule.extension),
                    logChanges: logChangesWhenResolvingModule
                });
            }
            function resolveSingleModuleNameWithoutWatching(moduleName, containingFile) {
                const path = resolutionHost.toPath(containingFile);
                const resolutionsInFile = resolvedModuleNames.get(path);
                const resolution = resolutionsInFile == null ? void 0 : resolutionsInFile.get(moduleName, 
                /*mode*/
                void 0);
                if (resolution && !resolution.isInvalidated)
                    return resolution;
                return resolveModuleName2(moduleName, containingFile, resolutionHost.getCompilationSettings());
            }
            function isNodeModulesAtTypesDirectory(dirPath) {
                return endsWith(dirPath, "/node_modules/@types");
            }
            function getDirectoryToWatchFailedLookupLocation(failedLookupLocation, failedLookupLocationPath) {
                if (isInDirectoryPath(rootPath, failedLookupLocationPath)) {
                    failedLookupLocation = isRootedDiskPath(failedLookupLocation) ? normalizePath(failedLookupLocation) : getNormalizedAbsolutePath(failedLookupLocation, getCurrentDirectory());
                    const failedLookupPathSplit = failedLookupLocationPath.split(directorySeparator);
                    const failedLookupSplit = failedLookupLocation.split(directorySeparator);
                    Debug.assert(failedLookupSplit.length === failedLookupPathSplit.length, `FailedLookup: ${failedLookupLocation} failedLookupLocationPath: ${failedLookupLocationPath}`);
                    if (failedLookupPathSplit.length > rootSplitLength + 1) {
                        return {
                            dir: failedLookupSplit.slice(0, rootSplitLength + 1).join(directorySeparator),
                            dirPath: failedLookupPathSplit.slice(0, rootSplitLength + 1).join(directorySeparator)
                        };
                    }
                    else {
                        return {
                            dir: rootDir,
                            dirPath: rootPath,
                            nonRecursive: false
                        };
                    }
                }
                return getDirectoryToWatchFromFailedLookupLocationDirectory(getDirectoryPath(getNormalizedAbsolutePath(failedLookupLocation, getCurrentDirectory())), getDirectoryPath(failedLookupLocationPath));
            }
            function getDirectoryToWatchFromFailedLookupLocationDirectory(dir, dirPath) {
                while (pathContainsNodeModules(dirPath)) {
                    dir = getDirectoryPath(dir);
                    dirPath = getDirectoryPath(dirPath);
                }
                if (isNodeModulesDirectory(dirPath)) {
                    return canWatchDirectoryOrFile(getDirectoryPath(dirPath)) ? { dir, dirPath } : void 0;
                }
                let nonRecursive = true;
                let subDirectoryPath, subDirectory;
                if (rootPath !== void 0) {
                    while (!isInDirectoryPath(dirPath, rootPath)) {
                        const parentPath = getDirectoryPath(dirPath);
                        if (parentPath === dirPath) {
                            break;
                        }
                        nonRecursive = false;
                        subDirectoryPath = dirPath;
                        subDirectory = dir;
                        dirPath = parentPath;
                        dir = getDirectoryPath(dir);
                    }
                }
                return canWatchDirectoryOrFile(dirPath) ? { dir: subDirectory || dir, dirPath: subDirectoryPath || dirPath, nonRecursive } : void 0;
            }
            function isPathWithDefaultFailedLookupExtension(path) {
                return fileExtensionIsOneOf(path, failedLookupDefaultExtensions);
            }
            function watchFailedLookupLocationsOfExternalModuleResolutions(name, resolution, filePath, getResolutionWithResolvedFileName) {
                var _a2, _b;
                if (resolution.refCount) {
                    resolution.refCount++;
                    Debug.assertIsDefined(resolution.files);
                }
                else {
                    resolution.refCount = 1;
                    Debug.assert(!((_a2 = resolution.files) == null ? void 0 : _a2.size));
                    if (isExternalModuleNameRelative(name)) {
                        watchFailedLookupLocationOfResolution(resolution);
                    }
                    else {
                        nonRelativeExternalModuleResolutions.add(name, resolution);
                    }
                    const resolved = getResolutionWithResolvedFileName(resolution);
                    if (resolved && resolved.resolvedFileName) {
                        const key = resolutionHost.toPath(resolved.resolvedFileName);
                        let resolutions = resolvedFileToResolution.get(key);
                        if (!resolutions)
                            resolvedFileToResolution.set(key, resolutions = /* @__PURE__ */ new Set());
                        resolutions.add(resolution);
                    }
                }
                ((_b = resolution.files) != null ? _b : resolution.files = /* @__PURE__ */ new Set()).add(filePath);
            }
            function watchFailedLookupLocationOfResolution(resolution) {
                Debug.assert(!!resolution.refCount);
                const { failedLookupLocations, affectingLocations } = resolution;
                if (!(failedLookupLocations == null ? void 0 : failedLookupLocations.length) && !(affectingLocations == null ? void 0 : affectingLocations.length))
                    return;
                if (failedLookupLocations == null ? void 0 : failedLookupLocations.length)
                    resolutionsWithFailedLookups.add(resolution);
                let setAtRoot = false;
                if (failedLookupLocations) {
                    for (const failedLookupLocation of failedLookupLocations) {
                        const failedLookupLocationPath = resolutionHost.toPath(failedLookupLocation);
                        const toWatch = getDirectoryToWatchFailedLookupLocation(failedLookupLocation, failedLookupLocationPath);
                        if (toWatch) {
                            const { dir, dirPath, nonRecursive } = toWatch;
                            if (!isPathWithDefaultFailedLookupExtension(failedLookupLocationPath)) {
                                const refCount = customFailedLookupPaths.get(failedLookupLocationPath) || 0;
                                customFailedLookupPaths.set(failedLookupLocationPath, refCount + 1);
                            }
                            if (dirPath === rootPath) {
                                Debug.assert(!nonRecursive);
                                setAtRoot = true;
                            }
                            else {
                                setDirectoryWatcher(dir, dirPath, nonRecursive);
                            }
                        }
                    }
                    if (setAtRoot) {
                        setDirectoryWatcher(rootDir, rootPath, 
                        /*nonRecursive*/
                        true);
                    }
                }
                watchAffectingLocationsOfResolution(resolution, !(failedLookupLocations == null ? void 0 : failedLookupLocations.length));
            }
            function watchAffectingLocationsOfResolution(resolution, addToResolutionsWithOnlyAffectingLocations) {
                Debug.assert(!!resolution.refCount);
                const { affectingLocations } = resolution;
                if (!(affectingLocations == null ? void 0 : affectingLocations.length))
                    return;
                if (addToResolutionsWithOnlyAffectingLocations)
                    resolutionsWithOnlyAffectingLocations.add(resolution);
                for (const affectingLocation of affectingLocations) {
                    createFileWatcherOfAffectingLocation(affectingLocation, 
                    /*forResolution*/
                    true);
                }
            }
            function createFileWatcherOfAffectingLocation(affectingLocation, forResolution) {
                const fileWatcher = fileWatchesOfAffectingLocations.get(affectingLocation);
                if (fileWatcher) {
                    if (forResolution)
                        fileWatcher.resolutions++;
                    else
                        fileWatcher.files++;
                    return;
                }
                let locationToWatch = affectingLocation;
                if (resolutionHost.realpath) {
                    locationToWatch = resolutionHost.realpath(affectingLocation);
                    if (affectingLocation !== locationToWatch) {
                        const fileWatcher2 = fileWatchesOfAffectingLocations.get(locationToWatch);
                        if (fileWatcher2) {
                            if (forResolution)
                                fileWatcher2.resolutions++;
                            else
                                fileWatcher2.files++;
                            fileWatcher2.paths.add(affectingLocation);
                            fileWatchesOfAffectingLocations.set(affectingLocation, fileWatcher2);
                            return;
                        }
                    }
                }
                const paths = /* @__PURE__ */ new Set();
                paths.add(locationToWatch);
                let actualWatcher = canWatchDirectoryOrFile(resolutionHost.toPath(locationToWatch)) ? resolutionHost.watchAffectingFileLocation(locationToWatch, (fileName, eventKind) => {
                    cachedDirectoryStructureHost == null ? void 0 : cachedDirectoryStructureHost.addOrDeleteFile(fileName, resolutionHost.toPath(locationToWatch), eventKind);
                    const packageJsonMap = moduleResolutionCache.getPackageJsonInfoCache().getInternalMap();
                    paths.forEach((path) => {
                        if (watcher.resolutions)
                            (affectingPathChecks != null ? affectingPathChecks : affectingPathChecks = /* @__PURE__ */ new Set()).add(path);
                        if (watcher.files)
                            (affectingPathChecksForFile != null ? affectingPathChecksForFile : affectingPathChecksForFile = /* @__PURE__ */ new Set()).add(path);
                        packageJsonMap == null ? void 0 : packageJsonMap.delete(resolutionHost.toPath(path));
                    });
                    resolutionHost.scheduleInvalidateResolutionsOfFailedLookupLocations();
                }) : noopFileWatcher;
                const watcher = {
                    watcher: actualWatcher !== noopFileWatcher ? {
                        close: () => {
                            actualWatcher.close();
                            actualWatcher = noopFileWatcher;
                        }
                    } : actualWatcher,
                    resolutions: forResolution ? 1 : 0,
                    files: forResolution ? 0 : 1,
                    paths
                };
                fileWatchesOfAffectingLocations.set(locationToWatch, watcher);
                if (affectingLocation !== locationToWatch) {
                    fileWatchesOfAffectingLocations.set(affectingLocation, watcher);
                    paths.add(affectingLocation);
                }
            }
            function watchFailedLookupLocationOfNonRelativeModuleResolutions(resolutions, name) {
                const program = resolutionHost.getCurrentProgram();
                if (!program || !program.getTypeChecker().tryFindAmbientModuleWithoutAugmentations(name)) {
                    resolutions.forEach(watchFailedLookupLocationOfResolution);
                }
                else {
                    resolutions.forEach((resolution) => watchAffectingLocationsOfResolution(resolution, 
                    /*addToResolutionWithOnlyAffectingLocations*/
                    true));
                }
            }
            function setDirectoryWatcher(dir, dirPath, nonRecursive) {
                const dirWatcher = directoryWatchesOfFailedLookups.get(dirPath);
                if (dirWatcher) {
                    Debug.assert(!!nonRecursive === !!dirWatcher.nonRecursive);
                    dirWatcher.refCount++;
                }
                else {
                    directoryWatchesOfFailedLookups.set(dirPath, { watcher: createDirectoryWatcher(dir, dirPath, nonRecursive), refCount: 1, nonRecursive });
                }
            }
            function stopWatchFailedLookupLocationOfResolution(resolution, filePath, getResolutionWithResolvedFileName) {
                Debug.checkDefined(resolution.files).delete(filePath);
                resolution.refCount--;
                if (resolution.refCount) {
                    return;
                }
                const resolved = getResolutionWithResolvedFileName(resolution);
                if (resolved && resolved.resolvedFileName) {
                    const key = resolutionHost.toPath(resolved.resolvedFileName);
                    const resolutions = resolvedFileToResolution.get(key);
                    if ((resolutions == null ? void 0 : resolutions.delete(resolution)) && !resolutions.size)
                        resolvedFileToResolution.delete(key);
                }
                const { failedLookupLocations, affectingLocations } = resolution;
                if (resolutionsWithFailedLookups.delete(resolution)) {
                    let removeAtRoot = false;
                    for (const failedLookupLocation of failedLookupLocations) {
                        const failedLookupLocationPath = resolutionHost.toPath(failedLookupLocation);
                        const toWatch = getDirectoryToWatchFailedLookupLocation(failedLookupLocation, failedLookupLocationPath);
                        if (toWatch) {
                            const { dirPath } = toWatch;
                            const refCount = customFailedLookupPaths.get(failedLookupLocationPath);
                            if (refCount) {
                                if (refCount === 1) {
                                    customFailedLookupPaths.delete(failedLookupLocationPath);
                                }
                                else {
                                    Debug.assert(refCount > 1);
                                    customFailedLookupPaths.set(failedLookupLocationPath, refCount - 1);
                                }
                            }
                            if (dirPath === rootPath) {
                                removeAtRoot = true;
                            }
                            else {
                                removeDirectoryWatcher(dirPath);
                            }
                        }
                    }
                    if (removeAtRoot) {
                        removeDirectoryWatcher(rootPath);
                    }
                }
                else if (affectingLocations == null ? void 0 : affectingLocations.length) {
                    resolutionsWithOnlyAffectingLocations.delete(resolution);
                }
                if (affectingLocations) {
                    for (const affectingLocation of affectingLocations) {
                        const watcher = fileWatchesOfAffectingLocations.get(affectingLocation);
                        watcher.resolutions--;
                    }
                }
            }
            function removeDirectoryWatcher(dirPath) {
                const dirWatcher = directoryWatchesOfFailedLookups.get(dirPath);
                dirWatcher.refCount--;
            }
            function createDirectoryWatcher(directory, dirPath, nonRecursive) {
                return resolutionHost.watchDirectoryOfFailedLookupLocation(directory, (fileOrDirectory) => {
                    const fileOrDirectoryPath = resolutionHost.toPath(fileOrDirectory);
                    if (cachedDirectoryStructureHost) {
                        cachedDirectoryStructureHost.addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath);
                    }
                    scheduleInvalidateResolutionOfFailedLookupLocation(fileOrDirectoryPath, dirPath === fileOrDirectoryPath);
                }, nonRecursive ? 0 /* None */ : 1 /* Recursive */);
            }
            function removeResolutionsOfFileFromCache(cache, filePath, getResolutionWithResolvedFileName) {
                const resolutions = cache.get(filePath);
                if (resolutions) {
                    resolutions.forEach((resolution) => stopWatchFailedLookupLocationOfResolution(resolution, filePath, getResolutionWithResolvedFileName));
                    cache.delete(filePath);
                }
            }
            function removeResolutionsFromProjectReferenceRedirects(filePath) {
                if (!fileExtensionIs(filePath, ".json" /* Json */))
                    return;
                const program = resolutionHost.getCurrentProgram();
                if (!program)
                    return;
                const resolvedProjectReference = program.getResolvedProjectReferenceByPath(filePath);
                if (!resolvedProjectReference)
                    return;
                resolvedProjectReference.commandLine.fileNames.forEach((f) => removeResolutionsOfFile(resolutionHost.toPath(f)));
            }
            function removeResolutionsOfFile(filePath) {
                removeResolutionsOfFileFromCache(resolvedModuleNames, filePath, getResolvedModule2);
                removeResolutionsOfFileFromCache(resolvedTypeReferenceDirectives, filePath, getResolvedTypeReferenceDirective2);
            }
            function invalidateResolutions(resolutions, canInvalidate) {
                if (!resolutions)
                    return false;
                let invalidated = false;
                resolutions.forEach((resolution) => {
                    if (resolution.isInvalidated || !canInvalidate(resolution))
                        return;
                    resolution.isInvalidated = invalidated = true;
                    for (const containingFilePath of Debug.checkDefined(resolution.files)) {
                        (filesWithInvalidatedResolutions != null ? filesWithInvalidatedResolutions : filesWithInvalidatedResolutions = /* @__PURE__ */ new Set()).add(containingFilePath);
                        hasChangedAutomaticTypeDirectiveNames = hasChangedAutomaticTypeDirectiveNames || endsWith(containingFilePath, inferredTypesContainingFile);
                    }
                });
                return invalidated;
            }
            function invalidateResolutionOfFile(filePath) {
                removeResolutionsOfFile(filePath);
                const prevHasChangedAutomaticTypeDirectiveNames = hasChangedAutomaticTypeDirectiveNames;
                if (invalidateResolutions(resolvedFileToResolution.get(filePath), returnTrue) && hasChangedAutomaticTypeDirectiveNames && !prevHasChangedAutomaticTypeDirectiveNames) {
                    resolutionHost.onChangedAutomaticTypeDirectiveNames();
                }
            }
            function setFilesWithInvalidatedNonRelativeUnresolvedImports(filesMap) {
                Debug.assert(filesWithInvalidatedNonRelativeUnresolvedImports === filesMap || filesWithInvalidatedNonRelativeUnresolvedImports === void 0);
                filesWithInvalidatedNonRelativeUnresolvedImports = filesMap;
            }
            function scheduleInvalidateResolutionOfFailedLookupLocation(fileOrDirectoryPath, isCreatingWatchedDirectory) {
                if (isCreatingWatchedDirectory) {
                    (isInDirectoryChecks || (isInDirectoryChecks = /* @__PURE__ */ new Set())).add(fileOrDirectoryPath);
                }
                else {
                    const updatedPath = removeIgnoredPath(fileOrDirectoryPath);
                    if (!updatedPath)
                        return false;
                    fileOrDirectoryPath = updatedPath;
                    if (resolutionHost.fileIsOpen(fileOrDirectoryPath)) {
                        return false;
                    }
                    const dirOfFileOrDirectory = getDirectoryPath(fileOrDirectoryPath);
                    if (isNodeModulesAtTypesDirectory(fileOrDirectoryPath) || isNodeModulesDirectory(fileOrDirectoryPath) || isNodeModulesAtTypesDirectory(dirOfFileOrDirectory) || isNodeModulesDirectory(dirOfFileOrDirectory)) {
                        (failedLookupChecks || (failedLookupChecks = /* @__PURE__ */ new Set())).add(fileOrDirectoryPath);
                        (startsWithPathChecks || (startsWithPathChecks = /* @__PURE__ */ new Set())).add(fileOrDirectoryPath);
                    }
                    else {
                        if (!isPathWithDefaultFailedLookupExtension(fileOrDirectoryPath) && !customFailedLookupPaths.has(fileOrDirectoryPath)) {
                            return false;
                        }
                        if (isEmittedFileOfProgram(resolutionHost.getCurrentProgram(), fileOrDirectoryPath)) {
                            return false;
                        }
                        (failedLookupChecks || (failedLookupChecks = /* @__PURE__ */ new Set())).add(fileOrDirectoryPath);
                        const packagePath = parseNodeModuleFromPath(fileOrDirectoryPath);
                        if (packagePath)
                            (startsWithPathChecks || (startsWithPathChecks = /* @__PURE__ */ new Set())).add(packagePath);
                    }
                }
                resolutionHost.scheduleInvalidateResolutionsOfFailedLookupLocations();
            }
            function invalidateResolutionsOfFailedLookupLocations() {
                var _a2;
                let invalidated = false;
                if (affectingPathChecksForFile) {
                    (_a2 = resolutionHost.getCurrentProgram()) == null ? void 0 : _a2.getSourceFiles().forEach((f) => {
                        if (some(f.packageJsonLocations, (location) => affectingPathChecksForFile.has(location))) {
                            (filesWithInvalidatedResolutions != null ? filesWithInvalidatedResolutions : filesWithInvalidatedResolutions = /* @__PURE__ */ new Set()).add(f.path);
                            invalidated = true;
                        }
                    });
                    affectingPathChecksForFile = void 0;
                }
                if (!failedLookupChecks && !startsWithPathChecks && !isInDirectoryChecks && !affectingPathChecks) {
                    return invalidated;
                }
                invalidated = invalidateResolutions(resolutionsWithFailedLookups, canInvalidateFailedLookupResolution) || invalidated;
                const packageJsonMap = moduleResolutionCache.getPackageJsonInfoCache().getInternalMap();
                if (packageJsonMap && (failedLookupChecks || startsWithPathChecks || isInDirectoryChecks)) {
                    packageJsonMap.forEach((_value, path) => isInvalidatedFailedLookup(path) ? packageJsonMap.delete(path) : void 0);
                }
                failedLookupChecks = void 0;
                startsWithPathChecks = void 0;
                isInDirectoryChecks = void 0;
                invalidated = invalidateResolutions(resolutionsWithOnlyAffectingLocations, canInvalidatedFailedLookupResolutionWithAffectingLocation) || invalidated;
                affectingPathChecks = void 0;
                return invalidated;
            }
            function canInvalidateFailedLookupResolution(resolution) {
                var _a2;
                if (canInvalidatedFailedLookupResolutionWithAffectingLocation(resolution))
                    return true;
                if (!failedLookupChecks && !startsWithPathChecks && !isInDirectoryChecks)
                    return false;
                return (_a2 = resolution.failedLookupLocations) == null ? void 0 : _a2.some((location) => isInvalidatedFailedLookup(resolutionHost.toPath(location)));
            }
            function isInvalidatedFailedLookup(locationPath) {
                return (failedLookupChecks == null ? void 0 : failedLookupChecks.has(locationPath)) || firstDefinedIterator((startsWithPathChecks == null ? void 0 : startsWithPathChecks.keys()) || [], (fileOrDirectoryPath) => startsWith(locationPath, fileOrDirectoryPath) ? true : void 0) || firstDefinedIterator((isInDirectoryChecks == null ? void 0 : isInDirectoryChecks.keys()) || [], (fileOrDirectoryPath) => isInDirectoryPath(fileOrDirectoryPath, locationPath) ? true : void 0);
            }
            function canInvalidatedFailedLookupResolutionWithAffectingLocation(resolution) {
                var _a2;
                return !!affectingPathChecks && ((_a2 = resolution.affectingLocations) == null ? void 0 : _a2.some((location) => affectingPathChecks.has(location)));
            }
            function closeTypeRootsWatch() {
                clearMap(typeRootsWatches, closeFileWatcher);
            }
            function getDirectoryToWatchFailedLookupLocationFromTypeRoot(typeRoot, typeRootPath) {
                if (isInDirectoryPath(rootPath, typeRootPath)) {
                    return rootPath;
                }
                const toWatch = getDirectoryToWatchFromFailedLookupLocationDirectory(typeRoot, typeRootPath);
                return toWatch && directoryWatchesOfFailedLookups.has(toWatch.dirPath) ? toWatch.dirPath : void 0;
            }
            function createTypeRootsWatch(typeRootPath, typeRoot) {
                return resolutionHost.watchTypeRootsDirectory(typeRoot, (fileOrDirectory) => {
                    const fileOrDirectoryPath = resolutionHost.toPath(fileOrDirectory);
                    if (cachedDirectoryStructureHost) {
                        cachedDirectoryStructureHost.addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath);
                    }
                    hasChangedAutomaticTypeDirectiveNames = true;
                    resolutionHost.onChangedAutomaticTypeDirectiveNames();
                    const dirPath = getDirectoryToWatchFailedLookupLocationFromTypeRoot(typeRoot, typeRootPath);
                    if (dirPath) {
                        scheduleInvalidateResolutionOfFailedLookupLocation(fileOrDirectoryPath, dirPath === fileOrDirectoryPath);
                    }
                }, 1 /* Recursive */);
            }
            function updateTypeRootsWatch() {
                const options = resolutionHost.getCompilationSettings();
                if (options.types) {
                    closeTypeRootsWatch();
                    return;
                }
                const typeRoots = getEffectiveTypeRoots(options, { directoryExists: directoryExistsForTypeRootWatch, getCurrentDirectory });
                if (typeRoots) {
                    mutateMap(typeRootsWatches, arrayToMap(typeRoots, (tr) => resolutionHost.toPath(tr)), {
                        createNewValue: createTypeRootsWatch,
                        onDeleteValue: closeFileWatcher
                    });
                }
                else {
                    closeTypeRootsWatch();
                }
            }
            function directoryExistsForTypeRootWatch(nodeTypesDirectory) {
                const dir = getDirectoryPath(getDirectoryPath(nodeTypesDirectory));
                const dirPath = resolutionHost.toPath(dir);
                return dirPath === rootPath || canWatchDirectoryOrFile(dirPath);
            }
        }
        function resolutionIsSymlink(resolution) {
            var _a2, _b;
            return !!(((_a2 = resolution.resolvedModule) == null ? void 0 : _a2.originalPath) || ((_b = resolution.resolvedTypeReferenceDirective) == null ? void 0 : _b.originalPath));
        }
        var init_resolutionCache = __esm({
            "src/compiler/resolutionCache.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
            }
        });
        // src/compiler/watch.ts
        function createDiagnosticReporter(system, pretty) {
            const host = system === sys && sysFormatDiagnosticsHost ? sysFormatDiagnosticsHost : {
                getCurrentDirectory: () => system.getCurrentDirectory(),
                getNewLine: () => system.newLine,
                getCanonicalFileName: createGetCanonicalFileName(system.useCaseSensitiveFileNames)
            };
            if (!pretty) {
                return (diagnostic) => system.write(formatDiagnostic(diagnostic, host));
            }
            const diagnostics = new Array(1);
            return (diagnostic) => {
                diagnostics[0] = diagnostic;
                system.write(formatDiagnosticsWithColorAndContext(diagnostics, host) + host.getNewLine());
                diagnostics[0] = void 0;
            };
        }
        function clearScreenIfNotWatchingForFileChanges(system, diagnostic, options) {
            if (system.clearScreen && !options.preserveWatchOutput && !options.extendedDiagnostics && !options.diagnostics && contains(screenStartingMessageCodes, diagnostic.code)) {
                system.clearScreen();
                return true;
            }
            return false;
        }
        function getPlainDiagnosticFollowingNewLines(diagnostic, newLine) {
            return contains(screenStartingMessageCodes, diagnostic.code) ? newLine + newLine : newLine;
        }
        function getLocaleTimeString(system) {
            return !system.now ? ( /* @__PURE__ */new Date()).toLocaleTimeString() : (
            // On some systems / builds of Node, there's a non-breaking space between the time and AM/PM.
            // This branch is solely for testing, so just switch it to a normal space for baseline stability.
            // See:
            //     - https://github.com/nodejs/node/issues/45171
            //     - https://github.com/nodejs/node/issues/45753
            system.now().toLocaleTimeString("en-US", { timeZone: "UTC" }).replace("\u202F", " "));
        }
        function createWatchStatusReporter(system, pretty) {
            return pretty ? (diagnostic, newLine, options) => {
                clearScreenIfNotWatchingForFileChanges(system, diagnostic, options);
                let output = `[${formatColorAndReset(getLocaleTimeString(system), "\x1B[90m" /* Grey */)}] `;
                output += `${flattenDiagnosticMessageText(diagnostic.messageText, system.newLine)}${newLine + newLine}`;
                system.write(output);
            } : (diagnostic, newLine, options) => {
                let output = "";
                if (!clearScreenIfNotWatchingForFileChanges(system, diagnostic, options)) {
                    output += newLine;
                }
                output += `${getLocaleTimeString(system)} - `;
                output += `${flattenDiagnosticMessageText(diagnostic.messageText, system.newLine)}${getPlainDiagnosticFollowingNewLines(diagnostic, newLine)}`;
                system.write(output);
            };
        }
        function parseConfigFileWithSystem(configFileName, optionsToExtend, extendedConfigCache, watchOptionsToExtend, system, reportDiagnostic) {
            const host = system;
            host.onUnRecoverableConfigFileDiagnostic = (diagnostic) => reportUnrecoverableDiagnostic(system, reportDiagnostic, diagnostic);
            const result = getParsedCommandLineOfConfigFile(configFileName, optionsToExtend, host, extendedConfigCache, watchOptionsToExtend);
            host.onUnRecoverableConfigFileDiagnostic = void 0;
            return result;
        }
        function getErrorCountForSummary(diagnostics) {
            return countWhere(diagnostics, (diagnostic) => diagnostic.category === 1 /* Error */);
        }
        function getFilesInErrorForSummary(diagnostics) {
            const filesInError = filter(diagnostics, (diagnostic) => diagnostic.category === 1 /* Error */).map((errorDiagnostic) => {
                if (errorDiagnostic.file === void 0)
                    return;
                return `${errorDiagnostic.file.fileName}`;
            });
            return filesInError.map((fileName) => {
                if (fileName === void 0) {
                    return void 0;
                }
                const diagnosticForFileName = find(diagnostics, (diagnostic) => diagnostic.file !== void 0 && diagnostic.file.fileName === fileName);
                if (diagnosticForFileName !== void 0) {
                    const { line } = getLineAndCharacterOfPosition(diagnosticForFileName.file, diagnosticForFileName.start);
                    return {
                        fileName,
                        line: line + 1
                    };
                }
            });
        }
        function getWatchErrorSummaryDiagnosticMessage(errorCount) {
            return errorCount === 1 ? Diagnostics.Found_1_error_Watching_for_file_changes : Diagnostics.Found_0_errors_Watching_for_file_changes;
        }
        function prettyPathForFileError(error, cwd) {
            const line = formatColorAndReset(":" + error.line, "\x1B[90m" /* Grey */);
            if (pathIsAbsolute(error.fileName) && pathIsAbsolute(cwd)) {
                return getRelativePathFromDirectory(cwd, error.fileName, 
                /* ignoreCase */
                false) + line;
            }
            return error.fileName + line;
        }
        function getErrorSummaryText(errorCount, filesInError, newLine, host) {
            if (errorCount === 0)
                return "";
            const nonNilFiles = filesInError.filter((fileInError) => fileInError !== void 0);
            const distinctFileNamesWithLines = nonNilFiles.map((fileInError) => `${fileInError.fileName}:${fileInError.line}`).filter((value, index, self) => self.indexOf(value) === index);
            const firstFileReference = nonNilFiles[0] && prettyPathForFileError(nonNilFiles[0], host.getCurrentDirectory());
            const d = errorCount === 1 ? createCompilerDiagnostic(filesInError[0] !== void 0 ? Diagnostics.Found_1_error_in_1 : Diagnostics.Found_1_error, errorCount, firstFileReference) : createCompilerDiagnostic(distinctFileNamesWithLines.length === 0 ? Diagnostics.Found_0_errors : distinctFileNamesWithLines.length === 1 ? Diagnostics.Found_0_errors_in_the_same_file_starting_at_Colon_1 : Diagnostics.Found_0_errors_in_1_files, errorCount, distinctFileNamesWithLines.length === 1 ? firstFileReference : distinctFileNamesWithLines.length);
            const suffix = distinctFileNamesWithLines.length > 1 ? createTabularErrorsDisplay(nonNilFiles, host) : "";
            return `${newLine}${flattenDiagnosticMessageText(d.messageText, newLine)}${newLine}${newLine}${suffix}`;
        }
        function createTabularErrorsDisplay(filesInError, host) {
            const distinctFiles = filesInError.filter((value, index, self) => index === self.findIndex((file) => (file == null ? void 0 : file.fileName) === (value == null ? void 0 : value.fileName)));
            if (distinctFiles.length === 0)
                return "";
            const numberLength = (num) => Math.log(num) * Math.LOG10E + 1;
            const fileToErrorCount = distinctFiles.map((file) => [file, countWhere(filesInError, (fileInError) => fileInError.fileName === file.fileName)]);
            const maxErrors = fileToErrorCount.reduce((acc, value) => Math.max(acc, value[1] || 0), 0);
            const headerRow = Diagnostics.Errors_Files.message;
            const leftColumnHeadingLength = headerRow.split(" ")[0].length;
            const leftPaddingGoal = Math.max(leftColumnHeadingLength, numberLength(maxErrors));
            const headerPadding = Math.max(numberLength(maxErrors) - leftColumnHeadingLength, 0);
            let tabularData = "";
            tabularData += " ".repeat(headerPadding) + headerRow + "\n";
            fileToErrorCount.forEach((row) => {
                const [file, errorCount] = row;
                const errorCountDigitsLength = Math.log(errorCount) * Math.LOG10E + 1 | 0;
                const leftPadding = errorCountDigitsLength < leftPaddingGoal ? " ".repeat(leftPaddingGoal - errorCountDigitsLength) : "";
                const fileRef = prettyPathForFileError(file, host.getCurrentDirectory());
                tabularData += `${leftPadding}${errorCount}  ${fileRef}
`;
            });
            return tabularData;
        }
        function isBuilderProgram2(program) {
            return !!program.getState;
        }
        function listFiles(program, write) {
            const options = program.getCompilerOptions();
            if (options.explainFiles) {
                explainFiles(isBuilderProgram2(program) ? program.getProgram() : program, write);
            }
            else if (options.listFiles || options.listFilesOnly) {
                forEach(program.getSourceFiles(), (file) => {
                    write(file.fileName);
                });
            }
        }
        function explainFiles(program, write) {
            var _a2, _b;
            const reasons = program.getFileIncludeReasons();
            const relativeFileName = (fileName) => convertToRelativePath(fileName, program.getCurrentDirectory(), program.getCanonicalFileName);
            for (const file of program.getSourceFiles()) {
                write(`${toFileName(file, relativeFileName)}`);
                (_a2 = reasons.get(file.path)) == null ? void 0 : _a2.forEach((reason) => write(`  ${fileIncludeReasonToDiagnostics(program, reason, relativeFileName).messageText}`));
                (_b = explainIfFileIsRedirectAndImpliedFormat(file, relativeFileName)) == null ? void 0 : _b.forEach((d) => write(`  ${d.messageText}`));
            }
        }
        function explainIfFileIsRedirectAndImpliedFormat(file, fileNameConvertor) {
            var _a2;
            let result;
            if (file.path !== file.resolvedPath) {
                (result != null ? result : result = []).push(chainDiagnosticMessages(
                /*details*/
                void 0, Diagnostics.File_is_output_of_project_reference_source_0, toFileName(file.originalFileName, fileNameConvertor)));
            }
            if (file.redirectInfo) {
                (result != null ? result : result = []).push(chainDiagnosticMessages(
                /*details*/
                void 0, Diagnostics.File_redirects_to_file_0, toFileName(file.redirectInfo.redirectTarget, fileNameConvertor)));
            }
            if (isExternalOrCommonJsModule(file)) {
                switch (file.impliedNodeFormat) {
                    case 99 /* ESNext */:
                        if (file.packageJsonScope) {
                            (result != null ? result : result = []).push(chainDiagnosticMessages(
                            /*details*/
                            void 0, Diagnostics.File_is_ECMAScript_module_because_0_has_field_type_with_value_module, toFileName(last(file.packageJsonLocations), fileNameConvertor)));
                        }
                        break;
                    case 1 /* CommonJS */:
                        if (file.packageJsonScope) {
                            (result != null ? result : result = []).push(chainDiagnosticMessages(
                            /*details*/
                            void 0, file.packageJsonScope.contents.packageJsonContent.type ? Diagnostics.File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module : Diagnostics.File_is_CommonJS_module_because_0_does_not_have_field_type, toFileName(last(file.packageJsonLocations), fileNameConvertor)));
                        }
                        else if ((_a2 = file.packageJsonLocations) == null ? void 0 : _a2.length) {
                            (result != null ? result : result = []).push(chainDiagnosticMessages(
                            /*details*/
                            void 0, Diagnostics.File_is_CommonJS_module_because_package_json_was_not_found));
                        }
                        break;
                }
            }
            return result;
        }
        function getMatchedFileSpec(program, fileName) {
            var _a2;
            const configFile = program.getCompilerOptions().configFile;
            if (!((_a2 = configFile == null ? void 0 : configFile.configFileSpecs) == null ? void 0 : _a2.validatedFilesSpec))
                return void 0;
            const filePath = program.getCanonicalFileName(fileName);
            const basePath = getDirectoryPath(getNormalizedAbsolutePath(configFile.fileName, program.getCurrentDirectory()));
            return find(configFile.configFileSpecs.validatedFilesSpec, (fileSpec) => program.getCanonicalFileName(getNormalizedAbsolutePath(fileSpec, basePath)) === filePath);
        }
        function getMatchedIncludeSpec(program, fileName) {
            var _a2, _b;
            const configFile = program.getCompilerOptions().configFile;
            if (!((_a2 = configFile == null ? void 0 : configFile.configFileSpecs) == null ? void 0 : _a2.validatedIncludeSpecs))
                return void 0;
            if (configFile.configFileSpecs.isDefaultIncludeSpec)
                return true;
            const isJsonFile = fileExtensionIs(fileName, ".json" /* Json */);
            const basePath = getDirectoryPath(getNormalizedAbsolutePath(configFile.fileName, program.getCurrentDirectory()));
            const useCaseSensitiveFileNames = program.useCaseSensitiveFileNames();
            return find((_b = configFile == null ? void 0 : configFile.configFileSpecs) == null ? void 0 : _b.validatedIncludeSpecs, (includeSpec) => {
                if (isJsonFile && !endsWith(includeSpec, ".json" /* Json */))
                    return false;
                const pattern = getPatternFromSpec(includeSpec, basePath, "files");
                return !!pattern && getRegexFromPattern(`(${pattern})$`, useCaseSensitiveFileNames).test(fileName);
            });
        }
        function fileIncludeReasonToDiagnostics(program, reason, fileNameConvertor) {
            var _a2, _b;
            const options = program.getCompilerOptions();
            if (isReferencedFile(reason)) {
                const referenceLocation = getReferencedFileLocation((path) => program.getSourceFileByPath(path), reason);
                const referenceText = isReferenceFileLocation(referenceLocation) ? referenceLocation.file.text.substring(referenceLocation.pos, referenceLocation.end) : `"${referenceLocation.text}"`;
                let message;
                Debug.assert(isReferenceFileLocation(referenceLocation) || reason.kind === 3 /* Import */, "Only synthetic references are imports");
                switch (reason.kind) {
                    case 3 /* Import */:
                        if (isReferenceFileLocation(referenceLocation)) {
                            message = referenceLocation.packageId ? Diagnostics.Imported_via_0_from_file_1_with_packageId_2 : Diagnostics.Imported_via_0_from_file_1;
                        }
                        else if (referenceLocation.text === externalHelpersModuleNameText) {
                            message = referenceLocation.packageId ? Diagnostics.Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions : Diagnostics.Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions;
                        }
                        else {
                            message = referenceLocation.packageId ? Diagnostics.Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions : Diagnostics.Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions;
                        }
                        break;
                    case 4 /* ReferenceFile */:
                        Debug.assert(!referenceLocation.packageId);
                        message = Diagnostics.Referenced_via_0_from_file_1;
                        break;
                    case 5 /* TypeReferenceDirective */:
                        message = referenceLocation.packageId ? Diagnostics.Type_library_referenced_via_0_from_file_1_with_packageId_2 : Diagnostics.Type_library_referenced_via_0_from_file_1;
                        break;
                    case 7 /* LibReferenceDirective */:
                        Debug.assert(!referenceLocation.packageId);
                        message = Diagnostics.Library_referenced_via_0_from_file_1;
                        break;
                    default:
                        Debug.assertNever(reason);
                }
                return chainDiagnosticMessages(
                /*details*/
                void 0, message, referenceText, toFileName(referenceLocation.file, fileNameConvertor), referenceLocation.packageId && packageIdToString(referenceLocation.packageId));
            }
            switch (reason.kind) {
                case 0 /* RootFile */:
                    if (!((_a2 = options.configFile) == null ? void 0 : _a2.configFileSpecs))
                        return chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Root_file_specified_for_compilation);
                    const fileName = getNormalizedAbsolutePath(program.getRootFileNames()[reason.index], program.getCurrentDirectory());
                    const matchedByFiles = getMatchedFileSpec(program, fileName);
                    if (matchedByFiles)
                        return chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Part_of_files_list_in_tsconfig_json);
                    const matchedByInclude = getMatchedIncludeSpec(program, fileName);
                    return isString(matchedByInclude) ? chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics.Matched_by_include_pattern_0_in_1, matchedByInclude, toFileName(options.configFile, fileNameConvertor)) : (
                    // Could be additional files specified as roots or matched by default include
                    chainDiagnosticMessages(
                    /*details*/
                    void 0, matchedByInclude ? Diagnostics.Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk : Diagnostics.Root_file_specified_for_compilation));
                case 1 /* SourceFromProjectReference */:
                case 2 /* OutputFromProjectReference */:
                    const isOutput = reason.kind === 2 /* OutputFromProjectReference */;
                    const referencedResolvedRef = Debug.checkDefined((_b = program.getResolvedProjectReferences()) == null ? void 0 : _b[reason.index]);
                    return chainDiagnosticMessages(
                    /*details*/
                    void 0, outFile(options) ? isOutput ? Diagnostics.Output_from_referenced_project_0_included_because_1_specified : Diagnostics.Source_from_referenced_project_0_included_because_1_specified : isOutput ? Diagnostics.Output_from_referenced_project_0_included_because_module_is_specified_as_none : Diagnostics.Source_from_referenced_project_0_included_because_module_is_specified_as_none, toFileName(referencedResolvedRef.sourceFile.fileName, fileNameConvertor), options.outFile ? "--outFile" : "--out");
                case 8 /* AutomaticTypeDirectiveFile */:
                    return chainDiagnosticMessages(
                    /*details*/
                    void 0, options.types ? reason.packageId ? Diagnostics.Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1 : Diagnostics.Entry_point_of_type_library_0_specified_in_compilerOptions : reason.packageId ? Diagnostics.Entry_point_for_implicit_type_library_0_with_packageId_1 : Diagnostics.Entry_point_for_implicit_type_library_0, reason.typeReference, reason.packageId && packageIdToString(reason.packageId));
                case 6 /* LibFile */:
                    if (reason.index !== void 0)
                        return chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Library_0_specified_in_compilerOptions, options.lib[reason.index]);
                    const target = forEachEntry(targetOptionDeclaration.type, (value, key) => value === getEmitScriptTarget(options) ? key : void 0);
                    return chainDiagnosticMessages(
                    /*details*/
                    void 0, target ? Diagnostics.Default_library_for_target_0 : Diagnostics.Default_library, target);
                default:
                    Debug.assertNever(reason);
            }
        }
        function toFileName(file, fileNameConvertor) {
            const fileName = isString(file) ? file : file.fileName;
            return fileNameConvertor ? fileNameConvertor(fileName) : fileName;
        }
        function emitFilesAndReportErrors(program, reportDiagnostic, write, reportSummary, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) {
            const isListFilesOnly = !!program.getCompilerOptions().listFilesOnly;
            const allDiagnostics = program.getConfigFileParsingDiagnostics().slice();
            const configFileParsingDiagnosticsLength = allDiagnostics.length;
            addRange(allDiagnostics, program.getSyntacticDiagnostics(
            /*sourceFile*/
            void 0, cancellationToken));
            if (allDiagnostics.length === configFileParsingDiagnosticsLength) {
                addRange(allDiagnostics, program.getOptionsDiagnostics(cancellationToken));
                if (!isListFilesOnly) {
                    addRange(allDiagnostics, program.getGlobalDiagnostics(cancellationToken));
                    if (allDiagnostics.length === configFileParsingDiagnosticsLength) {
                        addRange(allDiagnostics, program.getSemanticDiagnostics(
                        /*sourceFile*/
                        void 0, cancellationToken));
                    }
                }
            }
            const emitResult = isListFilesOnly ? { emitSkipped: true, diagnostics: emptyArray } : program.emit(
            /*targetSourceFile*/
            void 0, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers);
            const { emittedFiles, diagnostics: emitDiagnostics } = emitResult;
            addRange(allDiagnostics, emitDiagnostics);
            const diagnostics = sortAndDeduplicateDiagnostics(allDiagnostics);
            diagnostics.forEach(reportDiagnostic);
            if (write) {
                const currentDir = program.getCurrentDirectory();
                forEach(emittedFiles, (file) => {
                    const filepath = getNormalizedAbsolutePath(file, currentDir);
                    write(`TSFILE: ${filepath}`);
                });
                listFiles(program, write);
            }
            if (reportSummary) {
                reportSummary(getErrorCountForSummary(diagnostics), getFilesInErrorForSummary(diagnostics));
            }
            return {
                emitResult,
                diagnostics
            };
        }
        function emitFilesAndReportErrorsAndGetExitStatus(program, reportDiagnostic, write, reportSummary, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) {
            const { emitResult, diagnostics } = emitFilesAndReportErrors(program, reportDiagnostic, write, reportSummary, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers);
            if (emitResult.emitSkipped && diagnostics.length > 0) {
                return 1 /* DiagnosticsPresent_OutputsSkipped */;
            }
            else if (diagnostics.length > 0) {
                return 2 /* DiagnosticsPresent_OutputsGenerated */;
            }
            return 0 /* Success */;
        }
        function createWatchHost(system = sys, reportWatchStatus2) {
            const onWatchStatusChange = reportWatchStatus2 || createWatchStatusReporter(system);
            return {
                onWatchStatusChange,
                watchFile: maybeBind(system, system.watchFile) || returnNoopFileWatcher,
                watchDirectory: maybeBind(system, system.watchDirectory) || returnNoopFileWatcher,
                setTimeout: maybeBind(system, system.setTimeout) || noop,
                clearTimeout: maybeBind(system, system.clearTimeout) || noop
            };
        }
        function createWatchFactory(host, options) {
            const watchLogLevel = host.trace ? options.extendedDiagnostics ? 2 /* Verbose */ : options.diagnostics ? 1 /* TriggerOnly */ : 0 /* None */ : 0 /* None */;
            const writeLog = watchLogLevel !== 0 /* None */ ? (s) => host.trace(s) : noop;
            const result = getWatchFactory(host, watchLogLevel, writeLog);
            result.writeLog = writeLog;
            return result;
        }
        function createCompilerHostFromProgramHost(host, getCompilerOptions, directoryStructureHost = host) {
            const useCaseSensitiveFileNames = host.useCaseSensitiveFileNames();
            const compilerHost = {
                getSourceFile: createGetSourceFile((fileName, encoding) => !encoding ? compilerHost.readFile(fileName) : host.readFile(fileName, encoding), getCompilerOptions, 
                /*setParentNodes*/
                void 0),
                getDefaultLibLocation: maybeBind(host, host.getDefaultLibLocation),
                getDefaultLibFileName: (options) => host.getDefaultLibFileName(options),
                writeFile: createWriteFileMeasuringIO((path, data, writeByteOrderMark) => host.writeFile(path, data, writeByteOrderMark), (path) => host.createDirectory(path), (path) => host.directoryExists(path)),
                getCurrentDirectory: memoize(() => host.getCurrentDirectory()),
                useCaseSensitiveFileNames: () => useCaseSensitiveFileNames,
                getCanonicalFileName: createGetCanonicalFileName(useCaseSensitiveFileNames),
                getNewLine: () => getNewLineCharacter(getCompilerOptions()),
                fileExists: (f) => host.fileExists(f),
                readFile: (f) => host.readFile(f),
                trace: maybeBind(host, host.trace),
                directoryExists: maybeBind(directoryStructureHost, directoryStructureHost.directoryExists),
                getDirectories: maybeBind(directoryStructureHost, directoryStructureHost.getDirectories),
                realpath: maybeBind(host, host.realpath),
                getEnvironmentVariable: maybeBind(host, host.getEnvironmentVariable) || (() => ""),
                createHash: maybeBind(host, host.createHash),
                readDirectory: maybeBind(host, host.readDirectory),
                storeFilesChangingSignatureDuringEmit: host.storeFilesChangingSignatureDuringEmit
            };
            return compilerHost;
        }
        function getSourceFileVersionAsHashFromText(host, text) {
            if (text.match(sourceMapCommentRegExpDontCareLineStart)) {
                let lineEnd = text.length;
                let lineStart = lineEnd;
                for (let pos = lineEnd - 1; pos >= 0; pos--) {
                    const ch = text.charCodeAt(pos);
                    switch (ch) {
                        case 10 /* lineFeed */:
                            if (pos && text.charCodeAt(pos - 1) === 13 /* carriageReturn */) {
                                pos--;
                            }
                        case 13 /* carriageReturn */:
                            break;
                        default:
                            if (ch < 127 /* maxAsciiCharacter */ || !isLineBreak(ch)) {
                                lineStart = pos;
                                continue;
                            }
                            break;
                    }
                    const line = text.substring(lineStart, lineEnd);
                    if (line.match(sourceMapCommentRegExp)) {
                        text = text.substring(0, lineStart);
                        break;
                    }
                    else if (!line.match(whitespaceOrMapCommentRegExp)) {
                        break;
                    }
                    lineEnd = lineStart;
                }
            }
            return (host.createHash || generateDjb2Hash)(text);
        }
        function setGetSourceFileAsHashVersioned(compilerHost) {
            const originalGetSourceFile = compilerHost.getSourceFile;
            compilerHost.getSourceFile = (...args) => {
                const result = originalGetSourceFile.call(compilerHost, ...args);
                if (result) {
                    result.version = getSourceFileVersionAsHashFromText(compilerHost, result.text);
                }
                return result;
            };
        }
        function createProgramHost(system, createProgram2) {
            const getDefaultLibLocation = memoize(() => getDirectoryPath(normalizePath(system.getExecutingFilePath())));
            return {
                useCaseSensitiveFileNames: () => system.useCaseSensitiveFileNames,
                getNewLine: () => system.newLine,
                getCurrentDirectory: memoize(() => system.getCurrentDirectory()),
                getDefaultLibLocation,
                getDefaultLibFileName: (options) => combinePaths(getDefaultLibLocation(), getDefaultLibFileName(options)),
                fileExists: (path) => system.fileExists(path),
                readFile: (path, encoding) => system.readFile(path, encoding),
                directoryExists: (path) => system.directoryExists(path),
                getDirectories: (path) => system.getDirectories(path),
                readDirectory: (path, extensions, exclude, include, depth) => system.readDirectory(path, extensions, exclude, include, depth),
                realpath: maybeBind(system, system.realpath),
                getEnvironmentVariable: maybeBind(system, system.getEnvironmentVariable),
                trace: (s) => system.write(s + system.newLine),
                createDirectory: (path) => system.createDirectory(path),
                writeFile: (path, data, writeByteOrderMark) => system.writeFile(path, data, writeByteOrderMark),
                createHash: maybeBind(system, system.createHash),
                createProgram: createProgram2 || createEmitAndSemanticDiagnosticsBuilderProgram,
                storeFilesChangingSignatureDuringEmit: system.storeFilesChangingSignatureDuringEmit,
                now: maybeBind(system, system.now)
            };
        }
        function createWatchCompilerHost(system = sys, createProgram2, reportDiagnostic, reportWatchStatus2) {
            const write = (s) => system.write(s + system.newLine);
            const result = createProgramHost(system, createProgram2);
            copyProperties(result, createWatchHost(system, reportWatchStatus2));
            result.afterProgramCreate = (builderProgram) => {
                const compilerOptions = builderProgram.getCompilerOptions();
                const newLine = getNewLineCharacter(compilerOptions);
                emitFilesAndReportErrors(builderProgram, reportDiagnostic, write, (errorCount) => result.onWatchStatusChange(createCompilerDiagnostic(getWatchErrorSummaryDiagnosticMessage(errorCount), errorCount), newLine, compilerOptions, errorCount));
            };
            return result;
        }
        function reportUnrecoverableDiagnostic(system, reportDiagnostic, diagnostic) {
            reportDiagnostic(diagnostic);
            system.exit(1 /* DiagnosticsPresent_OutputsSkipped */);
        }
        function createWatchCompilerHostOfConfigFile({ configFileName, optionsToExtend, watchOptionsToExtend, extraFileExtensions, system, createProgram: createProgram2, reportDiagnostic, reportWatchStatus: reportWatchStatus2 }) {
            const diagnosticReporter = reportDiagnostic || createDiagnosticReporter(system);
            const host = createWatchCompilerHost(system, createProgram2, diagnosticReporter, reportWatchStatus2);
            host.onUnRecoverableConfigFileDiagnostic = (diagnostic) => reportUnrecoverableDiagnostic(system, diagnosticReporter, diagnostic);
            host.configFileName = configFileName;
            host.optionsToExtend = optionsToExtend;
            host.watchOptionsToExtend = watchOptionsToExtend;
            host.extraFileExtensions = extraFileExtensions;
            return host;
        }
        function createWatchCompilerHostOfFilesAndCompilerOptions({ rootFiles, options, watchOptions, projectReferences, system, createProgram: createProgram2, reportDiagnostic, reportWatchStatus: reportWatchStatus2 }) {
            const host = createWatchCompilerHost(system, createProgram2, reportDiagnostic || createDiagnosticReporter(system), reportWatchStatus2);
            host.rootFiles = rootFiles;
            host.options = options;
            host.watchOptions = watchOptions;
            host.projectReferences = projectReferences;
            return host;
        }
        function performIncrementalCompilation(input) {
            const system = input.system || sys;
            const host = input.host || (input.host = createIncrementalCompilerHost(input.options, system));
            const builderProgram = createIncrementalProgram(input);
            const exitStatus = emitFilesAndReportErrorsAndGetExitStatus(builderProgram, input.reportDiagnostic || createDiagnosticReporter(system), (s) => host.trace && host.trace(s), input.reportErrorSummary || input.options.pretty ? (errorCount, filesInError) => system.write(getErrorSummaryText(errorCount, filesInError, system.newLine, host)) : void 0);
            if (input.afterProgramEmitAndDiagnostics)
                input.afterProgramEmitAndDiagnostics(builderProgram);
            return exitStatus;
        }
        var sysFormatDiagnosticsHost, screenStartingMessageCodes, noopFileWatcher, returnNoopFileWatcher, WatchType;
        var init_watch = __esm({
            "src/compiler/watch.ts"() {
                "use strict";
                init_ts2();
                sysFormatDiagnosticsHost = sys ? {
                    getCurrentDirectory: () => sys.getCurrentDirectory(),
                    getNewLine: () => sys.newLine,
                    getCanonicalFileName: createGetCanonicalFileName(sys.useCaseSensitiveFileNames)
                } : void 0;
                screenStartingMessageCodes = [
                    Diagnostics.Starting_compilation_in_watch_mode.code,
                    Diagnostics.File_change_detected_Starting_incremental_compilation.code
                ];
                noopFileWatcher = { close: noop };
                returnNoopFileWatcher = () => noopFileWatcher;
                WatchType = {
                    ConfigFile: "Config file",
                    ExtendedConfigFile: "Extended config file",
                    SourceFile: "Source file",
                    MissingFile: "Missing file",
                    WildcardDirectory: "Wild card directory",
                    FailedLookupLocations: "Failed Lookup Locations",
                    AffectingFileLocation: "File location affecting resolution",
                    TypeRoots: "Type roots",
                    ConfigFileOfReferencedProject: "Config file of referened project",
                    ExtendedConfigOfReferencedProject: "Extended config file of referenced project",
                    WildcardDirectoryOfReferencedProject: "Wild card directory of referenced project",
                    PackageJson: "package.json file",
                    ClosedScriptInfo: "Closed Script info",
                    ConfigFileForInferredRoot: "Config file for the inferred project root",
                    NodeModules: "node_modules for closed script infos and package.jsons affecting module specifier cache",
                    MissingSourceMapFile: "Missing source map file",
                    NoopConfigFileForInferredRoot: "Noop Config file for the inferred project root",
                    MissingGeneratedFile: "Missing generated file",
                    NodeModulesForModuleSpecifierCache: "node_modules for module specifier cache invalidation"
                };
            }
        });
        // src/compiler/watchPublic.ts
        function readBuilderProgram(compilerOptions, host) {
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(compilerOptions);
            if (!buildInfoPath)
                return void 0;
            let buildInfo;
            if (host.getBuildInfo) {
                buildInfo = host.getBuildInfo(buildInfoPath, compilerOptions.configFilePath);
            }
            else {
                const content = host.readFile(buildInfoPath);
                if (!content)
                    return void 0;
                buildInfo = getBuildInfo(buildInfoPath, content);
            }
            if (!buildInfo || buildInfo.version !== version || !buildInfo.program)
                return void 0;
            return createBuilderProgramUsingProgramBuildInfo(buildInfo, buildInfoPath, host);
        }
        function createIncrementalCompilerHost(options, system = sys) {
            const host = createCompilerHostWorker(options, 
            /*setParentNodes*/
            void 0, system);
            host.createHash = maybeBind(system, system.createHash);
            host.storeFilesChangingSignatureDuringEmit = system.storeFilesChangingSignatureDuringEmit;
            setGetSourceFileAsHashVersioned(host);
            changeCompilerHostLikeToUseCache(host, (fileName) => toPath(fileName, host.getCurrentDirectory(), host.getCanonicalFileName));
            return host;
        }
        function createIncrementalProgram({ rootNames, options, configFileParsingDiagnostics, projectReferences, host, createProgram: createProgram2 }) {
            host = host || createIncrementalCompilerHost(options);
            createProgram2 = createProgram2 || createEmitAndSemanticDiagnosticsBuilderProgram;
            const oldProgram = readBuilderProgram(options, host);
            return createProgram2(rootNames, options, host, oldProgram, configFileParsingDiagnostics, projectReferences);
        }
        function createWatchCompilerHost2(rootFilesOrConfigFileName, options, system, createProgram2, reportDiagnostic, reportWatchStatus2, projectReferencesOrWatchOptionsToExtend, watchOptionsOrExtraFileExtensions) {
            if (isArray(rootFilesOrConfigFileName)) {
                return createWatchCompilerHostOfFilesAndCompilerOptions({
                    rootFiles: rootFilesOrConfigFileName,
                    options,
                    watchOptions: watchOptionsOrExtraFileExtensions,
                    projectReferences: projectReferencesOrWatchOptionsToExtend,
                    system,
                    createProgram: createProgram2,
                    reportDiagnostic,
                    reportWatchStatus: reportWatchStatus2
                });
            }
            else {
                return createWatchCompilerHostOfConfigFile({
                    configFileName: rootFilesOrConfigFileName,
                    optionsToExtend: options,
                    watchOptionsToExtend: projectReferencesOrWatchOptionsToExtend,
                    extraFileExtensions: watchOptionsOrExtraFileExtensions,
                    system,
                    createProgram: createProgram2,
                    reportDiagnostic,
                    reportWatchStatus: reportWatchStatus2
                });
            }
        }
        function createWatchProgram(host) {
            let builderProgram;
            let reloadLevel;
            let missingFilesMap;
            let watchedWildcardDirectories;
            let timerToUpdateProgram;
            let timerToInvalidateFailedLookupResolutions;
            let parsedConfigs;
            let sharedExtendedConfigFileWatchers;
            let extendedConfigCache = host.extendedConfigCache;
            let reportFileChangeDetectedOnCreateProgram = false;
            const sourceFilesCache = /* @__PURE__ */ new Map();
            let missingFilePathsRequestedForRelease;
            let hasChangedCompilerOptions = false;
            const useCaseSensitiveFileNames = host.useCaseSensitiveFileNames();
            const currentDirectory = host.getCurrentDirectory();
            const { configFileName, optionsToExtend: optionsToExtendForConfigFile = {}, watchOptionsToExtend, extraFileExtensions, createProgram: createProgram2 } = host;
            let { rootFiles: rootFileNames, options: compilerOptions, watchOptions, projectReferences } = host;
            let wildcardDirectories;
            let configFileParsingDiagnostics;
            let canConfigFileJsonReportNoInputFiles = false;
            let hasChangedConfigFileParsingErrors = false;
            const cachedDirectoryStructureHost = configFileName === void 0 ? void 0 : createCachedDirectoryStructureHost(host, currentDirectory, useCaseSensitiveFileNames);
            const directoryStructureHost = cachedDirectoryStructureHost || host;
            const parseConfigFileHost = parseConfigHostFromCompilerHostLike(host, directoryStructureHost);
            let newLine = updateNewLine();
            if (configFileName && host.configFileParsingResult) {
                setConfigFileParsingResult(host.configFileParsingResult);
                newLine = updateNewLine();
            }
            reportWatchDiagnostic(Diagnostics.Starting_compilation_in_watch_mode);
            if (configFileName && !host.configFileParsingResult) {
                newLine = getNewLineCharacter(optionsToExtendForConfigFile);
                Debug.assert(!rootFileNames);
                parseConfigFile2();
                newLine = updateNewLine();
            }
            Debug.assert(compilerOptions);
            Debug.assert(rootFileNames);
            const { watchFile: watchFile2, watchDirectory, writeLog } = createWatchFactory(host, compilerOptions);
            const getCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames);
            writeLog(`Current directory: ${currentDirectory} CaseSensitiveFileNames: ${useCaseSensitiveFileNames}`);
            let configFileWatcher;
            if (configFileName) {
                configFileWatcher = watchFile2(configFileName, scheduleProgramReload, 2e3 /* High */, watchOptions, WatchType.ConfigFile);
            }
            const compilerHost = createCompilerHostFromProgramHost(host, () => compilerOptions, directoryStructureHost);
            setGetSourceFileAsHashVersioned(compilerHost);
            const getNewSourceFile = compilerHost.getSourceFile;
            compilerHost.getSourceFile = (fileName, ...args) => getVersionedSourceFileByPath(fileName, toPath3(fileName), ...args);
            compilerHost.getSourceFileByPath = getVersionedSourceFileByPath;
            compilerHost.getNewLine = () => newLine;
            compilerHost.fileExists = fileExists;
            compilerHost.onReleaseOldSourceFile = onReleaseOldSourceFile;
            compilerHost.onReleaseParsedCommandLine = onReleaseParsedCommandLine;
            compilerHost.toPath = toPath3;
            compilerHost.getCompilationSettings = () => compilerOptions;
            compilerHost.useSourceOfProjectReferenceRedirect = maybeBind(host, host.useSourceOfProjectReferenceRedirect);
            compilerHost.watchDirectoryOfFailedLookupLocation = (dir, cb, flags) => watchDirectory(dir, cb, flags, watchOptions, WatchType.FailedLookupLocations);
            compilerHost.watchAffectingFileLocation = (file, cb) => watchFile2(file, cb, 2e3 /* High */, watchOptions, WatchType.AffectingFileLocation);
            compilerHost.watchTypeRootsDirectory = (dir, cb, flags) => watchDirectory(dir, cb, flags, watchOptions, WatchType.TypeRoots);
            compilerHost.getCachedDirectoryStructureHost = () => cachedDirectoryStructureHost;
            compilerHost.scheduleInvalidateResolutionsOfFailedLookupLocations = scheduleInvalidateResolutionsOfFailedLookupLocations;
            compilerHost.onInvalidatedResolution = scheduleProgramUpdate;
            compilerHost.onChangedAutomaticTypeDirectiveNames = scheduleProgramUpdate;
            compilerHost.fileIsOpen = returnFalse;
            compilerHost.getCurrentProgram = getCurrentProgram;
            compilerHost.writeLog = writeLog;
            compilerHost.getParsedCommandLine = getParsedCommandLine;
            const resolutionCache = createResolutionCache(compilerHost, configFileName ? getDirectoryPath(getNormalizedAbsolutePath(configFileName, currentDirectory)) : currentDirectory, 
            /*logChangesWhenResolvingModule*/
            false);
            compilerHost.resolveModuleNameLiterals = maybeBind(host, host.resolveModuleNameLiterals);
            compilerHost.resolveModuleNames = maybeBind(host, host.resolveModuleNames);
            if (!compilerHost.resolveModuleNameLiterals && !compilerHost.resolveModuleNames) {
                compilerHost.resolveModuleNameLiterals = resolutionCache.resolveModuleNameLiterals.bind(resolutionCache);
            }
            compilerHost.resolveTypeReferenceDirectiveReferences = maybeBind(host, host.resolveTypeReferenceDirectiveReferences);
            compilerHost.resolveTypeReferenceDirectives = maybeBind(host, host.resolveTypeReferenceDirectives);
            if (!compilerHost.resolveTypeReferenceDirectiveReferences && !compilerHost.resolveTypeReferenceDirectives) {
                compilerHost.resolveTypeReferenceDirectiveReferences = resolutionCache.resolveTypeReferenceDirectiveReferences.bind(resolutionCache);
            }
            compilerHost.getModuleResolutionCache = host.resolveModuleNameLiterals || host.resolveModuleNames ? maybeBind(host, host.getModuleResolutionCache) : () => resolutionCache.getModuleResolutionCache();
            const userProvidedResolution = !!host.resolveModuleNameLiterals || !!host.resolveTypeReferenceDirectiveReferences || !!host.resolveModuleNames || !!host.resolveTypeReferenceDirectives;
            const customHasInvalidatedResolutions = userProvidedResolution ? maybeBind(host, host.hasInvalidatedResolutions) || returnTrue : returnFalse;
            builderProgram = readBuilderProgram(compilerOptions, compilerHost);
            synchronizeProgram();
            watchConfigFileWildCardDirectories();
            if (configFileName)
                updateExtendedConfigFilesWatches(toPath3(configFileName), compilerOptions, watchOptions, WatchType.ExtendedConfigFile);
            return configFileName ? { getCurrentProgram: getCurrentBuilderProgram, getProgram: updateProgram, close } : { getCurrentProgram: getCurrentBuilderProgram, getProgram: updateProgram, updateRootFileNames, close };
            function close() {
                clearInvalidateResolutionsOfFailedLookupLocations();
                resolutionCache.clear();
                clearMap(sourceFilesCache, (value) => {
                    if (value && value.fileWatcher) {
                        value.fileWatcher.close();
                        value.fileWatcher = void 0;
                    }
                });
                if (configFileWatcher) {
                    configFileWatcher.close();
                    configFileWatcher = void 0;
                }
                extendedConfigCache == null ? void 0 : extendedConfigCache.clear();
                extendedConfigCache = void 0;
                if (sharedExtendedConfigFileWatchers) {
                    clearMap(sharedExtendedConfigFileWatchers, closeFileWatcherOf);
                    sharedExtendedConfigFileWatchers = void 0;
                }
                if (watchedWildcardDirectories) {
                    clearMap(watchedWildcardDirectories, closeFileWatcherOf);
                    watchedWildcardDirectories = void 0;
                }
                if (missingFilesMap) {
                    clearMap(missingFilesMap, closeFileWatcher);
                    missingFilesMap = void 0;
                }
                if (parsedConfigs) {
                    clearMap(parsedConfigs, (config) => {
                        var _a2;
                        (_a2 = config.watcher) == null ? void 0 : _a2.close();
                        config.watcher = void 0;
                        if (config.watchedDirectories)
                            clearMap(config.watchedDirectories, closeFileWatcherOf);
                        config.watchedDirectories = void 0;
                    });
                    parsedConfigs = void 0;
                }
            }
            function getCurrentBuilderProgram() {
                return builderProgram;
            }
            function getCurrentProgram() {
                return builderProgram && builderProgram.getProgramOrUndefined();
            }
            function synchronizeProgram() {
                writeLog(`Synchronizing program`);
                Debug.assert(compilerOptions);
                Debug.assert(rootFileNames);
                clearInvalidateResolutionsOfFailedLookupLocations();
                const program = getCurrentBuilderProgram();
                if (hasChangedCompilerOptions) {
                    newLine = updateNewLine();
                    if (program && changesAffectModuleResolution(program.getCompilerOptions(), compilerOptions)) {
                        resolutionCache.clear();
                    }
                }
                const hasInvalidatedResolutions = resolutionCache.createHasInvalidatedResolutions(customHasInvalidatedResolutions);
                const { originalReadFile, originalFileExists, originalDirectoryExists, originalCreateDirectory, originalWriteFile, readFileWithCache } = changeCompilerHostLikeToUseCache(compilerHost, toPath3);
                if (isProgramUptoDate(getCurrentProgram(), rootFileNames, compilerOptions, (path) => getSourceVersion(path, readFileWithCache), (fileName) => compilerHost.fileExists(fileName), hasInvalidatedResolutions, hasChangedAutomaticTypeDirectiveNames, getParsedCommandLine, projectReferences)) {
                    if (hasChangedConfigFileParsingErrors) {
                        if (reportFileChangeDetectedOnCreateProgram) {
                            reportWatchDiagnostic(Diagnostics.File_change_detected_Starting_incremental_compilation);
                        }
                        builderProgram = createProgram2(
                        /*rootNames*/
                        void 0, 
                        /*options*/
                        void 0, compilerHost, builderProgram, configFileParsingDiagnostics, projectReferences);
                        hasChangedConfigFileParsingErrors = false;
                    }
                }
                else {
                    if (reportFileChangeDetectedOnCreateProgram) {
                        reportWatchDiagnostic(Diagnostics.File_change_detected_Starting_incremental_compilation);
                    }
                    createNewProgram(hasInvalidatedResolutions);
                }
                reportFileChangeDetectedOnCreateProgram = false;
                if (host.afterProgramCreate && program !== builderProgram) {
                    host.afterProgramCreate(builderProgram);
                }
                compilerHost.readFile = originalReadFile;
                compilerHost.fileExists = originalFileExists;
                compilerHost.directoryExists = originalDirectoryExists;
                compilerHost.createDirectory = originalCreateDirectory;
                compilerHost.writeFile = originalWriteFile;
                return builderProgram;
            }
            function createNewProgram(hasInvalidatedResolutions) {
                writeLog("CreatingProgramWith::");
                writeLog(`  roots: ${JSON.stringify(rootFileNames)}`);
                writeLog(`  options: ${JSON.stringify(compilerOptions)}`);
                if (projectReferences)
                    writeLog(`  projectReferences: ${JSON.stringify(projectReferences)}`);
                const needsUpdateInTypeRootWatch = hasChangedCompilerOptions || !getCurrentProgram();
                hasChangedCompilerOptions = false;
                hasChangedConfigFileParsingErrors = false;
                resolutionCache.startCachingPerDirectoryResolution();
                compilerHost.hasInvalidatedResolutions = hasInvalidatedResolutions;
                compilerHost.hasChangedAutomaticTypeDirectiveNames = hasChangedAutomaticTypeDirectiveNames;
                const oldProgram = getCurrentProgram();
                builderProgram = createProgram2(rootFileNames, compilerOptions, compilerHost, builderProgram, configFileParsingDiagnostics, projectReferences);
                resolutionCache.finishCachingPerDirectoryResolution(builderProgram.getProgram(), oldProgram);
                updateMissingFilePathsWatch(builderProgram.getProgram(), missingFilesMap || (missingFilesMap = /* @__PURE__ */ new Map()), watchMissingFilePath);
                if (needsUpdateInTypeRootWatch) {
                    resolutionCache.updateTypeRootsWatch();
                }
                if (missingFilePathsRequestedForRelease) {
                    for (const missingFilePath of missingFilePathsRequestedForRelease) {
                        if (!missingFilesMap.has(missingFilePath)) {
                            sourceFilesCache.delete(missingFilePath);
                        }
                    }
                    missingFilePathsRequestedForRelease = void 0;
                }
            }
            function updateRootFileNames(files) {
                Debug.assert(!configFileName, "Cannot update root file names with config file watch mode");
                rootFileNames = files;
                scheduleProgramUpdate();
            }
            function updateNewLine() {
                return getNewLineCharacter(compilerOptions || optionsToExtendForConfigFile);
            }
            function toPath3(fileName) {
                return toPath(fileName, currentDirectory, getCanonicalFileName);
            }
            function isFileMissingOnHost(hostSourceFile) {
                return typeof hostSourceFile === "boolean";
            }
            function isFilePresenceUnknownOnHost(hostSourceFile) {
                return typeof hostSourceFile.version === "boolean";
            }
            function fileExists(fileName) {
                const path = toPath3(fileName);
                if (isFileMissingOnHost(sourceFilesCache.get(path))) {
                    return false;
                }
                return directoryStructureHost.fileExists(fileName);
            }
            function getVersionedSourceFileByPath(fileName, path, languageVersionOrOptions, onError, shouldCreateNewSourceFile) {
                const hostSourceFile = sourceFilesCache.get(path);
                if (isFileMissingOnHost(hostSourceFile)) {
                    return void 0;
                }
                if (hostSourceFile === void 0 || shouldCreateNewSourceFile || isFilePresenceUnknownOnHost(hostSourceFile)) {
                    const sourceFile = getNewSourceFile(fileName, languageVersionOrOptions, onError);
                    if (hostSourceFile) {
                        if (sourceFile) {
                            hostSourceFile.sourceFile = sourceFile;
                            hostSourceFile.version = sourceFile.version;
                            if (!hostSourceFile.fileWatcher) {
                                hostSourceFile.fileWatcher = watchFilePath(path, fileName, onSourceFileChange, 250 /* Low */, watchOptions, WatchType.SourceFile);
                            }
                        }
                        else {
                            if (hostSourceFile.fileWatcher) {
                                hostSourceFile.fileWatcher.close();
                            }
                            sourceFilesCache.set(path, false);
                        }
                    }
                    else {
                        if (sourceFile) {
                            const fileWatcher = watchFilePath(path, fileName, onSourceFileChange, 250 /* Low */, watchOptions, WatchType.SourceFile);
                            sourceFilesCache.set(path, { sourceFile, version: sourceFile.version, fileWatcher });
                        }
                        else {
                            sourceFilesCache.set(path, false);
                        }
                    }
                    return sourceFile;
                }
                return hostSourceFile.sourceFile;
            }
            function nextSourceFileVersion(path) {
                const hostSourceFile = sourceFilesCache.get(path);
                if (hostSourceFile !== void 0) {
                    if (isFileMissingOnHost(hostSourceFile)) {
                        sourceFilesCache.set(path, { version: false });
                    }
                    else {
                        hostSourceFile.version = false;
                    }
                }
            }
            function getSourceVersion(path, readFileWithCache) {
                const hostSourceFile = sourceFilesCache.get(path);
                if (!hostSourceFile)
                    return void 0;
                if (hostSourceFile.version)
                    return hostSourceFile.version;
                const text = readFileWithCache(path);
                return text !== void 0 ? getSourceFileVersionAsHashFromText(compilerHost, text) : void 0;
            }
            function onReleaseOldSourceFile(oldSourceFile, _oldOptions, hasSourceFileByPath) {
                const hostSourceFileInfo = sourceFilesCache.get(oldSourceFile.resolvedPath);
                if (hostSourceFileInfo !== void 0) {
                    if (isFileMissingOnHost(hostSourceFileInfo)) {
                        (missingFilePathsRequestedForRelease || (missingFilePathsRequestedForRelease = [])).push(oldSourceFile.path);
                    }
                    else if (hostSourceFileInfo.sourceFile === oldSourceFile) {
                        if (hostSourceFileInfo.fileWatcher) {
                            hostSourceFileInfo.fileWatcher.close();
                        }
                        sourceFilesCache.delete(oldSourceFile.resolvedPath);
                        if (!hasSourceFileByPath) {
                            resolutionCache.removeResolutionsOfFile(oldSourceFile.path);
                        }
                    }
                }
            }
            function reportWatchDiagnostic(message) {
                if (host.onWatchStatusChange) {
                    host.onWatchStatusChange(createCompilerDiagnostic(message), newLine, compilerOptions || optionsToExtendForConfigFile);
                }
            }
            function hasChangedAutomaticTypeDirectiveNames() {
                return resolutionCache.hasChangedAutomaticTypeDirectiveNames();
            }
            function clearInvalidateResolutionsOfFailedLookupLocations() {
                if (!timerToInvalidateFailedLookupResolutions)
                    return false;
                host.clearTimeout(timerToInvalidateFailedLookupResolutions);
                timerToInvalidateFailedLookupResolutions = void 0;
                return true;
            }
            function scheduleInvalidateResolutionsOfFailedLookupLocations() {
                if (!host.setTimeout || !host.clearTimeout) {
                    return resolutionCache.invalidateResolutionsOfFailedLookupLocations();
                }
                const pending = clearInvalidateResolutionsOfFailedLookupLocations();
                writeLog(`Scheduling invalidateFailedLookup${pending ? ", Cancelled earlier one" : ""}`);
                timerToInvalidateFailedLookupResolutions = host.setTimeout(invalidateResolutionsOfFailedLookup, 250);
            }
            function invalidateResolutionsOfFailedLookup() {
                timerToInvalidateFailedLookupResolutions = void 0;
                if (resolutionCache.invalidateResolutionsOfFailedLookupLocations()) {
                    scheduleProgramUpdate();
                }
            }
            function scheduleProgramUpdate() {
                if (!host.setTimeout || !host.clearTimeout) {
                    return;
                }
                if (timerToUpdateProgram) {
                    host.clearTimeout(timerToUpdateProgram);
                }
                writeLog("Scheduling update");
                timerToUpdateProgram = host.setTimeout(updateProgramWithWatchStatus, 250);
            }
            function scheduleProgramReload() {
                Debug.assert(!!configFileName);
                reloadLevel = 2 /* Full */;
                scheduleProgramUpdate();
            }
            function updateProgramWithWatchStatus() {
                timerToUpdateProgram = void 0;
                reportFileChangeDetectedOnCreateProgram = true;
                updateProgram();
            }
            function updateProgram() {
                switch (reloadLevel) {
                    case 1 /* Partial */:
                        perfLogger.logStartUpdateProgram("PartialConfigReload");
                        reloadFileNamesFromConfigFile();
                        break;
                    case 2 /* Full */:
                        perfLogger.logStartUpdateProgram("FullConfigReload");
                        reloadConfigFile();
                        break;
                    default:
                        perfLogger.logStartUpdateProgram("SynchronizeProgram");
                        synchronizeProgram();
                        break;
                }
                perfLogger.logStopUpdateProgram("Done");
                return getCurrentBuilderProgram();
            }
            function reloadFileNamesFromConfigFile() {
                writeLog("Reloading new file names and options");
                Debug.assert(compilerOptions);
                Debug.assert(configFileName);
                reloadLevel = 0 /* None */;
                rootFileNames = getFileNamesFromConfigSpecs(compilerOptions.configFile.configFileSpecs, getNormalizedAbsolutePath(getDirectoryPath(configFileName), currentDirectory), compilerOptions, parseConfigFileHost, extraFileExtensions);
                if (updateErrorForNoInputFiles(rootFileNames, getNormalizedAbsolutePath(configFileName, currentDirectory), compilerOptions.configFile.configFileSpecs, configFileParsingDiagnostics, canConfigFileJsonReportNoInputFiles)) {
                    hasChangedConfigFileParsingErrors = true;
                }
                synchronizeProgram();
            }
            function reloadConfigFile() {
                Debug.assert(configFileName);
                writeLog(`Reloading config file: ${configFileName}`);
                reloadLevel = 0 /* None */;
                if (cachedDirectoryStructureHost) {
                    cachedDirectoryStructureHost.clearCache();
                }
                parseConfigFile2();
                hasChangedCompilerOptions = true;
                synchronizeProgram();
                watchConfigFileWildCardDirectories();
                updateExtendedConfigFilesWatches(toPath3(configFileName), compilerOptions, watchOptions, WatchType.ExtendedConfigFile);
            }
            function parseConfigFile2() {
                Debug.assert(configFileName);
                setConfigFileParsingResult(getParsedCommandLineOfConfigFile(configFileName, optionsToExtendForConfigFile, parseConfigFileHost, extendedConfigCache || (extendedConfigCache = /* @__PURE__ */ new Map()), watchOptionsToExtend, extraFileExtensions));
            }
            function setConfigFileParsingResult(configFileParseResult) {
                rootFileNames = configFileParseResult.fileNames;
                compilerOptions = configFileParseResult.options;
                watchOptions = configFileParseResult.watchOptions;
                projectReferences = configFileParseResult.projectReferences;
                wildcardDirectories = configFileParseResult.wildcardDirectories;
                configFileParsingDiagnostics = getConfigFileParsingDiagnostics(configFileParseResult).slice();
                canConfigFileJsonReportNoInputFiles = canJsonReportNoInputFiles(configFileParseResult.raw);
                hasChangedConfigFileParsingErrors = true;
            }
            function getParsedCommandLine(configFileName2) {
                const configPath = toPath3(configFileName2);
                let config = parsedConfigs == null ? void 0 : parsedConfigs.get(configPath);
                if (config) {
                    if (!config.reloadLevel)
                        return config.parsedCommandLine;
                    if (config.parsedCommandLine && config.reloadLevel === 1 /* Partial */ && !host.getParsedCommandLine) {
                        writeLog("Reloading new file names and options");
                        Debug.assert(compilerOptions);
                        const fileNames = getFileNamesFromConfigSpecs(config.parsedCommandLine.options.configFile.configFileSpecs, getNormalizedAbsolutePath(getDirectoryPath(configFileName2), currentDirectory), compilerOptions, parseConfigFileHost);
                        config.parsedCommandLine = { ...config.parsedCommandLine, fileNames };
                        config.reloadLevel = void 0;
                        return config.parsedCommandLine;
                    }
                }
                writeLog(`Loading config file: ${configFileName2}`);
                const parsedCommandLine = host.getParsedCommandLine ? host.getParsedCommandLine(configFileName2) : getParsedCommandLineFromConfigFileHost(configFileName2);
                if (config) {
                    config.parsedCommandLine = parsedCommandLine;
                    config.reloadLevel = void 0;
                }
                else {
                    (parsedConfigs || (parsedConfigs = /* @__PURE__ */ new Map())).set(configPath, config = { parsedCommandLine });
                }
                watchReferencedProject(configFileName2, configPath, config);
                return parsedCommandLine;
            }
            function getParsedCommandLineFromConfigFileHost(configFileName2) {
                const onUnRecoverableConfigFileDiagnostic = parseConfigFileHost.onUnRecoverableConfigFileDiagnostic;
                parseConfigFileHost.onUnRecoverableConfigFileDiagnostic = noop;
                const parsedCommandLine = getParsedCommandLineOfConfigFile(configFileName2, 
                /*optionsToExtend*/
                void 0, parseConfigFileHost, extendedConfigCache || (extendedConfigCache = /* @__PURE__ */ new Map()), watchOptionsToExtend);
                parseConfigFileHost.onUnRecoverableConfigFileDiagnostic = onUnRecoverableConfigFileDiagnostic;
                return parsedCommandLine;
            }
            function onReleaseParsedCommandLine(fileName) {
                var _a2;
                const path = toPath3(fileName);
                const config = parsedConfigs == null ? void 0 : parsedConfigs.get(path);
                if (!config)
                    return;
                parsedConfigs.delete(path);
                if (config.watchedDirectories)
                    clearMap(config.watchedDirectories, closeFileWatcherOf);
                (_a2 = config.watcher) == null ? void 0 : _a2.close();
                clearSharedExtendedConfigFileWatcher(path, sharedExtendedConfigFileWatchers);
            }
            function watchFilePath(path, file, callback, pollingInterval, options, watchType) {
                return watchFile2(file, (fileName, eventKind) => callback(fileName, eventKind, path), pollingInterval, options, watchType);
            }
            function onSourceFileChange(fileName, eventKind, path) {
                updateCachedSystemWithFile(fileName, path, eventKind);
                if (eventKind === 2 /* Deleted */ && sourceFilesCache.has(path)) {
                    resolutionCache.invalidateResolutionOfFile(path);
                }
                nextSourceFileVersion(path);
                scheduleProgramUpdate();
            }
            function updateCachedSystemWithFile(fileName, path, eventKind) {
                if (cachedDirectoryStructureHost) {
                    cachedDirectoryStructureHost.addOrDeleteFile(fileName, path, eventKind);
                }
            }
            function watchMissingFilePath(missingFilePath) {
                return (parsedConfigs == null ? void 0 : parsedConfigs.has(missingFilePath)) ? noopFileWatcher : watchFilePath(missingFilePath, missingFilePath, onMissingFileChange, 500 /* Medium */, watchOptions, WatchType.MissingFile);
            }
            function onMissingFileChange(fileName, eventKind, missingFilePath) {
                updateCachedSystemWithFile(fileName, missingFilePath, eventKind);
                if (eventKind === 0 /* Created */ && missingFilesMap.has(missingFilePath)) {
                    missingFilesMap.get(missingFilePath).close();
                    missingFilesMap.delete(missingFilePath);
                    nextSourceFileVersion(missingFilePath);
                    scheduleProgramUpdate();
                }
            }
            function watchConfigFileWildCardDirectories() {
                if (wildcardDirectories) {
                    updateWatchingWildcardDirectories(watchedWildcardDirectories || (watchedWildcardDirectories = /* @__PURE__ */ new Map()), new Map(Object.entries(wildcardDirectories)), watchWildcardDirectory);
                }
                else if (watchedWildcardDirectories) {
                    clearMap(watchedWildcardDirectories, closeFileWatcherOf);
                }
            }
            function watchWildcardDirectory(directory, flags) {
                return watchDirectory(directory, (fileOrDirectory) => {
                    Debug.assert(configFileName);
                    Debug.assert(compilerOptions);
                    const fileOrDirectoryPath = toPath3(fileOrDirectory);
                    if (cachedDirectoryStructureHost) {
                        cachedDirectoryStructureHost.addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath);
                    }
                    nextSourceFileVersion(fileOrDirectoryPath);
                    if (isIgnoredFileFromWildCardWatching({
                        watchedDirPath: toPath3(directory),
                        fileOrDirectory,
                        fileOrDirectoryPath,
                        configFileName,
                        extraFileExtensions,
                        options: compilerOptions,
                        program: getCurrentBuilderProgram() || rootFileNames,
                        currentDirectory,
                        useCaseSensitiveFileNames,
                        writeLog,
                        toPath: toPath3
                    }))
                        return;
                    if (reloadLevel !== 2 /* Full */) {
                        reloadLevel = 1 /* Partial */;
                        scheduleProgramUpdate();
                    }
                }, flags, watchOptions, WatchType.WildcardDirectory);
            }
            function updateExtendedConfigFilesWatches(forProjectPath, options, watchOptions2, watchType) {
                updateSharedExtendedConfigFileWatcher(forProjectPath, options, sharedExtendedConfigFileWatchers || (sharedExtendedConfigFileWatchers = /* @__PURE__ */ new Map()), (extendedConfigFileName, extendedConfigFilePath) => watchFile2(extendedConfigFileName, (_fileName, eventKind) => {
                    var _a2;
                    updateCachedSystemWithFile(extendedConfigFileName, extendedConfigFilePath, eventKind);
                    if (extendedConfigCache)
                        cleanExtendedConfigCache(extendedConfigCache, extendedConfigFilePath, toPath3);
                    const projects = (_a2 = sharedExtendedConfigFileWatchers.get(extendedConfigFilePath)) == null ? void 0 : _a2.projects;
                    if (!(projects == null ? void 0 : projects.size))
                        return;
                    projects.forEach((projectPath) => {
                        if (configFileName && toPath3(configFileName) === projectPath) {
                            reloadLevel = 2 /* Full */;
                        }
                        else {
                            const config = parsedConfigs == null ? void 0 : parsedConfigs.get(projectPath);
                            if (config)
                                config.reloadLevel = 2 /* Full */;
                            resolutionCache.removeResolutionsFromProjectReferenceRedirects(projectPath);
                        }
                        scheduleProgramUpdate();
                    });
                }, 2e3 /* High */, watchOptions2, watchType), toPath3);
            }
            function watchReferencedProject(configFileName2, configPath, commandLine) {
                var _a2, _b, _c, _d, _e;
                commandLine.watcher || (commandLine.watcher = watchFile2(configFileName2, (_fileName, eventKind) => {
                    updateCachedSystemWithFile(configFileName2, configPath, eventKind);
                    const config = parsedConfigs == null ? void 0 : parsedConfigs.get(configPath);
                    if (config)
                        config.reloadLevel = 2 /* Full */;
                    resolutionCache.removeResolutionsFromProjectReferenceRedirects(configPath);
                    scheduleProgramUpdate();
                }, 2e3 /* High */, ((_a2 = commandLine.parsedCommandLine) == null ? void 0 : _a2.watchOptions) || watchOptions, WatchType.ConfigFileOfReferencedProject));
                if ((_b = commandLine.parsedCommandLine) == null ? void 0 : _b.wildcardDirectories) {
                    updateWatchingWildcardDirectories(commandLine.watchedDirectories || (commandLine.watchedDirectories = /* @__PURE__ */ new Map()), new Map(Object.entries((_c = commandLine.parsedCommandLine) == null ? void 0 : _c.wildcardDirectories)), (directory, flags) => {
                        var _a3;
                        return watchDirectory(directory, (fileOrDirectory) => {
                            const fileOrDirectoryPath = toPath3(fileOrDirectory);
                            if (cachedDirectoryStructureHost) {
                                cachedDirectoryStructureHost.addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath);
                            }
                            nextSourceFileVersion(fileOrDirectoryPath);
                            const config = parsedConfigs == null ? void 0 : parsedConfigs.get(configPath);
                            if (!(config == null ? void 0 : config.parsedCommandLine))
                                return;
                            if (isIgnoredFileFromWildCardWatching({
                                watchedDirPath: toPath3(directory),
                                fileOrDirectory,
                                fileOrDirectoryPath,
                                configFileName: configFileName2,
                                options: config.parsedCommandLine.options,
                                program: config.parsedCommandLine.fileNames,
                                currentDirectory,
                                useCaseSensitiveFileNames,
                                writeLog,
                                toPath: toPath3
                            }))
                                return;
                            if (config.reloadLevel !== 2 /* Full */) {
                                config.reloadLevel = 1 /* Partial */;
                                scheduleProgramUpdate();
                            }
                        }, flags, ((_a3 = commandLine.parsedCommandLine) == null ? void 0 : _a3.watchOptions) || watchOptions, WatchType.WildcardDirectoryOfReferencedProject);
                    });
                }
                else if (commandLine.watchedDirectories) {
                    clearMap(commandLine.watchedDirectories, closeFileWatcherOf);
                    commandLine.watchedDirectories = void 0;
                }
                updateExtendedConfigFilesWatches(configPath, (_d = commandLine.parsedCommandLine) == null ? void 0 : _d.options, ((_e = commandLine.parsedCommandLine) == null ? void 0 : _e.watchOptions) || watchOptions, WatchType.ExtendedConfigOfReferencedProject);
            }
        }
        var init_watchPublic = __esm({
            "src/compiler/watchPublic.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
            }
        });
        // src/compiler/tsbuild.ts
        function resolveConfigFileProjectName(project) {
            if (fileExtensionIs(project, ".json" /* Json */)) {
                return project;
            }
            return combinePaths(project, "tsconfig.json");
        }
        var UpToDateStatusType;
        var init_tsbuild = __esm({
            "src/compiler/tsbuild.ts"() {
                "use strict";
                init_ts2();
                UpToDateStatusType = /* @__PURE__ */ ((UpToDateStatusType2) => {
                    UpToDateStatusType2[UpToDateStatusType2["Unbuildable"] = 0] = "Unbuildable";
                    UpToDateStatusType2[UpToDateStatusType2["UpToDate"] = 1] = "UpToDate";
                    UpToDateStatusType2[UpToDateStatusType2["UpToDateWithUpstreamTypes"] = 2] = "UpToDateWithUpstreamTypes";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateWithPrepend"] = 3] = "OutOfDateWithPrepend";
                    UpToDateStatusType2[UpToDateStatusType2["OutputMissing"] = 4] = "OutputMissing";
                    UpToDateStatusType2[UpToDateStatusType2["ErrorReadingFile"] = 5] = "ErrorReadingFile";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateWithSelf"] = 6] = "OutOfDateWithSelf";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateWithUpstream"] = 7] = "OutOfDateWithUpstream";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateBuildInfo"] = 8] = "OutOfDateBuildInfo";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateOptions"] = 9] = "OutOfDateOptions";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateRoots"] = 10] = "OutOfDateRoots";
                    UpToDateStatusType2[UpToDateStatusType2["UpstreamOutOfDate"] = 11] = "UpstreamOutOfDate";
                    UpToDateStatusType2[UpToDateStatusType2["UpstreamBlocked"] = 12] = "UpstreamBlocked";
                    UpToDateStatusType2[UpToDateStatusType2["ComputingUpstream"] = 13] = "ComputingUpstream";
                    UpToDateStatusType2[UpToDateStatusType2["TsVersionOutputOfDate"] = 14] = "TsVersionOutputOfDate";
                    UpToDateStatusType2[UpToDateStatusType2["UpToDateWithInputFileText"] = 15] = "UpToDateWithInputFileText";
                    UpToDateStatusType2[UpToDateStatusType2["ContainerOnly"] = 16] = "ContainerOnly";
                    UpToDateStatusType2[UpToDateStatusType2["ForceBuild"] = 17] = "ForceBuild";
                    return UpToDateStatusType2;
                })(UpToDateStatusType || {});
            }
        });
        // src/compiler/tsbuildPublic.ts
        function getOrCreateValueFromConfigFileMap(configFileMap, resolved, createT) {
            const existingValue = configFileMap.get(resolved);
            let newValue;
            if (!existingValue) {
                newValue = createT();
                configFileMap.set(resolved, newValue);
            }
            return existingValue || newValue;
        }
        function getOrCreateValueMapFromConfigFileMap(configFileMap, resolved) {
            return getOrCreateValueFromConfigFileMap(configFileMap, resolved, () => /* @__PURE__ */ new Map());
        }
        function getCurrentTime(host) {
            return host.now ? host.now() : /* @__PURE__ */ new Date();
        }
        function isCircularBuildOrder(buildOrder) {
            return !!buildOrder && !!buildOrder.buildOrder;
        }
        function getBuildOrderFromAnyBuildOrder(anyBuildOrder) {
            return isCircularBuildOrder(anyBuildOrder) ? anyBuildOrder.buildOrder : anyBuildOrder;
        }
        function createBuilderStatusReporter(system, pretty) {
            return (diagnostic) => {
                let output = pretty ? `[${formatColorAndReset(getLocaleTimeString(system), "\x1B[90m" /* Grey */)}] ` : `${getLocaleTimeString(system)} - `;
                output += `${flattenDiagnosticMessageText(diagnostic.messageText, system.newLine)}${system.newLine + system.newLine}`;
                system.write(output);
            };
        }
        function createSolutionBuilderHostBase(system, createProgram2, reportDiagnostic, reportSolutionBuilderStatus) {
            const host = createProgramHost(system, createProgram2);
            host.getModifiedTime = system.getModifiedTime ? (path) => system.getModifiedTime(path) : returnUndefined;
            host.setModifiedTime = system.setModifiedTime ? (path, date) => system.setModifiedTime(path, date) : noop;
            host.deleteFile = system.deleteFile ? (path) => system.deleteFile(path) : noop;
            host.reportDiagnostic = reportDiagnostic || createDiagnosticReporter(system);
            host.reportSolutionBuilderStatus = reportSolutionBuilderStatus || createBuilderStatusReporter(system);
            host.now = maybeBind(system, system.now);
            return host;
        }
        function createSolutionBuilderHost(system = sys, createProgram2, reportDiagnostic, reportSolutionBuilderStatus, reportErrorSummary2) {
            const host = createSolutionBuilderHostBase(system, createProgram2, reportDiagnostic, reportSolutionBuilderStatus);
            host.reportErrorSummary = reportErrorSummary2;
            return host;
        }
        function createSolutionBuilderWithWatchHost(system = sys, createProgram2, reportDiagnostic, reportSolutionBuilderStatus, reportWatchStatus2) {
            const host = createSolutionBuilderHostBase(system, createProgram2, reportDiagnostic, reportSolutionBuilderStatus);
            const watchHost = createWatchHost(system, reportWatchStatus2);
            copyProperties(host, watchHost);
            return host;
        }
        function getCompilerOptionsOfBuildOptions(buildOptions) {
            const result = {};
            commonOptionsWithBuild.forEach((option) => {
                if (hasProperty(buildOptions, option.name))
                    result[option.name] = buildOptions[option.name];
            });
            return result;
        }
        function createSolutionBuilder(host, rootNames, defaultOptions) {
            return createSolutionBuilderWorker(
            /*watch*/
            false, host, rootNames, defaultOptions);
        }
        function createSolutionBuilderWithWatch(host, rootNames, defaultOptions, baseWatchOptions) {
            return createSolutionBuilderWorker(
            /*watch*/
            true, host, rootNames, defaultOptions, baseWatchOptions);
        }
        function createSolutionBuilderState(watch, hostOrHostWithWatch, rootNames, options, baseWatchOptions) {
            const host = hostOrHostWithWatch;
            const hostWithWatch = hostOrHostWithWatch;
            const baseCompilerOptions = getCompilerOptionsOfBuildOptions(options);
            const compilerHost = createCompilerHostFromProgramHost(host, () => state.projectCompilerOptions);
            setGetSourceFileAsHashVersioned(compilerHost);
            compilerHost.getParsedCommandLine = (fileName) => parseConfigFile(state, fileName, toResolvedConfigFilePath(state, fileName));
            compilerHost.resolveModuleNameLiterals = maybeBind(host, host.resolveModuleNameLiterals);
            compilerHost.resolveTypeReferenceDirectiveReferences = maybeBind(host, host.resolveTypeReferenceDirectiveReferences);
            compilerHost.resolveModuleNames = maybeBind(host, host.resolveModuleNames);
            compilerHost.resolveTypeReferenceDirectives = maybeBind(host, host.resolveTypeReferenceDirectives);
            compilerHost.getModuleResolutionCache = maybeBind(host, host.getModuleResolutionCache);
            let moduleResolutionCache, typeReferenceDirectiveResolutionCache;
            if (!compilerHost.resolveModuleNameLiterals && !compilerHost.resolveModuleNames) {
                moduleResolutionCache = createModuleResolutionCache(compilerHost.getCurrentDirectory(), compilerHost.getCanonicalFileName);
                compilerHost.resolveModuleNameLiterals = (moduleNames, containingFile, redirectedReference, options2, containingSourceFile) => loadWithModeAwareCache(moduleNames, containingFile, redirectedReference, options2, containingSourceFile, host, moduleResolutionCache, createModuleResolutionLoader);
                compilerHost.getModuleResolutionCache = () => moduleResolutionCache;
            }
            if (!compilerHost.resolveTypeReferenceDirectiveReferences && !compilerHost.resolveTypeReferenceDirectives) {
                typeReferenceDirectiveResolutionCache = createTypeReferenceDirectiveResolutionCache(compilerHost.getCurrentDirectory(), compilerHost.getCanonicalFileName, 
                /*options*/
                void 0, moduleResolutionCache == null ? void 0 : moduleResolutionCache.getPackageJsonInfoCache());
                compilerHost.resolveTypeReferenceDirectiveReferences = (typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile) => loadWithModeAwareCache(typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile, host, typeReferenceDirectiveResolutionCache, createTypeReferenceResolutionLoader);
            }
            compilerHost.getBuildInfo = (fileName, configFilePath) => getBuildInfo3(state, fileName, toResolvedConfigFilePath(state, configFilePath), 
            /*modifiedTime*/
            void 0);
            const { watchFile: watchFile2, watchDirectory, writeLog } = createWatchFactory(hostWithWatch, options);
            const state = {
                host,
                hostWithWatch,
                parseConfigFileHost: parseConfigHostFromCompilerHostLike(host),
                write: maybeBind(host, host.trace),
                // State of solution
                options,
                baseCompilerOptions,
                rootNames,
                baseWatchOptions,
                resolvedConfigFilePaths: /* @__PURE__ */ new Map(),
                configFileCache: /* @__PURE__ */ new Map(),
                projectStatus: /* @__PURE__ */ new Map(),
                extendedConfigCache: /* @__PURE__ */ new Map(),
                buildInfoCache: /* @__PURE__ */ new Map(),
                outputTimeStamps: /* @__PURE__ */ new Map(),
                builderPrograms: /* @__PURE__ */ new Map(),
                diagnostics: /* @__PURE__ */ new Map(),
                projectPendingBuild: /* @__PURE__ */ new Map(),
                projectErrorsReported: /* @__PURE__ */ new Map(),
                compilerHost,
                moduleResolutionCache,
                typeReferenceDirectiveResolutionCache,
                // Mutable state
                buildOrder: void 0,
                readFileWithCache: (f) => host.readFile(f),
                projectCompilerOptions: baseCompilerOptions,
                cache: void 0,
                allProjectBuildPending: true,
                needsSummary: true,
                watchAllProjectsPending: watch,
                // Watch state
                watch,
                allWatchedWildcardDirectories: /* @__PURE__ */ new Map(),
                allWatchedInputFiles: /* @__PURE__ */ new Map(),
                allWatchedConfigFiles: /* @__PURE__ */ new Map(),
                allWatchedExtendedConfigFiles: /* @__PURE__ */ new Map(),
                allWatchedPackageJsonFiles: /* @__PURE__ */ new Map(),
                filesWatched: /* @__PURE__ */ new Map(),
                lastCachedPackageJsonLookups: /* @__PURE__ */ new Map(),
                timerToBuildInvalidatedProject: void 0,
                reportFileChangeDetected: false,
                watchFile: watchFile2,
                watchDirectory,
                writeLog
            };
            return state;
        }
        function toPath2(state, fileName) {
            return toPath(fileName, state.compilerHost.getCurrentDirectory(), state.compilerHost.getCanonicalFileName);
        }
        function toResolvedConfigFilePath(state, fileName) {
            const { resolvedConfigFilePaths } = state;
            const path = resolvedConfigFilePaths.get(fileName);
            if (path !== void 0)
                return path;
            const resolvedPath = toPath2(state, fileName);
            resolvedConfigFilePaths.set(fileName, resolvedPath);
            return resolvedPath;
        }
        function isParsedCommandLine(entry) {
            return !!entry.options;
        }
        function getCachedParsedConfigFile(state, configFilePath) {
            const value = state.configFileCache.get(configFilePath);
            return value && isParsedCommandLine(value) ? value : void 0;
        }
        function parseConfigFile(state, configFileName, configFilePath) {
            const { configFileCache } = state;
            const value = configFileCache.get(configFilePath);
            if (value) {
                return isParsedCommandLine(value) ? value : void 0;
            }
            mark("SolutionBuilder::beforeConfigFileParsing");
            let diagnostic;
            const { parseConfigFileHost, baseCompilerOptions, baseWatchOptions, extendedConfigCache, host } = state;
            let parsed;
            if (host.getParsedCommandLine) {
                parsed = host.getParsedCommandLine(configFileName);
                if (!parsed)
                    diagnostic = createCompilerDiagnostic(Diagnostics.File_0_not_found, configFileName);
            }
            else {
                parseConfigFileHost.onUnRecoverableConfigFileDiagnostic = (d) => diagnostic = d;
                parsed = getParsedCommandLineOfConfigFile(configFileName, baseCompilerOptions, parseConfigFileHost, extendedConfigCache, baseWatchOptions);
                parseConfigFileHost.onUnRecoverableConfigFileDiagnostic = noop;
            }
            configFileCache.set(configFilePath, parsed || diagnostic);
            mark("SolutionBuilder::afterConfigFileParsing");
            measure("SolutionBuilder::Config file parsing", "SolutionBuilder::beforeConfigFileParsing", "SolutionBuilder::afterConfigFileParsing");
            return parsed;
        }
        function resolveProjectName(state, name) {
            return resolveConfigFileProjectName(resolvePath(state.compilerHost.getCurrentDirectory(), name));
        }
        function createBuildOrder(state, roots) {
            const temporaryMarks = /* @__PURE__ */ new Map();
            const permanentMarks = /* @__PURE__ */ new Map();
            const circularityReportStack = [];
            let buildOrder;
            let circularDiagnostics;
            for (const root of roots) {
                visit(root);
            }
            return circularDiagnostics ? { buildOrder: buildOrder || emptyArray, circularDiagnostics } : buildOrder || emptyArray;
            function visit(configFileName, inCircularContext) {
                const projPath = toResolvedConfigFilePath(state, configFileName);
                if (permanentMarks.has(projPath))
                    return;
                if (temporaryMarks.has(projPath)) {
                    if (!inCircularContext) {
                        (circularDiagnostics || (circularDiagnostics = [])).push(createCompilerDiagnostic(Diagnostics.Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0, circularityReportStack.join("\r\n")));
                    }
                    return;
                }
                temporaryMarks.set(projPath, true);
                circularityReportStack.push(configFileName);
                const parsed = parseConfigFile(state, configFileName, projPath);
                if (parsed && parsed.projectReferences) {
                    for (const ref of parsed.projectReferences) {
                        const resolvedRefPath = resolveProjectName(state, ref.path);
                        visit(resolvedRefPath, inCircularContext || ref.circular);
                    }
                }
                circularityReportStack.pop();
                permanentMarks.set(projPath, true);
                (buildOrder || (buildOrder = [])).push(configFileName);
            }
        }
        function getBuildOrder(state) {
            return state.buildOrder || createStateBuildOrder(state);
        }
        function createStateBuildOrder(state) {
            const buildOrder = createBuildOrder(state, state.rootNames.map((f) => resolveProjectName(state, f)));
            state.resolvedConfigFilePaths.clear();
            const currentProjects = new Map(getBuildOrderFromAnyBuildOrder(buildOrder).map((resolved) => [toResolvedConfigFilePath(state, resolved), true]));
            const noopOnDelete = { onDeleteValue: noop };
            mutateMapSkippingNewValues(state.configFileCache, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.projectStatus, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.builderPrograms, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.diagnostics, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.projectPendingBuild, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.projectErrorsReported, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.buildInfoCache, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.outputTimeStamps, currentProjects, noopOnDelete);
            if (state.watch) {
                mutateMapSkippingNewValues(state.allWatchedConfigFiles, currentProjects, { onDeleteValue: closeFileWatcher });
                state.allWatchedExtendedConfigFiles.forEach((watcher) => {
                    watcher.projects.forEach((project) => {
                        if (!currentProjects.has(project)) {
                            watcher.projects.delete(project);
                        }
                    });
                    watcher.close();
                });
                mutateMapSkippingNewValues(state.allWatchedWildcardDirectories, currentProjects, { onDeleteValue: (existingMap) => existingMap.forEach(closeFileWatcherOf) });
                mutateMapSkippingNewValues(state.allWatchedInputFiles, currentProjects, { onDeleteValue: (existingMap) => existingMap.forEach(closeFileWatcher) });
                mutateMapSkippingNewValues(state.allWatchedPackageJsonFiles, currentProjects, { onDeleteValue: (existingMap) => existingMap.forEach(closeFileWatcher) });
            }
            return state.buildOrder = buildOrder;
        }
        function getBuildOrderFor(state, project, onlyReferences) {
            const resolvedProject = project && resolveProjectName(state, project);
            const buildOrderFromState = getBuildOrder(state);
            if (isCircularBuildOrder(buildOrderFromState))
                return buildOrderFromState;
            if (resolvedProject) {
                const projectPath = toResolvedConfigFilePath(state, resolvedProject);
                const projectIndex = findIndex(buildOrderFromState, (configFileName) => toResolvedConfigFilePath(state, configFileName) === projectPath);
                if (projectIndex === -1)
                    return void 0;
            }
            const buildOrder = resolvedProject ? createBuildOrder(state, [resolvedProject]) : buildOrderFromState;
            Debug.assert(!isCircularBuildOrder(buildOrder));
            Debug.assert(!onlyReferences || resolvedProject !== void 0);
            Debug.assert(!onlyReferences || buildOrder[buildOrder.length - 1] === resolvedProject);
            return onlyReferences ? buildOrder.slice(0, buildOrder.length - 1) : buildOrder;
        }
        function enableCache(state) {
            if (state.cache) {
                disableCache(state);
            }
            const { compilerHost, host } = state;
            const originalReadFileWithCache = state.readFileWithCache;
            const originalGetSourceFile = compilerHost.getSourceFile;
            const { originalReadFile, originalFileExists, originalDirectoryExists, originalCreateDirectory, originalWriteFile, getSourceFileWithCache, readFileWithCache } = changeCompilerHostLikeToUseCache(host, (fileName) => toPath2(state, fileName), (...args) => originalGetSourceFile.call(compilerHost, ...args));
            state.readFileWithCache = readFileWithCache;
            compilerHost.getSourceFile = getSourceFileWithCache;
            state.cache = {
                originalReadFile,
                originalFileExists,
                originalDirectoryExists,
                originalCreateDirectory,
                originalWriteFile,
                originalReadFileWithCache,
                originalGetSourceFile
            };
        }
        function disableCache(state) {
            if (!state.cache)
                return;
            const { cache, host, compilerHost, extendedConfigCache, moduleResolutionCache, typeReferenceDirectiveResolutionCache } = state;
            host.readFile = cache.originalReadFile;
            host.fileExists = cache.originalFileExists;
            host.directoryExists = cache.originalDirectoryExists;
            host.createDirectory = cache.originalCreateDirectory;
            host.writeFile = cache.originalWriteFile;
            compilerHost.getSourceFile = cache.originalGetSourceFile;
            state.readFileWithCache = cache.originalReadFileWithCache;
            extendedConfigCache.clear();
            moduleResolutionCache == null ? void 0 : moduleResolutionCache.clear();
            typeReferenceDirectiveResolutionCache == null ? void 0 : typeReferenceDirectiveResolutionCache.clear();
            state.cache = void 0;
        }
        function clearProjectStatus(state, resolved) {
            state.projectStatus.delete(resolved);
            state.diagnostics.delete(resolved);
        }
        function addProjToQueue({ projectPendingBuild }, proj, reloadLevel) {
            const value = projectPendingBuild.get(proj);
            if (value === void 0) {
                projectPendingBuild.set(proj, reloadLevel);
            }
            else if (value < reloadLevel) {
                projectPendingBuild.set(proj, reloadLevel);
            }
        }
        function setupInitialBuild(state, cancellationToken) {
            if (!state.allProjectBuildPending)
                return;
            state.allProjectBuildPending = false;
            if (state.options.watch)
                reportWatchStatus(state, Diagnostics.Starting_compilation_in_watch_mode);
            enableCache(state);
            const buildOrder = getBuildOrderFromAnyBuildOrder(getBuildOrder(state));
            buildOrder.forEach((configFileName) => state.projectPendingBuild.set(toResolvedConfigFilePath(state, configFileName), 0 /* None */));
            if (cancellationToken) {
                cancellationToken.throwIfCancellationRequested();
            }
        }
        function doneInvalidatedProject(state, projectPath) {
            state.projectPendingBuild.delete(projectPath);
            return state.diagnostics.has(projectPath) ? 1 /* DiagnosticsPresent_OutputsSkipped */ : 0 /* Success */;
        }
        function createUpdateOutputFileStampsProject(state, project, projectPath, config, buildOrder) {
            let updateOutputFileStampsPending = true;
            return {
                kind: 2 /* UpdateOutputFileStamps */,
                project,
                projectPath,
                buildOrder,
                getCompilerOptions: () => config.options,
                getCurrentDirectory: () => state.compilerHost.getCurrentDirectory(),
                updateOutputFileStatmps: () => {
                    updateOutputTimestamps(state, config, projectPath);
                    updateOutputFileStampsPending = false;
                },
                done: () => {
                    if (updateOutputFileStampsPending) {
                        updateOutputTimestamps(state, config, projectPath);
                    }
                    mark("SolutionBuilder::Timestamps only updates");
                    return doneInvalidatedProject(state, projectPath);
                }
            };
        }
        function createBuildOrUpdateInvalidedProject(kind, state, project, projectPath, projectIndex, config, buildOrder) {
            let step = kind === 0 /* Build */ ? 0 /* CreateProgram */ : 4 /* EmitBundle */;
            let program;
            let buildResult;
            let invalidatedProjectOfBundle;
            return kind === 0 /* Build */ ? {
                kind,
                project,
                projectPath,
                buildOrder,
                getCompilerOptions: () => config.options,
                getCurrentDirectory: () => state.compilerHost.getCurrentDirectory(),
                getBuilderProgram: () => withProgramOrUndefined(identity),
                getProgram: () => withProgramOrUndefined((program2) => program2.getProgramOrUndefined()),
                getSourceFile: (fileName) => withProgramOrUndefined((program2) => program2.getSourceFile(fileName)),
                getSourceFiles: () => withProgramOrEmptyArray((program2) => program2.getSourceFiles()),
                getOptionsDiagnostics: (cancellationToken) => withProgramOrEmptyArray((program2) => program2.getOptionsDiagnostics(cancellationToken)),
                getGlobalDiagnostics: (cancellationToken) => withProgramOrEmptyArray((program2) => program2.getGlobalDiagnostics(cancellationToken)),
                getConfigFileParsingDiagnostics: () => withProgramOrEmptyArray((program2) => program2.getConfigFileParsingDiagnostics()),
                getSyntacticDiagnostics: (sourceFile, cancellationToken) => withProgramOrEmptyArray((program2) => program2.getSyntacticDiagnostics(sourceFile, cancellationToken)),
                getAllDependencies: (sourceFile) => withProgramOrEmptyArray((program2) => program2.getAllDependencies(sourceFile)),
                getSemanticDiagnostics: (sourceFile, cancellationToken) => withProgramOrEmptyArray((program2) => program2.getSemanticDiagnostics(sourceFile, cancellationToken)),
                getSemanticDiagnosticsOfNextAffectedFile: (cancellationToken, ignoreSourceFile) => withProgramOrUndefined((program2) => program2.getSemanticDiagnosticsOfNextAffectedFile && program2.getSemanticDiagnosticsOfNextAffectedFile(cancellationToken, ignoreSourceFile)),
                emit: (targetSourceFile, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) => {
                    if (targetSourceFile || emitOnlyDtsFiles) {
                        return withProgramOrUndefined((program2) => {
                            var _a2, _b;
                            return program2.emit(targetSourceFile, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers || ((_b = (_a2 = state.host).getCustomTransformers) == null ? void 0 : _b.call(_a2, project)));
                        });
                    }
                    executeSteps(2 /* SemanticDiagnostics */, cancellationToken);
                    if (step === 5 /* EmitBuildInfo */) {
                        return emitBuildInfo(writeFile2, cancellationToken);
                    }
                    if (step !== 3 /* Emit */)
                        return void 0;
                    return emit(writeFile2, cancellationToken, customTransformers);
                },
                done
            } : {
                kind,
                project,
                projectPath,
                buildOrder,
                getCompilerOptions: () => config.options,
                getCurrentDirectory: () => state.compilerHost.getCurrentDirectory(),
                emit: (writeFile2, customTransformers) => {
                    if (step !== 4 /* EmitBundle */)
                        return invalidatedProjectOfBundle;
                    return emitBundle(writeFile2, customTransformers);
                },
                done
            };
            function done(cancellationToken, writeFile2, customTransformers) {
                executeSteps(8 /* Done */, cancellationToken, writeFile2, customTransformers);
                if (kind === 0 /* Build */)
                    mark("SolutionBuilder::Projects built");
                else
                    mark("SolutionBuilder::Bundles updated");
                return doneInvalidatedProject(state, projectPath);
            }
            function withProgramOrUndefined(action) {
                executeSteps(0 /* CreateProgram */);
                return program && action(program);
            }
            function withProgramOrEmptyArray(action) {
                return withProgramOrUndefined(action) || emptyArray;
            }
            function createProgram2() {
                var _a2, _b;
                Debug.assert(program === void 0);
                if (state.options.dry) {
                    reportStatus(state, Diagnostics.A_non_dry_build_would_build_project_0, project);
                    buildResult = 1 /* Success */;
                    step = 7 /* QueueReferencingProjects */;
                    return;
                }
                if (state.options.verbose)
                    reportStatus(state, Diagnostics.Building_project_0, project);
                if (config.fileNames.length === 0) {
                    reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                    buildResult = 0 /* None */;
                    step = 7 /* QueueReferencingProjects */;
                    return;
                }
                const { host, compilerHost } = state;
                state.projectCompilerOptions = config.options;
                (_a2 = state.moduleResolutionCache) == null ? void 0 : _a2.update(config.options);
                (_b = state.typeReferenceDirectiveResolutionCache) == null ? void 0 : _b.update(config.options);
                program = host.createProgram(config.fileNames, config.options, compilerHost, getOldProgram(state, projectPath, config), getConfigFileParsingDiagnostics(config), config.projectReferences);
                if (state.watch) {
                    state.lastCachedPackageJsonLookups.set(projectPath, state.moduleResolutionCache && map(state.moduleResolutionCache.getPackageJsonInfoCache().entries(), ([path, data]) => [state.host.realpath && data ? toPath2(state, state.host.realpath(path)) : path, data]));
                    state.builderPrograms.set(projectPath, program);
                }
                step++;
            }
            function handleDiagnostics(diagnostics, errorFlags, errorType) {
                if (diagnostics.length) {
                    ({ buildResult, step } = buildErrors(state, projectPath, program, config, diagnostics, errorFlags, errorType));
                }
                else {
                    step++;
                }
            }
            function getSyntaxDiagnostics(cancellationToken) {
                Debug.assertIsDefined(program);
                handleDiagnostics([
                    ...program.getConfigFileParsingDiagnostics(),
                    ...program.getOptionsDiagnostics(cancellationToken),
                    ...program.getGlobalDiagnostics(cancellationToken),
                    ...program.getSyntacticDiagnostics(
                    /*sourceFile*/
                    void 0, cancellationToken)
                ], 8 /* SyntaxErrors */, "Syntactic");
            }
            function getSemanticDiagnostics(cancellationToken) {
                handleDiagnostics(Debug.checkDefined(program).getSemanticDiagnostics(
                /*sourceFile*/
                void 0, cancellationToken), 16 /* TypeErrors */, "Semantic");
            }
            function emit(writeFileCallback, cancellationToken, customTransformers) {
                var _a2, _b, _c;
                Debug.assertIsDefined(program);
                Debug.assert(step === 3 /* Emit */);
                const saved = program.saveEmitState();
                let declDiagnostics;
                const reportDeclarationDiagnostics = (d) => (declDiagnostics || (declDiagnostics = [])).push(d);
                const outputFiles = [];
                const { emitResult } = emitFilesAndReportErrors(program, reportDeclarationDiagnostics, 
                /*write*/
                void 0, 
                /*reportSummary*/
                void 0, (name, text, writeByteOrderMark, _onError, _sourceFiles, data) => outputFiles.push({ name, text, writeByteOrderMark, data }), cancellationToken, 
                /*emitOnlyDts*/
                false, customTransformers || ((_b = (_a2 = state.host).getCustomTransformers) == null ? void 0 : _b.call(_a2, project)));
                if (declDiagnostics) {
                    program.restoreEmitState(saved);
                    ({ buildResult, step } = buildErrors(state, projectPath, program, config, declDiagnostics, 32 /* DeclarationEmitErrors */, "Declaration file"));
                    return {
                        emitSkipped: true,
                        diagnostics: emitResult.diagnostics
                    };
                }
                const { host, compilerHost } = state;
                const resultFlags = ((_c = program.hasChangedEmitSignature) == null ? void 0 : _c.call(program)) ? 0 /* None */ : 2 /* DeclarationOutputUnchanged */;
                const emitterDiagnostics = createDiagnosticCollection();
                const emittedOutputs = /* @__PURE__ */ new Map();
                const options = program.getCompilerOptions();
                const isIncremental = isIncrementalCompilation(options);
                let outputTimeStampMap;
                let now;
                outputFiles.forEach(({ name, text, writeByteOrderMark, data }) => {
                    const path = toPath2(state, name);
                    emittedOutputs.set(toPath2(state, name), name);
                    if (data == null ? void 0 : data.buildInfo)
                        setBuildInfo(state, data.buildInfo, projectPath, options, resultFlags);
                    const modifiedTime = (data == null ? void 0 : data.differsOnlyInMap) ? getModifiedTime(state.host, name) : void 0;
                    writeFile(writeFileCallback ? { writeFile: writeFileCallback } : compilerHost, emitterDiagnostics, name, text, writeByteOrderMark);
                    if (data == null ? void 0 : data.differsOnlyInMap)
                        state.host.setModifiedTime(name, modifiedTime);
                    else if (!isIncremental && state.watch) {
                        (outputTimeStampMap || (outputTimeStampMap = getOutputTimeStampMap(state, projectPath))).set(path, now || (now = getCurrentTime(state.host)));
                    }
                });
                finishEmit(emitterDiagnostics, emittedOutputs, outputFiles.length ? outputFiles[0].name : getFirstProjectOutput(config, !host.useCaseSensitiveFileNames()), resultFlags);
                return emitResult;
            }
            function emitBuildInfo(writeFileCallback, cancellationToken) {
                Debug.assertIsDefined(program);
                Debug.assert(step === 5 /* EmitBuildInfo */);
                const emitResult = program.emitBuildInfo((name, text, writeByteOrderMark, onError, sourceFiles, data) => {
                    if (data == null ? void 0 : data.buildInfo)
                        setBuildInfo(state, data.buildInfo, projectPath, program.getCompilerOptions(), 2 /* DeclarationOutputUnchanged */);
                    if (writeFileCallback)
                        writeFileCallback(name, text, writeByteOrderMark, onError, sourceFiles, data);
                    else
                        state.compilerHost.writeFile(name, text, writeByteOrderMark, onError, sourceFiles, data);
                }, cancellationToken);
                if (emitResult.diagnostics.length) {
                    reportErrors(state, emitResult.diagnostics);
                    state.diagnostics.set(projectPath, [...state.diagnostics.get(projectPath), ...emitResult.diagnostics]);
                    buildResult = 64 /* EmitErrors */ & buildResult;
                }
                if (emitResult.emittedFiles && state.write) {
                    emitResult.emittedFiles.forEach((name) => listEmittedFile(state, config, name));
                }
                afterProgramDone(state, program, config);
                step = 7 /* QueueReferencingProjects */;
                return emitResult;
            }
            function finishEmit(emitterDiagnostics, emittedOutputs, oldestOutputFileName, resultFlags) {
                const emitDiagnostics = emitterDiagnostics.getDiagnostics();
                if (emitDiagnostics.length) {
                    ({ buildResult, step } = buildErrors(state, projectPath, program, config, emitDiagnostics, 64 /* EmitErrors */, "Emit"));
                    return emitDiagnostics;
                }
                if (state.write) {
                    emittedOutputs.forEach((name) => listEmittedFile(state, config, name));
                }
                updateOutputTimestampsWorker(state, config, projectPath, Diagnostics.Updating_unchanged_output_timestamps_of_project_0, emittedOutputs);
                state.diagnostics.delete(projectPath);
                state.projectStatus.set(projectPath, {
                    type: 1 /* UpToDate */,
                    oldestOutputFileName
                });
                afterProgramDone(state, program, config);
                step = 7 /* QueueReferencingProjects */;
                buildResult = resultFlags;
                return emitDiagnostics;
            }
            function emitBundle(writeFileCallback, customTransformers) {
                var _a2, _b, _c, _d;
                Debug.assert(kind === 1 /* UpdateBundle */);
                if (state.options.dry) {
                    reportStatus(state, Diagnostics.A_non_dry_build_would_update_output_of_project_0, project);
                    buildResult = 1 /* Success */;
                    step = 7 /* QueueReferencingProjects */;
                    return void 0;
                }
                if (state.options.verbose)
                    reportStatus(state, Diagnostics.Updating_output_of_project_0, project);
                const { compilerHost } = state;
                state.projectCompilerOptions = config.options;
                (_b = (_a2 = state.host).beforeEmitBundle) == null ? void 0 : _b.call(_a2, config);
                const outputFiles = emitUsingBuildInfo(config, compilerHost, (ref) => {
                    const refName = resolveProjectName(state, ref.path);
                    return parseConfigFile(state, refName, toResolvedConfigFilePath(state, refName));
                }, customTransformers || ((_d = (_c = state.host).getCustomTransformers) == null ? void 0 : _d.call(_c, project)));
                if (isString(outputFiles)) {
                    reportStatus(state, Diagnostics.Cannot_update_output_of_project_0_because_there_was_error_reading_file_1, project, relName(state, outputFiles));
                    step = 6 /* BuildInvalidatedProjectOfBundle */;
                    return invalidatedProjectOfBundle = createBuildOrUpdateInvalidedProject(0 /* Build */, state, project, projectPath, projectIndex, config, buildOrder);
                }
                Debug.assert(!!outputFiles.length);
                const emitterDiagnostics = createDiagnosticCollection();
                const emittedOutputs = /* @__PURE__ */ new Map();
                let resultFlags = 2 /* DeclarationOutputUnchanged */;
                const existingBuildInfo = state.buildInfoCache.get(projectPath).buildInfo || void 0;
                outputFiles.forEach(({ name, text, writeByteOrderMark, data }) => {
                    var _a3, _b2;
                    emittedOutputs.set(toPath2(state, name), name);
                    if (data == null ? void 0 : data.buildInfo) {
                        if (((_a3 = data.buildInfo.program) == null ? void 0 : _a3.outSignature) !== ((_b2 = existingBuildInfo == null ? void 0 : existingBuildInfo.program) == null ? void 0 : _b2.outSignature)) {
                            resultFlags &= ~2 /* DeclarationOutputUnchanged */;
                        }
                        setBuildInfo(state, data.buildInfo, projectPath, config.options, resultFlags);
                    }
                    writeFile(writeFileCallback ? { writeFile: writeFileCallback } : compilerHost, emitterDiagnostics, name, text, writeByteOrderMark);
                });
                const emitDiagnostics = finishEmit(emitterDiagnostics, emittedOutputs, outputFiles[0].name, resultFlags);
                return { emitSkipped: false, diagnostics: emitDiagnostics };
            }
            function executeSteps(till, cancellationToken, writeFile2, customTransformers) {
                while (step <= till && step < 8 /* Done */) {
                    const currentStep = step;
                    switch (step) {
                        case 0 /* CreateProgram */:
                            createProgram2();
                            break;
                        case 1 /* SyntaxDiagnostics */:
                            getSyntaxDiagnostics(cancellationToken);
                            break;
                        case 2 /* SemanticDiagnostics */:
                            getSemanticDiagnostics(cancellationToken);
                            break;
                        case 3 /* Emit */:
                            emit(writeFile2, cancellationToken, customTransformers);
                            break;
                        case 5 /* EmitBuildInfo */:
                            emitBuildInfo(writeFile2, cancellationToken);
                            break;
                        case 4 /* EmitBundle */:
                            emitBundle(writeFile2, customTransformers);
                            break;
                        case 6 /* BuildInvalidatedProjectOfBundle */:
                            Debug.checkDefined(invalidatedProjectOfBundle).done(cancellationToken, writeFile2, customTransformers);
                            step = 8 /* Done */;
                            break;
                        case 7 /* QueueReferencingProjects */:
                            queueReferencingProjects(state, project, projectPath, projectIndex, config, buildOrder, Debug.checkDefined(buildResult));
                            step++;
                            break;
                        case 8 /* Done */:
                        default:
                            assertType(step);
                    }
                    Debug.assert(step > currentStep);
                }
            }
        }
        function needsBuild({ options }, status, config) {
            if (status.type !== 3 /* OutOfDateWithPrepend */ || options.force)
                return true;
            return config.fileNames.length === 0 || !!getConfigFileParsingDiagnostics(config).length || !isIncrementalCompilation(config.options);
        }
        function getNextInvalidatedProjectCreateInfo(state, buildOrder, reportQueue) {
            if (!state.projectPendingBuild.size)
                return void 0;
            if (isCircularBuildOrder(buildOrder))
                return void 0;
            const { options, projectPendingBuild } = state;
            for (let projectIndex = 0; projectIndex < buildOrder.length; projectIndex++) {
                const project = buildOrder[projectIndex];
                const projectPath = toResolvedConfigFilePath(state, project);
                const reloadLevel = state.projectPendingBuild.get(projectPath);
                if (reloadLevel === void 0)
                    continue;
                if (reportQueue) {
                    reportQueue = false;
                    reportBuildQueue(state, buildOrder);
                }
                const config = parseConfigFile(state, project, projectPath);
                if (!config) {
                    reportParseConfigFileDiagnostic(state, projectPath);
                    projectPendingBuild.delete(projectPath);
                    continue;
                }
                if (reloadLevel === 2 /* Full */) {
                    watchConfigFile(state, project, projectPath, config);
                    watchExtendedConfigFiles(state, projectPath, config);
                    watchWildCardDirectories(state, project, projectPath, config);
                    watchInputFiles(state, project, projectPath, config);
                    watchPackageJsonFiles(state, project, projectPath, config);
                }
                else if (reloadLevel === 1 /* Partial */) {
                    config.fileNames = getFileNamesFromConfigSpecs(config.options.configFile.configFileSpecs, getDirectoryPath(project), config.options, state.parseConfigFileHost);
                    updateErrorForNoInputFiles(config.fileNames, project, config.options.configFile.configFileSpecs, config.errors, canJsonReportNoInputFiles(config.raw));
                    watchInputFiles(state, project, projectPath, config);
                    watchPackageJsonFiles(state, project, projectPath, config);
                }
                const status = getUpToDateStatus(state, config, projectPath);
                if (!options.force) {
                    if (status.type === 1 /* UpToDate */) {
                        verboseReportProjectStatus(state, project, status);
                        reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                        projectPendingBuild.delete(projectPath);
                        if (options.dry) {
                            reportStatus(state, Diagnostics.Project_0_is_up_to_date, project);
                        }
                        continue;
                    }
                    if (status.type === 2 /* UpToDateWithUpstreamTypes */ || status.type === 15 /* UpToDateWithInputFileText */) {
                        reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                        return {
                            kind: 2 /* UpdateOutputFileStamps */,
                            status,
                            project,
                            projectPath,
                            projectIndex,
                            config
                        };
                    }
                }
                if (status.type === 12 /* UpstreamBlocked */) {
                    verboseReportProjectStatus(state, project, status);
                    reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                    projectPendingBuild.delete(projectPath);
                    if (options.verbose) {
                        reportStatus(state, status.upstreamProjectBlocked ? Diagnostics.Skipping_build_of_project_0_because_its_dependency_1_was_not_built : Diagnostics.Skipping_build_of_project_0_because_its_dependency_1_has_errors, project, status.upstreamProjectName);
                    }
                    continue;
                }
                if (status.type === 16 /* ContainerOnly */) {
                    verboseReportProjectStatus(state, project, status);
                    reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                    projectPendingBuild.delete(projectPath);
                    continue;
                }
                return {
                    kind: needsBuild(state, status, config) ? 0 /* Build */ : 1 /* UpdateBundle */,
                    status,
                    project,
                    projectPath,
                    projectIndex,
                    config
                };
            }
            return void 0;
        }
        function createInvalidatedProjectWithInfo(state, info, buildOrder) {
            verboseReportProjectStatus(state, info.project, info.status);
            return info.kind !== 2 /* UpdateOutputFileStamps */ ? createBuildOrUpdateInvalidedProject(info.kind, state, info.project, info.projectPath, info.projectIndex, info.config, buildOrder) : createUpdateOutputFileStampsProject(state, info.project, info.projectPath, info.config, buildOrder);
        }
        function getNextInvalidatedProject(state, buildOrder, reportQueue) {
            const info = getNextInvalidatedProjectCreateInfo(state, buildOrder, reportQueue);
            if (!info)
                return info;
            return createInvalidatedProjectWithInfo(state, info, buildOrder);
        }
        function listEmittedFile({ write }, proj, file) {
            if (write && proj.options.listEmittedFiles) {
                write(`TSFILE: ${file}`);
            }
        }
        function getOldProgram({ options, builderPrograms, compilerHost }, proj, parsed) {
            if (options.force)
                return void 0;
            const value = builderPrograms.get(proj);
            if (value)
                return value;
            return readBuilderProgram(parsed.options, compilerHost);
        }
        function afterProgramDone(state, program, config) {
            if (program) {
                if (state.write)
                    listFiles(program, state.write);
                if (state.host.afterProgramEmitAndDiagnostics) {
                    state.host.afterProgramEmitAndDiagnostics(program);
                }
                program.releaseProgram();
            }
            else if (state.host.afterEmitBundle) {
                state.host.afterEmitBundle(config);
            }
            state.projectCompilerOptions = state.baseCompilerOptions;
        }
        function buildErrors(state, resolvedPath, program, config, diagnostics, buildResult, errorType) {
            const canEmitBuildInfo = program && !outFile(program.getCompilerOptions());
            reportAndStoreErrors(state, resolvedPath, diagnostics);
            state.projectStatus.set(resolvedPath, { type: 0 /* Unbuildable */, reason: `${errorType} errors` });
            if (canEmitBuildInfo)
                return { buildResult, step: 5 /* EmitBuildInfo */ };
            afterProgramDone(state, program, config);
            return { buildResult, step: 7 /* QueueReferencingProjects */ };
        }
        function isFileWatcherWithModifiedTime(value) {
            return !!value.watcher;
        }
        function getModifiedTime2(state, fileName) {
            const path = toPath2(state, fileName);
            const existing = state.filesWatched.get(path);
            if (state.watch && !!existing) {
                if (!isFileWatcherWithModifiedTime(existing))
                    return existing;
                if (existing.modifiedTime)
                    return existing.modifiedTime;
            }
            const result = getModifiedTime(state.host, fileName);
            if (state.watch) {
                if (existing)
                    existing.modifiedTime = result;
                else
                    state.filesWatched.set(path, result);
            }
            return result;
        }
        function watchFile(state, file, callback, pollingInterval, options, watchType, project) {
            const path = toPath2(state, file);
            const existing = state.filesWatched.get(path);
            if (existing && isFileWatcherWithModifiedTime(existing)) {
                existing.callbacks.push(callback);
            }
            else {
                const watcher = state.watchFile(file, (fileName, eventKind, modifiedTime) => {
                    const existing2 = Debug.checkDefined(state.filesWatched.get(path));
                    Debug.assert(isFileWatcherWithModifiedTime(existing2));
                    existing2.modifiedTime = modifiedTime;
                    existing2.callbacks.forEach((cb) => cb(fileName, eventKind, modifiedTime));
                }, pollingInterval, options, watchType, project);
                state.filesWatched.set(path, { callbacks: [callback], watcher, modifiedTime: existing });
            }
            return {
                close: () => {
                    const existing2 = Debug.checkDefined(state.filesWatched.get(path));
                    Debug.assert(isFileWatcherWithModifiedTime(existing2));
                    if (existing2.callbacks.length === 1) {
                        state.filesWatched.delete(path);
                        closeFileWatcherOf(existing2);
                    }
                    else {
                        unorderedRemoveItem(existing2.callbacks, callback);
                    }
                }
            };
        }
        function getOutputTimeStampMap(state, resolvedConfigFilePath) {
            if (!state.watch)
                return void 0;
            let result = state.outputTimeStamps.get(resolvedConfigFilePath);
            if (!result)
                state.outputTimeStamps.set(resolvedConfigFilePath, result = /* @__PURE__ */ new Map());
            return result;
        }
        function setBuildInfo(state, buildInfo, resolvedConfigPath, options, resultFlags) {
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(options);
            const existing = getBuildInfoCacheEntry(state, buildInfoPath, resolvedConfigPath);
            const modifiedTime = getCurrentTime(state.host);
            if (existing) {
                existing.buildInfo = buildInfo;
                existing.modifiedTime = modifiedTime;
                if (!(resultFlags & 2 /* DeclarationOutputUnchanged */))
                    existing.latestChangedDtsTime = modifiedTime;
            }
            else {
                state.buildInfoCache.set(resolvedConfigPath, {
                    path: toPath2(state, buildInfoPath),
                    buildInfo,
                    modifiedTime,
                    latestChangedDtsTime: resultFlags & 2 /* DeclarationOutputUnchanged */ ? void 0 : modifiedTime
                });
            }
        }
        function getBuildInfoCacheEntry(state, buildInfoPath, resolvedConfigPath) {
            const path = toPath2(state, buildInfoPath);
            const existing = state.buildInfoCache.get(resolvedConfigPath);
            return (existing == null ? void 0 : existing.path) === path ? existing : void 0;
        }
        function getBuildInfo3(state, buildInfoPath, resolvedConfigPath, modifiedTime) {
            const path = toPath2(state, buildInfoPath);
            const existing = state.buildInfoCache.get(resolvedConfigPath);
            if (existing !== void 0 && existing.path === path) {
                return existing.buildInfo || void 0;
            }
            const value = state.readFileWithCache(buildInfoPath);
            const buildInfo = value ? getBuildInfo(buildInfoPath, value) : void 0;
            state.buildInfoCache.set(resolvedConfigPath, { path, buildInfo: buildInfo || false, modifiedTime: modifiedTime || missingFileModifiedTime });
            return buildInfo;
        }
        function checkConfigFileUpToDateStatus(state, configFile, oldestOutputFileTime, oldestOutputFileName) {
            const tsconfigTime = getModifiedTime2(state, configFile);
            if (oldestOutputFileTime < tsconfigTime) {
                return {
                    type: 6 /* OutOfDateWithSelf */,
                    outOfDateOutputFileName: oldestOutputFileName,
                    newerInputFileName: configFile
                };
            }
        }
        function getUpToDateStatusWorker(state, project, resolvedPath) {
            var _a2, _b;
            if (!project.fileNames.length && !canJsonReportNoInputFiles(project.raw)) {
                return {
                    type: 16 /* ContainerOnly */
                };
            }
            let referenceStatuses;
            const force = !!state.options.force;
            if (project.projectReferences) {
                state.projectStatus.set(resolvedPath, { type: 13 /* ComputingUpstream */ });
                for (const ref of project.projectReferences) {
                    const resolvedRef = resolveProjectReferencePath(ref);
                    const resolvedRefPath = toResolvedConfigFilePath(state, resolvedRef);
                    const resolvedConfig = parseConfigFile(state, resolvedRef, resolvedRefPath);
                    const refStatus = getUpToDateStatus(state, resolvedConfig, resolvedRefPath);
                    if (refStatus.type === 13 /* ComputingUpstream */ || refStatus.type === 16 /* ContainerOnly */) {
                        continue;
                    }
                    if (refStatus.type === 0 /* Unbuildable */ || refStatus.type === 12 /* UpstreamBlocked */) {
                        return {
                            type: 12 /* UpstreamBlocked */,
                            upstreamProjectName: ref.path,
                            upstreamProjectBlocked: refStatus.type === 12 /* UpstreamBlocked */
                        };
                    }
                    if (refStatus.type !== 1 /* UpToDate */) {
                        return {
                            type: 11 /* UpstreamOutOfDate */,
                            upstreamProjectName: ref.path
                        };
                    }
                    if (!force)
                        (referenceStatuses || (referenceStatuses = [])).push({ ref, refStatus, resolvedRefPath, resolvedConfig });
                }
            }
            if (force)
                return { type: 17 /* ForceBuild */ };
            const { host } = state;
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(project.options);
            let oldestOutputFileName;
            let oldestOutputFileTime = maximumDate;
            let buildInfoTime;
            let buildInfoProgram;
            let buildInfoVersionMap;
            if (buildInfoPath) {
                const buildInfoCacheEntry2 = getBuildInfoCacheEntry(state, buildInfoPath, resolvedPath);
                buildInfoTime = (buildInfoCacheEntry2 == null ? void 0 : buildInfoCacheEntry2.modifiedTime) || getModifiedTime(host, buildInfoPath);
                if (buildInfoTime === missingFileModifiedTime) {
                    if (!buildInfoCacheEntry2) {
                        state.buildInfoCache.set(resolvedPath, {
                            path: toPath2(state, buildInfoPath),
                            buildInfo: false,
                            modifiedTime: buildInfoTime
                        });
                    }
                    return {
                        type: 4 /* OutputMissing */,
                        missingOutputFileName: buildInfoPath
                    };
                }
                const buildInfo = getBuildInfo3(state, buildInfoPath, resolvedPath, buildInfoTime);
                if (!buildInfo) {
                    return {
                        type: 5 /* ErrorReadingFile */,
                        fileName: buildInfoPath
                    };
                }
                if ((buildInfo.bundle || buildInfo.program) && buildInfo.version !== version) {
                    return {
                        type: 14 /* TsVersionOutputOfDate */,
                        version: buildInfo.version
                    };
                }
                if (buildInfo.program) {
                    if (((_a2 = buildInfo.program.changeFileSet) == null ? void 0 : _a2.length) || (!project.options.noEmit ? (_b = buildInfo.program.affectedFilesPendingEmit) == null ? void 0 : _b.length : some(buildInfo.program.semanticDiagnosticsPerFile, isArray))) {
                        return {
                            type: 8 /* OutOfDateBuildInfo */,
                            buildInfoFile: buildInfoPath
                        };
                    }
                    if (!project.options.noEmit && getPendingEmitKind(project.options, buildInfo.program.options || {})) {
                        return {
                            type: 9 /* OutOfDateOptions */,
                            buildInfoFile: buildInfoPath
                        };
                    }
                    buildInfoProgram = buildInfo.program;
                }
                oldestOutputFileTime = buildInfoTime;
                oldestOutputFileName = buildInfoPath;
            }
            let newestInputFileName = void 0;
            let newestInputFileTime = minimumDate;
            let pseudoInputUpToDate = false;
            const seenRoots = /* @__PURE__ */ new Set();
            for (const inputFile of project.fileNames) {
                const inputTime = getModifiedTime2(state, inputFile);
                if (inputTime === missingFileModifiedTime) {
                    return {
                        type: 0 /* Unbuildable */,
                        reason: `${inputFile} does not exist`
                    };
                }
                if (buildInfoTime && buildInfoTime < inputTime) {
                    let version2;
                    let currentVersion;
                    if (buildInfoProgram) {
                        if (!buildInfoVersionMap)
                            buildInfoVersionMap = getBuildInfoFileVersionMap(buildInfoProgram, buildInfoPath, host);
                        version2 = buildInfoVersionMap.fileInfos.get(toPath2(state, inputFile));
                        const text = version2 ? state.readFileWithCache(inputFile) : void 0;
                        currentVersion = text !== void 0 ? getSourceFileVersionAsHashFromText(host, text) : void 0;
                        if (version2 && version2 === currentVersion)
                            pseudoInputUpToDate = true;
                    }
                    if (!version2 || version2 !== currentVersion) {
                        return {
                            type: 6 /* OutOfDateWithSelf */,
                            outOfDateOutputFileName: buildInfoPath,
                            newerInputFileName: inputFile
                        };
                    }
                }
                if (inputTime > newestInputFileTime) {
                    newestInputFileName = inputFile;
                    newestInputFileTime = inputTime;
                }
                if (buildInfoProgram)
                    seenRoots.add(toPath2(state, inputFile));
            }
            if (buildInfoProgram) {
                if (!buildInfoVersionMap)
                    buildInfoVersionMap = getBuildInfoFileVersionMap(buildInfoProgram, buildInfoPath, host);
                for (const existingRoot of buildInfoVersionMap.roots) {
                    if (!seenRoots.has(existingRoot)) {
                        return {
                            type: 10 /* OutOfDateRoots */,
                            buildInfoFile: buildInfoPath,
                            inputFile: existingRoot
                        };
                    }
                }
            }
            if (!buildInfoPath) {
                const outputs = getAllProjectOutputs(project, !host.useCaseSensitiveFileNames());
                const outputTimeStampMap = getOutputTimeStampMap(state, resolvedPath);
                for (const output of outputs) {
                    const path = toPath2(state, output);
                    let outputTime = outputTimeStampMap == null ? void 0 : outputTimeStampMap.get(path);
                    if (!outputTime) {
                        outputTime = getModifiedTime(state.host, output);
                        outputTimeStampMap == null ? void 0 : outputTimeStampMap.set(path, outputTime);
                    }
                    if (outputTime === missingFileModifiedTime) {
                        return {
                            type: 4 /* OutputMissing */,
                            missingOutputFileName: output
                        };
                    }
                    if (outputTime < newestInputFileTime) {
                        return {
                            type: 6 /* OutOfDateWithSelf */,
                            outOfDateOutputFileName: output,
                            newerInputFileName: newestInputFileName
                        };
                    }
                    if (outputTime < oldestOutputFileTime) {
                        oldestOutputFileTime = outputTime;
                        oldestOutputFileName = output;
                    }
                }
            }
            const buildInfoCacheEntry = state.buildInfoCache.get(resolvedPath);
            let pseudoUpToDate = false;
            let usesPrepend = false;
            let upstreamChangedProject;
            if (referenceStatuses) {
                for (const { ref, refStatus, resolvedConfig, resolvedRefPath } of referenceStatuses) {
                    usesPrepend = usesPrepend || !!ref.prepend;
                    if (refStatus.newestInputFileTime && refStatus.newestInputFileTime <= oldestOutputFileTime) {
                        continue;
                    }
                    if (buildInfoCacheEntry && hasSameBuildInfo(state, buildInfoCacheEntry, resolvedRefPath)) {
                        return {
                            type: 7 /* OutOfDateWithUpstream */,
                            outOfDateOutputFileName: buildInfoPath,
                            newerProjectName: ref.path
                        };
                    }
                    const newestDeclarationFileContentChangedTime = getLatestChangedDtsTime(state, resolvedConfig.options, resolvedRefPath);
                    if (newestDeclarationFileContentChangedTime && newestDeclarationFileContentChangedTime <= oldestOutputFileTime) {
                        pseudoUpToDate = true;
                        upstreamChangedProject = ref.path;
                        continue;
                    }
                    Debug.assert(oldestOutputFileName !== void 0, "Should have an oldest output filename here");
                    return {
                        type: 7 /* OutOfDateWithUpstream */,
                        outOfDateOutputFileName: oldestOutputFileName,
                        newerProjectName: ref.path
                    };
                }
            }
            const configStatus = checkConfigFileUpToDateStatus(state, project.options.configFilePath, oldestOutputFileTime, oldestOutputFileName);
            if (configStatus)
                return configStatus;
            const extendedConfigStatus = forEach(project.options.configFile.extendedSourceFiles || emptyArray, (configFile) => checkConfigFileUpToDateStatus(state, configFile, oldestOutputFileTime, oldestOutputFileName));
            if (extendedConfigStatus)
                return extendedConfigStatus;
            const dependentPackageFileStatus = forEach(state.lastCachedPackageJsonLookups.get(resolvedPath) || emptyArray, ([path]) => checkConfigFileUpToDateStatus(state, path, oldestOutputFileTime, oldestOutputFileName));
            if (dependentPackageFileStatus)
                return dependentPackageFileStatus;
            if (usesPrepend && pseudoUpToDate) {
                return {
                    type: 3 /* OutOfDateWithPrepend */,
                    outOfDateOutputFileName: oldestOutputFileName,
                    newerProjectName: upstreamChangedProject
                };
            }
            return {
                type: pseudoUpToDate ? 2 /* UpToDateWithUpstreamTypes */ : pseudoInputUpToDate ? 15 /* UpToDateWithInputFileText */ : 1 /* UpToDate */,
                newestInputFileTime,
                newestInputFileName,
                oldestOutputFileName
            };
        }
        function hasSameBuildInfo(state, buildInfoCacheEntry, resolvedRefPath) {
            const refBuildInfo = state.buildInfoCache.get(resolvedRefPath);
            return refBuildInfo.path === buildInfoCacheEntry.path;
        }
        function getUpToDateStatus(state, project, resolvedPath) {
            if (project === void 0) {
                return { type: 0 /* Unbuildable */, reason: "File deleted mid-build" };
            }
            const prior = state.projectStatus.get(resolvedPath);
            if (prior !== void 0) {
                return prior;
            }
            mark("SolutionBuilder::beforeUpToDateCheck");
            const actual = getUpToDateStatusWorker(state, project, resolvedPath);
            mark("SolutionBuilder::afterUpToDateCheck");
            measure("SolutionBuilder::Up-to-date check", "SolutionBuilder::beforeUpToDateCheck", "SolutionBuilder::afterUpToDateCheck");
            state.projectStatus.set(resolvedPath, actual);
            return actual;
        }
        function updateOutputTimestampsWorker(state, proj, projectPath, verboseMessage, skipOutputs) {
            if (proj.options.noEmit)
                return;
            let now;
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(proj.options);
            if (buildInfoPath) {
                if (!(skipOutputs == null ? void 0 : skipOutputs.has(toPath2(state, buildInfoPath)))) {
                    if (!!state.options.verbose)
                        reportStatus(state, verboseMessage, proj.options.configFilePath);
                    state.host.setModifiedTime(buildInfoPath, now = getCurrentTime(state.host));
                    getBuildInfoCacheEntry(state, buildInfoPath, projectPath).modifiedTime = now;
                }
                state.outputTimeStamps.delete(projectPath);
                return;
            }
            const { host } = state;
            const outputs = getAllProjectOutputs(proj, !host.useCaseSensitiveFileNames());
            const outputTimeStampMap = getOutputTimeStampMap(state, projectPath);
            const modifiedOutputs = outputTimeStampMap ? /* @__PURE__ */ new Set() : void 0;
            if (!skipOutputs || outputs.length !== skipOutputs.size) {
                let reportVerbose = !!state.options.verbose;
                for (const file of outputs) {
                    const path = toPath2(state, file);
                    if (skipOutputs == null ? void 0 : skipOutputs.has(path))
                        continue;
                    if (reportVerbose) {
                        reportVerbose = false;
                        reportStatus(state, verboseMessage, proj.options.configFilePath);
                    }
                    host.setModifiedTime(file, now || (now = getCurrentTime(state.host)));
                    if (outputTimeStampMap) {
                        outputTimeStampMap.set(path, now);
                        modifiedOutputs.add(path);
                    }
                }
            }
            outputTimeStampMap == null ? void 0 : outputTimeStampMap.forEach((_value, key) => {
                if (!(skipOutputs == null ? void 0 : skipOutputs.has(key)) && !modifiedOutputs.has(key))
                    outputTimeStampMap.delete(key);
            });
        }
        function getLatestChangedDtsTime(state, options, resolvedConfigPath) {
            if (!options.composite)
                return void 0;
            const entry = Debug.checkDefined(state.buildInfoCache.get(resolvedConfigPath));
            if (entry.latestChangedDtsTime !== void 0)
                return entry.latestChangedDtsTime || void 0;
            const latestChangedDtsTime = entry.buildInfo && entry.buildInfo.program && entry.buildInfo.program.latestChangedDtsFile ? state.host.getModifiedTime(getNormalizedAbsolutePath(entry.buildInfo.program.latestChangedDtsFile, getDirectoryPath(entry.path))) : void 0;
            entry.latestChangedDtsTime = latestChangedDtsTime || false;
            return latestChangedDtsTime;
        }
        function updateOutputTimestamps(state, proj, resolvedPath) {
            if (state.options.dry) {
                return reportStatus(state, Diagnostics.A_non_dry_build_would_update_timestamps_for_output_of_project_0, proj.options.configFilePath);
            }
            updateOutputTimestampsWorker(state, proj, resolvedPath, Diagnostics.Updating_output_timestamps_of_project_0);
            state.projectStatus.set(resolvedPath, {
                type: 1 /* UpToDate */,
                oldestOutputFileName: getFirstProjectOutput(proj, !state.host.useCaseSensitiveFileNames())
            });
        }
        function queueReferencingProjects(state, project, projectPath, projectIndex, config, buildOrder, buildResult) {
            if (buildResult & 124 /* AnyErrors */)
                return;
            if (!config.options.composite)
                return;
            for (let index = projectIndex + 1; index < buildOrder.length; index++) {
                const nextProject = buildOrder[index];
                const nextProjectPath = toResolvedConfigFilePath(state, nextProject);
                if (state.projectPendingBuild.has(nextProjectPath))
                    continue;
                const nextProjectConfig = parseConfigFile(state, nextProject, nextProjectPath);
                if (!nextProjectConfig || !nextProjectConfig.projectReferences)
                    continue;
                for (const ref of nextProjectConfig.projectReferences) {
                    const resolvedRefPath = resolveProjectName(state, ref.path);
                    if (toResolvedConfigFilePath(state, resolvedRefPath) !== projectPath)
                        continue;
                    const status = state.projectStatus.get(nextProjectPath);
                    if (status) {
                        switch (status.type) {
                            case 1 /* UpToDate */:
                                if (buildResult & 2 /* DeclarationOutputUnchanged */) {
                                    if (ref.prepend) {
                                        state.projectStatus.set(nextProjectPath, {
                                            type: 3 /* OutOfDateWithPrepend */,
                                            outOfDateOutputFileName: status.oldestOutputFileName,
                                            newerProjectName: project
                                        });
                                    }
                                    else {
                                        status.type = 2 /* UpToDateWithUpstreamTypes */;
                                    }
                                    break;
                                }
                            case 15 /* UpToDateWithInputFileText */:
                            case 2 /* UpToDateWithUpstreamTypes */:
                            case 3 /* OutOfDateWithPrepend */:
                                if (!(buildResult & 2 /* DeclarationOutputUnchanged */)) {
                                    state.projectStatus.set(nextProjectPath, {
                                        type: 7 /* OutOfDateWithUpstream */,
                                        outOfDateOutputFileName: status.type === 3 /* OutOfDateWithPrepend */ ? status.outOfDateOutputFileName : status.oldestOutputFileName,
                                        newerProjectName: project
                                    });
                                }
                                break;
                            case 12 /* UpstreamBlocked */:
                                if (toResolvedConfigFilePath(state, resolveProjectName(state, status.upstreamProjectName)) === projectPath) {
                                    clearProjectStatus(state, nextProjectPath);
                                }
                                break;
                        }
                    }
                    addProjToQueue(state, nextProjectPath, 0 /* None */);
                    break;
                }
            }
        }
        function build(state, project, cancellationToken, writeFile2, getCustomTransformers, onlyReferences) {
            mark("SolutionBuilder::beforeBuild");
            const result = buildWorker(state, project, cancellationToken, writeFile2, getCustomTransformers, onlyReferences);
            mark("SolutionBuilder::afterBuild");
            measure("SolutionBuilder::Build", "SolutionBuilder::beforeBuild", "SolutionBuilder::afterBuild");
            return result;
        }
        function buildWorker(state, project, cancellationToken, writeFile2, getCustomTransformers, onlyReferences) {
            const buildOrder = getBuildOrderFor(state, project, onlyReferences);
            if (!buildOrder)
                return 3 /* InvalidProject_OutputsSkipped */;
            setupInitialBuild(state, cancellationToken);
            let reportQueue = true;
            let successfulProjects = 0;
            while (true) {
                const invalidatedProject = getNextInvalidatedProject(state, buildOrder, reportQueue);
                if (!invalidatedProject)
                    break;
                reportQueue = false;
                invalidatedProject.done(cancellationToken, writeFile2, getCustomTransformers == null ? void 0 : getCustomTransformers(invalidatedProject.project));
                if (!state.diagnostics.has(invalidatedProject.projectPath))
                    successfulProjects++;
            }
            disableCache(state);
            reportErrorSummary(state, buildOrder);
            startWatching(state, buildOrder);
            return isCircularBuildOrder(buildOrder) ? 4 /* ProjectReferenceCycle_OutputsSkipped */ : !buildOrder.some((p) => state.diagnostics.has(toResolvedConfigFilePath(state, p))) ? 0 /* Success */ : successfulProjects ? 2 /* DiagnosticsPresent_OutputsGenerated */ : 1 /* DiagnosticsPresent_OutputsSkipped */;
        }
        function clean(state, project, onlyReferences) {
            mark("SolutionBuilder::beforeClean");
            const result = cleanWorker(state, project, onlyReferences);
            mark("SolutionBuilder::afterClean");
            measure("SolutionBuilder::Clean", "SolutionBuilder::beforeClean", "SolutionBuilder::afterClean");
            return result;
        }
        function cleanWorker(state, project, onlyReferences) {
            const buildOrder = getBuildOrderFor(state, project, onlyReferences);
            if (!buildOrder)
                return 3 /* InvalidProject_OutputsSkipped */;
            if (isCircularBuildOrder(buildOrder)) {
                reportErrors(state, buildOrder.circularDiagnostics);
                return 4 /* ProjectReferenceCycle_OutputsSkipped */;
            }
            const { options, host } = state;
            const filesToDelete = options.dry ? [] : void 0;
            for (const proj of buildOrder) {
                const resolvedPath = toResolvedConfigFilePath(state, proj);
                const parsed = parseConfigFile(state, proj, resolvedPath);
                if (parsed === void 0) {
                    reportParseConfigFileDiagnostic(state, resolvedPath);
                    continue;
                }
                const outputs = getAllProjectOutputs(parsed, !host.useCaseSensitiveFileNames());
                if (!outputs.length)
                    continue;
                const inputFileNames = new Set(parsed.fileNames.map((f) => toPath2(state, f)));
                for (const output of outputs) {
                    if (inputFileNames.has(toPath2(state, output)))
                        continue;
                    if (host.fileExists(output)) {
                        if (filesToDelete) {
                            filesToDelete.push(output);
                        }
                        else {
                            host.deleteFile(output);
                            invalidateProject(state, resolvedPath, 0 /* None */);
                        }
                    }
                }
            }
            if (filesToDelete) {
                reportStatus(state, Diagnostics.A_non_dry_build_would_delete_the_following_files_Colon_0, filesToDelete.map((f) => `\r
 * ${f}`).join(""));
            }
            return 0 /* Success */;
        }
        function invalidateProject(state, resolved, reloadLevel) {
            if (state.host.getParsedCommandLine && reloadLevel === 1 /* Partial */) {
                reloadLevel = 2 /* Full */;
            }
            if (reloadLevel === 2 /* Full */) {
                state.configFileCache.delete(resolved);
                state.buildOrder = void 0;
            }
            state.needsSummary = true;
            clearProjectStatus(state, resolved);
            addProjToQueue(state, resolved, reloadLevel);
            enableCache(state);
        }
        function invalidateProjectAndScheduleBuilds(state, resolvedPath, reloadLevel) {
            state.reportFileChangeDetected = true;
            invalidateProject(state, resolvedPath, reloadLevel);
            scheduleBuildInvalidatedProject(state, 250, 
            /*changeDetected*/
            true);
        }
        function scheduleBuildInvalidatedProject(state, time, changeDetected) {
            const { hostWithWatch } = state;
            if (!hostWithWatch.setTimeout || !hostWithWatch.clearTimeout) {
                return;
            }
            if (state.timerToBuildInvalidatedProject) {
                hostWithWatch.clearTimeout(state.timerToBuildInvalidatedProject);
            }
            state.timerToBuildInvalidatedProject = hostWithWatch.setTimeout(buildNextInvalidatedProject, time, state, changeDetected);
        }
        function buildNextInvalidatedProject(state, changeDetected) {
            mark("SolutionBuilder::beforeBuild");
            const buildOrder = buildNextInvalidatedProjectWorker(state, changeDetected);
            mark("SolutionBuilder::afterBuild");
            measure("SolutionBuilder::Build", "SolutionBuilder::beforeBuild", "SolutionBuilder::afterBuild");
            if (buildOrder)
                reportErrorSummary(state, buildOrder);
        }
        function buildNextInvalidatedProjectWorker(state, changeDetected) {
            state.timerToBuildInvalidatedProject = void 0;
            if (state.reportFileChangeDetected) {
                state.reportFileChangeDetected = false;
                state.projectErrorsReported.clear();
                reportWatchStatus(state, Diagnostics.File_change_detected_Starting_incremental_compilation);
            }
            let projectsBuilt = 0;
            const buildOrder = getBuildOrder(state);
            const invalidatedProject = getNextInvalidatedProject(state, buildOrder, 
            /*reportQueue*/
            false);
            if (invalidatedProject) {
                invalidatedProject.done();
                projectsBuilt++;
                while (state.projectPendingBuild.size) {
                    if (state.timerToBuildInvalidatedProject)
                        return;
                    const info = getNextInvalidatedProjectCreateInfo(state, buildOrder, 
                    /*reportQueue*/
                    false);
                    if (!info)
                        break;
                    if (info.kind !== 2 /* UpdateOutputFileStamps */ && (changeDetected || projectsBuilt === 5)) {
                        scheduleBuildInvalidatedProject(state, 100, 
                        /*changeDetected*/
                        false);
                        return;
                    }
                    const project = createInvalidatedProjectWithInfo(state, info, buildOrder);
                    project.done();
                    if (info.kind !== 2 /* UpdateOutputFileStamps */)
                        projectsBuilt++;
                }
            }
            disableCache(state);
            return buildOrder;
        }
        function watchConfigFile(state, resolved, resolvedPath, parsed) {
            if (!state.watch || state.allWatchedConfigFiles.has(resolvedPath))
                return;
            state.allWatchedConfigFiles.set(resolvedPath, watchFile(state, resolved, () => invalidateProjectAndScheduleBuilds(state, resolvedPath, 2 /* Full */), 2e3 /* High */, parsed == null ? void 0 : parsed.watchOptions, WatchType.ConfigFile, resolved));
        }
        function watchExtendedConfigFiles(state, resolvedPath, parsed) {
            updateSharedExtendedConfigFileWatcher(resolvedPath, parsed == null ? void 0 : parsed.options, state.allWatchedExtendedConfigFiles, (extendedConfigFileName, extendedConfigFilePath) => watchFile(state, extendedConfigFileName, () => {
                var _a2;
                return (_a2 = state.allWatchedExtendedConfigFiles.get(extendedConfigFilePath)) == null ? void 0 : _a2.projects.forEach((projectConfigFilePath) => invalidateProjectAndScheduleBuilds(state, projectConfigFilePath, 2 /* Full */));
            }, 2e3 /* High */, parsed == null ? void 0 : parsed.watchOptions, WatchType.ExtendedConfigFile), (fileName) => toPath2(state, fileName));
        }
        function watchWildCardDirectories(state, resolved, resolvedPath, parsed) {
            if (!state.watch)
                return;
            updateWatchingWildcardDirectories(getOrCreateValueMapFromConfigFileMap(state.allWatchedWildcardDirectories, resolvedPath), new Map(Object.entries(parsed.wildcardDirectories)), (dir, flags) => state.watchDirectory(dir, (fileOrDirectory) => {
                var _a2;
                if (isIgnoredFileFromWildCardWatching({
                    watchedDirPath: toPath2(state, dir),
                    fileOrDirectory,
                    fileOrDirectoryPath: toPath2(state, fileOrDirectory),
                    configFileName: resolved,
                    currentDirectory: state.compilerHost.getCurrentDirectory(),
                    options: parsed.options,
                    program: state.builderPrograms.get(resolvedPath) || ((_a2 = getCachedParsedConfigFile(state, resolvedPath)) == null ? void 0 : _a2.fileNames),
                    useCaseSensitiveFileNames: state.parseConfigFileHost.useCaseSensitiveFileNames,
                    writeLog: (s) => state.writeLog(s),
                    toPath: (fileName) => toPath2(state, fileName)
                }))
                    return;
                invalidateProjectAndScheduleBuilds(state, resolvedPath, 1 /* Partial */);
            }, flags, parsed == null ? void 0 : parsed.watchOptions, WatchType.WildcardDirectory, resolved));
        }
        function watchInputFiles(state, resolved, resolvedPath, parsed) {
            if (!state.watch)
                return;
            mutateMap(getOrCreateValueMapFromConfigFileMap(state.allWatchedInputFiles, resolvedPath), arrayToMap(parsed.fileNames, (fileName) => toPath2(state, fileName)), {
                createNewValue: (_path, input) => watchFile(state, input, () => invalidateProjectAndScheduleBuilds(state, resolvedPath, 0 /* None */), 250 /* Low */, parsed == null ? void 0 : parsed.watchOptions, WatchType.SourceFile, resolved),
                onDeleteValue: closeFileWatcher
            });
        }
        function watchPackageJsonFiles(state, resolved, resolvedPath, parsed) {
            if (!state.watch || !state.lastCachedPackageJsonLookups)
                return;
            mutateMap(getOrCreateValueMapFromConfigFileMap(state.allWatchedPackageJsonFiles, resolvedPath), new Map(state.lastCachedPackageJsonLookups.get(resolvedPath)), {
                createNewValue: (path, _input) => watchFile(state, path, () => invalidateProjectAndScheduleBuilds(state, resolvedPath, 0 /* None */), 2e3 /* High */, parsed == null ? void 0 : parsed.watchOptions, WatchType.PackageJson, resolved),
                onDeleteValue: closeFileWatcher
            });
        }
        function startWatching(state, buildOrder) {
            if (!state.watchAllProjectsPending)
                return;
            mark("SolutionBuilder::beforeWatcherCreation");
            state.watchAllProjectsPending = false;
            for (const resolved of getBuildOrderFromAnyBuildOrder(buildOrder)) {
                const resolvedPath = toResolvedConfigFilePath(state, resolved);
                const cfg = parseConfigFile(state, resolved, resolvedPath);
                watchConfigFile(state, resolved, resolvedPath, cfg);
                watchExtendedConfigFiles(state, resolvedPath, cfg);
                if (cfg) {
                    watchWildCardDirectories(state, resolved, resolvedPath, cfg);
                    watchInputFiles(state, resolved, resolvedPath, cfg);
                    watchPackageJsonFiles(state, resolved, resolvedPath, cfg);
                }
            }
            mark("SolutionBuilder::afterWatcherCreation");
            measure("SolutionBuilder::Watcher creation", "SolutionBuilder::beforeWatcherCreation", "SolutionBuilder::afterWatcherCreation");
        }
        function stopWatching(state) {
            clearMap(state.allWatchedConfigFiles, closeFileWatcher);
            clearMap(state.allWatchedExtendedConfigFiles, closeFileWatcherOf);
            clearMap(state.allWatchedWildcardDirectories, (watchedWildcardDirectories) => clearMap(watchedWildcardDirectories, closeFileWatcherOf));
            clearMap(state.allWatchedInputFiles, (watchedWildcardDirectories) => clearMap(watchedWildcardDirectories, closeFileWatcher));
            clearMap(state.allWatchedPackageJsonFiles, (watchedPacageJsonFiles) => clearMap(watchedPacageJsonFiles, closeFileWatcher));
        }
        function createSolutionBuilderWorker(watch, hostOrHostWithWatch, rootNames, options, baseWatchOptions) {
            const state = createSolutionBuilderState(watch, hostOrHostWithWatch, rootNames, options, baseWatchOptions);
            return {
                build: (project, cancellationToken, writeFile2, getCustomTransformers) => build(state, project, cancellationToken, writeFile2, getCustomTransformers),
                clean: (project) => clean(state, project),
                buildReferences: (project, cancellationToken, writeFile2, getCustomTransformers) => build(state, project, cancellationToken, writeFile2, getCustomTransformers, 
                /*onlyReferences*/
                true),
                cleanReferences: (project) => clean(state, project, 
                /*onlyReferences*/
                true),
                getNextInvalidatedProject: (cancellationToken) => {
                    setupInitialBuild(state, cancellationToken);
                    return getNextInvalidatedProject(state, getBuildOrder(state), 
                    /*reportQueue*/
                    false);
                },
                getBuildOrder: () => getBuildOrder(state),
                getUpToDateStatusOfProject: (project) => {
                    const configFileName = resolveProjectName(state, project);
                    const configFilePath = toResolvedConfigFilePath(state, configFileName);
                    return getUpToDateStatus(state, parseConfigFile(state, configFileName, configFilePath), configFilePath);
                },
                invalidateProject: (configFilePath, reloadLevel) => invalidateProject(state, configFilePath, reloadLevel || 0 /* None */),
                close: () => stopWatching(state)
            };
        }
        function relName(state, path) {
            return convertToRelativePath(path, state.compilerHost.getCurrentDirectory(), state.compilerHost.getCanonicalFileName);
        }
        function reportStatus(state, message, ...args) {
            state.host.reportSolutionBuilderStatus(createCompilerDiagnostic(message, ...args));
        }
        function reportWatchStatus(state, message, ...args) {
            var _a2, _b;
            (_b = (_a2 = state.hostWithWatch).onWatchStatusChange) == null ? void 0 : _b.call(_a2, createCompilerDiagnostic(message, ...args), state.host.getNewLine(), state.baseCompilerOptions);
        }
        function reportErrors({ host }, errors) {
            errors.forEach((err) => host.reportDiagnostic(err));
        }
        function reportAndStoreErrors(state, proj, errors) {
            reportErrors(state, errors);
            state.projectErrorsReported.set(proj, true);
            if (errors.length) {
                state.diagnostics.set(proj, errors);
            }
        }
        function reportParseConfigFileDiagnostic(state, proj) {
            reportAndStoreErrors(state, proj, [state.configFileCache.get(proj)]);
        }
        function reportErrorSummary(state, buildOrder) {
            if (!state.needsSummary)
                return;
            state.needsSummary = false;
            const canReportSummary = state.watch || !!state.host.reportErrorSummary;
            const { diagnostics } = state;
            let totalErrors = 0;
            let filesInError = [];
            if (isCircularBuildOrder(buildOrder)) {
                reportBuildQueue(state, buildOrder.buildOrder);
                reportErrors(state, buildOrder.circularDiagnostics);
                if (canReportSummary)
                    totalErrors += getErrorCountForSummary(buildOrder.circularDiagnostics);
                if (canReportSummary)
                    filesInError = [...filesInError, ...getFilesInErrorForSummary(buildOrder.circularDiagnostics)];
            }
            else {
                buildOrder.forEach((project) => {
                    const projectPath = toResolvedConfigFilePath(state, project);
                    if (!state.projectErrorsReported.has(projectPath)) {
                        reportErrors(state, diagnostics.get(projectPath) || emptyArray);
                    }
                });
                if (canReportSummary)
                    diagnostics.forEach((singleProjectErrors) => totalErrors += getErrorCountForSummary(singleProjectErrors));
                if (canReportSummary)
                    diagnostics.forEach((singleProjectErrors) => [...filesInError, ...getFilesInErrorForSummary(singleProjectErrors)]);
            }
            if (state.watch) {
                reportWatchStatus(state, getWatchErrorSummaryDiagnosticMessage(totalErrors), totalErrors);
            }
            else if (state.host.reportErrorSummary) {
                state.host.reportErrorSummary(totalErrors, filesInError);
            }
        }
        function reportBuildQueue(state, buildQueue) {
            if (state.options.verbose) {
                reportStatus(state, Diagnostics.Projects_in_this_build_Colon_0, buildQueue.map((s) => "\r\n    * " + relName(state, s)).join(""));
            }
        }
        function reportUpToDateStatus(state, configFileName, status) {
            switch (status.type) {
                case 6 /* OutOfDateWithSelf */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_1_is_older_than_input_2, relName(state, configFileName), relName(state, status.outOfDateOutputFileName), relName(state, status.newerInputFileName));
                case 7 /* OutOfDateWithUpstream */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_1_is_older_than_input_2, relName(state, configFileName), relName(state, status.outOfDateOutputFileName), relName(state, status.newerProjectName));
                case 4 /* OutputMissing */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_file_1_does_not_exist, relName(state, configFileName), relName(state, status.missingOutputFileName));
                case 5 /* ErrorReadingFile */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_there_was_error_reading_file_1, relName(state, configFileName), relName(state, status.fileName));
                case 8 /* OutOfDateBuildInfo */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitted, relName(state, configFileName), relName(state, status.buildInfoFile));
                case 9 /* OutOfDateOptions */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_buildinfo_file_1_indicates_there_is_change_in_compilerOptions, relName(state, configFileName), relName(state, status.buildInfoFile));
                case 10 /* OutOfDateRoots */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_file_2_was_root_file_of_compilation_but_not_any_more, relName(state, configFileName), relName(state, status.buildInfoFile), relName(state, status.inputFile));
                case 1 /* UpToDate */:
                    if (status.newestInputFileTime !== void 0) {
                        return reportStatus(state, Diagnostics.Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2, relName(state, configFileName), relName(state, status.newestInputFileName || ""), relName(state, status.oldestOutputFileName || ""));
                    }
                    break;
                case 3 /* OutOfDateWithPrepend */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed, relName(state, configFileName), relName(state, status.newerProjectName));
                case 2 /* UpToDateWithUpstreamTypes */:
                    return reportStatus(state, Diagnostics.Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies, relName(state, configFileName));
                case 15 /* UpToDateWithInputFileText */:
                    return reportStatus(state, Diagnostics.Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_files, relName(state, configFileName));
                case 11 /* UpstreamOutOfDate */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date, relName(state, configFileName), relName(state, status.upstreamProjectName));
                case 12 /* UpstreamBlocked */:
                    return reportStatus(state, status.upstreamProjectBlocked ? Diagnostics.Project_0_can_t_be_built_because_its_dependency_1_was_not_built : Diagnostics.Project_0_can_t_be_built_because_its_dependency_1_has_errors, relName(state, configFileName), relName(state, status.upstreamProjectName));
                case 0 /* Unbuildable */:
                    return reportStatus(state, Diagnostics.Failed_to_parse_file_0_Colon_1, relName(state, configFileName), status.reason);
                case 14 /* TsVersionOutputOfDate */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_current_version_2, relName(state, configFileName), status.version, version);
                case 17 /* ForceBuild */:
                    return reportStatus(state, Diagnostics.Project_0_is_being_forcibly_rebuilt, relName(state, configFileName));
                case 16 /* ContainerOnly */:
                case 13 /* ComputingUpstream */:
                    break;
                default:
                    assertType(status);
            }
        }
        function verboseReportProjectStatus(state, configFileName, status) {
            if (state.options.verbose) {
                reportUpToDateStatus(state, configFileName, status);
            }
        }
        var minimumDate, maximumDate, InvalidatedProjectKind;
        var init_tsbuildPublic = __esm({
            "src/compiler/tsbuildPublic.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
                init_ts_performance();
                minimumDate = /* @__PURE__ */ new Date(-864e13);
                maximumDate = /* @__PURE__ */ new Date(864e13);
                InvalidatedProjectKind = /* @__PURE__ */ ((InvalidatedProjectKind2) => {
                    InvalidatedProjectKind2[InvalidatedProjectKind2["Build"] = 0] = "Build";
                    InvalidatedProjectKind2[InvalidatedProjectKind2["UpdateBundle"] = 1] = "UpdateBundle";
                    InvalidatedProjectKind2[InvalidatedProjectKind2["UpdateOutputFileStamps"] = 2] = "UpdateOutputFileStamps";
                    return InvalidatedProjectKind2;
                })(InvalidatedProjectKind || {});
            }
        });
        // src/compiler/_namespaces/ts.ts
        var init_ts2 = __esm({
            "src/compiler/_namespaces/ts.ts"() {
                "use strict";
                init_corePublic();
                init_core();
                init_debug();
                init_semver();
                init_performanceCore();
                init_perfLogger();
                init_tracing();
                init_types();
                init_sys();
                init_path();
                init_diagnosticInformationMap_generated();
                init_scanner();
                init_utilitiesPublic();
                init_utilities();
                init_baseNodeFactory();
                init_parenthesizerRules();
                init_nodeConverters();
                init_nodeFactory();
                init_emitNode();
                init_emitHelpers();
                init_nodeTests();
                init_utilities2();
                init_utilitiesPublic2();
                init_parser();
                init_commandLineParser();
                init_moduleNameResolver();
                init_binder();
                init_symbolWalker();
                init_checker();
                init_visitorPublic();
                init_sourcemap();
                init_utilities3();
                init_destructuring();
                init_taggedTemplate();
                init_ts();
                init_classFields();
                init_typeSerializer();
                init_legacyDecorators();
                init_esDecorators();
                init_es2017();
                init_es2018();
                init_es2019();
                init_es2020();
                init_es2021();
                init_esnext();
                init_jsx();
                init_es2016();
                init_es2015();
                init_es5();
                init_generators();
                init_module();
                init_system();
                init_esnextAnd2015();
                init_node();
                init_diagnostics();
                init_declarations();
                init_transformer();
                init_emitter();
                init_watchUtilities();
                init_program();
                init_builderStatePublic();
                init_builderState();
                init_builder();
                init_builderPublic();
                init_resolutionCache();
                init_watch();
                init_watchPublic();
                init_tsbuild();
                init_tsbuildPublic();
                init_ts_moduleSpecifiers();
                init_ts_performance();
            }
        });
        // src/jsTyping/jsTyping.ts
        function isTypingUpToDate(cachedTyping, availableTypingVersions) {
            const availableVersion = new Version(getProperty(availableTypingVersions, `ts${versionMajorMinor}`) || getProperty(availableTypingVersions, "latest"));
            return availableVersion.compareTo(cachedTyping.version) <= 0;
        }
        function nonRelativeModuleNameForTypingCache(moduleName) {
            return nodeCoreModules.has(moduleName) ? "node" : moduleName;
        }
        function loadSafeList(host, safeListPath) {
            const result = readConfigFile(safeListPath, (path) => host.readFile(path));
            return new Map(Object.entries(result.config));
        }
        function loadTypesMap(host, typesMapPath) {
            var _a2;
            const result = readConfigFile(typesMapPath, (path) => host.readFile(path));
            if ((_a2 = result.config) == null ? void 0 : _a2.simpleMap) {
                return new Map(Object.entries(result.config.simpleMap));
            }
            return void 0;
        }
        function discoverTypings(host, log, fileNames, projectRootPath, safeList, packageNameToTypingLocation, typeAcquisition, unresolvedImports, typesRegistry, compilerOptions) {
            if (!typeAcquisition || !typeAcquisition.enable) {
                return { cachedTypingPaths: [], newTypingNames: [], filesToWatch: [] };
            }
            const inferredTypings = /* @__PURE__ */ new Map();
            fileNames = mapDefined(fileNames, (fileName) => {
                const path = normalizePath(fileName);
                if (hasJSFileExtension(path)) {
                    return path;
                }
            });
            const filesToWatch = [];
            if (typeAcquisition.include)
                addInferredTypings(typeAcquisition.include, "Explicitly included types");
            const exclude = typeAcquisition.exclude || [];
            if (!compilerOptions.types) {
                const possibleSearchDirs = new Set(fileNames.map(getDirectoryPath));
                possibleSearchDirs.add(projectRootPath);
                possibleSearchDirs.forEach((searchDir) => {
                    getTypingNames(searchDir, "bower.json", "bower_components", filesToWatch);
                    getTypingNames(searchDir, "package.json", "node_modules", filesToWatch);
                });
            }
            if (!typeAcquisition.disableFilenameBasedTypeAcquisition) {
                getTypingNamesFromSourceFileNames(fileNames);
            }
            if (unresolvedImports) {
                const module2 = deduplicate(unresolvedImports.map(nonRelativeModuleNameForTypingCache), equateStringsCaseSensitive, compareStringsCaseSensitive);
                addInferredTypings(module2, "Inferred typings from unresolved imports");
            }
            packageNameToTypingLocation.forEach((typing, name) => {
                const registryEntry = typesRegistry.get(name);
                if (inferredTypings.has(name) && inferredTypings.get(name) === void 0 && registryEntry !== void 0 && isTypingUpToDate(typing, registryEntry)) {
                    inferredTypings.set(name, typing.typingLocation);
                }
            });
            for (const excludeTypingName of exclude) {
                const didDelete = inferredTypings.delete(excludeTypingName);
                if (didDelete && log)
                    log(`Typing for ${excludeTypingName} is in exclude list, will be ignored.`);
            }
            const newTypingNames = [];
            const cachedTypingPaths = [];
            inferredTypings.forEach((inferred, typing) => {
                if (inferred !== void 0) {
                    cachedTypingPaths.push(inferred);
                }
                else {
                    newTypingNames.push(typing);
                }
            });
            const result = { cachedTypingPaths, newTypingNames, filesToWatch };
            if (log)
                log(`Result: ${JSON.stringify(result)}`);
            return result;
            function addInferredTyping(typingName) {
                if (!inferredTypings.has(typingName)) {
                    inferredTypings.set(typingName, void 0);
                }
            }
            function addInferredTypings(typingNames, message) {
                if (log)
                    log(`${message}: ${JSON.stringify(typingNames)}`);
                forEach(typingNames, addInferredTyping);
            }
            function getTypingNames(projectRootPath2, manifestName, modulesDirName, filesToWatch2) {
                const manifestPath = combinePaths(projectRootPath2, manifestName);
                let manifest;
                let manifestTypingNames;
                if (host.fileExists(manifestPath)) {
                    filesToWatch2.push(manifestPath);
                    manifest = readConfigFile(manifestPath, (path) => host.readFile(path)).config;
                    manifestTypingNames = flatMap([manifest.dependencies, manifest.devDependencies, manifest.optionalDependencies, manifest.peerDependencies], getOwnKeys);
                    addInferredTypings(manifestTypingNames, `Typing names in '${manifestPath}' dependencies`);
                }
                const packagesFolderPath = combinePaths(projectRootPath2, modulesDirName);
                filesToWatch2.push(packagesFolderPath);
                if (!host.directoryExists(packagesFolderPath)) {
                    return;
                }
                const packageNames = [];
                const dependencyManifestNames = manifestTypingNames ? manifestTypingNames.map((typingName) => combinePaths(packagesFolderPath, typingName, manifestName)) : host.readDirectory(packagesFolderPath, [".json" /* Json */], 
                /*excludes*/
                void 0, 
                /*includes*/
                void 0, 
                /*depth*/
                3).filter((manifestPath2) => {
                    if (getBaseFileName(manifestPath2) !== manifestName) {
                        return false;
                    }
                    const pathComponents2 = getPathComponents(normalizePath(manifestPath2));
                    const isScoped = pathComponents2[pathComponents2.length - 3][0] === "@";
                    return isScoped && toFileNameLowerCase(pathComponents2[pathComponents2.length - 4]) === modulesDirName || // `node_modules/@foo/bar`
                        !isScoped && toFileNameLowerCase(pathComponents2[pathComponents2.length - 3]) === modulesDirName;
                });
                if (log)
                    log(`Searching for typing names in ${packagesFolderPath}; all files: ${JSON.stringify(dependencyManifestNames)}`);
                for (const manifestPath2 of dependencyManifestNames) {
                    const normalizedFileName = normalizePath(manifestPath2);
                    const result2 = readConfigFile(normalizedFileName, (path) => host.readFile(path));
                    const manifest2 = result2.config;
                    if (!manifest2.name) {
                        continue;
                    }
                    const ownTypes = manifest2.types || manifest2.typings;
                    if (ownTypes) {
                        const absolutePath = getNormalizedAbsolutePath(ownTypes, getDirectoryPath(normalizedFileName));
                        if (host.fileExists(absolutePath)) {
                            if (log)
                                log(`    Package '${manifest2.name}' provides its own types.`);
                            inferredTypings.set(manifest2.name, absolutePath);
                        }
                        else {
                            if (log)
                                log(`    Package '${manifest2.name}' provides its own types but they are missing.`);
                        }
                    }
                    else {
                        packageNames.push(manifest2.name);
                    }
                }
                addInferredTypings(packageNames, "    Found package names");
            }
            function getTypingNamesFromSourceFileNames(fileNames2) {
                const fromFileNames = mapDefined(fileNames2, (j) => {
                    if (!hasJSFileExtension(j))
                        return void 0;
                    const inferredTypingName = removeFileExtension(toFileNameLowerCase(getBaseFileName(j)));
                    const cleanedTypingName = removeMinAndVersionNumbers(inferredTypingName);
                    return safeList.get(cleanedTypingName);
                });
                if (fromFileNames.length) {
                    addInferredTypings(fromFileNames, "Inferred typings from file names");
                }
                const hasJsxFile = some(fileNames2, (f) => fileExtensionIs(f, ".jsx" /* Jsx */));
                if (hasJsxFile) {
                    if (log)
                        log(`Inferred 'react' typings due to presence of '.jsx' extension`);
                    addInferredTyping("react");
                }
            }
        }
        function validatePackageName(packageName) {
            return validatePackageNameWorker(packageName, 
            /*supportScopedPackage*/
            true);
        }
        function validatePackageNameWorker(packageName, supportScopedPackage) {
            if (!packageName) {
                return 1 /* EmptyName */;
            }
            if (packageName.length > maxPackageNameLength) {
                return 2 /* NameTooLong */;
            }
            if (packageName.charCodeAt(0) === 46 /* dot */) {
                return 3 /* NameStartsWithDot */;
            }
            if (packageName.charCodeAt(0) === 95 /* _ */) {
                return 4 /* NameStartsWithUnderscore */;
            }
            if (supportScopedPackage) {
                const matches = /^@([^/]+)\/([^/]+)$/.exec(packageName);
                if (matches) {
                    const scopeResult = validatePackageNameWorker(matches[1], 
                    /*supportScopedPackage*/
                    false);
                    if (scopeResult !== 0 /* Ok */) {
                        return { name: matches[1], isScopeName: true, result: scopeResult };
                    }
                    const packageResult = validatePackageNameWorker(matches[2], 
                    /*supportScopedPackage*/
                    false);
                    if (packageResult !== 0 /* Ok */) {
                        return { name: matches[2], isScopeName: false, result: packageResult };
                    }
                    return 0 /* Ok */;
                }
            }
            if (encodeURIComponent(packageName) !== packageName) {
                return 5 /* NameContainsNonURISafeCharacters */;
            }
            return 0 /* Ok */;
        }
        function renderPackageNameValidationFailure(result, typing) {
            return typeof result === "object" ? renderPackageNameValidationFailureWorker(typing, result.result, result.name, result.isScopeName) : renderPackageNameValidationFailureWorker(typing, result, typing, 
            /*isScopeName*/
            false);
        }
        function renderPackageNameValidationFailureWorker(typing, result, name, isScopeName) {
            const kind = isScopeName ? "Scope" : "Package";
            switch (result) {
                case 1 /* EmptyName */:
                    return `'${typing}':: ${kind} name '${name}' cannot be empty`;
                case 2 /* NameTooLong */:
                    return `'${typing}':: ${kind} name '${name}' should be less than ${maxPackageNameLength} characters`;
                case 3 /* NameStartsWithDot */:
                    return `'${typing}':: ${kind} name '${name}' cannot start with '.'`;
                case 4 /* NameStartsWithUnderscore */:
                    return `'${typing}':: ${kind} name '${name}' cannot start with '_'`;
                case 5 /* NameContainsNonURISafeCharacters */:
                    return `'${typing}':: ${kind} name '${name}' contains non URI safe characters`;
                case 0 /* Ok */:
                    return Debug.fail();
                default:
                    throw Debug.assertNever(result);
            }
        }
        var unprefixedNodeCoreModuleList, prefixedNodeCoreModuleList, nodeCoreModuleList, nodeCoreModules, NameValidationResult, maxPackageNameLength;
        var init_jsTyping = __esm({
            "src/jsTyping/jsTyping.ts"() {
                "use strict";
                init_ts3();
                unprefixedNodeCoreModuleList = [
                    "assert",
                    "assert/strict",
                    "async_hooks",
                    "buffer",
                    "child_process",
                    "cluster",
                    "console",
                    "constants",
                    "crypto",
                    "dgram",
                    "diagnostics_channel",
                    "dns",
                    "dns/promises",
                    "domain",
                    "events",
                    "fs",
                    "fs/promises",
                    "http",
                    "https",
                    "http2",
                    "inspector",
                    "module",
                    "net",
                    "os",
                    "path",
                    "perf_hooks",
                    "process",
                    "punycode",
                    "querystring",
                    "readline",
                    "repl",
                    "stream",
                    "stream/promises",
                    "string_decoder",
                    "timers",
                    "timers/promises",
                    "tls",
                    "trace_events",
                    "tty",
                    "url",
                    "util",
                    "util/types",
                    "v8",
                    "vm",
                    "wasi",
                    "worker_threads",
                    "zlib"
                ];
                prefixedNodeCoreModuleList = unprefixedNodeCoreModuleList.map((name) => `node:${name}`);
                nodeCoreModuleList = [...unprefixedNodeCoreModuleList, ...prefixedNodeCoreModuleList];
                nodeCoreModules = new Set(nodeCoreModuleList);
                NameValidationResult = /* @__PURE__ */ ((NameValidationResult2) => {
                    NameValidationResult2[NameValidationResult2["Ok"] = 0] = "Ok";
                    NameValidationResult2[NameValidationResult2["EmptyName"] = 1] = "EmptyName";
                    NameValidationResult2[NameValidationResult2["NameTooLong"] = 2] = "NameTooLong";
                    NameValidationResult2[NameValidationResult2["NameStartsWithDot"] = 3] = "NameStartsWithDot";
                    NameValidationResult2[NameValidationResult2["NameStartsWithUnderscore"] = 4] = "NameStartsWithUnderscore";
                    NameValidationResult2[NameValidationResult2["NameContainsNonURISafeCharacters"] = 5] = "NameContainsNonURISafeCharacters";
                    return NameValidationResult2;
                })(NameValidationResult || {});
                maxPackageNameLength = 214;
            }
        });
        // src/jsTyping/_namespaces/ts.JsTyping.ts
        var ts_JsTyping_exports = {};
        __export(ts_JsTyping_exports, {
            NameValidationResult: () => NameValidationResult,
            discoverTypings: () => discoverTypings,
            isTypingUpToDate: () => isTypingUpToDate,
            loadSafeList: () => loadSafeList,
            loadTypesMap: () => loadTypesMap,
            nodeCoreModuleList: () => nodeCoreModuleList,
            nodeCoreModules: () => nodeCoreModules,
            nonRelativeModuleNameForTypingCache: () => nonRelativeModuleNameForTypingCache,
            prefixedNodeCoreModuleList: () => prefixedNodeCoreModuleList,
            renderPackageNameValidationFailure: () => renderPackageNameValidationFailure,
            validatePackageName: () => validatePackageName
        });
        var init_ts_JsTyping = __esm({
            "src/jsTyping/_namespaces/ts.JsTyping.ts"() {
                "use strict";
                init_jsTyping();
            }
        });
        // src/jsTyping/shared.ts
        function hasArgument(argumentName) {
            return sys.args.indexOf(argumentName) >= 0;
        }
        function findArgument(argumentName) {
            const index = sys.args.indexOf(argumentName);
            return index >= 0 && index < sys.args.length - 1 ? sys.args[index + 1] : void 0;
        }
        function nowString() {
            const d = /* @__PURE__ */ new Date();
            return `${padLeft(d.getHours().toString(), 2, "0")}:${padLeft(d.getMinutes().toString(), 2, "0")}:${padLeft(d.getSeconds().toString(), 2, "0")}.${padLeft(d.getMilliseconds().toString(), 3, "0")}`;
        }
        var ActionSet, ActionInvalidate, ActionPackageInstalled, EventTypesRegistry, EventBeginInstallTypes, EventEndInstallTypes, EventInitializationFailed, Arguments;
        var init_shared = __esm({
            "src/jsTyping/shared.ts"() {
                "use strict";
                init_ts3();
                ActionSet = "action::set";
                ActionInvalidate = "action::invalidate";
                ActionPackageInstalled = "action::packageInstalled";
                EventTypesRegistry = "event::typesRegistry";
                EventBeginInstallTypes = "event::beginInstallTypes";
                EventEndInstallTypes = "event::endInstallTypes";
                EventInitializationFailed = "event::initializationFailed";
                ((Arguments2) => {
                    Arguments2.GlobalCacheLocation = "--globalTypingsCacheLocation";
                    Arguments2.LogFile = "--logFile";
                    Arguments2.EnableTelemetry = "--enableTelemetry";
                    Arguments2.TypingSafeListLocation = "--typingSafeListLocation";
                    Arguments2.TypesMapLocation = "--typesMapLocation";
                    Arguments2.NpmLocation = "--npmLocation";
                    Arguments2.ValidateDefaultNpmLocation = "--validateDefaultNpmLocation";
                })(Arguments || (Arguments = {}));
            }
        });
        // src/jsTyping/types.ts
        var init_types2 = __esm({
            "src/jsTyping/types.ts"() {
                "use strict";
            }
        });
        // src/jsTyping/_namespaces/ts.server.ts
        var ts_server_exports = {};
        __export(ts_server_exports, {
            ActionInvalidate: () => ActionInvalidate,
            ActionPackageInstalled: () => ActionPackageInstalled,
            ActionSet: () => ActionSet,
            Arguments: () => Arguments,
            EventBeginInstallTypes: () => EventBeginInstallTypes,
            EventEndInstallTypes: () => EventEndInstallTypes,
            EventInitializationFailed: () => EventInitializationFailed,
            EventTypesRegistry: () => EventTypesRegistry,
            findArgument: () => findArgument,
            hasArgument: () => hasArgument,
            nowString: () => nowString
        });
        var init_ts_server = __esm({
            "src/jsTyping/_namespaces/ts.server.ts"() {
                "use strict";
                init_shared();
                init_types2();
            }
        });
        // src/jsTyping/_namespaces/ts.ts
        var init_ts3 = __esm({
            "src/jsTyping/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_ts_JsTyping();
                init_ts_server();
            }
        });
        // src/services/types.ts
        function getDefaultFormatCodeSettings(newLineCharacter) {
            return {
                indentSize: 4,
                tabSize: 4,
                newLineCharacter: newLineCharacter || "\n",
                convertTabsToSpaces: true,
                indentStyle: 2 /* Smart */,
                insertSpaceAfterConstructor: false,
                insertSpaceAfterCommaDelimiter: true,
                insertSpaceAfterSemicolonInForStatements: true,
                insertSpaceBeforeAndAfterBinaryOperators: true,
                insertSpaceAfterKeywordsInControlFlowStatements: true,
                insertSpaceAfterFunctionKeywordForAnonymousFunctions: false,
                insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis: false,
                insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets: false,
                insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces: true,
                insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces: false,
                insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces: false,
                insertSpaceBeforeFunctionParenthesis: false,
                placeOpenBraceOnNewLineForFunctions: false,
                placeOpenBraceOnNewLineForControlBlocks: false,
                semicolons: "ignore" /* Ignore */,
                trimTrailingWhitespace: true
            };
        }
        var ScriptSnapshot, PackageJsonDependencyGroup, PackageJsonAutoImportPreference, LanguageServiceMode, emptyOptions, SemanticClassificationFormat, OrganizeImportsMode, CompletionTriggerKind, InlayHintKind, HighlightSpanKind, IndentStyle, SemicolonPreference, testFormatSettings, SymbolDisplayPartKind, CompletionInfoFlags, OutliningSpanKind, OutputFileType, EndOfLineState, TokenClass, ScriptElementKind, ScriptElementKindModifier, ClassificationTypeNames, ClassificationType;
        var init_types3 = __esm({
            "src/services/types.ts"() {
                "use strict";
                ((ScriptSnapshot2) => {
                    class StringScriptSnapshot {
                        constructor(text) {
                            this.text = text;
                        }
                        getText(start, end) {
                            return start === 0 && end === this.text.length ? this.text : this.text.substring(start, end);
                        }
                        getLength() {
                            return this.text.length;
                        }
                        getChangeRange() {
                            return void 0;
                        }
                    }
                    function fromString(text) {
                        return new StringScriptSnapshot(text);
                    }
                    ScriptSnapshot2.fromString = fromString;
                })(ScriptSnapshot || (ScriptSnapshot = {}));
                PackageJsonDependencyGroup = /* @__PURE__ */ ((PackageJsonDependencyGroup2) => {
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["Dependencies"] = 1] = "Dependencies";
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["DevDependencies"] = 2] = "DevDependencies";
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["PeerDependencies"] = 4] = "PeerDependencies";
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["OptionalDependencies"] = 8] = "OptionalDependencies";
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["All"] = 15] = "All";
                    return PackageJsonDependencyGroup2;
                })(PackageJsonDependencyGroup || {});
                PackageJsonAutoImportPreference = /* @__PURE__ */ ((PackageJsonAutoImportPreference2) => {
                    PackageJsonAutoImportPreference2[PackageJsonAutoImportPreference2["Off"] = 0] = "Off";
                    PackageJsonAutoImportPreference2[PackageJsonAutoImportPreference2["On"] = 1] = "On";
                    PackageJsonAutoImportPreference2[PackageJsonAutoImportPreference2["Auto"] = 2] = "Auto";
                    return PackageJsonAutoImportPreference2;
                })(PackageJsonAutoImportPreference || {});
                LanguageServiceMode = /* @__PURE__ */ ((LanguageServiceMode2) => {
                    LanguageServiceMode2[LanguageServiceMode2["Semantic"] = 0] = "Semantic";
                    LanguageServiceMode2[LanguageServiceMode2["PartialSemantic"] = 1] = "PartialSemantic";
                    LanguageServiceMode2[LanguageServiceMode2["Syntactic"] = 2] = "Syntactic";
                    return LanguageServiceMode2;
                })(LanguageServiceMode || {});
                emptyOptions = {};
                SemanticClassificationFormat = /* @__PURE__ */ ((SemanticClassificationFormat3) => {
                    SemanticClassificationFormat3["Original"] = "original";
                    SemanticClassificationFormat3["TwentyTwenty"] = "2020";
                    return SemanticClassificationFormat3;
                })(SemanticClassificationFormat || {});
                OrganizeImportsMode = /* @__PURE__ */ ((OrganizeImportsMode2) => {
                    OrganizeImportsMode2["All"] = "All";
                    OrganizeImportsMode2["SortAndCombine"] = "SortAndCombine";
                    OrganizeImportsMode2["RemoveUnused"] = "RemoveUnused";
                    return OrganizeImportsMode2;
                })(OrganizeImportsMode || {});
                CompletionTriggerKind = /* @__PURE__ */ ((CompletionTriggerKind2) => {
                    CompletionTriggerKind2[CompletionTriggerKind2["Invoked"] = 1] = "Invoked";
                    CompletionTriggerKind2[CompletionTriggerKind2["TriggerCharacter"] = 2] = "TriggerCharacter";
                    CompletionTriggerKind2[CompletionTriggerKind2["TriggerForIncompleteCompletions"] = 3] = "TriggerForIncompleteCompletions";
                    return CompletionTriggerKind2;
                })(CompletionTriggerKind || {});
                InlayHintKind = /* @__PURE__ */ ((InlayHintKind2) => {
                    InlayHintKind2["Type"] = "Type";
                    InlayHintKind2["Parameter"] = "Parameter";
                    InlayHintKind2["Enum"] = "Enum";
                    return InlayHintKind2;
                })(InlayHintKind || {});
                HighlightSpanKind = /* @__PURE__ */ ((HighlightSpanKind2) => {
                    HighlightSpanKind2["none"] = "none";
                    HighlightSpanKind2["definition"] = "definition";
                    HighlightSpanKind2["reference"] = "reference";
                    HighlightSpanKind2["writtenReference"] = "writtenReference";
                    return HighlightSpanKind2;
                })(HighlightSpanKind || {});
                IndentStyle = /* @__PURE__ */ ((IndentStyle2) => {
                    IndentStyle2[IndentStyle2["None"] = 0] = "None";
                    IndentStyle2[IndentStyle2["Block"] = 1] = "Block";
                    IndentStyle2[IndentStyle2["Smart"] = 2] = "Smart";
                    return IndentStyle2;
                })(IndentStyle || {});
                SemicolonPreference = /* @__PURE__ */ ((SemicolonPreference2) => {
                    SemicolonPreference2["Ignore"] = "ignore";
                    SemicolonPreference2["Insert"] = "insert";
                    SemicolonPreference2["Remove"] = "remove";
                    return SemicolonPreference2;
                })(SemicolonPreference || {});
                testFormatSettings = getDefaultFormatCodeSettings("\n");
                SymbolDisplayPartKind = /* @__PURE__ */ ((SymbolDisplayPartKind2) => {
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["aliasName"] = 0] = "aliasName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["className"] = 1] = "className";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["enumName"] = 2] = "enumName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["fieldName"] = 3] = "fieldName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["interfaceName"] = 4] = "interfaceName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["keyword"] = 5] = "keyword";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["lineBreak"] = 6] = "lineBreak";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["numericLiteral"] = 7] = "numericLiteral";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["stringLiteral"] = 8] = "stringLiteral";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["localName"] = 9] = "localName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["methodName"] = 10] = "methodName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["moduleName"] = 11] = "moduleName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["operator"] = 12] = "operator";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["parameterName"] = 13] = "parameterName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["propertyName"] = 14] = "propertyName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["punctuation"] = 15] = "punctuation";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["space"] = 16] = "space";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["text"] = 17] = "text";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["typeParameterName"] = 18] = "typeParameterName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["enumMemberName"] = 19] = "enumMemberName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["functionName"] = 20] = "functionName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["regularExpressionLiteral"] = 21] = "regularExpressionLiteral";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["link"] = 22] = "link";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["linkName"] = 23] = "linkName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["linkText"] = 24] = "linkText";
                    return SymbolDisplayPartKind2;
                })(SymbolDisplayPartKind || {});
                CompletionInfoFlags = /* @__PURE__ */ ((CompletionInfoFlags2) => {
                    CompletionInfoFlags2[CompletionInfoFlags2["None"] = 0] = "None";
                    CompletionInfoFlags2[CompletionInfoFlags2["MayIncludeAutoImports"] = 1] = "MayIncludeAutoImports";
                    CompletionInfoFlags2[CompletionInfoFlags2["IsImportStatementCompletion"] = 2] = "IsImportStatementCompletion";
                    CompletionInfoFlags2[CompletionInfoFlags2["IsContinuation"] = 4] = "IsContinuation";
                    CompletionInfoFlags2[CompletionInfoFlags2["ResolvedModuleSpecifiers"] = 8] = "ResolvedModuleSpecifiers";
                    CompletionInfoFlags2[CompletionInfoFlags2["ResolvedModuleSpecifiersBeyondLimit"] = 16] = "ResolvedModuleSpecifiersBeyondLimit";
                    CompletionInfoFlags2[CompletionInfoFlags2["MayIncludeMethodSnippets"] = 32] = "MayIncludeMethodSnippets";
                    return CompletionInfoFlags2;
                })(CompletionInfoFlags || {});
                OutliningSpanKind = /* @__PURE__ */ ((OutliningSpanKind2) => {
                    OutliningSpanKind2["Comment"] = "comment";
                    OutliningSpanKind2["Region"] = "region";
                    OutliningSpanKind2["Code"] = "code";
                    OutliningSpanKind2["Imports"] = "imports";
                    return OutliningSpanKind2;
                })(OutliningSpanKind || {});
                OutputFileType = /* @__PURE__ */ ((OutputFileType2) => {
                    OutputFileType2[OutputFileType2["JavaScript"] = 0] = "JavaScript";
                    OutputFileType2[OutputFileType2["SourceMap"] = 1] = "SourceMap";
                    OutputFileType2[OutputFileType2["Declaration"] = 2] = "Declaration";
                    return OutputFileType2;
                })(OutputFileType || {});
                EndOfLineState = /* @__PURE__ */ ((EndOfLineState3) => {
                    EndOfLineState3[EndOfLineState3["None"] = 0] = "None";
                    EndOfLineState3[EndOfLineState3["InMultiLineCommentTrivia"] = 1] = "InMultiLineCommentTrivia";
                    EndOfLineState3[EndOfLineState3["InSingleQuoteStringLiteral"] = 2] = "InSingleQuoteStringLiteral";
                    EndOfLineState3[EndOfLineState3["InDoubleQuoteStringLiteral"] = 3] = "InDoubleQuoteStringLiteral";
                    EndOfLineState3[EndOfLineState3["InTemplateHeadOrNoSubstitutionTemplate"] = 4] = "InTemplateHeadOrNoSubstitutionTemplate";
                    EndOfLineState3[EndOfLineState3["InTemplateMiddleOrTail"] = 5] = "InTemplateMiddleOrTail";
                    EndOfLineState3[EndOfLineState3["InTemplateSubstitutionPosition"] = 6] = "InTemplateSubstitutionPosition";
                    return EndOfLineState3;
                })(EndOfLineState || {});
                TokenClass = /* @__PURE__ */ ((TokenClass2) => {
                    TokenClass2[TokenClass2["Punctuation"] = 0] = "Punctuation";
                    TokenClass2[TokenClass2["Keyword"] = 1] = "Keyword";
                    TokenClass2[TokenClass2["Operator"] = 2] = "Operator";
                    TokenClass2[TokenClass2["Comment"] = 3] = "Comment";
                    TokenClass2[TokenClass2["Whitespace"] = 4] = "Whitespace";
                    TokenClass2[TokenClass2["Identifier"] = 5] = "Identifier";
                    TokenClass2[TokenClass2["NumberLiteral"] = 6] = "NumberLiteral";
                    TokenClass2[TokenClass2["BigIntLiteral"] = 7] = "BigIntLiteral";
                    TokenClass2[TokenClass2["StringLiteral"] = 8] = "StringLiteral";
                    TokenClass2[TokenClass2["RegExpLiteral"] = 9] = "RegExpLiteral";
                    return TokenClass2;
                })(TokenClass || {});
                ScriptElementKind = /* @__PURE__ */ ((ScriptElementKind2) => {
                    ScriptElementKind2["unknown"] = "";
                    ScriptElementKind2["warning"] = "warning";
                    ScriptElementKind2["keyword"] = "keyword";
                    ScriptElementKind2["scriptElement"] = "script";
                    ScriptElementKind2["moduleElement"] = "module";
                    ScriptElementKind2["classElement"] = "class";
                    ScriptElementKind2["localClassElement"] = "local class";
                    ScriptElementKind2["interfaceElement"] = "interface";
                    ScriptElementKind2["typeElement"] = "type";
                    ScriptElementKind2["enumElement"] = "enum";
                    ScriptElementKind2["enumMemberElement"] = "enum member";
                    ScriptElementKind2["variableElement"] = "var";
                    ScriptElementKind2["localVariableElement"] = "local var";
                    ScriptElementKind2["functionElement"] = "function";
                    ScriptElementKind2["localFunctionElement"] = "local function";
                    ScriptElementKind2["memberFunctionElement"] = "method";
                    ScriptElementKind2["memberGetAccessorElement"] = "getter";
                    ScriptElementKind2["memberSetAccessorElement"] = "setter";
                    ScriptElementKind2["memberVariableElement"] = "property";
                    ScriptElementKind2["memberAccessorVariableElement"] = "accessor";
                    ScriptElementKind2["constructorImplementationElement"] = "constructor";
                    ScriptElementKind2["callSignatureElement"] = "call";
                    ScriptElementKind2["indexSignatureElement"] = "index";
                    ScriptElementKind2["constructSignatureElement"] = "construct";
                    ScriptElementKind2["parameterElement"] = "parameter";
                    ScriptElementKind2["typeParameterElement"] = "type parameter";
                    ScriptElementKind2["primitiveType"] = "primitive type";
                    ScriptElementKind2["label"] = "label";
                    ScriptElementKind2["alias"] = "alias";
                    ScriptElementKind2["constElement"] = "const";
                    ScriptElementKind2["letElement"] = "let";
                    ScriptElementKind2["directory"] = "directory";
                    ScriptElementKind2["externalModuleName"] = "external module name";
                    ScriptElementKind2["jsxAttribute"] = "JSX attribute";
                    ScriptElementKind2["string"] = "string";
                    ScriptElementKind2["link"] = "link";
                    ScriptElementKind2["linkName"] = "link name";
                    ScriptElementKind2["linkText"] = "link text";
                    return ScriptElementKind2;
                })(ScriptElementKind || {});
                ScriptElementKindModifier = /* @__PURE__ */ ((ScriptElementKindModifier2) => {
                    ScriptElementKindModifier2["none"] = "";
                    ScriptElementKindModifier2["publicMemberModifier"] = "public";
                    ScriptElementKindModifier2["privateMemberModifier"] = "private";
                    ScriptElementKindModifier2["protectedMemberModifier"] = "protected";
                    ScriptElementKindModifier2["exportedModifier"] = "export";
                    ScriptElementKindModifier2["ambientModifier"] = "declare";
                    ScriptElementKindModifier2["staticModifier"] = "static";
                    ScriptElementKindModifier2["abstractModifier"] = "abstract";
                    ScriptElementKindModifier2["optionalModifier"] = "optional";
                    ScriptElementKindModifier2["deprecatedModifier"] = "deprecated";
                    ScriptElementKindModifier2["dtsModifier"] = ".d.ts";
                    ScriptElementKindModifier2["tsModifier"] = ".ts";
                    ScriptElementKindModifier2["tsxModifier"] = ".tsx";
                    ScriptElementKindModifier2["jsModifier"] = ".js";
                    ScriptElementKindModifier2["jsxModifier"] = ".jsx";
                    ScriptElementKindModifier2["jsonModifier"] = ".json";
                    ScriptElementKindModifier2["dmtsModifier"] = ".d.mts";
                    ScriptElementKindModifier2["mtsModifier"] = ".mts";
                    ScriptElementKindModifier2["mjsModifier"] = ".mjs";
                    ScriptElementKindModifier2["dctsModifier"] = ".d.cts";
                    ScriptElementKindModifier2["ctsModifier"] = ".cts";
                    ScriptElementKindModifier2["cjsModifier"] = ".cjs";
                    return ScriptElementKindModifier2;
                })(ScriptElementKindModifier || {});
                ClassificationTypeNames = /* @__PURE__ */ ((ClassificationTypeNames2) => {
                    ClassificationTypeNames2["comment"] = "comment";
                    ClassificationTypeNames2["identifier"] = "identifier";
                    ClassificationTypeNames2["keyword"] = "keyword";
                    ClassificationTypeNames2["numericLiteral"] = "number";
                    ClassificationTypeNames2["bigintLiteral"] = "bigint";
                    ClassificationTypeNames2["operator"] = "operator";
                    ClassificationTypeNames2["stringLiteral"] = "string";
                    ClassificationTypeNames2["whiteSpace"] = "whitespace";
                    ClassificationTypeNames2["text"] = "text";
                    ClassificationTypeNames2["punctuation"] = "punctuation";
                    ClassificationTypeNames2["className"] = "class name";
                    ClassificationTypeNames2["enumName"] = "enum name";
                    ClassificationTypeNames2["interfaceName"] = "interface name";
                    ClassificationTypeNames2["moduleName"] = "module name";
                    ClassificationTypeNames2["typeParameterName"] = "type parameter name";
                    ClassificationTypeNames2["typeAliasName"] = "type alias name";
                    ClassificationTypeNames2["parameterName"] = "parameter name";
                    ClassificationTypeNames2["docCommentTagName"] = "doc comment tag name";
                    ClassificationTypeNames2["jsxOpenTagName"] = "jsx open tag name";
                    ClassificationTypeNames2["jsxCloseTagName"] = "jsx close tag name";
                    ClassificationTypeNames2["jsxSelfClosingTagName"] = "jsx self closing tag name";
                    ClassificationTypeNames2["jsxAttribute"] = "jsx attribute";
                    ClassificationTypeNames2["jsxText"] = "jsx text";
                    ClassificationTypeNames2["jsxAttributeStringLiteralValue"] = "jsx attribute string literal value";
                    return ClassificationTypeNames2;
                })(ClassificationTypeNames || {});
                ClassificationType = /* @__PURE__ */ ((ClassificationType2) => {
                    ClassificationType2[ClassificationType2["comment"] = 1] = "comment";
                    ClassificationType2[ClassificationType2["identifier"] = 2] = "identifier";
                    ClassificationType2[ClassificationType2["keyword"] = 3] = "keyword";
                    ClassificationType2[ClassificationType2["numericLiteral"] = 4] = "numericLiteral";
                    ClassificationType2[ClassificationType2["operator"] = 5] = "operator";
                    ClassificationType2[ClassificationType2["stringLiteral"] = 6] = "stringLiteral";
                    ClassificationType2[ClassificationType2["regularExpressionLiteral"] = 7] = "regularExpressionLiteral";
                    ClassificationType2[ClassificationType2["whiteSpace"] = 8] = "whiteSpace";
                    ClassificationType2[ClassificationType2["text"] = 9] = "text";
                    ClassificationType2[ClassificationType2["punctuation"] = 10] = "punctuation";
                    ClassificationType2[ClassificationType2["className"] = 11] = "className";
                    ClassificationType2[ClassificationType2["enumName"] = 12] = "enumName";
                    ClassificationType2[ClassificationType2["interfaceName"] = 13] = "interfaceName";
                    ClassificationType2[ClassificationType2["moduleName"] = 14] = "moduleName";
                    ClassificationType2[ClassificationType2["typeParameterName"] = 15] = "typeParameterName";
                    ClassificationType2[ClassificationType2["typeAliasName"] = 16] = "typeAliasName";
                    ClassificationType2[ClassificationType2["parameterName"] = 17] = "parameterName";
                    ClassificationType2[ClassificationType2["docCommentTagName"] = 18] = "docCommentTagName";
                    ClassificationType2[ClassificationType2["jsxOpenTagName"] = 19] = "jsxOpenTagName";
                    ClassificationType2[ClassificationType2["jsxCloseTagName"] = 20] = "jsxCloseTagName";
                    ClassificationType2[ClassificationType2["jsxSelfClosingTagName"] = 21] = "jsxSelfClosingTagName";
                    ClassificationType2[ClassificationType2["jsxAttribute"] = 22] = "jsxAttribute";
                    ClassificationType2[ClassificationType2["jsxText"] = 23] = "jsxText";
                    ClassificationType2[ClassificationType2["jsxAttributeStringLiteralValue"] = 24] = "jsxAttributeStringLiteralValue";
                    ClassificationType2[ClassificationType2["bigintLiteral"] = 25] = "bigintLiteral";
                    return ClassificationType2;
                })(ClassificationType || {});
            }
        });
        // src/services/utilities.ts
        function getMeaningFromDeclaration(node) {
            switch (node.kind) {
                case 257 /* VariableDeclaration */:
                    return isInJSFile(node) && getJSDocEnumTag(node) ? 7 /* All */ : 1 /* Value */;
                case 166 /* Parameter */:
                case 205 /* BindingElement */:
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 299 /* PropertyAssignment */:
                case 300 /* ShorthandPropertyAssignment */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 173 /* Constructor */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                case 295 /* CatchClause */:
                case 288 /* JsxAttribute */:
                    return 1 /* Value */;
                case 165 /* TypeParameter */:
                case 261 /* InterfaceDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 184 /* TypeLiteral */:
                    return 2 /* Type */;
                case 349 /* JSDocTypedefTag */:
                    return node.name === void 0 ? 1 /* Value */ | 2 /* Type */ : 2 /* Type */;
                case 302 /* EnumMember */:
                case 260 /* ClassDeclaration */:
                    return 1 /* Value */ | 2 /* Type */;
                case 264 /* ModuleDeclaration */:
                    if (isAmbientModule(node)) {
                        return 4 /* Namespace */ | 1 /* Value */;
                    }
                    else if (getModuleInstanceState(node) === 1 /* Instantiated */) {
                        return 4 /* Namespace */ | 1 /* Value */;
                    }
                    else {
                        return 4 /* Namespace */;
                    }
                case 263 /* EnumDeclaration */:
                case 272 /* NamedImports */:
                case 273 /* ImportSpecifier */:
                case 268 /* ImportEqualsDeclaration */:
                case 269 /* ImportDeclaration */:
                case 274 /* ExportAssignment */:
                case 275 /* ExportDeclaration */:
                    return 7 /* All */;
                case 308 /* SourceFile */:
                    return 4 /* Namespace */ | 1 /* Value */;
            }
            return 7 /* All */;
        }
        function getMeaningFromLocation(node) {
            node = getAdjustedReferenceLocation(node);
            const parent2 = node.parent;
            if (node.kind === 308 /* SourceFile */) {
                return 1 /* Value */;
            }
            else if (isExportAssignment(parent2) || isExportSpecifier(parent2) || isExternalModuleReference(parent2) || isImportSpecifier(parent2) || isImportClause(parent2) || isImportEqualsDeclaration(parent2) && node === parent2.name) {
                return 7 /* All */;
            }
            else if (isInRightSideOfInternalImportEqualsDeclaration(node)) {
                return getMeaningFromRightHandSideOfImportEquals(node);
            }
            else if (isDeclarationName(node)) {
                return getMeaningFromDeclaration(parent2);
            }
            else if (isEntityName(node) && findAncestor(node, or(isJSDocNameReference, isJSDocLinkLike, isJSDocMemberName))) {
                return 7 /* All */;
            }
            else if (isTypeReference(node)) {
                return 2 /* Type */;
            }
            else if (isNamespaceReference(node)) {
                return 4 /* Namespace */;
            }
            else if (isTypeParameterDeclaration(parent2)) {
                Debug.assert(isJSDocTemplateTag(parent2.parent));
                return 2 /* Type */;
            }
            else if (isLiteralTypeNode(parent2)) {
                return 2 /* Type */ | 1 /* Value */;
            }
            else {
                return 1 /* Value */;
            }
        }
        function getMeaningFromRightHandSideOfImportEquals(node) {
            const name = node.kind === 163 /* QualifiedName */ ? node : isQualifiedName(node.parent) && node.parent.right === node ? node.parent : void 0;
            return name && name.parent.kind === 268 /* ImportEqualsDeclaration */ ? 7 /* All */ : 4 /* Namespace */;
        }
        function isInRightSideOfInternalImportEqualsDeclaration(node) {
            while (node.parent.kind === 163 /* QualifiedName */) {
                node = node.parent;
            }
            return isInternalModuleImportEqualsDeclaration(node.parent) && node.parent.moduleReference === node;
        }
        function isNamespaceReference(node) {
            return isQualifiedNameNamespaceReference(node) || isPropertyAccessNamespaceReference(node);
        }
        function isQualifiedNameNamespaceReference(node) {
            let root = node;
            let isLastClause = true;
            if (root.parent.kind === 163 /* QualifiedName */) {
                while (root.parent && root.parent.kind === 163 /* QualifiedName */) {
                    root = root.parent;
                }
                isLastClause = root.right === node;
            }
            return root.parent.kind === 180 /* TypeReference */ && !isLastClause;
        }
        function isPropertyAccessNamespaceReference(node) {
            let root = node;
            let isLastClause = true;
            if (root.parent.kind === 208 /* PropertyAccessExpression */) {
                while (root.parent && root.parent.kind === 208 /* PropertyAccessExpression */) {
                    root = root.parent;
                }
                isLastClause = root.name === node;
            }
            if (!isLastClause && root.parent.kind === 230 /* ExpressionWithTypeArguments */ && root.parent.parent.kind === 294 /* HeritageClause */) {
                const decl = root.parent.parent.parent;
                return decl.kind === 260 /* ClassDeclaration */ && root.parent.parent.token === 117 /* ImplementsKeyword */ || decl.kind === 261 /* InterfaceDeclaration */ && root.parent.parent.token === 94 /* ExtendsKeyword */;
            }
            return false;
        }
        function isTypeReference(node) {
            if (isRightSideOfQualifiedNameOrPropertyAccess(node)) {
                node = node.parent;
            }
            switch (node.kind) {
                case 108 /* ThisKeyword */:
                    return !isExpressionNode(node);
                case 194 /* ThisType */:
                    return true;
            }
            switch (node.parent.kind) {
                case 180 /* TypeReference */:
                    return true;
                case 202 /* ImportType */:
                    return !node.parent.isTypeOf;
                case 230 /* ExpressionWithTypeArguments */:
                    return isPartOfTypeNode(node.parent);
            }
            return false;
        }
        function isCallExpressionTarget(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isCallExpression, selectExpressionOfCallOrNewExpressionOrDecorator, includeElementAccess, skipPastOuterExpressions);
        }
        function isNewExpressionTarget(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isNewExpression, selectExpressionOfCallOrNewExpressionOrDecorator, includeElementAccess, skipPastOuterExpressions);
        }
        function isCallOrNewExpressionTarget(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isCallOrNewExpression, selectExpressionOfCallOrNewExpressionOrDecorator, includeElementAccess, skipPastOuterExpressions);
        }
        function isTaggedTemplateTag(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isTaggedTemplateExpression, selectTagOfTaggedTemplateExpression, includeElementAccess, skipPastOuterExpressions);
        }
        function isDecoratorTarget(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isDecorator, selectExpressionOfCallOrNewExpressionOrDecorator, includeElementAccess, skipPastOuterExpressions);
        }
        function isJsxOpeningLikeElementTagName(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isJsxOpeningLikeElement, selectTagNameOfJsxOpeningLikeElement, includeElementAccess, skipPastOuterExpressions);
        }
        function selectExpressionOfCallOrNewExpressionOrDecorator(node) {
            return node.expression;
        }
        function selectTagOfTaggedTemplateExpression(node) {
            return node.tag;
        }
        function selectTagNameOfJsxOpeningLikeElement(node) {
            return node.tagName;
        }
        function isCalleeWorker(node, pred, calleeSelector, includeElementAccess, skipPastOuterExpressions) {
            let target = includeElementAccess ? climbPastPropertyOrElementAccess(node) : climbPastPropertyAccess(node);
            if (skipPastOuterExpressions) {
                target = skipOuterExpressions(target);
            }
            return !!target && !!target.parent && pred(target.parent) && calleeSelector(target.parent) === target;
        }
        function climbPastPropertyAccess(node) {
            return isRightSideOfPropertyAccess(node) ? node.parent : node;
        }
        function climbPastPropertyOrElementAccess(node) {
            return isRightSideOfPropertyAccess(node) || isArgumentExpressionOfElementAccess(node) ? node.parent : node;
        }
        function getTargetLabel(referenceNode, labelName) {
            while (referenceNode) {
                if (referenceNode.kind === 253 /* LabeledStatement */ && referenceNode.label.escapedText === labelName) {
                    return referenceNode.label;
                }
                referenceNode = referenceNode.parent;
            }
            return void 0;
        }
        function hasPropertyAccessExpressionWithName(node, funcName) {
            if (!isPropertyAccessExpression(node.expression)) {
                return false;
            }
            return node.expression.name.text === funcName;
        }
        function isJumpStatementTarget(node) {
            var _a2;
            return isIdentifier(node) && ((_a2 = tryCast(node.parent, isBreakOrContinueStatement)) == null ? void 0 : _a2.label) === node;
        }
        function isLabelOfLabeledStatement(node) {
            var _a2;
            return isIdentifier(node) && ((_a2 = tryCast(node.parent, isLabeledStatement)) == null ? void 0 : _a2.label) === node;
        }
        function isLabelName(node) {
            return isLabelOfLabeledStatement(node) || isJumpStatementTarget(node);
        }
        function isTagName(node) {
            var _a2;
            return ((_a2 = tryCast(node.parent, isJSDocTag)) == null ? void 0 : _a2.tagName) === node;
        }
        function isRightSideOfQualifiedName(node) {
            var _a2;
            return ((_a2 = tryCast(node.parent, isQualifiedName)) == null ? void 0 : _a2.right) === node;
        }
        function isRightSideOfPropertyAccess(node) {
            var _a2;
            return ((_a2 = tryCast(node.parent, isPropertyAccessExpression)) == null ? void 0 : _a2.name) === node;
        }
        function isArgumentExpressionOfElementAccess(node) {
            var _a2;
            return ((_a2 = tryCast(node.parent, isElementAccessExpression)) == null ? void 0 : _a2.argumentExpression) === node;
        }
        function isNameOfModuleDeclaration(node) {
            var _a2;
            return ((_a2 = tryCast(node.parent, isModuleDeclaration)) == null ? void 0 : _a2.name) === node;
        }
        function isNameOfFunctionDeclaration(node) {
            var _a2;
            return isIdentifier(node) && ((_a2 = tryCast(node.parent, isFunctionLike)) == null ? void 0 : _a2.name) === node;
        }
        function isLiteralNameOfPropertyDeclarationOrIndexAccess(node) {
            switch (node.parent.kind) {
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 299 /* PropertyAssignment */:
                case 302 /* EnumMember */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 264 /* ModuleDeclaration */:
                    return getNameOfDeclaration(node.parent) === node;
                case 209 /* ElementAccessExpression */:
                    return node.parent.argumentExpression === node;
                case 164 /* ComputedPropertyName */:
                    return true;
                case 198 /* LiteralType */:
                    return node.parent.parent.kind === 196 /* IndexedAccessType */;
                default:
                    return false;
            }
        }
        function isExpressionOfExternalModuleImportEqualsDeclaration(node) {
            return isExternalModuleImportEqualsDeclaration(node.parent.parent) && getExternalModuleImportEqualsDeclarationExpression(node.parent.parent) === node;
        }
        function getContainerNode(node) {
            if (isJSDocTypeAlias(node)) {
                node = node.parent.parent;
            }
            while (true) {
                node = node.parent;
                if (!node) {
                    return void 0;
                }
                switch (node.kind) {
                    case 308 /* SourceFile */:
                    case 171 /* MethodDeclaration */:
                    case 170 /* MethodSignature */:
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 260 /* ClassDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                    case 263 /* EnumDeclaration */:
                    case 264 /* ModuleDeclaration */:
                        return node;
                }
            }
        }
        function getNodeKind(node) {
            switch (node.kind) {
                case 308 /* SourceFile */:
                    return isExternalModule(node) ? "module" /* moduleElement */ : "script" /* scriptElement */;
                case 264 /* ModuleDeclaration */:
                    return "module" /* moduleElement */;
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                    return "class" /* classElement */;
                case 261 /* InterfaceDeclaration */:
                    return "interface" /* interfaceElement */;
                case 262 /* TypeAliasDeclaration */:
                case 341 /* JSDocCallbackTag */:
                case 349 /* JSDocTypedefTag */:
                    return "type" /* typeElement */;
                case 263 /* EnumDeclaration */:
                    return "enum" /* enumElement */;
                case 257 /* VariableDeclaration */:
                    return getKindOfVariableDeclaration(node);
                case 205 /* BindingElement */:
                    return getKindOfVariableDeclaration(getRootDeclaration(node));
                case 216 /* ArrowFunction */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                    return "function" /* functionElement */;
                case 174 /* GetAccessor */:
                    return "getter" /* memberGetAccessorElement */;
                case 175 /* SetAccessor */:
                    return "setter" /* memberSetAccessorElement */;
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                    return "method" /* memberFunctionElement */;
                case 299 /* PropertyAssignment */:
                    const { initializer } = node;
                    return isFunctionLike(initializer) ? "method" /* memberFunctionElement */ : "property" /* memberVariableElement */;
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 300 /* ShorthandPropertyAssignment */:
                case 301 /* SpreadAssignment */:
                    return "property" /* memberVariableElement */;
                case 178 /* IndexSignature */:
                    return "index" /* indexSignatureElement */;
                case 177 /* ConstructSignature */:
                    return "construct" /* constructSignatureElement */;
                case 176 /* CallSignature */:
                    return "call" /* callSignatureElement */;
                case 173 /* Constructor */:
                case 172 /* ClassStaticBlockDeclaration */:
                    return "constructor" /* constructorImplementationElement */;
                case 165 /* TypeParameter */:
                    return "type parameter" /* typeParameterElement */;
                case 302 /* EnumMember */:
                    return "enum member" /* enumMemberElement */;
                case 166 /* Parameter */:
                    return hasSyntacticModifier(node, 16476 /* ParameterPropertyModifier */) ? "property" /* memberVariableElement */ : "parameter" /* parameterElement */;
                case 268 /* ImportEqualsDeclaration */:
                case 273 /* ImportSpecifier */:
                case 278 /* ExportSpecifier */:
                case 271 /* NamespaceImport */:
                case 277 /* NamespaceExport */:
                    return "alias" /* alias */;
                case 223 /* BinaryExpression */:
                    const kind = getAssignmentDeclarationKind(node);
                    const { right } = node;
                    switch (kind) {
                        case 7 /* ObjectDefinePropertyValue */:
                        case 8 /* ObjectDefinePropertyExports */:
                        case 9 /* ObjectDefinePrototypeProperty */:
                        case 0 /* None */:
                            return "" /* unknown */;
                        case 1 /* ExportsProperty */:
                        case 2 /* ModuleExports */:
                            const rightKind = getNodeKind(right);
                            return rightKind === "" /* unknown */ ? "const" /* constElement */ : rightKind;
                        case 3 /* PrototypeProperty */:
                            return isFunctionExpression(right) ? "method" /* memberFunctionElement */ : "property" /* memberVariableElement */;
                        case 4 /* ThisProperty */:
                            return "property" /* memberVariableElement */;
                        case 5 /* Property */:
                            return isFunctionExpression(right) ? "method" /* memberFunctionElement */ : "property" /* memberVariableElement */;
                        case 6 /* Prototype */:
                            return "local class" /* localClassElement */;
                        default: {
                            assertType(kind);
                            return "" /* unknown */;
                        }
                    }
                case 79 /* Identifier */:
                    return isImportClause(node.parent) ? "alias" /* alias */ : "" /* unknown */;
                case 274 /* ExportAssignment */:
                    const scriptKind = getNodeKind(node.expression);
                    return scriptKind === "" /* unknown */ ? "const" /* constElement */ : scriptKind;
                default:
                    return "" /* unknown */;
            }
            function getKindOfVariableDeclaration(v) {
                return isVarConst(v) ? "const" /* constElement */ : isLet(v) ? "let" /* letElement */ : "var" /* variableElement */;
            }
        }
        function isThis(node) {
            switch (node.kind) {
                case 108 /* ThisKeyword */:
                    return true;
                case 79 /* Identifier */:
                    return identifierIsThisKeyword(node) && node.parent.kind === 166 /* Parameter */;
                default:
                    return false;
            }
        }
        function getLineStartPositionForPosition(position, sourceFile) {
            const lineStarts = getLineStarts(sourceFile);
            const line = sourceFile.getLineAndCharacterOfPosition(position).line;
            return lineStarts[line];
        }
        function rangeContainsRange(r1, r2) {
            return startEndContainsRange(r1.pos, r1.end, r2);
        }
        function rangeContainsRangeExclusive(r1, r2) {
            return rangeContainsPositionExclusive(r1, r2.pos) && rangeContainsPositionExclusive(r1, r2.end);
        }
        function rangeContainsPosition(r, pos) {
            return r.pos <= pos && pos <= r.end;
        }
        function rangeContainsPositionExclusive(r, pos) {
            return r.pos < pos && pos < r.end;
        }
        function startEndContainsRange(start, end, range) {
            return start <= range.pos && end >= range.end;
        }
        function rangeContainsStartEnd(range, start, end) {
            return range.pos <= start && range.end >= end;
        }
        function rangeOverlapsWithStartEnd(r1, start, end) {
            return startEndOverlapsWithStartEnd(r1.pos, r1.end, start, end);
        }
        function nodeOverlapsWithStartEnd(node, sourceFile, start, end) {
            return startEndOverlapsWithStartEnd(node.getStart(sourceFile), node.end, start, end);
        }
        function startEndOverlapsWithStartEnd(start1, end1, start2, end2) {
            const start = Math.max(start1, start2);
            const end = Math.min(end1, end2);
            return start < end;
        }
        function positionBelongsToNode(candidate, position, sourceFile) {
            Debug.assert(candidate.pos <= position);
            return position < candidate.end || !isCompletedNode(candidate, sourceFile);
        }
        function isCompletedNode(n, sourceFile) {
            if (n === void 0 || nodeIsMissing(n)) {
                return false;
            }
            switch (n.kind) {
                case 260 /* ClassDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 263 /* EnumDeclaration */:
                case 207 /* ObjectLiteralExpression */:
                case 203 /* ObjectBindingPattern */:
                case 184 /* TypeLiteral */:
                case 238 /* Block */:
                case 265 /* ModuleBlock */:
                case 266 /* CaseBlock */:
                case 272 /* NamedImports */:
                case 276 /* NamedExports */:
                    return nodeEndsWith(n, 19 /* CloseBraceToken */, sourceFile);
                case 295 /* CatchClause */:
                    return isCompletedNode(n.block, sourceFile);
                case 211 /* NewExpression */:
                    if (!n.arguments) {
                        return true;
                    }
                case 210 /* CallExpression */:
                case 214 /* ParenthesizedExpression */:
                case 193 /* ParenthesizedType */:
                    return nodeEndsWith(n, 21 /* CloseParenToken */, sourceFile);
                case 181 /* FunctionType */:
                case 182 /* ConstructorType */:
                    return isCompletedNode(n.type, sourceFile);
                case 173 /* Constructor */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 177 /* ConstructSignature */:
                case 176 /* CallSignature */:
                case 216 /* ArrowFunction */:
                    if (n.body) {
                        return isCompletedNode(n.body, sourceFile);
                    }
                    if (n.type) {
                        return isCompletedNode(n.type, sourceFile);
                    }
                    return hasChildOfKind(n, 21 /* CloseParenToken */, sourceFile);
                case 264 /* ModuleDeclaration */:
                    return !!n.body && isCompletedNode(n.body, sourceFile);
                case 242 /* IfStatement */:
                    if (n.elseStatement) {
                        return isCompletedNode(n.elseStatement, sourceFile);
                    }
                    return isCompletedNode(n.thenStatement, sourceFile);
                case 241 /* ExpressionStatement */:
                    return isCompletedNode(n.expression, sourceFile) || hasChildOfKind(n, 26 /* SemicolonToken */, sourceFile);
                case 206 /* ArrayLiteralExpression */:
                case 204 /* ArrayBindingPattern */:
                case 209 /* ElementAccessExpression */:
                case 164 /* ComputedPropertyName */:
                case 186 /* TupleType */:
                    return nodeEndsWith(n, 23 /* CloseBracketToken */, sourceFile);
                case 178 /* IndexSignature */:
                    if (n.type) {
                        return isCompletedNode(n.type, sourceFile);
                    }
                    return hasChildOfKind(n, 23 /* CloseBracketToken */, sourceFile);
                case 292 /* CaseClause */:
                case 293 /* DefaultClause */:
                    return false;
                case 245 /* ForStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                case 244 /* WhileStatement */:
                    return isCompletedNode(n.statement, sourceFile);
                case 243 /* DoStatement */:
                    return hasChildOfKind(n, 115 /* WhileKeyword */, sourceFile) ? nodeEndsWith(n, 21 /* CloseParenToken */, sourceFile) : isCompletedNode(n.statement, sourceFile);
                case 183 /* TypeQuery */:
                    return isCompletedNode(n.exprName, sourceFile);
                case 218 /* TypeOfExpression */:
                case 217 /* DeleteExpression */:
                case 219 /* VoidExpression */:
                case 226 /* YieldExpression */:
                case 227 /* SpreadElement */:
                    const unaryWordExpression = n;
                    return isCompletedNode(unaryWordExpression.expression, sourceFile);
                case 212 /* TaggedTemplateExpression */:
                    return isCompletedNode(n.template, sourceFile);
                case 225 /* TemplateExpression */:
                    const lastSpan = lastOrUndefined(n.templateSpans);
                    return isCompletedNode(lastSpan, sourceFile);
                case 236 /* TemplateSpan */:
                    return nodeIsPresent(n.literal);
                case 275 /* ExportDeclaration */:
                case 269 /* ImportDeclaration */:
                    return nodeIsPresent(n.moduleSpecifier);
                case 221 /* PrefixUnaryExpression */:
                    return isCompletedNode(n.operand, sourceFile);
                case 223 /* BinaryExpression */:
                    return isCompletedNode(n.right, sourceFile);
                case 224 /* ConditionalExpression */:
                    return isCompletedNode(n.whenFalse, sourceFile);
                default:
                    return true;
            }
        }
        function nodeEndsWith(n, expectedLastToken, sourceFile) {
            const children = n.getChildren(sourceFile);
            if (children.length) {
                const lastChild = last(children);
                if (lastChild.kind === expectedLastToken) {
                    return true;
                }
                else if (lastChild.kind === 26 /* SemicolonToken */ && children.length !== 1) {
                    return children[children.length - 2].kind === expectedLastToken;
                }
            }
            return false;
        }
        function findListItemInfo(node) {
            const list = findContainingList(node);
            if (!list) {
                return void 0;
            }
            const children = list.getChildren();
            const listItemIndex = indexOfNode(children, node);
            return {
                listItemIndex,
                list
            };
        }
        function hasChildOfKind(n, kind, sourceFile) {
            return !!findChildOfKind(n, kind, sourceFile);
        }
        function findChildOfKind(n, kind, sourceFile) {
            return find(n.getChildren(sourceFile), (c) => c.kind === kind);
        }
        function findContainingList(node) {
            const syntaxList = find(node.parent.getChildren(), (c) => isSyntaxList(c) && rangeContainsRange(c, node));
            Debug.assert(!syntaxList || contains(syntaxList.getChildren(), node));
            return syntaxList;
        }
        function isDefaultModifier2(node) {
            return node.kind === 88 /* DefaultKeyword */;
        }
        function isClassKeyword(node) {
            return node.kind === 84 /* ClassKeyword */;
        }
        function isFunctionKeyword(node) {
            return node.kind === 98 /* FunctionKeyword */;
        }
        function getAdjustedLocationForClass(node) {
            if (isNamedDeclaration(node)) {
                return node.name;
            }
            if (isClassDeclaration(node)) {
                const defaultModifier = node.modifiers && find(node.modifiers, isDefaultModifier2);
                if (defaultModifier)
                    return defaultModifier;
            }
            if (isClassExpression(node)) {
                const classKeyword = find(node.getChildren(), isClassKeyword);
                if (classKeyword)
                    return classKeyword;
            }
        }
        function getAdjustedLocationForFunction(node) {
            if (isNamedDeclaration(node)) {
                return node.name;
            }
            if (isFunctionDeclaration(node)) {
                const defaultModifier = find(node.modifiers, isDefaultModifier2);
                if (defaultModifier)
                    return defaultModifier;
            }
            if (isFunctionExpression(node)) {
                const functionKeyword = find(node.getChildren(), isFunctionKeyword);
                if (functionKeyword)
                    return functionKeyword;
            }
        }
        function getAncestorTypeNode(node) {
            let lastTypeNode;
            findAncestor(node, (a) => {
                if (isTypeNode(a)) {
                    lastTypeNode = a;
                }
                return !isQualifiedName(a.parent) && !isTypeNode(a.parent) && !isTypeElement(a.parent);
            });
            return lastTypeNode;
        }
        function getContextualTypeFromParentOrAncestorTypeNode(node, checker) {
            if (node.flags & (8388608 /* JSDoc */ & ~262144 /* JavaScriptFile */))
                return void 0;
            const contextualType = getContextualTypeFromParent(node, checker);
            if (contextualType)
                return contextualType;
            const ancestorTypeNode = getAncestorTypeNode(node);
            return ancestorTypeNode && checker.getTypeAtLocation(ancestorTypeNode);
        }
        function getAdjustedLocationForDeclaration(node, forRename) {
            if (!forRename) {
                switch (node.kind) {
                    case 260 /* ClassDeclaration */:
                    case 228 /* ClassExpression */:
                        return getAdjustedLocationForClass(node);
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                        return getAdjustedLocationForFunction(node);
                    case 173 /* Constructor */:
                        return node;
                }
            }
            if (isNamedDeclaration(node)) {
                return node.name;
            }
        }
        function getAdjustedLocationForImportDeclaration(node, forRename) {
            if (node.importClause) {
                if (node.importClause.name && node.importClause.namedBindings) {
                    return;
                }
                if (node.importClause.name) {
                    return node.importClause.name;
                }
                if (node.importClause.namedBindings) {
                    if (isNamedImports(node.importClause.namedBindings)) {
                        const onlyBinding = singleOrUndefined(node.importClause.namedBindings.elements);
                        if (!onlyBinding) {
                            return;
                        }
                        return onlyBinding.name;
                    }
                    else if (isNamespaceImport(node.importClause.namedBindings)) {
                        return node.importClause.namedBindings.name;
                    }
                }
            }
            if (!forRename) {
                return node.moduleSpecifier;
            }
        }
        function getAdjustedLocationForExportDeclaration(node, forRename) {
            if (node.exportClause) {
                if (isNamedExports(node.exportClause)) {
                    const onlyBinding = singleOrUndefined(node.exportClause.elements);
                    if (!onlyBinding) {
                        return;
                    }
                    return node.exportClause.elements[0].name;
                }
                else if (isNamespaceExport(node.exportClause)) {
                    return node.exportClause.name;
                }
            }
            if (!forRename) {
                return node.moduleSpecifier;
            }
        }
        function getAdjustedLocationForHeritageClause(node) {
            if (node.types.length === 1) {
                return node.types[0].expression;
            }
        }
        function getAdjustedLocation(node, forRename) {
            const { parent: parent2 } = node;
            if (isModifier(node) && (forRename || node.kind !== 88 /* DefaultKeyword */) ? canHaveModifiers(parent2) && contains(parent2.modifiers, node) : node.kind === 84 /* ClassKeyword */ ? isClassDeclaration(parent2) || isClassExpression(node) : node.kind === 98 /* FunctionKeyword */ ? isFunctionDeclaration(parent2) || isFunctionExpression(node) : node.kind === 118 /* InterfaceKeyword */ ? isInterfaceDeclaration(parent2) : node.kind === 92 /* EnumKeyword */ ? isEnumDeclaration(parent2) : node.kind === 154 /* TypeKeyword */ ? isTypeAliasDeclaration(parent2) : node.kind === 143 /* NamespaceKeyword */ || node.kind === 142 /* ModuleKeyword */ ? isModuleDeclaration(parent2) : node.kind === 100 /* ImportKeyword */ ? isImportEqualsDeclaration(parent2) : node.kind === 137 /* GetKeyword */ ? isGetAccessorDeclaration(parent2) : node.kind === 151 /* SetKeyword */ && isSetAccessorDeclaration(parent2)) {
                const location = getAdjustedLocationForDeclaration(parent2, forRename);
                if (location) {
                    return location;
                }
            }
            if ((node.kind === 113 /* VarKeyword */ || node.kind === 85 /* ConstKeyword */ || node.kind === 119 /* LetKeyword */) && isVariableDeclarationList(parent2) && parent2.declarations.length === 1) {
                const decl = parent2.declarations[0];
                if (isIdentifier(decl.name)) {
                    return decl.name;
                }
            }
            if (node.kind === 154 /* TypeKeyword */) {
                if (isImportClause(parent2) && parent2.isTypeOnly) {
                    const location = getAdjustedLocationForImportDeclaration(parent2.parent, forRename);
                    if (location) {
                        return location;
                    }
                }
                if (isExportDeclaration(parent2) && parent2.isTypeOnly) {
                    const location = getAdjustedLocationForExportDeclaration(parent2, forRename);
                    if (location) {
                        return location;
                    }
                }
            }
            if (node.kind === 128 /* AsKeyword */) {
                if (isImportSpecifier(parent2) && parent2.propertyName || isExportSpecifier(parent2) && parent2.propertyName || isNamespaceImport(parent2) || isNamespaceExport(parent2)) {
                    return parent2.name;
                }
                if (isExportDeclaration(parent2) && parent2.exportClause && isNamespaceExport(parent2.exportClause)) {
                    return parent2.exportClause.name;
                }
            }
            if (node.kind === 100 /* ImportKeyword */ && isImportDeclaration(parent2)) {
                const location = getAdjustedLocationForImportDeclaration(parent2, forRename);
                if (location) {
                    return location;
                }
            }
            if (node.kind === 93 /* ExportKeyword */) {
                if (isExportDeclaration(parent2)) {
                    const location = getAdjustedLocationForExportDeclaration(parent2, forRename);
                    if (location) {
                        return location;
                    }
                }
                if (isExportAssignment(parent2)) {
                    return skipOuterExpressions(parent2.expression);
                }
            }
            if (node.kind === 147 /* RequireKeyword */ && isExternalModuleReference(parent2)) {
                return parent2.expression;
            }
            if (node.kind === 158 /* FromKeyword */ && (isImportDeclaration(parent2) || isExportDeclaration(parent2)) && parent2.moduleSpecifier) {
                return parent2.moduleSpecifier;
            }
            if ((node.kind === 94 /* ExtendsKeyword */ || node.kind === 117 /* ImplementsKeyword */) && isHeritageClause(parent2) && parent2.token === node.kind) {
                const location = getAdjustedLocationForHeritageClause(parent2);
                if (location) {
                    return location;
                }
            }
            if (node.kind === 94 /* ExtendsKeyword */) {
                if (isTypeParameterDeclaration(parent2) && parent2.constraint && isTypeReferenceNode(parent2.constraint)) {
                    return parent2.constraint.typeName;
                }
                if (isConditionalTypeNode(parent2) && isTypeReferenceNode(parent2.extendsType)) {
                    return parent2.extendsType.typeName;
                }
            }
            if (node.kind === 138 /* InferKeyword */ && isInferTypeNode(parent2)) {
                return parent2.typeParameter.name;
            }
            if (node.kind === 101 /* InKeyword */ && isTypeParameterDeclaration(parent2) && isMappedTypeNode(parent2.parent)) {
                return parent2.name;
            }
            if (node.kind === 141 /* KeyOfKeyword */ && isTypeOperatorNode(parent2) && parent2.operator === 141 /* KeyOfKeyword */ && isTypeReferenceNode(parent2.type)) {
                return parent2.type.typeName;
            }
            if (node.kind === 146 /* ReadonlyKeyword */ && isTypeOperatorNode(parent2) && parent2.operator === 146 /* ReadonlyKeyword */ && isArrayTypeNode(parent2.type) && isTypeReferenceNode(parent2.type.elementType)) {
                return parent2.type.elementType.typeName;
            }
            if (!forRename) {
                if (node.kind === 103 /* NewKeyword */ && isNewExpression(parent2) || node.kind === 114 /* VoidKeyword */ && isVoidExpression(parent2) || node.kind === 112 /* TypeOfKeyword */ && isTypeOfExpression(parent2) || node.kind === 133 /* AwaitKeyword */ && isAwaitExpression(parent2) || node.kind === 125 /* YieldKeyword */ && isYieldExpression(parent2) || node.kind === 89 /* DeleteKeyword */ && isDeleteExpression(parent2)) {
                    if (parent2.expression) {
                        return skipOuterExpressions(parent2.expression);
                    }
                }
                if ((node.kind === 101 /* InKeyword */ || node.kind === 102 /* InstanceOfKeyword */) && isBinaryExpression(parent2) && parent2.operatorToken === node) {
                    return skipOuterExpressions(parent2.right);
                }
                if (node.kind === 128 /* AsKeyword */ && isAsExpression(parent2) && isTypeReferenceNode(parent2.type)) {
                    return parent2.type.typeName;
                }
                if (node.kind === 101 /* InKeyword */ && isForInStatement(parent2) || node.kind === 162 /* OfKeyword */ && isForOfStatement(parent2)) {
                    return skipOuterExpressions(parent2.expression);
                }
            }
            return node;
        }
        function getAdjustedReferenceLocation(node) {
            return getAdjustedLocation(node, 
            /*forRename*/
            false);
        }
        function getAdjustedRenameLocation(node) {
            return getAdjustedLocation(node, 
            /*forRename*/
            true);
        }
        function getTouchingPropertyName(sourceFile, position) {
            return getTouchingToken(sourceFile, position, (n) => isPropertyNameLiteral(n) || isKeyword(n.kind) || isPrivateIdentifier(n));
        }
        function getTouchingToken(sourceFile, position, includePrecedingTokenAtEndPosition) {
            return getTokenAtPositionWorker(sourceFile, position, 
            /*allowPositionInLeadingTrivia*/
            false, includePrecedingTokenAtEndPosition, 
            /*includeEndPosition*/
            false);
        }
        function getTokenAtPosition(sourceFile, position) {
            return getTokenAtPositionWorker(sourceFile, position, 
            /*allowPositionInLeadingTrivia*/
            true, 
            /*includePrecedingTokenAtEndPosition*/
            void 0, 
            /*includeEndPosition*/
            false);
        }
        function getTokenAtPositionWorker(sourceFile, position, allowPositionInLeadingTrivia, includePrecedingTokenAtEndPosition, includeEndPosition) {
            let current = sourceFile;
            let foundToken;
            outer: while (true) {
                const children = current.getChildren(sourceFile);
                const i = binarySearchKey(children, position, (_, i2) => i2, (middle, _) => {
                    const end = children[middle].getEnd();
                    if (end < position) {
                        return -1 /* LessThan */;
                    }
                    const start = allowPositionInLeadingTrivia ? children[middle].getFullStart() : children[middle].getStart(sourceFile, 
                    /*includeJsDoc*/
                    true);
                    if (start > position) {
                        return 1 /* GreaterThan */;
                    }
                    if (nodeContainsPosition(children[middle], start, end)) {
                        if (children[middle - 1]) {
                            if (nodeContainsPosition(children[middle - 1])) {
                                return 1 /* GreaterThan */;
                            }
                        }
                        return 0 /* EqualTo */;
                    }
                    if (includePrecedingTokenAtEndPosition && start === position && children[middle - 1] && children[middle - 1].getEnd() === position && nodeContainsPosition(children[middle - 1])) {
                        return 1 /* GreaterThan */;
                    }
                    return -1 /* LessThan */;
                });
                if (foundToken) {
                    return foundToken;
                }
                if (i >= 0 && children[i]) {
                    current = children[i];
                    continue outer;
                }
                return current;
            }
            function nodeContainsPosition(node, start, end) {
                end != null ? end : end = node.getEnd();
                if (end < position) {
                    return false;
                }
                start != null ? start : start = allowPositionInLeadingTrivia ? node.getFullStart() : node.getStart(sourceFile, 
                /*includeJsDoc*/
                true);
                if (start > position) {
                    return false;
                }
                if (position < end || position === end && (node.kind === 1 /* EndOfFileToken */ || includeEndPosition)) {
                    return true;
                }
                else if (includePrecedingTokenAtEndPosition && end === position) {
                    const previousToken = findPrecedingToken(position, sourceFile, node);
                    if (previousToken && includePrecedingTokenAtEndPosition(previousToken)) {
                        foundToken = previousToken;
                        return true;
                    }
                }
                return false;
            }
        }
        function findFirstNonJsxWhitespaceToken(sourceFile, position) {
            let tokenAtPosition = getTokenAtPosition(sourceFile, position);
            while (isWhiteSpaceOnlyJsxText(tokenAtPosition)) {
                const nextToken = findNextToken(tokenAtPosition, tokenAtPosition.parent, sourceFile);
                if (!nextToken)
                    return;
                tokenAtPosition = nextToken;
            }
            return tokenAtPosition;
        }
        function findTokenOnLeftOfPosition(file, position) {
            const tokenAtPosition = getTokenAtPosition(file, position);
            if (isToken(tokenAtPosition) && position > tokenAtPosition.getStart(file) && position < tokenAtPosition.getEnd()) {
                return tokenAtPosition;
            }
            return findPrecedingToken(position, file);
        }
        function findNextToken(previousToken, parent2, sourceFile) {
            return find2(parent2);
            function find2(n) {
                if (isToken(n) && n.pos === previousToken.end) {
                    return n;
                }
                return firstDefined(n.getChildren(sourceFile), (child) => {
                    const shouldDiveInChildNode = (
                    // previous token is enclosed somewhere in the child
                    child.pos <= previousToken.pos && child.end > previousToken.end || // previous token ends exactly at the beginning of child
                        child.pos === previousToken.end);
                    return shouldDiveInChildNode && nodeHasTokens(child, sourceFile) ? find2(child) : void 0;
                });
            }
        }
        function findPrecedingToken(position, sourceFile, startNode2, excludeJsdoc) {
            const result = find2(startNode2 || sourceFile);
            Debug.assert(!(result && isWhiteSpaceOnlyJsxText(result)));
            return result;
            function find2(n) {
                if (isNonWhitespaceToken(n) && n.kind !== 1 /* EndOfFileToken */) {
                    return n;
                }
                const children = n.getChildren(sourceFile);
                const i = binarySearchKey(children, position, (_, i2) => i2, (middle, _) => {
                    if (position < children[middle].end) {
                        if (!children[middle - 1] || position >= children[middle - 1].end) {
                            return 0 /* EqualTo */;
                        }
                        return 1 /* GreaterThan */;
                    }
                    return -1 /* LessThan */;
                });
                if (i >= 0 && children[i]) {
                    const child = children[i];
                    if (position < child.end) {
                        const start = child.getStart(sourceFile, 
                        /*includeJsDoc*/
                        !excludeJsdoc);
                        const lookInPreviousChild = start >= position || // cursor in the leading trivia
                            !nodeHasTokens(child, sourceFile) || isWhiteSpaceOnlyJsxText(child);
                        if (lookInPreviousChild) {
                            const candidate2 = findRightmostChildNodeWithTokens(children, 
                            /*exclusiveStartPosition*/
                            i, sourceFile, n.kind);
                            return candidate2 && findRightmostToken(candidate2, sourceFile);
                        }
                        else {
                            return find2(child);
                        }
                    }
                }
                Debug.assert(startNode2 !== void 0 || n.kind === 308 /* SourceFile */ || n.kind === 1 /* EndOfFileToken */ || isJSDocCommentContainingNode(n));
                const candidate = findRightmostChildNodeWithTokens(children, 
                /*exclusiveStartPosition*/
                children.length, sourceFile, n.kind);
                return candidate && findRightmostToken(candidate, sourceFile);
            }
        }
        function isNonWhitespaceToken(n) {
            return isToken(n) && !isWhiteSpaceOnlyJsxText(n);
        }
        function findRightmostToken(n, sourceFile) {
            if (isNonWhitespaceToken(n)) {
                return n;
            }
            const children = n.getChildren(sourceFile);
            if (children.length === 0) {
                return n;
            }
            const candidate = findRightmostChildNodeWithTokens(children, 
            /*exclusiveStartPosition*/
            children.length, sourceFile, n.kind);
            return candidate && findRightmostToken(candidate, sourceFile);
        }
        function findRightmostChildNodeWithTokens(children, exclusiveStartPosition, sourceFile, parentKind) {
            for (let i = exclusiveStartPosition - 1; i >= 0; i--) {
                const child = children[i];
                if (isWhiteSpaceOnlyJsxText(child)) {
                    if (i === 0 && (parentKind === 11 /* JsxText */ || parentKind === 282 /* JsxSelfClosingElement */)) {
                        Debug.fail("`JsxText` tokens should not be the first child of `JsxElement | JsxSelfClosingElement`");
                    }
                }
                else if (nodeHasTokens(children[i], sourceFile)) {
                    return children[i];
                }
            }
        }
        function isInString(sourceFile, position, previousToken = findPrecedingToken(position, sourceFile)) {
            if (previousToken && isStringTextContainingNode(previousToken)) {
                const start = previousToken.getStart(sourceFile);
                const end = previousToken.getEnd();
                if (start < position && position < end) {
                    return true;
                }
                if (position === end) {
                    return !!previousToken.isUnterminated;
                }
            }
            return false;
        }
        function isInsideJsxElementOrAttribute(sourceFile, position) {
            const token = getTokenAtPosition(sourceFile, position);
            if (!token) {
                return false;
            }
            if (token.kind === 11 /* JsxText */) {
                return true;
            }
            if (token.kind === 29 /* LessThanToken */ && token.parent.kind === 11 /* JsxText */) {
                return true;
            }
            if (token.kind === 29 /* LessThanToken */ && token.parent.kind === 291 /* JsxExpression */) {
                return true;
            }
            if (token && token.kind === 19 /* CloseBraceToken */ && token.parent.kind === 291 /* JsxExpression */) {
                return true;
            }
            if (token.kind === 29 /* LessThanToken */ && token.parent.kind === 284 /* JsxClosingElement */) {
                return true;
            }
            return false;
        }
        function isWhiteSpaceOnlyJsxText(node) {
            return isJsxText(node) && node.containsOnlyTriviaWhiteSpaces;
        }
        function isInTemplateString(sourceFile, position) {
            const token = getTokenAtPosition(sourceFile, position);
            return isTemplateLiteralKind(token.kind) && position > token.getStart(sourceFile);
        }
        function isInJSXText(sourceFile, position) {
            const token = getTokenAtPosition(sourceFile, position);
            if (isJsxText(token)) {
                return true;
            }
            if (token.kind === 18 /* OpenBraceToken */ && isJsxExpression(token.parent) && isJsxElement(token.parent.parent)) {
                return true;
            }
            if (token.kind === 29 /* LessThanToken */ && isJsxOpeningLikeElement(token.parent) && isJsxElement(token.parent.parent)) {
                return true;
            }
            return false;
        }
        function isInsideJsxElement(sourceFile, position) {
            function isInsideJsxElementTraversal(node) {
                while (node) {
                    if (node.kind >= 282 /* JsxSelfClosingElement */ && node.kind <= 291 /* JsxExpression */ || node.kind === 11 /* JsxText */ || node.kind === 29 /* LessThanToken */ || node.kind === 31 /* GreaterThanToken */ || node.kind === 79 /* Identifier */ || node.kind === 19 /* CloseBraceToken */ || node.kind === 18 /* OpenBraceToken */ || node.kind === 43 /* SlashToken */) {
                        node = node.parent;
                    }
                    else if (node.kind === 281 /* JsxElement */) {
                        if (position > node.getStart(sourceFile))
                            return true;
                        node = node.parent;
                    }
                    else {
                        return false;
                    }
                }
                return false;
            }
            return isInsideJsxElementTraversal(getTokenAtPosition(sourceFile, position));
        }
        function findPrecedingMatchingToken(token, matchingTokenKind, sourceFile) {
            const closeTokenText = tokenToString(token.kind);
            const matchingTokenText = tokenToString(matchingTokenKind);
            const tokenFullStart = token.getFullStart();
            const bestGuessIndex = sourceFile.text.lastIndexOf(matchingTokenText, tokenFullStart);
            if (bestGuessIndex === -1) {
                return void 0;
            }
            if (sourceFile.text.lastIndexOf(closeTokenText, tokenFullStart - 1) < bestGuessIndex) {
                const nodeAtGuess = findPrecedingToken(bestGuessIndex + 1, sourceFile);
                if (nodeAtGuess && nodeAtGuess.kind === matchingTokenKind) {
                    return nodeAtGuess;
                }
            }
            const tokenKind = token.kind;
            let remainingMatchingTokens = 0;
            while (true) {
                const preceding = findPrecedingToken(token.getFullStart(), sourceFile);
                if (!preceding) {
                    return void 0;
                }
                token = preceding;
                if (token.kind === matchingTokenKind) {
                    if (remainingMatchingTokens === 0) {
                        return token;
                    }
                    remainingMatchingTokens--;
                }
                else if (token.kind === tokenKind) {
                    remainingMatchingTokens++;
                }
            }
        }
        function removeOptionality(type, isOptionalExpression, isOptionalChain2) {
            return isOptionalExpression ? type.getNonNullableType() : isOptionalChain2 ? type.getNonOptionalType() : type;
        }
        function isPossiblyTypeArgumentPosition(token, sourceFile, checker) {
            const info = getPossibleTypeArgumentsInfo(token, sourceFile);
            return info !== void 0 && (isPartOfTypeNode(info.called) || getPossibleGenericSignatures(info.called, info.nTypeArguments, checker).length !== 0 || isPossiblyTypeArgumentPosition(info.called, sourceFile, checker));
        }
        function getPossibleGenericSignatures(called, typeArgumentCount, checker) {
            let type = checker.getTypeAtLocation(called);
            if (isOptionalChain(called.parent)) {
                type = removeOptionality(type, isOptionalChainRoot(called.parent), 
                /*isOptionalChain*/
                true);
            }
            const signatures = isNewExpression(called.parent) ? type.getConstructSignatures() : type.getCallSignatures();
            return signatures.filter((candidate) => !!candidate.typeParameters && candidate.typeParameters.length >= typeArgumentCount);
        }
        function getPossibleTypeArgumentsInfo(tokenIn, sourceFile) {
            if (sourceFile.text.lastIndexOf("<", tokenIn ? tokenIn.pos : sourceFile.text.length) === -1) {
                return void 0;
            }
            let token = tokenIn;
            let remainingLessThanTokens = 0;
            let nTypeArguments = 0;
            while (token) {
                switch (token.kind) {
                    case 29 /* LessThanToken */:
                        token = findPrecedingToken(token.getFullStart(), sourceFile);
                        if (token && token.kind === 28 /* QuestionDotToken */) {
                            token = findPrecedingToken(token.getFullStart(), sourceFile);
                        }
                        if (!token || !isIdentifier(token))
                            return void 0;
                        if (!remainingLessThanTokens) {
                            return isDeclarationName(token) ? void 0 : { called: token, nTypeArguments };
                        }
                        remainingLessThanTokens--;
                        break;
                    case 49 /* GreaterThanGreaterThanGreaterThanToken */:
                        remainingLessThanTokens = 3;
                        break;
                    case 48 /* GreaterThanGreaterThanToken */:
                        remainingLessThanTokens = 2;
                        break;
                    case 31 /* GreaterThanToken */:
                        remainingLessThanTokens++;
                        break;
                    case 19 /* CloseBraceToken */:
                        token = findPrecedingMatchingToken(token, 18 /* OpenBraceToken */, sourceFile);
                        if (!token)
                            return void 0;
                        break;
                    case 21 /* CloseParenToken */:
                        token = findPrecedingMatchingToken(token, 20 /* OpenParenToken */, sourceFile);
                        if (!token)
                            return void 0;
                        break;
                    case 23 /* CloseBracketToken */:
                        token = findPrecedingMatchingToken(token, 22 /* OpenBracketToken */, sourceFile);
                        if (!token)
                            return void 0;
                        break;
                    case 27 /* CommaToken */:
                        nTypeArguments++;
                        break;
                    case 38 /* EqualsGreaterThanToken */:
                    case 79 /* Identifier */:
                    case 10 /* StringLiteral */:
                    case 8 /* NumericLiteral */:
                    case 9 /* BigIntLiteral */:
                    case 110 /* TrueKeyword */:
                    case 95 /* FalseKeyword */:
                    case 112 /* TypeOfKeyword */:
                    case 94 /* ExtendsKeyword */:
                    case 141 /* KeyOfKeyword */:
                    case 24 /* DotToken */:
                    case 51 /* BarToken */:
                    case 57 /* QuestionToken */:
                    case 58 /* ColonToken */:
                        break;
                    default:
                        if (isTypeNode(token)) {
                            break;
                        }
                        return void 0;
                }
                token = findPrecedingToken(token.getFullStart(), sourceFile);
            }
            return void 0;
        }
        function isInComment(sourceFile, position, tokenAtPosition) {
            return ts_formatting_exports.getRangeOfEnclosingComment(sourceFile, position, 
            /*precedingToken*/
            void 0, tokenAtPosition);
        }
        function hasDocComment(sourceFile, position) {
            const token = getTokenAtPosition(sourceFile, position);
            return !!findAncestor(token, isJSDoc);
        }
        function nodeHasTokens(n, sourceFile) {
            return n.kind === 1 /* EndOfFileToken */ ? !!n.jsDoc : n.getWidth(sourceFile) !== 0;
        }
        function getNodeModifiers(node, excludeFlags = 0 /* None */) {
            const result = [];
            const flags = isDeclaration(node) ? getCombinedNodeFlagsAlwaysIncludeJSDoc(node) & ~excludeFlags : 0 /* None */;
            if (flags & 8 /* Private */)
                result.push("private" /* privateMemberModifier */);
            if (flags & 16 /* Protected */)
                result.push("protected" /* protectedMemberModifier */);
            if (flags & 4 /* Public */)
                result.push("public" /* publicMemberModifier */);
            if (flags & 32 /* Static */ || isClassStaticBlockDeclaration(node))
                result.push("static" /* staticModifier */);
            if (flags & 256 /* Abstract */)
                result.push("abstract" /* abstractModifier */);
            if (flags & 1 /* Export */)
                result.push("export" /* exportedModifier */);
            if (flags & 8192 /* Deprecated */)
                result.push("deprecated" /* deprecatedModifier */);
            if (node.flags & 16777216 /* Ambient */)
                result.push("declare" /* ambientModifier */);
            if (node.kind === 274 /* ExportAssignment */)
                result.push("export" /* exportedModifier */);
            return result.length > 0 ? result.join(",") : "" /* none */;
        }
        function getTypeArgumentOrTypeParameterList(node) {
            if (node.kind === 180 /* TypeReference */ || node.kind === 210 /* CallExpression */) {
                return node.typeArguments;
            }
            if (isFunctionLike(node) || node.kind === 260 /* ClassDeclaration */ || node.kind === 261 /* InterfaceDeclaration */) {
                return node.typeParameters;
            }
            return void 0;
        }
        function isComment(kind) {
            return kind === 2 /* SingleLineCommentTrivia */ || kind === 3 /* MultiLineCommentTrivia */;
        }
        function isStringOrRegularExpressionOrTemplateLiteral(kind) {
            if (kind === 10 /* StringLiteral */ || kind === 13 /* RegularExpressionLiteral */ || isTemplateLiteralKind(kind)) {
                return true;
            }
            return false;
        }
        function isStringAndEmptyAnonymousObjectIntersection(type) {
            if (!type.isIntersection()) {
                return false;
            }
            const { types, checker } = type;
            return types.length === 2 && types[0].flags & 4 /* String */ && checker.isEmptyAnonymousObjectType(types[1]);
        }
        function isPunctuation(kind) {
            return 18 /* FirstPunctuation */ <= kind && kind <= 78 /* LastPunctuation */;
        }
        function isInsideTemplateLiteral(node, position, sourceFile) {
            return isTemplateLiteralKind(node.kind) && (node.getStart(sourceFile) < position && position < node.end) || !!node.isUnterminated && position === node.end;
        }
        function isAccessibilityModifier(kind) {
            switch (kind) {
                case 123 /* PublicKeyword */:
                case 121 /* PrivateKeyword */:
                case 122 /* ProtectedKeyword */:
                    return true;
            }
            return false;
        }
        function cloneCompilerOptions(options) {
            const result = clone(options);
            setConfigFileInOptions(result, options && options.configFile);
            return result;
        }
        function isArrayLiteralOrObjectLiteralDestructuringPattern(node) {
            if (node.kind === 206 /* ArrayLiteralExpression */ || node.kind === 207 /* ObjectLiteralExpression */) {
                if (node.parent.kind === 223 /* BinaryExpression */ && node.parent.left === node && node.parent.operatorToken.kind === 63 /* EqualsToken */) {
                    return true;
                }
                if (node.parent.kind === 247 /* ForOfStatement */ && node.parent.initializer === node) {
                    return true;
                }
                if (isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent.kind === 299 /* PropertyAssignment */ ? node.parent.parent : node.parent)) {
                    return true;
                }
            }
            return false;
        }
        function isInReferenceComment(sourceFile, position) {
            return isInReferenceCommentWorker(sourceFile, position, 
            /*shouldBeReference*/
            true);
        }
        function isInNonReferenceComment(sourceFile, position) {
            return isInReferenceCommentWorker(sourceFile, position, 
            /*shouldBeReference*/
            false);
        }
        function isInReferenceCommentWorker(sourceFile, position, shouldBeReference) {
            const range = isInComment(sourceFile, position, 
            /*tokenAtPosition*/
            void 0);
            return !!range && shouldBeReference === tripleSlashDirectivePrefixRegex.test(sourceFile.text.substring(range.pos, range.end));
        }
        function getReplacementSpanForContextToken(contextToken) {
            if (!contextToken)
                return void 0;
            switch (contextToken.kind) {
                case 10 /* StringLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                    return createTextSpanFromStringLiteralLikeContent(contextToken);
                default:
                    return createTextSpanFromNode(contextToken);
            }
        }
        function createTextSpanFromNode(node, sourceFile, endNode2) {
            return createTextSpanFromBounds(node.getStart(sourceFile), (endNode2 || node).getEnd());
        }
        function createTextSpanFromStringLiteralLikeContent(node) {
            if (node.isUnterminated)
                return void 0;
            return createTextSpanFromBounds(node.getStart() + 1, node.getEnd() - 1);
        }
        function createTextRangeFromNode(node, sourceFile) {
            return createRange(node.getStart(sourceFile), node.end);
        }
        function createTextSpanFromRange(range) {
            return createTextSpanFromBounds(range.pos, range.end);
        }
        function createTextRangeFromSpan(span) {
            return createRange(span.start, span.start + span.length);
        }
        function createTextChangeFromStartLength(start, length2, newText) {
            return createTextChange(createTextSpan(start, length2), newText);
        }
        function createTextChange(span, newText) {
            return { span, newText };
        }
        function isTypeKeyword(kind) {
            return contains(typeKeywords, kind);
        }
        function isTypeKeywordToken(node) {
            return node.kind === 154 /* TypeKeyword */;
        }
        function isTypeKeywordTokenOrIdentifier(node) {
            return isTypeKeywordToken(node) || isIdentifier(node) && node.text === "type";
        }
        function isExternalModuleSymbol(moduleSymbol) {
            return !!(moduleSymbol.flags & 1536 /* Module */) && moduleSymbol.name.charCodeAt(0) === 34 /* doubleQuote */;
        }
        function nodeSeenTracker() {
            const seen = [];
            return (node) => {
                const id = getNodeId(node);
                return !seen[id] && (seen[id] = true);
            };
        }
        function getSnapshotText(snap) {
            return snap.getText(0, snap.getLength());
        }
        function repeatString(str, count) {
            let result = "";
            for (let i = 0; i < count; i++) {
                result += str;
            }
            return result;
        }
        function skipConstraint(type) {
            return type.isTypeParameter() ? type.getConstraint() || type : type;
        }
        function getNameFromPropertyName(name) {
            return name.kind === 164 /* ComputedPropertyName */ ? isStringOrNumericLiteralLike(name.expression) ? name.expression.text : void 0 : isPrivateIdentifier(name) ? idText(name) : getTextOfIdentifierOrLiteral(name);
        }
        function programContainsModules(program) {
            return program.getSourceFiles().some((s) => !s.isDeclarationFile && !program.isSourceFileFromExternalLibrary(s) && !!(s.externalModuleIndicator || s.commonJsModuleIndicator));
        }
        function programContainsEsModules(program) {
            return program.getSourceFiles().some((s) => !s.isDeclarationFile && !program.isSourceFileFromExternalLibrary(s) && !!s.externalModuleIndicator);
        }
        function compilerOptionsIndicateEsModules(compilerOptions) {
            return !!compilerOptions.module || getEmitScriptTarget(compilerOptions) >= 2 /* ES2015 */ || !!compilerOptions.noEmit;
        }
        function createModuleSpecifierResolutionHost(program, host) {
            return {
                fileExists: (fileName) => program.fileExists(fileName),
                getCurrentDirectory: () => host.getCurrentDirectory(),
                readFile: maybeBind(host, host.readFile),
                useCaseSensitiveFileNames: maybeBind(host, host.useCaseSensitiveFileNames),
                getSymlinkCache: maybeBind(host, host.getSymlinkCache) || program.getSymlinkCache,
                getModuleSpecifierCache: maybeBind(host, host.getModuleSpecifierCache),
                getPackageJsonInfoCache: () => {
                    var _a2;
                    return (_a2 = program.getModuleResolutionCache()) == null ? void 0 : _a2.getPackageJsonInfoCache();
                },
                getGlobalTypingsCacheLocation: maybeBind(host, host.getGlobalTypingsCacheLocation),
                redirectTargetsMap: program.redirectTargetsMap,
                getProjectReferenceRedirect: (fileName) => program.getProjectReferenceRedirect(fileName),
                isSourceOfProjectReferenceRedirect: (fileName) => program.isSourceOfProjectReferenceRedirect(fileName),
                getNearestAncestorDirectoryWithPackageJson: maybeBind(host, host.getNearestAncestorDirectoryWithPackageJson),
                getFileIncludeReasons: () => program.getFileIncludeReasons()
            };
        }
        function getModuleSpecifierResolverHost(program, host) {
            return {
                ...createModuleSpecifierResolutionHost(program, host),
                getCommonSourceDirectory: () => program.getCommonSourceDirectory()
            };
        }
        function moduleResolutionUsesNodeModules(moduleResolution) {
            return moduleResolution === 2 /* Node10 */ || moduleResolution >= 3 /* Node16 */ && moduleResolution <= 99 /* NodeNext */ || moduleResolution === 100 /* Bundler */;
        }
        function makeImportIfNecessary(defaultImport, namedImports, moduleSpecifier, quotePreference) {
            return defaultImport || namedImports && namedImports.length ? makeImport(defaultImport, namedImports, moduleSpecifier, quotePreference) : void 0;
        }
        function makeImport(defaultImport, namedImports, moduleSpecifier, quotePreference, isTypeOnly) {
            return factory.createImportDeclaration(
            /*modifiers*/
            void 0, defaultImport || namedImports ? factory.createImportClause(!!isTypeOnly, defaultImport, namedImports && namedImports.length ? factory.createNamedImports(namedImports) : void 0) : void 0, typeof moduleSpecifier === "string" ? makeStringLiteral(moduleSpecifier, quotePreference) : moduleSpecifier, 
            /*assertClause*/
            void 0);
        }
        function makeStringLiteral(text, quotePreference) {
            return factory.createStringLiteral(text, quotePreference === 0 /* Single */);
        }
        function quotePreferenceFromString(str, sourceFile) {
            return isStringDoubleQuoted(str, sourceFile) ? 1 /* Double */ : 0 /* Single */;
        }
        function getQuotePreference(sourceFile, preferences) {
            if (preferences.quotePreference && preferences.quotePreference !== "auto") {
                return preferences.quotePreference === "single" ? 0 /* Single */ : 1 /* Double */;
            }
            else {
                const firstModuleSpecifier = sourceFile.imports && find(sourceFile.imports, (n) => isStringLiteral(n) && !nodeIsSynthesized(n.parent));
                return firstModuleSpecifier ? quotePreferenceFromString(firstModuleSpecifier, sourceFile) : 1 /* Double */;
            }
        }
        function getQuoteFromPreference(qp) {
            switch (qp) {
                case 0 /* Single */:
                    return "'";
                case 1 /* Double */:
                    return '"';
                default:
                    return Debug.assertNever(qp);
            }
        }
        function symbolNameNoDefault(symbol) {
            const escaped = symbolEscapedNameNoDefault(symbol);
            return escaped === void 0 ? void 0 : unescapeLeadingUnderscores(escaped);
        }
        function symbolEscapedNameNoDefault(symbol) {
            if (symbol.escapedName !== "default" /* Default */) {
                return symbol.escapedName;
            }
            return firstDefined(symbol.declarations, (decl) => {
                const name = getNameOfDeclaration(decl);
                return name && name.kind === 79 /* Identifier */ ? name.escapedText : void 0;
            });
        }
        function isModuleSpecifierLike(node) {
            return isStringLiteralLike(node) && (isExternalModuleReference(node.parent) || isImportDeclaration(node.parent) || isRequireCall(node.parent, 
            /*requireStringLiteralLikeArgument*/
            false) && node.parent.arguments[0] === node || isImportCall(node.parent) && node.parent.arguments[0] === node);
        }
        function isObjectBindingElementWithoutPropertyName(bindingElement) {
            return isBindingElement(bindingElement) && isObjectBindingPattern(bindingElement.parent) && isIdentifier(bindingElement.name) && !bindingElement.propertyName;
        }
        function getPropertySymbolFromBindingElement(checker, bindingElement) {
            const typeOfPattern = checker.getTypeAtLocation(bindingElement.parent);
            return typeOfPattern && checker.getPropertyOfType(typeOfPattern, bindingElement.name.text);
        }
        function getParentNodeInSpan(node, file, span) {
            if (!node)
                return void 0;
            while (node.parent) {
                if (isSourceFile(node.parent) || !spanContainsNode(span, node.parent, file)) {
                    return node;
                }
                node = node.parent;
            }
        }
        function spanContainsNode(span, node, file) {
            return textSpanContainsPosition(span, node.getStart(file)) && node.getEnd() <= textSpanEnd(span);
        }
        function findModifier(node, kind) {
            return canHaveModifiers(node) ? find(node.modifiers, (m) => m.kind === kind) : void 0;
        }
        function insertImports(changes, sourceFile, imports, blankLineBetween, preferences) {
            const decl = isArray(imports) ? imports[0] : imports;
            const importKindPredicate = decl.kind === 240 /* VariableStatement */ ? isRequireVariableStatement : isAnyImportSyntax;
            const existingImportStatements = filter(sourceFile.statements, importKindPredicate);
            let sortKind = isArray(imports) ? ts_OrganizeImports_exports.detectImportDeclarationSorting(imports, preferences) : 3 /* Both */;
            const comparer = ts_OrganizeImports_exports.getOrganizeImportsComparer(preferences, sortKind === 2 /* CaseInsensitive */);
            const sortedNewImports = isArray(imports) ? stableSort(imports, (a, b) => ts_OrganizeImports_exports.compareImportsOrRequireStatements(a, b, comparer)) : [imports];
            if (!existingImportStatements.length) {
                changes.insertNodesAtTopOfFile(sourceFile, sortedNewImports, blankLineBetween);
            }
            else if (existingImportStatements && (sortKind = ts_OrganizeImports_exports.detectImportDeclarationSorting(existingImportStatements, preferences))) {
                const comparer2 = ts_OrganizeImports_exports.getOrganizeImportsComparer(preferences, sortKind === 2 /* CaseInsensitive */);
                for (const newImport of sortedNewImports) {
                    const insertionIndex = ts_OrganizeImports_exports.getImportDeclarationInsertionIndex(existingImportStatements, newImport, comparer2);
                    if (insertionIndex === 0) {
                        const options = existingImportStatements[0] === sourceFile.statements[0] ? { leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude } : {};
                        changes.insertNodeBefore(sourceFile, existingImportStatements[0], newImport, 
                        /*blankLineBetween*/
                        false, options);
                    }
                    else {
                        const prevImport = existingImportStatements[insertionIndex - 1];
                        changes.insertNodeAfter(sourceFile, prevImport, newImport);
                    }
                }
            }
            else {
                const lastExistingImport = lastOrUndefined(existingImportStatements);
                if (lastExistingImport) {
                    changes.insertNodesAfter(sourceFile, lastExistingImport, sortedNewImports);
                }
                else {
                    changes.insertNodesAtTopOfFile(sourceFile, sortedNewImports, blankLineBetween);
                }
            }
        }
        function getTypeKeywordOfTypeOnlyImport(importClause, sourceFile) {
            Debug.assert(importClause.isTypeOnly);
            return cast(importClause.getChildAt(0, sourceFile), isTypeKeywordToken);
        }
        function textSpansEqual(a, b) {
            return !!a && !!b && a.start === b.start && a.length === b.length;
        }
        function documentSpansEqual(a, b) {
            return a.fileName === b.fileName && textSpansEqual(a.textSpan, b.textSpan);
        }
        function forEachUnique(array, callback) {
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    if (array.indexOf(array[i]) === i) {
                        const result = callback(array[i], i);
                        if (result) {
                            return result;
                        }
                    }
                }
            }
            return void 0;
        }
        function isTextWhiteSpaceLike(text, startPos, endPos) {
            for (let i = startPos; i < endPos; i++) {
                if (!isWhiteSpaceLike(text.charCodeAt(i))) {
                    return false;
                }
            }
            return true;
        }
        function getMappedLocation(location, sourceMapper, fileExists) {
            const mapsTo = sourceMapper.tryGetSourcePosition(location);
            return mapsTo && (!fileExists || fileExists(normalizePath(mapsTo.fileName)) ? mapsTo : void 0);
        }
        function getMappedDocumentSpan(documentSpan, sourceMapper, fileExists) {
            const { fileName, textSpan } = documentSpan;
            const newPosition = getMappedLocation({ fileName, pos: textSpan.start }, sourceMapper, fileExists);
            if (!newPosition)
                return void 0;
            const newEndPosition = getMappedLocation({ fileName, pos: textSpan.start + textSpan.length }, sourceMapper, fileExists);
            const newLength = newEndPosition ? newEndPosition.pos - newPosition.pos : textSpan.length;
            return {
                fileName: newPosition.fileName,
                textSpan: {
                    start: newPosition.pos,
                    length: newLength
                },
                originalFileName: documentSpan.fileName,
                originalTextSpan: documentSpan.textSpan,
                contextSpan: getMappedContextSpan(documentSpan, sourceMapper, fileExists),
                originalContextSpan: documentSpan.contextSpan
            };
        }
        function getMappedContextSpan(documentSpan, sourceMapper, fileExists) {
            const contextSpanStart = documentSpan.contextSpan && getMappedLocation({ fileName: documentSpan.fileName, pos: documentSpan.contextSpan.start }, sourceMapper, fileExists);
            const contextSpanEnd = documentSpan.contextSpan && getMappedLocation({ fileName: documentSpan.fileName, pos: documentSpan.contextSpan.start + documentSpan.contextSpan.length }, sourceMapper, fileExists);
            return contextSpanStart && contextSpanEnd ? { start: contextSpanStart.pos, length: contextSpanEnd.pos - contextSpanStart.pos } : void 0;
        }
        function isFirstDeclarationOfSymbolParameter(symbol) {
            const declaration = symbol.declarations ? firstOrUndefined(symbol.declarations) : void 0;
            return !!findAncestor(declaration, (n) => isParameter(n) ? true : isBindingElement(n) || isObjectBindingPattern(n) || isArrayBindingPattern(n) ? false : "quit");
        }
        function getDisplayPartWriter() {
            const absoluteMaximumLength = defaultMaximumTruncationLength * 10;
            let displayParts;
            let lineStart;
            let indent2;
            let length2;
            resetWriter();
            const unknownWrite = (text) => writeKind(text, 17 /* text */);
            return {
                displayParts: () => {
                    const finalText = displayParts.length && displayParts[displayParts.length - 1].text;
                    if (length2 > absoluteMaximumLength && finalText && finalText !== "...") {
                        if (!isWhiteSpaceLike(finalText.charCodeAt(finalText.length - 1))) {
                            displayParts.push(displayPart(" ", 16 /* space */));
                        }
                        displayParts.push(displayPart("...", 15 /* punctuation */));
                    }
                    return displayParts;
                },
                writeKeyword: (text) => writeKind(text, 5 /* keyword */),
                writeOperator: (text) => writeKind(text, 12 /* operator */),
                writePunctuation: (text) => writeKind(text, 15 /* punctuation */),
                writeTrailingSemicolon: (text) => writeKind(text, 15 /* punctuation */),
                writeSpace: (text) => writeKind(text, 16 /* space */),
                writeStringLiteral: (text) => writeKind(text, 8 /* stringLiteral */),
                writeParameter: (text) => writeKind(text, 13 /* parameterName */),
                writeProperty: (text) => writeKind(text, 14 /* propertyName */),
                writeLiteral: (text) => writeKind(text, 8 /* stringLiteral */),
                writeSymbol,
                writeLine,
                write: unknownWrite,
                writeComment: unknownWrite,
                getText: () => "",
                getTextPos: () => 0,
                getColumn: () => 0,
                getLine: () => 0,
                isAtStartOfLine: () => false,
                hasTrailingWhitespace: () => false,
                hasTrailingComment: () => false,
                rawWrite: notImplemented,
                getIndent: () => indent2,
                increaseIndent: () => {
                    indent2++;
                },
                decreaseIndent: () => {
                    indent2--;
                },
                clear: resetWriter
            };
            function writeIndent() {
                if (length2 > absoluteMaximumLength)
                    return;
                if (lineStart) {
                    const indentString = getIndentString(indent2);
                    if (indentString) {
                        length2 += indentString.length;
                        displayParts.push(displayPart(indentString, 16 /* space */));
                    }
                    lineStart = false;
                }
            }
            function writeKind(text, kind) {
                if (length2 > absoluteMaximumLength)
                    return;
                writeIndent();
                length2 += text.length;
                displayParts.push(displayPart(text, kind));
            }
            function writeSymbol(text, symbol) {
                if (length2 > absoluteMaximumLength)
                    return;
                writeIndent();
                length2 += text.length;
                displayParts.push(symbolPart(text, symbol));
            }
            function writeLine() {
                if (length2 > absoluteMaximumLength)
                    return;
                length2 += 1;
                displayParts.push(lineBreakPart());
                lineStart = true;
            }
            function resetWriter() {
                displayParts = [];
                lineStart = true;
                indent2 = 0;
                length2 = 0;
            }
        }
        function symbolPart(text, symbol) {
            return displayPart(text, displayPartKind(symbol));
            function displayPartKind(symbol2) {
                const flags = symbol2.flags;
                if (flags & 3 /* Variable */) {
                    return isFirstDeclarationOfSymbolParameter(symbol2) ? 13 /* parameterName */ : 9 /* localName */;
                }
                if (flags & 4 /* Property */)
                    return 14 /* propertyName */;
                if (flags & 32768 /* GetAccessor */)
                    return 14 /* propertyName */;
                if (flags & 65536 /* SetAccessor */)
                    return 14 /* propertyName */;
                if (flags & 8 /* EnumMember */)
                    return 19 /* enumMemberName */;
                if (flags & 16 /* Function */)
                    return 20 /* functionName */;
                if (flags & 32 /* Class */)
                    return 1 /* className */;
                if (flags & 64 /* Interface */)
                    return 4 /* interfaceName */;
                if (flags & 384 /* Enum */)
                    return 2 /* enumName */;
                if (flags & 1536 /* Module */)
                    return 11 /* moduleName */;
                if (flags & 8192 /* Method */)
                    return 10 /* methodName */;
                if (flags & 262144 /* TypeParameter */)
                    return 18 /* typeParameterName */;
                if (flags & 524288 /* TypeAlias */)
                    return 0 /* aliasName */;
                if (flags & 2097152 /* Alias */)
                    return 0 /* aliasName */;
                return 17 /* text */;
            }
        }
        function displayPart(text, kind) {
            return { text, kind: SymbolDisplayPartKind[kind] };
        }
        function spacePart() {
            return displayPart(" ", 16 /* space */);
        }
        function keywordPart(kind) {
            return displayPart(tokenToString(kind), 5 /* keyword */);
        }
        function punctuationPart(kind) {
            return displayPart(tokenToString(kind), 15 /* punctuation */);
        }
        function operatorPart(kind) {
            return displayPart(tokenToString(kind), 12 /* operator */);
        }
        function parameterNamePart(text) {
            return displayPart(text, 13 /* parameterName */);
        }
        function propertyNamePart(text) {
            return displayPart(text, 14 /* propertyName */);
        }
        function textOrKeywordPart(text) {
            const kind = stringToToken(text);
            return kind === void 0 ? textPart(text) : keywordPart(kind);
        }
        function textPart(text) {
            return displayPart(text, 17 /* text */);
        }
        function typeAliasNamePart(text) {
            return displayPart(text, 0 /* aliasName */);
        }
        function typeParameterNamePart(text) {
            return displayPart(text, 18 /* typeParameterName */);
        }
        function linkTextPart(text) {
            return displayPart(text, 24 /* linkText */);
        }
        function linkNamePart(text, target) {
            return {
                text,
                kind: SymbolDisplayPartKind[23 /* linkName */],
                target: {
                    fileName: getSourceFileOfNode(target).fileName,
                    textSpan: createTextSpanFromNode(target)
                }
            };
        }
        function linkPart(text) {
            return displayPart(text, 22 /* link */);
        }
        function buildLinkParts(link, checker) {
            var _a2;
            const prefix = isJSDocLink(link) ? "link" : isJSDocLinkCode(link) ? "linkcode" : "linkplain";
            const parts = [linkPart(`{@${prefix} `)];
            if (!link.name) {
                if (link.text) {
                    parts.push(linkTextPart(link.text));
                }
            }
            else {
                const symbol = checker == null ? void 0 : checker.getSymbolAtLocation(link.name);
                const suffix = findLinkNameEnd(link.text);
                const name = getTextOfNode(link.name) + link.text.slice(0, suffix);
                const text = skipSeparatorFromLinkText(link.text.slice(suffix));
                const decl = (symbol == null ? void 0 : symbol.valueDeclaration) || ((_a2 = symbol == null ? void 0 : symbol.declarations) == null ? void 0 : _a2[0]);
                if (decl) {
                    parts.push(linkNamePart(name, decl));
                    if (text)
                        parts.push(linkTextPart(text));
                }
                else {
                    parts.push(linkTextPart(name + (suffix ? "" : " ") + text));
                }
            }
            parts.push(linkPart("}"));
            return parts;
        }
        function skipSeparatorFromLinkText(text) {
            let pos = 0;
            if (text.charCodeAt(pos++) === 124 /* bar */) {
                while (pos < text.length && text.charCodeAt(pos) === 32 /* space */)
                    pos++;
                return text.slice(pos);
            }
            return text;
        }
        function findLinkNameEnd(text) {
            let pos = text.indexOf("://");
            if (pos === 0) {
                while (pos < text.length && text.charCodeAt(pos) !== 124 /* bar */)
                    pos++;
                return pos;
            }
            if (text.indexOf("()") === 0)
                return 2;
            if (text.charAt(0) === "<") {
                let brackets2 = 0;
                let i = 0;
                while (i < text.length) {
                    if (text[i] === "<")
                        brackets2++;
                    if (text[i] === ">")
                        brackets2--;
                    i++;
                    if (!brackets2)
                        return i;
                }
            }
            return 0;
        }
        function getNewLineOrDefaultFromHost(host, formatSettings) {
            var _a2;
            return (formatSettings == null ? void 0 : formatSettings.newLineCharacter) || ((_a2 = host.getNewLine) == null ? void 0 : _a2.call(host)) || lineFeed2;
        }
        function lineBreakPart() {
            return displayPart("\n", 6 /* lineBreak */);
        }
        function mapToDisplayParts(writeDisplayParts) {
            try {
                writeDisplayParts(displayPartWriter);
                return displayPartWriter.displayParts();
            }
            finally {
                displayPartWriter.clear();
            }
        }
        function typeToDisplayParts(typechecker, type, enclosingDeclaration, flags = 0 /* None */) {
            return mapToDisplayParts((writer) => {
                typechecker.writeType(type, enclosingDeclaration, flags | 1024 /* MultilineObjectLiterals */ | 16384 /* UseAliasDefinedOutsideCurrentScope */, writer);
            });
        }
        function symbolToDisplayParts(typeChecker, symbol, enclosingDeclaration, meaning, flags = 0 /* None */) {
            return mapToDisplayParts((writer) => {
                typeChecker.writeSymbol(symbol, enclosingDeclaration, meaning, flags | 8 /* UseAliasDefinedOutsideCurrentScope */, writer);
            });
        }
        function signatureToDisplayParts(typechecker, signature, enclosingDeclaration, flags = 0 /* None */) {
            flags |= 16384 /* UseAliasDefinedOutsideCurrentScope */ | 1024 /* MultilineObjectLiterals */ | 32 /* WriteTypeArgumentsOfSignature */ | 8192 /* OmitParameterModifiers */;
            return mapToDisplayParts((writer) => {
                typechecker.writeSignature(signature, enclosingDeclaration, flags, 
                /*signatureKind*/
                void 0, writer);
            });
        }
        function nodeToDisplayParts(node, enclosingDeclaration) {
            const file = enclosingDeclaration.getSourceFile();
            return mapToDisplayParts((writer) => {
                const printer = createPrinterWithRemoveCommentsOmitTrailingSemicolon();
                printer.writeNode(4 /* Unspecified */, node, file, writer);
            });
        }
        function isImportOrExportSpecifierName(location) {
            return !!location.parent && isImportOrExportSpecifier(location.parent) && location.parent.propertyName === location;
        }
        function getScriptKind(fileName, host) {
            return ensureScriptKind(fileName, host.getScriptKind && host.getScriptKind(fileName));
        }
        function getSymbolTarget(symbol, checker) {
            let next = symbol;
            while (isAliasSymbol(next) || isTransientSymbol(next) && next.links.target) {
                if (isTransientSymbol(next) && next.links.target) {
                    next = next.links.target;
                }
                else {
                    next = skipAlias(next, checker);
                }
            }
            return next;
        }
        function isAliasSymbol(symbol) {
            return (symbol.flags & 2097152 /* Alias */) !== 0;
        }
        function getUniqueSymbolId(symbol, checker) {
            return getSymbolId(skipAlias(symbol, checker));
        }
        function getFirstNonSpaceCharacterPosition(text, position) {
            while (isWhiteSpaceLike(text.charCodeAt(position))) {
                position += 1;
            }
            return position;
        }
        function getPrecedingNonSpaceCharacterPosition(text, position) {
            while (position > -1 && isWhiteSpaceSingleLine(text.charCodeAt(position))) {
                position -= 1;
            }
            return position + 1;
        }
        function getSynthesizedDeepClone(node, includeTrivia = true) {
            const clone2 = node && getSynthesizedDeepCloneWorker(node);
            if (clone2 && !includeTrivia)
                suppressLeadingAndTrailingTrivia(clone2);
            return clone2;
        }
        function getSynthesizedDeepCloneWithReplacements(node, includeTrivia, replaceNode) {
            let clone2 = replaceNode(node);
            if (clone2) {
                setOriginalNode(clone2, node);
            }
            else {
                clone2 = getSynthesizedDeepCloneWorker(node, replaceNode);
            }
            if (clone2 && !includeTrivia)
                suppressLeadingAndTrailingTrivia(clone2);
            return clone2;
        }
        function getSynthesizedDeepCloneWorker(node, replaceNode) {
            const nodeClone = replaceNode ? (n) => getSynthesizedDeepCloneWithReplacements(n, 
            /*includeTrivia*/
            true, replaceNode) : getSynthesizedDeepClone;
            const nodesClone = replaceNode ? (ns) => ns && getSynthesizedDeepClonesWithReplacements(ns, 
            /*includeTrivia*/
            true, replaceNode) : (ns) => ns && getSynthesizedDeepClones(ns);
            const visited = visitEachChild(node, nodeClone, nullTransformationContext, nodesClone, nodeClone);
            if (visited === node) {
                const clone2 = isStringLiteral(node) ? setOriginalNode(factory.createStringLiteralFromNode(node), node) : isNumericLiteral(node) ? setOriginalNode(factory.createNumericLiteral(node.text, node.numericLiteralFlags), node) : factory.cloneNode(node);
                return setTextRange(clone2, node);
            }
            visited.parent = void 0;
            return visited;
        }
        function getSynthesizedDeepClones(nodes, includeTrivia = true) {
            return nodes && factory.createNodeArray(nodes.map((n) => getSynthesizedDeepClone(n, includeTrivia)), nodes.hasTrailingComma);
        }
        function getSynthesizedDeepClonesWithReplacements(nodes, includeTrivia, replaceNode) {
            return factory.createNodeArray(nodes.map((n) => getSynthesizedDeepCloneWithReplacements(n, includeTrivia, replaceNode)), nodes.hasTrailingComma);
        }
        function suppressLeadingAndTrailingTrivia(node) {
            suppressLeadingTrivia(node);
            suppressTrailingTrivia(node);
        }
        function suppressLeadingTrivia(node) {
            addEmitFlagsRecursively(node, 1024 /* NoLeadingComments */, getFirstChild);
        }
        function suppressTrailingTrivia(node) {
            addEmitFlagsRecursively(node, 2048 /* NoTrailingComments */, getLastChild);
        }
        function copyComments(sourceNode, targetNode) {
            const sourceFile = sourceNode.getSourceFile();
            const text = sourceFile.text;
            if (hasLeadingLineBreak(sourceNode, text)) {
                copyLeadingComments(sourceNode, targetNode, sourceFile);
            }
            else {
                copyTrailingAsLeadingComments(sourceNode, targetNode, sourceFile);
            }
            copyTrailingComments(sourceNode, targetNode, sourceFile);
        }
        function hasLeadingLineBreak(node, text) {
            const start = node.getFullStart();
            const end = node.getStart();
            for (let i = start; i < end; i++) {
                if (text.charCodeAt(i) === 10 /* lineFeed */)
                    return true;
            }
            return false;
        }
        function addEmitFlagsRecursively(node, flag, getChild) {
            addEmitFlags(node, flag);
            const child = getChild(node);
            if (child)
                addEmitFlagsRecursively(child, flag, getChild);
        }
        function getFirstChild(node) {
            return node.forEachChild((child) => child);
        }
        function getUniqueName(baseName, sourceFile) {
            let nameText = baseName;
            for (let i = 1; !isFileLevelUniqueName(sourceFile, nameText); i++) {
                nameText = `${baseName}_${i}`;
            }
            return nameText;
        }
        function getRenameLocation(edits, renameFilename, name, preferLastLocation) {
            let delta = 0;
            let lastPos = -1;
            for (const { fileName, textChanges: textChanges2 } of edits) {
                Debug.assert(fileName === renameFilename);
                for (const change of textChanges2) {
                    const { span, newText } = change;
                    const index = indexInTextChange(newText, escapeString(name));
                    if (index !== -1) {
                        lastPos = span.start + delta + index;
                        if (!preferLastLocation) {
                            return lastPos;
                        }
                    }
                    delta += newText.length - span.length;
                }
            }
            Debug.assert(preferLastLocation);
            Debug.assert(lastPos >= 0);
            return lastPos;
        }
        function copyLeadingComments(sourceNode, targetNode, sourceFile, commentKind, hasTrailingNewLine) {
            forEachLeadingCommentRange(sourceFile.text, sourceNode.pos, getAddCommentsFunction(targetNode, sourceFile, commentKind, hasTrailingNewLine, addSyntheticLeadingComment));
        }
        function copyTrailingComments(sourceNode, targetNode, sourceFile, commentKind, hasTrailingNewLine) {
            forEachTrailingCommentRange(sourceFile.text, sourceNode.end, getAddCommentsFunction(targetNode, sourceFile, commentKind, hasTrailingNewLine, addSyntheticTrailingComment));
        }
        function copyTrailingAsLeadingComments(sourceNode, targetNode, sourceFile, commentKind, hasTrailingNewLine) {
            forEachTrailingCommentRange(sourceFile.text, sourceNode.pos, getAddCommentsFunction(targetNode, sourceFile, commentKind, hasTrailingNewLine, addSyntheticLeadingComment));
        }
        function getAddCommentsFunction(targetNode, sourceFile, commentKind, hasTrailingNewLine, cb) {
            return (pos, end, kind, htnl) => {
                if (kind === 3 /* MultiLineCommentTrivia */) {
                    pos += 2;
                    end -= 2;
                }
                else {
                    pos += 2;
                }
                cb(targetNode, commentKind || kind, sourceFile.text.slice(pos, end), hasTrailingNewLine !== void 0 ? hasTrailingNewLine : htnl);
            };
        }
        function indexInTextChange(change, name) {
            if (startsWith(change, name))
                return 0;
            let idx = change.indexOf(" " + name);
            if (idx === -1)
                idx = change.indexOf("." + name);
            if (idx === -1)
                idx = change.indexOf('"' + name);
            return idx === -1 ? -1 : idx + 1;
        }
        function needsParentheses(expression) {
            return isBinaryExpression(expression) && expression.operatorToken.kind === 27 /* CommaToken */ || isObjectLiteralExpression(expression) || isAsExpression(expression) && isObjectLiteralExpression(expression.expression);
        }
        function getContextualTypeFromParent(node, checker, contextFlags) {
            const parent2 = walkUpParenthesizedExpressions(node.parent);
            switch (parent2.kind) {
                case 211 /* NewExpression */:
                    return checker.getContextualType(parent2, contextFlags);
                case 223 /* BinaryExpression */: {
                    const { left, operatorToken, right } = parent2;
                    return isEqualityOperatorKind(operatorToken.kind) ? checker.getTypeAtLocation(node === right ? left : right) : checker.getContextualType(node, contextFlags);
                }
                case 292 /* CaseClause */:
                    return getSwitchedType(parent2, checker);
                default:
                    return checker.getContextualType(node, contextFlags);
            }
        }
        function quote(sourceFile, preferences, text) {
            const quotePreference = getQuotePreference(sourceFile, preferences);
            const quoted = JSON.stringify(text);
            return quotePreference === 0 /* Single */ ? `'${stripQuotes(quoted).replace(/'/g, "\\'").replace(/\\"/g, '"')}'` : quoted;
        }
        function isEqualityOperatorKind(kind) {
            switch (kind) {
                case 36 /* EqualsEqualsEqualsToken */:
                case 34 /* EqualsEqualsToken */:
                case 37 /* ExclamationEqualsEqualsToken */:
                case 35 /* ExclamationEqualsToken */:
                    return true;
                default:
                    return false;
            }
        }
        function isStringLiteralOrTemplate(node) {
            switch (node.kind) {
                case 10 /* StringLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 225 /* TemplateExpression */:
                case 212 /* TaggedTemplateExpression */:
                    return true;
                default:
                    return false;
            }
        }
        function hasIndexSignature(type) {
            return !!type.getStringIndexType() || !!type.getNumberIndexType();
        }
        function getSwitchedType(caseClause, checker) {
            return checker.getTypeAtLocation(caseClause.parent.parent.expression);
        }
        function getTypeNodeIfAccessible(type, enclosingScope, program, host) {
            const checker = program.getTypeChecker();
            let typeIsAccessible = true;
            const notAccessible = () => typeIsAccessible = false;
            const res = checker.typeToTypeNode(type, enclosingScope, 1 /* NoTruncation */, {
                trackSymbol: (symbol, declaration, meaning) => {
                    typeIsAccessible = typeIsAccessible && checker.isSymbolAccessible(symbol, declaration, meaning, 
                    /*shouldComputeAliasToMarkVisible*/
                    false).accessibility === 0 /* Accessible */;
                    return !typeIsAccessible;
                },
                reportInaccessibleThisError: notAccessible,
                reportPrivateInBaseOfClassExpression: notAccessible,
                reportInaccessibleUniqueSymbolError: notAccessible,
                moduleResolverHost: getModuleSpecifierResolverHost(program, host)
            });
            return typeIsAccessible ? res : void 0;
        }
        function syntaxRequiresTrailingCommaOrSemicolonOrASI(kind) {
            return kind === 176 /* CallSignature */ || kind === 177 /* ConstructSignature */ || kind === 178 /* IndexSignature */ || kind === 168 /* PropertySignature */ || kind === 170 /* MethodSignature */;
        }
        function syntaxRequiresTrailingFunctionBlockOrSemicolonOrASI(kind) {
            return kind === 259 /* FunctionDeclaration */ || kind === 173 /* Constructor */ || kind === 171 /* MethodDeclaration */ || kind === 174 /* GetAccessor */ || kind === 175 /* SetAccessor */;
        }
        function syntaxRequiresTrailingModuleBlockOrSemicolonOrASI(kind) {
            return kind === 264 /* ModuleDeclaration */;
        }
        function syntaxRequiresTrailingSemicolonOrASI(kind) {
            return kind === 240 /* VariableStatement */ || kind === 241 /* ExpressionStatement */ || kind === 243 /* DoStatement */ || kind === 248 /* ContinueStatement */ || kind === 249 /* BreakStatement */ || kind === 250 /* ReturnStatement */ || kind === 254 /* ThrowStatement */ || kind === 256 /* DebuggerStatement */ || kind === 169 /* PropertyDeclaration */ || kind === 262 /* TypeAliasDeclaration */ || kind === 269 /* ImportDeclaration */ || kind === 268 /* ImportEqualsDeclaration */ || kind === 275 /* ExportDeclaration */ || kind === 267 /* NamespaceExportDeclaration */ || kind === 274 /* ExportAssignment */;
        }
        function nodeIsASICandidate(node, sourceFile) {
            const lastToken = node.getLastToken(sourceFile);
            if (lastToken && lastToken.kind === 26 /* SemicolonToken */) {
                return false;
            }
            if (syntaxRequiresTrailingCommaOrSemicolonOrASI(node.kind)) {
                if (lastToken && lastToken.kind === 27 /* CommaToken */) {
                    return false;
                }
            }
            else if (syntaxRequiresTrailingModuleBlockOrSemicolonOrASI(node.kind)) {
                const lastChild = last(node.getChildren(sourceFile));
                if (lastChild && isModuleBlock(lastChild)) {
                    return false;
                }
            }
            else if (syntaxRequiresTrailingFunctionBlockOrSemicolonOrASI(node.kind)) {
                const lastChild = last(node.getChildren(sourceFile));
                if (lastChild && isFunctionBlock(lastChild)) {
                    return false;
                }
            }
            else if (!syntaxRequiresTrailingSemicolonOrASI(node.kind)) {
                return false;
            }
            if (node.kind === 243 /* DoStatement */) {
                return true;
            }
            const topNode = findAncestor(node, (ancestor) => !ancestor.parent);
            const nextToken = findNextToken(node, topNode, sourceFile);
            if (!nextToken || nextToken.kind === 19 /* CloseBraceToken */) {
                return true;
            }
            const startLine = sourceFile.getLineAndCharacterOfPosition(node.getEnd()).line;
            const endLine = sourceFile.getLineAndCharacterOfPosition(nextToken.getStart(sourceFile)).line;
            return startLine !== endLine;
        }
        function positionIsASICandidate(pos, context, sourceFile) {
            const contextAncestor = findAncestor(context, (ancestor) => {
                if (ancestor.end !== pos) {
                    return "quit";
                }
                return syntaxMayBeASICandidate(ancestor.kind);
            });
            return !!contextAncestor && nodeIsASICandidate(contextAncestor, sourceFile);
        }
        function probablyUsesSemicolons(sourceFile) {
            let withSemicolon = 0;
            let withoutSemicolon = 0;
            const nStatementsToObserve = 5;
            forEachChild(sourceFile, function visit(node) {
                if (syntaxRequiresTrailingSemicolonOrASI(node.kind)) {
                    const lastToken = node.getLastToken(sourceFile);
                    if ((lastToken == null ? void 0 : lastToken.kind) === 26 /* SemicolonToken */) {
                        withSemicolon++;
                    }
                    else {
                        withoutSemicolon++;
                    }
                }
                else if (syntaxRequiresTrailingCommaOrSemicolonOrASI(node.kind)) {
                    const lastToken = node.getLastToken(sourceFile);
                    if ((lastToken == null ? void 0 : lastToken.kind) === 26 /* SemicolonToken */) {
                        withSemicolon++;
                    }
                    else if (lastToken && lastToken.kind !== 27 /* CommaToken */) {
                        const lastTokenLine = getLineAndCharacterOfPosition(sourceFile, lastToken.getStart(sourceFile)).line;
                        const nextTokenLine = getLineAndCharacterOfPosition(sourceFile, getSpanOfTokenAtPosition(sourceFile, lastToken.end).start).line;
                        if (lastTokenLine !== nextTokenLine) {
                            withoutSemicolon++;
                        }
                    }
                }
                if (withSemicolon + withoutSemicolon >= nStatementsToObserve) {
                    return true;
                }
                return forEachChild(node, visit);
            });
            if (withSemicolon === 0 && withoutSemicolon <= 1) {
                return true;
            }
            return withSemicolon / withoutSemicolon > 1 / nStatementsToObserve;
        }
        function tryGetDirectories(host, directoryName) {
            return tryIOAndConsumeErrors(host, host.getDirectories, directoryName) || [];
        }
        function tryReadDirectory(host, path, extensions, exclude, include) {
            return tryIOAndConsumeErrors(host, host.readDirectory, path, extensions, exclude, include) || emptyArray;
        }
        function tryFileExists(host, path) {
            return tryIOAndConsumeErrors(host, host.fileExists, path);
        }
        function tryDirectoryExists(host, path) {
            return tryAndIgnoreErrors(() => directoryProbablyExists(path, host)) || false;
        }
        function tryAndIgnoreErrors(cb) {
            try {
                return cb();
            }
            catch (e) {
                return void 0;
            }
        }
        function tryIOAndConsumeErrors(host, toApply, ...args) {
            return tryAndIgnoreErrors(() => toApply && toApply.apply(host, args));
        }
        function findPackageJsons(startDirectory, host, stopDirectory) {
            const paths = [];
            forEachAncestorDirectory(startDirectory, (ancestor) => {
                if (ancestor === stopDirectory) {
                    return true;
                }
                const currentConfigPath = combinePaths(ancestor, "package.json");
                if (tryFileExists(host, currentConfigPath)) {
                    paths.push(currentConfigPath);
                }
            });
            return paths;
        }
        function findPackageJson(directory, host) {
            let packageJson;
            forEachAncestorDirectory(directory, (ancestor) => {
                if (ancestor === "node_modules")
                    return true;
                packageJson = findConfigFile(ancestor, (f) => tryFileExists(host, f), "package.json");
                if (packageJson) {
                    return true;
                }
            });
            return packageJson;
        }
        function getPackageJsonsVisibleToFile(fileName, host) {
            if (!host.fileExists) {
                return [];
            }
            const packageJsons = [];
            forEachAncestorDirectory(getDirectoryPath(fileName), (ancestor) => {
                const packageJsonFileName = combinePaths(ancestor, "package.json");
                if (host.fileExists(packageJsonFileName)) {
                    const info = createPackageJsonInfo(packageJsonFileName, host);
                    if (info) {
                        packageJsons.push(info);
                    }
                }
            });
            return packageJsons;
        }
        function createPackageJsonInfo(fileName, host) {
            if (!host.readFile) {
                return void 0;
            }
            const dependencyKeys = ["dependencies", "devDependencies", "optionalDependencies", "peerDependencies"];
            const stringContent = host.readFile(fileName) || "";
            const content = tryParseJson(stringContent);
            const info = {};
            if (content) {
                for (const key of dependencyKeys) {
                    const dependencies = content[key];
                    if (!dependencies) {
                        continue;
                    }
                    const dependencyMap = /* @__PURE__ */ new Map();
                    for (const packageName in dependencies) {
                        dependencyMap.set(packageName, dependencies[packageName]);
                    }
                    info[key] = dependencyMap;
                }
            }
            const dependencyGroups = [
                [1 /* Dependencies */, info.dependencies],
                [2 /* DevDependencies */, info.devDependencies],
                [8 /* OptionalDependencies */, info.optionalDependencies],
                [4 /* PeerDependencies */, info.peerDependencies]
            ];
            return {
                ...info,
                parseable: !!content,
                fileName,
                get,
                has(dependencyName, inGroups) {
                    return !!get(dependencyName, inGroups);
                }
            };
            function get(dependencyName, inGroups = 15 /* All */) {
                for (const [group2, deps] of dependencyGroups) {
                    if (deps && inGroups & group2) {
                        const dep = deps.get(dependencyName);
                        if (dep !== void 0) {
                            return dep;
                        }
                    }
                }
            }
        }
        function createPackageJsonImportFilter(fromFile, preferences, host) {
            const packageJsons = (host.getPackageJsonsVisibleToFile && host.getPackageJsonsVisibleToFile(fromFile.fileName) || getPackageJsonsVisibleToFile(fromFile.fileName, host)).filter((p) => p.parseable);
            let usesNodeCoreModules;
            let ambientModuleCache;
            let sourceFileCache;
            return {
                allowsImportingAmbientModule,
                allowsImportingSourceFile,
                allowsImportingSpecifier
            };
            function moduleSpecifierIsCoveredByPackageJson(specifier) {
                const packageName = getNodeModuleRootSpecifier(specifier);
                for (const packageJson of packageJsons) {
                    if (packageJson.has(packageName) || packageJson.has(getTypesPackageName(packageName))) {
                        return true;
                    }
                }
                return false;
            }
            function allowsImportingAmbientModule(moduleSymbol, moduleSpecifierResolutionHost) {
                if (!packageJsons.length || !moduleSymbol.valueDeclaration) {
                    return true;
                }
                if (!ambientModuleCache) {
                    ambientModuleCache = /* @__PURE__ */ new Map();
                }
                else {
                    const cached = ambientModuleCache.get(moduleSymbol);
                    if (cached !== void 0) {
                        return cached;
                    }
                }
                const declaredModuleSpecifier = stripQuotes(moduleSymbol.getName());
                if (isAllowedCoreNodeModulesImport(declaredModuleSpecifier)) {
                    ambientModuleCache.set(moduleSymbol, true);
                    return true;
                }
                const declaringSourceFile = moduleSymbol.valueDeclaration.getSourceFile();
                const declaringNodeModuleName = getNodeModulesPackageNameFromFileName(declaringSourceFile.fileName, moduleSpecifierResolutionHost);
                if (typeof declaringNodeModuleName === "undefined") {
                    ambientModuleCache.set(moduleSymbol, true);
                    return true;
                }
                const result = moduleSpecifierIsCoveredByPackageJson(declaringNodeModuleName) || moduleSpecifierIsCoveredByPackageJson(declaredModuleSpecifier);
                ambientModuleCache.set(moduleSymbol, result);
                return result;
            }
            function allowsImportingSourceFile(sourceFile, moduleSpecifierResolutionHost) {
                if (!packageJsons.length) {
                    return true;
                }
                if (!sourceFileCache) {
                    sourceFileCache = /* @__PURE__ */ new Map();
                }
                else {
                    const cached = sourceFileCache.get(sourceFile);
                    if (cached !== void 0) {
                        return cached;
                    }
                }
                const moduleSpecifier = getNodeModulesPackageNameFromFileName(sourceFile.fileName, moduleSpecifierResolutionHost);
                if (!moduleSpecifier) {
                    sourceFileCache.set(sourceFile, true);
                    return true;
                }
                const result = moduleSpecifierIsCoveredByPackageJson(moduleSpecifier);
                sourceFileCache.set(sourceFile, result);
                return result;
            }
            function allowsImportingSpecifier(moduleSpecifier) {
                if (!packageJsons.length || isAllowedCoreNodeModulesImport(moduleSpecifier)) {
                    return true;
                }
                if (pathIsRelative(moduleSpecifier) || isRootedDiskPath(moduleSpecifier)) {
                    return true;
                }
                return moduleSpecifierIsCoveredByPackageJson(moduleSpecifier);
            }
            function isAllowedCoreNodeModulesImport(moduleSpecifier) {
                if (isSourceFileJS(fromFile) && ts_JsTyping_exports.nodeCoreModules.has(moduleSpecifier)) {
                    if (usesNodeCoreModules === void 0) {
                        usesNodeCoreModules = consumesNodeCoreModules(fromFile);
                    }
                    if (usesNodeCoreModules) {
                        return true;
                    }
                }
                return false;
            }
            function getNodeModulesPackageNameFromFileName(importedFileName, moduleSpecifierResolutionHost) {
                if (!stringContains(importedFileName, "node_modules")) {
                    return void 0;
                }
                const specifier = ts_moduleSpecifiers_exports.getNodeModulesPackageName(host.getCompilationSettings(), fromFile, importedFileName, moduleSpecifierResolutionHost, preferences);
                if (!specifier) {
                    return void 0;
                }
                if (!pathIsRelative(specifier) && !isRootedDiskPath(specifier)) {
                    return getNodeModuleRootSpecifier(specifier);
                }
            }
            function getNodeModuleRootSpecifier(fullSpecifier) {
                const components = getPathComponents(getPackageNameFromTypesPackageName(fullSpecifier)).slice(1);
                if (startsWith(components[0], "@")) {
                    return `${components[0]}/${components[1]}`;
                }
                return components[0];
            }
        }
        function tryParseJson(text) {
            try {
                return JSON.parse(text);
            }
            catch (e) {
                return void 0;
            }
        }
        function consumesNodeCoreModules(sourceFile) {
            return some(sourceFile.imports, ({ text }) => ts_JsTyping_exports.nodeCoreModules.has(text));
        }
        function isInsideNodeModules(fileOrDirectory) {
            return contains(getPathComponents(fileOrDirectory), "node_modules");
        }
        function isDiagnosticWithLocation(diagnostic) {
            return diagnostic.file !== void 0 && diagnostic.start !== void 0 && diagnostic.length !== void 0;
        }
        function findDiagnosticForNode(node, sortedFileDiagnostics) {
            const span = createTextSpanFromNode(node);
            const index = binarySearchKey(sortedFileDiagnostics, span, identity, compareTextSpans);
            if (index >= 0) {
                const diagnostic = sortedFileDiagnostics[index];
                Debug.assertEqual(diagnostic.file, node.getSourceFile(), "Diagnostics proided to 'findDiagnosticForNode' must be from a single SourceFile");
                return cast(diagnostic, isDiagnosticWithLocation);
            }
        }
        function getDiagnosticsWithinSpan(span, sortedFileDiagnostics) {
            var _a2;
            let index = binarySearchKey(sortedFileDiagnostics, span.start, (diag2) => diag2.start, compareValues);
            if (index < 0) {
                index = ~index;
            }
            while (((_a2 = sortedFileDiagnostics[index - 1]) == null ? void 0 : _a2.start) === span.start) {
                index--;
            }
            const result = [];
            const end = textSpanEnd(span);
            while (true) {
                const diagnostic = tryCast(sortedFileDiagnostics[index], isDiagnosticWithLocation);
                if (!diagnostic || diagnostic.start > end) {
                    break;
                }
                if (textSpanContainsTextSpan(span, diagnostic)) {
                    result.push(diagnostic);
                }
                index++;
            }
            return result;
        }
        function getRefactorContextSpan({ startPosition, endPosition }) {
            return createTextSpanFromBounds(startPosition, endPosition === void 0 ? startPosition : endPosition);
        }
        function getFixableErrorSpanExpression(sourceFile, span) {
            const token = getTokenAtPosition(sourceFile, span.start);
            const expression = findAncestor(token, (node) => {
                if (node.getStart(sourceFile) < span.start || node.getEnd() > textSpanEnd(span)) {
                    return "quit";
                }
                return isExpression(node) && textSpansEqual(span, createTextSpanFromNode(node, sourceFile));
            });
            return expression;
        }
        function mapOneOrMany(valueOrArray, f, resultSelector = identity) {
            return valueOrArray ? isArray(valueOrArray) ? resultSelector(map(valueOrArray, f)) : f(valueOrArray, 0) : void 0;
        }
        function firstOrOnly(valueOrArray) {
            return isArray(valueOrArray) ? first(valueOrArray) : valueOrArray;
        }
        function getNamesForExportedSymbol(symbol, scriptTarget) {
            if (needsNameFromDeclaration(symbol)) {
                const fromDeclaration = getDefaultLikeExportNameFromDeclaration(symbol);
                if (fromDeclaration)
                    return fromDeclaration;
                const fileNameCase = ts_codefix_exports.moduleSymbolToValidIdentifier(getSymbolParentOrFail(symbol), scriptTarget, 
                /*preferCapitalized*/
                false);
                const capitalized = ts_codefix_exports.moduleSymbolToValidIdentifier(getSymbolParentOrFail(symbol), scriptTarget, 
                /*preferCapitalized*/
                true);
                if (fileNameCase === capitalized)
                    return fileNameCase;
                return [fileNameCase, capitalized];
            }
            return symbol.name;
        }
        function getNameForExportedSymbol(symbol, scriptTarget, preferCapitalized) {
            if (needsNameFromDeclaration(symbol)) {
                return getDefaultLikeExportNameFromDeclaration(symbol) || ts_codefix_exports.moduleSymbolToValidIdentifier(getSymbolParentOrFail(symbol), scriptTarget, !!preferCapitalized);
            }
            return symbol.name;
        }
        function needsNameFromDeclaration(symbol) {
            return !(symbol.flags & 33554432 /* Transient */) && (symbol.escapedName === "export=" /* ExportEquals */ || symbol.escapedName === "default" /* Default */);
        }
        function getDefaultLikeExportNameFromDeclaration(symbol) {
            return firstDefined(symbol.declarations, (d) => {
                var _a2, _b;
                return isExportAssignment(d) ? (_a2 = tryCast(skipOuterExpressions(d.expression), isIdentifier)) == null ? void 0 : _a2.text : (_b = tryCast(getNameOfDeclaration(d), isIdentifier)) == null ? void 0 : _b.text;
            });
        }
        function getSymbolParentOrFail(symbol) {
            var _a2;
            return Debug.checkDefined(symbol.parent, `Symbol parent was undefined. Flags: ${Debug.formatSymbolFlags(symbol.flags)}. Declarations: ${(_a2 = symbol.declarations) == null ? void 0 : _a2.map((d) => {
                const kind = Debug.formatSyntaxKind(d.kind);
                const inJS = isInJSFile(d);
                const { expression } = d;
                return (inJS ? "[JS]" : "") + kind + (expression ? ` (expression: ${Debug.formatSyntaxKind(expression.kind)})` : "");
            }).join(", ")}.`);
        }
        function stringContainsAt(haystack, needle, startIndex) {
            const needleLength = needle.length;
            if (needleLength + startIndex > haystack.length) {
                return false;
            }
            for (let i = 0; i < needleLength; i++) {
                if (needle.charCodeAt(i) !== haystack.charCodeAt(i + startIndex))
                    return false;
            }
            return true;
        }
        function startsWithUnderscore(name) {
            return name.charCodeAt(0) === 95 /* _ */;
        }
        function isGlobalDeclaration(declaration) {
            return !isNonGlobalDeclaration(declaration);
        }
        function isNonGlobalDeclaration(declaration) {
            const sourceFile = declaration.getSourceFile();
            if (!sourceFile.externalModuleIndicator && !sourceFile.commonJsModuleIndicator) {
                return false;
            }
            return isInJSFile(declaration) || !findAncestor(declaration, (d) => isModuleDeclaration(d) && isGlobalScopeAugmentation(d));
        }
        function isDeprecatedDeclaration(decl) {
            return !!(getCombinedNodeFlagsAlwaysIncludeJSDoc(decl) & 8192 /* Deprecated */);
        }
        function shouldUseUriStyleNodeCoreModules(file, program) {
            const decisionFromFile = firstDefined(file.imports, (node) => {
                if (ts_JsTyping_exports.nodeCoreModules.has(node.text)) {
                    return startsWith(node.text, "node:");
                }
            });
            return decisionFromFile != null ? decisionFromFile : program.usesUriStyleNodeCoreModules;
        }
        function getNewLineKind(newLineCharacter) {
            return newLineCharacter === "\n" ? 1 /* LineFeed */ : 0 /* CarriageReturnLineFeed */;
        }
        function diagnosticToString(diag2) {
            return isArray(diag2) ? formatStringFromArgs(getLocaleSpecificMessage(diag2[0]), diag2.slice(1)) : getLocaleSpecificMessage(diag2);
        }
        function getFormatCodeSettingsForWriting({ options }, sourceFile) {
            const shouldAutoDetectSemicolonPreference = !options.semicolons || options.semicolons === "ignore" /* Ignore */;
            const shouldRemoveSemicolons = options.semicolons === "remove" /* Remove */ || shouldAutoDetectSemicolonPreference && !probablyUsesSemicolons(sourceFile);
            return {
                ...options,
                semicolons: shouldRemoveSemicolons ? "remove" /* Remove */ : "ignore" /* Ignore */
            };
        }
        function jsxModeNeedsExplicitImport(jsx) {
            return jsx === 2 /* React */ || jsx === 3 /* ReactNative */;
        }
        function isSourceFileFromLibrary(program, node) {
            return program.isSourceFileFromExternalLibrary(node) || program.isSourceFileDefaultLibrary(node);
        }
        function newCaseClauseTracker(checker, clauses) {
            const existingStrings = /* @__PURE__ */ new Set();
            const existingNumbers = /* @__PURE__ */ new Set();
            const existingBigInts = /* @__PURE__ */ new Set();
            for (const clause of clauses) {
                if (!isDefaultClause(clause)) {
                    const expression = skipParentheses(clause.expression);
                    if (isLiteralExpression(expression)) {
                        switch (expression.kind) {
                            case 14 /* NoSubstitutionTemplateLiteral */:
                            case 10 /* StringLiteral */:
                                existingStrings.add(expression.text);
                                break;
                            case 8 /* NumericLiteral */:
                                existingNumbers.add(parseInt(expression.text));
                                break;
                            case 9 /* BigIntLiteral */:
                                const parsedBigInt = parseBigInt(endsWith(expression.text, "n") ? expression.text.slice(0, -1) : expression.text);
                                if (parsedBigInt) {
                                    existingBigInts.add(pseudoBigIntToString(parsedBigInt));
                                }
                                break;
                        }
                    }
                    else {
                        const symbol = checker.getSymbolAtLocation(clause.expression);
                        if (symbol && symbol.valueDeclaration && isEnumMember(symbol.valueDeclaration)) {
                            const enumValue = checker.getConstantValue(symbol.valueDeclaration);
                            if (enumValue !== void 0) {
                                addValue(enumValue);
                            }
                        }
                    }
                }
            }
            return {
                addValue,
                hasValue
            };
            function addValue(value) {
                switch (typeof value) {
                    case "string":
                        existingStrings.add(value);
                        break;
                    case "number":
                        existingNumbers.add(value);
                }
            }
            function hasValue(value) {
                switch (typeof value) {
                    case "string":
                        return existingStrings.has(value);
                    case "number":
                        return existingNumbers.has(value);
                    case "object":
                        return existingBigInts.has(pseudoBigIntToString(value));
                }
            }
        }
        var scanner, SemanticMeaning, tripleSlashDirectivePrefixRegex, typeKeywords, QuotePreference, displayPartWriter, lineFeed2, ANONYMOUS, syntaxMayBeASICandidate;
        var init_utilities4 = __esm({
            "src/services/utilities.ts"() {
                "use strict";
                init_ts4();
                scanner = createScanner(99 /* Latest */, 
                /*skipTrivia*/
                true);
                SemanticMeaning = /* @__PURE__ */ ((SemanticMeaning3) => {
                    SemanticMeaning3[SemanticMeaning3["None"] = 0] = "None";
                    SemanticMeaning3[SemanticMeaning3["Value"] = 1] = "Value";
                    SemanticMeaning3[SemanticMeaning3["Type"] = 2] = "Type";
                    SemanticMeaning3[SemanticMeaning3["Namespace"] = 4] = "Namespace";
                    SemanticMeaning3[SemanticMeaning3["All"] = 7] = "All";
                    return SemanticMeaning3;
                })(SemanticMeaning || {});
                tripleSlashDirectivePrefixRegex = /^\/\/\/\s*</;
                typeKeywords = [
                    131 /* AnyKeyword */,
                    129 /* AssertsKeyword */,
                    160 /* BigIntKeyword */,
                    134 /* BooleanKeyword */,
                    95 /* FalseKeyword */,
                    138 /* InferKeyword */,
                    141 /* KeyOfKeyword */,
                    144 /* NeverKeyword */,
                    104 /* NullKeyword */,
                    148 /* NumberKeyword */,
                    149 /* ObjectKeyword */,
                    146 /* ReadonlyKeyword */,
                    152 /* StringKeyword */,
                    153 /* SymbolKeyword */,
                    110 /* TrueKeyword */,
                    114 /* VoidKeyword */,
                    155 /* UndefinedKeyword */,
                    156 /* UniqueKeyword */,
                    157 /* UnknownKeyword */
                ];
                QuotePreference = /* @__PURE__ */ ((QuotePreference5) => {
                    QuotePreference5[QuotePreference5["Single"] = 0] = "Single";
                    QuotePreference5[QuotePreference5["Double"] = 1] = "Double";
                    return QuotePreference5;
                })(QuotePreference || {});
                displayPartWriter = getDisplayPartWriter();
                lineFeed2 = "\n";
                ANONYMOUS = "anonymous function";
                syntaxMayBeASICandidate = or(syntaxRequiresTrailingCommaOrSemicolonOrASI, syntaxRequiresTrailingFunctionBlockOrSemicolonOrASI, syntaxRequiresTrailingModuleBlockOrSemicolonOrASI, syntaxRequiresTrailingSemicolonOrASI);
            }
        });
        // src/services/exportInfoMap.ts
        function createCacheableExportInfoMap(host) {
            let exportInfoId = 1;
            const exportInfo = createMultiMap();
            const symbols = /* @__PURE__ */ new Map();
            const packages = /* @__PURE__ */ new Map();
            let usableByFileName;
            const cache = {
                isUsableByFile: (importingFile) => importingFile === usableByFileName,
                isEmpty: () => !exportInfo.size,
                clear: () => {
                    exportInfo.clear();
                    symbols.clear();
                    usableByFileName = void 0;
                },
                add: (importingFile, symbol, symbolTableKey, moduleSymbol, moduleFile, exportKind, isFromPackageJson, checker) => {
                    if (importingFile !== usableByFileName) {
                        cache.clear();
                        usableByFileName = importingFile;
                    }
                    let packageName;
                    if (moduleFile) {
                        const nodeModulesPathParts = getNodeModulePathParts(moduleFile.fileName);
                        if (nodeModulesPathParts) {
                            const { topLevelNodeModulesIndex, topLevelPackageNameIndex, packageRootIndex } = nodeModulesPathParts;
                            packageName = unmangleScopedPackageName(getPackageNameFromTypesPackageName(moduleFile.fileName.substring(topLevelPackageNameIndex + 1, packageRootIndex)));
                            if (startsWith(importingFile, moduleFile.path.substring(0, topLevelNodeModulesIndex))) {
                                const prevDeepestNodeModulesPath = packages.get(packageName);
                                const nodeModulesPath = moduleFile.fileName.substring(0, topLevelPackageNameIndex + 1);
                                if (prevDeepestNodeModulesPath) {
                                    const prevDeepestNodeModulesIndex = prevDeepestNodeModulesPath.indexOf(nodeModulesPathPart);
                                    if (topLevelNodeModulesIndex > prevDeepestNodeModulesIndex) {
                                        packages.set(packageName, nodeModulesPath);
                                    }
                                }
                                else {
                                    packages.set(packageName, nodeModulesPath);
                                }
                            }
                        }
                    }
                    const isDefault = exportKind === 1 /* Default */;
                    const namedSymbol = isDefault && getLocalSymbolForExportDefault(symbol) || symbol;
                    const names = exportKind === 0 /* Named */ || isExternalModuleSymbol(namedSymbol) ? unescapeLeadingUnderscores(symbolTableKey) : getNamesForExportedSymbol(namedSymbol, 
                    /*scriptTarget*/
                    void 0);
                    const symbolName2 = typeof names === "string" ? names : names[0];
                    const capitalizedSymbolName = typeof names === "string" ? void 0 : names[1];
                    const moduleName = stripQuotes(moduleSymbol.name);
                    const id = exportInfoId++;
                    const target = skipAlias(symbol, checker);
                    const storedSymbol = symbol.flags & 33554432 /* Transient */ ? void 0 : symbol;
                    const storedModuleSymbol = moduleSymbol.flags & 33554432 /* Transient */ ? void 0 : moduleSymbol;
                    if (!storedSymbol || !storedModuleSymbol)
                        symbols.set(id, [symbol, moduleSymbol]);
                    exportInfo.add(key(symbolName2, symbol, isExternalModuleNameRelative(moduleName) ? void 0 : moduleName, checker), {
                        id,
                        symbolTableKey,
                        symbolName: symbolName2,
                        capitalizedSymbolName,
                        moduleName,
                        moduleFile,
                        moduleFileName: moduleFile == null ? void 0 : moduleFile.fileName,
                        packageName,
                        exportKind,
                        targetFlags: target.flags,
                        isFromPackageJson,
                        symbol: storedSymbol,
                        moduleSymbol: storedModuleSymbol
                    });
                },
                get: (importingFile, key2) => {
                    if (importingFile !== usableByFileName)
                        return;
                    const result = exportInfo.get(key2);
                    return result == null ? void 0 : result.map(rehydrateCachedInfo);
                },
                search: (importingFile, preferCapitalized, matches, action) => {
                    if (importingFile !== usableByFileName)
                        return;
                    return forEachEntry(exportInfo, (info, key2) => {
                        const { symbolName: symbolName2, ambientModuleName } = parseKey(key2);
                        const name = preferCapitalized && info[0].capitalizedSymbolName || symbolName2;
                        if (matches(name, info[0].targetFlags)) {
                            const rehydrated = info.map(rehydrateCachedInfo);
                            const filtered = rehydrated.filter((r, i) => isNotShadowedByDeeperNodeModulesPackage(r, info[i].packageName));
                            if (filtered.length) {
                                const res = action(filtered, name, !!ambientModuleName, key2);
                                if (res !== void 0)
                                    return res;
                            }
                        }
                    });
                },
                releaseSymbols: () => {
                    symbols.clear();
                },
                onFileChanged: (oldSourceFile, newSourceFile, typeAcquisitionEnabled) => {
                    if (fileIsGlobalOnly(oldSourceFile) && fileIsGlobalOnly(newSourceFile)) {
                        return false;
                    }
                    if (usableByFileName && usableByFileName !== newSourceFile.path || // If ATA is enabled, auto-imports uses existing imports to guess whether you want auto-imports from node.
                        // Adding or removing imports from node could change the outcome of that guess, so could change the suggestions list.
                        typeAcquisitionEnabled && consumesNodeCoreModules(oldSourceFile) !== consumesNodeCoreModules(newSourceFile) || // Module agumentation and ambient module changes can add or remove exports available to be auto-imported.
                        // Changes elsewhere in the file can change the *type* of an export in a module augmentation,
                        // but type info is gathered in getCompletionEntryDetails, which doesn’t use the cache.
                        !arrayIsEqualTo(oldSourceFile.moduleAugmentations, newSourceFile.moduleAugmentations) || !ambientModuleDeclarationsAreEqual(oldSourceFile, newSourceFile)) {
                        cache.clear();
                        return true;
                    }
                    usableByFileName = newSourceFile.path;
                    return false;
                }
            };
            if (Debug.isDebugging) {
                Object.defineProperty(cache, "__cache", { get: () => exportInfo });
            }
            return cache;
            function rehydrateCachedInfo(info) {
                if (info.symbol && info.moduleSymbol)
                    return info;
                const { id, exportKind, targetFlags, isFromPackageJson, moduleFileName } = info;
                const [cachedSymbol, cachedModuleSymbol] = symbols.get(id) || emptyArray;
                if (cachedSymbol && cachedModuleSymbol) {
                    return {
                        symbol: cachedSymbol,
                        moduleSymbol: cachedModuleSymbol,
                        moduleFileName,
                        exportKind,
                        targetFlags,
                        isFromPackageJson
                    };
                }
                const checker = (isFromPackageJson ? host.getPackageJsonAutoImportProvider() : host.getCurrentProgram()).getTypeChecker();
                const moduleSymbol = info.moduleSymbol || cachedModuleSymbol || Debug.checkDefined(info.moduleFile ? checker.getMergedSymbol(info.moduleFile.symbol) : checker.tryFindAmbientModule(info.moduleName));
                const symbol = info.symbol || cachedSymbol || Debug.checkDefined(exportKind === 2 /* ExportEquals */ ? checker.resolveExternalModuleSymbol(moduleSymbol) : checker.tryGetMemberInModuleExportsAndProperties(unescapeLeadingUnderscores(info.symbolTableKey), moduleSymbol), `Could not find symbol '${info.symbolName}' by key '${info.symbolTableKey}' in module ${moduleSymbol.name}`);
                symbols.set(id, [symbol, moduleSymbol]);
                return {
                    symbol,
                    moduleSymbol,
                    moduleFileName,
                    exportKind,
                    targetFlags,
                    isFromPackageJson
                };
            }
            function key(importedName, symbol, ambientModuleName, checker) {
                const moduleKey = ambientModuleName || "";
                return `${importedName}|${getSymbolId(skipAlias(symbol, checker))}|${moduleKey}`;
            }
            function parseKey(key2) {
                const symbolName2 = key2.substring(0, key2.indexOf("|"));
                const moduleKey = key2.substring(key2.lastIndexOf("|") + 1);
                const ambientModuleName = moduleKey === "" ? void 0 : moduleKey;
                return { symbolName: symbolName2, ambientModuleName };
            }
            function fileIsGlobalOnly(file) {
                return !file.commonJsModuleIndicator && !file.externalModuleIndicator && !file.moduleAugmentations && !file.ambientModuleNames;
            }
            function ambientModuleDeclarationsAreEqual(oldSourceFile, newSourceFile) {
                if (!arrayIsEqualTo(oldSourceFile.ambientModuleNames, newSourceFile.ambientModuleNames)) {
                    return false;
                }
                let oldFileStatementIndex = -1;
                let newFileStatementIndex = -1;
                for (const ambientModuleName of newSourceFile.ambientModuleNames) {
                    const isMatchingModuleDeclaration = (node) => isNonGlobalAmbientModule(node) && node.name.text === ambientModuleName;
                    oldFileStatementIndex = findIndex(oldSourceFile.statements, isMatchingModuleDeclaration, oldFileStatementIndex + 1);
                    newFileStatementIndex = findIndex(newSourceFile.statements, isMatchingModuleDeclaration, newFileStatementIndex + 1);
                    if (oldSourceFile.statements[oldFileStatementIndex] !== newSourceFile.statements[newFileStatementIndex]) {
                        return false;
                    }
                }
                return true;
            }
            function isNotShadowedByDeeperNodeModulesPackage(info, packageName) {
                if (!packageName || !info.moduleFileName)
                    return true;
                const typingsCacheLocation = host.getGlobalTypingsCacheLocation();
                if (typingsCacheLocation && startsWith(info.moduleFileName, typingsCacheLocation))
                    return true;
                const packageDeepestNodeModulesPath = packages.get(packageName);
                return !packageDeepestNodeModulesPath || startsWith(info.moduleFileName, packageDeepestNodeModulesPath);
            }
        }
        function isImportableFile(program, from, to, preferences, packageJsonFilter, moduleSpecifierResolutionHost, moduleSpecifierCache) {
            var _a2;
            if (from === to)
                return false;
            const cachedResult = moduleSpecifierCache == null ? void 0 : moduleSpecifierCache.get(from.path, to.path, preferences, {});
            if ((cachedResult == null ? void 0 : cachedResult.isBlockedByPackageJsonDependencies) !== void 0) {
                return !cachedResult.isBlockedByPackageJsonDependencies;
            }
            const getCanonicalFileName = hostGetCanonicalFileName(moduleSpecifierResolutionHost);
            const globalTypingsCache = (_a2 = moduleSpecifierResolutionHost.getGlobalTypingsCacheLocation) == null ? void 0 : _a2.call(moduleSpecifierResolutionHost);
            const hasImportablePath = !!ts_moduleSpecifiers_exports.forEachFileNameOfModule(from.fileName, to.fileName, moduleSpecifierResolutionHost, 
            /*preferSymlinks*/
            false, (toPath3) => {
                const toFile = program.getSourceFile(toPath3);
                return (toFile === to || !toFile) && isImportablePath(from.fileName, toPath3, getCanonicalFileName, globalTypingsCache);
            });
            if (packageJsonFilter) {
                const isAutoImportable = hasImportablePath && packageJsonFilter.allowsImportingSourceFile(to, moduleSpecifierResolutionHost);
                moduleSpecifierCache == null ? void 0 : moduleSpecifierCache.setBlockedByPackageJsonDependencies(from.path, to.path, preferences, {}, !isAutoImportable);
                return isAutoImportable;
            }
            return hasImportablePath;
        }
        function isImportablePath(fromPath, toPath3, getCanonicalFileName, globalCachePath) {
            const toNodeModules = forEachAncestorDirectory(toPath3, (ancestor) => getBaseFileName(ancestor) === "node_modules" ? ancestor : void 0);
            const toNodeModulesParent = toNodeModules && getDirectoryPath(getCanonicalFileName(toNodeModules));
            return toNodeModulesParent === void 0 || startsWith(getCanonicalFileName(fromPath), toNodeModulesParent) || !!globalCachePath && startsWith(getCanonicalFileName(globalCachePath), toNodeModulesParent);
        }
        function forEachExternalModuleToImportFrom(program, host, preferences, useAutoImportProvider, cb) {
            var _a2, _b;
            const useCaseSensitiveFileNames = hostUsesCaseSensitiveFileNames(host);
            const excludePatterns = preferences.autoImportFileExcludePatterns && mapDefined(preferences.autoImportFileExcludePatterns, (spec) => {
                const pattern = getPatternFromSpec(spec, "", "exclude");
                return pattern ? getRegexFromPattern(pattern, useCaseSensitiveFileNames) : void 0;
            });
            forEachExternalModule(program.getTypeChecker(), program.getSourceFiles(), excludePatterns, (module2, file) => cb(module2, file, program, 
            /*isFromPackageJson*/
            false));
            const autoImportProvider = useAutoImportProvider && ((_a2 = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a2.call(host));
            if (autoImportProvider) {
                const start = timestamp();
                const checker = program.getTypeChecker();
                forEachExternalModule(autoImportProvider.getTypeChecker(), autoImportProvider.getSourceFiles(), excludePatterns, (module2, file) => {
                    if (file && !program.getSourceFile(file.fileName) || !file && !checker.resolveName(module2.name, 
                    /*location*/
                    void 0, 1536 /* Module */, 
                    /*excludeGlobals*/
                    false)) {
                        cb(module2, file, autoImportProvider, 
                        /*isFromPackageJson*/
                        true);
                    }
                });
                (_b = host.log) == null ? void 0 : _b.call(host, `forEachExternalModuleToImportFrom autoImportProvider: ${timestamp() - start}`);
            }
        }
        function forEachExternalModule(checker, allSourceFiles, excludePatterns, cb) {
            var _a2;
            const isExcluded = excludePatterns && ((fileName) => excludePatterns.some((p) => p.test(fileName)));
            for (const ambient of checker.getAmbientModules()) {
                if (!stringContains(ambient.name, "*") && !(excludePatterns && ((_a2 = ambient.declarations) == null ? void 0 : _a2.every((d) => isExcluded(d.getSourceFile().fileName))))) {
                    cb(ambient, 
                    /*sourceFile*/
                    void 0);
                }
            }
            for (const sourceFile of allSourceFiles) {
                if (isExternalOrCommonJsModule(sourceFile) && !(isExcluded == null ? void 0 : isExcluded(sourceFile.fileName))) {
                    cb(checker.getMergedSymbol(sourceFile.symbol), sourceFile);
                }
            }
        }
        function getExportInfoMap(importingFile, host, program, preferences, cancellationToken) {
            var _a2, _b, _c, _d, _e;
            const start = timestamp();
            (_a2 = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a2.call(host);
            const cache = ((_b = host.getCachedExportInfoMap) == null ? void 0 : _b.call(host)) || createCacheableExportInfoMap({
                getCurrentProgram: () => program,
                getPackageJsonAutoImportProvider: () => {
                    var _a3;
                    return (_a3 = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a3.call(host);
                },
                getGlobalTypingsCacheLocation: () => {
                    var _a3;
                    return (_a3 = host.getGlobalTypingsCacheLocation) == null ? void 0 : _a3.call(host);
                }
            });
            if (cache.isUsableByFile(importingFile.path)) {
                (_c = host.log) == null ? void 0 : _c.call(host, "getExportInfoMap: cache hit");
                return cache;
            }
            (_d = host.log) == null ? void 0 : _d.call(host, "getExportInfoMap: cache miss or empty; calculating new results");
            const compilerOptions = program.getCompilerOptions();
            let moduleCount = 0;
            try {
                forEachExternalModuleToImportFrom(program, host, preferences, 
                /*useAutoImportProvider*/
                true, (moduleSymbol, moduleFile, program2, isFromPackageJson) => {
                    if (++moduleCount % 100 === 0)
                        cancellationToken == null ? void 0 : cancellationToken.throwIfCancellationRequested();
                    const seenExports = /* @__PURE__ */ new Map();
                    const checker = program2.getTypeChecker();
                    const defaultInfo = getDefaultLikeExportInfo(moduleSymbol, checker, compilerOptions);
                    if (defaultInfo && isImportableSymbol(defaultInfo.symbol, checker)) {
                        cache.add(importingFile.path, defaultInfo.symbol, defaultInfo.exportKind === 1 /* Default */ ? "default" /* Default */ : "export=" /* ExportEquals */, moduleSymbol, moduleFile, defaultInfo.exportKind, isFromPackageJson, checker);
                    }
                    checker.forEachExportAndPropertyOfModule(moduleSymbol, (exported, key) => {
                        if (exported !== (defaultInfo == null ? void 0 : defaultInfo.symbol) && isImportableSymbol(exported, checker) && addToSeen(seenExports, key)) {
                            cache.add(importingFile.path, exported, key, moduleSymbol, moduleFile, 0 /* Named */, isFromPackageJson, checker);
                        }
                    });
                });
            }
            catch (err) {
                cache.clear();
                throw err;
            }
            (_e = host.log) == null ? void 0 : _e.call(host, `getExportInfoMap: done in ${timestamp() - start} ms`);
            return cache;
        }
        function getDefaultLikeExportInfo(moduleSymbol, checker, compilerOptions) {
            const exported = getDefaultLikeExportWorker(moduleSymbol, checker);
            if (!exported)
                return void 0;
            const { symbol, exportKind } = exported;
            const info = getDefaultExportInfoWorker(symbol, checker, compilerOptions);
            return info && { symbol, exportKind, ...info };
        }
        function isImportableSymbol(symbol, checker) {
            return !checker.isUndefinedSymbol(symbol) && !checker.isUnknownSymbol(symbol) && !isKnownSymbol(symbol) && !isPrivateIdentifierSymbol(symbol);
        }
        function getDefaultLikeExportWorker(moduleSymbol, checker) {
            const exportEquals = checker.resolveExternalModuleSymbol(moduleSymbol);
            if (exportEquals !== moduleSymbol)
                return { symbol: exportEquals, exportKind: 2 /* ExportEquals */ };
            const defaultExport = checker.tryGetMemberInModuleExports("default" /* Default */, moduleSymbol);
            if (defaultExport)
                return { symbol: defaultExport, exportKind: 1 /* Default */ };
        }
        function getDefaultExportInfoWorker(defaultExport, checker, compilerOptions) {
            const localSymbol = getLocalSymbolForExportDefault(defaultExport);
            if (localSymbol)
                return { resolvedSymbol: localSymbol, name: localSymbol.name };
            const name = getNameForExportDefault(defaultExport);
            if (name !== void 0)
                return { resolvedSymbol: defaultExport, name };
            if (defaultExport.flags & 2097152 /* Alias */) {
                const aliased = checker.getImmediateAliasedSymbol(defaultExport);
                if (aliased && aliased.parent) {
                    return getDefaultExportInfoWorker(aliased, checker, compilerOptions);
                }
            }
            if (defaultExport.escapedName !== "default" /* Default */ && defaultExport.escapedName !== "export=" /* ExportEquals */) {
                return { resolvedSymbol: defaultExport, name: defaultExport.getName() };
            }
            return { resolvedSymbol: defaultExport, name: getNameForExportedSymbol(defaultExport, compilerOptions.target) };
        }
        function getNameForExportDefault(symbol) {
            return symbol.declarations && firstDefined(symbol.declarations, (declaration) => {
                var _a2;
                if (isExportAssignment(declaration)) {
                    return (_a2 = tryCast(skipOuterExpressions(declaration.expression), isIdentifier)) == null ? void 0 : _a2.text;
                }
                else if (isExportSpecifier(declaration)) {
                    Debug.assert(declaration.name.text === "default" /* Default */, "Expected the specifier to be a default export");
                    return declaration.propertyName && declaration.propertyName.text;
                }
            });
        }
        var ImportKind, ExportKind;
        var init_exportInfoMap = __esm({
            "src/services/exportInfoMap.ts"() {
                "use strict";
                init_ts4();
                ImportKind = /* @__PURE__ */ ((ImportKind2) => {
                    ImportKind2[ImportKind2["Named"] = 0] = "Named";
                    ImportKind2[ImportKind2["Default"] = 1] = "Default";
                    ImportKind2[ImportKind2["Namespace"] = 2] = "Namespace";
                    ImportKind2[ImportKind2["CommonJS"] = 3] = "CommonJS";
                    return ImportKind2;
                })(ImportKind || {});
                ExportKind = /* @__PURE__ */ ((ExportKind3) => {
                    ExportKind3[ExportKind3["Named"] = 0] = "Named";
                    ExportKind3[ExportKind3["Default"] = 1] = "Default";
                    ExportKind3[ExportKind3["ExportEquals"] = 2] = "ExportEquals";
                    ExportKind3[ExportKind3["UMD"] = 3] = "UMD";
                    return ExportKind3;
                })(ExportKind || {});
            }
        });
        // src/services/classifier.ts
        function createClassifier() {
            const scanner2 = createScanner(99 /* Latest */, 
            /*skipTrivia*/
            false);
            function getClassificationsForLine(text, lexState, syntacticClassifierAbsent) {
                return convertClassificationsToResult(getEncodedLexicalClassifications(text, lexState, syntacticClassifierAbsent), text);
            }
            function getEncodedLexicalClassifications(text, lexState, syntacticClassifierAbsent) {
                let token = 0 /* Unknown */;
                let lastNonTriviaToken = 0 /* Unknown */;
                const templateStack = [];
                const { prefix, pushTemplate } = getPrefixFromLexState(lexState);
                text = prefix + text;
                const offset = prefix.length;
                if (pushTemplate) {
                    templateStack.push(15 /* TemplateHead */);
                }
                scanner2.setText(text);
                let endOfLineState = 0 /* None */;
                const spans = [];
                let angleBracketStack = 0;
                do {
                    token = scanner2.scan();
                    if (!isTrivia(token)) {
                        handleToken();
                        lastNonTriviaToken = token;
                    }
                    const end = scanner2.getTextPos();
                    pushEncodedClassification(scanner2.getTokenPos(), end, offset, classFromKind(token), spans);
                    if (end >= text.length) {
                        const end2 = getNewEndOfLineState(scanner2, token, lastOrUndefined(templateStack));
                        if (end2 !== void 0) {
                            endOfLineState = end2;
                        }
                    }
                } while (token !== 1 /* EndOfFileToken */);
                function handleToken() {
                    switch (token) {
                        case 43 /* SlashToken */:
                        case 68 /* SlashEqualsToken */:
                            if (!noRegexTable[lastNonTriviaToken] && scanner2.reScanSlashToken() === 13 /* RegularExpressionLiteral */) {
                                token = 13 /* RegularExpressionLiteral */;
                            }
                            break;
                        case 29 /* LessThanToken */:
                            if (lastNonTriviaToken === 79 /* Identifier */) {
                                angleBracketStack++;
                            }
                            break;
                        case 31 /* GreaterThanToken */:
                            if (angleBracketStack > 0) {
                                angleBracketStack--;
                            }
                            break;
                        case 131 /* AnyKeyword */:
                        case 152 /* StringKeyword */:
                        case 148 /* NumberKeyword */:
                        case 134 /* BooleanKeyword */:
                        case 153 /* SymbolKeyword */:
                            if (angleBracketStack > 0 && !syntacticClassifierAbsent) {
                                token = 79 /* Identifier */;
                            }
                            break;
                        case 15 /* TemplateHead */:
                            templateStack.push(token);
                            break;
                        case 18 /* OpenBraceToken */:
                            if (templateStack.length > 0) {
                                templateStack.push(token);
                            }
                            break;
                        case 19 /* CloseBraceToken */:
                            if (templateStack.length > 0) {
                                const lastTemplateStackToken = lastOrUndefined(templateStack);
                                if (lastTemplateStackToken === 15 /* TemplateHead */) {
                                    token = scanner2.reScanTemplateToken(
                                    /* isTaggedTemplate */
                                    false);
                                    if (token === 17 /* TemplateTail */) {
                                        templateStack.pop();
                                    }
                                    else {
                                        Debug.assertEqual(token, 16 /* TemplateMiddle */, "Should have been a template middle.");
                                    }
                                }
                                else {
                                    Debug.assertEqual(lastTemplateStackToken, 18 /* OpenBraceToken */, "Should have been an open brace");
                                    templateStack.pop();
                                }
                            }
                            break;
                        default:
                            if (!isKeyword(token)) {
                                break;
                            }
                            if (lastNonTriviaToken === 24 /* DotToken */) {
                                token = 79 /* Identifier */;
                            }
                            else if (isKeyword(lastNonTriviaToken) && isKeyword(token) && !canFollow(lastNonTriviaToken, token)) {
                                token = 79 /* Identifier */;
                            }
                    }
                }
                return { endOfLineState, spans };
            }
            return { getClassificationsForLine, getEncodedLexicalClassifications };
        }
        function getNewEndOfLineState(scanner2, token, lastOnTemplateStack) {
            switch (token) {
                case 10 /* StringLiteral */: {
                    if (!scanner2.isUnterminated())
                        return void 0;
                    const tokenText = scanner2.getTokenText();
                    const lastCharIndex = tokenText.length - 1;
                    let numBackslashes = 0;
                    while (tokenText.charCodeAt(lastCharIndex - numBackslashes) === 92 /* backslash */) {
                        numBackslashes++;
                    }
                    if ((numBackslashes & 1) === 0)
                        return void 0;
                    return tokenText.charCodeAt(0) === 34 /* doubleQuote */ ? 3 /* InDoubleQuoteStringLiteral */ : 2 /* InSingleQuoteStringLiteral */;
                }
                case 3 /* MultiLineCommentTrivia */:
                    return scanner2.isUnterminated() ? 1 /* InMultiLineCommentTrivia */ : void 0;
                default:
                    if (isTemplateLiteralKind(token)) {
                        if (!scanner2.isUnterminated()) {
                            return void 0;
                        }
                        switch (token) {
                            case 17 /* TemplateTail */:
                                return 5 /* InTemplateMiddleOrTail */;
                            case 14 /* NoSubstitutionTemplateLiteral */:
                                return 4 /* InTemplateHeadOrNoSubstitutionTemplate */;
                            default:
                                return Debug.fail("Only 'NoSubstitutionTemplateLiteral's and 'TemplateTail's can be unterminated; got SyntaxKind #" + token);
                        }
                    }
                    return lastOnTemplateStack === 15 /* TemplateHead */ ? 6 /* InTemplateSubstitutionPosition */ : void 0;
            }
        }
        function pushEncodedClassification(start, end, offset, classification, result) {
            if (classification === 8 /* whiteSpace */) {
                return;
            }
            if (start === 0 && offset > 0) {
                start += offset;
            }
            const length2 = end - start;
            if (length2 > 0) {
                result.push(start - offset, length2, classification);
            }
        }
        function convertClassificationsToResult(classifications, text) {
            const entries = [];
            const dense = classifications.spans;
            let lastEnd = 0;
            for (let i = 0; i < dense.length; i += 3) {
                const start = dense[i];
                const length2 = dense[i + 1];
                const type = dense[i + 2];
                if (lastEnd >= 0) {
                    const whitespaceLength2 = start - lastEnd;
                    if (whitespaceLength2 > 0) {
                        entries.push({ length: whitespaceLength2, classification: 4 /* Whitespace */ });
                    }
                }
                entries.push({ length: length2, classification: convertClassification(type) });
                lastEnd = start + length2;
            }
            const whitespaceLength = text.length - lastEnd;
            if (whitespaceLength > 0) {
                entries.push({ length: whitespaceLength, classification: 4 /* Whitespace */ });
            }
            return { entries, finalLexState: classifications.endOfLineState };
        }
        function convertClassification(type) {
            switch (type) {
                case 1 /* comment */:
                    return 3 /* Comment */;
                case 3 /* keyword */:
                    return 1 /* Keyword */;
                case 4 /* numericLiteral */:
                    return 6 /* NumberLiteral */;
                case 25 /* bigintLiteral */:
                    return 7 /* BigIntLiteral */;
                case 5 /* operator */:
                    return 2 /* Operator */;
                case 6 /* stringLiteral */:
                    return 8 /* StringLiteral */;
                case 8 /* whiteSpace */:
                    return 4 /* Whitespace */;
                case 10 /* punctuation */:
                    return 0 /* Punctuation */;
                case 2 /* identifier */:
                case 11 /* className */:
                case 12 /* enumName */:
                case 13 /* interfaceName */:
                case 14 /* moduleName */:
                case 15 /* typeParameterName */:
                case 16 /* typeAliasName */:
                case 9 /* text */:
                case 17 /* parameterName */:
                    return 5 /* Identifier */;
                default:
                    return void 0;
            }
        }
        function canFollow(keyword1, keyword2) {
            if (!isAccessibilityModifier(keyword1)) {
                return true;
            }
            switch (keyword2) {
                case 137 /* GetKeyword */:
                case 151 /* SetKeyword */:
                case 135 /* ConstructorKeyword */:
                case 124 /* StaticKeyword */:
                case 127 /* AccessorKeyword */:
                    return true;
                default:
                    return false;
            }
        }
        function getPrefixFromLexState(lexState) {
            switch (lexState) {
                case 3 /* InDoubleQuoteStringLiteral */:
                    return { prefix: '"\\\n' };
                case 2 /* InSingleQuoteStringLiteral */:
                    return { prefix: "'\\\n" };
                case 1 /* InMultiLineCommentTrivia */:
                    return { prefix: "/*\n" };
                case 4 /* InTemplateHeadOrNoSubstitutionTemplate */:
                    return { prefix: "`\n" };
                case 5 /* InTemplateMiddleOrTail */:
                    return { prefix: "}\n", pushTemplate: true };
                case 6 /* InTemplateSubstitutionPosition */:
                    return { prefix: "", pushTemplate: true };
                case 0 /* None */:
                    return { prefix: "" };
                default:
                    return Debug.assertNever(lexState);
            }
        }
        function isBinaryExpressionOperatorToken(token) {
            switch (token) {
                case 41 /* AsteriskToken */:
                case 43 /* SlashToken */:
                case 44 /* PercentToken */:
                case 39 /* PlusToken */:
                case 40 /* MinusToken */:
                case 47 /* LessThanLessThanToken */:
                case 48 /* GreaterThanGreaterThanToken */:
                case 49 /* GreaterThanGreaterThanGreaterThanToken */:
                case 29 /* LessThanToken */:
                case 31 /* GreaterThanToken */:
                case 32 /* LessThanEqualsToken */:
                case 33 /* GreaterThanEqualsToken */:
                case 102 /* InstanceOfKeyword */:
                case 101 /* InKeyword */:
                case 128 /* AsKeyword */:
                case 150 /* SatisfiesKeyword */:
                case 34 /* EqualsEqualsToken */:
                case 35 /* ExclamationEqualsToken */:
                case 36 /* EqualsEqualsEqualsToken */:
                case 37 /* ExclamationEqualsEqualsToken */:
                case 50 /* AmpersandToken */:
                case 52 /* CaretToken */:
                case 51 /* BarToken */:
                case 55 /* AmpersandAmpersandToken */:
                case 56 /* BarBarToken */:
                case 74 /* BarEqualsToken */:
                case 73 /* AmpersandEqualsToken */:
                case 78 /* CaretEqualsToken */:
                case 70 /* LessThanLessThanEqualsToken */:
                case 71 /* GreaterThanGreaterThanEqualsToken */:
                case 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                case 64 /* PlusEqualsToken */:
                case 65 /* MinusEqualsToken */:
                case 66 /* AsteriskEqualsToken */:
                case 68 /* SlashEqualsToken */:
                case 69 /* PercentEqualsToken */:
                case 63 /* EqualsToken */:
                case 27 /* CommaToken */:
                case 60 /* QuestionQuestionToken */:
                case 75 /* BarBarEqualsToken */:
                case 76 /* AmpersandAmpersandEqualsToken */:
                case 77 /* QuestionQuestionEqualsToken */:
                    return true;
                default:
                    return false;
            }
        }
        function isPrefixUnaryExpressionOperatorToken(token) {
            switch (token) {
                case 39 /* PlusToken */:
                case 40 /* MinusToken */:
                case 54 /* TildeToken */:
                case 53 /* ExclamationToken */:
                case 45 /* PlusPlusToken */:
                case 46 /* MinusMinusToken */:
                    return true;
                default:
                    return false;
            }
        }
        function classFromKind(token) {
            if (isKeyword(token)) {
                return 3 /* keyword */;
            }
            else if (isBinaryExpressionOperatorToken(token) || isPrefixUnaryExpressionOperatorToken(token)) {
                return 5 /* operator */;
            }
            else if (token >= 18 /* FirstPunctuation */ && token <= 78 /* LastPunctuation */) {
                return 10 /* punctuation */;
            }
            switch (token) {
                case 8 /* NumericLiteral */:
                    return 4 /* numericLiteral */;
                case 9 /* BigIntLiteral */:
                    return 25 /* bigintLiteral */;
                case 10 /* StringLiteral */:
                    return 6 /* stringLiteral */;
                case 13 /* RegularExpressionLiteral */:
                    return 7 /* regularExpressionLiteral */;
                case 7 /* ConflictMarkerTrivia */:
                case 3 /* MultiLineCommentTrivia */:
                case 2 /* SingleLineCommentTrivia */:
                    return 1 /* comment */;
                case 5 /* WhitespaceTrivia */:
                case 4 /* NewLineTrivia */:
                    return 8 /* whiteSpace */;
                case 79 /* Identifier */:
                default:
                    if (isTemplateLiteralKind(token)) {
                        return 6 /* stringLiteral */;
                    }
                    return 2 /* identifier */;
            }
        }
        function getSemanticClassifications(typeChecker, cancellationToken, sourceFile, classifiableNames, span) {
            return convertClassificationsToSpans(getEncodedSemanticClassifications(typeChecker, cancellationToken, sourceFile, classifiableNames, span));
        }
        function checkForClassificationCancellation(cancellationToken, kind) {
            switch (kind) {
                case 264 /* ModuleDeclaration */:
                case 260 /* ClassDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 259 /* FunctionDeclaration */:
                case 228 /* ClassExpression */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                    cancellationToken.throwIfCancellationRequested();
            }
        }
        function getEncodedSemanticClassifications(typeChecker, cancellationToken, sourceFile, classifiableNames, span) {
            const spans = [];
            sourceFile.forEachChild(function cb(node) {
                if (!node || !textSpanIntersectsWith(span, node.pos, node.getFullWidth())) {
                    return;
                }
                checkForClassificationCancellation(cancellationToken, node.kind);
                if (isIdentifier(node) && !nodeIsMissing(node) && classifiableNames.has(node.escapedText)) {
                    const symbol = typeChecker.getSymbolAtLocation(node);
                    const type = symbol && classifySymbol(symbol, getMeaningFromLocation(node), typeChecker);
                    if (type) {
                        pushClassification(node.getStart(sourceFile), node.getEnd(), type);
                    }
                }
                node.forEachChild(cb);
            });
            return { spans, endOfLineState: 0 /* None */ };
            function pushClassification(start, end, type) {
                const length2 = end - start;
                Debug.assert(length2 > 0, `Classification had non-positive length of ${length2}`);
                spans.push(start);
                spans.push(length2);
                spans.push(type);
            }
        }
        function classifySymbol(symbol, meaningAtPosition, checker) {
            const flags = symbol.getFlags();
            if ((flags & 2885600 /* Classifiable */) === 0 /* None */) {
                return void 0;
            }
            else if (flags & 32 /* Class */) {
                return 11 /* className */;
            }
            else if (flags & 384 /* Enum */) {
                return 12 /* enumName */;
            }
            else if (flags & 524288 /* TypeAlias */) {
                return 16 /* typeAliasName */;
            }
            else if (flags & 1536 /* Module */) {
                return meaningAtPosition & 4 /* Namespace */ || meaningAtPosition & 1 /* Value */ && hasValueSideModule(symbol) ? 14 /* moduleName */ : void 0;
            }
            else if (flags & 2097152 /* Alias */) {
                return classifySymbol(checker.getAliasedSymbol(symbol), meaningAtPosition, checker);
            }
            else if (meaningAtPosition & 2 /* Type */) {
                return flags & 64 /* Interface */ ? 13 /* interfaceName */ : flags & 262144 /* TypeParameter */ ? 15 /* typeParameterName */ : void 0;
            }
            else {
                return void 0;
            }
        }
        function hasValueSideModule(symbol) {
            return some(symbol.declarations, (declaration) => isModuleDeclaration(declaration) && getModuleInstanceState(declaration) === 1 /* Instantiated */);
        }
        function getClassificationTypeName(type) {
            switch (type) {
                case 1 /* comment */:
                    return "comment" /* comment */;
                case 2 /* identifier */:
                    return "identifier" /* identifier */;
                case 3 /* keyword */:
                    return "keyword" /* keyword */;
                case 4 /* numericLiteral */:
                    return "number" /* numericLiteral */;
                case 25 /* bigintLiteral */:
                    return "bigint" /* bigintLiteral */;
                case 5 /* operator */:
                    return "operator" /* operator */;
                case 6 /* stringLiteral */:
                    return "string" /* stringLiteral */;
                case 8 /* whiteSpace */:
                    return "whitespace" /* whiteSpace */;
                case 9 /* text */:
                    return "text" /* text */;
                case 10 /* punctuation */:
                    return "punctuation" /* punctuation */;
                case 11 /* className */:
                    return "class name" /* className */;
                case 12 /* enumName */:
                    return "enum name" /* enumName */;
                case 13 /* interfaceName */:
                    return "interface name" /* interfaceName */;
                case 14 /* moduleName */:
                    return "module name" /* moduleName */;
                case 15 /* typeParameterName */:
                    return "type parameter name" /* typeParameterName */;
                case 16 /* typeAliasName */:
                    return "type alias name" /* typeAliasName */;
                case 17 /* parameterName */:
                    return "parameter name" /* parameterName */;
                case 18 /* docCommentTagName */:
                    return "doc comment tag name" /* docCommentTagName */;
                case 19 /* jsxOpenTagName */:
                    return "jsx open tag name" /* jsxOpenTagName */;
                case 20 /* jsxCloseTagName */:
                    return "jsx close tag name" /* jsxCloseTagName */;
                case 21 /* jsxSelfClosingTagName */:
                    return "jsx self closing tag name" /* jsxSelfClosingTagName */;
                case 22 /* jsxAttribute */:
                    return "jsx attribute" /* jsxAttribute */;
                case 23 /* jsxText */:
                    return "jsx text" /* jsxText */;
                case 24 /* jsxAttributeStringLiteralValue */:
                    return "jsx attribute string literal value" /* jsxAttributeStringLiteralValue */;
                default:
                    return void 0;
            }
        }
        function convertClassificationsToSpans(classifications) {
            Debug.assert(classifications.spans.length % 3 === 0);
            const dense = classifications.spans;
            const result = [];
            for (let i = 0; i < dense.length; i += 3) {
                result.push({
                    textSpan: createTextSpan(dense[i], dense[i + 1]),
                    classificationType: getClassificationTypeName(dense[i + 2])
                });
            }
            return result;
        }
        function getSyntacticClassifications(cancellationToken, sourceFile, span) {
            return convertClassificationsToSpans(getEncodedSyntacticClassifications(cancellationToken, sourceFile, span));
        }
        function getEncodedSyntacticClassifications(cancellationToken, sourceFile, span) {
            const spanStart = span.start;
            const spanLength = span.length;
            const triviaScanner = createScanner(99 /* Latest */, 
            /*skipTrivia*/
            false, sourceFile.languageVariant, sourceFile.text);
            const mergeConflictScanner = createScanner(99 /* Latest */, 
            /*skipTrivia*/
            false, sourceFile.languageVariant, sourceFile.text);
            const result = [];
            processElement(sourceFile);
            return { spans: result, endOfLineState: 0 /* None */ };
            function pushClassification(start, length2, type) {
                result.push(start);
                result.push(length2);
                result.push(type);
            }
            function classifyLeadingTriviaAndGetTokenStart(token) {
                triviaScanner.setTextPos(token.pos);
                while (true) {
                    const start = triviaScanner.getTextPos();
                    if (!couldStartTrivia(sourceFile.text, start)) {
                        return start;
                    }
                    const kind = triviaScanner.scan();
                    const end = triviaScanner.getTextPos();
                    const width = end - start;
                    if (!isTrivia(kind)) {
                        return start;
                    }
                    switch (kind) {
                        case 4 /* NewLineTrivia */:
                        case 5 /* WhitespaceTrivia */:
                            continue;
                        case 2 /* SingleLineCommentTrivia */:
                        case 3 /* MultiLineCommentTrivia */:
                            classifyComment(token, kind, start, width);
                            triviaScanner.setTextPos(end);
                            continue;
                        case 7 /* ConflictMarkerTrivia */:
                            const text = sourceFile.text;
                            const ch = text.charCodeAt(start);
                            if (ch === 60 /* lessThan */ || ch === 62 /* greaterThan */) {
                                pushClassification(start, width, 1 /* comment */);
                                continue;
                            }
                            Debug.assert(ch === 124 /* bar */ || ch === 61 /* equals */);
                            classifyDisabledMergeCode(text, start, end);
                            break;
                        case 6 /* ShebangTrivia */:
                            break;
                        default:
                            Debug.assertNever(kind);
                    }
                }
            }
            function classifyComment(token, kind, start, width) {
                if (kind === 3 /* MultiLineCommentTrivia */) {
                    const docCommentAndDiagnostics = parseIsolatedJSDocComment(sourceFile.text, start, width);
                    if (docCommentAndDiagnostics && docCommentAndDiagnostics.jsDoc) {
                        setParent(docCommentAndDiagnostics.jsDoc, token);
                        classifyJSDocComment(docCommentAndDiagnostics.jsDoc);
                        return;
                    }
                }
                else if (kind === 2 /* SingleLineCommentTrivia */) {
                    if (tryClassifyTripleSlashComment(start, width)) {
                        return;
                    }
                }
                pushCommentRange(start, width);
            }
            function pushCommentRange(start, width) {
                pushClassification(start, width, 1 /* comment */);
            }
            function classifyJSDocComment(docComment) {
                var _a2, _b, _c, _d, _e, _f, _g, _h;
                let pos = docComment.pos;
                if (docComment.tags) {
                    for (const tag of docComment.tags) {
                        if (tag.pos !== pos) {
                            pushCommentRange(pos, tag.pos - pos);
                        }
                        pushClassification(tag.pos, 1, 10 /* punctuation */);
                        pushClassification(tag.tagName.pos, tag.tagName.end - tag.tagName.pos, 18 /* docCommentTagName */);
                        pos = tag.tagName.end;
                        let commentStart = tag.tagName.end;
                        switch (tag.kind) {
                            case 344 /* JSDocParameterTag */:
                                const param = tag;
                                processJSDocParameterTag(param);
                                commentStart = param.isNameFirst && ((_a2 = param.typeExpression) == null ? void 0 : _a2.end) || param.name.end;
                                break;
                            case 351 /* JSDocPropertyTag */:
                                const prop = tag;
                                commentStart = prop.isNameFirst && ((_b = prop.typeExpression) == null ? void 0 : _b.end) || prop.name.end;
                                break;
                            case 348 /* JSDocTemplateTag */:
                                processJSDocTemplateTag(tag);
                                pos = tag.end;
                                commentStart = tag.typeParameters.end;
                                break;
                            case 349 /* JSDocTypedefTag */:
                                const type = tag;
                                commentStart = ((_c = type.typeExpression) == null ? void 0 : _c.kind) === 312 /* JSDocTypeExpression */ && ((_d = type.fullName) == null ? void 0 : _d.end) || ((_e = type.typeExpression) == null ? void 0 : _e.end) || commentStart;
                                break;
                            case 341 /* JSDocCallbackTag */:
                                commentStart = tag.typeExpression.end;
                                break;
                            case 347 /* JSDocTypeTag */:
                                processElement(tag.typeExpression);
                                pos = tag.end;
                                commentStart = tag.typeExpression.end;
                                break;
                            case 346 /* JSDocThisTag */:
                            case 343 /* JSDocEnumTag */:
                                commentStart = tag.typeExpression.end;
                                break;
                            case 345 /* JSDocReturnTag */:
                                processElement(tag.typeExpression);
                                pos = tag.end;
                                commentStart = ((_f = tag.typeExpression) == null ? void 0 : _f.end) || commentStart;
                                break;
                            case 350 /* JSDocSeeTag */:
                                commentStart = ((_g = tag.name) == null ? void 0 : _g.end) || commentStart;
                                break;
                            case 331 /* JSDocAugmentsTag */:
                            case 332 /* JSDocImplementsTag */:
                                commentStart = tag.class.end;
                                break;
                            case 352 /* JSDocThrowsTag */:
                                processElement(tag.typeExpression);
                                pos = tag.end;
                                commentStart = ((_h = tag.typeExpression) == null ? void 0 : _h.end) || commentStart;
                                break;
                        }
                        if (typeof tag.comment === "object") {
                            pushCommentRange(tag.comment.pos, tag.comment.end - tag.comment.pos);
                        }
                        else if (typeof tag.comment === "string") {
                            pushCommentRange(commentStart, tag.end - commentStart);
                        }
                    }
                }
                if (pos !== docComment.end) {
                    pushCommentRange(pos, docComment.end - pos);
                }
                return;
                function processJSDocParameterTag(tag) {
                    if (tag.isNameFirst) {
                        pushCommentRange(pos, tag.name.pos - pos);
                        pushClassification(tag.name.pos, tag.name.end - tag.name.pos, 17 /* parameterName */);
                        pos = tag.name.end;
                    }
                    if (tag.typeExpression) {
                        pushCommentRange(pos, tag.typeExpression.pos - pos);
                        processElement(tag.typeExpression);
                        pos = tag.typeExpression.end;
                    }
                    if (!tag.isNameFirst) {
                        pushCommentRange(pos, tag.name.pos - pos);
                        pushClassification(tag.name.pos, tag.name.end - tag.name.pos, 17 /* parameterName */);
                        pos = tag.name.end;
                    }
                }
            }
            function tryClassifyTripleSlashComment(start, width) {
                const tripleSlashXMLCommentRegEx = /^(\/\/\/\s*)(<)(?:(\S+)((?:[^/]|\/[^>])*)(\/>)?)?/im;
                const attributeRegex = /(\s)(\S+)(\s*)(=)(\s*)('[^']+'|"[^"]+")/img;
                const text = sourceFile.text.substr(start, width);
                const match = tripleSlashXMLCommentRegEx.exec(text);
                if (!match) {
                    return false;
                }
                if (!match[3] || !(match[3] in commentPragmas)) {
                    return false;
                }
                let pos = start;
                pushCommentRange(pos, match[1].length);
                pos += match[1].length;
                pushClassification(pos, match[2].length, 10 /* punctuation */);
                pos += match[2].length;
                pushClassification(pos, match[3].length, 21 /* jsxSelfClosingTagName */);
                pos += match[3].length;
                const attrText = match[4];
                let attrPos = pos;
                while (true) {
                    const attrMatch = attributeRegex.exec(attrText);
                    if (!attrMatch) {
                        break;
                    }
                    const newAttrPos = pos + attrMatch.index + attrMatch[1].length;
                    if (newAttrPos > attrPos) {
                        pushCommentRange(attrPos, newAttrPos - attrPos);
                        attrPos = newAttrPos;
                    }
                    pushClassification(attrPos, attrMatch[2].length, 22 /* jsxAttribute */);
                    attrPos += attrMatch[2].length;
                    if (attrMatch[3].length) {
                        pushCommentRange(attrPos, attrMatch[3].length);
                        attrPos += attrMatch[3].length;
                    }
                    pushClassification(attrPos, attrMatch[4].length, 5 /* operator */);
                    attrPos += attrMatch[4].length;
                    if (attrMatch[5].length) {
                        pushCommentRange(attrPos, attrMatch[5].length);
                        attrPos += attrMatch[5].length;
                    }
                    pushClassification(attrPos, attrMatch[6].length, 24 /* jsxAttributeStringLiteralValue */);
                    attrPos += attrMatch[6].length;
                }
                pos += match[4].length;
                if (pos > attrPos) {
                    pushCommentRange(attrPos, pos - attrPos);
                }
                if (match[5]) {
                    pushClassification(pos, match[5].length, 10 /* punctuation */);
                    pos += match[5].length;
                }
                const end = start + width;
                if (pos < end) {
                    pushCommentRange(pos, end - pos);
                }
                return true;
            }
            function processJSDocTemplateTag(tag) {
                for (const child of tag.getChildren()) {
                    processElement(child);
                }
            }
            function classifyDisabledMergeCode(text, start, end) {
                let i;
                for (i = start; i < end; i++) {
                    if (isLineBreak(text.charCodeAt(i))) {
                        break;
                    }
                }
                pushClassification(start, i - start, 1 /* comment */);
                mergeConflictScanner.setTextPos(i);
                while (mergeConflictScanner.getTextPos() < end) {
                    classifyDisabledCodeToken();
                }
            }
            function classifyDisabledCodeToken() {
                const start = mergeConflictScanner.getTextPos();
                const tokenKind = mergeConflictScanner.scan();
                const end = mergeConflictScanner.getTextPos();
                const type = classifyTokenType(tokenKind);
                if (type) {
                    pushClassification(start, end - start, type);
                }
            }
            function tryClassifyNode(node) {
                if (isJSDoc(node)) {
                    return true;
                }
                if (nodeIsMissing(node)) {
                    return true;
                }
                const classifiedElementName = tryClassifyJsxElementName(node);
                if (!isToken(node) && node.kind !== 11 /* JsxText */ && classifiedElementName === void 0) {
                    return false;
                }
                const tokenStart = node.kind === 11 /* JsxText */ ? node.pos : classifyLeadingTriviaAndGetTokenStart(node);
                const tokenWidth = node.end - tokenStart;
                Debug.assert(tokenWidth >= 0);
                if (tokenWidth > 0) {
                    const type = classifiedElementName || classifyTokenType(node.kind, node);
                    if (type) {
                        pushClassification(tokenStart, tokenWidth, type);
                    }
                }
                return true;
            }
            function tryClassifyJsxElementName(token) {
                switch (token.parent && token.parent.kind) {
                    case 283 /* JsxOpeningElement */:
                        if (token.parent.tagName === token) {
                            return 19 /* jsxOpenTagName */;
                        }
                        break;
                    case 284 /* JsxClosingElement */:
                        if (token.parent.tagName === token) {
                            return 20 /* jsxCloseTagName */;
                        }
                        break;
                    case 282 /* JsxSelfClosingElement */:
                        if (token.parent.tagName === token) {
                            return 21 /* jsxSelfClosingTagName */;
                        }
                        break;
                    case 288 /* JsxAttribute */:
                        if (token.parent.name === token) {
                            return 22 /* jsxAttribute */;
                        }
                        break;
                }
                return void 0;
            }
            function classifyTokenType(tokenKind, token) {
                if (isKeyword(tokenKind)) {
                    return 3 /* keyword */;
                }
                if (tokenKind === 29 /* LessThanToken */ || tokenKind === 31 /* GreaterThanToken */) {
                    if (token && getTypeArgumentOrTypeParameterList(token.parent)) {
                        return 10 /* punctuation */;
                    }
                }
                if (isPunctuation(tokenKind)) {
                    if (token) {
                        const parent2 = token.parent;
                        if (tokenKind === 63 /* EqualsToken */) {
                            if (parent2.kind === 257 /* VariableDeclaration */ || parent2.kind === 169 /* PropertyDeclaration */ || parent2.kind === 166 /* Parameter */ || parent2.kind === 288 /* JsxAttribute */) {
                                return 5 /* operator */;
                            }
                        }
                        if (parent2.kind === 223 /* BinaryExpression */ || parent2.kind === 221 /* PrefixUnaryExpression */ || parent2.kind === 222 /* PostfixUnaryExpression */ || parent2.kind === 224 /* ConditionalExpression */) {
                            return 5 /* operator */;
                        }
                    }
                    return 10 /* punctuation */;
                }
                else if (tokenKind === 8 /* NumericLiteral */) {
                    return 4 /* numericLiteral */;
                }
                else if (tokenKind === 9 /* BigIntLiteral */) {
                    return 25 /* bigintLiteral */;
                }
                else if (tokenKind === 10 /* StringLiteral */) {
                    return token && token.parent.kind === 288 /* JsxAttribute */ ? 24 /* jsxAttributeStringLiteralValue */ : 6 /* stringLiteral */;
                }
                else if (tokenKind === 13 /* RegularExpressionLiteral */) {
                    return 6 /* stringLiteral */;
                }
                else if (isTemplateLiteralKind(tokenKind)) {
                    return 6 /* stringLiteral */;
                }
                else if (tokenKind === 11 /* JsxText */) {
                    return 23 /* jsxText */;
                }
                else if (tokenKind === 79 /* Identifier */) {
                    if (token) {
                        switch (token.parent.kind) {
                            case 260 /* ClassDeclaration */:
                                if (token.parent.name === token) {
                                    return 11 /* className */;
                                }
                                return;
                            case 165 /* TypeParameter */:
                                if (token.parent.name === token) {
                                    return 15 /* typeParameterName */;
                                }
                                return;
                            case 261 /* InterfaceDeclaration */:
                                if (token.parent.name === token) {
                                    return 13 /* interfaceName */;
                                }
                                return;
                            case 263 /* EnumDeclaration */:
                                if (token.parent.name === token) {
                                    return 12 /* enumName */;
                                }
                                return;
                            case 264 /* ModuleDeclaration */:
                                if (token.parent.name === token) {
                                    return 14 /* moduleName */;
                                }
                                return;
                            case 166 /* Parameter */:
                                if (token.parent.name === token) {
                                    return isThisIdentifier(token) ? 3 /* keyword */ : 17 /* parameterName */;
                                }
                                return;
                        }
                        if (isConstTypeReference(token.parent)) {
                            return 3 /* keyword */;
                        }
                    }
                    return 2 /* identifier */;
                }
            }
            function processElement(element) {
                if (!element) {
                    return;
                }
                if (decodedTextSpanIntersectsWith(spanStart, spanLength, element.pos, element.getFullWidth())) {
                    checkForClassificationCancellation(cancellationToken, element.kind);
                    for (const child of element.getChildren(sourceFile)) {
                        if (!tryClassifyNode(child)) {
                            processElement(child);
                        }
                    }
                }
            }
        }
        var noRegexTable;
        var init_classifier = __esm({
            "src/services/classifier.ts"() {
                "use strict";
                init_ts4();
                noRegexTable = arrayToNumericMap([
                    79 /* Identifier */,
                    10 /* StringLiteral */,
                    8 /* NumericLiteral */,
                    9 /* BigIntLiteral */,
                    13 /* RegularExpressionLiteral */,
                    108 /* ThisKeyword */,
                    45 /* PlusPlusToken */,
                    46 /* MinusMinusToken */,
                    21 /* CloseParenToken */,
                    23 /* CloseBracketToken */,
                    19 /* CloseBraceToken */,
                    110 /* TrueKeyword */,
                    95 /* FalseKeyword */
                ], (token) => token, () => true);
            }
        });
        // src/services/documentHighlights.ts
        var DocumentHighlights;
        var init_documentHighlights = __esm({
            "src/services/documentHighlights.ts"() {
                "use strict";
                init_ts4();
                ((DocumentHighlights2) => {
                    function getDocumentHighlights(program, cancellationToken, sourceFile, position, sourceFilesToSearch) {
                        const node = getTouchingPropertyName(sourceFile, position);
                        if (node.parent && (isJsxOpeningElement(node.parent) && node.parent.tagName === node || isJsxClosingElement(node.parent))) {
                            const { openingElement, closingElement } = node.parent.parent;
                            const highlightSpans = [openingElement, closingElement].map(({ tagName }) => getHighlightSpanForNode(tagName, sourceFile));
                            return [{ fileName: sourceFile.fileName, highlightSpans }];
                        }
                        return getSemanticDocumentHighlights(position, node, program, cancellationToken, sourceFilesToSearch) || getSyntacticDocumentHighlights(node, sourceFile);
                    }
                    DocumentHighlights2.getDocumentHighlights = getDocumentHighlights;
                    function getHighlightSpanForNode(node, sourceFile) {
                        return {
                            fileName: sourceFile.fileName,
                            textSpan: createTextSpanFromNode(node, sourceFile),
                            kind: "none" /* none */
                        };
                    }
                    function getSemanticDocumentHighlights(position, node, program, cancellationToken, sourceFilesToSearch) {
                        const sourceFilesSet = new Set(sourceFilesToSearch.map((f) => f.fileName));
                        const referenceEntries = ts_FindAllReferences_exports.getReferenceEntriesForNode(position, node, program, sourceFilesToSearch, cancellationToken, 
                        /*options*/
                        void 0, sourceFilesSet);
                        if (!referenceEntries)
                            return void 0;
                        const map2 = arrayToMultiMap(referenceEntries.map(ts_FindAllReferences_exports.toHighlightSpan), (e) => e.fileName, (e) => e.span);
                        const getCanonicalFileName = createGetCanonicalFileName(program.useCaseSensitiveFileNames());
                        return arrayFrom(mapDefinedIterator(map2.entries(), ([fileName, highlightSpans]) => {
                            if (!sourceFilesSet.has(fileName)) {
                                if (!program.redirectTargetsMap.has(toPath(fileName, program.getCurrentDirectory(), getCanonicalFileName))) {
                                    return void 0;
                                }
                                const redirectTarget = program.getSourceFile(fileName);
                                const redirect = find(sourceFilesToSearch, (f) => !!f.redirectInfo && f.redirectInfo.redirectTarget === redirectTarget);
                                fileName = redirect.fileName;
                                Debug.assert(sourceFilesSet.has(fileName));
                            }
                            return { fileName, highlightSpans };
                        }));
                    }
                    function getSyntacticDocumentHighlights(node, sourceFile) {
                        const highlightSpans = getHighlightSpans(node, sourceFile);
                        return highlightSpans && [{ fileName: sourceFile.fileName, highlightSpans }];
                    }
                    function getHighlightSpans(node, sourceFile) {
                        switch (node.kind) {
                            case 99 /* IfKeyword */:
                            case 91 /* ElseKeyword */:
                                return isIfStatement(node.parent) ? getIfElseOccurrences(node.parent, sourceFile) : void 0;
                            case 105 /* ReturnKeyword */:
                                return useParent(node.parent, isReturnStatement, getReturnOccurrences);
                            case 109 /* ThrowKeyword */:
                                return useParent(node.parent, isThrowStatement, getThrowOccurrences);
                            case 111 /* TryKeyword */:
                            case 83 /* CatchKeyword */:
                            case 96 /* FinallyKeyword */:
                                const tryStatement = node.kind === 83 /* CatchKeyword */ ? node.parent.parent : node.parent;
                                return useParent(tryStatement, isTryStatement, getTryCatchFinallyOccurrences);
                            case 107 /* SwitchKeyword */:
                                return useParent(node.parent, isSwitchStatement, getSwitchCaseDefaultOccurrences);
                            case 82 /* CaseKeyword */:
                            case 88 /* DefaultKeyword */: {
                                if (isDefaultClause(node.parent) || isCaseClause(node.parent)) {
                                    return useParent(node.parent.parent.parent, isSwitchStatement, getSwitchCaseDefaultOccurrences);
                                }
                                return void 0;
                            }
                            case 81 /* BreakKeyword */:
                            case 86 /* ContinueKeyword */:
                                return useParent(node.parent, isBreakOrContinueStatement, getBreakOrContinueStatementOccurrences);
                            case 97 /* ForKeyword */:
                            case 115 /* WhileKeyword */:
                            case 90 /* DoKeyword */:
                                return useParent(node.parent, (n) => isIterationStatement(n, 
                                /*lookInLabeledStatements*/
                                true), getLoopBreakContinueOccurrences);
                            case 135 /* ConstructorKeyword */:
                                return getFromAllDeclarations(isConstructorDeclaration, [135 /* ConstructorKeyword */]);
                            case 137 /* GetKeyword */:
                            case 151 /* SetKeyword */:
                                return getFromAllDeclarations(isAccessor, [137 /* GetKeyword */, 151 /* SetKeyword */]);
                            case 133 /* AwaitKeyword */:
                                return useParent(node.parent, isAwaitExpression, getAsyncAndAwaitOccurrences);
                            case 132 /* AsyncKeyword */:
                                return highlightSpans(getAsyncAndAwaitOccurrences(node));
                            case 125 /* YieldKeyword */:
                                return highlightSpans(getYieldOccurrences(node));
                            case 101 /* InKeyword */:
                                return void 0;
                            default:
                                return isModifierKind(node.kind) && (isDeclaration(node.parent) || isVariableStatement(node.parent)) ? highlightSpans(getModifierOccurrences(node.kind, node.parent)) : void 0;
                        }
                        function getFromAllDeclarations(nodeTest, keywords) {
                            return useParent(node.parent, nodeTest, (decl) => {
                                var _a2;
                                return mapDefined((_a2 = tryCast(decl, canHaveSymbol)) == null ? void 0 : _a2.symbol.declarations, (d) => nodeTest(d) ? find(d.getChildren(sourceFile), (c) => contains(keywords, c.kind)) : void 0);
                            });
                        }
                        function useParent(node2, nodeTest, getNodes4) {
                            return nodeTest(node2) ? highlightSpans(getNodes4(node2, sourceFile)) : void 0;
                        }
                        function highlightSpans(nodes) {
                            return nodes && nodes.map((node2) => getHighlightSpanForNode(node2, sourceFile));
                        }
                    }
                    function aggregateOwnedThrowStatements(node) {
                        if (isThrowStatement(node)) {
                            return [node];
                        }
                        else if (isTryStatement(node)) {
                            return concatenate(node.catchClause ? aggregateOwnedThrowStatements(node.catchClause) : node.tryBlock && aggregateOwnedThrowStatements(node.tryBlock), node.finallyBlock && aggregateOwnedThrowStatements(node.finallyBlock));
                        }
                        return isFunctionLike(node) ? void 0 : flatMapChildren(node, aggregateOwnedThrowStatements);
                    }
                    function getThrowStatementOwner(throwStatement) {
                        let child = throwStatement;
                        while (child.parent) {
                            const parent2 = child.parent;
                            if (isFunctionBlock(parent2) || parent2.kind === 308 /* SourceFile */) {
                                return parent2;
                            }
                            if (isTryStatement(parent2) && parent2.tryBlock === child && parent2.catchClause) {
                                return child;
                            }
                            child = parent2;
                        }
                        return void 0;
                    }
                    function aggregateAllBreakAndContinueStatements(node) {
                        return isBreakOrContinueStatement(node) ? [node] : isFunctionLike(node) ? void 0 : flatMapChildren(node, aggregateAllBreakAndContinueStatements);
                    }
                    function flatMapChildren(node, cb) {
                        const result = [];
                        node.forEachChild((child) => {
                            const value = cb(child);
                            if (value !== void 0) {
                                result.push(...toArray(value));
                            }
                        });
                        return result;
                    }
                    function ownsBreakOrContinueStatement(owner, statement) {
                        const actualOwner = getBreakOrContinueOwner(statement);
                        return !!actualOwner && actualOwner === owner;
                    }
                    function getBreakOrContinueOwner(statement) {
                        return findAncestor(statement, (node) => {
                            switch (node.kind) {
                                case 252 /* SwitchStatement */:
                                    if (statement.kind === 248 /* ContinueStatement */) {
                                        return false;
                                    }
                                case 245 /* ForStatement */:
                                case 246 /* ForInStatement */:
                                case 247 /* ForOfStatement */:
                                case 244 /* WhileStatement */:
                                case 243 /* DoStatement */:
                                    return !statement.label || isLabeledBy(node, statement.label.escapedText);
                                default:
                                    return isFunctionLike(node) && "quit";
                            }
                        });
                    }
                    function getModifierOccurrences(modifier, declaration) {
                        return mapDefined(getNodesToSearchForModifier(declaration, modifierToFlag(modifier)), (node) => findModifier(node, modifier));
                    }
                    function getNodesToSearchForModifier(declaration, modifierFlag) {
                        const container = declaration.parent;
                        switch (container.kind) {
                            case 265 /* ModuleBlock */:
                            case 308 /* SourceFile */:
                            case 238 /* Block */:
                            case 292 /* CaseClause */:
                            case 293 /* DefaultClause */:
                                if (modifierFlag & 256 /* Abstract */ && isClassDeclaration(declaration)) {
                                    return [...declaration.members, declaration];
                                }
                                else {
                                    return container.statements;
                                }
                            case 173 /* Constructor */:
                            case 171 /* MethodDeclaration */:
                            case 259 /* FunctionDeclaration */:
                                return [...container.parameters, ...isClassLike(container.parent) ? container.parent.members : []];
                            case 260 /* ClassDeclaration */:
                            case 228 /* ClassExpression */:
                            case 261 /* InterfaceDeclaration */:
                            case 184 /* TypeLiteral */:
                                const nodes = container.members;
                                if (modifierFlag & (28 /* AccessibilityModifier */ | 64 /* Readonly */)) {
                                    const constructor = find(container.members, isConstructorDeclaration);
                                    if (constructor) {
                                        return [...nodes, ...constructor.parameters];
                                    }
                                }
                                else if (modifierFlag & 256 /* Abstract */) {
                                    return [...nodes, container];
                                }
                                return nodes;
                            case 207 /* ObjectLiteralExpression */:
                                return void 0;
                            default:
                                Debug.assertNever(container, "Invalid container kind.");
                        }
                    }
                    function pushKeywordIf(keywordList, token, ...expected) {
                        if (token && contains(expected, token.kind)) {
                            keywordList.push(token);
                            return true;
                        }
                        return false;
                    }
                    function getLoopBreakContinueOccurrences(loopNode) {
                        const keywords = [];
                        if (pushKeywordIf(keywords, loopNode.getFirstToken(), 97 /* ForKeyword */, 115 /* WhileKeyword */, 90 /* DoKeyword */)) {
                            if (loopNode.kind === 243 /* DoStatement */) {
                                const loopTokens = loopNode.getChildren();
                                for (let i = loopTokens.length - 1; i >= 0; i--) {
                                    if (pushKeywordIf(keywords, loopTokens[i], 115 /* WhileKeyword */)) {
                                        break;
                                    }
                                }
                            }
                        }
                        forEach(aggregateAllBreakAndContinueStatements(loopNode.statement), (statement) => {
                            if (ownsBreakOrContinueStatement(loopNode, statement)) {
                                pushKeywordIf(keywords, statement.getFirstToken(), 81 /* BreakKeyword */, 86 /* ContinueKeyword */);
                            }
                        });
                        return keywords;
                    }
                    function getBreakOrContinueStatementOccurrences(breakOrContinueStatement) {
                        const owner = getBreakOrContinueOwner(breakOrContinueStatement);
                        if (owner) {
                            switch (owner.kind) {
                                case 245 /* ForStatement */:
                                case 246 /* ForInStatement */:
                                case 247 /* ForOfStatement */:
                                case 243 /* DoStatement */:
                                case 244 /* WhileStatement */:
                                    return getLoopBreakContinueOccurrences(owner);
                                case 252 /* SwitchStatement */:
                                    return getSwitchCaseDefaultOccurrences(owner);
                            }
                        }
                        return void 0;
                    }
                    function getSwitchCaseDefaultOccurrences(switchStatement) {
                        const keywords = [];
                        pushKeywordIf(keywords, switchStatement.getFirstToken(), 107 /* SwitchKeyword */);
                        forEach(switchStatement.caseBlock.clauses, (clause) => {
                            pushKeywordIf(keywords, clause.getFirstToken(), 82 /* CaseKeyword */, 88 /* DefaultKeyword */);
                            forEach(aggregateAllBreakAndContinueStatements(clause), (statement) => {
                                if (ownsBreakOrContinueStatement(switchStatement, statement)) {
                                    pushKeywordIf(keywords, statement.getFirstToken(), 81 /* BreakKeyword */);
                                }
                            });
                        });
                        return keywords;
                    }
                    function getTryCatchFinallyOccurrences(tryStatement, sourceFile) {
                        const keywords = [];
                        pushKeywordIf(keywords, tryStatement.getFirstToken(), 111 /* TryKeyword */);
                        if (tryStatement.catchClause) {
                            pushKeywordIf(keywords, tryStatement.catchClause.getFirstToken(), 83 /* CatchKeyword */);
                        }
                        if (tryStatement.finallyBlock) {
                            const finallyKeyword = findChildOfKind(tryStatement, 96 /* FinallyKeyword */, sourceFile);
                            pushKeywordIf(keywords, finallyKeyword, 96 /* FinallyKeyword */);
                        }
                        return keywords;
                    }
                    function getThrowOccurrences(throwStatement, sourceFile) {
                        const owner = getThrowStatementOwner(throwStatement);
                        if (!owner) {
                            return void 0;
                        }
                        const keywords = [];
                        forEach(aggregateOwnedThrowStatements(owner), (throwStatement2) => {
                            keywords.push(findChildOfKind(throwStatement2, 109 /* ThrowKeyword */, sourceFile));
                        });
                        if (isFunctionBlock(owner)) {
                            forEachReturnStatement(owner, (returnStatement) => {
                                keywords.push(findChildOfKind(returnStatement, 105 /* ReturnKeyword */, sourceFile));
                            });
                        }
                        return keywords;
                    }
                    function getReturnOccurrences(returnStatement, sourceFile) {
                        const func = getContainingFunction(returnStatement);
                        if (!func) {
                            return void 0;
                        }
                        const keywords = [];
                        forEachReturnStatement(cast(func.body, isBlock), (returnStatement2) => {
                            keywords.push(findChildOfKind(returnStatement2, 105 /* ReturnKeyword */, sourceFile));
                        });
                        forEach(aggregateOwnedThrowStatements(func.body), (throwStatement) => {
                            keywords.push(findChildOfKind(throwStatement, 109 /* ThrowKeyword */, sourceFile));
                        });
                        return keywords;
                    }
                    function getAsyncAndAwaitOccurrences(node) {
                        const func = getContainingFunction(node);
                        if (!func) {
                            return void 0;
                        }
                        const keywords = [];
                        if (func.modifiers) {
                            func.modifiers.forEach((modifier) => {
                                pushKeywordIf(keywords, modifier, 132 /* AsyncKeyword */);
                            });
                        }
                        forEachChild(func, (child) => {
                            traverseWithoutCrossingFunction(child, (node2) => {
                                if (isAwaitExpression(node2)) {
                                    pushKeywordIf(keywords, node2.getFirstToken(), 133 /* AwaitKeyword */);
                                }
                            });
                        });
                        return keywords;
                    }
                    function getYieldOccurrences(node) {
                        const func = getContainingFunction(node);
                        if (!func) {
                            return void 0;
                        }
                        const keywords = [];
                        forEachChild(func, (child) => {
                            traverseWithoutCrossingFunction(child, (node2) => {
                                if (isYieldExpression(node2)) {
                                    pushKeywordIf(keywords, node2.getFirstToken(), 125 /* YieldKeyword */);
                                }
                            });
                        });
                        return keywords;
                    }
                    function traverseWithoutCrossingFunction(node, cb) {
                        cb(node);
                        if (!isFunctionLike(node) && !isClassLike(node) && !isInterfaceDeclaration(node) && !isModuleDeclaration(node) && !isTypeAliasDeclaration(node) && !isTypeNode(node)) {
                            forEachChild(node, (child) => traverseWithoutCrossingFunction(child, cb));
                        }
                    }
                    function getIfElseOccurrences(ifStatement, sourceFile) {
                        const keywords = getIfElseKeywords(ifStatement, sourceFile);
                        const result = [];
                        for (let i = 0; i < keywords.length; i++) {
                            if (keywords[i].kind === 91 /* ElseKeyword */ && i < keywords.length - 1) {
                                const elseKeyword = keywords[i];
                                const ifKeyword = keywords[i + 1];
                                let shouldCombineElseAndIf = true;
                                for (let j = ifKeyword.getStart(sourceFile) - 1; j >= elseKeyword.end; j--) {
                                    if (!isWhiteSpaceSingleLine(sourceFile.text.charCodeAt(j))) {
                                        shouldCombineElseAndIf = false;
                                        break;
                                    }
                                }
                                if (shouldCombineElseAndIf) {
                                    result.push({
                                        fileName: sourceFile.fileName,
                                        textSpan: createTextSpanFromBounds(elseKeyword.getStart(), ifKeyword.end),
                                        kind: "reference" /* reference */
                                    });
                                    i++;
                                    continue;
                                }
                            }
                            result.push(getHighlightSpanForNode(keywords[i], sourceFile));
                        }
                        return result;
                    }
                    function getIfElseKeywords(ifStatement, sourceFile) {
                        const keywords = [];
                        while (isIfStatement(ifStatement.parent) && ifStatement.parent.elseStatement === ifStatement) {
                            ifStatement = ifStatement.parent;
                        }
                        while (true) {
                            const children = ifStatement.getChildren(sourceFile);
                            pushKeywordIf(keywords, children[0], 99 /* IfKeyword */);
                            for (let i = children.length - 1; i >= 0; i--) {
                                if (pushKeywordIf(keywords, children[i], 91 /* ElseKeyword */)) {
                                    break;
                                }
                            }
                            if (!ifStatement.elseStatement || !isIfStatement(ifStatement.elseStatement)) {
                                break;
                            }
                            ifStatement = ifStatement.elseStatement;
                        }
                        return keywords;
                    }
                    function isLabeledBy(node, labelName) {
                        return !!findAncestor(node.parent, (owner) => !isLabeledStatement(owner) ? "quit" : owner.label.escapedText === labelName);
                    }
                })(DocumentHighlights || (DocumentHighlights = {}));
            }
        });
        // src/services/documentRegistry.ts
        function isDocumentRegistryEntry(entry) {
            return !!entry.sourceFile;
        }
        function createDocumentRegistry(useCaseSensitiveFileNames, currentDirectory) {
            return createDocumentRegistryInternal(useCaseSensitiveFileNames, currentDirectory);
        }
        function createDocumentRegistryInternal(useCaseSensitiveFileNames, currentDirectory = "", externalCache) {
            const buckets = /* @__PURE__ */ new Map();
            const getCanonicalFileName = createGetCanonicalFileName(!!useCaseSensitiveFileNames);
            function reportStats() {
                const bucketInfoArray = arrayFrom(buckets.keys()).filter((name) => name && name.charAt(0) === "_").map((name) => {
                    const entries = buckets.get(name);
                    const sourceFiles = [];
                    entries.forEach((entry, name2) => {
                        if (isDocumentRegistryEntry(entry)) {
                            sourceFiles.push({
                                name: name2,
                                scriptKind: entry.sourceFile.scriptKind,
                                refCount: entry.languageServiceRefCount
                            });
                        }
                        else {
                            entry.forEach((value, scriptKind) => sourceFiles.push({ name: name2, scriptKind, refCount: value.languageServiceRefCount }));
                        }
                    });
                    sourceFiles.sort((x, y) => y.refCount - x.refCount);
                    return {
                        bucket: name,
                        sourceFiles
                    };
                });
                return JSON.stringify(bucketInfoArray, void 0, 2);
            }
            function getCompilationSettings(settingsOrHost) {
                if (typeof settingsOrHost.getCompilationSettings === "function") {
                    return settingsOrHost.getCompilationSettings();
                }
                return settingsOrHost;
            }
            function acquireDocument(fileName, compilationSettings, scriptSnapshot, version2, scriptKind, languageVersionOrOptions) {
                const path = toPath(fileName, currentDirectory, getCanonicalFileName);
                const key = getKeyForCompilationSettings(getCompilationSettings(compilationSettings));
                return acquireDocumentWithKey(fileName, path, compilationSettings, key, scriptSnapshot, version2, scriptKind, languageVersionOrOptions);
            }
            function acquireDocumentWithKey(fileName, path, compilationSettings, key, scriptSnapshot, version2, scriptKind, languageVersionOrOptions) {
                return acquireOrUpdateDocument(fileName, path, compilationSettings, key, scriptSnapshot, version2, 
                /*acquiring*/
                true, scriptKind, languageVersionOrOptions);
            }
            function updateDocument(fileName, compilationSettings, scriptSnapshot, version2, scriptKind, languageVersionOrOptions) {
                const path = toPath(fileName, currentDirectory, getCanonicalFileName);
                const key = getKeyForCompilationSettings(getCompilationSettings(compilationSettings));
                return updateDocumentWithKey(fileName, path, compilationSettings, key, scriptSnapshot, version2, scriptKind, languageVersionOrOptions);
            }
            function updateDocumentWithKey(fileName, path, compilationSettings, key, scriptSnapshot, version2, scriptKind, languageVersionOrOptions) {
                return acquireOrUpdateDocument(fileName, path, getCompilationSettings(compilationSettings), key, scriptSnapshot, version2, 
                /*acquiring*/
                false, scriptKind, languageVersionOrOptions);
            }
            function getDocumentRegistryEntry(bucketEntry, scriptKind) {
                const entry = isDocumentRegistryEntry(bucketEntry) ? bucketEntry : bucketEntry.get(Debug.checkDefined(scriptKind, "If there are more than one scriptKind's for same document the scriptKind should be provided"));
                Debug.assert(scriptKind === void 0 || !entry || entry.sourceFile.scriptKind === scriptKind, `Script kind should match provided ScriptKind:${scriptKind} and sourceFile.scriptKind: ${entry == null ? void 0 : entry.sourceFile.scriptKind}, !entry: ${!entry}`);
                return entry;
            }
            function acquireOrUpdateDocument(fileName, path, compilationSettingsOrHost, key, scriptSnapshot, version2, acquiring, scriptKind, languageVersionOrOptions) {
                var _a2, _b, _c, _d;
                scriptKind = ensureScriptKind(fileName, scriptKind);
                const compilationSettings = getCompilationSettings(compilationSettingsOrHost);
                const host = compilationSettingsOrHost === compilationSettings ? void 0 : compilationSettingsOrHost;
                const scriptTarget = scriptKind === 6 /* JSON */ ? 100 /* JSON */ : getEmitScriptTarget(compilationSettings);
                const sourceFileOptions = typeof languageVersionOrOptions === "object" ? languageVersionOrOptions : {
                    languageVersion: scriptTarget,
                    impliedNodeFormat: host && getImpliedNodeFormatForFile(path, (_d = (_c = (_b = (_a2 = host.getCompilerHost) == null ? void 0 : _a2.call(host)) == null ? void 0 : _b.getModuleResolutionCache) == null ? void 0 : _c.call(_b)) == null ? void 0 : _d.getPackageJsonInfoCache(), host, compilationSettings),
                    setExternalModuleIndicator: getSetExternalModuleIndicator(compilationSettings)
                };
                sourceFileOptions.languageVersion = scriptTarget;
                const oldBucketCount = buckets.size;
                const keyWithMode = getDocumentRegistryBucketKeyWithMode(key, sourceFileOptions.impliedNodeFormat);
                const bucket = getOrUpdate(buckets, keyWithMode, () => /* @__PURE__ */ new Map());
                if (tracing) {
                    if (buckets.size > oldBucketCount) {
                        tracing.instant(tracing.Phase.Session, "createdDocumentRegistryBucket", { configFilePath: compilationSettings.configFilePath, key: keyWithMode });
                    }
                    const otherBucketKey = !isDeclarationFileName(path) && forEachEntry(buckets, (bucket2, bucketKey) => bucketKey !== keyWithMode && bucket2.has(path) && bucketKey);
                    if (otherBucketKey) {
                        tracing.instant(tracing.Phase.Session, "documentRegistryBucketOverlap", { path, key1: otherBucketKey, key2: keyWithMode });
                    }
                }
                const bucketEntry = bucket.get(path);
                let entry = bucketEntry && getDocumentRegistryEntry(bucketEntry, scriptKind);
                if (!entry && externalCache) {
                    const sourceFile = externalCache.getDocument(keyWithMode, path);
                    if (sourceFile) {
                        Debug.assert(acquiring);
                        entry = {
                            sourceFile,
                            languageServiceRefCount: 0
                        };
                        setBucketEntry();
                    }
                }
                if (!entry) {
                    const sourceFile = createLanguageServiceSourceFile(fileName, scriptSnapshot, sourceFileOptions, version2, 
                    /*setNodeParents*/
                    false, scriptKind);
                    if (externalCache) {
                        externalCache.setDocument(keyWithMode, path, sourceFile);
                    }
                    entry = {
                        sourceFile,
                        languageServiceRefCount: 1
                    };
                    setBucketEntry();
                }
                else {
                    if (entry.sourceFile.version !== version2) {
                        entry.sourceFile = updateLanguageServiceSourceFile(entry.sourceFile, scriptSnapshot, version2, scriptSnapshot.getChangeRange(entry.sourceFile.scriptSnapshot));
                        if (externalCache) {
                            externalCache.setDocument(keyWithMode, path, entry.sourceFile);
                        }
                    }
                    if (acquiring) {
                        entry.languageServiceRefCount++;
                    }
                }
                Debug.assert(entry.languageServiceRefCount !== 0);
                return entry.sourceFile;
                function setBucketEntry() {
                    if (!bucketEntry) {
                        bucket.set(path, entry);
                    }
                    else if (isDocumentRegistryEntry(bucketEntry)) {
                        const scriptKindMap = /* @__PURE__ */ new Map();
                        scriptKindMap.set(bucketEntry.sourceFile.scriptKind, bucketEntry);
                        scriptKindMap.set(scriptKind, entry);
                        bucket.set(path, scriptKindMap);
                    }
                    else {
                        bucketEntry.set(scriptKind, entry);
                    }
                }
            }
            function releaseDocument(fileName, compilationSettings, scriptKind, impliedNodeFormat) {
                const path = toPath(fileName, currentDirectory, getCanonicalFileName);
                const key = getKeyForCompilationSettings(compilationSettings);
                return releaseDocumentWithKey(path, key, scriptKind, impliedNodeFormat);
            }
            function releaseDocumentWithKey(path, key, scriptKind, impliedNodeFormat) {
                const bucket = Debug.checkDefined(buckets.get(getDocumentRegistryBucketKeyWithMode(key, impliedNodeFormat)));
                const bucketEntry = bucket.get(path);
                const entry = getDocumentRegistryEntry(bucketEntry, scriptKind);
                entry.languageServiceRefCount--;
                Debug.assert(entry.languageServiceRefCount >= 0);
                if (entry.languageServiceRefCount === 0) {
                    if (isDocumentRegistryEntry(bucketEntry)) {
                        bucket.delete(path);
                    }
                    else {
                        bucketEntry.delete(scriptKind);
                        if (bucketEntry.size === 1) {
                            bucket.set(path, firstDefinedIterator(bucketEntry.values(), identity));
                        }
                    }
                }
            }
            function getLanguageServiceRefCounts(path, scriptKind) {
                return arrayFrom(buckets.entries(), ([key, bucket]) => {
                    const bucketEntry = bucket.get(path);
                    const entry = bucketEntry && getDocumentRegistryEntry(bucketEntry, scriptKind);
                    return [key, entry && entry.languageServiceRefCount];
                });
            }
            return {
                acquireDocument,
                acquireDocumentWithKey,
                updateDocument,
                updateDocumentWithKey,
                releaseDocument,
                releaseDocumentWithKey,
                getLanguageServiceRefCounts,
                reportStats,
                getKeyForCompilationSettings
            };
        }
        function getKeyForCompilationSettings(settings) {
            return getKeyForCompilerOptions(settings, sourceFileAffectingCompilerOptions);
        }
        function getDocumentRegistryBucketKeyWithMode(key, mode) {
            return mode ? `${key}|${mode}` : key;
        }
        var init_documentRegistry = __esm({
            "src/services/documentRegistry.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/getEditsForFileRename.ts
        function getEditsForFileRename(program, oldFileOrDirPath, newFileOrDirPath, host, formatContext, preferences, sourceMapper) {
            const useCaseSensitiveFileNames = hostUsesCaseSensitiveFileNames(host);
            const getCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames);
            const oldToNew = getPathUpdater(oldFileOrDirPath, newFileOrDirPath, getCanonicalFileName, sourceMapper);
            const newToOld = getPathUpdater(newFileOrDirPath, oldFileOrDirPath, getCanonicalFileName, sourceMapper);
            return ts_textChanges_exports.ChangeTracker.with({ host, formatContext, preferences }, (changeTracker) => {
                updateTsconfigFiles(program, changeTracker, oldToNew, oldFileOrDirPath, newFileOrDirPath, host.getCurrentDirectory(), useCaseSensitiveFileNames);
                updateImports(program, changeTracker, oldToNew, newToOld, host, getCanonicalFileName);
            });
        }
        function getPathUpdater(oldFileOrDirPath, newFileOrDirPath, getCanonicalFileName, sourceMapper) {
            const canonicalOldPath = getCanonicalFileName(oldFileOrDirPath);
            return (path) => {
                const originalPath = sourceMapper && sourceMapper.tryGetSourcePosition({ fileName: path, pos: 0 });
                const updatedPath = getUpdatedPath(originalPath ? originalPath.fileName : path);
                return originalPath ? updatedPath === void 0 ? void 0 : makeCorrespondingRelativeChange(originalPath.fileName, updatedPath, path, getCanonicalFileName) : updatedPath;
            };
            function getUpdatedPath(pathToUpdate) {
                if (getCanonicalFileName(pathToUpdate) === canonicalOldPath)
                    return newFileOrDirPath;
                const suffix = tryRemoveDirectoryPrefix(pathToUpdate, canonicalOldPath, getCanonicalFileName);
                return suffix === void 0 ? void 0 : newFileOrDirPath + "/" + suffix;
            }
        }
        function makeCorrespondingRelativeChange(a0, b0, a1, getCanonicalFileName) {
            const rel = getRelativePathFromFile(a0, b0, getCanonicalFileName);
            return combinePathsSafe(getDirectoryPath(a1), rel);
        }
        function updateTsconfigFiles(program, changeTracker, oldToNew, oldFileOrDirPath, newFileOrDirPath, currentDirectory, useCaseSensitiveFileNames) {
            const { configFile } = program.getCompilerOptions();
            if (!configFile)
                return;
            const configDir = getDirectoryPath(configFile.fileName);
            const jsonObjectLiteral = getTsConfigObjectLiteralExpression(configFile);
            if (!jsonObjectLiteral)
                return;
            forEachProperty(jsonObjectLiteral, (property, propertyName) => {
                switch (propertyName) {
                    case "files":
                    case "include":
                    case "exclude": {
                        const foundExactMatch = updatePaths(property);
                        if (foundExactMatch || propertyName !== "include" || !isArrayLiteralExpression(property.initializer))
                            return;
                        const includes = mapDefined(property.initializer.elements, (e) => isStringLiteral(e) ? e.text : void 0);
                        if (includes.length === 0)
                            return;
                        const matchers = getFileMatcherPatterns(configDir, 
                        /*excludes*/
                        [], includes, useCaseSensitiveFileNames, currentDirectory);
                        if (getRegexFromPattern(Debug.checkDefined(matchers.includeFilePattern), useCaseSensitiveFileNames).test(oldFileOrDirPath) && !getRegexFromPattern(Debug.checkDefined(matchers.includeFilePattern), useCaseSensitiveFileNames).test(newFileOrDirPath)) {
                            changeTracker.insertNodeAfter(configFile, last(property.initializer.elements), factory.createStringLiteral(relativePath(newFileOrDirPath)));
                        }
                        return;
                    }
                    case "compilerOptions":
                        forEachProperty(property.initializer, (property2, propertyName2) => {
                            const option = getOptionFromName(propertyName2);
                            Debug.assert((option == null ? void 0 : option.type) !== "listOrElement");
                            if (option && (option.isFilePath || option.type === "list" && option.element.isFilePath)) {
                                updatePaths(property2);
                            }
                            else if (propertyName2 === "paths") {
                                forEachProperty(property2.initializer, (pathsProperty) => {
                                    if (!isArrayLiteralExpression(pathsProperty.initializer))
                                        return;
                                    for (const e of pathsProperty.initializer.elements) {
                                        tryUpdateString(e);
                                    }
                                });
                            }
                        });
                        return;
                }
            });
            function updatePaths(property) {
                const elements = isArrayLiteralExpression(property.initializer) ? property.initializer.elements : [property.initializer];
                let foundExactMatch = false;
                for (const element of elements) {
                    foundExactMatch = tryUpdateString(element) || foundExactMatch;
                }
                return foundExactMatch;
            }
            function tryUpdateString(element) {
                if (!isStringLiteral(element))
                    return false;
                const elementFileName = combinePathsSafe(configDir, element.text);
                const updated = oldToNew(elementFileName);
                if (updated !== void 0) {
                    changeTracker.replaceRangeWithText(configFile, createStringRange(element, configFile), relativePath(updated));
                    return true;
                }
                return false;
            }
            function relativePath(path) {
                return getRelativePathFromDirectory(configDir, path, 
                /*ignoreCase*/
                !useCaseSensitiveFileNames);
            }
        }
        function updateImports(program, changeTracker, oldToNew, newToOld, host, getCanonicalFileName) {
            const allFiles = program.getSourceFiles();
            for (const sourceFile of allFiles) {
                const newFromOld = oldToNew(sourceFile.fileName);
                const newImportFromPath = newFromOld != null ? newFromOld : sourceFile.fileName;
                const newImportFromDirectory = getDirectoryPath(newImportFromPath);
                const oldFromNew = newToOld(sourceFile.fileName);
                const oldImportFromPath = oldFromNew || sourceFile.fileName;
                const oldImportFromDirectory = getDirectoryPath(oldImportFromPath);
                const importingSourceFileMoved = newFromOld !== void 0 || oldFromNew !== void 0;
                updateImportsWorker(sourceFile, changeTracker, (referenceText) => {
                    if (!pathIsRelative(referenceText))
                        return void 0;
                    const oldAbsolute = combinePathsSafe(oldImportFromDirectory, referenceText);
                    const newAbsolute = oldToNew(oldAbsolute);
                    return newAbsolute === void 0 ? void 0 : ensurePathIsNonModuleName(getRelativePathFromDirectory(newImportFromDirectory, newAbsolute, getCanonicalFileName));
                }, (importLiteral) => {
                    const importedModuleSymbol = program.getTypeChecker().getSymbolAtLocation(importLiteral);
                    if ((importedModuleSymbol == null ? void 0 : importedModuleSymbol.declarations) && importedModuleSymbol.declarations.some((d) => isAmbientModule(d)))
                        return void 0;
                    const toImport = oldFromNew !== void 0 ? getSourceFileToImportFromResolved(importLiteral, resolveModuleName(importLiteral.text, oldImportFromPath, program.getCompilerOptions(), host), oldToNew, allFiles) : getSourceFileToImport(importedModuleSymbol, importLiteral, sourceFile, program, host, oldToNew);
                    return toImport !== void 0 && (toImport.updated || importingSourceFileMoved && pathIsRelative(importLiteral.text)) ? ts_moduleSpecifiers_exports.updateModuleSpecifier(program.getCompilerOptions(), sourceFile, getCanonicalFileName(newImportFromPath), toImport.newFileName, createModuleSpecifierResolutionHost(program, host), importLiteral.text) : void 0;
                });
            }
        }
        function combineNormal(pathA, pathB) {
            return normalizePath(combinePaths(pathA, pathB));
        }
        function combinePathsSafe(pathA, pathB) {
            return ensurePathIsNonModuleName(combineNormal(pathA, pathB));
        }
        function getSourceFileToImport(importedModuleSymbol, importLiteral, importingSourceFile, program, host, oldToNew) {
            var _a2;
            if (importedModuleSymbol) {
                const oldFileName = find(importedModuleSymbol.declarations, isSourceFile).fileName;
                const newFileName = oldToNew(oldFileName);
                return newFileName === void 0 ? { newFileName: oldFileName, updated: false } : { newFileName, updated: true };
            }
            else {
                const mode = getModeForUsageLocation(importingSourceFile, importLiteral);
                const resolved = host.resolveModuleNameLiterals || !host.resolveModuleNames ? (_a2 = importingSourceFile.resolvedModules) == null ? void 0 : _a2.get(importLiteral.text, mode) : host.getResolvedModuleWithFailedLookupLocationsFromCache && host.getResolvedModuleWithFailedLookupLocationsFromCache(importLiteral.text, importingSourceFile.fileName, mode);
                return getSourceFileToImportFromResolved(importLiteral, resolved, oldToNew, program.getSourceFiles());
            }
        }
        function getSourceFileToImportFromResolved(importLiteral, resolved, oldToNew, sourceFiles) {
            if (!resolved)
                return void 0;
            if (resolved.resolvedModule) {
                const result2 = tryChange(resolved.resolvedModule.resolvedFileName);
                if (result2)
                    return result2;
            }
            const result = forEach(resolved.failedLookupLocations, tryChangeWithIgnoringPackageJsonExisting) || pathIsRelative(importLiteral.text) && forEach(resolved.failedLookupLocations, tryChangeWithIgnoringPackageJson);
            if (result)
                return result;
            return resolved.resolvedModule && { newFileName: resolved.resolvedModule.resolvedFileName, updated: false };
            function tryChangeWithIgnoringPackageJsonExisting(oldFileName) {
                const newFileName = oldToNew(oldFileName);
                return newFileName && find(sourceFiles, (src) => src.fileName === newFileName) ? tryChangeWithIgnoringPackageJson(oldFileName) : void 0;
            }
            function tryChangeWithIgnoringPackageJson(oldFileName) {
                return !endsWith(oldFileName, "/package.json") ? tryChange(oldFileName) : void 0;
            }
            function tryChange(oldFileName) {
                const newFileName = oldToNew(oldFileName);
                return newFileName && { newFileName, updated: true };
            }
        }
        function updateImportsWorker(sourceFile, changeTracker, updateRef, updateImport2) {
            for (const ref of sourceFile.referencedFiles || emptyArray) {
                const updated = updateRef(ref.fileName);
                if (updated !== void 0 && updated !== sourceFile.text.slice(ref.pos, ref.end))
                    changeTracker.replaceRangeWithText(sourceFile, ref, updated);
            }
            for (const importStringLiteral of sourceFile.imports) {
                const updated = updateImport2(importStringLiteral);
                if (updated !== void 0 && updated !== importStringLiteral.text)
                    changeTracker.replaceRangeWithText(sourceFile, createStringRange(importStringLiteral, sourceFile), updated);
            }
        }
        function createStringRange(node, sourceFile) {
            return createRange(node.getStart(sourceFile) + 1, node.end - 1);
        }
        function forEachProperty(objectLiteral, cb) {
            if (!isObjectLiteralExpression(objectLiteral))
                return;
            for (const property of objectLiteral.properties) {
                if (isPropertyAssignment(property) && isStringLiteral(property.name)) {
                    cb(property, property.name.text);
                }
            }
        }
        var init_getEditsForFileRename = __esm({
            "src/services/getEditsForFileRename.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/patternMatcher.ts
        function createPatternMatch(kind, isCaseSensitive) {
            return {
                kind,
                isCaseSensitive
            };
        }
        function createPatternMatcher(pattern) {
            const stringToWordSpans = /* @__PURE__ */ new Map();
            const dotSeparatedSegments = pattern.trim().split(".").map((p) => createSegment(p.trim()));
            if (dotSeparatedSegments.some((segment) => !segment.subWordTextChunks.length))
                return void 0;
            return {
                getFullMatch: (containers, candidate) => getFullMatch(containers, candidate, dotSeparatedSegments, stringToWordSpans),
                getMatchForLastSegmentOfPattern: (candidate) => matchSegment(candidate, last(dotSeparatedSegments), stringToWordSpans),
                patternContainsDots: dotSeparatedSegments.length > 1
            };
        }
        function getFullMatch(candidateContainers, candidate, dotSeparatedSegments, stringToWordSpans) {
            const candidateMatch = matchSegment(candidate, last(dotSeparatedSegments), stringToWordSpans);
            if (!candidateMatch) {
                return void 0;
            }
            if (dotSeparatedSegments.length - 1 > candidateContainers.length) {
                return void 0;
            }
            let bestMatch;
            for (let i = dotSeparatedSegments.length - 2, j = candidateContainers.length - 1; i >= 0; i -= 1, j -= 1) {
                bestMatch = betterMatch(bestMatch, matchSegment(candidateContainers[j], dotSeparatedSegments[i], stringToWordSpans));
            }
            return bestMatch;
        }
        function getWordSpans(word, stringToWordSpans) {
            let spans = stringToWordSpans.get(word);
            if (!spans) {
                stringToWordSpans.set(word, spans = breakIntoWordSpans(word));
            }
            return spans;
        }
        function matchTextChunk(candidate, chunk, stringToWordSpans) {
            const index = indexOfIgnoringCase(candidate, chunk.textLowerCase);
            if (index === 0) {
                return createPatternMatch(chunk.text.length === candidate.length ? 0 /* exact */ : 1 /* prefix */, 
                /*isCaseSensitive:*/
                startsWith(candidate, chunk.text));
            }
            if (chunk.isLowerCase) {
                if (index === -1)
                    return void 0;
                const wordSpans = getWordSpans(candidate, stringToWordSpans);
                for (const span of wordSpans) {
                    if (partStartsWith(candidate, span, chunk.text, 
                    /*ignoreCase:*/
                    true)) {
                        return createPatternMatch(2 /* substring */, 
                        /*isCaseSensitive:*/
                        partStartsWith(candidate, span, chunk.text, 
                        /*ignoreCase:*/
                        false));
                    }
                }
                if (chunk.text.length < candidate.length && isUpperCaseLetter(candidate.charCodeAt(index))) {
                    return createPatternMatch(2 /* substring */, 
                    /*isCaseSensitive:*/
                    false);
                }
            }
            else {
                if (candidate.indexOf(chunk.text) > 0) {
                    return createPatternMatch(2 /* substring */, 
                    /*isCaseSensitive:*/
                    true);
                }
                if (chunk.characterSpans.length > 0) {
                    const candidateParts = getWordSpans(candidate, stringToWordSpans);
                    const isCaseSensitive = tryCamelCaseMatch(candidate, candidateParts, chunk, 
                    /*ignoreCase:*/
                    false) ? true : tryCamelCaseMatch(candidate, candidateParts, chunk, 
                    /*ignoreCase:*/
                    true) ? false : void 0;
                    if (isCaseSensitive !== void 0) {
                        return createPatternMatch(3 /* camelCase */, isCaseSensitive);
                    }
                }
            }
        }
        function matchSegment(candidate, segment, stringToWordSpans) {
            if (every2(segment.totalTextChunk.text, (ch) => ch !== 32 /* space */ && ch !== 42 /* asterisk */)) {
                const match = matchTextChunk(candidate, segment.totalTextChunk, stringToWordSpans);
                if (match)
                    return match;
            }
            const subWordTextChunks = segment.subWordTextChunks;
            let bestMatch;
            for (const subWordTextChunk of subWordTextChunks) {
                bestMatch = betterMatch(bestMatch, matchTextChunk(candidate, subWordTextChunk, stringToWordSpans));
            }
            return bestMatch;
        }
        function betterMatch(a, b) {
            return min([a, b], compareMatches);
        }
        function compareMatches(a, b) {
            return a === void 0 ? 1 /* GreaterThan */ : b === void 0 ? -1 /* LessThan */ : compareValues(a.kind, b.kind) || compareBooleans(!a.isCaseSensitive, !b.isCaseSensitive);
        }
        function partStartsWith(candidate, candidateSpan, pattern, ignoreCase, patternSpan = { start: 0, length: pattern.length }) {
            return patternSpan.length <= candidateSpan.length && everyInRange(0, patternSpan.length, (i) => equalChars(pattern.charCodeAt(patternSpan.start + i), candidate.charCodeAt(candidateSpan.start + i), ignoreCase));
        }
        function equalChars(ch1, ch2, ignoreCase) {
            return ignoreCase ? toLowerCase2(ch1) === toLowerCase2(ch2) : ch1 === ch2;
        }
        function tryCamelCaseMatch(candidate, candidateParts, chunk, ignoreCase) {
            const chunkCharacterSpans = chunk.characterSpans;
            let currentCandidate = 0;
            let currentChunkSpan = 0;
            let firstMatch;
            let contiguous;
            while (true) {
                if (currentChunkSpan === chunkCharacterSpans.length) {
                    return true;
                }
                else if (currentCandidate === candidateParts.length) {
                    return false;
                }
                let candidatePart = candidateParts[currentCandidate];
                let gotOneMatchThisCandidate = false;
                for (; currentChunkSpan < chunkCharacterSpans.length; currentChunkSpan++) {
                    const chunkCharacterSpan = chunkCharacterSpans[currentChunkSpan];
                    if (gotOneMatchThisCandidate) {
                        if (!isUpperCaseLetter(chunk.text.charCodeAt(chunkCharacterSpans[currentChunkSpan - 1].start)) || !isUpperCaseLetter(chunk.text.charCodeAt(chunkCharacterSpans[currentChunkSpan].start))) {
                            break;
                        }
                    }
                    if (!partStartsWith(candidate, candidatePart, chunk.text, ignoreCase, chunkCharacterSpan)) {
                        break;
                    }
                    gotOneMatchThisCandidate = true;
                    firstMatch = firstMatch === void 0 ? currentCandidate : firstMatch;
                    contiguous = contiguous === void 0 ? true : contiguous;
                    candidatePart = createTextSpan(candidatePart.start + chunkCharacterSpan.length, candidatePart.length - chunkCharacterSpan.length);
                }
                if (!gotOneMatchThisCandidate && contiguous !== void 0) {
                    contiguous = false;
                }
                currentCandidate++;
            }
        }
        function createSegment(text) {
            return {
                totalTextChunk: createTextChunk(text),
                subWordTextChunks: breakPatternIntoTextChunks(text)
            };
        }
        function isUpperCaseLetter(ch) {
            if (ch >= 65 /* A */ && ch <= 90 /* Z */) {
                return true;
            }
            if (ch < 127 /* maxAsciiCharacter */ || !isUnicodeIdentifierStart(ch, 99 /* Latest */)) {
                return false;
            }
            const str = String.fromCharCode(ch);
            return str === str.toUpperCase();
        }
        function isLowerCaseLetter(ch) {
            if (ch >= 97 /* a */ && ch <= 122 /* z */) {
                return true;
            }
            if (ch < 127 /* maxAsciiCharacter */ || !isUnicodeIdentifierStart(ch, 99 /* Latest */)) {
                return false;
            }
            const str = String.fromCharCode(ch);
            return str === str.toLowerCase();
        }
        function indexOfIgnoringCase(str, value) {
            const n = str.length - value.length;
            for (let start = 0; start <= n; start++) {
                if (every2(value, (valueChar, i) => toLowerCase2(str.charCodeAt(i + start)) === valueChar)) {
                    return start;
                }
            }
            return -1;
        }
        function toLowerCase2(ch) {
            if (ch >= 65 /* A */ && ch <= 90 /* Z */) {
                return 97 /* a */ + (ch - 65 /* A */);
            }
            if (ch < 127 /* maxAsciiCharacter */) {
                return ch;
            }
            return String.fromCharCode(ch).toLowerCase().charCodeAt(0);
        }
        function isDigit2(ch) {
            return ch >= 48 /* _0 */ && ch <= 57 /* _9 */;
        }
        function isWordChar(ch) {
            return isUpperCaseLetter(ch) || isLowerCaseLetter(ch) || isDigit2(ch) || ch === 95 /* _ */ || ch === 36 /* $ */;
        }
        function breakPatternIntoTextChunks(pattern) {
            const result = [];
            let wordStart = 0;
            let wordLength = 0;
            for (let i = 0; i < pattern.length; i++) {
                const ch = pattern.charCodeAt(i);
                if (isWordChar(ch)) {
                    if (wordLength === 0) {
                        wordStart = i;
                    }
                    wordLength++;
                }
                else {
                    if (wordLength > 0) {
                        result.push(createTextChunk(pattern.substr(wordStart, wordLength)));
                        wordLength = 0;
                    }
                }
            }
            if (wordLength > 0) {
                result.push(createTextChunk(pattern.substr(wordStart, wordLength)));
            }
            return result;
        }
        function createTextChunk(text) {
            const textLowerCase = text.toLowerCase();
            return {
                text,
                textLowerCase,
                isLowerCase: text === textLowerCase,
                characterSpans: breakIntoCharacterSpans(text)
            };
        }
        function breakIntoCharacterSpans(identifier) {
            return breakIntoSpans(identifier, 
            /*word:*/
            false);
        }
        function breakIntoWordSpans(identifier) {
            return breakIntoSpans(identifier, 
            /*word:*/
            true);
        }
        function breakIntoSpans(identifier, word) {
            const result = [];
            let wordStart = 0;
            for (let i = 1; i < identifier.length; i++) {
                const lastIsDigit = isDigit2(identifier.charCodeAt(i - 1));
                const currentIsDigit = isDigit2(identifier.charCodeAt(i));
                const hasTransitionFromLowerToUpper = transitionFromLowerToUpper(identifier, word, i);
                const hasTransitionFromUpperToLower = word && transitionFromUpperToLower(identifier, i, wordStart);
                if (charIsPunctuation(identifier.charCodeAt(i - 1)) || charIsPunctuation(identifier.charCodeAt(i)) || lastIsDigit !== currentIsDigit || hasTransitionFromLowerToUpper || hasTransitionFromUpperToLower) {
                    if (!isAllPunctuation(identifier, wordStart, i)) {
                        result.push(createTextSpan(wordStart, i - wordStart));
                    }
                    wordStart = i;
                }
            }
            if (!isAllPunctuation(identifier, wordStart, identifier.length)) {
                result.push(createTextSpan(wordStart, identifier.length - wordStart));
            }
            return result;
        }
        function charIsPunctuation(ch) {
            switch (ch) {
                case 33 /* exclamation */:
                case 34 /* doubleQuote */:
                case 35 /* hash */:
                case 37 /* percent */:
                case 38 /* ampersand */:
                case 39 /* singleQuote */:
                case 40 /* openParen */:
                case 41 /* closeParen */:
                case 42 /* asterisk */:
                case 44 /* comma */:
                case 45 /* minus */:
                case 46 /* dot */:
                case 47 /* slash */:
                case 58 /* colon */:
                case 59 /* semicolon */:
                case 63 /* question */:
                case 64 /* at */:
                case 91 /* openBracket */:
                case 92 /* backslash */:
                case 93 /* closeBracket */:
                case 95 /* _ */:
                case 123 /* openBrace */:
                case 125 /* closeBrace */:
                    return true;
            }
            return false;
        }
        function isAllPunctuation(identifier, start, end) {
            return every2(identifier, (ch) => charIsPunctuation(ch) && ch !== 95 /* _ */, start, end);
        }
        function transitionFromUpperToLower(identifier, index, wordStart) {
            return index !== wordStart && index + 1 < identifier.length && isUpperCaseLetter(identifier.charCodeAt(index)) && isLowerCaseLetter(identifier.charCodeAt(index + 1)) && every2(identifier, isUpperCaseLetter, wordStart, index);
        }
        function transitionFromLowerToUpper(identifier, word, index) {
            const lastIsUpper = isUpperCaseLetter(identifier.charCodeAt(index - 1));
            const currentIsUpper = isUpperCaseLetter(identifier.charCodeAt(index));
            return currentIsUpper && (!word || !lastIsUpper);
        }
        function everyInRange(start, end, pred) {
            for (let i = start; i < end; i++) {
                if (!pred(i)) {
                    return false;
                }
            }
            return true;
        }
        function every2(s, pred, start = 0, end = s.length) {
            return everyInRange(start, end, (i) => pred(s.charCodeAt(i), i));
        }
        var PatternMatchKind;
        var init_patternMatcher = __esm({
            "src/services/patternMatcher.ts"() {
                "use strict";
                init_ts4();
                PatternMatchKind = /* @__PURE__ */ ((PatternMatchKind2) => {
                    PatternMatchKind2[PatternMatchKind2["exact"] = 0] = "exact";
                    PatternMatchKind2[PatternMatchKind2["prefix"] = 1] = "prefix";
                    PatternMatchKind2[PatternMatchKind2["substring"] = 2] = "substring";
                    PatternMatchKind2[PatternMatchKind2["camelCase"] = 3] = "camelCase";
                    return PatternMatchKind2;
                })(PatternMatchKind || {});
            }
        });
        // src/services/preProcess.ts
        function preProcessFile(sourceText, readImportFiles = true, detectJavaScriptImports = false) {
            const pragmaContext = {
                languageVersion: 1 /* ES5 */,
                // controls whether the token scanner considers unicode identifiers or not - shouldn't matter, since we're only using it for trivia
                pragmas: void 0,
                checkJsDirective: void 0,
                referencedFiles: [],
                typeReferenceDirectives: [],
                libReferenceDirectives: [],
                amdDependencies: [],
                hasNoDefaultLib: void 0,
                moduleName: void 0
            };
            const importedFiles = [];
            let ambientExternalModules;
            let lastToken;
            let currentToken;
            let braceNesting = 0;
            let externalModule = false;
            function nextToken() {
                lastToken = currentToken;
                currentToken = scanner.scan();
                if (currentToken === 18 /* OpenBraceToken */) {
                    braceNesting++;
                }
                else if (currentToken === 19 /* CloseBraceToken */) {
                    braceNesting--;
                }
                return currentToken;
            }
            function getFileReference() {
                const fileName = scanner.getTokenValue();
                const pos = scanner.getTokenPos();
                return { fileName, pos, end: pos + fileName.length };
            }
            function recordAmbientExternalModule() {
                if (!ambientExternalModules) {
                    ambientExternalModules = [];
                }
                ambientExternalModules.push({ ref: getFileReference(), depth: braceNesting });
            }
            function recordModuleName() {
                importedFiles.push(getFileReference());
                markAsExternalModuleIfTopLevel();
            }
            function markAsExternalModuleIfTopLevel() {
                if (braceNesting === 0) {
                    externalModule = true;
                }
            }
            function tryConsumeDeclare() {
                let token = scanner.getToken();
                if (token === 136 /* DeclareKeyword */) {
                    token = nextToken();
                    if (token === 142 /* ModuleKeyword */) {
                        token = nextToken();
                        if (token === 10 /* StringLiteral */) {
                            recordAmbientExternalModule();
                        }
                    }
                    return true;
                }
                return false;
            }
            function tryConsumeImport() {
                if (lastToken === 24 /* DotToken */) {
                    return false;
                }
                let token = scanner.getToken();
                if (token === 100 /* ImportKeyword */) {
                    token = nextToken();
                    if (token === 20 /* OpenParenToken */) {
                        token = nextToken();
                        if (token === 10 /* StringLiteral */ || token === 14 /* NoSubstitutionTemplateLiteral */) {
                            recordModuleName();
                            return true;
                        }
                    }
                    else if (token === 10 /* StringLiteral */) {
                        recordModuleName();
                        return true;
                    }
                    else {
                        if (token === 154 /* TypeKeyword */) {
                            const skipTypeKeyword = scanner.lookAhead(() => {
                                const token2 = scanner.scan();
                                return token2 !== 158 /* FromKeyword */ && (token2 === 41 /* AsteriskToken */ || token2 === 18 /* OpenBraceToken */ || token2 === 79 /* Identifier */ || isKeyword(token2));
                            });
                            if (skipTypeKeyword) {
                                token = nextToken();
                            }
                        }
                        if (token === 79 /* Identifier */ || isKeyword(token)) {
                            token = nextToken();
                            if (token === 158 /* FromKeyword */) {
                                token = nextToken();
                                if (token === 10 /* StringLiteral */) {
                                    recordModuleName();
                                    return true;
                                }
                            }
                            else if (token === 63 /* EqualsToken */) {
                                if (tryConsumeRequireCall(
                                /*skipCurrentToken*/
                                true)) {
                                    return true;
                                }
                            }
                            else if (token === 27 /* CommaToken */) {
                                token = nextToken();
                            }
                            else {
                                return true;
                            }
                        }
                        if (token === 18 /* OpenBraceToken */) {
                            token = nextToken();
                            while (token !== 19 /* CloseBraceToken */ && token !== 1 /* EndOfFileToken */) {
                                token = nextToken();
                            }
                            if (token === 19 /* CloseBraceToken */) {
                                token = nextToken();
                                if (token === 158 /* FromKeyword */) {
                                    token = nextToken();
                                    if (token === 10 /* StringLiteral */) {
                                        recordModuleName();
                                    }
                                }
                            }
                        }
                        else if (token === 41 /* AsteriskToken */) {
                            token = nextToken();
                            if (token === 128 /* AsKeyword */) {
                                token = nextToken();
                                if (token === 79 /* Identifier */ || isKeyword(token)) {
                                    token = nextToken();
                                    if (token === 158 /* FromKeyword */) {
                                        token = nextToken();
                                        if (token === 10 /* StringLiteral */) {
                                            recordModuleName();
                                        }
                                    }
                                }
                            }
                        }
                    }
                    return true;
                }
                return false;
            }
            function tryConsumeExport() {
                let token = scanner.getToken();
                if (token === 93 /* ExportKeyword */) {
                    markAsExternalModuleIfTopLevel();
                    token = nextToken();
                    if (token === 154 /* TypeKeyword */) {
                        const skipTypeKeyword = scanner.lookAhead(() => {
                            const token2 = scanner.scan();
                            return token2 === 41 /* AsteriskToken */ || token2 === 18 /* OpenBraceToken */;
                        });
                        if (skipTypeKeyword) {
                            token = nextToken();
                        }
                    }
                    if (token === 18 /* OpenBraceToken */) {
                        token = nextToken();
                        while (token !== 19 /* CloseBraceToken */ && token !== 1 /* EndOfFileToken */) {
                            token = nextToken();
                        }
                        if (token === 19 /* CloseBraceToken */) {
                            token = nextToken();
                            if (token === 158 /* FromKeyword */) {
                                token = nextToken();
                                if (token === 10 /* StringLiteral */) {
                                    recordModuleName();
                                }
                            }
                        }
                    }
                    else if (token === 41 /* AsteriskToken */) {
                        token = nextToken();
                        if (token === 158 /* FromKeyword */) {
                            token = nextToken();
                            if (token === 10 /* StringLiteral */) {
                                recordModuleName();
                            }
                        }
                    }
                    else if (token === 100 /* ImportKeyword */) {
                        token = nextToken();
                        if (token === 154 /* TypeKeyword */) {
                            const skipTypeKeyword = scanner.lookAhead(() => {
                                const token2 = scanner.scan();
                                return token2 === 79 /* Identifier */ || isKeyword(token2);
                            });
                            if (skipTypeKeyword) {
                                token = nextToken();
                            }
                        }
                        if (token === 79 /* Identifier */ || isKeyword(token)) {
                            token = nextToken();
                            if (token === 63 /* EqualsToken */) {
                                if (tryConsumeRequireCall(
                                /*skipCurrentToken*/
                                true)) {
                                    return true;
                                }
                            }
                        }
                    }
                    return true;
                }
                return false;
            }
            function tryConsumeRequireCall(skipCurrentToken, allowTemplateLiterals = false) {
                let token = skipCurrentToken ? nextToken() : scanner.getToken();
                if (token === 147 /* RequireKeyword */) {
                    token = nextToken();
                    if (token === 20 /* OpenParenToken */) {
                        token = nextToken();
                        if (token === 10 /* StringLiteral */ || allowTemplateLiterals && token === 14 /* NoSubstitutionTemplateLiteral */) {
                            recordModuleName();
                        }
                    }
                    return true;
                }
                return false;
            }
            function tryConsumeDefine() {
                let token = scanner.getToken();
                if (token === 79 /* Identifier */ && scanner.getTokenValue() === "define") {
                    token = nextToken();
                    if (token !== 20 /* OpenParenToken */) {
                        return true;
                    }
                    token = nextToken();
                    if (token === 10 /* StringLiteral */ || token === 14 /* NoSubstitutionTemplateLiteral */) {
                        token = nextToken();
                        if (token === 27 /* CommaToken */) {
                            token = nextToken();
                        }
                        else {
                            return true;
                        }
                    }
                    if (token !== 22 /* OpenBracketToken */) {
                        return true;
                    }
                    token = nextToken();
                    while (token !== 23 /* CloseBracketToken */ && token !== 1 /* EndOfFileToken */) {
                        if (token === 10 /* StringLiteral */ || token === 14 /* NoSubstitutionTemplateLiteral */) {
                            recordModuleName();
                        }
                        token = nextToken();
                    }
                    return true;
                }
                return false;
            }
            function processImports() {
                scanner.setText(sourceText);
                nextToken();
                while (true) {
                    if (scanner.getToken() === 1 /* EndOfFileToken */) {
                        break;
                    }
                    if (scanner.getToken() === 15 /* TemplateHead */) {
                        const stack = [scanner.getToken()];
                        loop: while (length(stack)) {
                            const token = scanner.scan();
                            switch (token) {
                                case 1 /* EndOfFileToken */:
                                    break loop;
                                case 100 /* ImportKeyword */:
                                    tryConsumeImport();
                                    break;
                                case 15 /* TemplateHead */:
                                    stack.push(token);
                                    break;
                                case 18 /* OpenBraceToken */:
                                    if (length(stack)) {
                                        stack.push(token);
                                    }
                                    break;
                                case 19 /* CloseBraceToken */:
                                    if (length(stack)) {
                                        if (lastOrUndefined(stack) === 15 /* TemplateHead */) {
                                            if (scanner.reScanTemplateToken(
                                            /* isTaggedTemplate */
                                            false) === 17 /* TemplateTail */) {
                                                stack.pop();
                                            }
                                        }
                                        else {
                                            stack.pop();
                                        }
                                    }
                                    break;
                            }
                        }
                        nextToken();
                    }
                    if (tryConsumeDeclare() || tryConsumeImport() || tryConsumeExport() || detectJavaScriptImports && (tryConsumeRequireCall(
                    /*skipCurrentToken*/
                    false, 
                    /*allowTemplateLiterals*/
                    true) || tryConsumeDefine())) {
                        continue;
                    }
                    else {
                        nextToken();
                    }
                }
                scanner.setText(void 0);
            }
            if (readImportFiles) {
                processImports();
            }
            processCommentPragmas(pragmaContext, sourceText);
            processPragmasIntoFields(pragmaContext, noop);
            if (externalModule) {
                if (ambientExternalModules) {
                    for (const decl of ambientExternalModules) {
                        importedFiles.push(decl.ref);
                    }
                }
                return { referencedFiles: pragmaContext.referencedFiles, typeReferenceDirectives: pragmaContext.typeReferenceDirectives, libReferenceDirectives: pragmaContext.libReferenceDirectives, importedFiles, isLibFile: !!pragmaContext.hasNoDefaultLib, ambientExternalModules: void 0 };
            }
            else {
                let ambientModuleNames;
                if (ambientExternalModules) {
                    for (const decl of ambientExternalModules) {
                        if (decl.depth === 0) {
                            if (!ambientModuleNames) {
                                ambientModuleNames = [];
                            }
                            ambientModuleNames.push(decl.ref.fileName);
                        }
                        else {
                            importedFiles.push(decl.ref);
                        }
                    }
                }
                return { referencedFiles: pragmaContext.referencedFiles, typeReferenceDirectives: pragmaContext.typeReferenceDirectives, libReferenceDirectives: pragmaContext.libReferenceDirectives, importedFiles, isLibFile: !!pragmaContext.hasNoDefaultLib, ambientExternalModules: ambientModuleNames };
            }
        }
        var init_preProcess = __esm({
            "src/services/preProcess.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/sourcemaps.ts
        function getSourceMapper(host) {
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames());
            const currentDirectory = host.getCurrentDirectory();
            const sourceFileLike = /* @__PURE__ */ new Map();
            const documentPositionMappers = /* @__PURE__ */ new Map();
            return { tryGetSourcePosition, tryGetGeneratedPosition, toLineColumnOffset, clearCache };
            function toPath3(fileName) {
                return toPath(fileName, currentDirectory, getCanonicalFileName);
            }
            function getDocumentPositionMapper2(generatedFileName, sourceFileName) {
                const path = toPath3(generatedFileName);
                const value = documentPositionMappers.get(path);
                if (value)
                    return value;
                let mapper;
                if (host.getDocumentPositionMapper) {
                    mapper = host.getDocumentPositionMapper(generatedFileName, sourceFileName);
                }
                else if (host.readFile) {
                    const file = getSourceFileLike(generatedFileName);
                    mapper = file && getDocumentPositionMapper({ getSourceFileLike, getCanonicalFileName, log: (s) => host.log(s) }, generatedFileName, getLineInfo(file.text, getLineStarts(file)), (f) => !host.fileExists || host.fileExists(f) ? host.readFile(f) : void 0);
                }
                documentPositionMappers.set(path, mapper || identitySourceMapConsumer);
                return mapper || identitySourceMapConsumer;
            }
            function tryGetSourcePosition(info) {
                if (!isDeclarationFileName(info.fileName))
                    return void 0;
                const file = getSourceFile(info.fileName);
                if (!file)
                    return void 0;
                const newLoc = getDocumentPositionMapper2(info.fileName).getSourcePosition(info);
                return !newLoc || newLoc === info ? void 0 : tryGetSourcePosition(newLoc) || newLoc;
            }
            function tryGetGeneratedPosition(info) {
                if (isDeclarationFileName(info.fileName))
                    return void 0;
                const sourceFile = getSourceFile(info.fileName);
                if (!sourceFile)
                    return void 0;
                const program = host.getProgram();
                if (program.isSourceOfProjectReferenceRedirect(sourceFile.fileName)) {
                    return void 0;
                }
                const options = program.getCompilerOptions();
                const outPath = outFile(options);
                const declarationPath = outPath ? removeFileExtension(outPath) + ".d.ts" /* Dts */ : getDeclarationEmitOutputFilePathWorker(info.fileName, program.getCompilerOptions(), currentDirectory, program.getCommonSourceDirectory(), getCanonicalFileName);
                if (declarationPath === void 0)
                    return void 0;
                const newLoc = getDocumentPositionMapper2(declarationPath, info.fileName).getGeneratedPosition(info);
                return newLoc === info ? void 0 : newLoc;
            }
            function getSourceFile(fileName) {
                const program = host.getProgram();
                if (!program)
                    return void 0;
                const path = toPath3(fileName);
                const file = program.getSourceFileByPath(path);
                return file && file.resolvedPath === path ? file : void 0;
            }
            function getOrCreateSourceFileLike(fileName) {
                const path = toPath3(fileName);
                const fileFromCache = sourceFileLike.get(path);
                if (fileFromCache !== void 0)
                    return fileFromCache ? fileFromCache : void 0;
                if (!host.readFile || host.fileExists && !host.fileExists(path)) {
                    sourceFileLike.set(path, false);
                    return void 0;
                }
                const text = host.readFile(path);
                const file = text ? createSourceFileLike(text) : false;
                sourceFileLike.set(path, file);
                return file ? file : void 0;
            }
            function getSourceFileLike(fileName) {
                return !host.getSourceFileLike ? getSourceFile(fileName) || getOrCreateSourceFileLike(fileName) : host.getSourceFileLike(fileName);
            }
            function toLineColumnOffset(fileName, position) {
                const file = getSourceFileLike(fileName);
                return file.getLineAndCharacterOfPosition(position);
            }
            function clearCache() {
                sourceFileLike.clear();
                documentPositionMappers.clear();
            }
        }
        function getDocumentPositionMapper(host, generatedFileName, generatedFileLineInfo, readMapFile) {
            let mapFileName = tryGetSourceMappingURL(generatedFileLineInfo);
            if (mapFileName) {
                const match = base64UrlRegExp.exec(mapFileName);
                if (match) {
                    if (match[1]) {
                        const base64Object = match[1];
                        return convertDocumentToSourceMapper(host, base64decode(sys, base64Object), generatedFileName);
                    }
                    mapFileName = void 0;
                }
            }
            const possibleMapLocations = [];
            if (mapFileName) {
                possibleMapLocations.push(mapFileName);
            }
            possibleMapLocations.push(generatedFileName + ".map");
            const originalMapFileName = mapFileName && getNormalizedAbsolutePath(mapFileName, getDirectoryPath(generatedFileName));
            for (const location of possibleMapLocations) {
                const mapFileName2 = getNormalizedAbsolutePath(location, getDirectoryPath(generatedFileName));
                const mapFileContents = readMapFile(mapFileName2, originalMapFileName);
                if (isString(mapFileContents)) {
                    return convertDocumentToSourceMapper(host, mapFileContents, mapFileName2);
                }
                if (mapFileContents !== void 0) {
                    return mapFileContents || void 0;
                }
            }
            return void 0;
        }
        function convertDocumentToSourceMapper(host, contents, mapFileName) {
            const map2 = tryParseRawSourceMap(contents);
            if (!map2 || !map2.sources || !map2.file || !map2.mappings) {
                return void 0;
            }
            if (map2.sourcesContent && map2.sourcesContent.some(isString))
                return void 0;
            return createDocumentPositionMapper(host, map2, mapFileName);
        }
        function createSourceFileLike(text, lineMap) {
            return {
                text,
                lineMap,
                getLineAndCharacterOfPosition(pos) {
                    return computeLineAndCharacterOfPosition(getLineStarts(this), pos);
                }
            };
        }
        var base64UrlRegExp;
        var init_sourcemaps = __esm({
            "src/services/sourcemaps.ts"() {
                "use strict";
                init_ts4();
                init_ts4();
                base64UrlRegExp = /^data:(?:application\/json(?:;charset=[uU][tT][fF]-8);base64,([A-Za-z0-9+\/=]+)$)?/;
            }
        });
        // src/services/suggestionDiagnostics.ts
        function computeSuggestionDiagnostics(sourceFile, program, cancellationToken) {
            program.getSemanticDiagnostics(sourceFile, cancellationToken);
            const diags = [];
            const checker = program.getTypeChecker();
            const isCommonJSFile = sourceFile.impliedNodeFormat === 1 /* CommonJS */ || fileExtensionIsOneOf(sourceFile.fileName, [".cts" /* Cts */, ".cjs" /* Cjs */]);
            if (!isCommonJSFile && sourceFile.commonJsModuleIndicator && (programContainsEsModules(program) || compilerOptionsIndicateEsModules(program.getCompilerOptions())) && containsTopLevelCommonjs(sourceFile)) {
                diags.push(createDiagnosticForNode(getErrorNodeFromCommonJsIndicator(sourceFile.commonJsModuleIndicator), Diagnostics.File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module));
            }
            const isJsFile = isSourceFileJS(sourceFile);
            visitedNestedConvertibleFunctions.clear();
            check(sourceFile);
            if (getAllowSyntheticDefaultImports(program.getCompilerOptions())) {
                for (const moduleSpecifier of sourceFile.imports) {
                    const importNode = importFromModuleSpecifier(moduleSpecifier);
                    const name = importNameForConvertToDefaultImport(importNode);
                    if (!name)
                        continue;
                    const module2 = getResolvedModule(sourceFile, moduleSpecifier.text, getModeForUsageLocation(sourceFile, moduleSpecifier));
                    const resolvedFile = module2 && program.getSourceFile(module2.resolvedFileName);
                    if (resolvedFile && resolvedFile.externalModuleIndicator && resolvedFile.externalModuleIndicator !== true && isExportAssignment(resolvedFile.externalModuleIndicator) && resolvedFile.externalModuleIndicator.isExportEquals) {
                        diags.push(createDiagnosticForNode(name, Diagnostics.Import_may_be_converted_to_a_default_import));
                    }
                }
            }
            addRange(diags, sourceFile.bindSuggestionDiagnostics);
            addRange(diags, program.getSuggestionDiagnostics(sourceFile, cancellationToken));
            return diags.sort((d1, d2) => d1.start - d2.start);
            function check(node) {
                if (isJsFile) {
                    if (canBeConvertedToClass(node, checker)) {
                        diags.push(createDiagnosticForNode(isVariableDeclaration(node.parent) ? node.parent.name : node, Diagnostics.This_constructor_function_may_be_converted_to_a_class_declaration));
                    }
                }
                else {
                    if (isVariableStatement(node) && node.parent === sourceFile && node.declarationList.flags & 2 /* Const */ && node.declarationList.declarations.length === 1) {
                        const init = node.declarationList.declarations[0].initializer;
                        if (init && isRequireCall(init, 
                        /*checkArgumentIsStringLiteralLike*/
                        true)) {
                            diags.push(createDiagnosticForNode(init, Diagnostics.require_call_may_be_converted_to_an_import));
                        }
                    }
                    if (ts_codefix_exports.parameterShouldGetTypeFromJSDoc(node)) {
                        diags.push(createDiagnosticForNode(node.name || node, Diagnostics.JSDoc_types_may_be_moved_to_TypeScript_types));
                    }
                }
                if (canBeConvertedToAsync(node)) {
                    addConvertToAsyncFunctionDiagnostics(node, checker, diags);
                }
                node.forEachChild(check);
            }
        }
        function containsTopLevelCommonjs(sourceFile) {
            return sourceFile.statements.some((statement) => {
                switch (statement.kind) {
                    case 240 /* VariableStatement */:
                        return statement.declarationList.declarations.some((decl) => !!decl.initializer && isRequireCall(propertyAccessLeftHandSide(decl.initializer), 
                        /*checkArgumentIsStringLiteralLike*/
                        true));
                    case 241 /* ExpressionStatement */: {
                        const { expression } = statement;
                        if (!isBinaryExpression(expression))
                            return isRequireCall(expression, 
                            /*checkArgumentIsStringLiteralLike*/
                            true);
                        const kind = getAssignmentDeclarationKind(expression);
                        return kind === 1 /* ExportsProperty */ || kind === 2 /* ModuleExports */;
                    }
                    default:
                        return false;
                }
            });
        }
        function propertyAccessLeftHandSide(node) {
            return isPropertyAccessExpression(node) ? propertyAccessLeftHandSide(node.expression) : node;
        }
        function importNameForConvertToDefaultImport(node) {
            switch (node.kind) {
                case 269 /* ImportDeclaration */:
                    const { importClause, moduleSpecifier } = node;
                    return importClause && !importClause.name && importClause.namedBindings && importClause.namedBindings.kind === 271 /* NamespaceImport */ && isStringLiteral(moduleSpecifier) ? importClause.namedBindings.name : void 0;
                case 268 /* ImportEqualsDeclaration */:
                    return node.name;
                default:
                    return void 0;
            }
        }
        function addConvertToAsyncFunctionDiagnostics(node, checker, diags) {
            if (isConvertibleFunction(node, checker) && !visitedNestedConvertibleFunctions.has(getKeyFromNode(node))) {
                diags.push(createDiagnosticForNode(!node.name && isVariableDeclaration(node.parent) && isIdentifier(node.parent.name) ? node.parent.name : node, Diagnostics.This_may_be_converted_to_an_async_function));
            }
        }
        function isConvertibleFunction(node, checker) {
            return !isAsyncFunction(node) && node.body && isBlock(node.body) && hasReturnStatementWithPromiseHandler(node.body, checker) && returnsPromise(node, checker);
        }
        function returnsPromise(node, checker) {
            const signature = checker.getSignatureFromDeclaration(node);
            const returnType = signature ? checker.getReturnTypeOfSignature(signature) : void 0;
            return !!returnType && !!checker.getPromisedTypeOfPromise(returnType);
        }
        function getErrorNodeFromCommonJsIndicator(commonJsModuleIndicator) {
            return isBinaryExpression(commonJsModuleIndicator) ? commonJsModuleIndicator.left : commonJsModuleIndicator;
        }
        function hasReturnStatementWithPromiseHandler(body, checker) {
            return !!forEachReturnStatement(body, (statement) => isReturnStatementWithFixablePromiseHandler(statement, checker));
        }
        function isReturnStatementWithFixablePromiseHandler(node, checker) {
            return isReturnStatement(node) && !!node.expression && isFixablePromiseHandler(node.expression, checker);
        }
        function isFixablePromiseHandler(node, checker) {
            if (!isPromiseHandler(node) || !hasSupportedNumberOfArguments(node) || !node.arguments.every((arg) => isFixablePromiseArgument(arg, checker))) {
                return false;
            }
            let currentNode = node.expression.expression;
            while (isPromiseHandler(currentNode) || isPropertyAccessExpression(currentNode)) {
                if (isCallExpression(currentNode)) {
                    if (!hasSupportedNumberOfArguments(currentNode) || !currentNode.arguments.every((arg) => isFixablePromiseArgument(arg, checker))) {
                        return false;
                    }
                    currentNode = currentNode.expression.expression;
                }
                else {
                    currentNode = currentNode.expression;
                }
            }
            return true;
        }
        function isPromiseHandler(node) {
            return isCallExpression(node) && (hasPropertyAccessExpressionWithName(node, "then") || hasPropertyAccessExpressionWithName(node, "catch") || hasPropertyAccessExpressionWithName(node, "finally"));
        }
        function hasSupportedNumberOfArguments(node) {
            const name = node.expression.name.text;
            const maxArguments = name === "then" ? 2 : name === "catch" ? 1 : name === "finally" ? 1 : 0;
            if (node.arguments.length > maxArguments)
                return false;
            if (node.arguments.length < maxArguments)
                return true;
            return maxArguments === 1 || some(node.arguments, (arg) => {
                return arg.kind === 104 /* NullKeyword */ || isIdentifier(arg) && arg.text === "undefined";
            });
        }
        function isFixablePromiseArgument(arg, checker) {
            switch (arg.kind) {
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                    const functionFlags = getFunctionFlags(arg);
                    if (functionFlags & 1 /* Generator */) {
                        return false;
                    }
                case 216 /* ArrowFunction */:
                    visitedNestedConvertibleFunctions.set(getKeyFromNode(arg), true);
                case 104 /* NullKeyword */:
                    return true;
                case 79 /* Identifier */:
                case 208 /* PropertyAccessExpression */: {
                    const symbol = checker.getSymbolAtLocation(arg);
                    if (!symbol) {
                        return false;
                    }
                    return checker.isUndefinedSymbol(symbol) || some(skipAlias(symbol, checker).declarations, (d) => isFunctionLike(d) || hasInitializer(d) && !!d.initializer && isFunctionLike(d.initializer));
                }
                default:
                    return false;
            }
        }
        function getKeyFromNode(exp) {
            return `${exp.pos.toString()}:${exp.end.toString()}`;
        }
        function canBeConvertedToClass(node, checker) {
            var _a2, _b, _c, _d;
            if (isFunctionExpression(node)) {
                if (isVariableDeclaration(node.parent) && ((_a2 = node.symbol.members) == null ? void 0 : _a2.size)) {
                    return true;
                }
                const symbol = checker.getSymbolOfExpando(node, 
                /*allowDeclaration*/
                false);
                return !!(symbol && (((_b = symbol.exports) == null ? void 0 : _b.size) || ((_c = symbol.members) == null ? void 0 : _c.size)));
            }
            if (isFunctionDeclaration(node)) {
                return !!((_d = node.symbol.members) == null ? void 0 : _d.size);
            }
            return false;
        }
        function canBeConvertedToAsync(node) {
            switch (node.kind) {
                case 259 /* FunctionDeclaration */:
                case 171 /* MethodDeclaration */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                    return true;
                default:
                    return false;
            }
        }
        var visitedNestedConvertibleFunctions;
        var init_suggestionDiagnostics = __esm({
            "src/services/suggestionDiagnostics.ts"() {
                "use strict";
                init_ts4();
                visitedNestedConvertibleFunctions = /* @__PURE__ */ new Map();
            }
        });
        // src/services/transpile.ts
        function transpileModule(input, transpileOptions) {
            const diagnostics = [];
            const options = transpileOptions.compilerOptions ? fixupCompilerOptions(transpileOptions.compilerOptions, diagnostics) : {};
            const defaultOptions = getDefaultCompilerOptions2();
            for (const key in defaultOptions) {
                if (hasProperty(defaultOptions, key) && options[key] === void 0) {
                    options[key] = defaultOptions[key];
                }
            }
            for (const option of transpileOptionValueCompilerOptions) {
                if (options.verbatimModuleSyntax && optionsRedundantWithVerbatimModuleSyntax.has(option.name)) {
                    continue;
                }
                options[option.name] = option.transpileOptionValue;
            }
            options.suppressOutputPathCheck = true;
            options.allowNonTsExtensions = true;
            const newLine = getNewLineCharacter(options);
            const compilerHost = {
                getSourceFile: (fileName) => fileName === normalizePath(inputFileName) ? sourceFile : void 0,
                writeFile: (name, text) => {
                    if (fileExtensionIs(name, ".map")) {
                        Debug.assertEqual(sourceMapText, void 0, "Unexpected multiple source map outputs, file:", name);
                        sourceMapText = text;
                    }
                    else {
                        Debug.assertEqual(outputText, void 0, "Unexpected multiple outputs, file:", name);
                        outputText = text;
                    }
                },
                getDefaultLibFileName: () => "lib.d.ts",
                useCaseSensitiveFileNames: () => false,
                getCanonicalFileName: (fileName) => fileName,
                getCurrentDirectory: () => "",
                getNewLine: () => newLine,
                fileExists: (fileName) => fileName === inputFileName,
                readFile: () => "",
                directoryExists: () => true,
                getDirectories: () => []
            };
            const inputFileName = transpileOptions.fileName || (transpileOptions.compilerOptions && transpileOptions.compilerOptions.jsx ? "module.tsx" : "module.ts");
            const sourceFile = createSourceFile(inputFileName, input, {
                languageVersion: getEmitScriptTarget(options),
                impliedNodeFormat: getImpliedNodeFormatForFile(toPath(inputFileName, "", compilerHost.getCanonicalFileName), 
                /*cache*/
                void 0, compilerHost, options),
                setExternalModuleIndicator: getSetExternalModuleIndicator(options)
            });
            if (transpileOptions.moduleName) {
                sourceFile.moduleName = transpileOptions.moduleName;
            }
            if (transpileOptions.renamedDependencies) {
                sourceFile.renamedDependencies = new Map(Object.entries(transpileOptions.renamedDependencies));
            }
            let outputText;
            let sourceMapText;
            const program = createProgram([inputFileName], options, compilerHost);
            if (transpileOptions.reportDiagnostics) {
                addRange(
                /*to*/
                diagnostics, 
                /*from*/
                program.getSyntacticDiagnostics(sourceFile));
                addRange(
                /*to*/
                diagnostics, 
                /*from*/
                program.getOptionsDiagnostics());
            }
            program.emit(
            /*targetSourceFile*/
            void 0, 
            /*writeFile*/
            void 0, 
            /*cancellationToken*/
            void 0, 
            /*emitOnlyDtsFiles*/
            void 0, transpileOptions.transformers);
            if (outputText === void 0)
                return Debug.fail("Output generation failed");
            return { outputText, diagnostics, sourceMapText };
        }
        function transpile(input, compilerOptions, fileName, diagnostics, moduleName) {
            const output = transpileModule(input, { compilerOptions, fileName, reportDiagnostics: !!diagnostics, moduleName });
            addRange(diagnostics, output.diagnostics);
            return output.outputText;
        }
        function fixupCompilerOptions(options, diagnostics) {
            commandLineOptionsStringToEnum = commandLineOptionsStringToEnum || filter(optionDeclarations, (o) => typeof o.type === "object" && !forEachEntry(o.type, (v) => typeof v !== "number"));
            options = cloneCompilerOptions(options);
            for (const opt of commandLineOptionsStringToEnum) {
                if (!hasProperty(options, opt.name)) {
                    continue;
                }
                const value = options[opt.name];
                if (isString(value)) {
                    options[opt.name] = parseCustomTypeOption(opt, value, diagnostics);
                }
                else {
                    if (!forEachEntry(opt.type, (v) => v === value)) {
                        diagnostics.push(createCompilerDiagnosticForInvalidCustomType(opt));
                    }
                }
            }
            return options;
        }
        var optionsRedundantWithVerbatimModuleSyntax, commandLineOptionsStringToEnum;
        var init_transpile = __esm({
            "src/services/transpile.ts"() {
                "use strict";
                init_ts4();
                optionsRedundantWithVerbatimModuleSyntax = /* @__PURE__ */ new Set([
                    "isolatedModules",
                    "preserveValueImports",
                    "importsNotUsedAsValues"
                ]);
            }
        });
        // src/services/navigateTo.ts
        function getNavigateToItems(sourceFiles, checker, cancellationToken, searchValue, maxResultCount, excludeDtsFiles) {
            const patternMatcher = createPatternMatcher(searchValue);
            if (!patternMatcher)
                return emptyArray;
            const rawItems = [];
            for (const sourceFile of sourceFiles) {
                cancellationToken.throwIfCancellationRequested();
                if (excludeDtsFiles && sourceFile.isDeclarationFile) {
                    continue;
                }
                sourceFile.getNamedDeclarations().forEach((declarations, name) => {
                    getItemsFromNamedDeclaration(patternMatcher, name, declarations, checker, sourceFile.fileName, rawItems);
                });
            }
            rawItems.sort(compareNavigateToItems);
            return (maxResultCount === void 0 ? rawItems : rawItems.slice(0, maxResultCount)).map(createNavigateToItem);
        }
        function getItemsFromNamedDeclaration(patternMatcher, name, declarations, checker, fileName, rawItems) {
            const match = patternMatcher.getMatchForLastSegmentOfPattern(name);
            if (!match) {
                return;
            }
            for (const declaration of declarations) {
                if (!shouldKeepItem(declaration, checker))
                    continue;
                if (patternMatcher.patternContainsDots) {
                    const fullMatch = patternMatcher.getFullMatch(getContainers(declaration), name);
                    if (fullMatch) {
                        rawItems.push({ name, fileName, matchKind: fullMatch.kind, isCaseSensitive: fullMatch.isCaseSensitive, declaration });
                    }
                }
                else {
                    rawItems.push({ name, fileName, matchKind: match.kind, isCaseSensitive: match.isCaseSensitive, declaration });
                }
            }
        }
        function shouldKeepItem(declaration, checker) {
            switch (declaration.kind) {
                case 270 /* ImportClause */:
                case 273 /* ImportSpecifier */:
                case 268 /* ImportEqualsDeclaration */:
                    const importer = checker.getSymbolAtLocation(declaration.name);
                    const imported = checker.getAliasedSymbol(importer);
                    return importer.escapedName !== imported.escapedName;
                default:
                    return true;
            }
        }
        function tryAddSingleDeclarationName(declaration, containers) {
            const name = getNameOfDeclaration(declaration);
            return !!name && (pushLiteral(name, containers) || name.kind === 164 /* ComputedPropertyName */ && tryAddComputedPropertyName(name.expression, containers));
        }
        function tryAddComputedPropertyName(expression, containers) {
            return pushLiteral(expression, containers) || isPropertyAccessExpression(expression) && (containers.push(expression.name.text), true) && tryAddComputedPropertyName(expression.expression, containers);
        }
        function pushLiteral(node, containers) {
            return isPropertyNameLiteral(node) && (containers.push(getTextOfIdentifierOrLiteral(node)), true);
        }
        function getContainers(declaration) {
            const containers = [];
            const name = getNameOfDeclaration(declaration);
            if (name && name.kind === 164 /* ComputedPropertyName */ && !tryAddComputedPropertyName(name.expression, containers)) {
                return emptyArray;
            }
            containers.shift();
            let container = getContainerNode(declaration);
            while (container) {
                if (!tryAddSingleDeclarationName(container, containers)) {
                    return emptyArray;
                }
                container = getContainerNode(container);
            }
            return containers.reverse();
        }
        function compareNavigateToItems(i1, i2) {
            return compareValues(i1.matchKind, i2.matchKind) || compareStringsCaseSensitiveUI(i1.name, i2.name);
        }
        function createNavigateToItem(rawItem) {
            const declaration = rawItem.declaration;
            const container = getContainerNode(declaration);
            const containerName = container && getNameOfDeclaration(container);
            return {
                name: rawItem.name,
                kind: getNodeKind(declaration),
                kindModifiers: getNodeModifiers(declaration),
                matchKind: PatternMatchKind[rawItem.matchKind],
                isCaseSensitive: rawItem.isCaseSensitive,
                fileName: rawItem.fileName,
                textSpan: createTextSpanFromNode(declaration),
                // TODO(jfreeman): What should be the containerName when the container has a computed name?
                containerName: containerName ? containerName.text : "",
                containerKind: containerName ? getNodeKind(container) : "" /* unknown */
            };
        }
        var init_navigateTo = __esm({
            "src/services/navigateTo.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/_namespaces/ts.NavigateTo.ts
        var ts_NavigateTo_exports = {};
        __export(ts_NavigateTo_exports, {
            getNavigateToItems: () => getNavigateToItems
        });
        var init_ts_NavigateTo = __esm({
            "src/services/_namespaces/ts.NavigateTo.ts"() {
                "use strict";
                init_navigateTo();
            }
        });
        // src/services/navigationBar.ts
        function getNavigationBarItems(sourceFile, cancellationToken) {
            curCancellationToken = cancellationToken;
            curSourceFile = sourceFile;
            try {
                return map(primaryNavBarMenuItems(rootNavigationBarNode(sourceFile)), convertToPrimaryNavBarMenuItem);
            }
            finally {
                reset();
            }
        }
        function getNavigationTree(sourceFile, cancellationToken) {
            curCancellationToken = cancellationToken;
            curSourceFile = sourceFile;
            try {
                return convertToTree(rootNavigationBarNode(sourceFile));
            }
            finally {
                reset();
            }
        }
        function reset() {
            curSourceFile = void 0;
            curCancellationToken = void 0;
            parentsStack = [];
            parent = void 0;
            emptyChildItemArray = [];
        }
        function nodeText(node) {
            return cleanText(node.getText(curSourceFile));
        }
        function navigationBarNodeKind(n) {
            return n.node.kind;
        }
        function pushChild(parent2, child) {
            if (parent2.children) {
                parent2.children.push(child);
            }
            else {
                parent2.children = [child];
            }
        }
        function rootNavigationBarNode(sourceFile) {
            Debug.assert(!parentsStack.length);
            const root = { node: sourceFile, name: void 0, additionalNodes: void 0, parent: void 0, children: void 0, indent: 0 };
            parent = root;
            for (const statement of sourceFile.statements) {
                addChildrenRecursively(statement);
            }
            endNode();
            Debug.assert(!parent && !parentsStack.length);
            return root;
        }
        function addLeafNode(node, name) {
            pushChild(parent, emptyNavigationBarNode(node, name));
        }
        function emptyNavigationBarNode(node, name) {
            return {
                node,
                name: name || (isDeclaration(node) || isExpression(node) ? getNameOfDeclaration(node) : void 0),
                additionalNodes: void 0,
                parent,
                children: void 0,
                indent: parent.indent + 1
            };
        }
        function addTrackedEs5Class(name) {
            if (!trackedEs5Classes) {
                trackedEs5Classes = /* @__PURE__ */ new Map();
            }
            trackedEs5Classes.set(name, true);
        }
        function endNestedNodes(depth) {
            for (let i = 0; i < depth; i++)
                endNode();
        }
        function startNestedNodes(targetNode, entityName) {
            const names = [];
            while (!isPropertyNameLiteral(entityName)) {
                const name = getNameOrArgument(entityName);
                const nameText = getElementOrPropertyAccessName(entityName);
                entityName = entityName.expression;
                if (nameText === "prototype" || isPrivateIdentifier(name))
                    continue;
                names.push(name);
            }
            names.push(entityName);
            for (let i = names.length - 1; i > 0; i--) {
                const name = names[i];
                startNode(targetNode, name);
            }
            return [names.length - 1, names[0]];
        }
        function startNode(node, name) {
            const navNode = emptyNavigationBarNode(node, name);
            pushChild(parent, navNode);
            parentsStack.push(parent);
            trackedEs5ClassesStack.push(trackedEs5Classes);
            trackedEs5Classes = void 0;
            parent = navNode;
        }
        function endNode() {
            if (parent.children) {
                mergeChildren(parent.children, parent);
                sortChildren(parent.children);
            }
            parent = parentsStack.pop();
            trackedEs5Classes = trackedEs5ClassesStack.pop();
        }
        function addNodeWithRecursiveChild(node, child, name) {
            startNode(node, name);
            addChildrenRecursively(child);
            endNode();
        }
        function addNodeWithRecursiveInitializer(node) {
            if (node.initializer && isFunctionOrClassExpression(node.initializer)) {
                startNode(node);
                forEachChild(node.initializer, addChildrenRecursively);
                endNode();
            }
            else {
                addNodeWithRecursiveChild(node, node.initializer);
            }
        }
        function hasNavigationBarName(node) {
            return !hasDynamicName(node) || node.kind !== 223 /* BinaryExpression */ && isPropertyAccessExpression(node.name.expression) && isIdentifier(node.name.expression.expression) && idText(node.name.expression.expression) === "Symbol";
        }
        function addChildrenRecursively(node) {
            curCancellationToken.throwIfCancellationRequested();
            if (!node || isToken(node)) {
                return;
            }
            switch (node.kind) {
                case 173 /* Constructor */:
                    const ctr = node;
                    addNodeWithRecursiveChild(ctr, ctr.body);
                    for (const param of ctr.parameters) {
                        if (isParameterPropertyDeclaration(param, ctr)) {
                            addLeafNode(param);
                        }
                    }
                    break;
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 170 /* MethodSignature */:
                    if (hasNavigationBarName(node)) {
                        addNodeWithRecursiveChild(node, node.body);
                    }
                    break;
                case 169 /* PropertyDeclaration */:
                    if (hasNavigationBarName(node)) {
                        addNodeWithRecursiveInitializer(node);
                    }
                    break;
                case 168 /* PropertySignature */:
                    if (hasNavigationBarName(node)) {
                        addLeafNode(node);
                    }
                    break;
                case 270 /* ImportClause */:
                    const importClause = node;
                    if (importClause.name) {
                        addLeafNode(importClause.name);
                    }
                    const { namedBindings } = importClause;
                    if (namedBindings) {
                        if (namedBindings.kind === 271 /* NamespaceImport */) {
                            addLeafNode(namedBindings);
                        }
                        else {
                            for (const element of namedBindings.elements) {
                                addLeafNode(element);
                            }
                        }
                    }
                    break;
                case 300 /* ShorthandPropertyAssignment */:
                    addNodeWithRecursiveChild(node, node.name);
                    break;
                case 301 /* SpreadAssignment */:
                    const { expression } = node;
                    isIdentifier(expression) ? addLeafNode(node, expression) : addLeafNode(node);
                    break;
                case 205 /* BindingElement */:
                case 299 /* PropertyAssignment */:
                case 257 /* VariableDeclaration */: {
                    const child = node;
                    if (isBindingPattern(child.name)) {
                        addChildrenRecursively(child.name);
                    }
                    else {
                        addNodeWithRecursiveInitializer(child);
                    }
                    break;
                }
                case 259 /* FunctionDeclaration */:
                    const nameNode = node.name;
                    if (nameNode && isIdentifier(nameNode)) {
                        addTrackedEs5Class(nameNode.text);
                    }
                    addNodeWithRecursiveChild(node, node.body);
                    break;
                case 216 /* ArrowFunction */:
                case 215 /* FunctionExpression */:
                    addNodeWithRecursiveChild(node, node.body);
                    break;
                case 263 /* EnumDeclaration */:
                    startNode(node);
                    for (const member of node.members) {
                        if (!isComputedProperty(member)) {
                            addLeafNode(member);
                        }
                    }
                    endNode();
                    break;
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 261 /* InterfaceDeclaration */:
                    startNode(node);
                    for (const member of node.members) {
                        addChildrenRecursively(member);
                    }
                    endNode();
                    break;
                case 264 /* ModuleDeclaration */:
                    addNodeWithRecursiveChild(node, getInteriorModule(node).body);
                    break;
                case 274 /* ExportAssignment */: {
                    const expression2 = node.expression;
                    const child = isObjectLiteralExpression(expression2) || isCallExpression(expression2) ? expression2 : isArrowFunction(expression2) || isFunctionExpression(expression2) ? expression2.body : void 0;
                    if (child) {
                        startNode(node);
                        addChildrenRecursively(child);
                        endNode();
                    }
                    else {
                        addLeafNode(node);
                    }
                    break;
                }
                case 278 /* ExportSpecifier */:
                case 268 /* ImportEqualsDeclaration */:
                case 178 /* IndexSignature */:
                case 176 /* CallSignature */:
                case 177 /* ConstructSignature */:
                case 262 /* TypeAliasDeclaration */:
                    addLeafNode(node);
                    break;
                case 210 /* CallExpression */:
                case 223 /* BinaryExpression */: {
                    const special = getAssignmentDeclarationKind(node);
                    switch (special) {
                        case 1 /* ExportsProperty */:
                        case 2 /* ModuleExports */:
                            addNodeWithRecursiveChild(node, node.right);
                            return;
                        case 6 /* Prototype */:
                        case 3 /* PrototypeProperty */: {
                            const binaryExpression = node;
                            const assignmentTarget = binaryExpression.left;
                            const prototypeAccess = special === 3 /* PrototypeProperty */ ? assignmentTarget.expression : assignmentTarget;
                            let depth = 0;
                            let className;
                            if (isIdentifier(prototypeAccess.expression)) {
                                addTrackedEs5Class(prototypeAccess.expression.text);
                                className = prototypeAccess.expression;
                            }
                            else {
                                [depth, className] = startNestedNodes(binaryExpression, prototypeAccess.expression);
                            }
                            if (special === 6 /* Prototype */) {
                                if (isObjectLiteralExpression(binaryExpression.right)) {
                                    if (binaryExpression.right.properties.length > 0) {
                                        startNode(binaryExpression, className);
                                        forEachChild(binaryExpression.right, addChildrenRecursively);
                                        endNode();
                                    }
                                }
                            }
                            else if (isFunctionExpression(binaryExpression.right) || isArrowFunction(binaryExpression.right)) {
                                addNodeWithRecursiveChild(node, binaryExpression.right, className);
                            }
                            else {
                                startNode(binaryExpression, className);
                                addNodeWithRecursiveChild(node, binaryExpression.right, assignmentTarget.name);
                                endNode();
                            }
                            endNestedNodes(depth);
                            return;
                        }
                        case 7 /* ObjectDefinePropertyValue */:
                        case 9 /* ObjectDefinePrototypeProperty */: {
                            const defineCall = node;
                            const className = special === 7 /* ObjectDefinePropertyValue */ ? defineCall.arguments[0] : defineCall.arguments[0].expression;
                            const memberName = defineCall.arguments[1];
                            const [depth, classNameIdentifier] = startNestedNodes(node, className);
                            startNode(node, classNameIdentifier);
                            startNode(node, setTextRange(factory.createIdentifier(memberName.text), memberName));
                            addChildrenRecursively(node.arguments[2]);
                            endNode();
                            endNode();
                            endNestedNodes(depth);
                            return;
                        }
                        case 5 /* Property */: {
                            const binaryExpression = node;
                            const assignmentTarget = binaryExpression.left;
                            const targetFunction = assignmentTarget.expression;
                            if (isIdentifier(targetFunction) && getElementOrPropertyAccessName(assignmentTarget) !== "prototype" && trackedEs5Classes && trackedEs5Classes.has(targetFunction.text)) {
                                if (isFunctionExpression(binaryExpression.right) || isArrowFunction(binaryExpression.right)) {
                                    addNodeWithRecursiveChild(node, binaryExpression.right, targetFunction);
                                }
                                else if (isBindableStaticAccessExpression(assignmentTarget)) {
                                    startNode(binaryExpression, targetFunction);
                                    addNodeWithRecursiveChild(binaryExpression.left, binaryExpression.right, getNameOrArgument(assignmentTarget));
                                    endNode();
                                }
                                return;
                            }
                            break;
                        }
                        case 4 /* ThisProperty */:
                        case 0 /* None */:
                        case 8 /* ObjectDefinePropertyExports */:
                            break;
                        default:
                            Debug.assertNever(special);
                    }
                }
                default:
                    if (hasJSDocNodes(node)) {
                        forEach(node.jsDoc, (jsDoc) => {
                            forEach(jsDoc.tags, (tag) => {
                                if (isJSDocTypeAlias(tag)) {
                                    addLeafNode(tag);
                                }
                            });
                        });
                    }
                    forEachChild(node, addChildrenRecursively);
            }
        }
        function mergeChildren(children, node) {
            const nameToItems = /* @__PURE__ */ new Map();
            filterMutate(children, (child, index) => {
                const declName = child.name || getNameOfDeclaration(child.node);
                const name = declName && nodeText(declName);
                if (!name) {
                    return true;
                }
                const itemsWithSameName = nameToItems.get(name);
                if (!itemsWithSameName) {
                    nameToItems.set(name, child);
                    return true;
                }
                if (itemsWithSameName instanceof Array) {
                    for (const itemWithSameName of itemsWithSameName) {
                        if (tryMerge(itemWithSameName, child, index, node)) {
                            return false;
                        }
                    }
                    itemsWithSameName.push(child);
                    return true;
                }
                else {
                    const itemWithSameName = itemsWithSameName;
                    if (tryMerge(itemWithSameName, child, index, node)) {
                        return false;
                    }
                    nameToItems.set(name, [itemWithSameName, child]);
                    return true;
                }
            });
        }
        function tryMergeEs5Class(a, b, bIndex, parent2) {
            function isPossibleConstructor(node) {
                return isFunctionExpression(node) || isFunctionDeclaration(node) || isVariableDeclaration(node);
            }
            const bAssignmentDeclarationKind = isBinaryExpression(b.node) || isCallExpression(b.node) ? getAssignmentDeclarationKind(b.node) : 0 /* None */;
            const aAssignmentDeclarationKind = isBinaryExpression(a.node) || isCallExpression(a.node) ? getAssignmentDeclarationKind(a.node) : 0 /* None */;
            if (isEs5ClassMember[bAssignmentDeclarationKind] && isEs5ClassMember[aAssignmentDeclarationKind] || isPossibleConstructor(a.node) && isEs5ClassMember[bAssignmentDeclarationKind] || isPossibleConstructor(b.node) && isEs5ClassMember[aAssignmentDeclarationKind] || isClassDeclaration(a.node) && isSynthesized(a.node) && isEs5ClassMember[bAssignmentDeclarationKind] || isClassDeclaration(b.node) && isEs5ClassMember[aAssignmentDeclarationKind] || isClassDeclaration(a.node) && isSynthesized(a.node) && isPossibleConstructor(b.node) || isClassDeclaration(b.node) && isPossibleConstructor(a.node) && isSynthesized(a.node)) {
                let lastANode = a.additionalNodes && lastOrUndefined(a.additionalNodes) || a.node;
                if (!isClassDeclaration(a.node) && !isClassDeclaration(b.node) || isPossibleConstructor(a.node) || isPossibleConstructor(b.node)) {
                    const ctorFunction = isPossibleConstructor(a.node) ? a.node : isPossibleConstructor(b.node) ? b.node : void 0;
                    if (ctorFunction !== void 0) {
                        const ctorNode = setTextRange(factory.createConstructorDeclaration(
                        /* modifiers */
                        void 0, [], 
                        /* body */
                        void 0), ctorFunction);
                        const ctor = emptyNavigationBarNode(ctorNode);
                        ctor.indent = a.indent + 1;
                        ctor.children = a.node === ctorFunction ? a.children : b.children;
                        a.children = a.node === ctorFunction ? concatenate([ctor], b.children || [b]) : concatenate(a.children || [{ ...a }], [ctor]);
                    }
                    else {
                        if (a.children || b.children) {
                            a.children = concatenate(a.children || [{ ...a }], b.children || [b]);
                            if (a.children) {
                                mergeChildren(a.children, a);
                                sortChildren(a.children);
                            }
                        }
                    }
                    lastANode = a.node = setTextRange(factory.createClassDeclaration(
                    /* modifiers */
                    void 0, a.name || factory.createIdentifier("__class__"), 
                    /* typeParameters */
                    void 0, 
                    /* heritageClauses */
                    void 0, []), a.node);
                }
                else {
                    a.children = concatenate(a.children, b.children);
                    if (a.children) {
                        mergeChildren(a.children, a);
                    }
                }
                const bNode = b.node;
                if (parent2.children[bIndex - 1].node.end === lastANode.end) {
                    setTextRange(lastANode, { pos: lastANode.pos, end: bNode.end });
                }
                else {
                    if (!a.additionalNodes)
                        a.additionalNodes = [];
                    a.additionalNodes.push(setTextRange(factory.createClassDeclaration(
                    /* modifiers */
                    void 0, a.name || factory.createIdentifier("__class__"), 
                    /* typeParameters */
                    void 0, 
                    /* heritageClauses */
                    void 0, []), b.node));
                }
                return true;
            }
            return bAssignmentDeclarationKind === 0 /* None */ ? false : true;
        }
        function tryMerge(a, b, bIndex, parent2) {
            if (tryMergeEs5Class(a, b, bIndex, parent2)) {
                return true;
            }
            if (shouldReallyMerge(a.node, b.node, parent2)) {
                merge(a, b);
                return true;
            }
            return false;
        }
        function shouldReallyMerge(a, b, parent2) {
            if (a.kind !== b.kind || a.parent !== b.parent && !(isOwnChild(a, parent2) && isOwnChild(b, parent2))) {
                return false;
            }
            switch (a.kind) {
                case 169 /* PropertyDeclaration */:
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    return isStatic(a) === isStatic(b);
                case 264 /* ModuleDeclaration */:
                    return areSameModule(a, b) && getFullyQualifiedModuleName(a) === getFullyQualifiedModuleName(b);
                default:
                    return true;
            }
        }
        function isSynthesized(node) {
            return !!(node.flags & 8 /* Synthesized */);
        }
        function isOwnChild(n, parent2) {
            const par = isModuleBlock(n.parent) ? n.parent.parent : n.parent;
            return par === parent2.node || contains(parent2.additionalNodes, par);
        }
        function areSameModule(a, b) {
            if (!a.body || !b.body) {
                return a.body === b.body;
            }
            return a.body.kind === b.body.kind && (a.body.kind !== 264 /* ModuleDeclaration */ || areSameModule(a.body, b.body));
        }
        function merge(target, source) {
            target.additionalNodes = target.additionalNodes || [];
            target.additionalNodes.push(source.node);
            if (source.additionalNodes) {
                target.additionalNodes.push(...source.additionalNodes);
            }
            target.children = concatenate(target.children, source.children);
            if (target.children) {
                mergeChildren(target.children, target);
                sortChildren(target.children);
            }
        }
        function sortChildren(children) {
            children.sort(compareChildren);
        }
        function compareChildren(child1, child2) {
            return compareStringsCaseSensitiveUI(tryGetName(child1.node), tryGetName(child2.node)) || compareValues(navigationBarNodeKind(child1), navigationBarNodeKind(child2));
        }
        function tryGetName(node) {
            if (node.kind === 264 /* ModuleDeclaration */) {
                return getModuleName(node);
            }
            const declName = getNameOfDeclaration(node);
            if (declName && isPropertyName(declName)) {
                const propertyName = getPropertyNameForPropertyNameNode(declName);
                return propertyName && unescapeLeadingUnderscores(propertyName);
            }
            switch (node.kind) {
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                case 228 /* ClassExpression */:
                    return getFunctionOrClassName(node);
                default:
                    return void 0;
            }
        }
        function getItemName(node, name) {
            if (node.kind === 264 /* ModuleDeclaration */) {
                return cleanText(getModuleName(node));
            }
            if (name) {
                const text = isIdentifier(name) ? name.text : isElementAccessExpression(name) ? `[${nodeText(name.argumentExpression)}]` : nodeText(name);
                if (text.length > 0) {
                    return cleanText(text);
                }
            }
            switch (node.kind) {
                case 308 /* SourceFile */:
                    const sourceFile = node;
                    return isExternalModule(sourceFile) ? `"${escapeString(getBaseFileName(removeFileExtension(normalizePath(sourceFile.fileName))))}"` : "<global>";
                case 274 /* ExportAssignment */:
                    return isExportAssignment(node) && node.isExportEquals ? "export=" /* ExportEquals */ : "default" /* Default */;
                case 216 /* ArrowFunction */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                    if (getSyntacticModifierFlags(node) & 1024 /* Default */) {
                        return "default";
                    }
                    return getFunctionOrClassName(node);
                case 173 /* Constructor */:
                    return "constructor";
                case 177 /* ConstructSignature */:
                    return "new()";
                case 176 /* CallSignature */:
                    return "()";
                case 178 /* IndexSignature */:
                    return "[]";
                default:
                    return "<unknown>";
            }
        }
        function primaryNavBarMenuItems(root) {
            const primaryNavBarMenuItems2 = [];
            function recur(item) {
                if (shouldAppearInPrimaryNavBarMenu(item)) {
                    primaryNavBarMenuItems2.push(item);
                    if (item.children) {
                        for (const child of item.children) {
                            recur(child);
                        }
                    }
                }
            }
            recur(root);
            return primaryNavBarMenuItems2;
            function shouldAppearInPrimaryNavBarMenu(item) {
                if (item.children) {
                    return true;
                }
                switch (navigationBarNodeKind(item)) {
                    case 260 /* ClassDeclaration */:
                    case 228 /* ClassExpression */:
                    case 263 /* EnumDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                    case 264 /* ModuleDeclaration */:
                    case 308 /* SourceFile */:
                    case 262 /* TypeAliasDeclaration */:
                    case 349 /* JSDocTypedefTag */:
                    case 341 /* JSDocCallbackTag */:
                        return true;
                    case 216 /* ArrowFunction */:
                    case 259 /* FunctionDeclaration */:
                    case 215 /* FunctionExpression */:
                        return isTopLevelFunctionDeclaration(item);
                    default:
                        return false;
                }
                function isTopLevelFunctionDeclaration(item2) {
                    if (!item2.node.body) {
                        return false;
                    }
                    switch (navigationBarNodeKind(item2.parent)) {
                        case 265 /* ModuleBlock */:
                        case 308 /* SourceFile */:
                        case 171 /* MethodDeclaration */:
                        case 173 /* Constructor */:
                            return true;
                        default:
                            return false;
                    }
                }
            }
        }
        function convertToTree(n) {
            return {
                text: getItemName(n.node, n.name),
                kind: getNodeKind(n.node),
                kindModifiers: getModifiers2(n.node),
                spans: getSpans(n),
                nameSpan: n.name && getNodeSpan(n.name),
                childItems: map(n.children, convertToTree)
            };
        }
        function convertToPrimaryNavBarMenuItem(n) {
            return {
                text: getItemName(n.node, n.name),
                kind: getNodeKind(n.node),
                kindModifiers: getModifiers2(n.node),
                spans: getSpans(n),
                childItems: map(n.children, convertToSecondaryNavBarMenuItem) || emptyChildItemArray,
                indent: n.indent,
                bolded: false,
                grayed: false
            };
            function convertToSecondaryNavBarMenuItem(n2) {
                return {
                    text: getItemName(n2.node, n2.name),
                    kind: getNodeKind(n2.node),
                    kindModifiers: getNodeModifiers(n2.node),
                    spans: getSpans(n2),
                    childItems: emptyChildItemArray,
                    indent: 0,
                    bolded: false,
                    grayed: false
                };
            }
        }
        function getSpans(n) {
            const spans = [getNodeSpan(n.node)];
            if (n.additionalNodes) {
                for (const node of n.additionalNodes) {
                    spans.push(getNodeSpan(node));
                }
            }
            return spans;
        }
        function getModuleName(moduleDeclaration) {
            if (isAmbientModule(moduleDeclaration)) {
                return getTextOfNode(moduleDeclaration.name);
            }
            return getFullyQualifiedModuleName(moduleDeclaration);
        }
        function getFullyQualifiedModuleName(moduleDeclaration) {
            const result = [getTextOfIdentifierOrLiteral(moduleDeclaration.name)];
            while (moduleDeclaration.body && moduleDeclaration.body.kind === 264 /* ModuleDeclaration */) {
                moduleDeclaration = moduleDeclaration.body;
                result.push(getTextOfIdentifierOrLiteral(moduleDeclaration.name));
            }
            return result.join(".");
        }
        function getInteriorModule(decl) {
            return decl.body && isModuleDeclaration(decl.body) ? getInteriorModule(decl.body) : decl;
        }
        function isComputedProperty(member) {
            return !member.name || member.name.kind === 164 /* ComputedPropertyName */;
        }
        function getNodeSpan(node) {
            return node.kind === 308 /* SourceFile */ ? createTextSpanFromRange(node) : createTextSpanFromNode(node, curSourceFile);
        }
        function getModifiers2(node) {
            if (node.parent && node.parent.kind === 257 /* VariableDeclaration */) {
                node = node.parent;
            }
            return getNodeModifiers(node);
        }
        function getFunctionOrClassName(node) {
            const { parent: parent2 } = node;
            if (node.name && getFullWidth(node.name) > 0) {
                return cleanText(declarationNameToString(node.name));
            }
            else if (isVariableDeclaration(parent2)) {
                return cleanText(declarationNameToString(parent2.name));
            }
            else if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 63 /* EqualsToken */) {
                return nodeText(parent2.left).replace(whiteSpaceRegex, "");
            }
            else if (isPropertyAssignment(parent2)) {
                return nodeText(parent2.name);
            }
            else if (getSyntacticModifierFlags(node) & 1024 /* Default */) {
                return "default";
            }
            else if (isClassLike(node)) {
                return "<class>";
            }
            else if (isCallExpression(parent2)) {
                let name = getCalledExpressionName(parent2.expression);
                if (name !== void 0) {
                    name = cleanText(name);
                    if (name.length > maxLength) {
                        return `${name} callback`;
                    }
                    const args = cleanText(mapDefined(parent2.arguments, (a) => isStringLiteralLike(a) ? a.getText(curSourceFile) : void 0).join(", "));
                    return `${name}(${args}) callback`;
                }
            }
            return "<function>";
        }
        function getCalledExpressionName(expr) {
            if (isIdentifier(expr)) {
                return expr.text;
            }
            else if (isPropertyAccessExpression(expr)) {
                const left = getCalledExpressionName(expr.expression);
                const right = expr.name.text;
                return left === void 0 ? right : `${left}.${right}`;
            }
            else {
                return void 0;
            }
        }
        function isFunctionOrClassExpression(node) {
            switch (node.kind) {
                case 216 /* ArrowFunction */:
                case 215 /* FunctionExpression */:
                case 228 /* ClassExpression */:
                    return true;
                default:
                    return false;
            }
        }
        function cleanText(text) {
            text = text.length > maxLength ? text.substring(0, maxLength) + "..." : text;
            return text.replace(/\\?(\r?\n|\r|\u2028|\u2029)/g, "");
        }
        var whiteSpaceRegex, maxLength, curCancellationToken, curSourceFile, parentsStack, parent, trackedEs5ClassesStack, trackedEs5Classes, emptyChildItemArray, isEs5ClassMember;
        var init_navigationBar = __esm({
            "src/services/navigationBar.ts"() {
                "use strict";
                init_ts4();
                whiteSpaceRegex = /\s+/g;
                maxLength = 150;
                parentsStack = [];
                trackedEs5ClassesStack = [];
                emptyChildItemArray = [];
                isEs5ClassMember = {
                    [5 /* Property */]: true,
                    [3 /* PrototypeProperty */]: true,
                    [7 /* ObjectDefinePropertyValue */]: true,
                    [9 /* ObjectDefinePrototypeProperty */]: true,
                    [0 /* None */]: false,
                    [1 /* ExportsProperty */]: false,
                    [2 /* ModuleExports */]: false,
                    [8 /* ObjectDefinePropertyExports */]: false,
                    [6 /* Prototype */]: true,
                    [4 /* ThisProperty */]: false
                };
            }
        });
        // src/services/_namespaces/ts.NavigationBar.ts
        var ts_NavigationBar_exports = {};
        __export(ts_NavigationBar_exports, {
            getNavigationBarItems: () => getNavigationBarItems,
            getNavigationTree: () => getNavigationTree
        });
        var init_ts_NavigationBar = __esm({
            "src/services/_namespaces/ts.NavigationBar.ts"() {
                "use strict";
                init_navigationBar();
            }
        });
        // src/services/services.ts
        function createNode(kind, pos, end, parent2) {
            const node = isNodeKind(kind) ? new NodeObject(kind, pos, end) : kind === 79 /* Identifier */ ? new IdentifierObject(79 /* Identifier */, pos, end) : kind === 80 /* PrivateIdentifier */ ? new PrivateIdentifierObject(80 /* PrivateIdentifier */, pos, end) : new TokenObject(kind, pos, end);
            node.parent = parent2;
            node.flags = parent2.flags & 50720768 /* ContextFlags */;
            return node;
        }
        function createChildren(node, sourceFile) {
            if (!isNodeKind(node.kind)) {
                return emptyArray;
            }
            const children = [];
            if (isJSDocCommentContainingNode(node)) {
                node.forEachChild((child) => {
                    children.push(child);
                });
                return children;
            }
            scanner.setText((sourceFile || node.getSourceFile()).text);
            let pos = node.pos;
            const processNode = (child) => {
                addSyntheticNodes(children, pos, child.pos, node);
                children.push(child);
                pos = child.end;
            };
            const processNodes = (nodes) => {
                addSyntheticNodes(children, pos, nodes.pos, node);
                children.push(createSyntaxList(nodes, node));
                pos = nodes.end;
            };
            forEach(node.jsDoc, processNode);
            pos = node.pos;
            node.forEachChild(processNode, processNodes);
            addSyntheticNodes(children, pos, node.end, node);
            scanner.setText(void 0);
            return children;
        }
        function addSyntheticNodes(nodes, pos, end, parent2) {
            scanner.setTextPos(pos);
            while (pos < end) {
                const token = scanner.scan();
                const textPos = scanner.getTextPos();
                if (textPos <= end) {
                    if (token === 79 /* Identifier */) {
                        if (hasTabstop(parent2)) {
                            continue;
                        }
                        Debug.fail(`Did not expect ${Debug.formatSyntaxKind(parent2.kind)} to have an Identifier in its trivia`);
                    }
                    nodes.push(createNode(token, pos, textPos, parent2));
                }
                pos = textPos;
                if (token === 1 /* EndOfFileToken */) {
                    break;
                }
            }
        }
        function createSyntaxList(nodes, parent2) {
            const list = createNode(354 /* SyntaxList */, nodes.pos, nodes.end, parent2);
            list._children = [];
            let pos = nodes.pos;
            for (const node of nodes) {
                addSyntheticNodes(list._children, pos, node.pos, parent2);
                list._children.push(node);
                pos = node.end;
            }
            addSyntheticNodes(list._children, pos, nodes.end, parent2);
            return list;
        }
        function hasJSDocInheritDocTag(node) {
            return getJSDocTags(node).some((tag) => tag.tagName.text === "inheritDoc" || tag.tagName.text === "inheritdoc");
        }
        function getJsDocTagsOfDeclarations(declarations, checker) {
            if (!declarations)
                return emptyArray;
            let tags = ts_JsDoc_exports.getJsDocTagsFromDeclarations(declarations, checker);
            if (checker && (tags.length === 0 || declarations.some(hasJSDocInheritDocTag))) {
                const seenSymbols = /* @__PURE__ */ new Set();
                for (const declaration of declarations) {
                    const inheritedTags = findBaseOfDeclaration(checker, declaration, (symbol) => {
                        var _a2;
                        if (!seenSymbols.has(symbol)) {
                            seenSymbols.add(symbol);
                            if (declaration.kind === 174 /* GetAccessor */ || declaration.kind === 175 /* SetAccessor */) {
                                return symbol.getContextualJsDocTags(declaration, checker);
                            }
                            return ((_a2 = symbol.declarations) == null ? void 0 : _a2.length) === 1 ? symbol.getJsDocTags() : void 0;
                        }
                    });
                    if (inheritedTags) {
                        tags = [...inheritedTags, ...tags];
                    }
                }
            }
            return tags;
        }
        function getDocumentationComment(declarations, checker) {
            if (!declarations)
                return emptyArray;
            let doc = ts_JsDoc_exports.getJsDocCommentsFromDeclarations(declarations, checker);
            if (checker && (doc.length === 0 || declarations.some(hasJSDocInheritDocTag))) {
                const seenSymbols = /* @__PURE__ */ new Set();
                for (const declaration of declarations) {
                    const inheritedDocs = findBaseOfDeclaration(checker, declaration, (symbol) => {
                        if (!seenSymbols.has(symbol)) {
                            seenSymbols.add(symbol);
                            if (declaration.kind === 174 /* GetAccessor */ || declaration.kind === 175 /* SetAccessor */) {
                                return symbol.getContextualDocumentationComment(declaration, checker);
                            }
                            return symbol.getDocumentationComment(checker);
                        }
                    });
                    if (inheritedDocs)
                        doc = doc.length === 0 ? inheritedDocs.slice() : inheritedDocs.concat(lineBreakPart(), doc);
                }
            }
            return doc;
        }
        function findBaseOfDeclaration(checker, declaration, cb) {
            var _a2;
            const classOrInterfaceDeclaration = ((_a2 = declaration.parent) == null ? void 0 : _a2.kind) === 173 /* Constructor */ ? declaration.parent.parent : declaration.parent;
            if (!classOrInterfaceDeclaration)
                return;
            const isStaticMember = hasStaticModifier(declaration);
            return firstDefined(getAllSuperTypeNodes(classOrInterfaceDeclaration), (superTypeNode) => {
                const baseType = checker.getTypeAtLocation(superTypeNode);
                const type = isStaticMember && baseType.symbol ? checker.getTypeOfSymbol(baseType.symbol) : baseType;
                const symbol = checker.getPropertyOfType(type, declaration.symbol.name);
                return symbol ? cb(symbol) : void 0;
            });
        }
        function getServicesObjectAllocator() {
            return {
                getNodeConstructor: () => NodeObject,
                getTokenConstructor: () => TokenObject,
                getIdentifierConstructor: () => IdentifierObject,
                getPrivateIdentifierConstructor: () => PrivateIdentifierObject,
                getSourceFileConstructor: () => SourceFileObject,
                getSymbolConstructor: () => SymbolObject,
                getTypeConstructor: () => TypeObject,
                getSignatureConstructor: () => SignatureObject,
                getSourceMapSourceConstructor: () => SourceMapSourceObject
            };
        }
        function toEditorSettings(optionsAsMap) {
            let allPropertiesAreCamelCased = true;
            for (const key in optionsAsMap) {
                if (hasProperty(optionsAsMap, key) && !isCamelCase(key)) {
                    allPropertiesAreCamelCased = false;
                    break;
                }
            }
            if (allPropertiesAreCamelCased) {
                return optionsAsMap;
            }
            const settings = {};
            for (const key in optionsAsMap) {
                if (hasProperty(optionsAsMap, key)) {
                    const newKey = isCamelCase(key) ? key : key.charAt(0).toLowerCase() + key.substr(1);
                    settings[newKey] = optionsAsMap[key];
                }
            }
            return settings;
        }
        function isCamelCase(s) {
            return !s.length || s.charAt(0) === s.charAt(0).toLowerCase();
        }
        function displayPartsToString(displayParts) {
            if (displayParts) {
                return map(displayParts, (displayPart2) => displayPart2.text).join("");
            }
            return "";
        }
        function getDefaultCompilerOptions2() {
            return {
                target: 1 /* ES5 */,
                jsx: 1 /* Preserve */
            };
        }
        function getSupportedCodeFixes() {
            return ts_codefix_exports.getSupportedErrorCodes();
        }
        function setSourceFileFields(sourceFile, scriptSnapshot, version2) {
            sourceFile.version = version2;
            sourceFile.scriptSnapshot = scriptSnapshot;
        }
        function createLanguageServiceSourceFile(fileName, scriptSnapshot, scriptTargetOrOptions, version2, setNodeParents, scriptKind) {
            const sourceFile = createSourceFile(fileName, getSnapshotText(scriptSnapshot), scriptTargetOrOptions, setNodeParents, scriptKind);
            setSourceFileFields(sourceFile, scriptSnapshot, version2);
            return sourceFile;
        }
        function updateLanguageServiceSourceFile(sourceFile, scriptSnapshot, version2, textChangeRange, aggressiveChecks) {
            if (textChangeRange) {
                if (version2 !== sourceFile.version) {
                    let newText;
                    const prefix = textChangeRange.span.start !== 0 ? sourceFile.text.substr(0, textChangeRange.span.start) : "";
                    const suffix = textSpanEnd(textChangeRange.span) !== sourceFile.text.length ? sourceFile.text.substr(textSpanEnd(textChangeRange.span)) : "";
                    if (textChangeRange.newLength === 0) {
                        newText = prefix && suffix ? prefix + suffix : prefix || suffix;
                    }
                    else {
                        const changedText = scriptSnapshot.getText(textChangeRange.span.start, textChangeRange.span.start + textChangeRange.newLength);
                        newText = prefix && suffix ? prefix + changedText + suffix : prefix ? prefix + changedText : changedText + suffix;
                    }
                    const newSourceFile = updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks);
                    setSourceFileFields(newSourceFile, scriptSnapshot, version2);
                    newSourceFile.nameTable = void 0;
                    if (sourceFile !== newSourceFile && sourceFile.scriptSnapshot) {
                        if (sourceFile.scriptSnapshot.dispose) {
                            sourceFile.scriptSnapshot.dispose();
                        }
                        sourceFile.scriptSnapshot = void 0;
                    }
                    return newSourceFile;
                }
            }
            const options = {
                languageVersion: sourceFile.languageVersion,
                impliedNodeFormat: sourceFile.impliedNodeFormat,
                setExternalModuleIndicator: sourceFile.setExternalModuleIndicator
            };
            return createLanguageServiceSourceFile(sourceFile.fileName, scriptSnapshot, options, version2, 
            /*setNodeParents*/
            true, sourceFile.scriptKind);
        }
        function createLanguageService(host, documentRegistry = createDocumentRegistry(host.useCaseSensitiveFileNames && host.useCaseSensitiveFileNames(), host.getCurrentDirectory()), syntaxOnlyOrLanguageServiceMode) {
            var _a2;
            let languageServiceMode;
            if (syntaxOnlyOrLanguageServiceMode === void 0) {
                languageServiceMode = 0 /* Semantic */;
            }
            else if (typeof syntaxOnlyOrLanguageServiceMode === "boolean") {
                languageServiceMode = syntaxOnlyOrLanguageServiceMode ? 2 /* Syntactic */ : 0 /* Semantic */;
            }
            else {
                languageServiceMode = syntaxOnlyOrLanguageServiceMode;
            }
            const syntaxTreeCache = new SyntaxTreeCache(host);
            let program;
            let lastProjectVersion;
            let lastTypesRootVersion = 0;
            const cancellationToken = host.getCancellationToken ? new CancellationTokenObject(host.getCancellationToken()) : NoopCancellationToken;
            const currentDirectory = host.getCurrentDirectory();
            maybeSetLocalizedDiagnosticMessages((_a2 = host.getLocalizedDiagnosticMessages) == null ? void 0 : _a2.bind(host));
            function log(message) {
                if (host.log) {
                    host.log(message);
                }
            }
            const useCaseSensitiveFileNames = hostUsesCaseSensitiveFileNames(host);
            const getCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames);
            const sourceMapper = getSourceMapper({
                useCaseSensitiveFileNames: () => useCaseSensitiveFileNames,
                getCurrentDirectory: () => currentDirectory,
                getProgram,
                fileExists: maybeBind(host, host.fileExists),
                readFile: maybeBind(host, host.readFile),
                getDocumentPositionMapper: maybeBind(host, host.getDocumentPositionMapper),
                getSourceFileLike: maybeBind(host, host.getSourceFileLike),
                log
            });
            function getValidSourceFile(fileName) {
                const sourceFile = program.getSourceFile(fileName);
                if (!sourceFile) {
                    const error = new Error(`Could not find source file: '${fileName}'.`);
                    error.ProgramFiles = program.getSourceFiles().map((f) => f.fileName);
                    throw error;
                }
                return sourceFile;
            }
            function synchronizeHostData() {
                var _a3, _b, _c;
                Debug.assert(languageServiceMode !== 2 /* Syntactic */);
                if (host.getProjectVersion) {
                    const hostProjectVersion = host.getProjectVersion();
                    if (hostProjectVersion) {
                        if (lastProjectVersion === hostProjectVersion && !((_a3 = host.hasChangedAutomaticTypeDirectiveNames) == null ? void 0 : _a3.call(host))) {
                            return;
                        }
                        lastProjectVersion = hostProjectVersion;
                    }
                }
                const typeRootsVersion = host.getTypeRootsVersion ? host.getTypeRootsVersion() : 0;
                if (lastTypesRootVersion !== typeRootsVersion) {
                    log("TypeRoots version has changed; provide new program");
                    program = void 0;
                    lastTypesRootVersion = typeRootsVersion;
                }
                const rootFileNames = host.getScriptFileNames().slice();
                const newSettings = host.getCompilationSettings() || getDefaultCompilerOptions2();
                const hasInvalidatedResolutions = host.hasInvalidatedResolutions || returnFalse;
                const hasChangedAutomaticTypeDirectiveNames = maybeBind(host, host.hasChangedAutomaticTypeDirectiveNames);
                const projectReferences = (_b = host.getProjectReferences) == null ? void 0 : _b.call(host);
                let parsedCommandLines;
                let compilerHost = {
                    getSourceFile: getOrCreateSourceFile,
                    getSourceFileByPath: getOrCreateSourceFileByPath,
                    getCancellationToken: () => cancellationToken,
                    getCanonicalFileName,
                    useCaseSensitiveFileNames: () => useCaseSensitiveFileNames,
                    getNewLine: () => getNewLineCharacter(newSettings),
                    getDefaultLibFileName: (options2) => host.getDefaultLibFileName(options2),
                    writeFile: noop,
                    getCurrentDirectory: () => currentDirectory,
                    fileExists: (fileName) => host.fileExists(fileName),
                    readFile: (fileName) => host.readFile && host.readFile(fileName),
                    getSymlinkCache: maybeBind(host, host.getSymlinkCache),
                    realpath: maybeBind(host, host.realpath),
                    directoryExists: (directoryName) => {
                        return directoryProbablyExists(directoryName, host);
                    },
                    getDirectories: (path) => {
                        return host.getDirectories ? host.getDirectories(path) : [];
                    },
                    readDirectory: (path, extensions, exclude, include, depth) => {
                        Debug.checkDefined(host.readDirectory, "'LanguageServiceHost.readDirectory' must be implemented to correctly process 'projectReferences'");
                        return host.readDirectory(path, extensions, exclude, include, depth);
                    },
                    onReleaseOldSourceFile,
                    onReleaseParsedCommandLine,
                    hasInvalidatedResolutions,
                    hasChangedAutomaticTypeDirectiveNames,
                    trace: maybeBind(host, host.trace),
                    resolveModuleNames: maybeBind(host, host.resolveModuleNames),
                    getModuleResolutionCache: maybeBind(host, host.getModuleResolutionCache),
                    createHash: maybeBind(host, host.createHash),
                    resolveTypeReferenceDirectives: maybeBind(host, host.resolveTypeReferenceDirectives),
                    resolveModuleNameLiterals: maybeBind(host, host.resolveModuleNameLiterals),
                    resolveTypeReferenceDirectiveReferences: maybeBind(host, host.resolveTypeReferenceDirectiveReferences),
                    useSourceOfProjectReferenceRedirect: maybeBind(host, host.useSourceOfProjectReferenceRedirect),
                    getParsedCommandLine
                };
                const originalGetSourceFile = compilerHost.getSourceFile;
                const { getSourceFileWithCache } = changeCompilerHostLikeToUseCache(compilerHost, (fileName) => toPath(fileName, currentDirectory, getCanonicalFileName), (...args) => originalGetSourceFile.call(compilerHost, ...args));
                compilerHost.getSourceFile = getSourceFileWithCache;
                (_c = host.setCompilerHost) == null ? void 0 : _c.call(host, compilerHost);
                const parseConfigHost = {
                    useCaseSensitiveFileNames,
                    fileExists: (fileName) => compilerHost.fileExists(fileName),
                    readFile: (fileName) => compilerHost.readFile(fileName),
                    readDirectory: (...args) => compilerHost.readDirectory(...args),
                    trace: compilerHost.trace,
                    getCurrentDirectory: compilerHost.getCurrentDirectory,
                    onUnRecoverableConfigFileDiagnostic: noop
                };
                const documentRegistryBucketKey = documentRegistry.getKeyForCompilationSettings(newSettings);
                if (isProgramUptoDate(program, rootFileNames, newSettings, (_path, fileName) => host.getScriptVersion(fileName), (fileName) => compilerHost.fileExists(fileName), hasInvalidatedResolutions, hasChangedAutomaticTypeDirectiveNames, getParsedCommandLine, projectReferences)) {
                    return;
                }
                const options = {
                    rootNames: rootFileNames,
                    options: newSettings,
                    host: compilerHost,
                    oldProgram: program,
                    projectReferences
                };
                program = createProgram(options);
                compilerHost = void 0;
                parsedCommandLines = void 0;
                sourceMapper.clearCache();
                program.getTypeChecker();
                return;
                function getParsedCommandLine(fileName) {
                    const path = toPath(fileName, currentDirectory, getCanonicalFileName);
                    const existing = parsedCommandLines == null ? void 0 : parsedCommandLines.get(path);
                    if (existing !== void 0)
                        return existing || void 0;
                    const result = host.getParsedCommandLine ? host.getParsedCommandLine(fileName) : getParsedCommandLineOfConfigFileUsingSourceFile(fileName);
                    (parsedCommandLines || (parsedCommandLines = /* @__PURE__ */ new Map())).set(path, result || false);
                    return result;
                }
                function getParsedCommandLineOfConfigFileUsingSourceFile(configFileName) {
                    const result = getOrCreateSourceFile(configFileName, 100 /* JSON */);
                    if (!result)
                        return void 0;
                    result.path = toPath(configFileName, currentDirectory, getCanonicalFileName);
                    result.resolvedPath = result.path;
                    result.originalFileName = result.fileName;
                    return parseJsonSourceFileConfigFileContent(result, parseConfigHost, getNormalizedAbsolutePath(getDirectoryPath(configFileName), currentDirectory), 
                    /*optionsToExtend*/
                    void 0, getNormalizedAbsolutePath(configFileName, currentDirectory));
                }
                function onReleaseParsedCommandLine(configFileName, oldResolvedRef, oldOptions) {
                    var _a4;
                    if (host.getParsedCommandLine) {
                        (_a4 = host.onReleaseParsedCommandLine) == null ? void 0 : _a4.call(host, configFileName, oldResolvedRef, oldOptions);
                    }
                    else if (oldResolvedRef) {
                        onReleaseOldSourceFile(oldResolvedRef.sourceFile, oldOptions);
                    }
                }
                function onReleaseOldSourceFile(oldSourceFile, oldOptions) {
                    const oldSettingsKey = documentRegistry.getKeyForCompilationSettings(oldOptions);
                    documentRegistry.releaseDocumentWithKey(oldSourceFile.resolvedPath, oldSettingsKey, oldSourceFile.scriptKind, oldSourceFile.impliedNodeFormat);
                }
                function getOrCreateSourceFile(fileName, languageVersionOrOptions, onError, shouldCreateNewSourceFile) {
                    return getOrCreateSourceFileByPath(fileName, toPath(fileName, currentDirectory, getCanonicalFileName), languageVersionOrOptions, onError, shouldCreateNewSourceFile);
                }
                function getOrCreateSourceFileByPath(fileName, path, languageVersionOrOptions, _onError, shouldCreateNewSourceFile) {
                    Debug.assert(compilerHost, "getOrCreateSourceFileByPath called after typical CompilerHost lifetime, check the callstack something with a reference to an old host.");
                    const scriptSnapshot = host.getScriptSnapshot(fileName);
                    if (!scriptSnapshot) {
                        return void 0;
                    }
                    const scriptKind = getScriptKind(fileName, host);
                    const scriptVersion = host.getScriptVersion(fileName);
                    if (!shouldCreateNewSourceFile) {
                        const oldSourceFile = program && program.getSourceFileByPath(path);
                        if (oldSourceFile) {
                            if (scriptKind === oldSourceFile.scriptKind) {
                                return documentRegistry.updateDocumentWithKey(fileName, path, host, documentRegistryBucketKey, scriptSnapshot, scriptVersion, scriptKind, languageVersionOrOptions);
                            }
                            else {
                                documentRegistry.releaseDocumentWithKey(oldSourceFile.resolvedPath, documentRegistry.getKeyForCompilationSettings(program.getCompilerOptions()), oldSourceFile.scriptKind, oldSourceFile.impliedNodeFormat);
                            }
                        }
                    }
                    return documentRegistry.acquireDocumentWithKey(fileName, path, host, documentRegistryBucketKey, scriptSnapshot, scriptVersion, scriptKind, languageVersionOrOptions);
                }
            }
            function getProgram() {
                if (languageServiceMode === 2 /* Syntactic */) {
                    Debug.assert(program === void 0);
                    return void 0;
                }
                synchronizeHostData();
                return program;
            }
            function getAutoImportProvider() {
                var _a3;
                return (_a3 = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a3.call(host);
            }
            function updateIsDefinitionOfReferencedSymbols(referencedSymbols, knownSymbolSpans) {
                const checker = program.getTypeChecker();
                const symbol = getSymbolForProgram();
                if (!symbol)
                    return false;
                for (const referencedSymbol of referencedSymbols) {
                    for (const ref of referencedSymbol.references) {
                        const refNode = getNodeForSpan(ref);
                        Debug.assertIsDefined(refNode);
                        if (knownSymbolSpans.has(ref) || ts_FindAllReferences_exports.isDeclarationOfSymbol(refNode, symbol)) {
                            knownSymbolSpans.add(ref);
                            ref.isDefinition = true;
                            const mappedSpan = getMappedDocumentSpan(ref, sourceMapper, maybeBind(host, host.fileExists));
                            if (mappedSpan) {
                                knownSymbolSpans.add(mappedSpan);
                            }
                        }
                        else {
                            ref.isDefinition = false;
                        }
                    }
                }
                return true;
                function getSymbolForProgram() {
                    for (const referencedSymbol of referencedSymbols) {
                        for (const ref of referencedSymbol.references) {
                            if (knownSymbolSpans.has(ref)) {
                                const refNode = getNodeForSpan(ref);
                                Debug.assertIsDefined(refNode);
                                return checker.getSymbolAtLocation(refNode);
                            }
                            const mappedSpan = getMappedDocumentSpan(ref, sourceMapper, maybeBind(host, host.fileExists));
                            if (mappedSpan && knownSymbolSpans.has(mappedSpan)) {
                                const refNode = getNodeForSpan(mappedSpan);
                                if (refNode) {
                                    return checker.getSymbolAtLocation(refNode);
                                }
                            }
                        }
                    }
                    return void 0;
                }
                function getNodeForSpan(docSpan) {
                    const sourceFile = program.getSourceFile(docSpan.fileName);
                    if (!sourceFile)
                        return void 0;
                    const rawNode = getTouchingPropertyName(sourceFile, docSpan.textSpan.start);
                    const adjustedNode = ts_FindAllReferences_exports.Core.getAdjustedNode(rawNode, { use: ts_FindAllReferences_exports.FindReferencesUse.References });
                    return adjustedNode;
                }
            }
            function cleanupSemanticCache() {
                program = void 0;
            }
            function dispose() {
                if (program) {
                    const key = documentRegistry.getKeyForCompilationSettings(program.getCompilerOptions());
                    forEach(program.getSourceFiles(), (f) => documentRegistry.releaseDocumentWithKey(f.resolvedPath, key, f.scriptKind, f.impliedNodeFormat));
                    program = void 0;
                }
                host = void 0;
            }
            function getSyntacticDiagnostics(fileName) {
                synchronizeHostData();
                return program.getSyntacticDiagnostics(getValidSourceFile(fileName), cancellationToken).slice();
            }
            function getSemanticDiagnostics(fileName) {
                synchronizeHostData();
                const targetSourceFile = getValidSourceFile(fileName);
                const semanticDiagnostics = program.getSemanticDiagnostics(targetSourceFile, cancellationToken);
                if (!getEmitDeclarations(program.getCompilerOptions())) {
                    return semanticDiagnostics.slice();
                }
                const declarationDiagnostics = program.getDeclarationDiagnostics(targetSourceFile, cancellationToken);
                return [...semanticDiagnostics, ...declarationDiagnostics];
            }
            function getSuggestionDiagnostics(fileName) {
                synchronizeHostData();
                return computeSuggestionDiagnostics(getValidSourceFile(fileName), program, cancellationToken);
            }
            function getCompilerOptionsDiagnostics() {
                synchronizeHostData();
                return [...program.getOptionsDiagnostics(cancellationToken), ...program.getGlobalDiagnostics(cancellationToken)];
            }
            function getCompletionsAtPosition2(fileName, position, options = emptyOptions, formattingSettings) {
                const fullPreferences = {
                    ...identity(options),
                    // avoid excess property check
                    includeCompletionsForModuleExports: options.includeCompletionsForModuleExports || options.includeExternalModuleExports,
                    includeCompletionsWithInsertText: options.includeCompletionsWithInsertText || options.includeInsertTextCompletions
                };
                synchronizeHostData();
                return ts_Completions_exports.getCompletionsAtPosition(host, program, log, getValidSourceFile(fileName), position, fullPreferences, options.triggerCharacter, options.triggerKind, cancellationToken, formattingSettings && ts_formatting_exports.getFormatContext(formattingSettings, host), options.includeSymbol);
            }
            function getCompletionEntryDetails2(fileName, position, name, formattingOptions, source, preferences = emptyOptions, data) {
                synchronizeHostData();
                return ts_Completions_exports.getCompletionEntryDetails(program, log, getValidSourceFile(fileName), position, { name, source, data }, host, formattingOptions && ts_formatting_exports.getFormatContext(formattingOptions, host), 
                // TODO: GH#18217
                preferences, cancellationToken);
            }
            function getCompletionEntrySymbol2(fileName, position, name, source, preferences = emptyOptions) {
                synchronizeHostData();
                return ts_Completions_exports.getCompletionEntrySymbol(program, log, getValidSourceFile(fileName), position, { name, source }, host, preferences);
            }
            function getQuickInfoAtPosition(fileName, position) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const node = getTouchingPropertyName(sourceFile, position);
                if (node === sourceFile) {
                    return void 0;
                }
                const typeChecker = program.getTypeChecker();
                const nodeForQuickInfo = getNodeForQuickInfo(node);
                const symbol = getSymbolAtLocationForQuickInfo(nodeForQuickInfo, typeChecker);
                if (!symbol || typeChecker.isUnknownSymbol(symbol)) {
                    const type = shouldGetType(sourceFile, nodeForQuickInfo, position) ? typeChecker.getTypeAtLocation(nodeForQuickInfo) : void 0;
                    return type && {
                        kind: "" /* unknown */,
                        kindModifiers: "" /* none */,
                        textSpan: createTextSpanFromNode(nodeForQuickInfo, sourceFile),
                        displayParts: typeChecker.runWithCancellationToken(cancellationToken, (typeChecker2) => typeToDisplayParts(typeChecker2, type, getContainerNode(nodeForQuickInfo))),
                        documentation: type.symbol ? type.symbol.getDocumentationComment(typeChecker) : void 0,
                        tags: type.symbol ? type.symbol.getJsDocTags(typeChecker) : void 0
                    };
                }
                const { symbolKind, displayParts, documentation, tags } = typeChecker.runWithCancellationToken(cancellationToken, (typeChecker2) => ts_SymbolDisplay_exports.getSymbolDisplayPartsDocumentationAndSymbolKind(typeChecker2, symbol, sourceFile, getContainerNode(nodeForQuickInfo), nodeForQuickInfo));
                return {
                    kind: symbolKind,
                    kindModifiers: ts_SymbolDisplay_exports.getSymbolModifiers(typeChecker, symbol),
                    textSpan: createTextSpanFromNode(nodeForQuickInfo, sourceFile),
                    displayParts,
                    documentation,
                    tags
                };
            }
            function getNodeForQuickInfo(node) {
                if (isNewExpression(node.parent) && node.pos === node.parent.pos) {
                    return node.parent.expression;
                }
                if (isNamedTupleMember(node.parent) && node.pos === node.parent.pos) {
                    return node.parent;
                }
                if (isImportMeta(node.parent) && node.parent.name === node) {
                    return node.parent;
                }
                return node;
            }
            function shouldGetType(sourceFile, node, position) {
                switch (node.kind) {
                    case 79 /* Identifier */:
                        return !isLabelName(node) && !isTagName(node) && !isConstTypeReference(node.parent);
                    case 208 /* PropertyAccessExpression */:
                    case 163 /* QualifiedName */:
                        return !isInComment(sourceFile, position);
                    case 108 /* ThisKeyword */:
                    case 194 /* ThisType */:
                    case 106 /* SuperKeyword */:
                    case 199 /* NamedTupleMember */:
                        return true;
                    case 233 /* MetaProperty */:
                        return isImportMeta(node);
                    default:
                        return false;
                }
            }
            function getDefinitionAtPosition2(fileName, position, searchOtherFilesOnly, stopAtAlias) {
                synchronizeHostData();
                return ts_GoToDefinition_exports.getDefinitionAtPosition(program, getValidSourceFile(fileName), position, searchOtherFilesOnly, stopAtAlias);
            }
            function getDefinitionAndBoundSpan2(fileName, position) {
                synchronizeHostData();
                return ts_GoToDefinition_exports.getDefinitionAndBoundSpan(program, getValidSourceFile(fileName), position);
            }
            function getTypeDefinitionAtPosition2(fileName, position) {
                synchronizeHostData();
                return ts_GoToDefinition_exports.getTypeDefinitionAtPosition(program.getTypeChecker(), getValidSourceFile(fileName), position);
            }
            function getImplementationAtPosition(fileName, position) {
                synchronizeHostData();
                return ts_FindAllReferences_exports.getImplementationsAtPosition(program, cancellationToken, program.getSourceFiles(), getValidSourceFile(fileName), position);
            }
            function getOccurrencesAtPosition(fileName, position) {
                return flatMap(getDocumentHighlights(fileName, position, [fileName]), (entry) => entry.highlightSpans.map((highlightSpan) => ({
                    fileName: entry.fileName,
                    textSpan: highlightSpan.textSpan,
                    isWriteAccess: highlightSpan.kind === "writtenReference" /* writtenReference */,
                    ...highlightSpan.isInString && { isInString: true },
                    ...highlightSpan.contextSpan && { contextSpan: highlightSpan.contextSpan }
                })));
            }
            function getDocumentHighlights(fileName, position, filesToSearch) {
                const normalizedFileName = normalizePath(fileName);
                Debug.assert(filesToSearch.some((f) => normalizePath(f) === normalizedFileName));
                synchronizeHostData();
                const sourceFilesToSearch = mapDefined(filesToSearch, (fileName2) => program.getSourceFile(fileName2));
                const sourceFile = getValidSourceFile(fileName);
                return DocumentHighlights.getDocumentHighlights(program, cancellationToken, sourceFile, position, sourceFilesToSearch);
            }
            function findRenameLocations(fileName, position, findInStrings, findInComments, providePrefixAndSuffixTextForRename) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const node = getAdjustedRenameLocation(getTouchingPropertyName(sourceFile, position));
                if (!ts_Rename_exports.nodeIsEligibleForRename(node))
                    return void 0;
                if (isIdentifier(node) && (isJsxOpeningElement(node.parent) || isJsxClosingElement(node.parent)) && isIntrinsicJsxName(node.escapedText)) {
                    const { openingElement, closingElement } = node.parent.parent;
                    return [openingElement, closingElement].map((node2) => {
                        const textSpan = createTextSpanFromNode(node2.tagName, sourceFile);
                        return {
                            fileName: sourceFile.fileName,
                            textSpan,
                            ...ts_FindAllReferences_exports.toContextSpan(textSpan, sourceFile, node2.parent)
                        };
                    });
                }
                else {
                    return getReferencesWorker(node, position, { findInStrings, findInComments, providePrefixAndSuffixTextForRename, use: ts_FindAllReferences_exports.FindReferencesUse.Rename }, (entry, originalNode, checker) => ts_FindAllReferences_exports.toRenameLocation(entry, originalNode, checker, providePrefixAndSuffixTextForRename || false));
                }
            }
            function getReferencesAtPosition(fileName, position) {
                synchronizeHostData();
                return getReferencesWorker(getTouchingPropertyName(getValidSourceFile(fileName), position), position, { use: ts_FindAllReferences_exports.FindReferencesUse.References }, ts_FindAllReferences_exports.toReferenceEntry);
            }
            function getReferencesWorker(node, position, options, cb) {
                synchronizeHostData();
                const sourceFiles = options && options.use === ts_FindAllReferences_exports.FindReferencesUse.Rename ? program.getSourceFiles().filter((sourceFile) => !program.isSourceFileDefaultLibrary(sourceFile)) : program.getSourceFiles();
                return ts_FindAllReferences_exports.findReferenceOrRenameEntries(program, cancellationToken, sourceFiles, node, position, options, cb);
            }
            function findReferences(fileName, position) {
                synchronizeHostData();
                return ts_FindAllReferences_exports.findReferencedSymbols(program, cancellationToken, program.getSourceFiles(), getValidSourceFile(fileName), position);
            }
            function getFileReferences(fileName) {
                synchronizeHostData();
                return ts_FindAllReferences_exports.Core.getReferencesForFileName(fileName, program, program.getSourceFiles()).map(ts_FindAllReferences_exports.toReferenceEntry);
            }
            function getNavigateToItems2(searchValue, maxResultCount, fileName, excludeDtsFiles = false) {
                synchronizeHostData();
                const sourceFiles = fileName ? [getValidSourceFile(fileName)] : program.getSourceFiles();
                return getNavigateToItems(sourceFiles, program.getTypeChecker(), cancellationToken, searchValue, maxResultCount, excludeDtsFiles);
            }
            function getEmitOutput(fileName, emitOnlyDtsFiles, forceDtsEmit) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const customTransformers = host.getCustomTransformers && host.getCustomTransformers();
                return getFileEmitOutput(program, sourceFile, !!emitOnlyDtsFiles, cancellationToken, customTransformers, forceDtsEmit);
            }
            function getSignatureHelpItems2(fileName, position, { triggerReason } = emptyOptions) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                return ts_SignatureHelp_exports.getSignatureHelpItems(program, sourceFile, position, triggerReason, cancellationToken);
            }
            function getNonBoundSourceFile(fileName) {
                return syntaxTreeCache.getCurrentSourceFile(fileName);
            }
            function getNameOrDottedNameSpan(fileName, startPos, _endPos) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const node = getTouchingPropertyName(sourceFile, startPos);
                if (node === sourceFile) {
                    return void 0;
                }
                switch (node.kind) {
                    case 208 /* PropertyAccessExpression */:
                    case 163 /* QualifiedName */:
                    case 10 /* StringLiteral */:
                    case 95 /* FalseKeyword */:
                    case 110 /* TrueKeyword */:
                    case 104 /* NullKeyword */:
                    case 106 /* SuperKeyword */:
                    case 108 /* ThisKeyword */:
                    case 194 /* ThisType */:
                    case 79 /* Identifier */:
                        break;
                    default:
                        return void 0;
                }
                let nodeForStartPos = node;
                while (true) {
                    if (isRightSideOfPropertyAccess(nodeForStartPos) || isRightSideOfQualifiedName(nodeForStartPos)) {
                        nodeForStartPos = nodeForStartPos.parent;
                    }
                    else if (isNameOfModuleDeclaration(nodeForStartPos)) {
                        if (nodeForStartPos.parent.parent.kind === 264 /* ModuleDeclaration */ && nodeForStartPos.parent.parent.body === nodeForStartPos.parent) {
                            nodeForStartPos = nodeForStartPos.parent.parent.name;
                        }
                        else {
                            break;
                        }
                    }
                    else {
                        break;
                    }
                }
                return createTextSpanFromBounds(nodeForStartPos.getStart(), node.getEnd());
            }
            function getBreakpointStatementAtPosition(fileName, position) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                return ts_BreakpointResolver_exports.spanInSourceFileAtLocation(sourceFile, position);
            }
            function getNavigationBarItems2(fileName) {
                return getNavigationBarItems(syntaxTreeCache.getCurrentSourceFile(fileName), cancellationToken);
            }
            function getNavigationTree2(fileName) {
                return getNavigationTree(syntaxTreeCache.getCurrentSourceFile(fileName), cancellationToken);
            }
            function getSemanticClassifications3(fileName, span, format) {
                synchronizeHostData();
                const responseFormat = format || "original" /* Original */;
                if (responseFormat === "2020" /* TwentyTwenty */) {
                    return ts_classifier_exports.v2020.getSemanticClassifications(program, cancellationToken, getValidSourceFile(fileName), span);
                }
                else {
                    return getSemanticClassifications(program.getTypeChecker(), cancellationToken, getValidSourceFile(fileName), program.getClassifiableNames(), span);
                }
            }
            function getEncodedSemanticClassifications3(fileName, span, format) {
                synchronizeHostData();
                const responseFormat = format || "original" /* Original */;
                if (responseFormat === "original" /* Original */) {
                    return getEncodedSemanticClassifications(program.getTypeChecker(), cancellationToken, getValidSourceFile(fileName), program.getClassifiableNames(), span);
                }
                else {
                    return ts_classifier_exports.v2020.getEncodedSemanticClassifications(program, cancellationToken, getValidSourceFile(fileName), span);
                }
            }
            function getSyntacticClassifications2(fileName, span) {
                return getSyntacticClassifications(cancellationToken, syntaxTreeCache.getCurrentSourceFile(fileName), span);
            }
            function getEncodedSyntacticClassifications2(fileName, span) {
                return getEncodedSyntacticClassifications(cancellationToken, syntaxTreeCache.getCurrentSourceFile(fileName), span);
            }
            function getOutliningSpans(fileName) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                return ts_OutliningElementsCollector_exports.collectElements(sourceFile, cancellationToken);
            }
            const braceMatching = new Map(Object.entries({
                [18 /* OpenBraceToken */]: 19 /* CloseBraceToken */,
                [20 /* OpenParenToken */]: 21 /* CloseParenToken */,
                [22 /* OpenBracketToken */]: 23 /* CloseBracketToken */,
                [31 /* GreaterThanToken */]: 29 /* LessThanToken */
            }));
            braceMatching.forEach((value, key) => braceMatching.set(value.toString(), Number(key)));
            function getBraceMatchingAtPosition(fileName, position) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const token = getTouchingToken(sourceFile, position);
                const matchKind = token.getStart(sourceFile) === position ? braceMatching.get(token.kind.toString()) : void 0;
                const match = matchKind && findChildOfKind(token.parent, matchKind, sourceFile);
                return match ? [createTextSpanFromNode(token, sourceFile), createTextSpanFromNode(match, sourceFile)].sort((a, b) => a.start - b.start) : emptyArray;
            }
            function getIndentationAtPosition(fileName, position, editorOptions) {
                let start = timestamp();
                const settings = toEditorSettings(editorOptions);
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                log("getIndentationAtPosition: getCurrentSourceFile: " + (timestamp() - start));
                start = timestamp();
                const result = ts_formatting_exports.SmartIndenter.getIndentation(position, sourceFile, settings);
                log("getIndentationAtPosition: computeIndentation  : " + (timestamp() - start));
                return result;
            }
            function getFormattingEditsForRange(fileName, start, end, options) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                return ts_formatting_exports.formatSelection(start, end, sourceFile, ts_formatting_exports.getFormatContext(toEditorSettings(options), host));
            }
            function getFormattingEditsForDocument(fileName, options) {
                return ts_formatting_exports.formatDocument(syntaxTreeCache.getCurrentSourceFile(fileName), ts_formatting_exports.getFormatContext(toEditorSettings(options), host));
            }
            function getFormattingEditsAfterKeystroke(fileName, position, key, options) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const formatContext = ts_formatting_exports.getFormatContext(toEditorSettings(options), host);
                if (!isInComment(sourceFile, position)) {
                    switch (key) {
                        case "{":
                            return ts_formatting_exports.formatOnOpeningCurly(position, sourceFile, formatContext);
                        case "}":
                            return ts_formatting_exports.formatOnClosingCurly(position, sourceFile, formatContext);
                        case ";":
                            return ts_formatting_exports.formatOnSemicolon(position, sourceFile, formatContext);
                        case "\n":
                            return ts_formatting_exports.formatOnEnter(position, sourceFile, formatContext);
                    }
                }
                return [];
            }
            function getCodeFixesAtPosition(fileName, start, end, errorCodes63, formatOptions, preferences = emptyOptions) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const span = createTextSpanFromBounds(start, end);
                const formatContext = ts_formatting_exports.getFormatContext(formatOptions, host);
                return flatMap(deduplicate(errorCodes63, equateValues, compareValues), (errorCode) => {
                    cancellationToken.throwIfCancellationRequested();
                    return ts_codefix_exports.getFixes({ errorCode, sourceFile, span, program, host, cancellationToken, formatContext, preferences });
                });
            }
            function getCombinedCodeFix(scope, fixId51, formatOptions, preferences = emptyOptions) {
                synchronizeHostData();
                Debug.assert(scope.type === "file");
                const sourceFile = getValidSourceFile(scope.fileName);
                const formatContext = ts_formatting_exports.getFormatContext(formatOptions, host);
                return ts_codefix_exports.getAllFixes({ fixId: fixId51, sourceFile, program, host, cancellationToken, formatContext, preferences });
            }
            function organizeImports2(args, formatOptions, preferences = emptyOptions) {
                var _a3;
                synchronizeHostData();
                Debug.assert(args.type === "file");
                const sourceFile = getValidSourceFile(args.fileName);
                const formatContext = ts_formatting_exports.getFormatContext(formatOptions, host);
                const mode = (_a3 = args.mode) != null ? _a3 : args.skipDestructiveCodeActions ? "SortAndCombine" /* SortAndCombine */ : "All" /* All */;
                return ts_OrganizeImports_exports.organizeImports(sourceFile, formatContext, host, program, preferences, mode);
            }
            function getEditsForFileRename2(oldFilePath, newFilePath, formatOptions, preferences = emptyOptions) {
                return getEditsForFileRename(getProgram(), oldFilePath, newFilePath, host, ts_formatting_exports.getFormatContext(formatOptions, host), preferences, sourceMapper);
            }
            function applyCodeActionCommand(fileName, actionOrFormatSettingsOrUndefined) {
                const action = typeof fileName === "string" ? actionOrFormatSettingsOrUndefined : fileName;
                return isArray(action) ? Promise.all(action.map((a) => applySingleCodeActionCommand(a))) : applySingleCodeActionCommand(action);
            }
            function applySingleCodeActionCommand(action) {
                const getPath = (path) => toPath(path, currentDirectory, getCanonicalFileName);
                Debug.assertEqual(action.type, "install package");
                return host.installPackage ? host.installPackage({ fileName: getPath(action.file), packageName: action.packageName }) : Promise.reject("Host does not implement `installPackage`");
            }
            function getDocCommentTemplateAtPosition2(fileName, position, options, formatOptions) {
                const formatSettings = formatOptions ? ts_formatting_exports.getFormatContext(formatOptions, host).options : void 0;
                return ts_JsDoc_exports.getDocCommentTemplateAtPosition(getNewLineOrDefaultFromHost(host, formatSettings), syntaxTreeCache.getCurrentSourceFile(fileName), position, options);
            }
            function isValidBraceCompletionAtPosition(fileName, position, openingBrace) {
                if (openingBrace === 60 /* lessThan */) {
                    return false;
                }
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                if (isInString(sourceFile, position)) {
                    return false;
                }
                if (isInsideJsxElementOrAttribute(sourceFile, position)) {
                    return openingBrace === 123 /* openBrace */;
                }
                if (isInTemplateString(sourceFile, position)) {
                    return false;
                }
                switch (openingBrace) {
                    case 39 /* singleQuote */:
                    case 34 /* doubleQuote */:
                    case 96 /* backtick */:
                        return !isInComment(sourceFile, position);
                }
                return true;
            }
            function getJsxClosingTagAtPosition(fileName, position) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const token = findPrecedingToken(position, sourceFile);
                if (!token)
                    return void 0;
                const element = token.kind === 31 /* GreaterThanToken */ && isJsxOpeningElement(token.parent) ? token.parent.parent : isJsxText(token) && isJsxElement(token.parent) ? token.parent : void 0;
                if (element && isUnclosedTag(element)) {
                    return { newText: `</${element.openingElement.tagName.getText(sourceFile)}>` };
                }
                const fragment = token.kind === 31 /* GreaterThanToken */ && isJsxOpeningFragment(token.parent) ? token.parent.parent : isJsxText(token) && isJsxFragment(token.parent) ? token.parent : void 0;
                if (fragment && isUnclosedFragment(fragment)) {
                    return { newText: "</>" };
                }
            }
            function getLinesForRange(sourceFile, textRange) {
                return {
                    lineStarts: sourceFile.getLineStarts(),
                    firstLine: sourceFile.getLineAndCharacterOfPosition(textRange.pos).line,
                    lastLine: sourceFile.getLineAndCharacterOfPosition(textRange.end).line
                };
            }
            function toggleLineComment(fileName, textRange, insertComment) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const textChanges2 = [];
                const { lineStarts, firstLine, lastLine } = getLinesForRange(sourceFile, textRange);
                let isCommenting = insertComment || false;
                let leftMostPosition = Number.MAX_VALUE;
                const lineTextStarts = /* @__PURE__ */ new Map();
                const firstNonWhitespaceCharacterRegex = new RegExp(/\S/);
                const isJsx = isInsideJsxElement(sourceFile, lineStarts[firstLine]);
                const openComment = isJsx ? "{/*" : "//";
                for (let i = firstLine; i <= lastLine; i++) {
                    const lineText = sourceFile.text.substring(lineStarts[i], sourceFile.getLineEndOfPosition(lineStarts[i]));
                    const regExec = firstNonWhitespaceCharacterRegex.exec(lineText);
                    if (regExec) {
                        leftMostPosition = Math.min(leftMostPosition, regExec.index);
                        lineTextStarts.set(i.toString(), regExec.index);
                        if (lineText.substr(regExec.index, openComment.length) !== openComment) {
                            isCommenting = insertComment === void 0 || insertComment;
                        }
                    }
                }
                for (let i = firstLine; i <= lastLine; i++) {
                    if (firstLine !== lastLine && lineStarts[i] === textRange.end) {
                        continue;
                    }
                    const lineTextStart = lineTextStarts.get(i.toString());
                    if (lineTextStart !== void 0) {
                        if (isJsx) {
                            textChanges2.push.apply(textChanges2, toggleMultilineComment(fileName, { pos: lineStarts[i] + leftMostPosition, end: sourceFile.getLineEndOfPosition(lineStarts[i]) }, isCommenting, isJsx));
                        }
                        else if (isCommenting) {
                            textChanges2.push({
                                newText: openComment,
                                span: {
                                    length: 0,
                                    start: lineStarts[i] + leftMostPosition
                                }
                            });
                        }
                        else if (sourceFile.text.substr(lineStarts[i] + lineTextStart, openComment.length) === openComment) {
                            textChanges2.push({
                                newText: "",
                                span: {
                                    length: openComment.length,
                                    start: lineStarts[i] + lineTextStart
                                }
                            });
                        }
                    }
                }
                return textChanges2;
            }
            function toggleMultilineComment(fileName, textRange, insertComment, isInsideJsx) {
                var _a3;
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const textChanges2 = [];
                const { text } = sourceFile;
                let hasComment = false;
                let isCommenting = insertComment || false;
                const positions = [];
                let { pos } = textRange;
                const isJsx = isInsideJsx !== void 0 ? isInsideJsx : isInsideJsxElement(sourceFile, pos);
                const openMultiline = isJsx ? "{/*" : "/*";
                const closeMultiline = isJsx ? "*/}" : "*/";
                const openMultilineRegex = isJsx ? "\\{\\/\\*" : "\\/\\*";
                const closeMultilineRegex = isJsx ? "\\*\\/\\}" : "\\*\\/";
                while (pos <= textRange.end) {
                    const offset = text.substr(pos, openMultiline.length) === openMultiline ? openMultiline.length : 0;
                    const commentRange = isInComment(sourceFile, pos + offset);
                    if (commentRange) {
                        if (isJsx) {
                            commentRange.pos--;
                            commentRange.end++;
                        }
                        positions.push(commentRange.pos);
                        if (commentRange.kind === 3 /* MultiLineCommentTrivia */) {
                            positions.push(commentRange.end);
                        }
                        hasComment = true;
                        pos = commentRange.end + 1;
                    }
                    else {
                        const newPos = text.substring(pos, textRange.end).search(`(${openMultilineRegex})|(${closeMultilineRegex})`);
                        isCommenting = insertComment !== void 0 ? insertComment : isCommenting || !isTextWhiteSpaceLike(text, pos, newPos === -1 ? textRange.end : pos + newPos);
                        pos = newPos === -1 ? textRange.end + 1 : pos + newPos + closeMultiline.length;
                    }
                }
                if (isCommenting || !hasComment) {
                    if (((_a3 = isInComment(sourceFile, textRange.pos)) == null ? void 0 : _a3.kind) !== 2 /* SingleLineCommentTrivia */) {
                        insertSorted(positions, textRange.pos, compareValues);
                    }
                    insertSorted(positions, textRange.end, compareValues);
                    const firstPos = positions[0];
                    if (text.substr(firstPos, openMultiline.length) !== openMultiline) {
                        textChanges2.push({
                            newText: openMultiline,
                            span: {
                                length: 0,
                                start: firstPos
                            }
                        });
                    }
                    for (let i = 1; i < positions.length - 1; i++) {
                        if (text.substr(positions[i] - closeMultiline.length, closeMultiline.length) !== closeMultiline) {
                            textChanges2.push({
                                newText: closeMultiline,
                                span: {
                                    length: 0,
                                    start: positions[i]
                                }
                            });
                        }
                        if (text.substr(positions[i], openMultiline.length) !== openMultiline) {
                            textChanges2.push({
                                newText: openMultiline,
                                span: {
                                    length: 0,
                                    start: positions[i]
                                }
                            });
                        }
                    }
                    if (textChanges2.length % 2 !== 0) {
                        textChanges2.push({
                            newText: closeMultiline,
                            span: {
                                length: 0,
                                start: positions[positions.length - 1]
                            }
                        });
                    }
                }
                else {
                    for (const pos2 of positions) {
                        const from = pos2 - closeMultiline.length > 0 ? pos2 - closeMultiline.length : 0;
                        const offset = text.substr(from, closeMultiline.length) === closeMultiline ? closeMultiline.length : 0;
                        textChanges2.push({
                            newText: "",
                            span: {
                                length: openMultiline.length,
                                start: pos2 - offset
                            }
                        });
                    }
                }
                return textChanges2;
            }
            function commentSelection(fileName, textRange) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const { firstLine, lastLine } = getLinesForRange(sourceFile, textRange);
                return firstLine === lastLine && textRange.pos !== textRange.end ? toggleMultilineComment(fileName, textRange, 
                /*insertComment*/
                true) : toggleLineComment(fileName, textRange, 
                /*insertComment*/
                true);
            }
            function uncommentSelection(fileName, textRange) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const textChanges2 = [];
                const { pos } = textRange;
                let { end } = textRange;
                if (pos === end) {
                    end += isInsideJsxElement(sourceFile, pos) ? 2 : 1;
                }
                for (let i = pos; i <= end; i++) {
                    const commentRange = isInComment(sourceFile, i);
                    if (commentRange) {
                        switch (commentRange.kind) {
                            case 2 /* SingleLineCommentTrivia */:
                                textChanges2.push.apply(textChanges2, toggleLineComment(fileName, { end: commentRange.end, pos: commentRange.pos + 1 }, 
                                /*insertComment*/
                                false));
                                break;
                            case 3 /* MultiLineCommentTrivia */:
                                textChanges2.push.apply(textChanges2, toggleMultilineComment(fileName, { end: commentRange.end, pos: commentRange.pos + 1 }, 
                                /*insertComment*/
                                false));
                        }
                        i = commentRange.end + 1;
                    }
                }
                return textChanges2;
            }
            function isUnclosedTag({ openingElement, closingElement, parent: parent2 }) {
                return !tagNamesAreEquivalent(openingElement.tagName, closingElement.tagName) || isJsxElement(parent2) && tagNamesAreEquivalent(openingElement.tagName, parent2.openingElement.tagName) && isUnclosedTag(parent2);
            }
            function isUnclosedFragment({ closingFragment, parent: parent2 }) {
                return !!(closingFragment.flags & 131072 /* ThisNodeHasError */) || isJsxFragment(parent2) && isUnclosedFragment(parent2);
            }
            function getSpanOfEnclosingComment(fileName, position, onlyMultiLine) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const range = ts_formatting_exports.getRangeOfEnclosingComment(sourceFile, position);
                return range && (!onlyMultiLine || range.kind === 3 /* MultiLineCommentTrivia */) ? createTextSpanFromRange(range) : void 0;
            }
            function getTodoComments(fileName, descriptors) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                cancellationToken.throwIfCancellationRequested();
                const fileContents = sourceFile.text;
                const result = [];
                if (descriptors.length > 0 && !isNodeModulesFile(sourceFile.fileName)) {
                    const regExp = getTodoCommentsRegExp();
                    let matchArray;
                    while (matchArray = regExp.exec(fileContents)) {
                        cancellationToken.throwIfCancellationRequested();
                        const firstDescriptorCaptureIndex = 3;
                        Debug.assert(matchArray.length === descriptors.length + firstDescriptorCaptureIndex);
                        const preamble = matchArray[1];
                        const matchPosition = matchArray.index + preamble.length;
                        if (!isInComment(sourceFile, matchPosition)) {
                            continue;
                        }
                        let descriptor;
                        for (let i = 0; i < descriptors.length; i++) {
                            if (matchArray[i + firstDescriptorCaptureIndex]) {
                                descriptor = descriptors[i];
                            }
                        }
                        if (descriptor === void 0)
                            return Debug.fail();
                        if (isLetterOrDigit(fileContents.charCodeAt(matchPosition + descriptor.text.length))) {
                            continue;
                        }
                        const message = matchArray[2];
                        result.push({ descriptor, message, position: matchPosition });
                    }
                }
                return result;
                function escapeRegExp(str) {
                    return str.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, "\\$&");
                }
                function getTodoCommentsRegExp() {
                    const singleLineCommentStart = /(?:\/\/+\s*)/.source;
                    const multiLineCommentStart = /(?:\/\*+\s*)/.source;
                    const anyNumberOfSpacesAndAsterisksAtStartOfLine = /(?:^(?:\s|\*)*)/.source;
                    const preamble = "(" + anyNumberOfSpacesAndAsterisksAtStartOfLine + "|" + singleLineCommentStart + "|" + multiLineCommentStart + ")";
                    const literals = "(?:" + map(descriptors, (d) => "(" + escapeRegExp(d.text) + ")").join("|") + ")";
                    const endOfLineOrEndOfComment = /(?:$|\*\/)/.source;
                    const messageRemainder = /(?:.*?)/.source;
                    const messagePortion = "(" + literals + messageRemainder + ")";
                    const regExpString = preamble + messagePortion + endOfLineOrEndOfComment;
                    return new RegExp(regExpString, "gim");
                }
                function isLetterOrDigit(char) {
                    return char >= 97 /* a */ && char <= 122 /* z */ || char >= 65 /* A */ && char <= 90 /* Z */ || char >= 48 /* _0 */ && char <= 57 /* _9 */;
                }
                function isNodeModulesFile(path) {
                    return stringContains(path, "/node_modules/");
                }
            }
            function getRenameInfo2(fileName, position, preferences) {
                synchronizeHostData();
                return ts_Rename_exports.getRenameInfo(program, getValidSourceFile(fileName), position, preferences || {});
            }
            function getRefactorContext(file, positionOrRange, preferences, formatOptions, triggerReason, kind) {
                const [startPosition, endPosition] = typeof positionOrRange === "number" ? [positionOrRange, void 0] : [positionOrRange.pos, positionOrRange.end];
                return {
                    file,
                    startPosition,
                    endPosition,
                    program: getProgram(),
                    host,
                    formatContext: ts_formatting_exports.getFormatContext(formatOptions, host),
                    // TODO: GH#18217
                    cancellationToken,
                    preferences,
                    triggerReason,
                    kind
                };
            }
            function getInlayHintsContext(file, span, preferences) {
                return {
                    file,
                    program: getProgram(),
                    host,
                    span,
                    preferences,
                    cancellationToken
                };
            }
            function getSmartSelectionRange2(fileName, position) {
                return ts_SmartSelectionRange_exports.getSmartSelectionRange(position, syntaxTreeCache.getCurrentSourceFile(fileName));
            }
            function getApplicableRefactors2(fileName, positionOrRange, preferences = emptyOptions, triggerReason, kind) {
                synchronizeHostData();
                const file = getValidSourceFile(fileName);
                return ts_refactor_exports.getApplicableRefactors(getRefactorContext(file, positionOrRange, preferences, emptyOptions, triggerReason, kind));
            }
            function getEditsForRefactor2(fileName, formatOptions, positionOrRange, refactorName13, actionName2, preferences = emptyOptions) {
                synchronizeHostData();
                const file = getValidSourceFile(fileName);
                return ts_refactor_exports.getEditsForRefactor(getRefactorContext(file, positionOrRange, preferences, formatOptions), refactorName13, actionName2);
            }
            function toLineColumnOffset(fileName, position) {
                if (position === 0) {
                    return { line: 0, character: 0 };
                }
                return sourceMapper.toLineColumnOffset(fileName, position);
            }
            function prepareCallHierarchy(fileName, position) {
                synchronizeHostData();
                const declarations = ts_CallHierarchy_exports.resolveCallHierarchyDeclaration(program, getTouchingPropertyName(getValidSourceFile(fileName), position));
                return declarations && mapOneOrMany(declarations, (declaration) => ts_CallHierarchy_exports.createCallHierarchyItem(program, declaration));
            }
            function provideCallHierarchyIncomingCalls(fileName, position) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const declaration = firstOrOnly(ts_CallHierarchy_exports.resolveCallHierarchyDeclaration(program, position === 0 ? sourceFile : getTouchingPropertyName(sourceFile, position)));
                return declaration ? ts_CallHierarchy_exports.getIncomingCalls(program, declaration, cancellationToken) : [];
            }
            function provideCallHierarchyOutgoingCalls(fileName, position) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const declaration = firstOrOnly(ts_CallHierarchy_exports.resolveCallHierarchyDeclaration(program, position === 0 ? sourceFile : getTouchingPropertyName(sourceFile, position)));
                return declaration ? ts_CallHierarchy_exports.getOutgoingCalls(program, declaration) : [];
            }
            function provideInlayHints2(fileName, span, preferences = emptyOptions) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                return ts_InlayHints_exports.provideInlayHints(getInlayHintsContext(sourceFile, span, preferences));
            }
            const ls = {
                dispose,
                cleanupSemanticCache,
                getSyntacticDiagnostics,
                getSemanticDiagnostics,
                getSuggestionDiagnostics,
                getCompilerOptionsDiagnostics,
                getSyntacticClassifications: getSyntacticClassifications2,
                getSemanticClassifications: getSemanticClassifications3,
                getEncodedSyntacticClassifications: getEncodedSyntacticClassifications2,
                getEncodedSemanticClassifications: getEncodedSemanticClassifications3,
                getCompletionsAtPosition: getCompletionsAtPosition2,
                getCompletionEntryDetails: getCompletionEntryDetails2,
                getCompletionEntrySymbol: getCompletionEntrySymbol2,
                getSignatureHelpItems: getSignatureHelpItems2,
                getQuickInfoAtPosition,
                getDefinitionAtPosition: getDefinitionAtPosition2,
                getDefinitionAndBoundSpan: getDefinitionAndBoundSpan2,
                getImplementationAtPosition,
                getTypeDefinitionAtPosition: getTypeDefinitionAtPosition2,
                getReferencesAtPosition,
                findReferences,
                getFileReferences,
                getOccurrencesAtPosition,
                getDocumentHighlights,
                getNameOrDottedNameSpan,
                getBreakpointStatementAtPosition,
                getNavigateToItems: getNavigateToItems2,
                getRenameInfo: getRenameInfo2,
                getSmartSelectionRange: getSmartSelectionRange2,
                findRenameLocations,
                getNavigationBarItems: getNavigationBarItems2,
                getNavigationTree: getNavigationTree2,
                getOutliningSpans,
                getTodoComments,
                getBraceMatchingAtPosition,
                getIndentationAtPosition,
                getFormattingEditsForRange,
                getFormattingEditsForDocument,
                getFormattingEditsAfterKeystroke,
                getDocCommentTemplateAtPosition: getDocCommentTemplateAtPosition2,
                isValidBraceCompletionAtPosition,
                getJsxClosingTagAtPosition,
                getSpanOfEnclosingComment,
                getCodeFixesAtPosition,
                getCombinedCodeFix,
                applyCodeActionCommand,
                organizeImports: organizeImports2,
                getEditsForFileRename: getEditsForFileRename2,
                getEmitOutput,
                getNonBoundSourceFile,
                getProgram,
                getCurrentProgram: () => program,
                getAutoImportProvider,
                updateIsDefinitionOfReferencedSymbols,
                getApplicableRefactors: getApplicableRefactors2,
                getEditsForRefactor: getEditsForRefactor2,
                toLineColumnOffset,
                getSourceMapper: () => sourceMapper,
                clearSourceMapperCache: () => sourceMapper.clearCache(),
                prepareCallHierarchy,
                provideCallHierarchyIncomingCalls,
                provideCallHierarchyOutgoingCalls,
                toggleLineComment,
                toggleMultilineComment,
                commentSelection,
                uncommentSelection,
                provideInlayHints: provideInlayHints2,
                getSupportedCodeFixes
            };
            switch (languageServiceMode) {
                case 0 /* Semantic */:
                    break;
                case 1 /* PartialSemantic */:
                    invalidOperationsInPartialSemanticMode.forEach((key) => ls[key] = () => {
                        throw new Error(`LanguageService Operation: ${key} not allowed in LanguageServiceMode.PartialSemantic`);
                    });
                    break;
                case 2 /* Syntactic */:
                    invalidOperationsInSyntacticMode.forEach((key) => ls[key] = () => {
                        throw new Error(`LanguageService Operation: ${key} not allowed in LanguageServiceMode.Syntactic`);
                    });
                    break;
                default:
                    Debug.assertNever(languageServiceMode);
            }
            return ls;
        }
        function getNameTable(sourceFile) {
            if (!sourceFile.nameTable) {
                initializeNameTable(sourceFile);
            }
            return sourceFile.nameTable;
        }
        function initializeNameTable(sourceFile) {
            const nameTable = sourceFile.nameTable = /* @__PURE__ */ new Map();
            sourceFile.forEachChild(function walk(node) {
                if (isIdentifier(node) && !isTagName(node) && node.escapedText || isStringOrNumericLiteralLike(node) && literalIsName(node)) {
                    const text = getEscapedTextOfIdentifierOrLiteral(node);
                    nameTable.set(text, nameTable.get(text) === void 0 ? node.pos : -1);
                }
                else if (isPrivateIdentifier(node)) {
                    const text = node.escapedText;
                    nameTable.set(text, nameTable.get(text) === void 0 ? node.pos : -1);
                }
                forEachChild(node, walk);
                if (hasJSDocNodes(node)) {
                    for (const jsDoc of node.jsDoc) {
                        forEachChild(jsDoc, walk);
                    }
                }
            });
        }
        function literalIsName(node) {
            return isDeclarationName(node) || node.parent.kind === 280 /* ExternalModuleReference */ || isArgumentOfElementAccessExpression(node) || isLiteralComputedPropertyDeclarationName(node);
        }
        function getContainingObjectLiteralElement(node) {
            const element = getContainingObjectLiteralElementWorker(node);
            return element && (isObjectLiteralExpression(element.parent) || isJsxAttributes(element.parent)) ? element : void 0;
        }
        function getContainingObjectLiteralElementWorker(node) {
            switch (node.kind) {
                case 10 /* StringLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 8 /* NumericLiteral */:
                    if (node.parent.kind === 164 /* ComputedPropertyName */) {
                        return isObjectLiteralElement(node.parent.parent) ? node.parent.parent : void 0;
                    }
                case 79 /* Identifier */:
                    return isObjectLiteralElement(node.parent) && (node.parent.parent.kind === 207 /* ObjectLiteralExpression */ || node.parent.parent.kind === 289 /* JsxAttributes */) && node.parent.name === node ? node.parent : void 0;
            }
            return void 0;
        }
        function getSymbolAtLocationForQuickInfo(node, checker) {
            const object = getContainingObjectLiteralElement(node);
            if (object) {
                const contextualType = checker.getContextualType(object.parent);
                const properties = contextualType && getPropertySymbolsFromContextualType(object, checker, contextualType, 
                /*unionSymbolOk*/
                false);
                if (properties && properties.length === 1) {
                    return first(properties);
                }
            }
            return checker.getSymbolAtLocation(node);
        }
        function getPropertySymbolsFromContextualType(node, checker, contextualType, unionSymbolOk) {
            const name = getNameFromPropertyName(node.name);
            if (!name)
                return emptyArray;
            if (!contextualType.isUnion()) {
                const symbol = contextualType.getProperty(name);
                return symbol ? [symbol] : emptyArray;
            }
            const discriminatedPropertySymbols = mapDefined(contextualType.types, (t) => (isObjectLiteralExpression(node.parent) || isJsxAttributes(node.parent)) && checker.isTypeInvalidDueToUnionDiscriminant(t, node.parent) ? void 0 : t.getProperty(name));
            if (unionSymbolOk && (discriminatedPropertySymbols.length === 0 || discriminatedPropertySymbols.length === contextualType.types.length)) {
                const symbol = contextualType.getProperty(name);
                if (symbol)
                    return [symbol];
            }
            if (discriminatedPropertySymbols.length === 0) {
                return mapDefined(contextualType.types, (t) => t.getProperty(name));
            }
            return discriminatedPropertySymbols;
        }
        function isArgumentOfElementAccessExpression(node) {
            return node && node.parent && node.parent.kind === 209 /* ElementAccessExpression */ && node.parent.argumentExpression === node;
        }
        function getDefaultLibFilePath(options) {
            if (sys) {
                return combinePaths(getDirectoryPath(normalizePath(sys.getExecutingFilePath())), getDefaultLibFileName(options));
            }
            throw new Error("getDefaultLibFilePath is only supported when consumed as a node module. ");
        }
        var servicesVersion, NodeObject, TokenOrIdentifierObject, SymbolObject, TokenObject, IdentifierObject, PrivateIdentifierObject, TypeObject, SignatureObject, SourceFileObject, SourceMapSourceObject, SyntaxTreeCache, NoopCancellationToken, CancellationTokenObject, ThrottledCancellationToken, invalidOperationsInPartialSemanticMode, invalidOperationsInSyntacticMode;
        var init_services = __esm({
            "src/services/services.ts"() {
                "use strict";
                init_ts4();
                init_ts4();
                init_ts_NavigateTo();
                init_ts_NavigationBar();
                servicesVersion = "0.8";
                NodeObject = class {
                    constructor(kind, pos, end) {
                        this.pos = pos;
                        this.end = end;
                        this.flags = 0 /* None */;
                        this.modifierFlagsCache = 0 /* None */;
                        this.transformFlags = 0 /* None */;
                        this.parent = void 0;
                        this.kind = kind;
                    }
                    assertHasRealPosition(message) {
                        Debug.assert(!positionIsSynthesized(this.pos) && !positionIsSynthesized(this.end), message || "Node must have a real position for this operation");
                    }
                    getSourceFile() {
                        return getSourceFileOfNode(this);
                    }
                    getStart(sourceFile, includeJsDocComment) {
                        this.assertHasRealPosition();
                        return getTokenPosOfNode(this, sourceFile, includeJsDocComment);
                    }
                    getFullStart() {
                        this.assertHasRealPosition();
                        return this.pos;
                    }
                    getEnd() {
                        this.assertHasRealPosition();
                        return this.end;
                    }
                    getWidth(sourceFile) {
                        this.assertHasRealPosition();
                        return this.getEnd() - this.getStart(sourceFile);
                    }
                    getFullWidth() {
                        this.assertHasRealPosition();
                        return this.end - this.pos;
                    }
                    getLeadingTriviaWidth(sourceFile) {
                        this.assertHasRealPosition();
                        return this.getStart(sourceFile) - this.pos;
                    }
                    getFullText(sourceFile) {
                        this.assertHasRealPosition();
                        return (sourceFile || this.getSourceFile()).text.substring(this.pos, this.end);
                    }
                    getText(sourceFile) {
                        this.assertHasRealPosition();
                        if (!sourceFile) {
                            sourceFile = this.getSourceFile();
                        }
                        return sourceFile.text.substring(this.getStart(sourceFile), this.getEnd());
                    }
                    getChildCount(sourceFile) {
                        return this.getChildren(sourceFile).length;
                    }
                    getChildAt(index, sourceFile) {
                        return this.getChildren(sourceFile)[index];
                    }
                    getChildren(sourceFile) {
                        this.assertHasRealPosition("Node without a real position cannot be scanned and thus has no token nodes - use forEachChild and collect the result if that's fine");
                        return this._children || (this._children = createChildren(this, sourceFile));
                    }
                    getFirstToken(sourceFile) {
                        this.assertHasRealPosition();
                        const children = this.getChildren(sourceFile);
                        if (!children.length) {
                            return void 0;
                        }
                        const child = find(children, (kid) => kid.kind < 312 /* FirstJSDocNode */ || kid.kind > 353 /* LastJSDocNode */);
                        return child.kind < 163 /* FirstNode */ ? child : child.getFirstToken(sourceFile);
                    }
                    getLastToken(sourceFile) {
                        this.assertHasRealPosition();
                        const children = this.getChildren(sourceFile);
                        const child = lastOrUndefined(children);
                        if (!child) {
                            return void 0;
                        }
                        return child.kind < 163 /* FirstNode */ ? child : child.getLastToken(sourceFile);
                    }
                    forEachChild(cbNode, cbNodeArray) {
                        return forEachChild(this, cbNode, cbNodeArray);
                    }
                };
                TokenOrIdentifierObject = class {
                    constructor(pos, end) {
                        this.pos = pos;
                        this.end = end;
                        this.flags = 0 /* None */;
                        this.modifierFlagsCache = 0 /* None */;
                        this.transformFlags = 0 /* None */;
                        this.parent = void 0;
                    }
                    getSourceFile() {
                        return getSourceFileOfNode(this);
                    }
                    getStart(sourceFile, includeJsDocComment) {
                        return getTokenPosOfNode(this, sourceFile, includeJsDocComment);
                    }
                    getFullStart() {
                        return this.pos;
                    }
                    getEnd() {
                        return this.end;
                    }
                    getWidth(sourceFile) {
                        return this.getEnd() - this.getStart(sourceFile);
                    }
                    getFullWidth() {
                        return this.end - this.pos;
                    }
                    getLeadingTriviaWidth(sourceFile) {
                        return this.getStart(sourceFile) - this.pos;
                    }
                    getFullText(sourceFile) {
                        return (sourceFile || this.getSourceFile()).text.substring(this.pos, this.end);
                    }
                    getText(sourceFile) {
                        if (!sourceFile) {
                            sourceFile = this.getSourceFile();
                        }
                        return sourceFile.text.substring(this.getStart(sourceFile), this.getEnd());
                    }
                    getChildCount() {
                        return this.getChildren().length;
                    }
                    getChildAt(index) {
                        return this.getChildren()[index];
                    }
                    getChildren() {
                        return this.kind === 1 /* EndOfFileToken */ ? this.jsDoc || emptyArray : emptyArray;
                    }
                    getFirstToken() {
                        return void 0;
                    }
                    getLastToken() {
                        return void 0;
                    }
                    forEachChild() {
                        return void 0;
                    }
                };
                SymbolObject = class {
                    constructor(flags, name) {
                        this.id = 0;
                        this.mergeId = 0;
                        this.flags = flags;
                        this.escapedName = name;
                    }
                    getFlags() {
                        return this.flags;
                    }
                    get name() {
                        return symbolName(this);
                    }
                    getEscapedName() {
                        return this.escapedName;
                    }
                    getName() {
                        return this.name;
                    }
                    getDeclarations() {
                        return this.declarations;
                    }
                    getDocumentationComment(checker) {
                        if (!this.documentationComment) {
                            this.documentationComment = emptyArray;
                            if (!this.declarations && isTransientSymbol(this) && this.links.target && isTransientSymbol(this.links.target) && this.links.target.links.tupleLabelDeclaration) {
                                const labelDecl = this.links.target.links.tupleLabelDeclaration;
                                this.documentationComment = getDocumentationComment([labelDecl], checker);
                            }
                            else {
                                this.documentationComment = getDocumentationComment(this.declarations, checker);
                            }
                        }
                        return this.documentationComment;
                    }
                    getContextualDocumentationComment(context, checker) {
                        if (context) {
                            if (isGetAccessor(context)) {
                                if (!this.contextualGetAccessorDocumentationComment) {
                                    this.contextualGetAccessorDocumentationComment = getDocumentationComment(filter(this.declarations, isGetAccessor), checker);
                                }
                                if (length(this.contextualGetAccessorDocumentationComment)) {
                                    return this.contextualGetAccessorDocumentationComment;
                                }
                            }
                            if (isSetAccessor(context)) {
                                if (!this.contextualSetAccessorDocumentationComment) {
                                    this.contextualSetAccessorDocumentationComment = getDocumentationComment(filter(this.declarations, isSetAccessor), checker);
                                }
                                if (length(this.contextualSetAccessorDocumentationComment)) {
                                    return this.contextualSetAccessorDocumentationComment;
                                }
                            }
                        }
                        return this.getDocumentationComment(checker);
                    }
                    getJsDocTags(checker) {
                        if (this.tags === void 0) {
                            this.tags = getJsDocTagsOfDeclarations(this.declarations, checker);
                        }
                        return this.tags;
                    }
                    getContextualJsDocTags(context, checker) {
                        if (context) {
                            if (isGetAccessor(context)) {
                                if (!this.contextualGetAccessorTags) {
                                    this.contextualGetAccessorTags = getJsDocTagsOfDeclarations(filter(this.declarations, isGetAccessor), checker);
                                }
                                if (length(this.contextualGetAccessorTags)) {
                                    return this.contextualGetAccessorTags;
                                }
                            }
                            if (isSetAccessor(context)) {
                                if (!this.contextualSetAccessorTags) {
                                    this.contextualSetAccessorTags = getJsDocTagsOfDeclarations(filter(this.declarations, isSetAccessor), checker);
                                }
                                if (length(this.contextualSetAccessorTags)) {
                                    return this.contextualSetAccessorTags;
                                }
                            }
                        }
                        return this.getJsDocTags(checker);
                    }
                };
                TokenObject = class extends TokenOrIdentifierObject {
                    constructor(kind, pos, end) {
                        super(pos, end);
                        this.kind = kind;
                    }
                };
                IdentifierObject = class extends TokenOrIdentifierObject {
                    constructor(_kind, pos, end) {
                        super(pos, end);
                        this.kind = 79 /* Identifier */;
                    }
                    get text() {
                        return idText(this);
                    }
                };
                IdentifierObject.prototype.kind = 79 /* Identifier */;
                PrivateIdentifierObject = class extends TokenOrIdentifierObject {
                    constructor(_kind, pos, end) {
                        super(pos, end);
                        this.kind = 80 /* PrivateIdentifier */;
                    }
                    get text() {
                        return idText(this);
                    }
                };
                PrivateIdentifierObject.prototype.kind = 80 /* PrivateIdentifier */;
                TypeObject = class {
                    constructor(checker, flags) {
                        this.checker = checker;
                        this.flags = flags;
                    }
                    getFlags() {
                        return this.flags;
                    }
                    getSymbol() {
                        return this.symbol;
                    }
                    getProperties() {
                        return this.checker.getPropertiesOfType(this);
                    }
                    getProperty(propertyName) {
                        return this.checker.getPropertyOfType(this, propertyName);
                    }
                    getApparentProperties() {
                        return this.checker.getAugmentedPropertiesOfType(this);
                    }
                    getCallSignatures() {
                        return this.checker.getSignaturesOfType(this, 0 /* Call */);
                    }
                    getConstructSignatures() {
                        return this.checker.getSignaturesOfType(this, 1 /* Construct */);
                    }
                    getStringIndexType() {
                        return this.checker.getIndexTypeOfType(this, 0 /* String */);
                    }
                    getNumberIndexType() {
                        return this.checker.getIndexTypeOfType(this, 1 /* Number */);
                    }
                    getBaseTypes() {
                        return this.isClassOrInterface() ? this.checker.getBaseTypes(this) : void 0;
                    }
                    isNullableType() {
                        return this.checker.isNullableType(this);
                    }
                    getNonNullableType() {
                        return this.checker.getNonNullableType(this);
                    }
                    getNonOptionalType() {
                        return this.checker.getNonOptionalType(this);
                    }
                    getConstraint() {
                        return this.checker.getBaseConstraintOfType(this);
                    }
                    getDefault() {
                        return this.checker.getDefaultFromTypeParameter(this);
                    }
                    isUnion() {
                        return !!(this.flags & 1048576 /* Union */);
                    }
                    isIntersection() {
                        return !!(this.flags & 2097152 /* Intersection */);
                    }
                    isUnionOrIntersection() {
                        return !!(this.flags & 3145728 /* UnionOrIntersection */);
                    }
                    isLiteral() {
                        return !!(this.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */ | 2048 /* BigIntLiteral */));
                    }
                    isStringLiteral() {
                        return !!(this.flags & 128 /* StringLiteral */);
                    }
                    isNumberLiteral() {
                        return !!(this.flags & 256 /* NumberLiteral */);
                    }
                    isTypeParameter() {
                        return !!(this.flags & 262144 /* TypeParameter */);
                    }
                    isClassOrInterface() {
                        return !!(getObjectFlags(this) & 3 /* ClassOrInterface */);
                    }
                    isClass() {
                        return !!(getObjectFlags(this) & 1 /* Class */);
                    }
                    isIndexType() {
                        return !!(this.flags & 4194304 /* Index */);
                    }
                    /**
                     * This polyfills `referenceType.typeArguments` for API consumers
                     */
                    get typeArguments() {
                        if (getObjectFlags(this) & 4 /* Reference */) {
                            return this.checker.getTypeArguments(this);
                        }
                        return void 0;
                    }
                };
                SignatureObject = class {
                    // same
                    constructor(checker, flags) {
                        this.checker = checker;
                        this.flags = flags;
                    }
                    getDeclaration() {
                        return this.declaration;
                    }
                    getTypeParameters() {
                        return this.typeParameters;
                    }
                    getParameters() {
                        return this.parameters;
                    }
                    getReturnType() {
                        return this.checker.getReturnTypeOfSignature(this);
                    }
                    getTypeParameterAtPosition(pos) {
                        const type = this.checker.getParameterType(this, pos);
                        if (type.isIndexType() && isThisTypeParameter(type.type)) {
                            const constraint = type.type.getConstraint();
                            if (constraint) {
                                return this.checker.getIndexType(constraint);
                            }
                        }
                        return type;
                    }
                    getDocumentationComment() {
                        return this.documentationComment || (this.documentationComment = getDocumentationComment(singleElementArray(this.declaration), this.checker));
                    }
                    getJsDocTags() {
                        return this.jsDocTags || (this.jsDocTags = getJsDocTagsOfDeclarations(singleElementArray(this.declaration), this.checker));
                    }
                };
                SourceFileObject = class extends NodeObject {
                    constructor(kind, pos, end) {
                        super(kind, pos, end);
                        this.kind = 308 /* SourceFile */;
                    }
                    update(newText, textChangeRange) {
                        return updateSourceFile(this, newText, textChangeRange);
                    }
                    getLineAndCharacterOfPosition(position) {
                        return getLineAndCharacterOfPosition(this, position);
                    }
                    getLineStarts() {
                        return getLineStarts(this);
                    }
                    getPositionOfLineAndCharacter(line, character, allowEdits) {
                        return computePositionOfLineAndCharacter(getLineStarts(this), line, character, this.text, allowEdits);
                    }
                    getLineEndOfPosition(pos) {
                        const { line } = this.getLineAndCharacterOfPosition(pos);
                        const lineStarts = this.getLineStarts();
                        let lastCharPos;
                        if (line + 1 >= lineStarts.length) {
                            lastCharPos = this.getEnd();
                        }
                        if (!lastCharPos) {
                            lastCharPos = lineStarts[line + 1] - 1;
                        }
                        const fullText = this.getFullText();
                        return fullText[lastCharPos] === "\n" && fullText[lastCharPos - 1] === "\r" ? lastCharPos - 1 : lastCharPos;
                    }
                    getNamedDeclarations() {
                        if (!this.namedDeclarations) {
                            this.namedDeclarations = this.computeNamedDeclarations();
                        }
                        return this.namedDeclarations;
                    }
                    computeNamedDeclarations() {
                        const result = createMultiMap();
                        this.forEachChild(visit);
                        return result;
                        function addDeclaration(declaration) {
                            const name = getDeclarationName(declaration);
                            if (name) {
                                result.add(name, declaration);
                            }
                        }
                        function getDeclarations(name) {
                            let declarations = result.get(name);
                            if (!declarations) {
                                result.set(name, declarations = []);
                            }
                            return declarations;
                        }
                        function getDeclarationName(declaration) {
                            const name = getNonAssignedNameOfDeclaration(declaration);
                            return name && (isComputedPropertyName(name) && isPropertyAccessExpression(name.expression) ? name.expression.name.text : isPropertyName(name) ? getNameFromPropertyName(name) : void 0);
                        }
                        function visit(node) {
                            switch (node.kind) {
                                case 259 /* FunctionDeclaration */:
                                case 215 /* FunctionExpression */:
                                case 171 /* MethodDeclaration */:
                                case 170 /* MethodSignature */:
                                    const functionDeclaration = node;
                                    const declarationName = getDeclarationName(functionDeclaration);
                                    if (declarationName) {
                                        const declarations = getDeclarations(declarationName);
                                        const lastDeclaration = lastOrUndefined(declarations);
                                        if (lastDeclaration && functionDeclaration.parent === lastDeclaration.parent && functionDeclaration.symbol === lastDeclaration.symbol) {
                                            if (functionDeclaration.body && !lastDeclaration.body) {
                                                declarations[declarations.length - 1] = functionDeclaration;
                                            }
                                        }
                                        else {
                                            declarations.push(functionDeclaration);
                                        }
                                    }
                                    forEachChild(node, visit);
                                    break;
                                case 260 /* ClassDeclaration */:
                                case 228 /* ClassExpression */:
                                case 261 /* InterfaceDeclaration */:
                                case 262 /* TypeAliasDeclaration */:
                                case 263 /* EnumDeclaration */:
                                case 264 /* ModuleDeclaration */:
                                case 268 /* ImportEqualsDeclaration */:
                                case 278 /* ExportSpecifier */:
                                case 273 /* ImportSpecifier */:
                                case 270 /* ImportClause */:
                                case 271 /* NamespaceImport */:
                                case 174 /* GetAccessor */:
                                case 175 /* SetAccessor */:
                                case 184 /* TypeLiteral */:
                                    addDeclaration(node);
                                    forEachChild(node, visit);
                                    break;
                                case 166 /* Parameter */:
                                    if (!hasSyntacticModifier(node, 16476 /* ParameterPropertyModifier */)) {
                                        break;
                                    }
                                case 257 /* VariableDeclaration */:
                                case 205 /* BindingElement */: {
                                    const decl = node;
                                    if (isBindingPattern(decl.name)) {
                                        forEachChild(decl.name, visit);
                                        break;
                                    }
                                    if (decl.initializer) {
                                        visit(decl.initializer);
                                    }
                                }
                                case 302 /* EnumMember */:
                                case 169 /* PropertyDeclaration */:
                                case 168 /* PropertySignature */:
                                    addDeclaration(node);
                                    break;
                                case 275 /* ExportDeclaration */:
                                    const exportDeclaration = node;
                                    if (exportDeclaration.exportClause) {
                                        if (isNamedExports(exportDeclaration.exportClause)) {
                                            forEach(exportDeclaration.exportClause.elements, visit);
                                        }
                                        else {
                                            visit(exportDeclaration.exportClause.name);
                                        }
                                    }
                                    break;
                                case 269 /* ImportDeclaration */:
                                    const importClause = node.importClause;
                                    if (importClause) {
                                        if (importClause.name) {
                                            addDeclaration(importClause.name);
                                        }
                                        if (importClause.namedBindings) {
                                            if (importClause.namedBindings.kind === 271 /* NamespaceImport */) {
                                                addDeclaration(importClause.namedBindings);
                                            }
                                            else {
                                                forEach(importClause.namedBindings.elements, visit);
                                            }
                                        }
                                    }
                                    break;
                                case 223 /* BinaryExpression */:
                                    if (getAssignmentDeclarationKind(node) !== 0 /* None */) {
                                        addDeclaration(node);
                                    }
                                default:
                                    forEachChild(node, visit);
                            }
                        }
                    }
                };
                SourceMapSourceObject = class {
                    constructor(fileName, text, skipTrivia2) {
                        this.fileName = fileName;
                        this.text = text;
                        this.skipTrivia = skipTrivia2;
                    }
                    getLineAndCharacterOfPosition(pos) {
                        return getLineAndCharacterOfPosition(this, pos);
                    }
                };
                SyntaxTreeCache = class {
                    constructor(host) {
                        this.host = host;
                    }
                    getCurrentSourceFile(fileName) {
                        var _a2, _b, _c, _d, _e, _f, _g, _h;
                        const scriptSnapshot = this.host.getScriptSnapshot(fileName);
                        if (!scriptSnapshot) {
                            throw new Error("Could not find file: '" + fileName + "'.");
                        }
                        const scriptKind = getScriptKind(fileName, this.host);
                        const version2 = this.host.getScriptVersion(fileName);
                        let sourceFile;
                        if (this.currentFileName !== fileName) {
                            const options = {
                                languageVersion: 99 /* Latest */,
                                impliedNodeFormat: getImpliedNodeFormatForFile(toPath(fileName, this.host.getCurrentDirectory(), ((_c = (_b = (_a2 = this.host).getCompilerHost) == null ? void 0 : _b.call(_a2)) == null ? void 0 : _c.getCanonicalFileName) || hostGetCanonicalFileName(this.host)), (_h = (_g = (_f = (_e = (_d = this.host).getCompilerHost) == null ? void 0 : _e.call(_d)) == null ? void 0 : _f.getModuleResolutionCache) == null ? void 0 : _g.call(_f)) == null ? void 0 : _h.getPackageJsonInfoCache(), this.host, this.host.getCompilationSettings()),
                                setExternalModuleIndicator: getSetExternalModuleIndicator(this.host.getCompilationSettings())
                            };
                            sourceFile = createLanguageServiceSourceFile(fileName, scriptSnapshot, options, version2, 
                            /*setNodeParents*/
                            true, scriptKind);
                        }
                        else if (this.currentFileVersion !== version2) {
                            const editRange = scriptSnapshot.getChangeRange(this.currentFileScriptSnapshot);
                            sourceFile = updateLanguageServiceSourceFile(this.currentSourceFile, scriptSnapshot, version2, editRange);
                        }
                        if (sourceFile) {
                            this.currentFileVersion = version2;
                            this.currentFileName = fileName;
                            this.currentFileScriptSnapshot = scriptSnapshot;
                            this.currentSourceFile = sourceFile;
                        }
                        return this.currentSourceFile;
                    }
                };
                NoopCancellationToken = {
                    isCancellationRequested: returnFalse,
                    throwIfCancellationRequested: noop
                };
                CancellationTokenObject = class {
                    constructor(cancellationToken) {
                        this.cancellationToken = cancellationToken;
                    }
                    isCancellationRequested() {
                        return this.cancellationToken.isCancellationRequested();
                    }
                    throwIfCancellationRequested() {
                        var _a2;
                        if (this.isCancellationRequested()) {
                            (_a2 = tracing) == null ? void 0 : _a2.instant(tracing.Phase.Session, "cancellationThrown", { kind: "CancellationTokenObject" });
                            throw new OperationCanceledException();
                        }
                    }
                };
                ThrottledCancellationToken = class {
                    constructor(hostCancellationToken, throttleWaitMilliseconds = 20) {
                        this.hostCancellationToken = hostCancellationToken;
                        this.throttleWaitMilliseconds = throttleWaitMilliseconds;
                        // Store when we last tried to cancel.  Checking cancellation can be expensive (as we have
                        // to marshall over to the host layer).  So we only bother actually checking once enough
                        // time has passed.
                        this.lastCancellationCheckTime = 0;
                    }
                    isCancellationRequested() {
                        const time = timestamp();
                        const duration = Math.abs(time - this.lastCancellationCheckTime);
                        if (duration >= this.throttleWaitMilliseconds) {
                            this.lastCancellationCheckTime = time;
                            return this.hostCancellationToken.isCancellationRequested();
                        }
                        return false;
                    }
                    throwIfCancellationRequested() {
                        var _a2;
                        if (this.isCancellationRequested()) {
                            (_a2 = tracing) == null ? void 0 : _a2.instant(tracing.Phase.Session, "cancellationThrown", { kind: "ThrottledCancellationToken" });
                            throw new OperationCanceledException();
                        }
                    }
                };
                invalidOperationsInPartialSemanticMode = [
                    "getSemanticDiagnostics",
                    "getSuggestionDiagnostics",
                    "getCompilerOptionsDiagnostics",
                    "getSemanticClassifications",
                    "getEncodedSemanticClassifications",
                    "getCodeFixesAtPosition",
                    "getCombinedCodeFix",
                    "applyCodeActionCommand",
                    "organizeImports",
                    "getEditsForFileRename",
                    "getEmitOutput",
                    "getApplicableRefactors",
                    "getEditsForRefactor",
                    "prepareCallHierarchy",
                    "provideCallHierarchyIncomingCalls",
                    "provideCallHierarchyOutgoingCalls",
                    "provideInlayHints",
                    "getSupportedCodeFixes"
                ];
                invalidOperationsInSyntacticMode = [
                    ...invalidOperationsInPartialSemanticMode,
                    "getCompletionsAtPosition",
                    "getCompletionEntryDetails",
                    "getCompletionEntrySymbol",
                    "getSignatureHelpItems",
                    "getQuickInfoAtPosition",
                    "getDefinitionAtPosition",
                    "getDefinitionAndBoundSpan",
                    "getImplementationAtPosition",
                    "getTypeDefinitionAtPosition",
                    "getReferencesAtPosition",
                    "findReferences",
                    "getOccurrencesAtPosition",
                    "getDocumentHighlights",
                    "getNavigateToItems",
                    "getRenameInfo",
                    "findRenameLocations",
                    "getApplicableRefactors"
                ];
                setObjectAllocator(getServicesObjectAllocator());
            }
        });
        // src/services/transform.ts
        function transform(source, transformers, compilerOptions) {
            const diagnostics = [];
            compilerOptions = fixupCompilerOptions(compilerOptions, diagnostics);
            const nodes = isArray(source) ? source : [source];
            const result = transformNodes(
            /*resolver*/
            void 0, 
            /*emitHost*/
            void 0, factory, compilerOptions, nodes, transformers, 
            /*allowDtsFiles*/
            true);
            result.diagnostics = concatenate(result.diagnostics, diagnostics);
            return result;
        }
        var init_transform = __esm({
            "src/services/transform.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/shims.ts
        function logInternalError(logger, err) {
            if (logger) {
                logger.log("*INTERNAL ERROR* - Exception in typescript services: " + err.message);
            }
        }
        function simpleForwardCall(logger, actionDescription2, action, logPerformance) {
            let start;
            if (logPerformance) {
                logger.log(actionDescription2);
                start = timestamp();
            }
            const result = action();
            if (logPerformance) {
                const end = timestamp();
                logger.log(`${actionDescription2} completed in ${end - start} msec`);
                if (isString(result)) {
                    let str = result;
                    if (str.length > 128) {
                        str = str.substring(0, 128) + "...";
                    }
                    logger.log(`  result.length=${str.length}, result='${JSON.stringify(str)}'`);
                }
            }
            return result;
        }
        function forwardJSONCall(logger, actionDescription2, action, logPerformance) {
            return forwardCall(logger, actionDescription2, 
            /*returnJson*/
            true, action, logPerformance);
        }
        function forwardCall(logger, actionDescription2, returnJson, action, logPerformance) {
            try {
                const result = simpleForwardCall(logger, actionDescription2, action, logPerformance);
                return returnJson ? JSON.stringify({ result }) : result;
            }
            catch (err) {
                if (err instanceof OperationCanceledException) {
                    return JSON.stringify({ canceled: true });
                }
                logInternalError(logger, err);
                err.description = actionDescription2;
                return JSON.stringify({ error: err });
            }
        }
        function realizeDiagnostics(diagnostics, newLine) {
            return diagnostics.map((d) => realizeDiagnostic(d, newLine));
        }
        function realizeDiagnostic(diagnostic, newLine) {
            return {
                message: flattenDiagnosticMessageText(diagnostic.messageText, newLine),
                start: diagnostic.start,
                // TODO: GH#18217
                length: diagnostic.length,
                // TODO: GH#18217
                category: diagnosticCategoryName(diagnostic),
                code: diagnostic.code,
                reportsUnnecessary: diagnostic.reportsUnnecessary,
                reportsDeprecated: diagnostic.reportsDeprecated
            };
        }
        function convertClassifications(classifications) {
            return { spans: classifications.spans.join(","), endOfLineState: classifications.endOfLineState };
        }
        var debugObjectHost, ScriptSnapshotShimAdapter, LanguageServiceShimHostAdapter, CoreServicesShimHostAdapter, ShimBase, LanguageServiceShimObject, ClassifierShimObject, CoreServicesShimObject, TypeScriptServicesFactory;
        var init_shims = __esm({
            "src/services/shims.ts"() {
                "use strict";
                init_ts4();
                debugObjectHost = function () {
                    return this;
                }();
                ScriptSnapshotShimAdapter = class {
                    constructor(scriptSnapshotShim) {
                        this.scriptSnapshotShim = scriptSnapshotShim;
                    }
                    getText(start, end) {
                        return this.scriptSnapshotShim.getText(start, end);
                    }
                    getLength() {
                        return this.scriptSnapshotShim.getLength();
                    }
                    getChangeRange(oldSnapshot) {
                        const oldSnapshotShim = oldSnapshot;
                        const encoded = this.scriptSnapshotShim.getChangeRange(oldSnapshotShim.scriptSnapshotShim);
                        if (encoded === null) {
                            return null;
                        }
                        const decoded = JSON.parse(encoded);
                        return createTextChangeRange(createTextSpan(decoded.span.start, decoded.span.length), decoded.newLength);
                    }
                    dispose() {
                        if ("dispose" in this.scriptSnapshotShim) {
                            this.scriptSnapshotShim.dispose();
                        }
                    }
                };
                LanguageServiceShimHostAdapter = class {
                    constructor(shimHost) {
                        this.shimHost = shimHost;
                        this.loggingEnabled = false;
                        this.tracingEnabled = false;
                        if ("getModuleResolutionsForFile" in this.shimHost) {
                            this.resolveModuleNames = (moduleNames, containingFile) => {
                                const resolutionsInFile = JSON.parse(this.shimHost.getModuleResolutionsForFile(containingFile));
                                return map(moduleNames, (name) => {
                                    const result = getProperty(resolutionsInFile, name);
                                    return result ? { resolvedFileName: result, extension: extensionFromPath(result), isExternalLibraryImport: false } : void 0;
                                });
                            };
                        }
                        if ("directoryExists" in this.shimHost) {
                            this.directoryExists = (directoryName) => this.shimHost.directoryExists(directoryName);
                        }
                        if ("getTypeReferenceDirectiveResolutionsForFile" in this.shimHost) {
                            this.resolveTypeReferenceDirectives = (typeDirectiveNames, containingFile) => {
                                const typeDirectivesForFile = JSON.parse(this.shimHost.getTypeReferenceDirectiveResolutionsForFile(containingFile));
                                return map(typeDirectiveNames, (name) => getProperty(typeDirectivesForFile, isString(name) ? name : toFileNameLowerCase(name.fileName)));
                            };
                        }
                    }
                    log(s) {
                        if (this.loggingEnabled) {
                            this.shimHost.log(s);
                        }
                    }
                    trace(s) {
                        if (this.tracingEnabled) {
                            this.shimHost.trace(s);
                        }
                    }
                    error(s) {
                        this.shimHost.error(s);
                    }
                    getProjectVersion() {
                        if (!this.shimHost.getProjectVersion) {
                            return void 0;
                        }
                        return this.shimHost.getProjectVersion();
                    }
                    getTypeRootsVersion() {
                        if (!this.shimHost.getTypeRootsVersion) {
                            return 0;
                        }
                        return this.shimHost.getTypeRootsVersion();
                    }
                    useCaseSensitiveFileNames() {
                        return this.shimHost.useCaseSensitiveFileNames ? this.shimHost.useCaseSensitiveFileNames() : false;
                    }
                    getCompilationSettings() {
                        const settingsJson = this.shimHost.getCompilationSettings();
                        if (settingsJson === null || settingsJson === "") {
                            throw Error("LanguageServiceShimHostAdapter.getCompilationSettings: empty compilationSettings");
                        }
                        const compilerOptions = JSON.parse(settingsJson);
                        compilerOptions.allowNonTsExtensions = true;
                        return compilerOptions;
                    }
                    getScriptFileNames() {
                        const encoded = this.shimHost.getScriptFileNames();
                        return JSON.parse(encoded);
                    }
                    getScriptSnapshot(fileName) {
                        const scriptSnapshot = this.shimHost.getScriptSnapshot(fileName);
                        return scriptSnapshot && new ScriptSnapshotShimAdapter(scriptSnapshot);
                    }
                    getScriptKind(fileName) {
                        if ("getScriptKind" in this.shimHost) {
                            return this.shimHost.getScriptKind(fileName);
                        }
                        else {
                            return 0 /* Unknown */;
                        }
                    }
                    getScriptVersion(fileName) {
                        return this.shimHost.getScriptVersion(fileName);
                    }
                    getLocalizedDiagnosticMessages() {
                        const diagnosticMessagesJson = this.shimHost.getLocalizedDiagnosticMessages();
                        if (diagnosticMessagesJson === null || diagnosticMessagesJson === "") {
                            return null;
                        }
                        try {
                            return JSON.parse(diagnosticMessagesJson);
                        }
                        catch (e) {
                            this.log(e.description || "diagnosticMessages.generated.json has invalid JSON format");
                            return null;
                        }
                    }
                    getCancellationToken() {
                        const hostCancellationToken = this.shimHost.getCancellationToken();
                        return new ThrottledCancellationToken(hostCancellationToken);
                    }
                    getCurrentDirectory() {
                        return this.shimHost.getCurrentDirectory();
                    }
                    getDirectories(path) {
                        return JSON.parse(this.shimHost.getDirectories(path));
                    }
                    getDefaultLibFileName(options) {
                        return this.shimHost.getDefaultLibFileName(JSON.stringify(options));
                    }
                    readDirectory(path, extensions, exclude, include, depth) {
                        const pattern = getFileMatcherPatterns(path, exclude, include, this.shimHost.useCaseSensitiveFileNames(), this.shimHost.getCurrentDirectory());
                        return JSON.parse(this.shimHost.readDirectory(path, JSON.stringify(extensions), JSON.stringify(pattern.basePaths), pattern.excludePattern, pattern.includeFilePattern, pattern.includeDirectoryPattern, depth));
                    }
                    readFile(path, encoding) {
                        return this.shimHost.readFile(path, encoding);
                    }
                    fileExists(path) {
                        return this.shimHost.fileExists(path);
                    }
                };
                CoreServicesShimHostAdapter = class {
                    constructor(shimHost) {
                        this.shimHost = shimHost;
                        this.useCaseSensitiveFileNames = this.shimHost.useCaseSensitiveFileNames ? this.shimHost.useCaseSensitiveFileNames() : false;
                        if ("directoryExists" in this.shimHost) {
                            this.directoryExists = (directoryName) => this.shimHost.directoryExists(directoryName);
                        }
                        else {
                            this.directoryExists = void 0;
                        }
                        if ("realpath" in this.shimHost) {
                            this.realpath = (path) => this.shimHost.realpath(path);
                        }
                        else {
                            this.realpath = void 0;
                        }
                    }
                    readDirectory(rootDir, extensions, exclude, include, depth) {
                        const pattern = getFileMatcherPatterns(rootDir, exclude, include, this.shimHost.useCaseSensitiveFileNames(), this.shimHost.getCurrentDirectory());
                        return JSON.parse(this.shimHost.readDirectory(rootDir, JSON.stringify(extensions), JSON.stringify(pattern.basePaths), pattern.excludePattern, pattern.includeFilePattern, pattern.includeDirectoryPattern, depth));
                    }
                    fileExists(fileName) {
                        return this.shimHost.fileExists(fileName);
                    }
                    readFile(fileName) {
                        return this.shimHost.readFile(fileName);
                    }
                    getDirectories(path) {
                        return JSON.parse(this.shimHost.getDirectories(path));
                    }
                };
                ShimBase = class {
                    constructor(factory2) {
                        this.factory = factory2;
                        factory2.registerShim(this);
                    }
                    dispose(_dummy) {
                        this.factory.unregisterShim(this);
                    }
                };
                LanguageServiceShimObject = class extends ShimBase {
                    constructor(factory2, host, languageService) {
                        super(factory2);
                        this.host = host;
                        this.languageService = languageService;
                        this.logPerformance = false;
                        this.logger = this.host;
                    }
                    forwardJSONCall(actionDescription2, action) {
                        return forwardJSONCall(this.logger, actionDescription2, action, this.logPerformance);
                    }
                    /// DISPOSE
                    /**
                     * Ensure (almost) deterministic release of internal Javascript resources when
                     * some external native objects holds onto us (e.g. Com/Interop).
                     */
                    dispose(dummy) {
                        this.logger.log("dispose()");
                        this.languageService.dispose();
                        this.languageService = null;
                        if (debugObjectHost && debugObjectHost.CollectGarbage) {
                            debugObjectHost.CollectGarbage();
                            this.logger.log("CollectGarbage()");
                        }
                        this.logger = null;
                        super.dispose(dummy);
                    }
                    /// REFRESH
                    /**
                     * Update the list of scripts known to the compiler
                     */
                    refresh(throwOnError) {
                        this.forwardJSONCall(`refresh(${throwOnError})`, () => null
                        // eslint-disable-line no-null/no-null
                        );
                    }
                    cleanupSemanticCache() {
                        this.forwardJSONCall("cleanupSemanticCache()", () => {
                            this.languageService.cleanupSemanticCache();
                            return null;
                        });
                    }
                    realizeDiagnostics(diagnostics) {
                        const newLine = getNewLineOrDefaultFromHost(this.host, 
                        /*formatSettings*/
                        void 0);
                        return realizeDiagnostics(diagnostics, newLine);
                    }
                    getSyntacticClassifications(fileName, start, length2) {
                        return this.forwardJSONCall(`getSyntacticClassifications('${fileName}', ${start}, ${length2})`, () => this.languageService.getSyntacticClassifications(fileName, createTextSpan(start, length2)));
                    }
                    getSemanticClassifications(fileName, start, length2) {
                        return this.forwardJSONCall(`getSemanticClassifications('${fileName}', ${start}, ${length2})`, () => this.languageService.getSemanticClassifications(fileName, createTextSpan(start, length2)));
                    }
                    getEncodedSyntacticClassifications(fileName, start, length2) {
                        return this.forwardJSONCall(`getEncodedSyntacticClassifications('${fileName}', ${start}, ${length2})`, 
                        // directly serialize the spans out to a string.  This is much faster to decode
                        // on the managed side versus a full JSON array.
                        () => convertClassifications(this.languageService.getEncodedSyntacticClassifications(fileName, createTextSpan(start, length2))));
                    }
                    getEncodedSemanticClassifications(fileName, start, length2) {
                        return this.forwardJSONCall(`getEncodedSemanticClassifications('${fileName}', ${start}, ${length2})`, 
                        // directly serialize the spans out to a string.  This is much faster to decode
                        // on the managed side versus a full JSON array.
                        () => convertClassifications(this.languageService.getEncodedSemanticClassifications(fileName, createTextSpan(start, length2))));
                    }
                    getSyntacticDiagnostics(fileName) {
                        return this.forwardJSONCall(`getSyntacticDiagnostics('${fileName}')`, () => {
                            const diagnostics = this.languageService.getSyntacticDiagnostics(fileName);
                            return this.realizeDiagnostics(diagnostics);
                        });
                    }
                    getSemanticDiagnostics(fileName) {
                        return this.forwardJSONCall(`getSemanticDiagnostics('${fileName}')`, () => {
                            const diagnostics = this.languageService.getSemanticDiagnostics(fileName);
                            return this.realizeDiagnostics(diagnostics);
                        });
                    }
                    getSuggestionDiagnostics(fileName) {
                        return this.forwardJSONCall(`getSuggestionDiagnostics('${fileName}')`, () => this.realizeDiagnostics(this.languageService.getSuggestionDiagnostics(fileName)));
                    }
                    getCompilerOptionsDiagnostics() {
                        return this.forwardJSONCall("getCompilerOptionsDiagnostics()", () => {
                            const diagnostics = this.languageService.getCompilerOptionsDiagnostics();
                            return this.realizeDiagnostics(diagnostics);
                        });
                    }
                    /// QUICKINFO
                    /**
                     * Computes a string representation of the type at the requested position
                     * in the active file.
                     */
                    getQuickInfoAtPosition(fileName, position) {
                        return this.forwardJSONCall(`getQuickInfoAtPosition('${fileName}', ${position})`, () => this.languageService.getQuickInfoAtPosition(fileName, position));
                    }
                    /// NAMEORDOTTEDNAMESPAN
                    /**
                     * Computes span information of the name or dotted name at the requested position
                     * in the active file.
                     */
                    getNameOrDottedNameSpan(fileName, startPos, endPos) {
                        return this.forwardJSONCall(`getNameOrDottedNameSpan('${fileName}', ${startPos}, ${endPos})`, () => this.languageService.getNameOrDottedNameSpan(fileName, startPos, endPos));
                    }
                    /**
                     * STATEMENTSPAN
                     * Computes span information of statement at the requested position in the active file.
                     */
                    getBreakpointStatementAtPosition(fileName, position) {
                        return this.forwardJSONCall(`getBreakpointStatementAtPosition('${fileName}', ${position})`, () => this.languageService.getBreakpointStatementAtPosition(fileName, position));
                    }
                    /// SIGNATUREHELP
                    getSignatureHelpItems(fileName, position, options) {
                        return this.forwardJSONCall(`getSignatureHelpItems('${fileName}', ${position})`, () => this.languageService.getSignatureHelpItems(fileName, position, options));
                    }
                    /// GOTO DEFINITION
                    /**
                     * Computes the definition location and file for the symbol
                     * at the requested position.
                     */
                    getDefinitionAtPosition(fileName, position) {
                        return this.forwardJSONCall(`getDefinitionAtPosition('${fileName}', ${position})`, () => this.languageService.getDefinitionAtPosition(fileName, position));
                    }
                    /**
                     * Computes the definition location and file for the symbol
                     * at the requested position.
                     */
                    getDefinitionAndBoundSpan(fileName, position) {
                        return this.forwardJSONCall(`getDefinitionAndBoundSpan('${fileName}', ${position})`, () => this.languageService.getDefinitionAndBoundSpan(fileName, position));
                    }
                    /// GOTO Type
                    /**
                     * Computes the definition location of the type of the symbol
                     * at the requested position.
                     */
                    getTypeDefinitionAtPosition(fileName, position) {
                        return this.forwardJSONCall(`getTypeDefinitionAtPosition('${fileName}', ${position})`, () => this.languageService.getTypeDefinitionAtPosition(fileName, position));
                    }
                    /// GOTO Implementation
                    /**
                     * Computes the implementation location of the symbol
                     * at the requested position.
                     */
                    getImplementationAtPosition(fileName, position) {
                        return this.forwardJSONCall(`getImplementationAtPosition('${fileName}', ${position})`, () => this.languageService.getImplementationAtPosition(fileName, position));
                    }
                    getRenameInfo(fileName, position, preferences) {
                        return this.forwardJSONCall(`getRenameInfo('${fileName}', ${position})`, () => this.languageService.getRenameInfo(fileName, position, preferences));
                    }
                    getSmartSelectionRange(fileName, position) {
                        return this.forwardJSONCall(`getSmartSelectionRange('${fileName}', ${position})`, () => this.languageService.getSmartSelectionRange(fileName, position));
                    }
                    findRenameLocations(fileName, position, findInStrings, findInComments, providePrefixAndSuffixTextForRename) {
                        return this.forwardJSONCall(`findRenameLocations('${fileName}', ${position}, ${findInStrings}, ${findInComments}, ${providePrefixAndSuffixTextForRename})`, () => this.languageService.findRenameLocations(fileName, position, findInStrings, findInComments, providePrefixAndSuffixTextForRename));
                    }
                    /// GET BRACE MATCHING
                    getBraceMatchingAtPosition(fileName, position) {
                        return this.forwardJSONCall(`getBraceMatchingAtPosition('${fileName}', ${position})`, () => this.languageService.getBraceMatchingAtPosition(fileName, position));
                    }
                    isValidBraceCompletionAtPosition(fileName, position, openingBrace) {
                        return this.forwardJSONCall(`isValidBraceCompletionAtPosition('${fileName}', ${position}, ${openingBrace})`, () => this.languageService.isValidBraceCompletionAtPosition(fileName, position, openingBrace));
                    }
                    getSpanOfEnclosingComment(fileName, position, onlyMultiLine) {
                        return this.forwardJSONCall(`getSpanOfEnclosingComment('${fileName}', ${position})`, () => this.languageService.getSpanOfEnclosingComment(fileName, position, onlyMultiLine));
                    }
                    /// GET SMART INDENT
                    getIndentationAtPosition(fileName, position, options) {
                        return this.forwardJSONCall(`getIndentationAtPosition('${fileName}', ${position})`, () => {
                            const localOptions = JSON.parse(options);
                            return this.languageService.getIndentationAtPosition(fileName, position, localOptions);
                        });
                    }
                    /// GET REFERENCES
                    getReferencesAtPosition(fileName, position) {
                        return this.forwardJSONCall(`getReferencesAtPosition('${fileName}', ${position})`, () => this.languageService.getReferencesAtPosition(fileName, position));
                    }
                    findReferences(fileName, position) {
                        return this.forwardJSONCall(`findReferences('${fileName}', ${position})`, () => this.languageService.findReferences(fileName, position));
                    }
                    getFileReferences(fileName) {
                        return this.forwardJSONCall(`getFileReferences('${fileName})`, () => this.languageService.getFileReferences(fileName));
                    }
                    getOccurrencesAtPosition(fileName, position) {
                        return this.forwardJSONCall(`getOccurrencesAtPosition('${fileName}', ${position})`, () => this.languageService.getOccurrencesAtPosition(fileName, position));
                    }
                    getDocumentHighlights(fileName, position, filesToSearch) {
                        return this.forwardJSONCall(`getDocumentHighlights('${fileName}', ${position})`, () => {
                            const results = this.languageService.getDocumentHighlights(fileName, position, JSON.parse(filesToSearch));
                            const normalizedName = toFileNameLowerCase(normalizeSlashes(fileName));
                            return filter(results, (r) => toFileNameLowerCase(normalizeSlashes(r.fileName)) === normalizedName);
                        });
                    }
                    /// COMPLETION LISTS
                    /**
                     * Get a string based representation of the completions
                     * to provide at the given source position and providing a member completion
                     * list if requested.
                     */
                    getCompletionsAtPosition(fileName, position, preferences, formattingSettings) {
                        return this.forwardJSONCall(`getCompletionsAtPosition('${fileName}', ${position}, ${preferences}, ${formattingSettings})`, () => this.languageService.getCompletionsAtPosition(fileName, position, preferences, formattingSettings));
                    }
                    /** Get a string based representation of a completion list entry details */
                    getCompletionEntryDetails(fileName, position, entryName, formatOptions, source, preferences, data) {
                        return this.forwardJSONCall(`getCompletionEntryDetails('${fileName}', ${position}, '${entryName}')`, () => {
                            const localOptions = formatOptions === void 0 ? void 0 : JSON.parse(formatOptions);
                            return this.languageService.getCompletionEntryDetails(fileName, position, entryName, localOptions, source, preferences, data);
                        });
                    }
                    getFormattingEditsForRange(fileName, start, end, options) {
                        return this.forwardJSONCall(`getFormattingEditsForRange('${fileName}', ${start}, ${end})`, () => {
                            const localOptions = JSON.parse(options);
                            return this.languageService.getFormattingEditsForRange(fileName, start, end, localOptions);
                        });
                    }
                    getFormattingEditsForDocument(fileName, options) {
                        return this.forwardJSONCall(`getFormattingEditsForDocument('${fileName}')`, () => {
                            const localOptions = JSON.parse(options);
                            return this.languageService.getFormattingEditsForDocument(fileName, localOptions);
                        });
                    }
                    getFormattingEditsAfterKeystroke(fileName, position, key, options) {
                        return this.forwardJSONCall(`getFormattingEditsAfterKeystroke('${fileName}', ${position}, '${key}')`, () => {
                            const localOptions = JSON.parse(options);
                            return this.languageService.getFormattingEditsAfterKeystroke(fileName, position, key, localOptions);
                        });
                    }
                    getDocCommentTemplateAtPosition(fileName, position, options, formatOptions) {
                        return this.forwardJSONCall(`getDocCommentTemplateAtPosition('${fileName}', ${position})`, () => this.languageService.getDocCommentTemplateAtPosition(fileName, position, options, formatOptions));
                    }
                    /// NAVIGATE TO
                    /** Return a list of symbols that are interesting to navigate to */
                    getNavigateToItems(searchValue, maxResultCount, fileName) {
                        return this.forwardJSONCall(`getNavigateToItems('${searchValue}', ${maxResultCount}, ${fileName})`, () => this.languageService.getNavigateToItems(searchValue, maxResultCount, fileName));
                    }
                    getNavigationBarItems(fileName) {
                        return this.forwardJSONCall(`getNavigationBarItems('${fileName}')`, () => this.languageService.getNavigationBarItems(fileName));
                    }
                    getNavigationTree(fileName) {
                        return this.forwardJSONCall(`getNavigationTree('${fileName}')`, () => this.languageService.getNavigationTree(fileName));
                    }
                    getOutliningSpans(fileName) {
                        return this.forwardJSONCall(`getOutliningSpans('${fileName}')`, () => this.languageService.getOutliningSpans(fileName));
                    }
                    getTodoComments(fileName, descriptors) {
                        return this.forwardJSONCall(`getTodoComments('${fileName}')`, () => this.languageService.getTodoComments(fileName, JSON.parse(descriptors)));
                    }
                    /// CALL HIERARCHY
                    prepareCallHierarchy(fileName, position) {
                        return this.forwardJSONCall(`prepareCallHierarchy('${fileName}', ${position})`, () => this.languageService.prepareCallHierarchy(fileName, position));
                    }
                    provideCallHierarchyIncomingCalls(fileName, position) {
                        return this.forwardJSONCall(`provideCallHierarchyIncomingCalls('${fileName}', ${position})`, () => this.languageService.provideCallHierarchyIncomingCalls(fileName, position));
                    }
                    provideCallHierarchyOutgoingCalls(fileName, position) {
                        return this.forwardJSONCall(`provideCallHierarchyOutgoingCalls('${fileName}', ${position})`, () => this.languageService.provideCallHierarchyOutgoingCalls(fileName, position));
                    }
                    provideInlayHints(fileName, span, preference) {
                        return this.forwardJSONCall(`provideInlayHints('${fileName}', '${JSON.stringify(span)}', ${JSON.stringify(preference)})`, () => this.languageService.provideInlayHints(fileName, span, preference));
                    }
                    /// Emit
                    getEmitOutput(fileName) {
                        return this.forwardJSONCall(`getEmitOutput('${fileName}')`, () => {
                            const { diagnostics, ...rest } = this.languageService.getEmitOutput(fileName);
                            return { ...rest, diagnostics: this.realizeDiagnostics(diagnostics) };
                        });
                    }
                    getEmitOutputObject(fileName) {
                        return forwardCall(this.logger, `getEmitOutput('${fileName}')`, 
                        /*returnJson*/
                        false, () => this.languageService.getEmitOutput(fileName), this.logPerformance);
                    }
                    toggleLineComment(fileName, textRange) {
                        return this.forwardJSONCall(`toggleLineComment('${fileName}', '${JSON.stringify(textRange)}')`, () => this.languageService.toggleLineComment(fileName, textRange));
                    }
                    toggleMultilineComment(fileName, textRange) {
                        return this.forwardJSONCall(`toggleMultilineComment('${fileName}', '${JSON.stringify(textRange)}')`, () => this.languageService.toggleMultilineComment(fileName, textRange));
                    }
                    commentSelection(fileName, textRange) {
                        return this.forwardJSONCall(`commentSelection('${fileName}', '${JSON.stringify(textRange)}')`, () => this.languageService.commentSelection(fileName, textRange));
                    }
                    uncommentSelection(fileName, textRange) {
                        return this.forwardJSONCall(`uncommentSelection('${fileName}', '${JSON.stringify(textRange)}')`, () => this.languageService.uncommentSelection(fileName, textRange));
                    }
                };
                ClassifierShimObject = class extends ShimBase {
                    constructor(factory2, logger) {
                        super(factory2);
                        this.logger = logger;
                        this.logPerformance = false;
                        this.classifier = createClassifier();
                    }
                    getEncodedLexicalClassifications(text, lexState, syntacticClassifierAbsent = false) {
                        return forwardJSONCall(this.logger, "getEncodedLexicalClassifications", () => convertClassifications(this.classifier.getEncodedLexicalClassifications(text, lexState, syntacticClassifierAbsent)), this.logPerformance);
                    }
                    /// COLORIZATION
                    getClassificationsForLine(text, lexState, classifyKeywordsInGenerics = false) {
                        const classification = this.classifier.getClassificationsForLine(text, lexState, classifyKeywordsInGenerics);
                        let result = "";
                        for (const item of classification.entries) {
                            result += item.length + "\n";
                            result += item.classification + "\n";
                        }
                        result += classification.finalLexState;
                        return result;
                    }
                };
                CoreServicesShimObject = class extends ShimBase {
                    constructor(factory2, logger, host) {
                        super(factory2);
                        this.logger = logger;
                        this.host = host;
                        this.logPerformance = false;
                    }
                    forwardJSONCall(actionDescription2, action) {
                        return forwardJSONCall(this.logger, actionDescription2, action, this.logPerformance);
                    }
                    resolveModuleName(fileName, moduleName, compilerOptionsJson) {
                        return this.forwardJSONCall(`resolveModuleName('${fileName}')`, () => {
                            const compilerOptions = JSON.parse(compilerOptionsJson);
                            const result = resolveModuleName(moduleName, normalizeSlashes(fileName), compilerOptions, this.host);
                            let resolvedFileName = result.resolvedModule ? result.resolvedModule.resolvedFileName : void 0;
                            if (result.resolvedModule && result.resolvedModule.extension !== ".ts" /* Ts */ && result.resolvedModule.extension !== ".tsx" /* Tsx */ && result.resolvedModule.extension !== ".d.ts" /* Dts */) {
                                resolvedFileName = void 0;
                            }
                            return {
                                resolvedFileName,
                                failedLookupLocations: result.failedLookupLocations,
                                affectingLocations: result.affectingLocations
                            };
                        });
                    }
                    resolveTypeReferenceDirective(fileName, typeReferenceDirective, compilerOptionsJson) {
                        return this.forwardJSONCall(`resolveTypeReferenceDirective(${fileName})`, () => {
                            const compilerOptions = JSON.parse(compilerOptionsJson);
                            const result = resolveTypeReferenceDirective(typeReferenceDirective, normalizeSlashes(fileName), compilerOptions, this.host);
                            return {
                                resolvedFileName: result.resolvedTypeReferenceDirective ? result.resolvedTypeReferenceDirective.resolvedFileName : void 0,
                                primary: result.resolvedTypeReferenceDirective ? result.resolvedTypeReferenceDirective.primary : true,
                                failedLookupLocations: result.failedLookupLocations
                            };
                        });
                    }
                    getPreProcessedFileInfo(fileName, sourceTextSnapshot) {
                        return this.forwardJSONCall(`getPreProcessedFileInfo('${fileName}')`, () => {
                            const result = preProcessFile(getSnapshotText(sourceTextSnapshot), 
                            /* readImportFiles */
                            true, 
                            /* detectJavaScriptImports */
                            true);
                            return {
                                referencedFiles: this.convertFileReferences(result.referencedFiles),
                                importedFiles: this.convertFileReferences(result.importedFiles),
                                ambientExternalModules: result.ambientExternalModules,
                                isLibFile: result.isLibFile,
                                typeReferenceDirectives: this.convertFileReferences(result.typeReferenceDirectives),
                                libReferenceDirectives: this.convertFileReferences(result.libReferenceDirectives)
                            };
                        });
                    }
                    getAutomaticTypeDirectiveNames(compilerOptionsJson) {
                        return this.forwardJSONCall(`getAutomaticTypeDirectiveNames('${compilerOptionsJson}')`, () => {
                            const compilerOptions = JSON.parse(compilerOptionsJson);
                            return getAutomaticTypeDirectiveNames(compilerOptions, this.host);
                        });
                    }
                    convertFileReferences(refs) {
                        if (!refs) {
                            return void 0;
                        }
                        const result = [];
                        for (const ref of refs) {
                            result.push({
                                path: normalizeSlashes(ref.fileName),
                                position: ref.pos,
                                length: ref.end - ref.pos
                            });
                        }
                        return result;
                    }
                    getTSConfigFileInfo(fileName, sourceTextSnapshot) {
                        return this.forwardJSONCall(`getTSConfigFileInfo('${fileName}')`, () => {
                            const result = parseJsonText(fileName, getSnapshotText(sourceTextSnapshot));
                            const normalizedFileName = normalizeSlashes(fileName);
                            const configFile = parseJsonSourceFileConfigFileContent(result, this.host, getDirectoryPath(normalizedFileName), 
                            /*existingOptions*/
                            {}, normalizedFileName);
                            return {
                                options: configFile.options,
                                typeAcquisition: configFile.typeAcquisition,
                                files: configFile.fileNames,
                                raw: configFile.raw,
                                errors: realizeDiagnostics([...result.parseDiagnostics, ...configFile.errors], "\r\n")
                            };
                        });
                    }
                    getDefaultCompilationSettings() {
                        return this.forwardJSONCall("getDefaultCompilationSettings()", () => getDefaultCompilerOptions2());
                    }
                    discoverTypings(discoverTypingsJson) {
                        const getCanonicalFileName = createGetCanonicalFileName(
                        /*useCaseSensitivefileNames:*/
                        false);
                        return this.forwardJSONCall("discoverTypings()", () => {
                            const info = JSON.parse(discoverTypingsJson);
                            if (this.safeList === void 0) {
                                this.safeList = ts_JsTyping_exports.loadSafeList(this.host, toPath(info.safeListPath, info.safeListPath, getCanonicalFileName));
                            }
                            return ts_JsTyping_exports.discoverTypings(this.host, (msg) => this.logger.log(msg), info.fileNames, toPath(info.projectRootPath, info.projectRootPath, getCanonicalFileName), this.safeList, info.packageNameToTypingLocation, info.typeAcquisition, info.unresolvedImports, info.typesRegistry, emptyOptions);
                        });
                    }
                };
                TypeScriptServicesFactory = class {
                    constructor() {
                        this._shims = [];
                    }
                    /*
                     * Returns script API version.
                     */
                    getServicesVersion() {
                        return servicesVersion;
                    }
                    createLanguageServiceShim(host) {
                        try {
                            if (this.documentRegistry === void 0) {
                                this.documentRegistry = createDocumentRegistry(host.useCaseSensitiveFileNames && host.useCaseSensitiveFileNames(), host.getCurrentDirectory());
                            }
                            const hostAdapter = new LanguageServiceShimHostAdapter(host);
                            const languageService = createLanguageService(hostAdapter, this.documentRegistry, 
                            /*syntaxOnly*/
                            false);
                            return new LanguageServiceShimObject(this, host, languageService);
                        }
                        catch (err) {
                            logInternalError(host, err);
                            throw err;
                        }
                    }
                    createClassifierShim(logger) {
                        try {
                            return new ClassifierShimObject(this, logger);
                        }
                        catch (err) {
                            logInternalError(logger, err);
                            throw err;
                        }
                    }
                    createCoreServicesShim(host) {
                        try {
                            const adapter = new CoreServicesShimHostAdapter(host);
                            return new CoreServicesShimObject(this, host, adapter);
                        }
                        catch (err) {
                            logInternalError(host, err);
                            throw err;
                        }
                    }
                    close() {
                        clear(this._shims);
                        this.documentRegistry = void 0;
                    }
                    registerShim(shim) {
                        this._shims.push(shim);
                    }
                    unregisterShim(shim) {
                        for (let i = 0; i < this._shims.length; i++) {
                            if (this._shims[i] === shim) {
                                delete this._shims[i];
                                return;
                            }
                        }
                        throw new Error("Invalid operation");
                    }
                };
            }
        });
        // src/services/breakpoints.ts
        function spanInSourceFileAtLocation(sourceFile, position) {
            if (sourceFile.isDeclarationFile) {
                return void 0;
            }
            let tokenAtLocation = getTokenAtPosition(sourceFile, position);
            const lineOfPosition = sourceFile.getLineAndCharacterOfPosition(position).line;
            if (sourceFile.getLineAndCharacterOfPosition(tokenAtLocation.getStart(sourceFile)).line > lineOfPosition) {
                const preceding = findPrecedingToken(tokenAtLocation.pos, sourceFile);
                if (!preceding || sourceFile.getLineAndCharacterOfPosition(preceding.getEnd()).line !== lineOfPosition) {
                    return void 0;
                }
                tokenAtLocation = preceding;
            }
            if (tokenAtLocation.flags & 16777216 /* Ambient */) {
                return void 0;
            }
            return spanInNode(tokenAtLocation);
            function textSpan(startNode2, endNode2) {
                const lastDecorator = canHaveDecorators(startNode2) ? findLast(startNode2.modifiers, isDecorator) : void 0;
                const start = lastDecorator ? skipTrivia(sourceFile.text, lastDecorator.end) : startNode2.getStart(sourceFile);
                return createTextSpanFromBounds(start, (endNode2 || startNode2).getEnd());
            }
            function textSpanEndingAtNextToken(startNode2, previousTokenToFindNextEndToken) {
                return textSpan(startNode2, findNextToken(previousTokenToFindNextEndToken, previousTokenToFindNextEndToken.parent, sourceFile));
            }
            function spanInNodeIfStartsOnSameLine(node, otherwiseOnNode) {
                if (node && lineOfPosition === sourceFile.getLineAndCharacterOfPosition(node.getStart(sourceFile)).line) {
                    return spanInNode(node);
                }
                return spanInNode(otherwiseOnNode);
            }
            function spanInNodeArray(nodeArray, node, match) {
                if (nodeArray) {
                    const index = nodeArray.indexOf(node);
                    if (index >= 0) {
                        let start = index;
                        let end = index + 1;
                        while (start > 0 && match(nodeArray[start - 1]))
                            start--;
                        while (end < nodeArray.length && match(nodeArray[end]))
                            end++;
                        return createTextSpanFromBounds(skipTrivia(sourceFile.text, nodeArray[start].pos), nodeArray[end - 1].end);
                    }
                }
                return textSpan(node);
            }
            function spanInPreviousNode(node) {
                return spanInNode(findPrecedingToken(node.pos, sourceFile));
            }
            function spanInNextNode(node) {
                return spanInNode(findNextToken(node, node.parent, sourceFile));
            }
            function spanInNode(node) {
                if (node) {
                    const { parent: parent2 } = node;
                    switch (node.kind) {
                        case 240 /* VariableStatement */:
                            return spanInVariableDeclaration(node.declarationList.declarations[0]);
                        case 257 /* VariableDeclaration */:
                        case 169 /* PropertyDeclaration */:
                        case 168 /* PropertySignature */:
                            return spanInVariableDeclaration(node);
                        case 166 /* Parameter */:
                            return spanInParameterDeclaration(node);
                        case 259 /* FunctionDeclaration */:
                        case 171 /* MethodDeclaration */:
                        case 170 /* MethodSignature */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                        case 173 /* Constructor */:
                        case 215 /* FunctionExpression */:
                        case 216 /* ArrowFunction */:
                            return spanInFunctionDeclaration(node);
                        case 238 /* Block */:
                            if (isFunctionBlock(node)) {
                                return spanInFunctionBlock(node);
                            }
                        case 265 /* ModuleBlock */:
                            return spanInBlock(node);
                        case 295 /* CatchClause */:
                            return spanInBlock(node.block);
                        case 241 /* ExpressionStatement */:
                            return textSpan(node.expression);
                        case 250 /* ReturnStatement */:
                            return textSpan(node.getChildAt(0), node.expression);
                        case 244 /* WhileStatement */:
                            return textSpanEndingAtNextToken(node, node.expression);
                        case 243 /* DoStatement */:
                            return spanInNode(node.statement);
                        case 256 /* DebuggerStatement */:
                            return textSpan(node.getChildAt(0));
                        case 242 /* IfStatement */:
                            return textSpanEndingAtNextToken(node, node.expression);
                        case 253 /* LabeledStatement */:
                            return spanInNode(node.statement);
                        case 249 /* BreakStatement */:
                        case 248 /* ContinueStatement */:
                            return textSpan(node.getChildAt(0), node.label);
                        case 245 /* ForStatement */:
                            return spanInForStatement(node);
                        case 246 /* ForInStatement */:
                            return textSpanEndingAtNextToken(node, node.expression);
                        case 247 /* ForOfStatement */:
                            return spanInInitializerOfForLike(node);
                        case 252 /* SwitchStatement */:
                            return textSpanEndingAtNextToken(node, node.expression);
                        case 292 /* CaseClause */:
                        case 293 /* DefaultClause */:
                            return spanInNode(node.statements[0]);
                        case 255 /* TryStatement */:
                            return spanInBlock(node.tryBlock);
                        case 254 /* ThrowStatement */:
                            return textSpan(node, node.expression);
                        case 274 /* ExportAssignment */:
                            return textSpan(node, node.expression);
                        case 268 /* ImportEqualsDeclaration */:
                            return textSpan(node, node.moduleReference);
                        case 269 /* ImportDeclaration */:
                            return textSpan(node, node.moduleSpecifier);
                        case 275 /* ExportDeclaration */:
                            return textSpan(node, node.moduleSpecifier);
                        case 264 /* ModuleDeclaration */:
                            if (getModuleInstanceState(node) !== 1 /* Instantiated */) {
                                return void 0;
                            }
                        case 260 /* ClassDeclaration */:
                        case 263 /* EnumDeclaration */:
                        case 302 /* EnumMember */:
                        case 205 /* BindingElement */:
                            return textSpan(node);
                        case 251 /* WithStatement */:
                            return spanInNode(node.statement);
                        case 167 /* Decorator */:
                            return spanInNodeArray(parent2.modifiers, node, isDecorator);
                        case 203 /* ObjectBindingPattern */:
                        case 204 /* ArrayBindingPattern */:
                            return spanInBindingPattern(node);
                        case 261 /* InterfaceDeclaration */:
                        case 262 /* TypeAliasDeclaration */:
                            return void 0;
                        case 26 /* SemicolonToken */:
                        case 1 /* EndOfFileToken */:
                            return spanInNodeIfStartsOnSameLine(findPrecedingToken(node.pos, sourceFile));
                        case 27 /* CommaToken */:
                            return spanInPreviousNode(node);
                        case 18 /* OpenBraceToken */:
                            return spanInOpenBraceToken(node);
                        case 19 /* CloseBraceToken */:
                            return spanInCloseBraceToken(node);
                        case 23 /* CloseBracketToken */:
                            return spanInCloseBracketToken(node);
                        case 20 /* OpenParenToken */:
                            return spanInOpenParenToken(node);
                        case 21 /* CloseParenToken */:
                            return spanInCloseParenToken(node);
                        case 58 /* ColonToken */:
                            return spanInColonToken(node);
                        case 31 /* GreaterThanToken */:
                        case 29 /* LessThanToken */:
                            return spanInGreaterThanOrLessThanToken(node);
                        case 115 /* WhileKeyword */:
                            return spanInWhileKeyword(node);
                        case 91 /* ElseKeyword */:
                        case 83 /* CatchKeyword */:
                        case 96 /* FinallyKeyword */:
                            return spanInNextNode(node);
                        case 162 /* OfKeyword */:
                            return spanInOfKeyword(node);
                        default:
                            if (isArrayLiteralOrObjectLiteralDestructuringPattern(node)) {
                                return spanInArrayLiteralOrObjectLiteralDestructuringPattern(node);
                            }
                            if ((node.kind === 79 /* Identifier */ || node.kind === 227 /* SpreadElement */ || node.kind === 299 /* PropertyAssignment */ || node.kind === 300 /* ShorthandPropertyAssignment */) && isArrayLiteralOrObjectLiteralDestructuringPattern(parent2)) {
                                return textSpan(node);
                            }
                            if (node.kind === 223 /* BinaryExpression */) {
                                const { left, operatorToken } = node;
                                if (isArrayLiteralOrObjectLiteralDestructuringPattern(left)) {
                                    return spanInArrayLiteralOrObjectLiteralDestructuringPattern(left);
                                }
                                if (operatorToken.kind === 63 /* EqualsToken */ && isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent)) {
                                    return textSpan(node);
                                }
                                if (operatorToken.kind === 27 /* CommaToken */) {
                                    return spanInNode(left);
                                }
                            }
                            if (isExpressionNode(node)) {
                                switch (parent2.kind) {
                                    case 243 /* DoStatement */:
                                        return spanInPreviousNode(node);
                                    case 167 /* Decorator */:
                                        return spanInNode(node.parent);
                                    case 245 /* ForStatement */:
                                    case 247 /* ForOfStatement */:
                                        return textSpan(node);
                                    case 223 /* BinaryExpression */:
                                        if (node.parent.operatorToken.kind === 27 /* CommaToken */) {
                                            return textSpan(node);
                                        }
                                        break;
                                    case 216 /* ArrowFunction */:
                                        if (node.parent.body === node) {
                                            return textSpan(node);
                                        }
                                        break;
                                }
                            }
                            switch (node.parent.kind) {
                                case 299 /* PropertyAssignment */:
                                    if (node.parent.name === node && !isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent.parent)) {
                                        return spanInNode(node.parent.initializer);
                                    }
                                    break;
                                case 213 /* TypeAssertionExpression */:
                                    if (node.parent.type === node) {
                                        return spanInNextNode(node.parent.type);
                                    }
                                    break;
                                case 257 /* VariableDeclaration */:
                                case 166 /* Parameter */: {
                                    const { initializer, type } = node.parent;
                                    if (initializer === node || type === node || isAssignmentOperator(node.kind)) {
                                        return spanInPreviousNode(node);
                                    }
                                    break;
                                }
                                case 223 /* BinaryExpression */: {
                                    const { left } = node.parent;
                                    if (isArrayLiteralOrObjectLiteralDestructuringPattern(left) && node !== left) {
                                        return spanInPreviousNode(node);
                                    }
                                    break;
                                }
                                default:
                                    if (isFunctionLike(node.parent) && node.parent.type === node) {
                                        return spanInPreviousNode(node);
                                    }
                            }
                            return spanInNode(node.parent);
                    }
                }
                function textSpanFromVariableDeclaration(variableDeclaration) {
                    if (isVariableDeclarationList(variableDeclaration.parent) && variableDeclaration.parent.declarations[0] === variableDeclaration) {
                        return textSpan(findPrecedingToken(variableDeclaration.pos, sourceFile, variableDeclaration.parent), variableDeclaration);
                    }
                    else {
                        return textSpan(variableDeclaration);
                    }
                }
                function spanInVariableDeclaration(variableDeclaration) {
                    if (variableDeclaration.parent.parent.kind === 246 /* ForInStatement */) {
                        return spanInNode(variableDeclaration.parent.parent);
                    }
                    const parent2 = variableDeclaration.parent;
                    if (isBindingPattern(variableDeclaration.name)) {
                        return spanInBindingPattern(variableDeclaration.name);
                    }
                    if (hasOnlyExpressionInitializer(variableDeclaration) && variableDeclaration.initializer || hasSyntacticModifier(variableDeclaration, 1 /* Export */) || parent2.parent.kind === 247 /* ForOfStatement */) {
                        return textSpanFromVariableDeclaration(variableDeclaration);
                    }
                    if (isVariableDeclarationList(variableDeclaration.parent) && variableDeclaration.parent.declarations[0] !== variableDeclaration) {
                        return spanInNode(findPrecedingToken(variableDeclaration.pos, sourceFile, variableDeclaration.parent));
                    }
                }
                function canHaveSpanInParameterDeclaration(parameter) {
                    return !!parameter.initializer || parameter.dotDotDotToken !== void 0 || hasSyntacticModifier(parameter, 4 /* Public */ | 8 /* Private */);
                }
                function spanInParameterDeclaration(parameter) {
                    if (isBindingPattern(parameter.name)) {
                        return spanInBindingPattern(parameter.name);
                    }
                    else if (canHaveSpanInParameterDeclaration(parameter)) {
                        return textSpan(parameter);
                    }
                    else {
                        const functionDeclaration = parameter.parent;
                        const indexOfParameter = functionDeclaration.parameters.indexOf(parameter);
                        Debug.assert(indexOfParameter !== -1);
                        if (indexOfParameter !== 0) {
                            return spanInParameterDeclaration(functionDeclaration.parameters[indexOfParameter - 1]);
                        }
                        else {
                            return spanInNode(functionDeclaration.body);
                        }
                    }
                }
                function canFunctionHaveSpanInWholeDeclaration(functionDeclaration) {
                    return hasSyntacticModifier(functionDeclaration, 1 /* Export */) || functionDeclaration.parent.kind === 260 /* ClassDeclaration */ && functionDeclaration.kind !== 173 /* Constructor */;
                }
                function spanInFunctionDeclaration(functionDeclaration) {
                    if (!functionDeclaration.body) {
                        return void 0;
                    }
                    if (canFunctionHaveSpanInWholeDeclaration(functionDeclaration)) {
                        return textSpan(functionDeclaration);
                    }
                    return spanInNode(functionDeclaration.body);
                }
                function spanInFunctionBlock(block) {
                    const nodeForSpanInBlock = block.statements.length ? block.statements[0] : block.getLastToken();
                    if (canFunctionHaveSpanInWholeDeclaration(block.parent)) {
                        return spanInNodeIfStartsOnSameLine(block.parent, nodeForSpanInBlock);
                    }
                    return spanInNode(nodeForSpanInBlock);
                }
                function spanInBlock(block) {
                    switch (block.parent.kind) {
                        case 264 /* ModuleDeclaration */:
                            if (getModuleInstanceState(block.parent) !== 1 /* Instantiated */) {
                                return void 0;
                            }
                        case 244 /* WhileStatement */:
                        case 242 /* IfStatement */:
                        case 246 /* ForInStatement */:
                            return spanInNodeIfStartsOnSameLine(block.parent, block.statements[0]);
                        case 245 /* ForStatement */:
                        case 247 /* ForOfStatement */:
                            return spanInNodeIfStartsOnSameLine(findPrecedingToken(block.pos, sourceFile, block.parent), block.statements[0]);
                    }
                    return spanInNode(block.statements[0]);
                }
                function spanInInitializerOfForLike(forLikeStatement) {
                    if (forLikeStatement.initializer.kind === 258 /* VariableDeclarationList */) {
                        const variableDeclarationList = forLikeStatement.initializer;
                        if (variableDeclarationList.declarations.length > 0) {
                            return spanInNode(variableDeclarationList.declarations[0]);
                        }
                    }
                    else {
                        return spanInNode(forLikeStatement.initializer);
                    }
                }
                function spanInForStatement(forStatement) {
                    if (forStatement.initializer) {
                        return spanInInitializerOfForLike(forStatement);
                    }
                    if (forStatement.condition) {
                        return textSpan(forStatement.condition);
                    }
                    if (forStatement.incrementor) {
                        return textSpan(forStatement.incrementor);
                    }
                }
                function spanInBindingPattern(bindingPattern) {
                    const firstBindingElement = forEach(bindingPattern.elements, (element) => element.kind !== 229 /* OmittedExpression */ ? element : void 0);
                    if (firstBindingElement) {
                        return spanInNode(firstBindingElement);
                    }
                    if (bindingPattern.parent.kind === 205 /* BindingElement */) {
                        return textSpan(bindingPattern.parent);
                    }
                    return textSpanFromVariableDeclaration(bindingPattern.parent);
                }
                function spanInArrayLiteralOrObjectLiteralDestructuringPattern(node2) {
                    Debug.assert(node2.kind !== 204 /* ArrayBindingPattern */ && node2.kind !== 203 /* ObjectBindingPattern */);
                    const elements = node2.kind === 206 /* ArrayLiteralExpression */ ? node2.elements : node2.properties;
                    const firstBindingElement = forEach(elements, (element) => element.kind !== 229 /* OmittedExpression */ ? element : void 0);
                    if (firstBindingElement) {
                        return spanInNode(firstBindingElement);
                    }
                    return textSpan(node2.parent.kind === 223 /* BinaryExpression */ ? node2.parent : node2);
                }
                function spanInOpenBraceToken(node2) {
                    switch (node2.parent.kind) {
                        case 263 /* EnumDeclaration */:
                            const enumDeclaration = node2.parent;
                            return spanInNodeIfStartsOnSameLine(findPrecedingToken(node2.pos, sourceFile, node2.parent), enumDeclaration.members.length ? enumDeclaration.members[0] : enumDeclaration.getLastToken(sourceFile));
                        case 260 /* ClassDeclaration */:
                            const classDeclaration = node2.parent;
                            return spanInNodeIfStartsOnSameLine(findPrecedingToken(node2.pos, sourceFile, node2.parent), classDeclaration.members.length ? classDeclaration.members[0] : classDeclaration.getLastToken(sourceFile));
                        case 266 /* CaseBlock */:
                            return spanInNodeIfStartsOnSameLine(node2.parent.parent, node2.parent.clauses[0]);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInCloseBraceToken(node2) {
                    switch (node2.parent.kind) {
                        case 265 /* ModuleBlock */:
                            if (getModuleInstanceState(node2.parent.parent) !== 1 /* Instantiated */) {
                                return void 0;
                            }
                        case 263 /* EnumDeclaration */:
                        case 260 /* ClassDeclaration */:
                            return textSpan(node2);
                        case 238 /* Block */:
                            if (isFunctionBlock(node2.parent)) {
                                return textSpan(node2);
                            }
                        case 295 /* CatchClause */:
                            return spanInNode(lastOrUndefined(node2.parent.statements));
                        case 266 /* CaseBlock */:
                            const caseBlock = node2.parent;
                            const lastClause = lastOrUndefined(caseBlock.clauses);
                            if (lastClause) {
                                return spanInNode(lastOrUndefined(lastClause.statements));
                            }
                            return void 0;
                        case 203 /* ObjectBindingPattern */:
                            const bindingPattern = node2.parent;
                            return spanInNode(lastOrUndefined(bindingPattern.elements) || bindingPattern);
                        default:
                            if (isArrayLiteralOrObjectLiteralDestructuringPattern(node2.parent)) {
                                const objectLiteral = node2.parent;
                                return textSpan(lastOrUndefined(objectLiteral.properties) || objectLiteral);
                            }
                            return spanInNode(node2.parent);
                    }
                }
                function spanInCloseBracketToken(node2) {
                    switch (node2.parent.kind) {
                        case 204 /* ArrayBindingPattern */:
                            const bindingPattern = node2.parent;
                            return textSpan(lastOrUndefined(bindingPattern.elements) || bindingPattern);
                        default:
                            if (isArrayLiteralOrObjectLiteralDestructuringPattern(node2.parent)) {
                                const arrayLiteral = node2.parent;
                                return textSpan(lastOrUndefined(arrayLiteral.elements) || arrayLiteral);
                            }
                            return spanInNode(node2.parent);
                    }
                }
                function spanInOpenParenToken(node2) {
                    if (node2.parent.kind === 243 /* DoStatement */ || // Go to while keyword and do action instead
                        node2.parent.kind === 210 /* CallExpression */ || node2.parent.kind === 211 /* NewExpression */) {
                        return spanInPreviousNode(node2);
                    }
                    if (node2.parent.kind === 214 /* ParenthesizedExpression */) {
                        return spanInNextNode(node2);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInCloseParenToken(node2) {
                    switch (node2.parent.kind) {
                        case 215 /* FunctionExpression */:
                        case 259 /* FunctionDeclaration */:
                        case 216 /* ArrowFunction */:
                        case 171 /* MethodDeclaration */:
                        case 170 /* MethodSignature */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                        case 173 /* Constructor */:
                        case 244 /* WhileStatement */:
                        case 243 /* DoStatement */:
                        case 245 /* ForStatement */:
                        case 247 /* ForOfStatement */:
                        case 210 /* CallExpression */:
                        case 211 /* NewExpression */:
                        case 214 /* ParenthesizedExpression */:
                            return spanInPreviousNode(node2);
                        default:
                            return spanInNode(node2.parent);
                    }
                }
                function spanInColonToken(node2) {
                    if (isFunctionLike(node2.parent) || node2.parent.kind === 299 /* PropertyAssignment */ || node2.parent.kind === 166 /* Parameter */) {
                        return spanInPreviousNode(node2);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInGreaterThanOrLessThanToken(node2) {
                    if (node2.parent.kind === 213 /* TypeAssertionExpression */) {
                        return spanInNextNode(node2);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInWhileKeyword(node2) {
                    if (node2.parent.kind === 243 /* DoStatement */) {
                        return textSpanEndingAtNextToken(node2, node2.parent.expression);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInOfKeyword(node2) {
                    if (node2.parent.kind === 247 /* ForOfStatement */) {
                        return spanInNextNode(node2);
                    }
                    return spanInNode(node2.parent);
                }
            }
        }
        var init_breakpoints = __esm({
            "src/services/breakpoints.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/_namespaces/ts.BreakpointResolver.ts
        var ts_BreakpointResolver_exports = {};
        __export(ts_BreakpointResolver_exports, {
            spanInSourceFileAtLocation: () => spanInSourceFileAtLocation
        });
        var init_ts_BreakpointResolver = __esm({
            "src/services/_namespaces/ts.BreakpointResolver.ts"() {
                "use strict";
                init_breakpoints();
            }
        });
        // src/services/callHierarchy.ts
        function isNamedExpression(node) {
            return (isFunctionExpression(node) || isClassExpression(node)) && isNamedDeclaration(node);
        }
        function isConstNamedExpression(node) {
            return (isFunctionExpression(node) || isArrowFunction(node) || isClassExpression(node)) && isVariableDeclaration(node.parent) && node === node.parent.initializer && isIdentifier(node.parent.name) && !!(getCombinedNodeFlags(node.parent) & 2 /* Const */);
        }
        function isPossibleCallHierarchyDeclaration(node) {
            return isSourceFile(node) || isModuleDeclaration(node) || isFunctionDeclaration(node) || isFunctionExpression(node) || isClassDeclaration(node) || isClassExpression(node) || isClassStaticBlockDeclaration(node) || isMethodDeclaration(node) || isMethodSignature(node) || isGetAccessorDeclaration(node) || isSetAccessorDeclaration(node);
        }
        function isValidCallHierarchyDeclaration(node) {
            return isSourceFile(node) || isModuleDeclaration(node) && isIdentifier(node.name) || isFunctionDeclaration(node) || isClassDeclaration(node) || isClassStaticBlockDeclaration(node) || isMethodDeclaration(node) || isMethodSignature(node) || isGetAccessorDeclaration(node) || isSetAccessorDeclaration(node) || isNamedExpression(node) || isConstNamedExpression(node);
        }
        function getCallHierarchyDeclarationReferenceNode(node) {
            if (isSourceFile(node))
                return node;
            if (isNamedDeclaration(node))
                return node.name;
            if (isConstNamedExpression(node))
                return node.parent.name;
            return Debug.checkDefined(node.modifiers && find(node.modifiers, isDefaultModifier3));
        }
        function isDefaultModifier3(node) {
            return node.kind === 88 /* DefaultKeyword */;
        }
        function getSymbolOfCallHierarchyDeclaration(typeChecker, node) {
            const location = getCallHierarchyDeclarationReferenceNode(node);
            return location && typeChecker.getSymbolAtLocation(location);
        }
        function getCallHierarchyItemName(program, node) {
            if (isSourceFile(node)) {
                return { text: node.fileName, pos: 0, end: 0 };
            }
            if ((isFunctionDeclaration(node) || isClassDeclaration(node)) && !isNamedDeclaration(node)) {
                const defaultModifier = node.modifiers && find(node.modifiers, isDefaultModifier3);
                if (defaultModifier) {
                    return { text: "default", pos: defaultModifier.getStart(), end: defaultModifier.getEnd() };
                }
            }
            if (isClassStaticBlockDeclaration(node)) {
                const sourceFile = node.getSourceFile();
                const pos = skipTrivia(sourceFile.text, moveRangePastModifiers(node).pos);
                const end = pos + 6;
                const typeChecker = program.getTypeChecker();
                const symbol = typeChecker.getSymbolAtLocation(node.parent);
                const prefix = symbol ? `${typeChecker.symbolToString(symbol, node.parent)} ` : "";
                return { text: `${prefix}static {}`, pos, end };
            }
            const declName = isConstNamedExpression(node) ? node.parent.name : Debug.checkDefined(getNameOfDeclaration(node), "Expected call hierarchy item to have a name");
            let text = isIdentifier(declName) ? idText(declName) : isStringOrNumericLiteralLike(declName) ? declName.text : isComputedPropertyName(declName) ? isStringOrNumericLiteralLike(declName.expression) ? declName.expression.text : void 0 : void 0;
            if (text === void 0) {
                const typeChecker = program.getTypeChecker();
                const symbol = typeChecker.getSymbolAtLocation(declName);
                if (symbol) {
                    text = typeChecker.symbolToString(symbol, node);
                }
            }
            if (text === void 0) {
                const printer = createPrinterWithRemoveCommentsOmitTrailingSemicolon();
                text = usingSingleLineStringWriter((writer) => printer.writeNode(4 /* Unspecified */, node, node.getSourceFile(), writer));
            }
            return { text, pos: declName.getStart(), end: declName.getEnd() };
        }
        function getCallHierarchItemContainerName(node) {
            var _a2, _b;
            if (isConstNamedExpression(node)) {
                if (isModuleBlock(node.parent.parent.parent.parent) && isIdentifier(node.parent.parent.parent.parent.parent.name)) {
                    return node.parent.parent.parent.parent.parent.name.getText();
                }
                return;
            }
            switch (node.kind) {
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 171 /* MethodDeclaration */:
                    if (node.parent.kind === 207 /* ObjectLiteralExpression */) {
                        return (_a2 = getAssignedName(node.parent)) == null ? void 0 : _a2.getText();
                    }
                    return (_b = getNameOfDeclaration(node.parent)) == null ? void 0 : _b.getText();
                case 259 /* FunctionDeclaration */:
                case 260 /* ClassDeclaration */:
                case 264 /* ModuleDeclaration */:
                    if (isModuleBlock(node.parent) && isIdentifier(node.parent.parent.name)) {
                        return node.parent.parent.name.getText();
                    }
            }
        }
        function findImplementation(typeChecker, node) {
            if (node.body) {
                return node;
            }
            if (isConstructorDeclaration(node)) {
                return getFirstConstructorWithBody(node.parent);
            }
            if (isFunctionDeclaration(node) || isMethodDeclaration(node)) {
                const symbol = getSymbolOfCallHierarchyDeclaration(typeChecker, node);
                if (symbol && symbol.valueDeclaration && isFunctionLikeDeclaration(symbol.valueDeclaration) && symbol.valueDeclaration.body) {
                    return symbol.valueDeclaration;
                }
                return void 0;
            }
            return node;
        }
        function findAllInitialDeclarations(typeChecker, node) {
            const symbol = getSymbolOfCallHierarchyDeclaration(typeChecker, node);
            let declarations;
            if (symbol && symbol.declarations) {
                const indices = indicesOf(symbol.declarations);
                const keys = map(symbol.declarations, (decl) => ({ file: decl.getSourceFile().fileName, pos: decl.pos }));
                indices.sort((a, b) => compareStringsCaseSensitive(keys[a].file, keys[b].file) || keys[a].pos - keys[b].pos);
                const sortedDeclarations = map(indices, (i) => symbol.declarations[i]);
                let lastDecl;
                for (const decl of sortedDeclarations) {
                    if (isValidCallHierarchyDeclaration(decl)) {
                        if (!lastDecl || lastDecl.parent !== decl.parent || lastDecl.end !== decl.pos) {
                            declarations = append(declarations, decl);
                        }
                        lastDecl = decl;
                    }
                }
            }
            return declarations;
        }
        function findImplementationOrAllInitialDeclarations(typeChecker, node) {
            var _a2, _b, _c;
            if (isClassStaticBlockDeclaration(node)) {
                return node;
            }
            if (isFunctionLikeDeclaration(node)) {
                return (_b = (_a2 = findImplementation(typeChecker, node)) != null ? _a2 : findAllInitialDeclarations(typeChecker, node)) != null ? _b : node;
            }
            return (_c = findAllInitialDeclarations(typeChecker, node)) != null ? _c : node;
        }
        function resolveCallHierarchyDeclaration(program, location) {
            const typeChecker = program.getTypeChecker();
            let followingSymbol = false;
            while (true) {
                if (isValidCallHierarchyDeclaration(location)) {
                    return findImplementationOrAllInitialDeclarations(typeChecker, location);
                }
                if (isPossibleCallHierarchyDeclaration(location)) {
                    const ancestor = findAncestor(location, isValidCallHierarchyDeclaration);
                    return ancestor && findImplementationOrAllInitialDeclarations(typeChecker, ancestor);
                }
                if (isDeclarationName(location)) {
                    if (isValidCallHierarchyDeclaration(location.parent)) {
                        return findImplementationOrAllInitialDeclarations(typeChecker, location.parent);
                    }
                    if (isPossibleCallHierarchyDeclaration(location.parent)) {
                        const ancestor = findAncestor(location.parent, isValidCallHierarchyDeclaration);
                        return ancestor && findImplementationOrAllInitialDeclarations(typeChecker, ancestor);
                    }
                    if (isVariableDeclaration(location.parent) && location.parent.initializer && isConstNamedExpression(location.parent.initializer)) {
                        return location.parent.initializer;
                    }
                    return void 0;
                }
                if (isConstructorDeclaration(location)) {
                    if (isValidCallHierarchyDeclaration(location.parent)) {
                        return location.parent;
                    }
                    return void 0;
                }
                if (location.kind === 124 /* StaticKeyword */ && isClassStaticBlockDeclaration(location.parent)) {
                    location = location.parent;
                    continue;
                }
                if (isVariableDeclaration(location) && location.initializer && isConstNamedExpression(location.initializer)) {
                    return location.initializer;
                }
                if (!followingSymbol) {
                    let symbol = typeChecker.getSymbolAtLocation(location);
                    if (symbol) {
                        if (symbol.flags & 2097152 /* Alias */) {
                            symbol = typeChecker.getAliasedSymbol(symbol);
                        }
                        if (symbol.valueDeclaration) {
                            followingSymbol = true;
                            location = symbol.valueDeclaration;
                            continue;
                        }
                    }
                }
                return void 0;
            }
        }
        function createCallHierarchyItem(program, node) {
            const sourceFile = node.getSourceFile();
            const name = getCallHierarchyItemName(program, node);
            const containerName = getCallHierarchItemContainerName(node);
            const kind = getNodeKind(node);
            const kindModifiers = getNodeModifiers(node);
            const span = createTextSpanFromBounds(skipTrivia(sourceFile.text, node.getFullStart(), 
            /*stopAfterLineBreak*/
            false, 
            /*stopAtComments*/
            true), node.getEnd());
            const selectionSpan = createTextSpanFromBounds(name.pos, name.end);
            return { file: sourceFile.fileName, kind, kindModifiers, name: name.text, containerName, span, selectionSpan };
        }
        function isDefined(x) {
            return x !== void 0;
        }
        function convertEntryToCallSite(entry) {
            if (entry.kind === ts_FindAllReferences_exports.EntryKind.Node) {
                const { node } = entry;
                if (isCallOrNewExpressionTarget(node, 
                /*includeElementAccess*/
                true, 
                /*skipPastOuterExpressions*/
                true) || isTaggedTemplateTag(node, 
                /*includeElementAccess*/
                true, 
                /*skipPastOuterExpressions*/
                true) || isDecoratorTarget(node, 
                /*includeElementAccess*/
                true, 
                /*skipPastOuterExpressions*/
                true) || isJsxOpeningLikeElementTagName(node, 
                /*includeElementAccess*/
                true, 
                /*skipPastOuterExpressions*/
                true) || isRightSideOfPropertyAccess(node) || isArgumentExpressionOfElementAccess(node)) {
                    const sourceFile = node.getSourceFile();
                    const ancestor = findAncestor(node, isValidCallHierarchyDeclaration) || sourceFile;
                    return { declaration: ancestor, range: createTextRangeFromNode(node, sourceFile) };
                }
            }
        }
        function getCallSiteGroupKey(entry) {
            return getNodeId(entry.declaration);
        }
        function createCallHierarchyIncomingCall(from, fromSpans) {
            return { from, fromSpans };
        }
        function convertCallSiteGroupToIncomingCall(program, entries) {
            return createCallHierarchyIncomingCall(createCallHierarchyItem(program, entries[0].declaration), map(entries, (entry) => createTextSpanFromRange(entry.range)));
        }
        function getIncomingCalls(program, declaration, cancellationToken) {
            if (isSourceFile(declaration) || isModuleDeclaration(declaration) || isClassStaticBlockDeclaration(declaration)) {
                return [];
            }
            const location = getCallHierarchyDeclarationReferenceNode(declaration);
            const calls = filter(ts_FindAllReferences_exports.findReferenceOrRenameEntries(program, cancellationToken, program.getSourceFiles(), location, 
            /*position*/
            0, { use: ts_FindAllReferences_exports.FindReferencesUse.References }, convertEntryToCallSite), isDefined);
            return calls ? group(calls, getCallSiteGroupKey, (entries) => convertCallSiteGroupToIncomingCall(program, entries)) : [];
        }
        function createCallSiteCollector(program, callSites) {
            function recordCallSite(node) {
                const target = isTaggedTemplateExpression(node) ? node.tag : isJsxOpeningLikeElement(node) ? node.tagName : isAccessExpression(node) ? node : isClassStaticBlockDeclaration(node) ? node : node.expression;
                const declaration = resolveCallHierarchyDeclaration(program, target);
                if (declaration) {
                    const range = createTextRangeFromNode(target, node.getSourceFile());
                    if (isArray(declaration)) {
                        for (const decl of declaration) {
                            callSites.push({ declaration: decl, range });
                        }
                    }
                    else {
                        callSites.push({ declaration, range });
                    }
                }
            }
            function collect(node) {
                if (!node)
                    return;
                if (node.flags & 16777216 /* Ambient */) {
                    return;
                }
                if (isValidCallHierarchyDeclaration(node)) {
                    if (isClassLike(node)) {
                        for (const member of node.members) {
                            if (member.name && isComputedPropertyName(member.name)) {
                                collect(member.name.expression);
                            }
                        }
                    }
                    return;
                }
                switch (node.kind) {
                    case 79 /* Identifier */:
                    case 268 /* ImportEqualsDeclaration */:
                    case 269 /* ImportDeclaration */:
                    case 275 /* ExportDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                    case 262 /* TypeAliasDeclaration */:
                        return;
                    case 172 /* ClassStaticBlockDeclaration */:
                        recordCallSite(node);
                        return;
                    case 213 /* TypeAssertionExpression */:
                    case 231 /* AsExpression */:
                        collect(node.expression);
                        return;
                    case 257 /* VariableDeclaration */:
                    case 166 /* Parameter */:
                        collect(node.name);
                        collect(node.initializer);
                        return;
                    case 210 /* CallExpression */:
                        recordCallSite(node);
                        collect(node.expression);
                        forEach(node.arguments, collect);
                        return;
                    case 211 /* NewExpression */:
                        recordCallSite(node);
                        collect(node.expression);
                        forEach(node.arguments, collect);
                        return;
                    case 212 /* TaggedTemplateExpression */:
                        recordCallSite(node);
                        collect(node.tag);
                        collect(node.template);
                        return;
                    case 283 /* JsxOpeningElement */:
                    case 282 /* JsxSelfClosingElement */:
                        recordCallSite(node);
                        collect(node.tagName);
                        collect(node.attributes);
                        return;
                    case 167 /* Decorator */:
                        recordCallSite(node);
                        collect(node.expression);
                        return;
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        recordCallSite(node);
                        forEachChild(node, collect);
                        break;
                    case 235 /* SatisfiesExpression */:
                        collect(node.expression);
                        return;
                }
                if (isPartOfTypeNode(node)) {
                    return;
                }
                forEachChild(node, collect);
            }
            return collect;
        }
        function collectCallSitesOfSourceFile(node, collect) {
            forEach(node.statements, collect);
        }
        function collectCallSitesOfModuleDeclaration(node, collect) {
            if (!hasSyntacticModifier(node, 2 /* Ambient */) && node.body && isModuleBlock(node.body)) {
                forEach(node.body.statements, collect);
            }
        }
        function collectCallSitesOfFunctionLikeDeclaration(typeChecker, node, collect) {
            const implementation = findImplementation(typeChecker, node);
            if (implementation) {
                forEach(implementation.parameters, collect);
                collect(implementation.body);
            }
        }
        function collectCallSitesOfClassStaticBlockDeclaration(node, collect) {
            collect(node.body);
        }
        function collectCallSitesOfClassLikeDeclaration(node, collect) {
            forEach(node.modifiers, collect);
            const heritage = getClassExtendsHeritageElement(node);
            if (heritage) {
                collect(heritage.expression);
            }
            for (const member of node.members) {
                if (canHaveModifiers(member)) {
                    forEach(member.modifiers, collect);
                }
                if (isPropertyDeclaration(member)) {
                    collect(member.initializer);
                }
                else if (isConstructorDeclaration(member) && member.body) {
                    forEach(member.parameters, collect);
                    collect(member.body);
                }
                else if (isClassStaticBlockDeclaration(member)) {
                    collect(member);
                }
            }
        }
        function collectCallSites(program, node) {
            const callSites = [];
            const collect = createCallSiteCollector(program, callSites);
            switch (node.kind) {
                case 308 /* SourceFile */:
                    collectCallSitesOfSourceFile(node, collect);
                    break;
                case 264 /* ModuleDeclaration */:
                    collectCallSitesOfModuleDeclaration(node, collect);
                    break;
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    collectCallSitesOfFunctionLikeDeclaration(program.getTypeChecker(), node, collect);
                    break;
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                    collectCallSitesOfClassLikeDeclaration(node, collect);
                    break;
                case 172 /* ClassStaticBlockDeclaration */:
                    collectCallSitesOfClassStaticBlockDeclaration(node, collect);
                    break;
                default:
                    Debug.assertNever(node);
            }
            return callSites;
        }
        function createCallHierarchyOutgoingCall(to, fromSpans) {
            return { to, fromSpans };
        }
        function convertCallSiteGroupToOutgoingCall(program, entries) {
            return createCallHierarchyOutgoingCall(createCallHierarchyItem(program, entries[0].declaration), map(entries, (entry) => createTextSpanFromRange(entry.range)));
        }
        function getOutgoingCalls(program, declaration) {
            if (declaration.flags & 16777216 /* Ambient */ || isMethodSignature(declaration)) {
                return [];
            }
            return group(collectCallSites(program, declaration), getCallSiteGroupKey, (entries) => convertCallSiteGroupToOutgoingCall(program, entries));
        }
        var init_callHierarchy = __esm({
            "src/services/callHierarchy.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/_namespaces/ts.CallHierarchy.ts
        var ts_CallHierarchy_exports = {};
        __export(ts_CallHierarchy_exports, {
            createCallHierarchyItem: () => createCallHierarchyItem,
            getIncomingCalls: () => getIncomingCalls,
            getOutgoingCalls: () => getOutgoingCalls,
            resolveCallHierarchyDeclaration: () => resolveCallHierarchyDeclaration
        });
        var init_ts_CallHierarchy = __esm({
            "src/services/_namespaces/ts.CallHierarchy.ts"() {
                "use strict";
                init_callHierarchy();
            }
        });
        // src/services/classifier2020.ts
        function getSemanticClassifications2(program, cancellationToken, sourceFile, span) {
            const classifications = getEncodedSemanticClassifications2(program, cancellationToken, sourceFile, span);
            Debug.assert(classifications.spans.length % 3 === 0);
            const dense = classifications.spans;
            const result = [];
            for (let i = 0; i < dense.length; i += 3) {
                result.push({
                    textSpan: createTextSpan(dense[i], dense[i + 1]),
                    classificationType: dense[i + 2]
                });
            }
            return result;
        }
        function getEncodedSemanticClassifications2(program, cancellationToken, sourceFile, span) {
            return {
                spans: getSemanticTokens(program, sourceFile, span, cancellationToken),
                endOfLineState: 0 /* None */
            };
        }
        function getSemanticTokens(program, sourceFile, span, cancellationToken) {
            const resultTokens = [];
            const collector = (node, typeIdx, modifierSet) => {
                resultTokens.push(node.getStart(sourceFile), node.getWidth(sourceFile), (typeIdx + 1 << 8 /* typeOffset */) + modifierSet);
            };
            if (program && sourceFile) {
                collectTokens(program, sourceFile, span, collector, cancellationToken);
            }
            return resultTokens;
        }
        function collectTokens(program, sourceFile, span, collector, cancellationToken) {
            const typeChecker = program.getTypeChecker();
            let inJSXElement = false;
            function visit(node) {
                switch (node.kind) {
                    case 264 /* ModuleDeclaration */:
                    case 260 /* ClassDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                    case 259 /* FunctionDeclaration */:
                    case 228 /* ClassExpression */:
                    case 215 /* FunctionExpression */:
                    case 216 /* ArrowFunction */:
                        cancellationToken.throwIfCancellationRequested();
                }
                if (!node || !textSpanIntersectsWith(span, node.pos, node.getFullWidth()) || node.getFullWidth() === 0) {
                    return;
                }
                const prevInJSXElement = inJSXElement;
                if (isJsxElement(node) || isJsxSelfClosingElement(node)) {
                    inJSXElement = true;
                }
                if (isJsxExpression(node)) {
                    inJSXElement = false;
                }
                if (isIdentifier(node) && !inJSXElement && !inImportClause(node) && !isInfinityOrNaNString(node.escapedText)) {
                    let symbol = typeChecker.getSymbolAtLocation(node);
                    if (symbol) {
                        if (symbol.flags & 2097152 /* Alias */) {
                            symbol = typeChecker.getAliasedSymbol(symbol);
                        }
                        let typeIdx = classifySymbol2(symbol, getMeaningFromLocation(node));
                        if (typeIdx !== void 0) {
                            let modifierSet = 0;
                            if (node.parent) {
                                const parentIsDeclaration = isBindingElement(node.parent) || tokenFromDeclarationMapping.get(node.parent.kind) === typeIdx;
                                if (parentIsDeclaration && node.parent.name === node) {
                                    modifierSet = 1 << 0 /* declaration */;
                                }
                            }
                            if (typeIdx === 6 /* parameter */ && isRightSideOfQualifiedNameOrPropertyAccess2(node)) {
                                typeIdx = 9 /* property */;
                            }
                            typeIdx = reclassifyByType(typeChecker, node, typeIdx);
                            const decl = symbol.valueDeclaration;
                            if (decl) {
                                const modifiers = getCombinedModifierFlags(decl);
                                const nodeFlags = getCombinedNodeFlags(decl);
                                if (modifiers & 32 /* Static */) {
                                    modifierSet |= 1 << 1 /* static */;
                                }
                                if (modifiers & 512 /* Async */) {
                                    modifierSet |= 1 << 2 /* async */;
                                }
                                if (typeIdx !== 0 /* class */ && typeIdx !== 2 /* interface */) {
                                    if (modifiers & 64 /* Readonly */ || nodeFlags & 2 /* Const */ || symbol.getFlags() & 8 /* EnumMember */) {
                                        modifierSet |= 1 << 3 /* readonly */;
                                    }
                                }
                                if ((typeIdx === 7 /* variable */ || typeIdx === 10 /* function */) && isLocalDeclaration(decl, sourceFile)) {
                                    modifierSet |= 1 << 5 /* local */;
                                }
                                if (program.isSourceFileDefaultLibrary(decl.getSourceFile())) {
                                    modifierSet |= 1 << 4 /* defaultLibrary */;
                                }
                            }
                            else if (symbol.declarations && symbol.declarations.some((d) => program.isSourceFileDefaultLibrary(d.getSourceFile()))) {
                                modifierSet |= 1 << 4 /* defaultLibrary */;
                            }
                            collector(node, typeIdx, modifierSet);
                        }
                    }
                }
                forEachChild(node, visit);
                inJSXElement = prevInJSXElement;
            }
            visit(sourceFile);
        }
        function classifySymbol2(symbol, meaning) {
            const flags = symbol.getFlags();
            if (flags & 32 /* Class */) {
                return 0 /* class */;
            }
            else if (flags & 384 /* Enum */) {
                return 1 /* enum */;
            }
            else if (flags & 524288 /* TypeAlias */) {
                return 5 /* type */;
            }
            else if (flags & 64 /* Interface */) {
                if (meaning & 2 /* Type */) {
                    return 2 /* interface */;
                }
            }
            else if (flags & 262144 /* TypeParameter */) {
                return 4 /* typeParameter */;
            }
            let decl = symbol.valueDeclaration || symbol.declarations && symbol.declarations[0];
            if (decl && isBindingElement(decl)) {
                decl = getDeclarationForBindingElement(decl);
            }
            return decl && tokenFromDeclarationMapping.get(decl.kind);
        }
        function reclassifyByType(typeChecker, node, typeIdx) {
            if (typeIdx === 7 /* variable */ || typeIdx === 9 /* property */ || typeIdx === 6 /* parameter */) {
                const type = typeChecker.getTypeAtLocation(node);
                if (type) {
                    const test = (condition) => {
                        return condition(type) || type.isUnion() && type.types.some(condition);
                    };
                    if (typeIdx !== 6 /* parameter */ && test((t) => t.getConstructSignatures().length > 0)) {
                        return 0 /* class */;
                    }
                    if (test((t) => t.getCallSignatures().length > 0) && !test((t) => t.getProperties().length > 0) || isExpressionInCallExpression(node)) {
                        return typeIdx === 9 /* property */ ? 11 /* member */ : 10 /* function */;
                    }
                }
            }
            return typeIdx;
        }
        function isLocalDeclaration(decl, sourceFile) {
            if (isBindingElement(decl)) {
                decl = getDeclarationForBindingElement(decl);
            }
            if (isVariableDeclaration(decl)) {
                return (!isSourceFile(decl.parent.parent.parent) || isCatchClause(decl.parent)) && decl.getSourceFile() === sourceFile;
            }
            else if (isFunctionDeclaration(decl)) {
                return !isSourceFile(decl.parent) && decl.getSourceFile() === sourceFile;
            }
            return false;
        }
        function getDeclarationForBindingElement(element) {
            while (true) {
                if (isBindingElement(element.parent.parent)) {
                    element = element.parent.parent;
                }
                else {
                    return element.parent.parent;
                }
            }
        }
        function inImportClause(node) {
            const parent2 = node.parent;
            return parent2 && (isImportClause(parent2) || isImportSpecifier(parent2) || isNamespaceImport(parent2));
        }
        function isExpressionInCallExpression(node) {
            while (isRightSideOfQualifiedNameOrPropertyAccess2(node)) {
                node = node.parent;
            }
            return isCallExpression(node.parent) && node.parent.expression === node;
        }
        function isRightSideOfQualifiedNameOrPropertyAccess2(node) {
            return isQualifiedName(node.parent) && node.parent.right === node || isPropertyAccessExpression(node.parent) && node.parent.name === node;
        }
        var TokenEncodingConsts, TokenType, TokenModifier, tokenFromDeclarationMapping;
        var init_classifier2020 = __esm({
            "src/services/classifier2020.ts"() {
                "use strict";
                init_ts4();
                TokenEncodingConsts = /* @__PURE__ */ ((TokenEncodingConsts2) => {
                    TokenEncodingConsts2[TokenEncodingConsts2["typeOffset"] = 8] = "typeOffset";
                    TokenEncodingConsts2[TokenEncodingConsts2["modifierMask"] = 255] = "modifierMask";
                    return TokenEncodingConsts2;
                })(TokenEncodingConsts || {});
                TokenType = /* @__PURE__ */ ((TokenType2) => {
                    TokenType2[TokenType2["class"] = 0] = "class";
                    TokenType2[TokenType2["enum"] = 1] = "enum";
                    TokenType2[TokenType2["interface"] = 2] = "interface";
                    TokenType2[TokenType2["namespace"] = 3] = "namespace";
                    TokenType2[TokenType2["typeParameter"] = 4] = "typeParameter";
                    TokenType2[TokenType2["type"] = 5] = "type";
                    TokenType2[TokenType2["parameter"] = 6] = "parameter";
                    TokenType2[TokenType2["variable"] = 7] = "variable";
                    TokenType2[TokenType2["enumMember"] = 8] = "enumMember";
                    TokenType2[TokenType2["property"] = 9] = "property";
                    TokenType2[TokenType2["function"] = 10] = "function";
                    TokenType2[TokenType2["member"] = 11] = "member";
                    return TokenType2;
                })(TokenType || {});
                TokenModifier = /* @__PURE__ */ ((TokenModifier2) => {
                    TokenModifier2[TokenModifier2["declaration"] = 0] = "declaration";
                    TokenModifier2[TokenModifier2["static"] = 1] = "static";
                    TokenModifier2[TokenModifier2["async"] = 2] = "async";
                    TokenModifier2[TokenModifier2["readonly"] = 3] = "readonly";
                    TokenModifier2[TokenModifier2["defaultLibrary"] = 4] = "defaultLibrary";
                    TokenModifier2[TokenModifier2["local"] = 5] = "local";
                    return TokenModifier2;
                })(TokenModifier || {});
                tokenFromDeclarationMapping = /* @__PURE__ */ new Map([
                    [257 /* VariableDeclaration */, 7 /* variable */],
                    [166 /* Parameter */, 6 /* parameter */],
                    [169 /* PropertyDeclaration */, 9 /* property */],
                    [264 /* ModuleDeclaration */, 3 /* namespace */],
                    [263 /* EnumDeclaration */, 1 /* enum */],
                    [302 /* EnumMember */, 8 /* enumMember */],
                    [260 /* ClassDeclaration */, 0 /* class */],
                    [171 /* MethodDeclaration */, 11 /* member */],
                    [259 /* FunctionDeclaration */, 10 /* function */],
                    [215 /* FunctionExpression */, 10 /* function */],
                    [170 /* MethodSignature */, 11 /* member */],
                    [174 /* GetAccessor */, 9 /* property */],
                    [175 /* SetAccessor */, 9 /* property */],
                    [168 /* PropertySignature */, 9 /* property */],
                    [261 /* InterfaceDeclaration */, 2 /* interface */],
                    [262 /* TypeAliasDeclaration */, 5 /* type */],
                    [165 /* TypeParameter */, 4 /* typeParameter */],
                    [299 /* PropertyAssignment */, 9 /* property */],
                    [300 /* ShorthandPropertyAssignment */, 9 /* property */]
                ]);
            }
        });
        // src/services/_namespaces/ts.classifier.v2020.ts
        var ts_classifier_v2020_exports = {};
        __export(ts_classifier_v2020_exports, {
            TokenEncodingConsts: () => TokenEncodingConsts,
            TokenModifier: () => TokenModifier,
            TokenType: () => TokenType,
            getEncodedSemanticClassifications: () => getEncodedSemanticClassifications2,
            getSemanticClassifications: () => getSemanticClassifications2
        });
        var init_ts_classifier_v2020 = __esm({
            "src/services/_namespaces/ts.classifier.v2020.ts"() {
                "use strict";
                init_classifier2020();
            }
        });
        // src/services/_namespaces/ts.classifier.ts
        var ts_classifier_exports = {};
        __export(ts_classifier_exports, {
            v2020: () => ts_classifier_v2020_exports
        });
        var init_ts_classifier = __esm({
            "src/services/_namespaces/ts.classifier.ts"() {
                "use strict";
                init_ts_classifier_v2020();
            }
        });
        // src/services/codeFixProvider.ts
        function createCodeFixActionWithoutFixAll(fixName8, changes, description2) {
            return createCodeFixActionWorker(fixName8, diagnosticToString(description2), changes, 
            /*fixId*/
            void 0, 
            /*fixAllDescription*/
            void 0);
        }
        function createCodeFixAction(fixName8, changes, description2, fixId51, fixAllDescription, command) {
            return createCodeFixActionWorker(fixName8, diagnosticToString(description2), changes, fixId51, diagnosticToString(fixAllDescription), command);
        }
        function createCodeFixActionMaybeFixAll(fixName8, changes, description2, fixId51, fixAllDescription, command) {
            return createCodeFixActionWorker(fixName8, diagnosticToString(description2), changes, fixId51, fixAllDescription && diagnosticToString(fixAllDescription), command);
        }
        function createCodeFixActionWorker(fixName8, description2, changes, fixId51, fixAllDescription, command) {
            return { fixName: fixName8, description: description2, changes, fixId: fixId51, fixAllDescription, commands: command ? [command] : void 0 };
        }
        function registerCodeFix(reg) {
            for (const error of reg.errorCodes) {
                errorCodeToFixes.add(String(error), reg);
            }
            if (reg.fixIds) {
                for (const fixId51 of reg.fixIds) {
                    Debug.assert(!fixIdToRegistration.has(fixId51));
                    fixIdToRegistration.set(fixId51, reg);
                }
            }
        }
        function getSupportedErrorCodes() {
            return arrayFrom(errorCodeToFixes.keys());
        }
        function removeFixIdIfFixAllUnavailable(registration, diagnostics) {
            const { errorCodes: errorCodes63 } = registration;
            let maybeFixableDiagnostics = 0;
            for (const diag2 of diagnostics) {
                if (contains(errorCodes63, diag2.code))
                    maybeFixableDiagnostics++;
                if (maybeFixableDiagnostics > 1)
                    break;
            }
            const fixAllUnavailable = maybeFixableDiagnostics < 2;
            return ({ fixId: fixId51, fixAllDescription, ...action }) => {
                return fixAllUnavailable ? action : { ...action, fixId: fixId51, fixAllDescription };
            };
        }
        function getFixes(context) {
            const diagnostics = getDiagnostics(context);
            const registrations = errorCodeToFixes.get(String(context.errorCode));
            return flatMap(registrations, (f) => map(f.getCodeActions(context), removeFixIdIfFixAllUnavailable(f, diagnostics)));
        }
        function getAllFixes(context) {
            return fixIdToRegistration.get(cast(context.fixId, isString)).getAllCodeActions(context);
        }
        function createCombinedCodeActions(changes, commands) {
            return { changes, commands };
        }
        function createFileTextChanges(fileName, textChanges2) {
            return { fileName, textChanges: textChanges2 };
        }
        function codeFixAll(context, errorCodes63, use) {
            const commands = [];
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => eachDiagnostic(context, errorCodes63, (diag2) => use(t, diag2, commands)));
            return createCombinedCodeActions(changes, commands.length === 0 ? void 0 : commands);
        }
        function eachDiagnostic(context, errorCodes63, cb) {
            for (const diag2 of getDiagnostics(context)) {
                if (contains(errorCodes63, diag2.code)) {
                    cb(diag2);
                }
            }
        }
        function getDiagnostics({ program, sourceFile, cancellationToken }) {
            return [
                ...program.getSemanticDiagnostics(sourceFile, cancellationToken),
                ...program.getSyntacticDiagnostics(sourceFile, cancellationToken),
                ...computeSuggestionDiagnostics(sourceFile, program, cancellationToken)
            ];
        }
        var errorCodeToFixes, fixIdToRegistration;
        var init_codeFixProvider = __esm({
            "src/services/codeFixProvider.ts"() {
                "use strict";
                init_ts4();
                errorCodeToFixes = createMultiMap();
                fixIdToRegistration = /* @__PURE__ */ new Map();
            }
        });
        // src/services/codefixes/addConvertToUnknownForNonOverlappingTypes.ts
        function makeChange(changeTracker, sourceFile, assertion) {
            const replacement = isAsExpression(assertion) ? factory.createAsExpression(assertion.expression, factory.createKeywordTypeNode(157 /* UnknownKeyword */)) : factory.createTypeAssertion(factory.createKeywordTypeNode(157 /* UnknownKeyword */), assertion.expression);
            changeTracker.replaceNode(sourceFile, assertion.expression, replacement);
        }
        function getAssertion(sourceFile, pos) {
            if (isInJSFile(sourceFile))
                return void 0;
            return findAncestor(getTokenAtPosition(sourceFile, pos), (n) => isAsExpression(n) || isTypeAssertionExpression(n));
        }
        var fixId, errorCodes;
        var init_addConvertToUnknownForNonOverlappingTypes = __esm({
            "src/services/codefixes/addConvertToUnknownForNonOverlappingTypes.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId = "addConvertToUnknownForNonOverlappingTypes";
                errorCodes = [Diagnostics.Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first.code];
                registerCodeFix({
                    errorCodes,
                    getCodeActions: function getCodeActionsToAddConvertToUnknownForNonOverlappingTypes(context) {
                        const assertion = getAssertion(context.sourceFile, context.span.start);
                        if (assertion === void 0)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange(t, context.sourceFile, assertion));
                        return [createCodeFixAction(fixId, changes, Diagnostics.Add_unknown_conversion_for_non_overlapping_types, fixId, Diagnostics.Add_unknown_to_all_conversions_of_non_overlapping_types)];
                    },
                    fixIds: [fixId],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes, (changes, diag2) => {
                        const assertion = getAssertion(diag2.file, diag2.start);
                        if (assertion) {
                            makeChange(changes, diag2.file, assertion);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/addEmptyExportDeclaration.ts
        var init_addEmptyExportDeclaration = __esm({
            "src/services/codefixes/addEmptyExportDeclaration.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                registerCodeFix({
                    errorCodes: [
                        Diagnostics.await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module.code,
                        Diagnostics.for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module.code
                    ],
                    getCodeActions: function getCodeActionsToAddEmptyExportDeclaration(context) {
                        const { sourceFile } = context;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => {
                            const exportDeclaration = factory.createExportDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*isTypeOnly*/
                            false, factory.createNamedExports([]), 
                            /*moduleSpecifier*/
                            void 0);
                            changes2.insertNodeAtEndOfScope(sourceFile, sourceFile, exportDeclaration);
                        });
                        return [createCodeFixActionWithoutFixAll("addEmptyExportDeclaration", changes, Diagnostics.Add_export_to_make_this_file_into_a_module)];
                    }
                });
            }
        });
        // src/services/codefixes/addMissingAsync.ts
        function getFix(context, decl, trackChanges, fixedDeclarations) {
            const changes = trackChanges((t) => makeChange2(t, context.sourceFile, decl, fixedDeclarations));
            return createCodeFixAction(fixId2, changes, Diagnostics.Add_async_modifier_to_containing_function, fixId2, Diagnostics.Add_all_missing_async_modifiers);
        }
        function makeChange2(changeTracker, sourceFile, insertionSite, fixedDeclarations) {
            if (fixedDeclarations) {
                if (fixedDeclarations.has(getNodeId(insertionSite))) {
                    return;
                }
            }
            fixedDeclarations == null ? void 0 : fixedDeclarations.add(getNodeId(insertionSite));
            const cloneWithModifier = factory.updateModifiers(getSynthesizedDeepClone(insertionSite, 
            /*includeTrivia*/
            true), factory.createNodeArray(factory.createModifiersFromModifierFlags(getSyntacticModifierFlags(insertionSite) | 512 /* Async */)));
            changeTracker.replaceNode(sourceFile, insertionSite, cloneWithModifier);
        }
        function getFixableErrorSpanDeclaration(sourceFile, span) {
            if (!span)
                return void 0;
            const token = getTokenAtPosition(sourceFile, span.start);
            const decl = findAncestor(token, (node) => {
                if (node.getStart(sourceFile) < span.start || node.getEnd() > textSpanEnd(span)) {
                    return "quit";
                }
                return (isArrowFunction(node) || isMethodDeclaration(node) || isFunctionExpression(node) || isFunctionDeclaration(node)) && textSpansEqual(span, createTextSpanFromNode(node, sourceFile));
            });
            return decl;
        }
        function getIsMatchingAsyncError(span, errorCode) {
            return ({ start, length: length2, relatedInformation, code }) => isNumber(start) && isNumber(length2) && textSpansEqual({ start, length: length2 }, span) && code === errorCode && !!relatedInformation && some(relatedInformation, (related) => related.code === Diagnostics.Did_you_mean_to_mark_this_function_as_async.code);
        }
        var fixId2, errorCodes2;
        var init_addMissingAsync = __esm({
            "src/services/codefixes/addMissingAsync.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId2 = "addMissingAsync";
                errorCodes2 = [
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1.code,
                    Diagnostics.Type_0_is_not_comparable_to_type_1.code
                ];
                registerCodeFix({
                    fixIds: [fixId2],
                    errorCodes: errorCodes2,
                    getCodeActions: function getCodeActionsToAddMissingAsync(context) {
                        const { sourceFile, errorCode, cancellationToken, program, span } = context;
                        const diagnostic = find(program.getTypeChecker().getDiagnostics(sourceFile, cancellationToken), getIsMatchingAsyncError(span, errorCode));
                        const directSpan = diagnostic && diagnostic.relatedInformation && find(diagnostic.relatedInformation, (r) => r.code === Diagnostics.Did_you_mean_to_mark_this_function_as_async.code);
                        const decl = getFixableErrorSpanDeclaration(sourceFile, directSpan);
                        if (!decl) {
                            return;
                        }
                        const trackChanges = (cb) => ts_textChanges_exports.ChangeTracker.with(context, cb);
                        return [getFix(context, decl, trackChanges)];
                    },
                    getAllCodeActions: (context) => {
                        const { sourceFile } = context;
                        const fixedDeclarations = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes2, (t, diagnostic) => {
                            const span = diagnostic.relatedInformation && find(diagnostic.relatedInformation, (r) => r.code === Diagnostics.Did_you_mean_to_mark_this_function_as_async.code);
                            const decl = getFixableErrorSpanDeclaration(sourceFile, span);
                            if (!decl) {
                                return;
                            }
                            const trackChanges = (cb) => (cb(t), []);
                            return getFix(context, decl, trackChanges, fixedDeclarations);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/addMissingAwait.ts
        function getAwaitErrorSpanExpression(sourceFile, errorCode, span, cancellationToken, program) {
            const expression = getFixableErrorSpanExpression(sourceFile, span);
            return expression && isMissingAwaitError(sourceFile, errorCode, span, cancellationToken, program) && isInsideAwaitableBody(expression) ? expression : void 0;
        }
        function getDeclarationSiteFix(context, expression, errorCode, checker, trackChanges, fixedDeclarations) {
            const { sourceFile, program, cancellationToken } = context;
            const awaitableInitializers = findAwaitableInitializers(expression, sourceFile, cancellationToken, program, checker);
            if (awaitableInitializers) {
                const initializerChanges = trackChanges((t) => {
                    forEach(awaitableInitializers.initializers, ({ expression: expression2 }) => makeChange3(t, errorCode, sourceFile, checker, expression2, fixedDeclarations));
                    if (fixedDeclarations && awaitableInitializers.needsSecondPassForFixAll) {
                        makeChange3(t, errorCode, sourceFile, checker, expression, fixedDeclarations);
                    }
                });
                return createCodeFixActionWithoutFixAll("addMissingAwaitToInitializer", initializerChanges, awaitableInitializers.initializers.length === 1 ? [Diagnostics.Add_await_to_initializer_for_0, awaitableInitializers.initializers[0].declarationSymbol.name] : Diagnostics.Add_await_to_initializers);
            }
        }
        function getUseSiteFix(context, expression, errorCode, checker, trackChanges, fixedDeclarations) {
            const changes = trackChanges((t) => makeChange3(t, errorCode, context.sourceFile, checker, expression, fixedDeclarations));
            return createCodeFixAction(fixId3, changes, Diagnostics.Add_await, fixId3, Diagnostics.Fix_all_expressions_possibly_missing_await);
        }
        function isMissingAwaitError(sourceFile, errorCode, span, cancellationToken, program) {
            const checker = program.getTypeChecker();
            const diagnostics = checker.getDiagnostics(sourceFile, cancellationToken);
            return some(diagnostics, ({ start, length: length2, relatedInformation, code }) => isNumber(start) && isNumber(length2) && textSpansEqual({ start, length: length2 }, span) && code === errorCode && !!relatedInformation && some(relatedInformation, (related) => related.code === Diagnostics.Did_you_forget_to_use_await.code));
        }
        function findAwaitableInitializers(expression, sourceFile, cancellationToken, program, checker) {
            const identifiers = getIdentifiersFromErrorSpanExpression(expression, checker);
            if (!identifiers) {
                return;
            }
            let isCompleteFix = identifiers.isCompleteFix;
            let initializers;
            for (const identifier of identifiers.identifiers) {
                const symbol = checker.getSymbolAtLocation(identifier);
                if (!symbol) {
                    continue;
                }
                const declaration = tryCast(symbol.valueDeclaration, isVariableDeclaration);
                const variableName = declaration && tryCast(declaration.name, isIdentifier);
                const variableStatement = getAncestor(declaration, 240 /* VariableStatement */);
                if (!declaration || !variableStatement || declaration.type || !declaration.initializer || variableStatement.getSourceFile() !== sourceFile || hasSyntacticModifier(variableStatement, 1 /* Export */) || !variableName || !isInsideAwaitableBody(declaration.initializer)) {
                    isCompleteFix = false;
                    continue;
                }
                const diagnostics = program.getSemanticDiagnostics(sourceFile, cancellationToken);
                const isUsedElsewhere = ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(variableName, checker, sourceFile, (reference) => {
                    return identifier !== reference && !symbolReferenceIsAlsoMissingAwait(reference, diagnostics, sourceFile, checker);
                });
                if (isUsedElsewhere) {
                    isCompleteFix = false;
                    continue;
                }
                (initializers || (initializers = [])).push({
                    expression: declaration.initializer,
                    declarationSymbol: symbol
                });
            }
            return initializers && {
                initializers,
                needsSecondPassForFixAll: !isCompleteFix
            };
        }
        function getIdentifiersFromErrorSpanExpression(expression, checker) {
            if (isPropertyAccessExpression(expression.parent) && isIdentifier(expression.parent.expression)) {
                return { identifiers: [expression.parent.expression], isCompleteFix: true };
            }
            if (isIdentifier(expression)) {
                return { identifiers: [expression], isCompleteFix: true };
            }
            if (isBinaryExpression(expression)) {
                let sides;
                let isCompleteFix = true;
                for (const side of [expression.left, expression.right]) {
                    const type = checker.getTypeAtLocation(side);
                    if (checker.getPromisedTypeOfPromise(type)) {
                        if (!isIdentifier(side)) {
                            isCompleteFix = false;
                            continue;
                        }
                        (sides || (sides = [])).push(side);
                    }
                }
                return sides && { identifiers: sides, isCompleteFix };
            }
        }
        function symbolReferenceIsAlsoMissingAwait(reference, diagnostics, sourceFile, checker) {
            const errorNode = isPropertyAccessExpression(reference.parent) ? reference.parent.name : isBinaryExpression(reference.parent) ? reference.parent : reference;
            const diagnostic = find(diagnostics, (diagnostic2) => diagnostic2.start === errorNode.getStart(sourceFile) && diagnostic2.start + diagnostic2.length === errorNode.getEnd());
            return diagnostic && contains(errorCodes3, diagnostic.code) || // A Promise is usually not correct in a binary expression (it’s not valid
                // in an arithmetic expression and an equality comparison seems unusual),
                // but if the other side of the binary expression has an error, the side
                // is typed `any` which will squash the error that would identify this
                // Promise as an invalid operand. So if the whole binary expression is
                // typed `any` as a result, there is a strong likelihood that this Promise
                // is accidentally missing `await`.
                checker.getTypeAtLocation(errorNode).flags & 1 /* Any */;
        }
        function isInsideAwaitableBody(node) {
            return node.kind & 32768 /* AwaitContext */ || !!findAncestor(node, (ancestor) => ancestor.parent && isArrowFunction(ancestor.parent) && ancestor.parent.body === ancestor || isBlock(ancestor) && (ancestor.parent.kind === 259 /* FunctionDeclaration */ || ancestor.parent.kind === 215 /* FunctionExpression */ || ancestor.parent.kind === 216 /* ArrowFunction */ || ancestor.parent.kind === 171 /* MethodDeclaration */));
        }
        function makeChange3(changeTracker, errorCode, sourceFile, checker, insertionSite, fixedDeclarations) {
            if (isForOfStatement(insertionSite.parent) && !insertionSite.parent.awaitModifier) {
                const exprType = checker.getTypeAtLocation(insertionSite);
                const asyncIter = checker.getAsyncIterableType();
                if (asyncIter && checker.isTypeAssignableTo(exprType, asyncIter)) {
                    const forOf = insertionSite.parent;
                    changeTracker.replaceNode(sourceFile, forOf, factory.updateForOfStatement(forOf, factory.createToken(133 /* AwaitKeyword */), forOf.initializer, forOf.expression, forOf.statement));
                    return;
                }
            }
            if (isBinaryExpression(insertionSite)) {
                for (const side of [insertionSite.left, insertionSite.right]) {
                    if (fixedDeclarations && isIdentifier(side)) {
                        const symbol = checker.getSymbolAtLocation(side);
                        if (symbol && fixedDeclarations.has(getSymbolId(symbol))) {
                            continue;
                        }
                    }
                    const type = checker.getTypeAtLocation(side);
                    const newNode = checker.getPromisedTypeOfPromise(type) ? factory.createAwaitExpression(side) : side;
                    changeTracker.replaceNode(sourceFile, side, newNode);
                }
            }
            else if (errorCode === propertyAccessCode && isPropertyAccessExpression(insertionSite.parent)) {
                if (fixedDeclarations && isIdentifier(insertionSite.parent.expression)) {
                    const symbol = checker.getSymbolAtLocation(insertionSite.parent.expression);
                    if (symbol && fixedDeclarations.has(getSymbolId(symbol))) {
                        return;
                    }
                }
                changeTracker.replaceNode(sourceFile, insertionSite.parent.expression, factory.createParenthesizedExpression(factory.createAwaitExpression(insertionSite.parent.expression)));
                insertLeadingSemicolonIfNeeded(changeTracker, insertionSite.parent.expression, sourceFile);
            }
            else if (contains(callableConstructableErrorCodes, errorCode) && isCallOrNewExpression(insertionSite.parent)) {
                if (fixedDeclarations && isIdentifier(insertionSite)) {
                    const symbol = checker.getSymbolAtLocation(insertionSite);
                    if (symbol && fixedDeclarations.has(getSymbolId(symbol))) {
                        return;
                    }
                }
                changeTracker.replaceNode(sourceFile, insertionSite, factory.createParenthesizedExpression(factory.createAwaitExpression(insertionSite)));
                insertLeadingSemicolonIfNeeded(changeTracker, insertionSite, sourceFile);
            }
            else {
                if (fixedDeclarations && isVariableDeclaration(insertionSite.parent) && isIdentifier(insertionSite.parent.name)) {
                    const symbol = checker.getSymbolAtLocation(insertionSite.parent.name);
                    if (symbol && !tryAddToSet(fixedDeclarations, getSymbolId(symbol))) {
                        return;
                    }
                }
                changeTracker.replaceNode(sourceFile, insertionSite, factory.createAwaitExpression(insertionSite));
            }
        }
        function insertLeadingSemicolonIfNeeded(changeTracker, beforeNode, sourceFile) {
            const precedingToken = findPrecedingToken(beforeNode.pos, sourceFile);
            if (precedingToken && positionIsASICandidate(precedingToken.end, precedingToken.parent, sourceFile)) {
                changeTracker.insertText(sourceFile, beforeNode.getStart(sourceFile), ";");
            }
        }
        var fixId3, propertyAccessCode, callableConstructableErrorCodes, errorCodes3;
        var init_addMissingAwait = __esm({
            "src/services/codefixes/addMissingAwait.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId3 = "addMissingAwait";
                propertyAccessCode = Diagnostics.Property_0_does_not_exist_on_type_1.code;
                callableConstructableErrorCodes = [
                    Diagnostics.This_expression_is_not_callable.code,
                    Diagnostics.This_expression_is_not_constructable.code
                ];
                errorCodes3 = [
                    Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type.code,
                    Diagnostics.The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type.code,
                    Diagnostics.The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type.code,
                    Diagnostics.Operator_0_cannot_be_applied_to_type_1.code,
                    Diagnostics.Operator_0_cannot_be_applied_to_types_1_and_2.code,
                    Diagnostics.This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap.code,
                    Diagnostics.This_condition_will_always_return_true_since_this_0_is_always_defined.code,
                    Diagnostics.Type_0_is_not_an_array_type.code,
                    Diagnostics.Type_0_is_not_an_array_type_or_a_string_type.code,
                    Diagnostics.Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher.code,
                    Diagnostics.Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator.code,
                    Diagnostics.Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator.code,
                    Diagnostics.Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator.code,
                    Diagnostics.Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,
                    propertyAccessCode,
                    ...callableConstructableErrorCodes
                ];
                registerCodeFix({
                    fixIds: [fixId3],
                    errorCodes: errorCodes3,
                    getCodeActions: function getCodeActionsToAddMissingAwait(context) {
                        const { sourceFile, errorCode, span, cancellationToken, program } = context;
                        const expression = getAwaitErrorSpanExpression(sourceFile, errorCode, span, cancellationToken, program);
                        if (!expression) {
                            return;
                        }
                        const checker = context.program.getTypeChecker();
                        const trackChanges = (cb) => ts_textChanges_exports.ChangeTracker.with(context, cb);
                        return compact([
                            getDeclarationSiteFix(context, expression, errorCode, checker, trackChanges),
                            getUseSiteFix(context, expression, errorCode, checker, trackChanges)
                        ]);
                    },
                    getAllCodeActions: (context) => {
                        const { sourceFile, program, cancellationToken } = context;
                        const checker = context.program.getTypeChecker();
                        const fixedDeclarations = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes3, (t, diagnostic) => {
                            const expression = getAwaitErrorSpanExpression(sourceFile, diagnostic.code, diagnostic, cancellationToken, program);
                            if (!expression) {
                                return;
                            }
                            const trackChanges = (cb) => (cb(t), []);
                            return getDeclarationSiteFix(context, expression, diagnostic.code, checker, trackChanges, fixedDeclarations) || getUseSiteFix(context, expression, diagnostic.code, checker, trackChanges, fixedDeclarations);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/addMissingConst.ts
        function makeChange4(changeTracker, sourceFile, pos, program, fixedNodes) {
            const token = getTokenAtPosition(sourceFile, pos);
            const forInitializer = findAncestor(token, (node) => isForInOrOfStatement(node.parent) ? node.parent.initializer === node : isPossiblyPartOfDestructuring(node) ? false : "quit");
            if (forInitializer)
                return applyChange(changeTracker, forInitializer, sourceFile, fixedNodes);
            const parent2 = token.parent;
            if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 63 /* EqualsToken */ && isExpressionStatement(parent2.parent)) {
                return applyChange(changeTracker, token, sourceFile, fixedNodes);
            }
            if (isArrayLiteralExpression(parent2)) {
                const checker = program.getTypeChecker();
                if (!every(parent2.elements, (element) => arrayElementCouldBeVariableDeclaration(element, checker))) {
                    return;
                }
                return applyChange(changeTracker, parent2, sourceFile, fixedNodes);
            }
            const commaExpression = findAncestor(token, (node) => isExpressionStatement(node.parent) ? true : isPossiblyPartOfCommaSeperatedInitializer(node) ? false : "quit");
            if (commaExpression) {
                const checker = program.getTypeChecker();
                if (!expressionCouldBeVariableDeclaration(commaExpression, checker)) {
                    return;
                }
                return applyChange(changeTracker, commaExpression, sourceFile, fixedNodes);
            }
        }
        function applyChange(changeTracker, initializer, sourceFile, fixedNodes) {
            if (!fixedNodes || tryAddToSet(fixedNodes, initializer)) {
                changeTracker.insertModifierBefore(sourceFile, 85 /* ConstKeyword */, initializer);
            }
        }
        function isPossiblyPartOfDestructuring(node) {
            switch (node.kind) {
                case 79 /* Identifier */:
                case 206 /* ArrayLiteralExpression */:
                case 207 /* ObjectLiteralExpression */:
                case 299 /* PropertyAssignment */:
                case 300 /* ShorthandPropertyAssignment */:
                    return true;
                default:
                    return false;
            }
        }
        function arrayElementCouldBeVariableDeclaration(expression, checker) {
            const identifier = isIdentifier(expression) ? expression : isAssignmentExpression(expression, 
            /*excludeCompoundAssignment*/
            true) && isIdentifier(expression.left) ? expression.left : void 0;
            return !!identifier && !checker.getSymbolAtLocation(identifier);
        }
        function isPossiblyPartOfCommaSeperatedInitializer(node) {
            switch (node.kind) {
                case 79 /* Identifier */:
                case 223 /* BinaryExpression */:
                case 27 /* CommaToken */:
                    return true;
                default:
                    return false;
            }
        }
        function expressionCouldBeVariableDeclaration(expression, checker) {
            if (!isBinaryExpression(expression)) {
                return false;
            }
            if (expression.operatorToken.kind === 27 /* CommaToken */) {
                return every([expression.left, expression.right], (expression2) => expressionCouldBeVariableDeclaration(expression2, checker));
            }
            return expression.operatorToken.kind === 63 /* EqualsToken */ && isIdentifier(expression.left) && !checker.getSymbolAtLocation(expression.left);
        }
        var fixId4, errorCodes4;
        var init_addMissingConst = __esm({
            "src/services/codefixes/addMissingConst.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId4 = "addMissingConst";
                errorCodes4 = [
                    Diagnostics.Cannot_find_name_0.code,
                    Diagnostics.No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes4,
                    getCodeActions: function getCodeActionsToAddMissingConst(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange4(t, context.sourceFile, context.span.start, context.program));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixId4, changes, Diagnostics.Add_const_to_unresolved_variable, fixId4, Diagnostics.Add_const_to_all_unresolved_variables)];
                        }
                    },
                    fixIds: [fixId4],
                    getAllCodeActions: (context) => {
                        const fixedNodes = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes4, (changes, diag2) => makeChange4(changes, diag2.file, diag2.start, context.program, fixedNodes));
                    }
                });
            }
        });
        // src/services/codefixes/addMissingDeclareProperty.ts
        function makeChange5(changeTracker, sourceFile, pos, fixedNodes) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (!isIdentifier(token)) {
                return;
            }
            const declaration = token.parent;
            if (declaration.kind === 169 /* PropertyDeclaration */ && (!fixedNodes || tryAddToSet(fixedNodes, declaration))) {
                changeTracker.insertModifierBefore(sourceFile, 136 /* DeclareKeyword */, declaration);
            }
        }
        var fixId5, errorCodes5;
        var init_addMissingDeclareProperty = __esm({
            "src/services/codefixes/addMissingDeclareProperty.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId5 = "addMissingDeclareProperty";
                errorCodes5 = [
                    Diagnostics.Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes5,
                    getCodeActions: function getCodeActionsToAddMissingDeclareOnProperty(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange5(t, context.sourceFile, context.span.start));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixId5, changes, Diagnostics.Prefix_with_declare, fixId5, Diagnostics.Prefix_all_incorrect_property_declarations_with_declare)];
                        }
                    },
                    fixIds: [fixId5],
                    getAllCodeActions: (context) => {
                        const fixedNodes = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes5, (changes, diag2) => makeChange5(changes, diag2.file, diag2.start, fixedNodes));
                    }
                });
            }
        });
        // src/services/codefixes/addMissingInvocationForDecorator.ts
        function makeChange6(changeTracker, sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const decorator = findAncestor(token, isDecorator);
            Debug.assert(!!decorator, "Expected position to be owned by a decorator.");
            const replacement = factory.createCallExpression(decorator.expression, 
            /*typeArguments*/
            void 0, 
            /*argumentsArray*/
            void 0);
            changeTracker.replaceNode(sourceFile, decorator.expression, replacement);
        }
        var fixId6, errorCodes6;
        var init_addMissingInvocationForDecorator = __esm({
            "src/services/codefixes/addMissingInvocationForDecorator.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId6 = "addMissingInvocationForDecorator";
                errorCodes6 = [Diagnostics._0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0.code];
                registerCodeFix({
                    errorCodes: errorCodes6,
                    getCodeActions: function getCodeActionsToAddMissingInvocationForDecorator(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange6(t, context.sourceFile, context.span.start));
                        return [createCodeFixAction(fixId6, changes, Diagnostics.Call_decorator_expression, fixId6, Diagnostics.Add_to_all_uncalled_decorators)];
                    },
                    fixIds: [fixId6],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes6, (changes, diag2) => makeChange6(changes, diag2.file, diag2.start))
                });
            }
        });
        // src/services/codefixes/addNameToNamelessParameter.ts
        function makeChange7(changeTracker, sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const param = token.parent;
            if (!isParameter(param)) {
                return Debug.fail("Tried to add a parameter name to a non-parameter: " + Debug.formatSyntaxKind(token.kind));
            }
            const i = param.parent.parameters.indexOf(param);
            Debug.assert(!param.type, "Tried to add a parameter name to a parameter that already had one.");
            Debug.assert(i > -1, "Parameter not found in parent parameter list.");
            const typeNode = factory.createTypeReferenceNode(param.name, 
            /*typeArguments*/
            void 0);
            const replacement = factory.createParameterDeclaration(param.modifiers, param.dotDotDotToken, "arg" + i, param.questionToken, param.dotDotDotToken ? factory.createArrayTypeNode(typeNode) : typeNode, param.initializer);
            changeTracker.replaceNode(sourceFile, param, replacement);
        }
        var fixId7, errorCodes7;
        var init_addNameToNamelessParameter = __esm({
            "src/services/codefixes/addNameToNamelessParameter.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId7 = "addNameToNamelessParameter";
                errorCodes7 = [Diagnostics.Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1.code];
                registerCodeFix({
                    errorCodes: errorCodes7,
                    getCodeActions: function getCodeActionsToAddNameToNamelessParameter(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange7(t, context.sourceFile, context.span.start));
                        return [createCodeFixAction(fixId7, changes, Diagnostics.Add_parameter_name, fixId7, Diagnostics.Add_names_to_all_parameters_without_names)];
                    },
                    fixIds: [fixId7],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes7, (changes, diag2) => makeChange7(changes, diag2.file, diag2.start))
                });
            }
        });
        // src/services/codefixes/addOptionalPropertyUndefined.ts
        function getPropertiesToAdd(file, span, checker) {
            var _a2, _b;
            const sourceTarget = getSourceTarget(getFixableErrorSpanExpression(file, span), checker);
            if (!sourceTarget) {
                return emptyArray;
            }
            const { source: sourceNode, target: targetNode } = sourceTarget;
            const target = shouldUseParentTypeOfProperty(sourceNode, targetNode, checker) ? checker.getTypeAtLocation(targetNode.expression) : checker.getTypeAtLocation(targetNode);
            if ((_b = (_a2 = target.symbol) == null ? void 0 : _a2.declarations) == null ? void 0 : _b.some((d) => getSourceFileOfNode(d).fileName.match(/\.d\.ts$/))) {
                return emptyArray;
            }
            return checker.getExactOptionalProperties(target);
        }
        function shouldUseParentTypeOfProperty(sourceNode, targetNode, checker) {
            return isPropertyAccessExpression(targetNode) && !!checker.getExactOptionalProperties(checker.getTypeAtLocation(targetNode.expression)).length && checker.getTypeAtLocation(sourceNode) === checker.getUndefinedType();
        }
        function getSourceTarget(errorNode, checker) {
            var _a2;
            if (!errorNode) {
                return void 0;
            }
            else if (isBinaryExpression(errorNode.parent) && errorNode.parent.operatorToken.kind === 63 /* EqualsToken */) {
                return { source: errorNode.parent.right, target: errorNode.parent.left };
            }
            else if (isVariableDeclaration(errorNode.parent) && errorNode.parent.initializer) {
                return { source: errorNode.parent.initializer, target: errorNode.parent.name };
            }
            else if (isCallExpression(errorNode.parent)) {
                const n = checker.getSymbolAtLocation(errorNode.parent.expression);
                if (!(n == null ? void 0 : n.valueDeclaration) || !isFunctionLikeKind(n.valueDeclaration.kind))
                    return void 0;
                if (!isExpression(errorNode))
                    return void 0;
                const i = errorNode.parent.arguments.indexOf(errorNode);
                if (i === -1)
                    return void 0;
                const name = n.valueDeclaration.parameters[i].name;
                if (isIdentifier(name))
                    return { source: errorNode, target: name };
            }
            else if (isPropertyAssignment(errorNode.parent) && isIdentifier(errorNode.parent.name) || isShorthandPropertyAssignment(errorNode.parent)) {
                const parentTarget = getSourceTarget(errorNode.parent.parent, checker);
                if (!parentTarget)
                    return void 0;
                const prop = checker.getPropertyOfType(checker.getTypeAtLocation(parentTarget.target), errorNode.parent.name.text);
                const declaration = (_a2 = prop == null ? void 0 : prop.declarations) == null ? void 0 : _a2[0];
                if (!declaration)
                    return void 0;
                return {
                    source: isPropertyAssignment(errorNode.parent) ? errorNode.parent.initializer : errorNode.parent.name,
                    target: declaration
                };
            }
            return void 0;
        }
        function addUndefinedToOptionalProperty(changes, toAdd) {
            for (const add of toAdd) {
                const d = add.valueDeclaration;
                if (d && (isPropertySignature(d) || isPropertyDeclaration(d)) && d.type) {
                    const t = factory.createUnionTypeNode([
                        ...d.type.kind === 189 /* UnionType */ ? d.type.types : [d.type],
                        factory.createTypeReferenceNode("undefined")
                    ]);
                    changes.replaceNode(d.getSourceFile(), d.type, t);
                }
            }
        }
        var addOptionalPropertyUndefined, errorCodes8;
        var init_addOptionalPropertyUndefined = __esm({
            "src/services/codefixes/addOptionalPropertyUndefined.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                addOptionalPropertyUndefined = "addOptionalPropertyUndefined";
                errorCodes8 = [
                    Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes8,
                    getCodeActions(context) {
                        const typeChecker = context.program.getTypeChecker();
                        const toAdd = getPropertiesToAdd(context.sourceFile, context.span, typeChecker);
                        if (!toAdd.length) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addUndefinedToOptionalProperty(t, toAdd));
                        return [createCodeFixActionWithoutFixAll(addOptionalPropertyUndefined, changes, Diagnostics.Add_undefined_to_optional_property_type)];
                    },
                    fixIds: [addOptionalPropertyUndefined]
                });
            }
        });
        // src/services/codefixes/annotateWithTypeFromJSDoc.ts
        function getDeclaration(file, pos) {
            const name = getTokenAtPosition(file, pos);
            return tryCast(isParameter(name.parent) ? name.parent.parent : name.parent, parameterShouldGetTypeFromJSDoc);
        }
        function parameterShouldGetTypeFromJSDoc(node) {
            return isDeclarationWithType(node) && hasUsableJSDoc(node);
        }
        function hasUsableJSDoc(decl) {
            return isFunctionLikeDeclaration(decl) ? decl.parameters.some(hasUsableJSDoc) || !decl.type && !!getJSDocReturnType(decl) : !decl.type && !!getJSDocType(decl);
        }
        function doChange(changes, sourceFile, decl) {
            if (isFunctionLikeDeclaration(decl) && (getJSDocReturnType(decl) || decl.parameters.some((p) => !!getJSDocType(p)))) {
                if (!decl.typeParameters) {
                    const typeParameters = getJSDocTypeParameterDeclarations(decl);
                    if (typeParameters.length)
                        changes.insertTypeParameters(sourceFile, decl, typeParameters);
                }
                const needParens = isArrowFunction(decl) && !findChildOfKind(decl, 20 /* OpenParenToken */, sourceFile);
                if (needParens)
                    changes.insertNodeBefore(sourceFile, first(decl.parameters), factory.createToken(20 /* OpenParenToken */));
                for (const param of decl.parameters) {
                    if (!param.type) {
                        const paramType = getJSDocType(param);
                        if (paramType)
                            changes.tryInsertTypeAnnotation(sourceFile, param, visitNode(paramType, transformJSDocType, isTypeNode));
                    }
                }
                if (needParens)
                    changes.insertNodeAfter(sourceFile, last(decl.parameters), factory.createToken(21 /* CloseParenToken */));
                if (!decl.type) {
                    const returnType = getJSDocReturnType(decl);
                    if (returnType)
                        changes.tryInsertTypeAnnotation(sourceFile, decl, visitNode(returnType, transformJSDocType, isTypeNode));
                }
            }
            else {
                const jsdocType = Debug.checkDefined(getJSDocType(decl), "A JSDocType for this declaration should exist");
                Debug.assert(!decl.type, "The JSDocType decl should have a type");
                changes.tryInsertTypeAnnotation(sourceFile, decl, visitNode(jsdocType, transformJSDocType, isTypeNode));
            }
        }
        function isDeclarationWithType(node) {
            return isFunctionLikeDeclaration(node) || node.kind === 257 /* VariableDeclaration */ || node.kind === 168 /* PropertySignature */ || node.kind === 169 /* PropertyDeclaration */;
        }
        function transformJSDocType(node) {
            switch (node.kind) {
                case 315 /* JSDocAllType */:
                case 316 /* JSDocUnknownType */:
                    return factory.createTypeReferenceNode("any", emptyArray);
                case 319 /* JSDocOptionalType */:
                    return transformJSDocOptionalType(node);
                case 318 /* JSDocNonNullableType */:
                    return transformJSDocType(node.type);
                case 317 /* JSDocNullableType */:
                    return transformJSDocNullableType(node);
                case 321 /* JSDocVariadicType */:
                    return transformJSDocVariadicType(node);
                case 320 /* JSDocFunctionType */:
                    return transformJSDocFunctionType(node);
                case 180 /* TypeReference */:
                    return transformJSDocTypeReference(node);
                case 325 /* JSDocTypeLiteral */:
                    return transformJSDocTypeLiteral(node);
                default:
                    const visited = visitEachChild(node, transformJSDocType, nullTransformationContext);
                    setEmitFlags(visited, 1 /* SingleLine */);
                    return visited;
            }
        }
        function transformJSDocTypeLiteral(node) {
            const typeNode = factory.createTypeLiteralNode(map(node.jsDocPropertyTags, (tag) => factory.createPropertySignature(
            /*modifiers*/
            void 0, isIdentifier(tag.name) ? tag.name : tag.name.right, isOptionalJSDocPropertyLikeTag(tag) ? factory.createToken(57 /* QuestionToken */) : void 0, tag.typeExpression && visitNode(tag.typeExpression.type, transformJSDocType, isTypeNode) || factory.createKeywordTypeNode(131 /* AnyKeyword */))));
            setEmitFlags(typeNode, 1 /* SingleLine */);
            return typeNode;
        }
        function transformJSDocOptionalType(node) {
            return factory.createUnionTypeNode([visitNode(node.type, transformJSDocType, isTypeNode), factory.createTypeReferenceNode("undefined", emptyArray)]);
        }
        function transformJSDocNullableType(node) {
            return factory.createUnionTypeNode([visitNode(node.type, transformJSDocType, isTypeNode), factory.createTypeReferenceNode("null", emptyArray)]);
        }
        function transformJSDocVariadicType(node) {
            return factory.createArrayTypeNode(visitNode(node.type, transformJSDocType, isTypeNode));
        }
        function transformJSDocFunctionType(node) {
            var _a2;
            return factory.createFunctionTypeNode(emptyArray, node.parameters.map(transformJSDocParameter), (_a2 = node.type) != null ? _a2 : factory.createKeywordTypeNode(131 /* AnyKeyword */));
        }
        function transformJSDocParameter(node) {
            const index = node.parent.parameters.indexOf(node);
            const isRest = node.type.kind === 321 /* JSDocVariadicType */ && index === node.parent.parameters.length - 1;
            const name = node.name || (isRest ? "rest" : "arg" + index);
            const dotdotdot = isRest ? factory.createToken(25 /* DotDotDotToken */) : node.dotDotDotToken;
            return factory.createParameterDeclaration(node.modifiers, dotdotdot, name, node.questionToken, visitNode(node.type, transformJSDocType, isTypeNode), node.initializer);
        }
        function transformJSDocTypeReference(node) {
            let name = node.typeName;
            let args = node.typeArguments;
            if (isIdentifier(node.typeName)) {
                if (isJSDocIndexSignature(node)) {
                    return transformJSDocIndexSignature(node);
                }
                let text = node.typeName.text;
                switch (node.typeName.text) {
                    case "String":
                    case "Boolean":
                    case "Object":
                    case "Number":
                        text = text.toLowerCase();
                        break;
                    case "array":
                    case "date":
                    case "promise":
                        text = text[0].toUpperCase() + text.slice(1);
                        break;
                }
                name = factory.createIdentifier(text);
                if ((text === "Array" || text === "Promise") && !node.typeArguments) {
                    args = factory.createNodeArray([factory.createTypeReferenceNode("any", emptyArray)]);
                }
                else {
                    args = visitNodes2(node.typeArguments, transformJSDocType, isTypeNode);
                }
            }
            return factory.createTypeReferenceNode(name, args);
        }
        function transformJSDocIndexSignature(node) {
            const index = factory.createParameterDeclaration(
            /*modifiers*/
            void 0, 
            /*dotDotDotToken*/
            void 0, node.typeArguments[0].kind === 148 /* NumberKeyword */ ? "n" : "s", 
            /*questionToken*/
            void 0, factory.createTypeReferenceNode(node.typeArguments[0].kind === 148 /* NumberKeyword */ ? "number" : "string", []), 
            /*initializer*/
            void 0);
            const indexSignature = factory.createTypeLiteralNode([factory.createIndexSignature(
                /*modifiers*/
                void 0, [index], node.typeArguments[1])]);
            setEmitFlags(indexSignature, 1 /* SingleLine */);
            return indexSignature;
        }
        var fixId8, errorCodes9;
        var init_annotateWithTypeFromJSDoc = __esm({
            "src/services/codefixes/annotateWithTypeFromJSDoc.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId8 = "annotateWithTypeFromJSDoc";
                errorCodes9 = [Diagnostics.JSDoc_types_may_be_moved_to_TypeScript_types.code];
                registerCodeFix({
                    errorCodes: errorCodes9,
                    getCodeActions(context) {
                        const decl = getDeclaration(context.sourceFile, context.span.start);
                        if (!decl)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange(t, context.sourceFile, decl));
                        return [createCodeFixAction(fixId8, changes, Diagnostics.Annotate_with_type_from_JSDoc, fixId8, Diagnostics.Annotate_everything_with_types_from_JSDoc)];
                    },
                    fixIds: [fixId8],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes9, (changes, diag2) => {
                        const decl = getDeclaration(diag2.file, diag2.start);
                        if (decl)
                            doChange(changes, diag2.file, decl);
                    })
                });
            }
        });
        // src/services/codefixes/convertFunctionToEs6Class.ts
        function doChange2(changes, sourceFile, position, checker, preferences, compilerOptions) {
            const ctorSymbol = checker.getSymbolAtLocation(getTokenAtPosition(sourceFile, position));
            if (!ctorSymbol || !ctorSymbol.valueDeclaration || !(ctorSymbol.flags & (16 /* Function */ | 3 /* Variable */))) {
                return void 0;
            }
            const ctorDeclaration = ctorSymbol.valueDeclaration;
            if (isFunctionDeclaration(ctorDeclaration) || isFunctionExpression(ctorDeclaration)) {
                changes.replaceNode(sourceFile, ctorDeclaration, createClassFromFunction(ctorDeclaration));
            }
            else if (isVariableDeclaration(ctorDeclaration)) {
                const classDeclaration = createClassFromVariableDeclaration(ctorDeclaration);
                if (!classDeclaration) {
                    return void 0;
                }
                const ancestor = ctorDeclaration.parent.parent;
                if (isVariableDeclarationList(ctorDeclaration.parent) && ctorDeclaration.parent.declarations.length > 1) {
                    changes.delete(sourceFile, ctorDeclaration);
                    changes.insertNodeAfter(sourceFile, ancestor, classDeclaration);
                }
                else {
                    changes.replaceNode(sourceFile, ancestor, classDeclaration);
                }
            }
            function createClassElementsFromSymbol(symbol) {
                const memberElements = [];
                if (symbol.exports) {
                    symbol.exports.forEach((member) => {
                        if (member.name === "prototype" && member.declarations) {
                            const firstDeclaration = member.declarations[0];
                            if (member.declarations.length === 1 && isPropertyAccessExpression(firstDeclaration) && isBinaryExpression(firstDeclaration.parent) && firstDeclaration.parent.operatorToken.kind === 63 /* EqualsToken */ && isObjectLiteralExpression(firstDeclaration.parent.right)) {
                                const prototypes = firstDeclaration.parent.right;
                                createClassElement(prototypes.symbol, 
                                /** modifiers */
                                void 0, memberElements);
                            }
                        }
                        else {
                            createClassElement(member, [factory.createToken(124 /* StaticKeyword */)], memberElements);
                        }
                    });
                }
                if (symbol.members) {
                    symbol.members.forEach((member, key) => {
                        var _a2, _b, _c, _d;
                        if (key === "constructor" && member.valueDeclaration) {
                            const prototypeAssignment = (_d = (_c = (_b = (_a2 = symbol.exports) == null ? void 0 : _a2.get("prototype")) == null ? void 0 : _b.declarations) == null ? void 0 : _c[0]) == null ? void 0 : _d.parent;
                            if (prototypeAssignment && isBinaryExpression(prototypeAssignment) && isObjectLiteralExpression(prototypeAssignment.right) && some(prototypeAssignment.right.properties, isConstructorAssignment)) {
                            }
                            else {
                                changes.delete(sourceFile, member.valueDeclaration.parent);
                            }
                            return;
                        }
                        createClassElement(member, 
                        /*modifiers*/
                        void 0, memberElements);
                    });
                }
                return memberElements;
                function shouldConvertDeclaration(_target, source) {
                    if (isAccessExpression(_target)) {
                        if (isPropertyAccessExpression(_target) && isConstructorAssignment(_target))
                            return true;
                        return isFunctionLike(source);
                    }
                    else {
                        return every(_target.properties, (property) => {
                            if (isMethodDeclaration(property) || isGetOrSetAccessorDeclaration(property))
                                return true;
                            if (isPropertyAssignment(property) && isFunctionExpression(property.initializer) && !!property.name)
                                return true;
                            if (isConstructorAssignment(property))
                                return true;
                            return false;
                        });
                    }
                }
                function createClassElement(symbol2, modifiers, members) {
                    if (!(symbol2.flags & 8192 /* Method */) && !(symbol2.flags & 4096 /* ObjectLiteral */)) {
                        return;
                    }
                    const memberDeclaration = symbol2.valueDeclaration;
                    const assignmentBinaryExpression = memberDeclaration.parent;
                    const assignmentExpr = assignmentBinaryExpression.right;
                    if (!shouldConvertDeclaration(memberDeclaration, assignmentExpr)) {
                        return;
                    }
                    if (some(members, (m) => {
                        const name = getNameOfDeclaration(m);
                        if (name && isIdentifier(name) && idText(name) === symbolName(symbol2)) {
                            return true;
                        }
                        return false;
                    })) {
                        return;
                    }
                    const nodeToDelete = assignmentBinaryExpression.parent && assignmentBinaryExpression.parent.kind === 241 /* ExpressionStatement */ ? assignmentBinaryExpression.parent : assignmentBinaryExpression;
                    changes.delete(sourceFile, nodeToDelete);
                    if (!assignmentExpr) {
                        members.push(factory.createPropertyDeclaration(modifiers, symbol2.name, 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0));
                        return;
                    }
                    if (isAccessExpression(memberDeclaration) && (isFunctionExpression(assignmentExpr) || isArrowFunction(assignmentExpr))) {
                        const quotePreference = getQuotePreference(sourceFile, preferences);
                        const name = tryGetPropertyName(memberDeclaration, compilerOptions, quotePreference);
                        if (name) {
                            createFunctionLikeExpressionMember(members, assignmentExpr, name);
                        }
                        return;
                    }
                    else if (isObjectLiteralExpression(assignmentExpr)) {
                        forEach(assignmentExpr.properties, (property) => {
                            if (isMethodDeclaration(property) || isGetOrSetAccessorDeclaration(property)) {
                                members.push(property);
                            }
                            if (isPropertyAssignment(property) && isFunctionExpression(property.initializer)) {
                                createFunctionLikeExpressionMember(members, property.initializer, property.name);
                            }
                            if (isConstructorAssignment(property))
                                return;
                            return;
                        });
                        return;
                    }
                    else {
                        if (isSourceFileJS(sourceFile))
                            return;
                        if (!isPropertyAccessExpression(memberDeclaration))
                            return;
                        const prop = factory.createPropertyDeclaration(modifiers, memberDeclaration.name, 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0, assignmentExpr);
                        copyLeadingComments(assignmentBinaryExpression.parent, prop, sourceFile);
                        members.push(prop);
                        return;
                    }
                    function createFunctionLikeExpressionMember(members2, expression, name) {
                        if (isFunctionExpression(expression))
                            return createFunctionExpressionMember(members2, expression, name);
                        else
                            return createArrowFunctionExpressionMember(members2, expression, name);
                    }
                    function createFunctionExpressionMember(members2, functionExpression, name) {
                        const fullModifiers = concatenate(modifiers, getModifierKindFromSource(functionExpression, 132 /* AsyncKeyword */));
                        const method = factory.createMethodDeclaration(fullModifiers, 
                        /*asteriskToken*/
                        void 0, name, 
                        /*questionToken*/
                        void 0, 
                        /*typeParameters*/
                        void 0, functionExpression.parameters, 
                        /*type*/
                        void 0, functionExpression.body);
                        copyLeadingComments(assignmentBinaryExpression, method, sourceFile);
                        members2.push(method);
                        return;
                    }
                    function createArrowFunctionExpressionMember(members2, arrowFunction, name) {
                        const arrowFunctionBody = arrowFunction.body;
                        let bodyBlock;
                        if (arrowFunctionBody.kind === 238 /* Block */) {
                            bodyBlock = arrowFunctionBody;
                        }
                        else {
                            bodyBlock = factory.createBlock([factory.createReturnStatement(arrowFunctionBody)]);
                        }
                        const fullModifiers = concatenate(modifiers, getModifierKindFromSource(arrowFunction, 132 /* AsyncKeyword */));
                        const method = factory.createMethodDeclaration(fullModifiers, 
                        /*asteriskToken*/
                        void 0, name, 
                        /*questionToken*/
                        void 0, 
                        /*typeParameters*/
                        void 0, arrowFunction.parameters, 
                        /*type*/
                        void 0, bodyBlock);
                        copyLeadingComments(assignmentBinaryExpression, method, sourceFile);
                        members2.push(method);
                    }
                }
            }
            function createClassFromVariableDeclaration(node) {
                const initializer = node.initializer;
                if (!initializer || !isFunctionExpression(initializer) || !isIdentifier(node.name)) {
                    return void 0;
                }
                const memberElements = createClassElementsFromSymbol(node.symbol);
                if (initializer.body) {
                    memberElements.unshift(factory.createConstructorDeclaration(
                    /*modifiers*/
                    void 0, initializer.parameters, initializer.body));
                }
                const modifiers = getModifierKindFromSource(node.parent.parent, 93 /* ExportKeyword */);
                const cls = factory.createClassDeclaration(modifiers, node.name, 
                /*typeParameters*/
                void 0, 
                /*heritageClauses*/
                void 0, memberElements);
                return cls;
            }
            function createClassFromFunction(node) {
                const memberElements = createClassElementsFromSymbol(ctorSymbol);
                if (node.body) {
                    memberElements.unshift(factory.createConstructorDeclaration(
                    /*modifiers*/
                    void 0, node.parameters, node.body));
                }
                const modifiers = getModifierKindFromSource(node, 93 /* ExportKeyword */);
                const cls = factory.createClassDeclaration(modifiers, node.name, 
                /*typeParameters*/
                void 0, 
                /*heritageClauses*/
                void 0, memberElements);
                return cls;
            }
        }
        function getModifierKindFromSource(source, kind) {
            return canHaveModifiers(source) ? filter(source.modifiers, (modifier) => modifier.kind === kind) : void 0;
        }
        function isConstructorAssignment(x) {
            if (!x.name)
                return false;
            if (isIdentifier(x.name) && x.name.text === "constructor")
                return true;
            return false;
        }
        function tryGetPropertyName(node, compilerOptions, quotePreference) {
            if (isPropertyAccessExpression(node)) {
                return node.name;
            }
            const propName = node.argumentExpression;
            if (isNumericLiteral(propName)) {
                return propName;
            }
            if (isStringLiteralLike(propName)) {
                return isIdentifierText(propName.text, getEmitScriptTarget(compilerOptions)) ? factory.createIdentifier(propName.text) : isNoSubstitutionTemplateLiteral(propName) ? factory.createStringLiteral(propName.text, quotePreference === 0 /* Single */) : propName;
            }
            return void 0;
        }
        var fixId9, errorCodes10;
        var init_convertFunctionToEs6Class = __esm({
            "src/services/codefixes/convertFunctionToEs6Class.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId9 = "convertFunctionToEs6Class";
                errorCodes10 = [Diagnostics.This_constructor_function_may_be_converted_to_a_class_declaration.code];
                registerCodeFix({
                    errorCodes: errorCodes10,
                    getCodeActions(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange2(t, context.sourceFile, context.span.start, context.program.getTypeChecker(), context.preferences, context.program.getCompilerOptions()));
                        return [createCodeFixAction(fixId9, changes, Diagnostics.Convert_function_to_an_ES2015_class, fixId9, Diagnostics.Convert_all_constructor_functions_to_classes)];
                    },
                    fixIds: [fixId9],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes10, (changes, err) => doChange2(changes, err.file, err.start, context.program.getTypeChecker(), context.preferences, context.program.getCompilerOptions()))
                });
            }
        });
        // src/services/codefixes/convertToAsyncFunction.ts
        function convertToAsyncFunction(changes, sourceFile, position, checker) {
            const tokenAtPosition = getTokenAtPosition(sourceFile, position);
            let functionToConvert;
            if (isIdentifier(tokenAtPosition) && isVariableDeclaration(tokenAtPosition.parent) && tokenAtPosition.parent.initializer && isFunctionLikeDeclaration(tokenAtPosition.parent.initializer)) {
                functionToConvert = tokenAtPosition.parent.initializer;
            }
            else {
                functionToConvert = tryCast(getContainingFunction(getTokenAtPosition(sourceFile, position)), canBeConvertedToAsync);
            }
            if (!functionToConvert) {
                return;
            }
            const synthNamesMap = /* @__PURE__ */ new Map();
            const isInJavascript = isInJSFile(functionToConvert);
            const setOfExpressionsToReturn = getAllPromiseExpressionsToReturn(functionToConvert, checker);
            const functionToConvertRenamed = renameCollidingVarNames(functionToConvert, checker, synthNamesMap);
            if (!returnsPromise(functionToConvertRenamed, checker)) {
                return;
            }
            const returnStatements = functionToConvertRenamed.body && isBlock(functionToConvertRenamed.body) ? getReturnStatementsWithPromiseHandlers(functionToConvertRenamed.body, checker) : emptyArray;
            const transformer = { checker, synthNamesMap, setOfExpressionsToReturn, isInJSFile: isInJavascript };
            if (!returnStatements.length) {
                return;
            }
            const pos = skipTrivia(sourceFile.text, moveRangePastModifiers(functionToConvert).pos);
            changes.insertModifierAt(sourceFile, pos, 132 /* AsyncKeyword */, { suffix: " " });
            for (const returnStatement of returnStatements) {
                forEachChild(returnStatement, function visit(node) {
                    if (isCallExpression(node)) {
                        const newNodes = transformExpression(node, node, transformer, 
                        /*hasContinuation*/
                        false);
                        if (hasFailed()) {
                            return true;
                        }
                        changes.replaceNodeWithNodes(sourceFile, returnStatement, newNodes);
                    }
                    else if (!isFunctionLike(node)) {
                        forEachChild(node, visit);
                        if (hasFailed()) {
                            return true;
                        }
                    }
                });
                if (hasFailed()) {
                    return;
                }
            }
        }
        function getReturnStatementsWithPromiseHandlers(body, checker) {
            const res = [];
            forEachReturnStatement(body, (ret) => {
                if (isReturnStatementWithFixablePromiseHandler(ret, checker))
                    res.push(ret);
            });
            return res;
        }
        function getAllPromiseExpressionsToReturn(func, checker) {
            if (!func.body) {
                return /* @__PURE__ */ new Set();
            }
            const setOfExpressionsToReturn = /* @__PURE__ */ new Set();
            forEachChild(func.body, function visit(node) {
                if (isPromiseReturningCallExpression(node, checker, "then")) {
                    setOfExpressionsToReturn.add(getNodeId(node));
                    forEach(node.arguments, visit);
                }
                else if (isPromiseReturningCallExpression(node, checker, "catch") || isPromiseReturningCallExpression(node, checker, "finally")) {
                    setOfExpressionsToReturn.add(getNodeId(node));
                    forEachChild(node, visit);
                }
                else if (isPromiseTypedExpression(node, checker)) {
                    setOfExpressionsToReturn.add(getNodeId(node));
                }
                else {
                    forEachChild(node, visit);
                }
            });
            return setOfExpressionsToReturn;
        }
        function isPromiseReturningCallExpression(node, checker, name) {
            if (!isCallExpression(node))
                return false;
            const isExpressionOfName = hasPropertyAccessExpressionWithName(node, name);
            const nodeType = isExpressionOfName && checker.getTypeAtLocation(node);
            return !!(nodeType && checker.getPromisedTypeOfPromise(nodeType));
        }
        function isReferenceToType(type, target) {
            return (getObjectFlags(type) & 4 /* Reference */) !== 0 && type.target === target;
        }
        function getExplicitPromisedTypeOfPromiseReturningCallExpression(node, callback, checker) {
            if (node.expression.name.escapedText === "finally") {
                return void 0;
            }
            const promiseType = checker.getTypeAtLocation(node.expression.expression);
            if (isReferenceToType(promiseType, checker.getPromiseType()) || isReferenceToType(promiseType, checker.getPromiseLikeType())) {
                if (node.expression.name.escapedText === "then") {
                    if (callback === elementAt(node.arguments, 0)) {
                        return elementAt(node.typeArguments, 0);
                    }
                    else if (callback === elementAt(node.arguments, 1)) {
                        return elementAt(node.typeArguments, 1);
                    }
                }
                else {
                    return elementAt(node.typeArguments, 0);
                }
            }
        }
        function isPromiseTypedExpression(node, checker) {
            if (!isExpression(node))
                return false;
            return !!checker.getPromisedTypeOfPromise(checker.getTypeAtLocation(node));
        }
        function renameCollidingVarNames(nodeToRename, checker, synthNamesMap) {
            const identsToRenameMap = /* @__PURE__ */ new Map();
            const collidingSymbolMap = createMultiMap();
            forEachChild(nodeToRename, function visit(node) {
                if (!isIdentifier(node)) {
                    forEachChild(node, visit);
                    return;
                }
                const symbol = checker.getSymbolAtLocation(node);
                if (symbol) {
                    const type = checker.getTypeAtLocation(node);
                    const lastCallSignature = getLastCallSignature(type, checker);
                    const symbolIdString = getSymbolId(symbol).toString();
                    if (lastCallSignature && !isParameter(node.parent) && !isFunctionLikeDeclaration(node.parent) && !synthNamesMap.has(symbolIdString)) {
                        const firstParameter = firstOrUndefined(lastCallSignature.parameters);
                        const ident = (firstParameter == null ? void 0 : firstParameter.valueDeclaration) && isParameter(firstParameter.valueDeclaration) && tryCast(firstParameter.valueDeclaration.name, isIdentifier) || factory.createUniqueName("result", 16 /* Optimistic */);
                        const synthName = getNewNameIfConflict(ident, collidingSymbolMap);
                        synthNamesMap.set(symbolIdString, synthName);
                        collidingSymbolMap.add(ident.text, symbol);
                    }
                    else if (node.parent && (isParameter(node.parent) || isVariableDeclaration(node.parent) || isBindingElement(node.parent))) {
                        const originalName = node.text;
                        const collidingSymbols = collidingSymbolMap.get(originalName);
                        if (collidingSymbols && collidingSymbols.some((prevSymbol) => prevSymbol !== symbol)) {
                            const newName = getNewNameIfConflict(node, collidingSymbolMap);
                            identsToRenameMap.set(symbolIdString, newName.identifier);
                            synthNamesMap.set(symbolIdString, newName);
                            collidingSymbolMap.add(originalName, symbol);
                        }
                        else {
                            const identifier = getSynthesizedDeepClone(node);
                            synthNamesMap.set(symbolIdString, createSynthIdentifier(identifier));
                            collidingSymbolMap.add(originalName, symbol);
                        }
                    }
                }
            });
            return getSynthesizedDeepCloneWithReplacements(nodeToRename, 
            /*includeTrivia*/
            true, (original) => {
                if (isBindingElement(original) && isIdentifier(original.name) && isObjectBindingPattern(original.parent)) {
                    const symbol = checker.getSymbolAtLocation(original.name);
                    const renameInfo = symbol && identsToRenameMap.get(String(getSymbolId(symbol)));
                    if (renameInfo && renameInfo.text !== (original.name || original.propertyName).getText()) {
                        return factory.createBindingElement(original.dotDotDotToken, original.propertyName || original.name, renameInfo, original.initializer);
                    }
                }
                else if (isIdentifier(original)) {
                    const symbol = checker.getSymbolAtLocation(original);
                    const renameInfo = symbol && identsToRenameMap.get(String(getSymbolId(symbol)));
                    if (renameInfo) {
                        return factory.createIdentifier(renameInfo.text);
                    }
                }
            });
        }
        function getNewNameIfConflict(name, originalNames) {
            const numVarsSameName = (originalNames.get(name.text) || emptyArray).length;
            const identifier = numVarsSameName === 0 ? name : factory.createIdentifier(name.text + "_" + numVarsSameName);
            return createSynthIdentifier(identifier);
        }
        function hasFailed() {
            return !codeActionSucceeded;
        }
        function silentFail() {
            codeActionSucceeded = false;
            return emptyArray;
        }
        function transformExpression(returnContextNode, node, transformer, hasContinuation, continuationArgName) {
            if (isPromiseReturningCallExpression(node, transformer.checker, "then")) {
                return transformThen(node, elementAt(node.arguments, 0), elementAt(node.arguments, 1), transformer, hasContinuation, continuationArgName);
            }
            if (isPromiseReturningCallExpression(node, transformer.checker, "catch")) {
                return transformCatch(node, elementAt(node.arguments, 0), transformer, hasContinuation, continuationArgName);
            }
            if (isPromiseReturningCallExpression(node, transformer.checker, "finally")) {
                return transformFinally(node, elementAt(node.arguments, 0), transformer, hasContinuation, continuationArgName);
            }
            if (isPropertyAccessExpression(node)) {
                return transformExpression(returnContextNode, node.expression, transformer, hasContinuation, continuationArgName);
            }
            const nodeType = transformer.checker.getTypeAtLocation(node);
            if (nodeType && transformer.checker.getPromisedTypeOfPromise(nodeType)) {
                Debug.assertNode(getOriginalNode(node).parent, isPropertyAccessExpression);
                return transformPromiseExpressionOfPropertyAccess(returnContextNode, node, transformer, hasContinuation, continuationArgName);
            }
            return silentFail();
        }
        function isNullOrUndefined2({ checker }, node) {
            if (node.kind === 104 /* NullKeyword */)
                return true;
            if (isIdentifier(node) && !isGeneratedIdentifier(node) && idText(node) === "undefined") {
                const symbol = checker.getSymbolAtLocation(node);
                return !symbol || checker.isUndefinedSymbol(symbol);
            }
            return false;
        }
        function createUniqueSynthName(prevArgName) {
            const renamedPrevArg = factory.createUniqueName(prevArgName.identifier.text, 16 /* Optimistic */);
            return createSynthIdentifier(renamedPrevArg);
        }
        function getPossibleNameForVarDecl(node, transformer, continuationArgName) {
            let possibleNameForVarDecl;
            if (continuationArgName && !shouldReturn(node, transformer)) {
                if (isSynthIdentifier(continuationArgName)) {
                    possibleNameForVarDecl = continuationArgName;
                    transformer.synthNamesMap.forEach((val, key) => {
                        if (val.identifier.text === continuationArgName.identifier.text) {
                            const newSynthName = createUniqueSynthName(continuationArgName);
                            transformer.synthNamesMap.set(key, newSynthName);
                        }
                    });
                }
                else {
                    possibleNameForVarDecl = createSynthIdentifier(factory.createUniqueName("result", 16 /* Optimistic */), continuationArgName.types);
                }
                declareSynthIdentifier(possibleNameForVarDecl);
            }
            return possibleNameForVarDecl;
        }
        function finishCatchOrFinallyTransform(node, transformer, tryStatement, possibleNameForVarDecl, continuationArgName) {
            const statements = [];
            let varDeclIdentifier;
            if (possibleNameForVarDecl && !shouldReturn(node, transformer)) {
                varDeclIdentifier = getSynthesizedDeepClone(declareSynthIdentifier(possibleNameForVarDecl));
                const typeArray = possibleNameForVarDecl.types;
                const unionType = transformer.checker.getUnionType(typeArray, 2 /* Subtype */);
                const unionTypeNode = transformer.isInJSFile ? void 0 : transformer.checker.typeToTypeNode(unionType, 
                /*enclosingDeclaration*/
                void 0, 
                /*flags*/
                void 0);
                const varDecl = [factory.createVariableDeclaration(varDeclIdentifier, 
                    /*exclamationToken*/
                    void 0, unionTypeNode)];
                const varDeclList = factory.createVariableStatement(
                /*modifiers*/
                void 0, factory.createVariableDeclarationList(varDecl, 1 /* Let */));
                statements.push(varDeclList);
            }
            statements.push(tryStatement);
            if (continuationArgName && varDeclIdentifier && isSynthBindingPattern(continuationArgName)) {
                statements.push(factory.createVariableStatement(
                /*modifiers*/
                void 0, factory.createVariableDeclarationList([
                    factory.createVariableDeclaration(getSynthesizedDeepClone(declareSynthBindingPattern(continuationArgName)), 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, varDeclIdentifier)
                ], 2 /* Const */)));
            }
            return statements;
        }
        function transformFinally(node, onFinally, transformer, hasContinuation, continuationArgName) {
            if (!onFinally || isNullOrUndefined2(transformer, onFinally)) {
                return transformExpression(
                /* returnContextNode */
                node, node.expression.expression, transformer, hasContinuation, continuationArgName);
            }
            const possibleNameForVarDecl = getPossibleNameForVarDecl(node, transformer, continuationArgName);
            const inlinedLeftHandSide = transformExpression(
            /*returnContextNode*/
            node, node.expression.expression, transformer, 
            /*hasContinuation*/
            true, possibleNameForVarDecl);
            if (hasFailed())
                return silentFail();
            const inlinedCallback = transformCallbackArgument(onFinally, hasContinuation, 
            /*continuationArgName*/
            void 0, 
            /*argName*/
            void 0, node, transformer);
            if (hasFailed())
                return silentFail();
            const tryBlock = factory.createBlock(inlinedLeftHandSide);
            const finallyBlock = factory.createBlock(inlinedCallback);
            const tryStatement = factory.createTryStatement(tryBlock, 
            /*catchClause*/
            void 0, finallyBlock);
            return finishCatchOrFinallyTransform(node, transformer, tryStatement, possibleNameForVarDecl, continuationArgName);
        }
        function transformCatch(node, onRejected, transformer, hasContinuation, continuationArgName) {
            if (!onRejected || isNullOrUndefined2(transformer, onRejected)) {
                return transformExpression(
                /* returnContextNode */
                node, node.expression.expression, transformer, hasContinuation, continuationArgName);
            }
            const inputArgName = getArgBindingName(onRejected, transformer);
            const possibleNameForVarDecl = getPossibleNameForVarDecl(node, transformer, continuationArgName);
            const inlinedLeftHandSide = transformExpression(
            /*returnContextNode*/
            node, node.expression.expression, transformer, 
            /*hasContinuation*/
            true, possibleNameForVarDecl);
            if (hasFailed())
                return silentFail();
            const inlinedCallback = transformCallbackArgument(onRejected, hasContinuation, possibleNameForVarDecl, inputArgName, node, transformer);
            if (hasFailed())
                return silentFail();
            const tryBlock = factory.createBlock(inlinedLeftHandSide);
            const catchClause = factory.createCatchClause(inputArgName && getSynthesizedDeepClone(declareSynthBindingName(inputArgName)), factory.createBlock(inlinedCallback));
            const tryStatement = factory.createTryStatement(tryBlock, catchClause, 
            /*finallyBlock*/
            void 0);
            return finishCatchOrFinallyTransform(node, transformer, tryStatement, possibleNameForVarDecl, continuationArgName);
        }
        function transformThen(node, onFulfilled, onRejected, transformer, hasContinuation, continuationArgName) {
            if (!onFulfilled || isNullOrUndefined2(transformer, onFulfilled)) {
                return transformCatch(node, onRejected, transformer, hasContinuation, continuationArgName);
            }
            if (onRejected && !isNullOrUndefined2(transformer, onRejected)) {
                return silentFail();
            }
            const inputArgName = getArgBindingName(onFulfilled, transformer);
            const inlinedLeftHandSide = transformExpression(node.expression.expression, node.expression.expression, transformer, 
            /*hasContinuation*/
            true, inputArgName);
            if (hasFailed())
                return silentFail();
            const inlinedCallback = transformCallbackArgument(onFulfilled, hasContinuation, continuationArgName, inputArgName, node, transformer);
            if (hasFailed())
                return silentFail();
            return concatenate(inlinedLeftHandSide, inlinedCallback);
        }
        function transformPromiseExpressionOfPropertyAccess(returnContextNode, node, transformer, hasContinuation, continuationArgName) {
            if (shouldReturn(returnContextNode, transformer)) {
                let returnValue = getSynthesizedDeepClone(node);
                if (hasContinuation) {
                    returnValue = factory.createAwaitExpression(returnValue);
                }
                return [factory.createReturnStatement(returnValue)];
            }
            return createVariableOrAssignmentOrExpressionStatement(continuationArgName, factory.createAwaitExpression(node), 
            /*typeAnnotation*/
            void 0);
        }
        function createVariableOrAssignmentOrExpressionStatement(variableName, rightHandSide, typeAnnotation) {
            if (!variableName || isEmptyBindingName(variableName)) {
                return [factory.createExpressionStatement(rightHandSide)];
            }
            if (isSynthIdentifier(variableName) && variableName.hasBeenDeclared) {
                return [factory.createExpressionStatement(factory.createAssignment(getSynthesizedDeepClone(referenceSynthIdentifier(variableName)), rightHandSide))];
            }
            return [
                factory.createVariableStatement(
                /*modifiers*/
                void 0, factory.createVariableDeclarationList([
                    factory.createVariableDeclaration(getSynthesizedDeepClone(declareSynthBindingName(variableName)), 
                    /*exclamationToken*/
                    void 0, typeAnnotation, rightHandSide)
                ], 2 /* Const */))
            ];
        }
        function maybeAnnotateAndReturn(expressionToReturn, typeAnnotation) {
            if (typeAnnotation && expressionToReturn) {
                const name = factory.createUniqueName("result", 16 /* Optimistic */);
                return [
                    ...createVariableOrAssignmentOrExpressionStatement(createSynthIdentifier(name), expressionToReturn, typeAnnotation),
                    factory.createReturnStatement(name)
                ];
            }
            return [factory.createReturnStatement(expressionToReturn)];
        }
        function transformCallbackArgument(func, hasContinuation, continuationArgName, inputArgName, parent2, transformer) {
            var _a2;
            switch (func.kind) {
                case 104 /* NullKeyword */:
                    break;
                case 208 /* PropertyAccessExpression */:
                case 79 /* Identifier */:
                    if (!inputArgName) {
                        break;
                    }
                    const synthCall = factory.createCallExpression(getSynthesizedDeepClone(func), 
                    /*typeArguments*/
                    void 0, isSynthIdentifier(inputArgName) ? [referenceSynthIdentifier(inputArgName)] : []);
                    if (shouldReturn(parent2, transformer)) {
                        return maybeAnnotateAndReturn(synthCall, getExplicitPromisedTypeOfPromiseReturningCallExpression(parent2, func, transformer.checker));
                    }
                    const type = transformer.checker.getTypeAtLocation(func);
                    const callSignatures = transformer.checker.getSignaturesOfType(type, 0 /* Call */);
                    if (!callSignatures.length) {
                        return silentFail();
                    }
                    const returnType = callSignatures[0].getReturnType();
                    const varDeclOrAssignment = createVariableOrAssignmentOrExpressionStatement(continuationArgName, factory.createAwaitExpression(synthCall), getExplicitPromisedTypeOfPromiseReturningCallExpression(parent2, func, transformer.checker));
                    if (continuationArgName) {
                        continuationArgName.types.push(transformer.checker.getAwaitedType(returnType) || returnType);
                    }
                    return varDeclOrAssignment;
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */: {
                    const funcBody = func.body;
                    const returnType2 = (_a2 = getLastCallSignature(transformer.checker.getTypeAtLocation(func), transformer.checker)) == null ? void 0 : _a2.getReturnType();
                    if (isBlock(funcBody)) {
                        let refactoredStmts = [];
                        let seenReturnStatement = false;
                        for (const statement of funcBody.statements) {
                            if (isReturnStatement(statement)) {
                                seenReturnStatement = true;
                                if (isReturnStatementWithFixablePromiseHandler(statement, transformer.checker)) {
                                    refactoredStmts = refactoredStmts.concat(transformReturnStatementWithFixablePromiseHandler(transformer, statement, hasContinuation, continuationArgName));
                                }
                                else {
                                    const possiblyAwaitedRightHandSide = returnType2 && statement.expression ? getPossiblyAwaitedRightHandSide(transformer.checker, returnType2, statement.expression) : statement.expression;
                                    refactoredStmts.push(...maybeAnnotateAndReturn(possiblyAwaitedRightHandSide, getExplicitPromisedTypeOfPromiseReturningCallExpression(parent2, func, transformer.checker)));
                                }
                            }
                            else if (hasContinuation && forEachReturnStatement(statement, returnTrue)) {
                                return silentFail();
                            }
                            else {
                                refactoredStmts.push(statement);
                            }
                        }
                        return shouldReturn(parent2, transformer) ? refactoredStmts.map((s) => getSynthesizedDeepClone(s)) : removeReturns(refactoredStmts, continuationArgName, transformer, seenReturnStatement);
                    }
                    else {
                        const inlinedStatements = isFixablePromiseHandler(funcBody, transformer.checker) ? transformReturnStatementWithFixablePromiseHandler(transformer, factory.createReturnStatement(funcBody), hasContinuation, continuationArgName) : emptyArray;
                        if (inlinedStatements.length > 0) {
                            return inlinedStatements;
                        }
                        if (returnType2) {
                            const possiblyAwaitedRightHandSide = getPossiblyAwaitedRightHandSide(transformer.checker, returnType2, funcBody);
                            if (!shouldReturn(parent2, transformer)) {
                                const transformedStatement = createVariableOrAssignmentOrExpressionStatement(continuationArgName, possiblyAwaitedRightHandSide, 
                                /*typeAnnotation*/
                                void 0);
                                if (continuationArgName) {
                                    continuationArgName.types.push(transformer.checker.getAwaitedType(returnType2) || returnType2);
                                }
                                return transformedStatement;
                            }
                            else {
                                return maybeAnnotateAndReturn(possiblyAwaitedRightHandSide, getExplicitPromisedTypeOfPromiseReturningCallExpression(parent2, func, transformer.checker));
                            }
                        }
                        else {
                            return silentFail();
                        }
                    }
                }
                default:
                    return silentFail();
            }
            return emptyArray;
        }
        function getPossiblyAwaitedRightHandSide(checker, type, expr) {
            const rightHandSide = getSynthesizedDeepClone(expr);
            return !!checker.getPromisedTypeOfPromise(type) ? factory.createAwaitExpression(rightHandSide) : rightHandSide;
        }
        function getLastCallSignature(type, checker) {
            const callSignatures = checker.getSignaturesOfType(type, 0 /* Call */);
            return lastOrUndefined(callSignatures);
        }
        function removeReturns(stmts, prevArgName, transformer, seenReturnStatement) {
            const ret = [];
            for (const stmt of stmts) {
                if (isReturnStatement(stmt)) {
                    if (stmt.expression) {
                        const possiblyAwaitedExpression = isPromiseTypedExpression(stmt.expression, transformer.checker) ? factory.createAwaitExpression(stmt.expression) : stmt.expression;
                        if (prevArgName === void 0) {
                            ret.push(factory.createExpressionStatement(possiblyAwaitedExpression));
                        }
                        else if (isSynthIdentifier(prevArgName) && prevArgName.hasBeenDeclared) {
                            ret.push(factory.createExpressionStatement(factory.createAssignment(referenceSynthIdentifier(prevArgName), possiblyAwaitedExpression)));
                        }
                        else {
                            ret.push(factory.createVariableStatement(
                            /*modifiers*/
                            void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(declareSynthBindingName(prevArgName), 
                                /*exclamationToken*/
                                void 0, 
                                /*type*/
                                void 0, possiblyAwaitedExpression)], 2 /* Const */)));
                        }
                    }
                }
                else {
                    ret.push(getSynthesizedDeepClone(stmt));
                }
            }
            if (!seenReturnStatement && prevArgName !== void 0) {
                ret.push(factory.createVariableStatement(
                /*modifiers*/
                void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(declareSynthBindingName(prevArgName), 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory.createIdentifier("undefined"))], 2 /* Const */)));
            }
            return ret;
        }
        function transformReturnStatementWithFixablePromiseHandler(transformer, innerRetStmt, hasContinuation, continuationArgName) {
            let innerCbBody = [];
            forEachChild(innerRetStmt, function visit(node) {
                if (isCallExpression(node)) {
                    const temp = transformExpression(node, node, transformer, hasContinuation, continuationArgName);
                    innerCbBody = innerCbBody.concat(temp);
                    if (innerCbBody.length > 0) {
                        return;
                    }
                }
                else if (!isFunctionLike(node)) {
                    forEachChild(node, visit);
                }
            });
            return innerCbBody;
        }
        function getArgBindingName(funcNode, transformer) {
            const types = [];
            let name;
            if (isFunctionLikeDeclaration(funcNode)) {
                if (funcNode.parameters.length > 0) {
                    const param = funcNode.parameters[0].name;
                    name = getMappedBindingNameOrDefault(param);
                }
            }
            else if (isIdentifier(funcNode)) {
                name = getMapEntryOrDefault(funcNode);
            }
            else if (isPropertyAccessExpression(funcNode) && isIdentifier(funcNode.name)) {
                name = getMapEntryOrDefault(funcNode.name);
            }
            if (!name || "identifier" in name && name.identifier.text === "undefined") {
                return void 0;
            }
            return name;
            function getMappedBindingNameOrDefault(bindingName) {
                if (isIdentifier(bindingName))
                    return getMapEntryOrDefault(bindingName);
                const elements = flatMap(bindingName.elements, (element) => {
                    if (isOmittedExpression(element))
                        return [];
                    return [getMappedBindingNameOrDefault(element.name)];
                });
                return createSynthBindingPattern(bindingName, elements);
            }
            function getMapEntryOrDefault(identifier) {
                const originalNode = getOriginalNode2(identifier);
                const symbol = getSymbol2(originalNode);
                if (!symbol) {
                    return createSynthIdentifier(identifier, types);
                }
                const mapEntry = transformer.synthNamesMap.get(getSymbolId(symbol).toString());
                return mapEntry || createSynthIdentifier(identifier, types);
            }
            function getSymbol2(node) {
                var _a2, _b;
                return (_b = (_a2 = tryCast(node, canHaveSymbol)) == null ? void 0 : _a2.symbol) != null ? _b : transformer.checker.getSymbolAtLocation(node);
            }
            function getOriginalNode2(node) {
                return node.original ? node.original : node;
            }
        }
        function isEmptyBindingName(bindingName) {
            if (!bindingName) {
                return true;
            }
            if (isSynthIdentifier(bindingName)) {
                return !bindingName.identifier.text;
            }
            return every(bindingName.elements, isEmptyBindingName);
        }
        function createSynthIdentifier(identifier, types = []) {
            return { kind: 0 /* Identifier */, identifier, types, hasBeenDeclared: false, hasBeenReferenced: false };
        }
        function createSynthBindingPattern(bindingPattern, elements = emptyArray, types = []) {
            return { kind: 1 /* BindingPattern */, bindingPattern, elements, types };
        }
        function referenceSynthIdentifier(synthId) {
            synthId.hasBeenReferenced = true;
            return synthId.identifier;
        }
        function declareSynthBindingName(synthName) {
            return isSynthIdentifier(synthName) ? declareSynthIdentifier(synthName) : declareSynthBindingPattern(synthName);
        }
        function declareSynthBindingPattern(synthPattern) {
            for (const element of synthPattern.elements) {
                declareSynthBindingName(element);
            }
            return synthPattern.bindingPattern;
        }
        function declareSynthIdentifier(synthId) {
            synthId.hasBeenDeclared = true;
            return synthId.identifier;
        }
        function isSynthIdentifier(bindingName) {
            return bindingName.kind === 0 /* Identifier */;
        }
        function isSynthBindingPattern(bindingName) {
            return bindingName.kind === 1 /* BindingPattern */;
        }
        function shouldReturn(expression, transformer) {
            return !!expression.original && transformer.setOfExpressionsToReturn.has(getNodeId(expression.original));
        }
        var fixId10, errorCodes11, codeActionSucceeded;
        var init_convertToAsyncFunction = __esm({
            "src/services/codefixes/convertToAsyncFunction.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId10 = "convertToAsyncFunction";
                errorCodes11 = [Diagnostics.This_may_be_converted_to_an_async_function.code];
                codeActionSucceeded = true;
                registerCodeFix({
                    errorCodes: errorCodes11,
                    getCodeActions(context) {
                        codeActionSucceeded = true;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => convertToAsyncFunction(t, context.sourceFile, context.span.start, context.program.getTypeChecker()));
                        return codeActionSucceeded ? [createCodeFixAction(fixId10, changes, Diagnostics.Convert_to_async_function, fixId10, Diagnostics.Convert_all_to_async_functions)] : [];
                    },
                    fixIds: [fixId10],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes11, (changes, err) => convertToAsyncFunction(changes, err.file, err.start, context.program.getTypeChecker()))
                });
            }
        });
        // src/services/codefixes/convertToEsModule.ts
        function fixImportOfModuleExports(importingFile, exportingFile, changes, quotePreference) {
            for (const moduleSpecifier of importingFile.imports) {
                const imported = getResolvedModule(importingFile, moduleSpecifier.text, getModeForUsageLocation(importingFile, moduleSpecifier));
                if (!imported || imported.resolvedFileName !== exportingFile.fileName) {
                    continue;
                }
                const importNode = importFromModuleSpecifier(moduleSpecifier);
                switch (importNode.kind) {
                    case 268 /* ImportEqualsDeclaration */:
                        changes.replaceNode(importingFile, importNode, makeImport(importNode.name, 
                        /*namedImports*/
                        void 0, moduleSpecifier, quotePreference));
                        break;
                    case 210 /* CallExpression */:
                        if (isRequireCall(importNode, 
                        /*checkArgumentIsStringLiteralLike*/
                        false)) {
                            changes.replaceNode(importingFile, importNode, factory.createPropertyAccessExpression(getSynthesizedDeepClone(importNode), "default"));
                        }
                        break;
                }
            }
        }
        function convertFileToEsModule(sourceFile, checker, changes, target, quotePreference) {
            const identifiers = { original: collectFreeIdentifiers(sourceFile), additional: /* @__PURE__ */ new Set() };
            const exports = collectExportRenames(sourceFile, checker, identifiers);
            convertExportsAccesses(sourceFile, exports, changes);
            let moduleExportsChangedToDefault = false;
            let useSitesToUnqualify;
            for (const statement of filter(sourceFile.statements, isVariableStatement)) {
                const newUseSites = convertVariableStatement(sourceFile, statement, changes, checker, identifiers, target, quotePreference);
                if (newUseSites) {
                    copyEntries(newUseSites, useSitesToUnqualify != null ? useSitesToUnqualify : useSitesToUnqualify = /* @__PURE__ */ new Map());
                }
            }
            for (const statement of filter(sourceFile.statements, (s) => !isVariableStatement(s))) {
                const moduleExportsChanged = convertStatement(sourceFile, statement, checker, changes, identifiers, target, exports, useSitesToUnqualify, quotePreference);
                moduleExportsChangedToDefault = moduleExportsChangedToDefault || moduleExportsChanged;
            }
            useSitesToUnqualify == null ? void 0 : useSitesToUnqualify.forEach((replacement, original) => {
                changes.replaceNode(sourceFile, original, replacement);
            });
            return moduleExportsChangedToDefault;
        }
        function collectExportRenames(sourceFile, checker, identifiers) {
            const res = /* @__PURE__ */ new Map();
            forEachExportReference(sourceFile, (node) => {
                const { text } = node.name;
                if (!res.has(text) && (isIdentifierANonContextualKeyword(node.name) || checker.resolveName(text, node, 111551 /* Value */, 
                /*excludeGlobals*/
                true))) {
                    res.set(text, makeUniqueName(`_${text}`, identifiers));
                }
            });
            return res;
        }
        function convertExportsAccesses(sourceFile, exports, changes) {
            forEachExportReference(sourceFile, (node, isAssignmentLhs) => {
                if (isAssignmentLhs) {
                    return;
                }
                const { text } = node.name;
                changes.replaceNode(sourceFile, node, factory.createIdentifier(exports.get(text) || text));
            });
        }
        function forEachExportReference(sourceFile, cb) {
            sourceFile.forEachChild(function recur(node) {
                if (isPropertyAccessExpression(node) && isExportsOrModuleExportsOrAlias(sourceFile, node.expression) && isIdentifier(node.name)) {
                    const { parent: parent2 } = node;
                    cb(node, isBinaryExpression(parent2) && parent2.left === node && parent2.operatorToken.kind === 63 /* EqualsToken */);
                }
                node.forEachChild(recur);
            });
        }
        function convertStatement(sourceFile, statement, checker, changes, identifiers, target, exports, useSitesToUnqualify, quotePreference) {
            switch (statement.kind) {
                case 240 /* VariableStatement */:
                    convertVariableStatement(sourceFile, statement, changes, checker, identifiers, target, quotePreference);
                    return false;
                case 241 /* ExpressionStatement */: {
                    const { expression } = statement;
                    switch (expression.kind) {
                        case 210 /* CallExpression */: {
                            if (isRequireCall(expression, 
                            /*checkArgumentIsStringLiteralLike*/
                            true)) {
                                changes.replaceNode(sourceFile, statement, makeImport(
                                /*name*/
                                void 0, 
                                /*namedImports*/
                                void 0, expression.arguments[0], quotePreference));
                            }
                            return false;
                        }
                        case 223 /* BinaryExpression */: {
                            const { operatorToken } = expression;
                            return operatorToken.kind === 63 /* EqualsToken */ && convertAssignment(sourceFile, checker, expression, changes, exports, useSitesToUnqualify);
                        }
                    }
                }
                default:
                    return false;
            }
        }
        function convertVariableStatement(sourceFile, statement, changes, checker, identifiers, target, quotePreference) {
            const { declarationList } = statement;
            let foundImport = false;
            const converted = map(declarationList.declarations, (decl) => {
                const { name, initializer } = decl;
                if (initializer) {
                    if (isExportsOrModuleExportsOrAlias(sourceFile, initializer)) {
                        foundImport = true;
                        return convertedImports([]);
                    }
                    else if (isRequireCall(initializer, 
                    /*checkArgumentIsStringLiteralLike*/
                    true)) {
                        foundImport = true;
                        return convertSingleImport(name, initializer.arguments[0], checker, identifiers, target, quotePreference);
                    }
                    else if (isPropertyAccessExpression(initializer) && isRequireCall(initializer.expression, 
                    /*checkArgumentIsStringLiteralLike*/
                    true)) {
                        foundImport = true;
                        return convertPropertyAccessImport(name, initializer.name.text, initializer.expression.arguments[0], identifiers, quotePreference);
                    }
                }
                return convertedImports([factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([decl], declarationList.flags))]);
            });
            if (foundImport) {
                changes.replaceNodeWithNodes(sourceFile, statement, flatMap(converted, (c) => c.newImports));
                let combinedUseSites;
                forEach(converted, (c) => {
                    if (c.useSitesToUnqualify) {
                        copyEntries(c.useSitesToUnqualify, combinedUseSites != null ? combinedUseSites : combinedUseSites = /* @__PURE__ */ new Map());
                    }
                });
                return combinedUseSites;
            }
        }
        function convertPropertyAccessImport(name, propertyName, moduleSpecifier, identifiers, quotePreference) {
            switch (name.kind) {
                case 203 /* ObjectBindingPattern */:
                case 204 /* ArrayBindingPattern */: {
                    const tmp = makeUniqueName(propertyName, identifiers);
                    return convertedImports([
                        makeSingleImport(tmp, propertyName, moduleSpecifier, quotePreference),
                        makeConst(
                        /*modifiers*/
                        void 0, name, factory.createIdentifier(tmp))
                    ]);
                }
                case 79 /* Identifier */:
                    return convertedImports([makeSingleImport(name.text, propertyName, moduleSpecifier, quotePreference)]);
                default:
                    return Debug.assertNever(name, `Convert to ES module got invalid syntax form ${name.kind}`);
            }
        }
        function convertAssignment(sourceFile, checker, assignment, changes, exports, useSitesToUnqualify) {
            const { left, right } = assignment;
            if (!isPropertyAccessExpression(left)) {
                return false;
            }
            if (isExportsOrModuleExportsOrAlias(sourceFile, left)) {
                if (isExportsOrModuleExportsOrAlias(sourceFile, right)) {
                    changes.delete(sourceFile, assignment.parent);
                }
                else {
                    const replacement = isObjectLiteralExpression(right) ? tryChangeModuleExportsObject(right, useSitesToUnqualify) : isRequireCall(right, 
                    /*checkArgumentIsStringLiteralLike*/
                    true) ? convertReExportAll(right.arguments[0], checker) : void 0;
                    if (replacement) {
                        changes.replaceNodeWithNodes(sourceFile, assignment.parent, replacement[0]);
                        return replacement[1];
                    }
                    else {
                        changes.replaceRangeWithText(sourceFile, createRange(left.getStart(sourceFile), right.pos), "export default");
                        return true;
                    }
                }
            }
            else if (isExportsOrModuleExportsOrAlias(sourceFile, left.expression)) {
                convertNamedExport(sourceFile, assignment, changes, exports);
            }
            return false;
        }
        function tryChangeModuleExportsObject(object, useSitesToUnqualify) {
            const statements = mapAllOrFail(object.properties, (prop) => {
                switch (prop.kind) {
                    case 174 /* GetAccessor */:
                    case 175 /* SetAccessor */:
                    case 300 /* ShorthandPropertyAssignment */:
                    case 301 /* SpreadAssignment */:
                        return void 0;
                    case 299 /* PropertyAssignment */:
                        return !isIdentifier(prop.name) ? void 0 : convertExportsDotXEquals_replaceNode(prop.name.text, prop.initializer, useSitesToUnqualify);
                    case 171 /* MethodDeclaration */:
                        return !isIdentifier(prop.name) ? void 0 : functionExpressionToDeclaration(prop.name.text, [factory.createToken(93 /* ExportKeyword */)], prop, useSitesToUnqualify);
                    default:
                        Debug.assertNever(prop, `Convert to ES6 got invalid prop kind ${prop.kind}`);
                }
            });
            return statements && [statements, false];
        }
        function convertNamedExport(sourceFile, assignment, changes, exports) {
            const { text } = assignment.left.name;
            const rename = exports.get(text);
            if (rename !== void 0) {
                const newNodes = [
                    makeConst(
                    /*modifiers*/
                    void 0, rename, assignment.right),
                    makeExportDeclaration([factory.createExportSpecifier(
                        /*isTypeOnly*/
                        false, rename, text)])
                ];
                changes.replaceNodeWithNodes(sourceFile, assignment.parent, newNodes);
            }
            else {
                convertExportsPropertyAssignment(assignment, sourceFile, changes);
            }
        }
        function convertReExportAll(reExported, checker) {
            const moduleSpecifier = reExported.text;
            const moduleSymbol = checker.getSymbolAtLocation(reExported);
            const exports = moduleSymbol ? moduleSymbol.exports : emptyMap;
            return exports.has("export=" /* ExportEquals */) ? [[reExportDefault(moduleSpecifier)], true] : !exports.has("default" /* Default */) ? [[reExportStar(moduleSpecifier)], false] : (
            // If there's some non-default export, must include both `export *` and `export default`.
            exports.size > 1 ? [[reExportStar(moduleSpecifier), reExportDefault(moduleSpecifier)], true] : [[reExportDefault(moduleSpecifier)], true]);
        }
        function reExportStar(moduleSpecifier) {
            return makeExportDeclaration(
            /*exportClause*/
            void 0, moduleSpecifier);
        }
        function reExportDefault(moduleSpecifier) {
            return makeExportDeclaration([factory.createExportSpecifier(
                /*isTypeOnly*/
                false, 
                /*propertyName*/
                void 0, "default")], moduleSpecifier);
        }
        function convertExportsPropertyAssignment({ left, right, parent: parent2 }, sourceFile, changes) {
            const name = left.name.text;
            if ((isFunctionExpression(right) || isArrowFunction(right) || isClassExpression(right)) && (!right.name || right.name.text === name)) {
                changes.replaceRange(sourceFile, { pos: left.getStart(sourceFile), end: right.getStart(sourceFile) }, factory.createToken(93 /* ExportKeyword */), { suffix: " " });
                if (!right.name)
                    changes.insertName(sourceFile, right, name);
                const semi = findChildOfKind(parent2, 26 /* SemicolonToken */, sourceFile);
                if (semi)
                    changes.delete(sourceFile, semi);
            }
            else {
                changes.replaceNodeRangeWithNodes(sourceFile, left.expression, findChildOfKind(left, 24 /* DotToken */, sourceFile), [factory.createToken(93 /* ExportKeyword */), factory.createToken(85 /* ConstKeyword */)], { joiner: " ", suffix: " " });
            }
        }
        function convertExportsDotXEquals_replaceNode(name, exported, useSitesToUnqualify) {
            const modifiers = [factory.createToken(93 /* ExportKeyword */)];
            switch (exported.kind) {
                case 215 /* FunctionExpression */: {
                    const { name: expressionName } = exported;
                    if (expressionName && expressionName.text !== name) {
                        return exportConst();
                    }
                }
                case 216 /* ArrowFunction */:
                    return functionExpressionToDeclaration(name, modifiers, exported, useSitesToUnqualify);
                case 228 /* ClassExpression */:
                    return classExpressionToDeclaration(name, modifiers, exported, useSitesToUnqualify);
                default:
                    return exportConst();
            }
            function exportConst() {
                return makeConst(modifiers, factory.createIdentifier(name), replaceImportUseSites(exported, useSitesToUnqualify));
            }
        }
        function replaceImportUseSites(nodeOrNodes, useSitesToUnqualify) {
            if (!useSitesToUnqualify || !some(arrayFrom(useSitesToUnqualify.keys()), (original) => rangeContainsRange(nodeOrNodes, original))) {
                return nodeOrNodes;
            }
            return isArray(nodeOrNodes) ? getSynthesizedDeepClonesWithReplacements(nodeOrNodes, 
            /*includeTrivia*/
            true, replaceNode) : getSynthesizedDeepCloneWithReplacements(nodeOrNodes, 
            /*includeTrivia*/
            true, replaceNode);
            function replaceNode(original) {
                if (original.kind === 208 /* PropertyAccessExpression */) {
                    const replacement = useSitesToUnqualify.get(original);
                    useSitesToUnqualify.delete(original);
                    return replacement;
                }
            }
        }
        function convertSingleImport(name, moduleSpecifier, checker, identifiers, target, quotePreference) {
            switch (name.kind) {
                case 203 /* ObjectBindingPattern */: {
                    const importSpecifiers = mapAllOrFail(name.elements, (e) => e.dotDotDotToken || e.initializer || e.propertyName && !isIdentifier(e.propertyName) || !isIdentifier(e.name) ? void 0 : makeImportSpecifier(e.propertyName && e.propertyName.text, e.name.text));
                    if (importSpecifiers) {
                        return convertedImports([makeImport(
                            /*name*/
                            void 0, importSpecifiers, moduleSpecifier, quotePreference)]);
                    }
                }
                case 204 /* ArrayBindingPattern */: {
                    const tmp = makeUniqueName(moduleSpecifierToValidIdentifier(moduleSpecifier.text, target), identifiers);
                    return convertedImports([
                        makeImport(factory.createIdentifier(tmp), 
                        /*namedImports*/
                        void 0, moduleSpecifier, quotePreference),
                        makeConst(
                        /*modifiers*/
                        void 0, getSynthesizedDeepClone(name), factory.createIdentifier(tmp))
                    ]);
                }
                case 79 /* Identifier */:
                    return convertSingleIdentifierImport(name, moduleSpecifier, checker, identifiers, quotePreference);
                default:
                    return Debug.assertNever(name, `Convert to ES module got invalid name kind ${name.kind}`);
            }
        }
        function convertSingleIdentifierImport(name, moduleSpecifier, checker, identifiers, quotePreference) {
            const nameSymbol = checker.getSymbolAtLocation(name);
            const namedBindingsNames = /* @__PURE__ */ new Map();
            let needDefaultImport = false;
            let useSitesToUnqualify;
            for (const use of identifiers.original.get(name.text)) {
                if (checker.getSymbolAtLocation(use) !== nameSymbol || use === name) {
                    continue;
                }
                const { parent: parent2 } = use;
                if (isPropertyAccessExpression(parent2)) {
                    const { name: { text: propertyName } } = parent2;
                    if (propertyName === "default") {
                        needDefaultImport = true;
                        const importDefaultName = use.getText();
                        (useSitesToUnqualify != null ? useSitesToUnqualify : useSitesToUnqualify = /* @__PURE__ */ new Map()).set(parent2, factory.createIdentifier(importDefaultName));
                    }
                    else {
                        Debug.assert(parent2.expression === use, "Didn't expect expression === use");
                        let idName = namedBindingsNames.get(propertyName);
                        if (idName === void 0) {
                            idName = makeUniqueName(propertyName, identifiers);
                            namedBindingsNames.set(propertyName, idName);
                        }
                        (useSitesToUnqualify != null ? useSitesToUnqualify : useSitesToUnqualify = /* @__PURE__ */ new Map()).set(parent2, factory.createIdentifier(idName));
                    }
                }
                else {
                    needDefaultImport = true;
                }
            }
            const namedBindings = namedBindingsNames.size === 0 ? void 0 : arrayFrom(mapIterator(namedBindingsNames.entries(), ([propertyName, idName]) => factory.createImportSpecifier(
            /*isTypeOnly*/
            false, propertyName === idName ? void 0 : factory.createIdentifier(propertyName), factory.createIdentifier(idName))));
            if (!namedBindings) {
                needDefaultImport = true;
            }
            return convertedImports([makeImport(needDefaultImport ? getSynthesizedDeepClone(name) : void 0, namedBindings, moduleSpecifier, quotePreference)], useSitesToUnqualify);
        }
        function makeUniqueName(name, identifiers) {
            while (identifiers.original.has(name) || identifiers.additional.has(name)) {
                name = `_${name}`;
            }
            identifiers.additional.add(name);
            return name;
        }
        function collectFreeIdentifiers(file) {
            const map2 = createMultiMap();
            forEachFreeIdentifier(file, (id) => map2.add(id.text, id));
            return map2;
        }
        function forEachFreeIdentifier(node, cb) {
            if (isIdentifier(node) && isFreeIdentifier(node))
                cb(node);
            node.forEachChild((child) => forEachFreeIdentifier(child, cb));
        }
        function isFreeIdentifier(node) {
            const { parent: parent2 } = node;
            switch (parent2.kind) {
                case 208 /* PropertyAccessExpression */:
                    return parent2.name !== node;
                case 205 /* BindingElement */:
                    return parent2.propertyName !== node;
                case 273 /* ImportSpecifier */:
                    return parent2.propertyName !== node;
                default:
                    return true;
            }
        }
        function functionExpressionToDeclaration(name, additionalModifiers, fn, useSitesToUnqualify) {
            return factory.createFunctionDeclaration(concatenate(additionalModifiers, getSynthesizedDeepClones(fn.modifiers)), getSynthesizedDeepClone(fn.asteriskToken), name, getSynthesizedDeepClones(fn.typeParameters), getSynthesizedDeepClones(fn.parameters), getSynthesizedDeepClone(fn.type), factory.converters.convertToFunctionBlock(replaceImportUseSites(fn.body, useSitesToUnqualify)));
        }
        function classExpressionToDeclaration(name, additionalModifiers, cls, useSitesToUnqualify) {
            return factory.createClassDeclaration(concatenate(additionalModifiers, getSynthesizedDeepClones(cls.modifiers)), name, getSynthesizedDeepClones(cls.typeParameters), getSynthesizedDeepClones(cls.heritageClauses), replaceImportUseSites(cls.members, useSitesToUnqualify));
        }
        function makeSingleImport(localName, propertyName, moduleSpecifier, quotePreference) {
            return propertyName === "default" ? makeImport(factory.createIdentifier(localName), 
            /*namedImports*/
            void 0, moduleSpecifier, quotePreference) : makeImport(
            /*name*/
            void 0, [makeImportSpecifier(propertyName, localName)], moduleSpecifier, quotePreference);
        }
        function makeImportSpecifier(propertyName, name) {
            return factory.createImportSpecifier(
            /*isTypeOnly*/
            false, propertyName !== void 0 && propertyName !== name ? factory.createIdentifier(propertyName) : void 0, factory.createIdentifier(name));
        }
        function makeConst(modifiers, name, init) {
            return factory.createVariableStatement(modifiers, factory.createVariableDeclarationList([factory.createVariableDeclaration(name, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, init)], 2 /* Const */));
        }
        function makeExportDeclaration(exportSpecifiers, moduleSpecifier) {
            return factory.createExportDeclaration(
            /*modifiers*/
            void 0, 
            /*isTypeOnly*/
            false, exportSpecifiers && factory.createNamedExports(exportSpecifiers), moduleSpecifier === void 0 ? void 0 : factory.createStringLiteral(moduleSpecifier));
        }
        function convertedImports(newImports, useSitesToUnqualify) {
            return {
                newImports,
                useSitesToUnqualify
            };
        }
        var init_convertToEsModule = __esm({
            "src/services/codefixes/convertToEsModule.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                registerCodeFix({
                    errorCodes: [Diagnostics.File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module.code],
                    getCodeActions(context) {
                        const { sourceFile, program, preferences } = context;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => {
                            const moduleExportsChangedToDefault = convertFileToEsModule(sourceFile, program.getTypeChecker(), changes2, getEmitScriptTarget(program.getCompilerOptions()), getQuotePreference(sourceFile, preferences));
                            if (moduleExportsChangedToDefault) {
                                for (const importingFile of program.getSourceFiles()) {
                                    fixImportOfModuleExports(importingFile, sourceFile, changes2, getQuotePreference(importingFile, preferences));
                                }
                            }
                        });
                        return [createCodeFixActionWithoutFixAll("convertToEsModule", changes, Diagnostics.Convert_to_ES_module)];
                    }
                });
            }
        });
        // src/services/codefixes/correctQualifiedNameToIndexedAccessType.ts
        function getQualifiedName(sourceFile, pos) {
            const qualifiedName = findAncestor(getTokenAtPosition(sourceFile, pos), isQualifiedName);
            Debug.assert(!!qualifiedName, "Expected position to be owned by a qualified name.");
            return isIdentifier(qualifiedName.left) ? qualifiedName : void 0;
        }
        function doChange3(changeTracker, sourceFile, qualifiedName) {
            const rightText = qualifiedName.right.text;
            const replacement = factory.createIndexedAccessTypeNode(factory.createTypeReferenceNode(qualifiedName.left, 
            /*typeArguments*/
            void 0), factory.createLiteralTypeNode(factory.createStringLiteral(rightText)));
            changeTracker.replaceNode(sourceFile, qualifiedName, replacement);
        }
        var fixId11, errorCodes12;
        var init_correctQualifiedNameToIndexedAccessType = __esm({
            "src/services/codefixes/correctQualifiedNameToIndexedAccessType.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId11 = "correctQualifiedNameToIndexedAccessType";
                errorCodes12 = [Diagnostics.Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1.code];
                registerCodeFix({
                    errorCodes: errorCodes12,
                    getCodeActions(context) {
                        const qualifiedName = getQualifiedName(context.sourceFile, context.span.start);
                        if (!qualifiedName)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange3(t, context.sourceFile, qualifiedName));
                        const newText = `${qualifiedName.left.text}["${qualifiedName.right.text}"]`;
                        return [createCodeFixAction(fixId11, changes, [Diagnostics.Rewrite_as_the_indexed_access_type_0, newText], fixId11, Diagnostics.Rewrite_all_as_indexed_access_types)];
                    },
                    fixIds: [fixId11],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes12, (changes, diag2) => {
                        const q = getQualifiedName(diag2.file, diag2.start);
                        if (q) {
                            doChange3(changes, diag2.file, q);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/convertToTypeOnlyExport.ts
        function getExportSpecifierForDiagnosticSpan(span, sourceFile) {
            return tryCast(getTokenAtPosition(sourceFile, span.start).parent, isExportSpecifier);
        }
        function fixSingleExportDeclaration(changes, exportSpecifier, context) {
            if (!exportSpecifier) {
                return;
            }
            const exportClause = exportSpecifier.parent;
            const exportDeclaration = exportClause.parent;
            const typeExportSpecifiers = getTypeExportSpecifiers(exportSpecifier, context);
            if (typeExportSpecifiers.length === exportClause.elements.length) {
                changes.insertModifierBefore(context.sourceFile, 154 /* TypeKeyword */, exportClause);
            }
            else {
                const valueExportDeclaration = factory.updateExportDeclaration(exportDeclaration, exportDeclaration.modifiers, 
                /*isTypeOnly*/
                false, factory.updateNamedExports(exportClause, filter(exportClause.elements, (e) => !contains(typeExportSpecifiers, e))), exportDeclaration.moduleSpecifier, 
                /*assertClause*/
                void 0);
                const typeExportDeclaration = factory.createExportDeclaration(
                /*modifiers*/
                void 0, 
                /*isTypeOnly*/
                true, factory.createNamedExports(typeExportSpecifiers), exportDeclaration.moduleSpecifier, 
                /*assertClause*/
                void 0);
                changes.replaceNode(context.sourceFile, exportDeclaration, valueExportDeclaration, {
                    leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.IncludeAll,
                    trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Exclude
                });
                changes.insertNodeAfter(context.sourceFile, exportDeclaration, typeExportDeclaration);
            }
        }
        function getTypeExportSpecifiers(originExportSpecifier, context) {
            const exportClause = originExportSpecifier.parent;
            if (exportClause.elements.length === 1) {
                return exportClause.elements;
            }
            const diagnostics = getDiagnosticsWithinSpan(createTextSpanFromNode(exportClause), context.program.getSemanticDiagnostics(context.sourceFile, context.cancellationToken));
            return filter(exportClause.elements, (element) => {
                var _a2;
                return element === originExportSpecifier || ((_a2 = findDiagnosticForNode(element, diagnostics)) == null ? void 0 : _a2.code) === errorCodes13[0];
            });
        }
        var errorCodes13, fixId12;
        var init_convertToTypeOnlyExport = __esm({
            "src/services/codefixes/convertToTypeOnlyExport.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes13 = [Diagnostics.Re_exporting_a_type_when_0_is_enabled_requires_using_export_type.code];
                fixId12 = "convertToTypeOnlyExport";
                registerCodeFix({
                    errorCodes: errorCodes13,
                    getCodeActions: function getCodeActionsToConvertToTypeOnlyExport(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => fixSingleExportDeclaration(t, getExportSpecifierForDiagnosticSpan(context.span, context.sourceFile), context));
                        if (changes.length) {
                            return [createCodeFixAction(fixId12, changes, Diagnostics.Convert_to_type_only_export, fixId12, Diagnostics.Convert_all_re_exported_types_to_type_only_exports)];
                        }
                    },
                    fixIds: [fixId12],
                    getAllCodeActions: function getAllCodeActionsToConvertToTypeOnlyExport(context) {
                        const fixedExportDeclarations = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes13, (changes, diag2) => {
                            const exportSpecifier = getExportSpecifierForDiagnosticSpan(diag2, context.sourceFile);
                            if (exportSpecifier && addToSeen(fixedExportDeclarations, getNodeId(exportSpecifier.parent.parent))) {
                                fixSingleExportDeclaration(changes, exportSpecifier, context);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/convertToTypeOnlyImport.ts
        function getDeclaration2(sourceFile, pos) {
            const { parent: parent2 } = getTokenAtPosition(sourceFile, pos);
            return isImportSpecifier(parent2) || isImportDeclaration(parent2) && parent2.importClause ? parent2 : void 0;
        }
        function doChange4(changes, sourceFile, declaration) {
            if (isImportSpecifier(declaration)) {
                changes.replaceNode(sourceFile, declaration, factory.updateImportSpecifier(declaration, 
                /*isTypeOnly*/
                true, declaration.propertyName, declaration.name));
            }
            else {
                const importClause = declaration.importClause;
                if (importClause.name && importClause.namedBindings) {
                    changes.replaceNodeWithNodes(sourceFile, declaration, [
                        factory.createImportDeclaration(getSynthesizedDeepClones(declaration.modifiers, 
                        /*includeTrivia*/
                        true), factory.createImportClause(
                        /*isTypeOnly*/
                        true, getSynthesizedDeepClone(importClause.name, 
                        /*includeTrivia*/
                        true), 
                        /*namedBindings*/
                        void 0), getSynthesizedDeepClone(declaration.moduleSpecifier, 
                        /*includeTrivia*/
                        true), getSynthesizedDeepClone(declaration.assertClause, 
                        /*includeTrivia*/
                        true)),
                        factory.createImportDeclaration(getSynthesizedDeepClones(declaration.modifiers, 
                        /*includeTrivia*/
                        true), factory.createImportClause(
                        /*isTypeOnly*/
                        true, 
                        /*name*/
                        void 0, getSynthesizedDeepClone(importClause.namedBindings, 
                        /*includeTrivia*/
                        true)), getSynthesizedDeepClone(declaration.moduleSpecifier, 
                        /*includeTrivia*/
                        true), getSynthesizedDeepClone(declaration.assertClause, 
                        /*includeTrivia*/
                        true))
                    ]);
                }
                else {
                    const importDeclaration = factory.updateImportDeclaration(declaration, declaration.modifiers, factory.updateImportClause(importClause, 
                    /*isTypeOnly*/
                    true, importClause.name, importClause.namedBindings), declaration.moduleSpecifier, declaration.assertClause);
                    changes.replaceNode(sourceFile, declaration, importDeclaration);
                }
            }
        }
        var errorCodes14, fixId13;
        var init_convertToTypeOnlyImport = __esm({
            "src/services/codefixes/convertToTypeOnlyImport.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes14 = [
                    Diagnostics.This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error.code,
                    Diagnostics._0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled.code
                ];
                fixId13 = "convertToTypeOnlyImport";
                registerCodeFix({
                    errorCodes: errorCodes14,
                    getCodeActions: function getCodeActionsToConvertToTypeOnlyImport(context) {
                        const declaration = getDeclaration2(context.sourceFile, context.span.start);
                        if (declaration) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange4(t, context.sourceFile, declaration));
                            return [createCodeFixAction(fixId13, changes, Diagnostics.Convert_to_type_only_import, fixId13, Diagnostics.Convert_all_imports_not_used_as_a_value_to_type_only_imports)];
                        }
                        return void 0;
                    },
                    fixIds: [fixId13],
                    getAllCodeActions: function getAllCodeActionsToConvertToTypeOnlyImport(context) {
                        return codeFixAll(context, errorCodes14, (changes, diag2) => {
                            const declaration = getDeclaration2(diag2.file, diag2.start);
                            if (declaration) {
                                doChange4(changes, diag2.file, declaration);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/convertLiteralTypeToMappedType.ts
        function getInfo2(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (isIdentifier(token)) {
                const propertySignature = cast(token.parent.parent, isPropertySignature);
                const propertyName = token.getText(sourceFile);
                return {
                    container: cast(propertySignature.parent, isTypeLiteralNode),
                    typeNode: propertySignature.type,
                    constraint: propertyName,
                    name: propertyName === "K" ? "P" : "K"
                };
            }
            return void 0;
        }
        function doChange5(changes, sourceFile, { container, typeNode, constraint, name }) {
            changes.replaceNode(sourceFile, container, factory.createMappedTypeNode(
            /*readonlyToken*/
            void 0, factory.createTypeParameterDeclaration(
            /*modifiers*/
            void 0, name, factory.createTypeReferenceNode(constraint)), 
            /*nameType*/
            void 0, 
            /*questionToken*/
            void 0, typeNode, 
            /*members*/
            void 0));
        }
        var fixId14, errorCodes15;
        var init_convertLiteralTypeToMappedType = __esm({
            "src/services/codefixes/convertLiteralTypeToMappedType.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId14 = "convertLiteralTypeToMappedType";
                errorCodes15 = [Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0.code];
                registerCodeFix({
                    errorCodes: errorCodes15,
                    getCodeActions: function getCodeActionsToConvertLiteralTypeToMappedType(context) {
                        const { sourceFile, span } = context;
                        const info = getInfo2(sourceFile, span.start);
                        if (!info) {
                            return void 0;
                        }
                        const { name, constraint } = info;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange5(t, sourceFile, info));
                        return [createCodeFixAction(fixId14, changes, [Diagnostics.Convert_0_to_1_in_0, constraint, name], fixId14, Diagnostics.Convert_all_type_literals_to_mapped_type)];
                    },
                    fixIds: [fixId14],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes15, (changes, diag2) => {
                        const info = getInfo2(diag2.file, diag2.start);
                        if (info) {
                            doChange5(changes, diag2.file, info);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/fixClassIncorrectlyImplementsInterface.ts
        function getClass(sourceFile, pos) {
            return Debug.checkDefined(getContainingClass(getTokenAtPosition(sourceFile, pos)), "There should be a containing class");
        }
        function symbolPointsToNonPrivateMember(symbol) {
            return !symbol.valueDeclaration || !(getEffectiveModifierFlags(symbol.valueDeclaration) & 8 /* Private */);
        }
        function addMissingDeclarations(context, implementedTypeNode, sourceFile, classDeclaration, changeTracker, preferences) {
            const checker = context.program.getTypeChecker();
            const maybeHeritageClauseSymbol = getHeritageClauseSymbolTable(classDeclaration, checker);
            const implementedType = checker.getTypeAtLocation(implementedTypeNode);
            const implementedTypeSymbols = checker.getPropertiesOfType(implementedType);
            const nonPrivateAndNotExistedInHeritageClauseMembers = implementedTypeSymbols.filter(and(symbolPointsToNonPrivateMember, (symbol) => !maybeHeritageClauseSymbol.has(symbol.escapedName)));
            const classType = checker.getTypeAtLocation(classDeclaration);
            const constructor = find(classDeclaration.members, (m) => isConstructorDeclaration(m));
            if (!classType.getNumberIndexType()) {
                createMissingIndexSignatureDeclaration(implementedType, 1 /* Number */);
            }
            if (!classType.getStringIndexType()) {
                createMissingIndexSignatureDeclaration(implementedType, 0 /* String */);
            }
            const importAdder = createImportAdder(sourceFile, context.program, preferences, context.host);
            createMissingMemberNodes(classDeclaration, nonPrivateAndNotExistedInHeritageClauseMembers, sourceFile, context, preferences, importAdder, (member) => insertInterfaceMemberNode(sourceFile, classDeclaration, member));
            importAdder.writeFixes(changeTracker);
            function createMissingIndexSignatureDeclaration(type, kind) {
                const indexInfoOfKind = checker.getIndexInfoOfType(type, kind);
                if (indexInfoOfKind) {
                    insertInterfaceMemberNode(sourceFile, classDeclaration, checker.indexInfoToIndexSignatureDeclaration(indexInfoOfKind, classDeclaration, 
                    /*flags*/
                    void 0, getNoopSymbolTrackerWithResolver(context)));
                }
            }
            function insertInterfaceMemberNode(sourceFile2, cls, newElement) {
                if (constructor) {
                    changeTracker.insertNodeAfter(sourceFile2, constructor, newElement);
                }
                else {
                    changeTracker.insertMemberAtStart(sourceFile2, cls, newElement);
                }
            }
        }
        function getHeritageClauseSymbolTable(classDeclaration, checker) {
            const heritageClauseNode = getEffectiveBaseTypeNode(classDeclaration);
            if (!heritageClauseNode)
                return createSymbolTable();
            const heritageClauseType = checker.getTypeAtLocation(heritageClauseNode);
            const heritageClauseTypeSymbols = checker.getPropertiesOfType(heritageClauseType);
            return createSymbolTable(heritageClauseTypeSymbols.filter(symbolPointsToNonPrivateMember));
        }
        var errorCodes16, fixId15;
        var init_fixClassIncorrectlyImplementsInterface = __esm({
            "src/services/codefixes/fixClassIncorrectlyImplementsInterface.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes16 = [
                    Diagnostics.Class_0_incorrectly_implements_interface_1.code,
                    Diagnostics.Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass.code
                ];
                fixId15 = "fixClassIncorrectlyImplementsInterface";
                registerCodeFix({
                    errorCodes: errorCodes16,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const classDeclaration = getClass(sourceFile, span.start);
                        return mapDefined(getEffectiveImplementsTypeNodes(classDeclaration), (implementedTypeNode) => {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingDeclarations(context, implementedTypeNode, sourceFile, classDeclaration, t, context.preferences));
                            return changes.length === 0 ? void 0 : createCodeFixAction(fixId15, changes, [Diagnostics.Implement_interface_0, implementedTypeNode.getText(sourceFile)], fixId15, Diagnostics.Implement_all_unimplemented_interfaces);
                        });
                    },
                    fixIds: [fixId15],
                    getAllCodeActions(context) {
                        const seenClassDeclarations = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes16, (changes, diag2) => {
                            const classDeclaration = getClass(diag2.file, diag2.start);
                            if (addToSeen(seenClassDeclarations, getNodeId(classDeclaration))) {
                                for (const implementedTypeNode of getEffectiveImplementsTypeNodes(classDeclaration)) {
                                    addMissingDeclarations(context, implementedTypeNode, diag2.file, classDeclaration, changes, context.preferences);
                                }
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/importFixes.ts
        function createImportAdder(sourceFile, program, preferences, host, cancellationToken) {
            return createImportAdderWorker(sourceFile, program, 
            /*useAutoImportProvider*/
            false, preferences, host, cancellationToken);
        }
        function createImportAdderWorker(sourceFile, program, useAutoImportProvider, preferences, host, cancellationToken) {
            const compilerOptions = program.getCompilerOptions();
            const addToNamespace = [];
            const importType = [];
            const addToExisting = /* @__PURE__ */ new Map();
            const newImports = /* @__PURE__ */ new Map();
            return { addImportFromDiagnostic, addImportFromExportedSymbol, writeFixes, hasFixes };
            function addImportFromDiagnostic(diagnostic, context) {
                const info = getFixInfos(context, diagnostic.code, diagnostic.start, useAutoImportProvider);
                if (!info || !info.length)
                    return;
                addImport(first(info));
            }
            function addImportFromExportedSymbol(exportedSymbol, isValidTypeOnlyUseSite) {
                const moduleSymbol = Debug.checkDefined(exportedSymbol.parent);
                const symbolName2 = getNameForExportedSymbol(exportedSymbol, getEmitScriptTarget(compilerOptions));
                const checker = program.getTypeChecker();
                const symbol = checker.getMergedSymbol(skipAlias(exportedSymbol, checker));
                const exportInfo = getAllExportInfoForSymbol(sourceFile, symbol, symbolName2, moduleSymbol, 
                /*isJsxTagName*/
                false, program, host, preferences, cancellationToken);
                const useRequire = shouldUseRequire(sourceFile, program);
                const fix = getImportFixForSymbol(sourceFile, Debug.checkDefined(exportInfo), program, 
                /*position*/
                void 0, !!isValidTypeOnlyUseSite, useRequire, host, preferences);
                if (fix) {
                    addImport({ fix, symbolName: symbolName2, errorIdentifierText: void 0 });
                }
            }
            function addImport(info) {
                var _a2, _b;
                const { fix, symbolName: symbolName2 } = info;
                switch (fix.kind) {
                    case 0 /* UseNamespace */:
                        addToNamespace.push(fix);
                        break;
                    case 1 /* JsdocTypeImport */:
                        importType.push(fix);
                        break;
                    case 2 /* AddToExisting */: {
                        const { importClauseOrBindingPattern, importKind, addAsTypeOnly } = fix;
                        const key = String(getNodeId(importClauseOrBindingPattern));
                        let entry = addToExisting.get(key);
                        if (!entry) {
                            addToExisting.set(key, entry = { importClauseOrBindingPattern, defaultImport: void 0, namedImports: /* @__PURE__ */ new Map() });
                        }
                        if (importKind === 0 /* Named */) {
                            const prevValue = entry == null ? void 0 : entry.namedImports.get(symbolName2);
                            entry.namedImports.set(symbolName2, reduceAddAsTypeOnlyValues(prevValue, addAsTypeOnly));
                        }
                        else {
                            Debug.assert(entry.defaultImport === void 0 || entry.defaultImport.name === symbolName2, "(Add to Existing) Default import should be missing or match symbolName");
                            entry.defaultImport = {
                                name: symbolName2,
                                addAsTypeOnly: reduceAddAsTypeOnlyValues((_a2 = entry.defaultImport) == null ? void 0 : _a2.addAsTypeOnly, addAsTypeOnly)
                            };
                        }
                        break;
                    }
                    case 3 /* AddNew */: {
                        const { moduleSpecifier, importKind, useRequire, addAsTypeOnly } = fix;
                        const entry = getNewImportEntry(moduleSpecifier, importKind, useRequire, addAsTypeOnly);
                        Debug.assert(entry.useRequire === useRequire, "(Add new) Tried to add an `import` and a `require` for the same module");
                        switch (importKind) {
                            case 1 /* Default */:
                                Debug.assert(entry.defaultImport === void 0 || entry.defaultImport.name === symbolName2, "(Add new) Default import should be missing or match symbolName");
                                entry.defaultImport = { name: symbolName2, addAsTypeOnly: reduceAddAsTypeOnlyValues((_b = entry.defaultImport) == null ? void 0 : _b.addAsTypeOnly, addAsTypeOnly) };
                                break;
                            case 0 /* Named */:
                                const prevValue = (entry.namedImports || (entry.namedImports = /* @__PURE__ */ new Map())).get(symbolName2);
                                entry.namedImports.set(symbolName2, reduceAddAsTypeOnlyValues(prevValue, addAsTypeOnly));
                                break;
                            case 3 /* CommonJS */:
                            case 2 /* Namespace */:
                                Debug.assert(entry.namespaceLikeImport === void 0 || entry.namespaceLikeImport.name === symbolName2, "Namespacelike import shoudl be missing or match symbolName");
                                entry.namespaceLikeImport = { importKind, name: symbolName2, addAsTypeOnly };
                                break;
                        }
                        break;
                    }
                    case 4 /* PromoteTypeOnly */:
                        break;
                    default:
                        Debug.assertNever(fix, `fix wasn't never - got kind ${fix.kind}`);
                }
                function reduceAddAsTypeOnlyValues(prevValue, newValue) {
                    return Math.max(prevValue != null ? prevValue : 0, newValue);
                }
                function getNewImportEntry(moduleSpecifier, importKind, useRequire, addAsTypeOnly) {
                    const typeOnlyKey = newImportsKey(moduleSpecifier, 
                    /*topLevelTypeOnly*/
                    true);
                    const nonTypeOnlyKey = newImportsKey(moduleSpecifier, 
                    /*topLevelTypeOnly*/
                    false);
                    const typeOnlyEntry = newImports.get(typeOnlyKey);
                    const nonTypeOnlyEntry = newImports.get(nonTypeOnlyKey);
                    const newEntry = {
                        defaultImport: void 0,
                        namedImports: void 0,
                        namespaceLikeImport: void 0,
                        useRequire
                    };
                    if (importKind === 1 /* Default */ && addAsTypeOnly === 2 /* Required */) {
                        if (typeOnlyEntry)
                            return typeOnlyEntry;
                        newImports.set(typeOnlyKey, newEntry);
                        return newEntry;
                    }
                    if (addAsTypeOnly === 1 /* Allowed */ && (typeOnlyEntry || nonTypeOnlyEntry)) {
                        return typeOnlyEntry || nonTypeOnlyEntry;
                    }
                    if (nonTypeOnlyEntry) {
                        return nonTypeOnlyEntry;
                    }
                    newImports.set(nonTypeOnlyKey, newEntry);
                    return newEntry;
                }
                function newImportsKey(moduleSpecifier, topLevelTypeOnly) {
                    return `${topLevelTypeOnly ? 1 : 0}|${moduleSpecifier}`;
                }
            }
            function writeFixes(changeTracker) {
                const quotePreference = getQuotePreference(sourceFile, preferences);
                for (const fix of addToNamespace) {
                    addNamespaceQualifier(changeTracker, sourceFile, fix);
                }
                for (const fix of importType) {
                    addImportType(changeTracker, sourceFile, fix, quotePreference);
                }
                addToExisting.forEach(({ importClauseOrBindingPattern, defaultImport, namedImports }) => {
                    doAddExistingFix(changeTracker, sourceFile, importClauseOrBindingPattern, defaultImport, arrayFrom(namedImports.entries(), ([name, addAsTypeOnly]) => ({ addAsTypeOnly, name })), compilerOptions, preferences);
                });
                let newDeclarations;
                newImports.forEach(({ useRequire, defaultImport, namedImports, namespaceLikeImport }, key) => {
                    const moduleSpecifier = key.slice(2);
                    const getDeclarations = useRequire ? getNewRequires : getNewImports;
                    const declarations = getDeclarations(moduleSpecifier, quotePreference, defaultImport, namedImports && arrayFrom(namedImports.entries(), ([name, addAsTypeOnly]) => ({ addAsTypeOnly, name })), namespaceLikeImport, compilerOptions);
                    newDeclarations = combine(newDeclarations, declarations);
                });
                if (newDeclarations) {
                    insertImports(changeTracker, sourceFile, newDeclarations, 
                    /*blankLineBetween*/
                    true, preferences);
                }
            }
            function hasFixes() {
                return addToNamespace.length > 0 || importType.length > 0 || addToExisting.size > 0 || newImports.size > 0;
            }
        }
        function createImportSpecifierResolver(importingFile, program, host, preferences) {
            const packageJsonImportFilter = createPackageJsonImportFilter(importingFile, preferences, host);
            const importMap = createExistingImportMap(program.getTypeChecker(), importingFile, program.getCompilerOptions());
            return { getModuleSpecifierForBestExportInfo };
            function getModuleSpecifierForBestExportInfo(exportInfo, position, isValidTypeOnlyUseSite, fromCacheOnly) {
                const { fixes, computedWithoutCacheCount } = getImportFixes(exportInfo, position, isValidTypeOnlyUseSite, 
                /*useRequire*/
                false, program, importingFile, host, preferences, importMap, fromCacheOnly);
                const result = getBestFix(fixes, importingFile, program, packageJsonImportFilter, host);
                return result && { ...result, computedWithoutCacheCount };
            }
        }
        function getImportCompletionAction(targetSymbol, moduleSymbol, exportMapKey, sourceFile, symbolName2, isJsxTagName, host, program, formatContext, position, preferences, cancellationToken) {
            const compilerOptions = program.getCompilerOptions();
            let exportInfos;
            if (exportMapKey) {
                exportInfos = getExportInfoMap(sourceFile, host, program, preferences, cancellationToken).get(sourceFile.path, exportMapKey);
                Debug.assertIsDefined(exportInfos, "Some exportInfo should match the specified exportMapKey");
            }
            else {
                exportInfos = pathIsBareSpecifier(stripQuotes(moduleSymbol.name)) ? [getSingleExportInfoForSymbol(targetSymbol, symbolName2, moduleSymbol, program, host)] : getAllExportInfoForSymbol(sourceFile, targetSymbol, symbolName2, moduleSymbol, isJsxTagName, program, host, preferences, cancellationToken);
                Debug.assertIsDefined(exportInfos, "Some exportInfo should match the specified symbol / moduleSymbol");
            }
            const useRequire = shouldUseRequire(sourceFile, program);
            const isValidTypeOnlyUseSite = isValidTypeOnlyAliasUseSite(getTokenAtPosition(sourceFile, position));
            const fix = Debug.checkDefined(getImportFixForSymbol(sourceFile, exportInfos, program, position, isValidTypeOnlyUseSite, useRequire, host, preferences));
            return {
                moduleSpecifier: fix.moduleSpecifier,
                codeAction: codeFixActionToCodeAction(codeActionForFix({ host, formatContext, preferences }, sourceFile, symbolName2, fix, 
                /*includeSymbolNameInDescription*/
                false, compilerOptions, preferences))
            };
        }
        function getPromoteTypeOnlyCompletionAction(sourceFile, symbolToken, program, host, formatContext, preferences) {
            const compilerOptions = program.getCompilerOptions();
            const symbolName2 = single(getSymbolNamesToImport(sourceFile, program.getTypeChecker(), symbolToken, compilerOptions));
            const fix = getTypeOnlyPromotionFix(sourceFile, symbolToken, symbolName2, program);
            const includeSymbolNameInDescription = symbolName2 !== symbolToken.text;
            return fix && codeFixActionToCodeAction(codeActionForFix({ host, formatContext, preferences }, sourceFile, symbolName2, fix, includeSymbolNameInDescription, compilerOptions, preferences));
        }
        function getImportFixForSymbol(sourceFile, exportInfos, program, position, isValidTypeOnlyUseSite, useRequire, host, preferences) {
            const packageJsonImportFilter = createPackageJsonImportFilter(sourceFile, preferences, host);
            return getBestFix(getImportFixes(exportInfos, position, isValidTypeOnlyUseSite, useRequire, program, sourceFile, host, preferences).fixes, sourceFile, program, packageJsonImportFilter, host);
        }
        function codeFixActionToCodeAction({ description: description2, changes, commands }) {
            return { description: description2, changes, commands };
        }
        function getAllExportInfoForSymbol(importingFile, symbol, symbolName2, moduleSymbol, preferCapitalized, program, host, preferences, cancellationToken) {
            const getChecker = createGetChecker(program, host);
            return getExportInfoMap(importingFile, host, program, preferences, cancellationToken).search(importingFile.path, preferCapitalized, (name) => name === symbolName2, (info) => {
                if (skipAlias(info[0].symbol, getChecker(info[0].isFromPackageJson)) === symbol && info.some((i) => i.moduleSymbol === moduleSymbol || i.symbol.parent === moduleSymbol)) {
                    return info;
                }
            });
        }
        function getSingleExportInfoForSymbol(symbol, symbolName2, moduleSymbol, program, host) {
            var _a2, _b;
            const compilerOptions = program.getCompilerOptions();
            const mainProgramInfo = getInfoWithChecker(program.getTypeChecker(), 
            /*isFromPackageJson*/
            false);
            if (mainProgramInfo) {
                return mainProgramInfo;
            }
            const autoImportProvider = (_b = (_a2 = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a2.call(host)) == null ? void 0 : _b.getTypeChecker();
            return Debug.checkDefined(autoImportProvider && getInfoWithChecker(autoImportProvider, 
            /*isFromPackageJson*/
            true), `Could not find symbol in specified module for code actions`);
            function getInfoWithChecker(checker, isFromPackageJson) {
                const defaultInfo = getDefaultLikeExportInfo(moduleSymbol, checker, compilerOptions);
                if (defaultInfo && skipAlias(defaultInfo.symbol, checker) === symbol) {
                    return { symbol: defaultInfo.symbol, moduleSymbol, moduleFileName: void 0, exportKind: defaultInfo.exportKind, targetFlags: skipAlias(symbol, checker).flags, isFromPackageJson };
                }
                const named = checker.tryGetMemberInModuleExportsAndProperties(symbolName2, moduleSymbol);
                if (named && skipAlias(named, checker) === symbol) {
                    return { symbol: named, moduleSymbol, moduleFileName: void 0, exportKind: 0 /* Named */, targetFlags: skipAlias(symbol, checker).flags, isFromPackageJson };
                }
            }
        }
        function getImportFixes(exportInfos, usagePosition, isValidTypeOnlyUseSite, useRequire, program, sourceFile, host, preferences, importMap = createExistingImportMap(program.getTypeChecker(), sourceFile, program.getCompilerOptions()), fromCacheOnly) {
            const checker = program.getTypeChecker();
            const existingImports = flatMap(exportInfos, importMap.getImportsForExportInfo);
            const useNamespace = usagePosition !== void 0 && tryUseExistingNamespaceImport(existingImports, usagePosition);
            const addToExisting = tryAddToExistingImport(existingImports, isValidTypeOnlyUseSite, checker, program.getCompilerOptions());
            if (addToExisting) {
                return {
                    computedWithoutCacheCount: 0,
                    fixes: [...useNamespace ? [useNamespace] : emptyArray, addToExisting]
                };
            }
            const { fixes, computedWithoutCacheCount = 0 } = getFixesForAddImport(exportInfos, existingImports, program, sourceFile, usagePosition, isValidTypeOnlyUseSite, useRequire, host, preferences, fromCacheOnly);
            return {
                computedWithoutCacheCount,
                fixes: [...useNamespace ? [useNamespace] : emptyArray, ...fixes]
            };
        }
        function tryUseExistingNamespaceImport(existingImports, position) {
            return firstDefined(existingImports, ({ declaration, importKind }) => {
                var _a2;
                if (importKind !== 0 /* Named */)
                    return void 0;
                const namespacePrefix = getNamespaceLikeImportText(declaration);
                const moduleSpecifier = namespacePrefix && ((_a2 = tryGetModuleSpecifierFromDeclaration(declaration)) == null ? void 0 : _a2.text);
                if (moduleSpecifier) {
                    return { kind: 0 /* UseNamespace */, namespacePrefix, usagePosition: position, moduleSpecifier };
                }
            });
        }
        function getNamespaceLikeImportText(declaration) {
            var _a2, _b, _c;
            switch (declaration.kind) {
                case 257 /* VariableDeclaration */:
                    return (_a2 = tryCast(declaration.name, isIdentifier)) == null ? void 0 : _a2.text;
                case 268 /* ImportEqualsDeclaration */:
                    return declaration.name.text;
                case 269 /* ImportDeclaration */:
                    return (_c = tryCast((_b = declaration.importClause) == null ? void 0 : _b.namedBindings, isNamespaceImport)) == null ? void 0 : _c.name.text;
                default:
                    return Debug.assertNever(declaration);
            }
        }
        function getAddAsTypeOnly(isValidTypeOnlyUseSite, isForNewImportDeclaration, symbol, targetFlags, checker, compilerOptions) {
            if (!isValidTypeOnlyUseSite) {
                return 4 /* NotAllowed */;
            }
            if (isForNewImportDeclaration && compilerOptions.importsNotUsedAsValues === 2 /* Error */) {
                return 2 /* Required */;
            }
            if (importNameElisionDisabled(compilerOptions) && (!(targetFlags & 111551 /* Value */) || !!checker.getTypeOnlyAliasDeclaration(symbol))) {
                return 2 /* Required */;
            }
            return 1 /* Allowed */;
        }
        function tryAddToExistingImport(existingImports, isValidTypeOnlyUseSite, checker, compilerOptions) {
            return firstDefined(existingImports, ({ declaration, importKind, symbol, targetFlags }) => {
                if (importKind === 3 /* CommonJS */ || importKind === 2 /* Namespace */ || declaration.kind === 268 /* ImportEqualsDeclaration */) {
                    return void 0;
                }
                if (declaration.kind === 257 /* VariableDeclaration */) {
                    return (importKind === 0 /* Named */ || importKind === 1 /* Default */) && declaration.name.kind === 203 /* ObjectBindingPattern */ ? { kind: 2 /* AddToExisting */, importClauseOrBindingPattern: declaration.name, importKind, moduleSpecifier: declaration.initializer.arguments[0].text, addAsTypeOnly: 4 /* NotAllowed */ } : void 0;
                }
                const { importClause } = declaration;
                if (!importClause || !isStringLiteralLike(declaration.moduleSpecifier))
                    return void 0;
                const { name, namedBindings } = importClause;
                if (importClause.isTypeOnly && !(importKind === 0 /* Named */ && namedBindings))
                    return void 0;
                const addAsTypeOnly = getAddAsTypeOnly(isValidTypeOnlyUseSite, 
                /*isForNewImportDeclaration*/
                false, symbol, targetFlags, checker, compilerOptions);
                if (importKind === 1 /* Default */ && (name || // Cannot add a default import to a declaration that already has one
                    addAsTypeOnly === 2 /* Required */ && namedBindings))
                    return void 0;
                if (importKind === 0 /* Named */ && (namedBindings == null ? void 0 : namedBindings.kind) === 271 /* NamespaceImport */)
                    return void 0;
                return {
                    kind: 2 /* AddToExisting */,
                    importClauseOrBindingPattern: importClause,
                    importKind,
                    moduleSpecifier: declaration.moduleSpecifier.text,
                    addAsTypeOnly
                };
            });
        }
        function createExistingImportMap(checker, importingFile, compilerOptions) {
            let importMap;
            for (const moduleSpecifier of importingFile.imports) {
                const i = importFromModuleSpecifier(moduleSpecifier);
                if (isVariableDeclarationInitializedToRequire(i.parent)) {
                    const moduleSymbol = checker.resolveExternalModuleName(moduleSpecifier);
                    if (moduleSymbol) {
                        (importMap || (importMap = createMultiMap())).add(getSymbolId(moduleSymbol), i.parent);
                    }
                }
                else if (i.kind === 269 /* ImportDeclaration */ || i.kind === 268 /* ImportEqualsDeclaration */) {
                    const moduleSymbol = checker.getSymbolAtLocation(moduleSpecifier);
                    if (moduleSymbol) {
                        (importMap || (importMap = createMultiMap())).add(getSymbolId(moduleSymbol), i);
                    }
                }
            }
            return {
                getImportsForExportInfo: ({ moduleSymbol, exportKind, targetFlags, symbol }) => {
                    if (!(targetFlags & 111551 /* Value */) && isSourceFileJS(importingFile))
                        return emptyArray;
                    const matchingDeclarations = importMap == null ? void 0 : importMap.get(getSymbolId(moduleSymbol));
                    if (!matchingDeclarations)
                        return emptyArray;
                    const importKind = getImportKind(importingFile, exportKind, compilerOptions);
                    return matchingDeclarations.map((declaration) => ({ declaration, importKind, symbol, targetFlags }));
                }
            };
        }
        function shouldUseRequire(sourceFile, program) {
            if (!isSourceFileJS(sourceFile)) {
                return false;
            }
            if (sourceFile.commonJsModuleIndicator && !sourceFile.externalModuleIndicator)
                return true;
            if (sourceFile.externalModuleIndicator && !sourceFile.commonJsModuleIndicator)
                return false;
            const compilerOptions = program.getCompilerOptions();
            if (compilerOptions.configFile) {
                return getEmitModuleKind(compilerOptions) < 5 /* ES2015 */;
            }
            for (const otherFile of program.getSourceFiles()) {
                if (otherFile === sourceFile || !isSourceFileJS(otherFile) || program.isSourceFileFromExternalLibrary(otherFile))
                    continue;
                if (otherFile.commonJsModuleIndicator && !otherFile.externalModuleIndicator)
                    return true;
                if (otherFile.externalModuleIndicator && !otherFile.commonJsModuleIndicator)
                    return false;
            }
            return true;
        }
        function createGetChecker(program, host) {
            return memoizeOne((isFromPackageJson) => isFromPackageJson ? host.getPackageJsonAutoImportProvider().getTypeChecker() : program.getTypeChecker());
        }
        function getNewImportFixes(program, sourceFile, usagePosition, isValidTypeOnlyUseSite, useRequire, exportInfo, host, preferences, fromCacheOnly) {
            const isJs = isSourceFileJS(sourceFile);
            const compilerOptions = program.getCompilerOptions();
            const moduleSpecifierResolutionHost = createModuleSpecifierResolutionHost(program, host);
            const getChecker = createGetChecker(program, host);
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            const rejectNodeModulesRelativePaths = moduleResolutionUsesNodeModules(moduleResolution);
            const getModuleSpecifiers2 = fromCacheOnly ? (moduleSymbol) => ({ moduleSpecifiers: ts_moduleSpecifiers_exports.tryGetModuleSpecifiersFromCache(moduleSymbol, sourceFile, moduleSpecifierResolutionHost, preferences), computedWithoutCache: false }) : (moduleSymbol, checker) => ts_moduleSpecifiers_exports.getModuleSpecifiersWithCacheInfo(moduleSymbol, checker, compilerOptions, sourceFile, moduleSpecifierResolutionHost, preferences);
            let computedWithoutCacheCount = 0;
            const fixes = flatMap(exportInfo, (exportInfo2, i) => {
                const checker = getChecker(exportInfo2.isFromPackageJson);
                const { computedWithoutCache, moduleSpecifiers } = getModuleSpecifiers2(exportInfo2.moduleSymbol, checker);
                const importedSymbolHasValueMeaning = !!(exportInfo2.targetFlags & 111551 /* Value */);
                const addAsTypeOnly = getAddAsTypeOnly(isValidTypeOnlyUseSite, 
                /*isForNewImportDeclaration*/
                true, exportInfo2.symbol, exportInfo2.targetFlags, checker, compilerOptions);
                computedWithoutCacheCount += computedWithoutCache ? 1 : 0;
                return mapDefined(moduleSpecifiers, (moduleSpecifier) => {
                    var _a2;
                    if (rejectNodeModulesRelativePaths && pathContainsNodeModules(moduleSpecifier)) {
                        return void 0;
                    }
                    if (!importedSymbolHasValueMeaning && isJs && usagePosition !== void 0) {
                        return { kind: 1 /* JsdocTypeImport */, moduleSpecifier, usagePosition, exportInfo: exportInfo2, isReExport: i > 0 };
                    }
                    const importKind = getImportKind(sourceFile, exportInfo2.exportKind, compilerOptions);
                    let qualification;
                    if (usagePosition !== void 0 && importKind === 3 /* CommonJS */ && exportInfo2.exportKind === 0 /* Named */) {
                        const exportEquals = checker.resolveExternalModuleSymbol(exportInfo2.moduleSymbol);
                        let namespacePrefix;
                        if (exportEquals !== exportInfo2.moduleSymbol) {
                            namespacePrefix = (_a2 = getDefaultExportInfoWorker(exportEquals, checker, compilerOptions)) == null ? void 0 : _a2.name;
                        }
                        namespacePrefix || (namespacePrefix = moduleSymbolToValidIdentifier(exportInfo2.moduleSymbol, getEmitScriptTarget(compilerOptions), 
                        /*forceCapitalize*/
                        false));
                        qualification = { namespacePrefix, usagePosition };
                    }
                    return {
                        kind: 3 /* AddNew */,
                        moduleSpecifier,
                        importKind,
                        useRequire,
                        addAsTypeOnly,
                        exportInfo: exportInfo2,
                        isReExport: i > 0,
                        qualification
                    };
                });
            });
            return { computedWithoutCacheCount, fixes };
        }
        function getFixesForAddImport(exportInfos, existingImports, program, sourceFile, usagePosition, isValidTypeOnlyUseSite, useRequire, host, preferences, fromCacheOnly) {
            const existingDeclaration = firstDefined(existingImports, (info) => newImportInfoFromExistingSpecifier(info, isValidTypeOnlyUseSite, useRequire, program.getTypeChecker(), program.getCompilerOptions()));
            return existingDeclaration ? { fixes: [existingDeclaration] } : getNewImportFixes(program, sourceFile, usagePosition, isValidTypeOnlyUseSite, useRequire, exportInfos, host, preferences, fromCacheOnly);
        }
        function newImportInfoFromExistingSpecifier({ declaration, importKind, symbol, targetFlags }, isValidTypeOnlyUseSite, useRequire, checker, compilerOptions) {
            var _a2;
            const moduleSpecifier = (_a2 = tryGetModuleSpecifierFromDeclaration(declaration)) == null ? void 0 : _a2.text;
            if (moduleSpecifier) {
                const addAsTypeOnly = useRequire ? 4 /* NotAllowed */ : getAddAsTypeOnly(isValidTypeOnlyUseSite, 
                /*isForNewImportDeclaration*/
                true, symbol, targetFlags, checker, compilerOptions);
                return { kind: 3 /* AddNew */, moduleSpecifier, importKind, addAsTypeOnly, useRequire };
            }
        }
        function getFixInfos(context, errorCode, pos, useAutoImportProvider) {
            const symbolToken = getTokenAtPosition(context.sourceFile, pos);
            let info;
            if (errorCode === Diagnostics._0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead.code) {
                info = getFixesInfoForUMDImport(context, symbolToken);
            }
            else if (!isIdentifier(symbolToken)) {
                return void 0;
            }
            else if (errorCode === Diagnostics._0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type.code) {
                const symbolName2 = single(getSymbolNamesToImport(context.sourceFile, context.program.getTypeChecker(), symbolToken, context.program.getCompilerOptions()));
                const fix = getTypeOnlyPromotionFix(context.sourceFile, symbolToken, symbolName2, context.program);
                return fix && [{ fix, symbolName: symbolName2, errorIdentifierText: symbolToken.text }];
            }
            else {
                info = getFixesInfoForNonUMDImport(context, symbolToken, useAutoImportProvider);
            }
            const packageJsonImportFilter = createPackageJsonImportFilter(context.sourceFile, context.preferences, context.host);
            return info && sortFixInfo(info, context.sourceFile, context.program, packageJsonImportFilter, context.host);
        }
        function sortFixInfo(fixes, sourceFile, program, packageJsonImportFilter, host) {
            const _toPath = (fileName) => toPath(fileName, host.getCurrentDirectory(), hostGetCanonicalFileName(host));
            return sort(fixes, (a, b) => compareBooleans(!!a.isJsxNamespaceFix, !!b.isJsxNamespaceFix) || compareValues(a.fix.kind, b.fix.kind) || compareModuleSpecifiers(a.fix, b.fix, sourceFile, program, packageJsonImportFilter.allowsImportingSpecifier, _toPath));
        }
        function getBestFix(fixes, sourceFile, program, packageJsonImportFilter, host) {
            if (!some(fixes))
                return;
            if (fixes[0].kind === 0 /* UseNamespace */ || fixes[0].kind === 2 /* AddToExisting */) {
                return fixes[0];
            }
            return fixes.reduce((best, fix) => (
            // Takes true branch of conditional if `fix` is better than `best`
            compareModuleSpecifiers(fix, best, sourceFile, program, packageJsonImportFilter.allowsImportingSpecifier, (fileName) => toPath(fileName, host.getCurrentDirectory(), hostGetCanonicalFileName(host))) === -1 /* LessThan */ ? fix : best));
        }
        function compareModuleSpecifiers(a, b, importingFile, program, allowsImportingSpecifier, toPath3) {
            if (a.kind !== 0 /* UseNamespace */ && b.kind !== 0 /* UseNamespace */) {
                return compareBooleans(allowsImportingSpecifier(b.moduleSpecifier), allowsImportingSpecifier(a.moduleSpecifier)) || compareNodeCoreModuleSpecifiers(a.moduleSpecifier, b.moduleSpecifier, importingFile, program) || compareBooleans(isFixPossiblyReExportingImportingFile(a, importingFile, program.getCompilerOptions(), toPath3), isFixPossiblyReExportingImportingFile(b, importingFile, program.getCompilerOptions(), toPath3)) || compareNumberOfDirectorySeparators(a.moduleSpecifier, b.moduleSpecifier);
            }
            return 0 /* EqualTo */;
        }
        function isFixPossiblyReExportingImportingFile(fix, importingFile, compilerOptions, toPath3) {
            var _a2;
            if (fix.isReExport && ((_a2 = fix.exportInfo) == null ? void 0 : _a2.moduleFileName) && getEmitModuleResolutionKind(compilerOptions) === 2 /* Node10 */ && isIndexFileName(fix.exportInfo.moduleFileName)) {
                const reExportDir = toPath3(getDirectoryPath(fix.exportInfo.moduleFileName));
                return startsWith(importingFile.path, reExportDir);
            }
            return false;
        }
        function isIndexFileName(fileName) {
            return getBaseFileName(fileName, [".js", ".jsx", ".d.ts", ".ts", ".tsx"], 
            /*ignoreCase*/
            true) === "index";
        }
        function compareNodeCoreModuleSpecifiers(a, b, importingFile, program) {
            if (startsWith(a, "node:") && !startsWith(b, "node:"))
                return shouldUseUriStyleNodeCoreModules(importingFile, program) ? -1 /* LessThan */ : 1 /* GreaterThan */;
            if (startsWith(b, "node:") && !startsWith(a, "node:"))
                return shouldUseUriStyleNodeCoreModules(importingFile, program) ? 1 /* GreaterThan */ : -1 /* LessThan */;
            return 0 /* EqualTo */;
        }
        function getFixesInfoForUMDImport({ sourceFile, program, host, preferences }, token) {
            const checker = program.getTypeChecker();
            const umdSymbol = getUmdSymbol(token, checker);
            if (!umdSymbol)
                return void 0;
            const symbol = checker.getAliasedSymbol(umdSymbol);
            const symbolName2 = umdSymbol.name;
            const exportInfo = [{ symbol: umdSymbol, moduleSymbol: symbol, moduleFileName: void 0, exportKind: 3 /* UMD */, targetFlags: symbol.flags, isFromPackageJson: false }];
            const useRequire = shouldUseRequire(sourceFile, program);
            const fixes = getImportFixes(exportInfo, 
            /*usagePosition*/
            void 0, 
            /*isValidTypeOnlyUseSite*/
            false, useRequire, program, sourceFile, host, preferences).fixes;
            return fixes.map((fix) => {
                var _a2;
                return { fix, symbolName: symbolName2, errorIdentifierText: (_a2 = tryCast(token, isIdentifier)) == null ? void 0 : _a2.text };
            });
        }
        function getUmdSymbol(token, checker) {
            const umdSymbol = isIdentifier(token) ? checker.getSymbolAtLocation(token) : void 0;
            if (isUMDExportSymbol(umdSymbol))
                return umdSymbol;
            const { parent: parent2 } = token;
            if (isJsxOpeningLikeElement(parent2) && parent2.tagName === token || isJsxOpeningFragment(parent2)) {
                const parentSymbol = checker.resolveName(checker.getJsxNamespace(parent2), isJsxOpeningLikeElement(parent2) ? token : parent2, 111551 /* Value */, 
                /*excludeGlobals*/
                false);
                if (isUMDExportSymbol(parentSymbol)) {
                    return parentSymbol;
                }
            }
            return void 0;
        }
        function getImportKind(importingFile, exportKind, compilerOptions, forceImportKeyword) {
            if (compilerOptions.verbatimModuleSyntax && (getEmitModuleKind(compilerOptions) === 1 /* CommonJS */ || importingFile.impliedNodeFormat === 1 /* CommonJS */)) {
                return 3 /* CommonJS */;
            }
            switch (exportKind) {
                case 0 /* Named */:
                    return 0 /* Named */;
                case 1 /* Default */:
                    return 1 /* Default */;
                case 2 /* ExportEquals */:
                    return getExportEqualsImportKind(importingFile, compilerOptions, !!forceImportKeyword);
                case 3 /* UMD */:
                    return getUmdImportKind(importingFile, compilerOptions, !!forceImportKeyword);
                default:
                    return Debug.assertNever(exportKind);
            }
        }
        function getUmdImportKind(importingFile, compilerOptions, forceImportKeyword) {
            if (getAllowSyntheticDefaultImports(compilerOptions)) {
                return 1 /* Default */;
            }
            const moduleKind = getEmitModuleKind(compilerOptions);
            switch (moduleKind) {
                case 2 /* AMD */:
                case 1 /* CommonJS */:
                case 3 /* UMD */:
                    if (isInJSFile(importingFile)) {
                        return isExternalModule(importingFile) || forceImportKeyword ? 2 /* Namespace */ : 3 /* CommonJS */;
                    }
                    return 3 /* CommonJS */;
                case 4 /* System */:
                case 5 /* ES2015 */:
                case 6 /* ES2020 */:
                case 7 /* ES2022 */:
                case 99 /* ESNext */:
                case 0 /* None */:
                    return 2 /* Namespace */;
                case 100 /* Node16 */:
                case 199 /* NodeNext */:
                    return importingFile.impliedNodeFormat === 99 /* ESNext */ ? 2 /* Namespace */ : 3 /* CommonJS */;
                default:
                    return Debug.assertNever(moduleKind, `Unexpected moduleKind ${moduleKind}`);
            }
        }
        function getFixesInfoForNonUMDImport({ sourceFile, program, cancellationToken, host, preferences }, symbolToken, useAutoImportProvider) {
            const checker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            return flatMap(getSymbolNamesToImport(sourceFile, checker, symbolToken, compilerOptions), (symbolName2) => {
                if (symbolName2 === "default" /* Default */) {
                    return void 0;
                }
                const isValidTypeOnlyUseSite = isValidTypeOnlyAliasUseSite(symbolToken);
                const useRequire = shouldUseRequire(sourceFile, program);
                const exportInfo = getExportInfos(symbolName2, isJSXTagName(symbolToken), getMeaningFromLocation(symbolToken), cancellationToken, sourceFile, program, useAutoImportProvider, host, preferences);
                return arrayFrom(flatMapIterator(exportInfo.values(), (exportInfos) => getImportFixes(exportInfos, symbolToken.getStart(sourceFile), isValidTypeOnlyUseSite, useRequire, program, sourceFile, host, preferences).fixes), (fix) => ({ fix, symbolName: symbolName2, errorIdentifierText: symbolToken.text, isJsxNamespaceFix: symbolName2 !== symbolToken.text }));
            });
        }
        function getTypeOnlyPromotionFix(sourceFile, symbolToken, symbolName2, program) {
            const checker = program.getTypeChecker();
            const symbol = checker.resolveName(symbolName2, symbolToken, 111551 /* Value */, 
            /*excludeGlobals*/
            true);
            if (!symbol)
                return void 0;
            const typeOnlyAliasDeclaration = checker.getTypeOnlyAliasDeclaration(symbol);
            if (!typeOnlyAliasDeclaration || getSourceFileOfNode(typeOnlyAliasDeclaration) !== sourceFile)
                return void 0;
            return { kind: 4 /* PromoteTypeOnly */, typeOnlyAliasDeclaration };
        }
        function getSymbolNamesToImport(sourceFile, checker, symbolToken, compilerOptions) {
            const parent2 = symbolToken.parent;
            if ((isJsxOpeningLikeElement(parent2) || isJsxClosingElement(parent2)) && parent2.tagName === symbolToken && jsxModeNeedsExplicitImport(compilerOptions.jsx)) {
                const jsxNamespace = checker.getJsxNamespace(sourceFile);
                if (needsJsxNamespaceFix(jsxNamespace, symbolToken, checker)) {
                    const needsComponentNameFix = !isIntrinsicJsxName(symbolToken.text) && !checker.resolveName(symbolToken.text, symbolToken, 111551 /* Value */, 
                    /*excludeGlobals*/
                    false);
                    return needsComponentNameFix ? [symbolToken.text, jsxNamespace] : [jsxNamespace];
                }
            }
            return [symbolToken.text];
        }
        function needsJsxNamespaceFix(jsxNamespace, symbolToken, checker) {
            if (isIntrinsicJsxName(symbolToken.text))
                return true;
            const namespaceSymbol = checker.resolveName(jsxNamespace, symbolToken, 111551 /* Value */, 
            /*excludeGlobals*/
            true);
            return !namespaceSymbol || some(namespaceSymbol.declarations, isTypeOnlyImportOrExportDeclaration) && !(namespaceSymbol.flags & 111551 /* Value */);
        }
        function getExportInfos(symbolName2, isJsxTagName, currentTokenMeaning, cancellationToken, fromFile, program, useAutoImportProvider, host, preferences) {
            var _a2;
            const originalSymbolToExportInfos = createMultiMap();
            const packageJsonFilter = createPackageJsonImportFilter(fromFile, preferences, host);
            const moduleSpecifierCache = (_a2 = host.getModuleSpecifierCache) == null ? void 0 : _a2.call(host);
            const getModuleSpecifierResolutionHost = memoizeOne((isFromPackageJson) => {
                return createModuleSpecifierResolutionHost(isFromPackageJson ? host.getPackageJsonAutoImportProvider() : program, host);
            });
            function addSymbol(moduleSymbol, toFile, exportedSymbol, exportKind, program2, isFromPackageJson) {
                const moduleSpecifierResolutionHost = getModuleSpecifierResolutionHost(isFromPackageJson);
                if (toFile && isImportableFile(program2, fromFile, toFile, preferences, packageJsonFilter, moduleSpecifierResolutionHost, moduleSpecifierCache) || !toFile && packageJsonFilter.allowsImportingAmbientModule(moduleSymbol, moduleSpecifierResolutionHost)) {
                    const checker = program2.getTypeChecker();
                    originalSymbolToExportInfos.add(getUniqueSymbolId(exportedSymbol, checker).toString(), { symbol: exportedSymbol, moduleSymbol, moduleFileName: toFile == null ? void 0 : toFile.fileName, exportKind, targetFlags: skipAlias(exportedSymbol, checker).flags, isFromPackageJson });
                }
            }
            forEachExternalModuleToImportFrom(program, host, preferences, useAutoImportProvider, (moduleSymbol, sourceFile, program2, isFromPackageJson) => {
                const checker = program2.getTypeChecker();
                cancellationToken.throwIfCancellationRequested();
                const compilerOptions = program2.getCompilerOptions();
                const defaultInfo = getDefaultLikeExportInfo(moduleSymbol, checker, compilerOptions);
                if (defaultInfo && (defaultInfo.name === symbolName2 || moduleSymbolToValidIdentifier(moduleSymbol, getEmitScriptTarget(compilerOptions), isJsxTagName) === symbolName2) && symbolHasMeaning(defaultInfo.resolvedSymbol, currentTokenMeaning)) {
                    addSymbol(moduleSymbol, sourceFile, defaultInfo.symbol, defaultInfo.exportKind, program2, isFromPackageJson);
                }
                const exportSymbolWithIdenticalName = checker.tryGetMemberInModuleExportsAndProperties(symbolName2, moduleSymbol);
                if (exportSymbolWithIdenticalName && symbolHasMeaning(exportSymbolWithIdenticalName, currentTokenMeaning)) {
                    addSymbol(moduleSymbol, sourceFile, exportSymbolWithIdenticalName, 0 /* Named */, program2, isFromPackageJson);
                }
            });
            return originalSymbolToExportInfos;
        }
        function getExportEqualsImportKind(importingFile, compilerOptions, forceImportKeyword) {
            const allowSyntheticDefaults = getAllowSyntheticDefaultImports(compilerOptions);
            const isJS = isInJSFile(importingFile);
            if (!isJS && getEmitModuleKind(compilerOptions) >= 5 /* ES2015 */) {
                return allowSyntheticDefaults ? 1 /* Default */ : 2 /* Namespace */;
            }
            if (isJS) {
                return isExternalModule(importingFile) || forceImportKeyword ? allowSyntheticDefaults ? 1 /* Default */ : 2 /* Namespace */ : 3 /* CommonJS */;
            }
            for (const statement of importingFile.statements) {
                if (isImportEqualsDeclaration(statement) && !nodeIsMissing(statement.moduleReference)) {
                    return 3 /* CommonJS */;
                }
            }
            return allowSyntheticDefaults ? 1 /* Default */ : 3 /* CommonJS */;
        }
        function codeActionForFix(context, sourceFile, symbolName2, fix, includeSymbolNameInDescription, compilerOptions, preferences) {
            let diag2;
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (tracker) => {
                diag2 = codeActionForFixWorker(tracker, sourceFile, symbolName2, fix, includeSymbolNameInDescription, compilerOptions, preferences);
            });
            return createCodeFixAction(importFixName, changes, diag2, importFixId, Diagnostics.Add_all_missing_imports);
        }
        function codeActionForFixWorker(changes, sourceFile, symbolName2, fix, includeSymbolNameInDescription, compilerOptions, preferences) {
            const quotePreference = getQuotePreference(sourceFile, preferences);
            switch (fix.kind) {
                case 0 /* UseNamespace */:
                    addNamespaceQualifier(changes, sourceFile, fix);
                    return [Diagnostics.Change_0_to_1, symbolName2, `${fix.namespacePrefix}.${symbolName2}`];
                case 1 /* JsdocTypeImport */:
                    addImportType(changes, sourceFile, fix, quotePreference);
                    return [Diagnostics.Change_0_to_1, symbolName2, getImportTypePrefix(fix.moduleSpecifier, quotePreference) + symbolName2];
                case 2 /* AddToExisting */: {
                    const { importClauseOrBindingPattern, importKind, addAsTypeOnly, moduleSpecifier } = fix;
                    doAddExistingFix(changes, sourceFile, importClauseOrBindingPattern, importKind === 1 /* Default */ ? { name: symbolName2, addAsTypeOnly } : void 0, importKind === 0 /* Named */ ? [{ name: symbolName2, addAsTypeOnly }] : emptyArray, compilerOptions, preferences);
                    const moduleSpecifierWithoutQuotes = stripQuotes(moduleSpecifier);
                    return includeSymbolNameInDescription ? [Diagnostics.Import_0_from_1, symbolName2, moduleSpecifierWithoutQuotes] : [Diagnostics.Update_import_from_0, moduleSpecifierWithoutQuotes];
                }
                case 3 /* AddNew */: {
                    const { importKind, moduleSpecifier, addAsTypeOnly, useRequire, qualification } = fix;
                    const getDeclarations = useRequire ? getNewRequires : getNewImports;
                    const defaultImport = importKind === 1 /* Default */ ? { name: symbolName2, addAsTypeOnly } : void 0;
                    const namedImports = importKind === 0 /* Named */ ? [{ name: symbolName2, addAsTypeOnly }] : void 0;
                    const namespaceLikeImport = importKind === 2 /* Namespace */ || importKind === 3 /* CommonJS */ ? { importKind, name: (qualification == null ? void 0 : qualification.namespacePrefix) || symbolName2, addAsTypeOnly } : void 0;
                    insertImports(changes, sourceFile, getDeclarations(moduleSpecifier, quotePreference, defaultImport, namedImports, namespaceLikeImport, compilerOptions), 
                    /*blankLineBetween*/
                    true, preferences);
                    if (qualification) {
                        addNamespaceQualifier(changes, sourceFile, qualification);
                    }
                    return includeSymbolNameInDescription ? [Diagnostics.Import_0_from_1, symbolName2, moduleSpecifier] : [Diagnostics.Add_import_from_0, moduleSpecifier];
                }
                case 4 /* PromoteTypeOnly */: {
                    const { typeOnlyAliasDeclaration } = fix;
                    const promotedDeclaration = promoteFromTypeOnly(changes, typeOnlyAliasDeclaration, compilerOptions, sourceFile, preferences);
                    return promotedDeclaration.kind === 273 /* ImportSpecifier */ ? [Diagnostics.Remove_type_from_import_of_0_from_1, symbolName2, getModuleSpecifierText(promotedDeclaration.parent.parent)] : [Diagnostics.Remove_type_from_import_declaration_from_0, getModuleSpecifierText(promotedDeclaration)];
                }
                default:
                    return Debug.assertNever(fix, `Unexpected fix kind ${fix.kind}`);
            }
        }
        function getModuleSpecifierText(promotedDeclaration) {
            var _a2, _b;
            return promotedDeclaration.kind === 268 /* ImportEqualsDeclaration */ ? ((_b = tryCast((_a2 = tryCast(promotedDeclaration.moduleReference, isExternalModuleReference)) == null ? void 0 : _a2.expression, isStringLiteralLike)) == null ? void 0 : _b.text) || promotedDeclaration.moduleReference.getText() : cast(promotedDeclaration.parent.moduleSpecifier, isStringLiteral).text;
        }
        function promoteFromTypeOnly(changes, aliasDeclaration, compilerOptions, sourceFile, preferences) {
            const convertExistingToTypeOnly = importNameElisionDisabled(compilerOptions);
            switch (aliasDeclaration.kind) {
                case 273 /* ImportSpecifier */:
                    if (aliasDeclaration.isTypeOnly) {
                        const sortKind = ts_OrganizeImports_exports.detectImportSpecifierSorting(aliasDeclaration.parent.elements, preferences);
                        if (aliasDeclaration.parent.elements.length > 1 && sortKind) {
                            changes.delete(sourceFile, aliasDeclaration);
                            const newSpecifier = factory.updateImportSpecifier(aliasDeclaration, 
                            /*isTypeOnly*/
                            false, aliasDeclaration.propertyName, aliasDeclaration.name);
                            const comparer = ts_OrganizeImports_exports.getOrganizeImportsComparer(preferences, sortKind === 2 /* CaseInsensitive */);
                            const insertionIndex = ts_OrganizeImports_exports.getImportSpecifierInsertionIndex(aliasDeclaration.parent.elements, newSpecifier, comparer);
                            changes.insertImportSpecifierAtIndex(sourceFile, newSpecifier, aliasDeclaration.parent, insertionIndex);
                        }
                        else {
                            changes.deleteRange(sourceFile, aliasDeclaration.getFirstToken());
                        }
                        return aliasDeclaration;
                    }
                    else {
                        Debug.assert(aliasDeclaration.parent.parent.isTypeOnly);
                        promoteImportClause(aliasDeclaration.parent.parent);
                        return aliasDeclaration.parent.parent;
                    }
                case 270 /* ImportClause */:
                    promoteImportClause(aliasDeclaration);
                    return aliasDeclaration;
                case 271 /* NamespaceImport */:
                    promoteImportClause(aliasDeclaration.parent);
                    return aliasDeclaration.parent;
                case 268 /* ImportEqualsDeclaration */:
                    changes.deleteRange(sourceFile, aliasDeclaration.getChildAt(1));
                    return aliasDeclaration;
                default:
                    Debug.failBadSyntaxKind(aliasDeclaration);
            }
            function promoteImportClause(importClause) {
                changes.delete(sourceFile, getTypeKeywordOfTypeOnlyImport(importClause, sourceFile));
                if (convertExistingToTypeOnly) {
                    const namedImports = tryCast(importClause.namedBindings, isNamedImports);
                    if (namedImports && namedImports.elements.length > 1) {
                        if (ts_OrganizeImports_exports.detectImportSpecifierSorting(namedImports.elements, preferences) && aliasDeclaration.kind === 273 /* ImportSpecifier */ && namedImports.elements.indexOf(aliasDeclaration) !== 0) {
                            changes.delete(sourceFile, aliasDeclaration);
                            changes.insertImportSpecifierAtIndex(sourceFile, aliasDeclaration, namedImports, 0);
                        }
                        for (const element of namedImports.elements) {
                            if (element !== aliasDeclaration && !element.isTypeOnly) {
                                changes.insertModifierBefore(sourceFile, 154 /* TypeKeyword */, element);
                            }
                        }
                    }
                }
            }
        }
        function doAddExistingFix(changes, sourceFile, clause, defaultImport, namedImports, compilerOptions, preferences) {
            var _a2;
            if (clause.kind === 203 /* ObjectBindingPattern */) {
                if (defaultImport) {
                    addElementToBindingPattern(clause, defaultImport.name, "default");
                }
                for (const specifier of namedImports) {
                    addElementToBindingPattern(clause, specifier.name, 
                    /*propertyName*/
                    void 0);
                }
                return;
            }
            const promoteFromTypeOnly2 = clause.isTypeOnly && some([defaultImport, ...namedImports], (i) => (i == null ? void 0 : i.addAsTypeOnly) === 4 /* NotAllowed */);
            const existingSpecifiers = clause.namedBindings && ((_a2 = tryCast(clause.namedBindings, isNamedImports)) == null ? void 0 : _a2.elements);
            const convertExistingToTypeOnly = promoteFromTypeOnly2 && importNameElisionDisabled(compilerOptions);
            if (defaultImport) {
                Debug.assert(!clause.name, "Cannot add a default import to an import clause that already has one");
                changes.insertNodeAt(sourceFile, clause.getStart(sourceFile), factory.createIdentifier(defaultImport.name), { suffix: ", " });
            }
            if (namedImports.length) {
                let ignoreCaseForSorting;
                if (typeof preferences.organizeImportsIgnoreCase === "boolean") {
                    ignoreCaseForSorting = preferences.organizeImportsIgnoreCase;
                }
                else if (existingSpecifiers) {
                    const targetImportSorting = ts_OrganizeImports_exports.detectImportSpecifierSorting(existingSpecifiers, preferences);
                    if (targetImportSorting !== 3 /* Both */) {
                        ignoreCaseForSorting = targetImportSorting === 2 /* CaseInsensitive */;
                    }
                }
                if (ignoreCaseForSorting === void 0) {
                    ignoreCaseForSorting = ts_OrganizeImports_exports.detectSorting(sourceFile, preferences) === 2 /* CaseInsensitive */;
                }
                const comparer = ts_OrganizeImports_exports.getOrganizeImportsComparer(preferences, ignoreCaseForSorting);
                const newSpecifiers = stableSort(namedImports.map((namedImport) => factory.createImportSpecifier((!clause.isTypeOnly || promoteFromTypeOnly2) && needsTypeOnly(namedImport), 
                /*propertyName*/
                void 0, factory.createIdentifier(namedImport.name))), (s1, s2) => ts_OrganizeImports_exports.compareImportOrExportSpecifiers(s1, s2, comparer));
                const specifierSort = (existingSpecifiers == null ? void 0 : existingSpecifiers.length) && ts_OrganizeImports_exports.detectImportSpecifierSorting(existingSpecifiers, preferences);
                if (specifierSort && !(ignoreCaseForSorting && specifierSort === 1 /* CaseSensitive */)) {
                    for (const spec of newSpecifiers) {
                        const insertionIndex = convertExistingToTypeOnly && !spec.isTypeOnly ? 0 : ts_OrganizeImports_exports.getImportSpecifierInsertionIndex(existingSpecifiers, spec, comparer);
                        changes.insertImportSpecifierAtIndex(sourceFile, spec, clause.namedBindings, insertionIndex);
                    }
                }
                else if (existingSpecifiers == null ? void 0 : existingSpecifiers.length) {
                    for (const spec of newSpecifiers) {
                        changes.insertNodeInListAfter(sourceFile, last(existingSpecifiers), spec, existingSpecifiers);
                    }
                }
                else {
                    if (newSpecifiers.length) {
                        const namedImports2 = factory.createNamedImports(newSpecifiers);
                        if (clause.namedBindings) {
                            changes.replaceNode(sourceFile, clause.namedBindings, namedImports2);
                        }
                        else {
                            changes.insertNodeAfter(sourceFile, Debug.checkDefined(clause.name, "Import clause must have either named imports or a default import"), namedImports2);
                        }
                    }
                }
            }
            if (promoteFromTypeOnly2) {
                changes.delete(sourceFile, getTypeKeywordOfTypeOnlyImport(clause, sourceFile));
                if (convertExistingToTypeOnly && existingSpecifiers) {
                    for (const specifier of existingSpecifiers) {
                        changes.insertModifierBefore(sourceFile, 154 /* TypeKeyword */, specifier);
                    }
                }
            }
            function addElementToBindingPattern(bindingPattern, name, propertyName) {
                const element = factory.createBindingElement(
                /*dotDotDotToken*/
                void 0, propertyName, name);
                if (bindingPattern.elements.length) {
                    changes.insertNodeInListAfter(sourceFile, last(bindingPattern.elements), element);
                }
                else {
                    changes.replaceNode(sourceFile, bindingPattern, factory.createObjectBindingPattern([element]));
                }
            }
        }
        function addNamespaceQualifier(changes, sourceFile, { namespacePrefix, usagePosition }) {
            changes.insertText(sourceFile, usagePosition, namespacePrefix + ".");
        }
        function addImportType(changes, sourceFile, { moduleSpecifier, usagePosition: position }, quotePreference) {
            changes.insertText(sourceFile, position, getImportTypePrefix(moduleSpecifier, quotePreference));
        }
        function getImportTypePrefix(moduleSpecifier, quotePreference) {
            const quote2 = getQuoteFromPreference(quotePreference);
            return `import(${quote2}${moduleSpecifier}${quote2}).`;
        }
        function needsTypeOnly({ addAsTypeOnly }) {
            return addAsTypeOnly === 2 /* Required */;
        }
        function getNewImports(moduleSpecifier, quotePreference, defaultImport, namedImports, namespaceLikeImport, compilerOptions) {
            const quotedModuleSpecifier = makeStringLiteral(moduleSpecifier, quotePreference);
            let statements;
            if (defaultImport !== void 0 || (namedImports == null ? void 0 : namedImports.length)) {
                const topLevelTypeOnly = (!defaultImport || needsTypeOnly(defaultImport)) && every(namedImports, needsTypeOnly) || compilerOptions.verbatimModuleSyntax && (defaultImport == null ? void 0 : defaultImport.addAsTypeOnly) !== 4 /* NotAllowed */ && !some(namedImports, (i) => i.addAsTypeOnly === 4 /* NotAllowed */);
                statements = combine(statements, makeImport(defaultImport && factory.createIdentifier(defaultImport.name), namedImports == null ? void 0 : namedImports.map(({ addAsTypeOnly, name }) => factory.createImportSpecifier(!topLevelTypeOnly && addAsTypeOnly === 2 /* Required */, 
                /*propertyName*/
                void 0, factory.createIdentifier(name))), moduleSpecifier, quotePreference, topLevelTypeOnly));
            }
            if (namespaceLikeImport) {
                const declaration = namespaceLikeImport.importKind === 3 /* CommonJS */ ? factory.createImportEqualsDeclaration(
                /*modifiers*/
                void 0, needsTypeOnly(namespaceLikeImport), factory.createIdentifier(namespaceLikeImport.name), factory.createExternalModuleReference(quotedModuleSpecifier)) : factory.createImportDeclaration(
                /*modifiers*/
                void 0, factory.createImportClause(needsTypeOnly(namespaceLikeImport), 
                /*name*/
                void 0, factory.createNamespaceImport(factory.createIdentifier(namespaceLikeImport.name))), quotedModuleSpecifier, 
                /*assertClause*/
                void 0);
                statements = combine(statements, declaration);
            }
            return Debug.checkDefined(statements);
        }
        function getNewRequires(moduleSpecifier, quotePreference, defaultImport, namedImports, namespaceLikeImport) {
            const quotedModuleSpecifier = makeStringLiteral(moduleSpecifier, quotePreference);
            let statements;
            if (defaultImport || (namedImports == null ? void 0 : namedImports.length)) {
                const bindingElements = (namedImports == null ? void 0 : namedImports.map(({ name }) => factory.createBindingElement(
                /*dotDotDotToken*/
                void 0, 
                /*propertyName*/
                void 0, name))) || [];
                if (defaultImport) {
                    bindingElements.unshift(factory.createBindingElement(
                    /*dotDotDotToken*/
                    void 0, "default", defaultImport.name));
                }
                const declaration = createConstEqualsRequireDeclaration(factory.createObjectBindingPattern(bindingElements), quotedModuleSpecifier);
                statements = combine(statements, declaration);
            }
            if (namespaceLikeImport) {
                const declaration = createConstEqualsRequireDeclaration(namespaceLikeImport.name, quotedModuleSpecifier);
                statements = combine(statements, declaration);
            }
            return Debug.checkDefined(statements);
        }
        function createConstEqualsRequireDeclaration(name, quotedModuleSpecifier) {
            return factory.createVariableStatement(
            /*modifiers*/
            void 0, factory.createVariableDeclarationList([
                factory.createVariableDeclaration(typeof name === "string" ? factory.createIdentifier(name) : name, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, factory.createCallExpression(factory.createIdentifier("require"), 
                /*typeArguments*/
                void 0, [quotedModuleSpecifier]))
            ], 2 /* Const */));
        }
        function symbolHasMeaning({ declarations }, meaning) {
            return some(declarations, (decl) => !!(getMeaningFromDeclaration(decl) & meaning));
        }
        function moduleSymbolToValidIdentifier(moduleSymbol, target, forceCapitalize) {
            return moduleSpecifierToValidIdentifier(removeFileExtension(stripQuotes(moduleSymbol.name)), target, forceCapitalize);
        }
        function moduleSpecifierToValidIdentifier(moduleSpecifier, target, forceCapitalize) {
            const baseName = getBaseFileName(removeSuffix(moduleSpecifier, "/index"));
            let res = "";
            let lastCharWasValid = true;
            const firstCharCode = baseName.charCodeAt(0);
            if (isIdentifierStart(firstCharCode, target)) {
                res += String.fromCharCode(firstCharCode);
                if (forceCapitalize) {
                    res = res.toUpperCase();
                }
            }
            else {
                lastCharWasValid = false;
            }
            for (let i = 1; i < baseName.length; i++) {
                const ch = baseName.charCodeAt(i);
                const isValid = isIdentifierPart(ch, target);
                if (isValid) {
                    let char = String.fromCharCode(ch);
                    if (!lastCharWasValid) {
                        char = char.toUpperCase();
                    }
                    res += char;
                }
                lastCharWasValid = isValid;
            }
            return !isStringANonContextualKeyword(res) ? res || "_" : `_${res}`;
        }
        var importFixName, importFixId, errorCodes17;
        var init_importFixes = __esm({
            "src/services/codefixes/importFixes.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                importFixName = "import";
                importFixId = "fixMissingImport";
                errorCodes17 = [
                    Diagnostics.Cannot_find_name_0.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_1.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0.code,
                    Diagnostics.Cannot_find_namespace_0.code,
                    Diagnostics._0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead.code,
                    Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here.code,
                    Diagnostics.No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer.code,
                    Diagnostics._0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes17,
                    getCodeActions(context) {
                        const { errorCode, preferences, sourceFile, span, program } = context;
                        const info = getFixInfos(context, errorCode, span.start, 
                        /*useAutoImportProvider*/
                        true);
                        if (!info)
                            return void 0;
                        return info.map(({ fix, symbolName: symbolName2, errorIdentifierText }) => codeActionForFix(context, sourceFile, symbolName2, fix, 
                        /*includeSymbolNameInDescription*/
                        symbolName2 !== errorIdentifierText, program.getCompilerOptions(), preferences));
                    },
                    fixIds: [importFixId],
                    getAllCodeActions: (context) => {
                        const { sourceFile, program, preferences, host, cancellationToken } = context;
                        const importAdder = createImportAdderWorker(sourceFile, program, 
                        /*useAutoImportProvider*/
                        true, preferences, host, cancellationToken);
                        eachDiagnostic(context, errorCodes17, (diag2) => importAdder.addImportFromDiagnostic(diag2, context));
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, importAdder.writeFixes));
                    }
                });
            }
        });
        // src/services/codefixes/fixAddMissingConstraint.ts
        function getInfo3(program, sourceFile, span) {
            const diag2 = find(program.getSemanticDiagnostics(sourceFile), (diag3) => diag3.start === span.start && diag3.length === span.length);
            if (diag2 === void 0 || diag2.relatedInformation === void 0)
                return;
            const related = find(diag2.relatedInformation, (related2) => related2.code === Diagnostics.This_type_parameter_might_need_an_extends_0_constraint.code);
            if (related === void 0 || related.file === void 0 || related.start === void 0 || related.length === void 0)
                return;
            let declaration = findAncestorMatchingSpan(related.file, createTextSpan(related.start, related.length));
            if (declaration === void 0)
                return;
            if (isIdentifier(declaration) && isTypeParameterDeclaration(declaration.parent)) {
                declaration = declaration.parent;
            }
            if (isTypeParameterDeclaration(declaration)) {
                if (isMappedTypeNode(declaration.parent))
                    return;
                const token = getTokenAtPosition(sourceFile, span.start);
                const checker = program.getTypeChecker();
                const constraint = tryGetConstraintType(checker, token) || tryGetConstraintFromDiagnosticMessage(related.messageText);
                return { constraint, declaration, token };
            }
            return void 0;
        }
        function addMissingConstraint(changes, program, preferences, host, sourceFile, info) {
            const { declaration, constraint } = info;
            const checker = program.getTypeChecker();
            if (isString(constraint)) {
                changes.insertText(sourceFile, declaration.name.end, ` extends ${constraint}`);
            }
            else {
                const scriptTarget = getEmitScriptTarget(program.getCompilerOptions());
                const tracker = getNoopSymbolTrackerWithResolver({ program, host });
                const importAdder = createImportAdder(sourceFile, program, preferences, host);
                const typeNode = typeToAutoImportableTypeNode(checker, importAdder, constraint, 
                /*contextNode*/
                void 0, scriptTarget, 
                /*flags*/
                void 0, tracker);
                if (typeNode) {
                    changes.replaceNode(sourceFile, declaration, factory.updateTypeParameterDeclaration(declaration, 
                    /*modifiers*/
                    void 0, declaration.name, typeNode, declaration.default));
                    importAdder.writeFixes(changes);
                }
            }
        }
        function tryGetConstraintFromDiagnosticMessage(messageText) {
            const [_, constraint] = flattenDiagnosticMessageText(messageText, "\n", 0).match(/`extends (.*)`/) || [];
            return constraint;
        }
        function tryGetConstraintType(checker, node) {
            if (isTypeNode(node.parent)) {
                return checker.getTypeArgumentConstraint(node.parent);
            }
            const contextualType = isExpression(node) ? checker.getContextualType(node) : void 0;
            return contextualType || checker.getTypeAtLocation(node);
        }
        var fixId16, errorCodes18;
        var init_fixAddMissingConstraint = __esm({
            "src/services/codefixes/fixAddMissingConstraint.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId16 = "addMissingConstraint";
                errorCodes18 = [
                    // We want errors this could be attached to:
                    // Diagnostics.This_type_parameter_probably_needs_an_extends_0_constraint
                    Diagnostics.Type_0_is_not_comparable_to_type_1.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties.code,
                    Diagnostics.Property_0_is_incompatible_with_index_signature.code,
                    Diagnostics.Property_0_in_type_1_is_not_assignable_to_type_2.code,
                    Diagnostics.Type_0_does_not_satisfy_the_constraint_1.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes18,
                    getCodeActions(context) {
                        const { sourceFile, span, program, preferences, host } = context;
                        const info = getInfo3(program, sourceFile, span);
                        if (info === void 0)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingConstraint(t, program, preferences, host, sourceFile, info));
                        return [createCodeFixAction(fixId16, changes, Diagnostics.Add_extends_constraint, fixId16, Diagnostics.Add_extends_constraint_to_all_type_parameters)];
                    },
                    fixIds: [fixId16],
                    getAllCodeActions: (context) => {
                        const { program, preferences, host } = context;
                        const seen = /* @__PURE__ */ new Map();
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            eachDiagnostic(context, errorCodes18, (diag2) => {
                                const info = getInfo3(program, diag2.file, createTextSpan(diag2.start, diag2.length));
                                if (info) {
                                    if (addToSeen(seen, getNodeId(info.declaration))) {
                                        return addMissingConstraint(changes, program, preferences, host, diag2.file, info);
                                    }
                                }
                                return void 0;
                            });
                        }));
                    }
                });
            }
        });
        // src/services/codefixes/fixOverrideModifier.ts
        function dispatchChanges(changeTracker, context, errorCode, pos) {
            switch (errorCode) {
                case Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0.code:
                case Diagnostics.This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code:
                case Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0.code:
                case Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0.code:
                case Diagnostics.This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code:
                    return doAddOverrideModifierChange(changeTracker, context.sourceFile, pos);
                case Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0.code:
                case Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0.code:
                case Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class.code:
                case Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class.code:
                    return doRemoveOverrideModifierChange(changeTracker, context.sourceFile, pos);
                default:
                    Debug.fail("Unexpected error code: " + errorCode);
            }
        }
        function doAddOverrideModifierChange(changeTracker, sourceFile, pos) {
            const classElement = findContainerClassElementLike(sourceFile, pos);
            if (isSourceFileJS(sourceFile)) {
                changeTracker.addJSDocTags(sourceFile, classElement, [factory.createJSDocOverrideTag(factory.createIdentifier("override"))]);
                return;
            }
            const modifiers = classElement.modifiers || emptyArray;
            const staticModifier = find(modifiers, isStaticModifier);
            const abstractModifier = find(modifiers, isAbstractModifier);
            const accessibilityModifier = find(modifiers, (m) => isAccessibilityModifier(m.kind));
            const lastDecorator = findLast(modifiers, isDecorator);
            const modifierPos = abstractModifier ? abstractModifier.end : staticModifier ? staticModifier.end : accessibilityModifier ? accessibilityModifier.end : lastDecorator ? skipTrivia(sourceFile.text, lastDecorator.end) : classElement.getStart(sourceFile);
            const options = accessibilityModifier || staticModifier || abstractModifier ? { prefix: " " } : { suffix: " " };
            changeTracker.insertModifierAt(sourceFile, modifierPos, 161 /* OverrideKeyword */, options);
        }
        function doRemoveOverrideModifierChange(changeTracker, sourceFile, pos) {
            const classElement = findContainerClassElementLike(sourceFile, pos);
            if (isSourceFileJS(sourceFile)) {
                changeTracker.filterJSDocTags(sourceFile, classElement, not(isJSDocOverrideTag));
                return;
            }
            const overrideModifier = find(classElement.modifiers, isOverrideModifier);
            Debug.assertIsDefined(overrideModifier);
            changeTracker.deleteModifier(sourceFile, overrideModifier);
        }
        function isClassElementLikeHasJSDoc(node) {
            switch (node.kind) {
                case 173 /* Constructor */:
                case 169 /* PropertyDeclaration */:
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    return true;
                case 166 /* Parameter */:
                    return isParameterPropertyDeclaration(node, node.parent);
                default:
                    return false;
            }
        }
        function findContainerClassElementLike(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const classElement = findAncestor(token, (node) => {
                if (isClassLike(node))
                    return "quit";
                return isClassElementLikeHasJSDoc(node);
            });
            Debug.assert(classElement && isClassElementLikeHasJSDoc(classElement));
            return classElement;
        }
        var fixName, fixAddOverrideId, fixRemoveOverrideId, errorCodes19, errorCodeFixIdMap;
        var init_fixOverrideModifier = __esm({
            "src/services/codefixes/fixOverrideModifier.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName = "fixOverrideModifier";
                fixAddOverrideId = "fixAddOverrideModifier";
                fixRemoveOverrideId = "fixRemoveOverrideModifier";
                errorCodes19 = [
                    Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0.code,
                    Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class.code,
                    Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0.code,
                    Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0.code,
                    Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0.code,
                    Diagnostics.This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code,
                    Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class.code,
                    Diagnostics.This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code,
                    Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0.code
                ];
                errorCodeFixIdMap = {
                    // case #1:
                    [Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Add_all_missing_override_modifiers
                    },
                    [Diagnostics.This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Add_all_missing_override_modifiers
                    },
                    // case #2:
                    [Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class.code]: {
                        descriptions: Diagnostics.Remove_override_modifier,
                        fixId: fixRemoveOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_all_unnecessary_override_modifiers
                    },
                    [Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class.code]: {
                        descriptions: Diagnostics.Remove_override_modifier,
                        fixId: fixRemoveOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_override_modifier
                    },
                    // case #3:
                    [Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Add_all_missing_override_modifiers
                    },
                    [Diagnostics.This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Add_all_missing_override_modifiers
                    },
                    // case #4:
                    [Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_all_unnecessary_override_modifiers
                    },
                    // case #5:
                    [Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Remove_override_modifier,
                        fixId: fixRemoveOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_all_unnecessary_override_modifiers
                    },
                    [Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Remove_override_modifier,
                        fixId: fixRemoveOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_all_unnecessary_override_modifiers
                    }
                };
                registerCodeFix({
                    errorCodes: errorCodes19,
                    getCodeActions: function getCodeActionsToFixOverrideModifierIssues(context) {
                        const { errorCode, span } = context;
                        const info = errorCodeFixIdMap[errorCode];
                        if (!info)
                            return emptyArray;
                        const { descriptions, fixId: fixId51, fixAllDescriptions } = info;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => dispatchChanges(changes2, context, errorCode, span.start));
                        return [
                            createCodeFixActionMaybeFixAll(fixName, changes, descriptions, fixId51, fixAllDescriptions)
                        ];
                    },
                    fixIds: [fixName, fixAddOverrideId, fixRemoveOverrideId],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes19, (changes, diag2) => {
                        const { code, start } = diag2;
                        const info = errorCodeFixIdMap[code];
                        if (!info || info.fixId !== context.fixId) {
                            return;
                        }
                        dispatchChanges(changes, context, code, start);
                    })
                });
            }
        });
        // src/services/codefixes/fixNoPropertyAccessFromIndexSignature.ts
        function doChange6(changes, sourceFile, node, preferences) {
            const quotePreference = getQuotePreference(sourceFile, preferences);
            const argumentsExpression = factory.createStringLiteral(node.name.text, quotePreference === 0 /* Single */);
            changes.replaceNode(sourceFile, node, isPropertyAccessChain(node) ? factory.createElementAccessChain(node.expression, node.questionDotToken, argumentsExpression) : factory.createElementAccessExpression(node.expression, argumentsExpression));
        }
        function getPropertyAccessExpression(sourceFile, pos) {
            return cast(getTokenAtPosition(sourceFile, pos).parent, isPropertyAccessExpression);
        }
        var fixId17, errorCodes20;
        var init_fixNoPropertyAccessFromIndexSignature = __esm({
            "src/services/codefixes/fixNoPropertyAccessFromIndexSignature.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId17 = "fixNoPropertyAccessFromIndexSignature";
                errorCodes20 = [
                    Diagnostics.Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes20,
                    fixIds: [fixId17],
                    getCodeActions(context) {
                        const { sourceFile, span, preferences } = context;
                        const property = getPropertyAccessExpression(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange6(t, context.sourceFile, property, preferences));
                        return [createCodeFixAction(fixId17, changes, [Diagnostics.Use_element_access_for_0, property.name.text], fixId17, Diagnostics.Use_element_access_for_all_undeclared_properties)];
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes20, (changes, diag2) => doChange6(changes, diag2.file, getPropertyAccessExpression(diag2.file, diag2.start), context.preferences))
                });
            }
        });
        // src/services/codefixes/fixImplicitThis.ts
        function doChange7(changes, sourceFile, pos, checker) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (!isThis(token))
                return void 0;
            const fn = getThisContainer(token, 
            /*includeArrowFunctions*/
            false, 
            /*includeClassComputedPropertyName*/
            false);
            if (!isFunctionDeclaration(fn) && !isFunctionExpression(fn))
                return void 0;
            if (!isSourceFile(getThisContainer(fn, 
            /*includeArrowFunctions*/
            false, 
            /*includeClassComputedPropertyName*/
            false))) {
                const fnKeyword = Debug.checkDefined(findChildOfKind(fn, 98 /* FunctionKeyword */, sourceFile));
                const { name } = fn;
                const body = Debug.checkDefined(fn.body);
                if (isFunctionExpression(fn)) {
                    if (name && ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(name, checker, sourceFile, body)) {
                        return void 0;
                    }
                    changes.delete(sourceFile, fnKeyword);
                    if (name) {
                        changes.delete(sourceFile, name);
                    }
                    changes.insertText(sourceFile, body.pos, " =>");
                    return [Diagnostics.Convert_function_expression_0_to_arrow_function, name ? name.text : ANONYMOUS];
                }
                else {
                    changes.replaceNode(sourceFile, fnKeyword, factory.createToken(85 /* ConstKeyword */));
                    changes.insertText(sourceFile, name.end, " = ");
                    changes.insertText(sourceFile, body.pos, " =>");
                    return [Diagnostics.Convert_function_declaration_0_to_arrow_function, name.text];
                }
            }
        }
        var fixId18, errorCodes21;
        var init_fixImplicitThis = __esm({
            "src/services/codefixes/fixImplicitThis.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId18 = "fixImplicitThis";
                errorCodes21 = [Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code];
                registerCodeFix({
                    errorCodes: errorCodes21,
                    getCodeActions: function getCodeActionsToFixImplicitThis(context) {
                        const { sourceFile, program, span } = context;
                        let diagnostic;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                            diagnostic = doChange7(t, sourceFile, span.start, program.getTypeChecker());
                        });
                        return diagnostic ? [createCodeFixAction(fixId18, changes, diagnostic, fixId18, Diagnostics.Fix_all_implicit_this_errors)] : emptyArray;
                    },
                    fixIds: [fixId18],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes21, (changes, diag2) => {
                        doChange7(changes, diag2.file, diag2.start, context.program.getTypeChecker());
                    })
                });
            }
        });
        // src/services/codefixes/fixImportNonExportedMember.ts
        function getInfo4(sourceFile, pos, program) {
            var _a2;
            const token = getTokenAtPosition(sourceFile, pos);
            if (isIdentifier(token)) {
                const importDeclaration = findAncestor(token, isImportDeclaration);
                if (importDeclaration === void 0)
                    return void 0;
                const moduleSpecifier = isStringLiteral(importDeclaration.moduleSpecifier) ? importDeclaration.moduleSpecifier.text : void 0;
                if (moduleSpecifier === void 0)
                    return void 0;
                const resolvedModule = getResolvedModule(sourceFile, moduleSpecifier, 
                /*mode*/
                void 0);
                if (resolvedModule === void 0)
                    return void 0;
                const moduleSourceFile = program.getSourceFile(resolvedModule.resolvedFileName);
                if (moduleSourceFile === void 0 || isSourceFileFromLibrary(program, moduleSourceFile))
                    return void 0;
                const moduleSymbol = moduleSourceFile.symbol;
                const locals = (_a2 = tryCast(moduleSymbol.valueDeclaration, canHaveLocals)) == null ? void 0 : _a2.locals;
                if (locals === void 0)
                    return void 0;
                const localSymbol = locals.get(token.escapedText);
                if (localSymbol === void 0)
                    return void 0;
                const node = getNodeOfSymbol(localSymbol);
                if (node === void 0)
                    return void 0;
                const exportName = { node: token, isTypeOnly: isTypeDeclaration(node) };
                return { exportName, node, moduleSourceFile, moduleSpecifier };
            }
            return void 0;
        }
        function doChange8(changes, program, { exportName, node, moduleSourceFile }) {
            const exportDeclaration = tryGetExportDeclaration(moduleSourceFile, exportName.isTypeOnly);
            if (exportDeclaration) {
                updateExport(changes, program, moduleSourceFile, exportDeclaration, [exportName]);
            }
            else if (canHaveExportModifier(node)) {
                changes.insertExportModifier(moduleSourceFile, node);
            }
            else {
                createExport(changes, program, moduleSourceFile, [exportName]);
            }
        }
        function doChanges(changes, program, sourceFile, moduleExports, node) {
            if (length(moduleExports)) {
                if (node) {
                    updateExport(changes, program, sourceFile, node, moduleExports);
                }
                else {
                    createExport(changes, program, sourceFile, moduleExports);
                }
            }
        }
        function tryGetExportDeclaration(sourceFile, isTypeOnly) {
            const predicate = (node) => isExportDeclaration(node) && (isTypeOnly && node.isTypeOnly || !node.isTypeOnly);
            return findLast(sourceFile.statements, predicate);
        }
        function updateExport(changes, program, sourceFile, node, names) {
            const namedExports = node.exportClause && isNamedExports(node.exportClause) ? node.exportClause.elements : factory.createNodeArray([]);
            const allowTypeModifier = !node.isTypeOnly && !!(getIsolatedModules(program.getCompilerOptions()) || find(namedExports, (e) => e.isTypeOnly));
            changes.replaceNode(sourceFile, node, factory.updateExportDeclaration(node, node.modifiers, node.isTypeOnly, factory.createNamedExports(factory.createNodeArray([...namedExports, ...createExportSpecifiers(names, allowTypeModifier)], 
            /*hasTrailingComma*/
            namedExports.hasTrailingComma)), node.moduleSpecifier, node.assertClause));
        }
        function createExport(changes, program, sourceFile, names) {
            changes.insertNodeAtEndOfScope(sourceFile, sourceFile, factory.createExportDeclaration(
            /*modifiers*/
            void 0, 
            /*isTypeOnly*/
            false, factory.createNamedExports(createExportSpecifiers(names, 
            /*allowTypeModifier*/
            getIsolatedModules(program.getCompilerOptions()))), 
            /*moduleSpecifier*/
            void 0, 
            /*assertClause*/
            void 0));
        }
        function createExportSpecifiers(names, allowTypeModifier) {
            return factory.createNodeArray(map(names, (n) => factory.createExportSpecifier(allowTypeModifier && n.isTypeOnly, 
            /*propertyName*/
            void 0, n.node)));
        }
        function getNodeOfSymbol(symbol) {
            if (symbol.valueDeclaration === void 0) {
                return firstOrUndefined(symbol.declarations);
            }
            const declaration = symbol.valueDeclaration;
            const variableStatement = isVariableDeclaration(declaration) ? tryCast(declaration.parent.parent, isVariableStatement) : void 0;
            return variableStatement && length(variableStatement.declarationList.declarations) === 1 ? variableStatement : declaration;
        }
        var fixId19, errorCodes22;
        var init_fixImportNonExportedMember = __esm({
            "src/services/codefixes/fixImportNonExportedMember.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId19 = "fixImportNonExportedMember";
                errorCodes22 = [
                    Diagnostics.Module_0_declares_1_locally_but_it_is_not_exported.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes22,
                    fixIds: [fixId19],
                    getCodeActions(context) {
                        const { sourceFile, span, program } = context;
                        const info = getInfo4(sourceFile, span.start, program);
                        if (info === void 0)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange8(t, program, info));
                        return [createCodeFixAction(fixId19, changes, [Diagnostics.Export_0_from_module_1, info.exportName.node.text, info.moduleSpecifier], fixId19, Diagnostics.Export_all_referenced_locals)];
                    },
                    getAllCodeActions(context) {
                        const { program } = context;
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            const exports = /* @__PURE__ */ new Map();
                            eachDiagnostic(context, errorCodes22, (diag2) => {
                                const info = getInfo4(diag2.file, diag2.start, program);
                                if (info === void 0)
                                    return void 0;
                                const { exportName, node, moduleSourceFile } = info;
                                if (tryGetExportDeclaration(moduleSourceFile, exportName.isTypeOnly) === void 0 && canHaveExportModifier(node)) {
                                    changes.insertExportModifier(moduleSourceFile, node);
                                }
                                else {
                                    const moduleExports = exports.get(moduleSourceFile) || { typeOnlyExports: [], exports: [] };
                                    if (exportName.isTypeOnly) {
                                        moduleExports.typeOnlyExports.push(exportName);
                                    }
                                    else {
                                        moduleExports.exports.push(exportName);
                                    }
                                    exports.set(moduleSourceFile, moduleExports);
                                }
                            });
                            exports.forEach((moduleExports, moduleSourceFile) => {
                                const exportDeclaration = tryGetExportDeclaration(moduleSourceFile, 
                                /*isTypeOnly*/
                                true);
                                if (exportDeclaration && exportDeclaration.isTypeOnly) {
                                    doChanges(changes, program, moduleSourceFile, moduleExports.typeOnlyExports, exportDeclaration);
                                    doChanges(changes, program, moduleSourceFile, moduleExports.exports, tryGetExportDeclaration(moduleSourceFile, 
                                    /*isTypeOnly*/
                                    false));
                                }
                                else {
                                    doChanges(changes, program, moduleSourceFile, [...moduleExports.exports, ...moduleExports.typeOnlyExports], exportDeclaration);
                                }
                            });
                        }));
                    }
                });
            }
        });
        // src/services/codefixes/fixIncorrectNamedTupleSyntax.ts
        function getNamedTupleMember(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            return findAncestor(token, (t) => t.kind === 199 /* NamedTupleMember */);
        }
        function doChange9(changes, sourceFile, namedTupleMember) {
            if (!namedTupleMember) {
                return;
            }
            let unwrappedType = namedTupleMember.type;
            let sawOptional = false;
            let sawRest = false;
            while (unwrappedType.kind === 187 /* OptionalType */ || unwrappedType.kind === 188 /* RestType */ || unwrappedType.kind === 193 /* ParenthesizedType */) {
                if (unwrappedType.kind === 187 /* OptionalType */) {
                    sawOptional = true;
                }
                else if (unwrappedType.kind === 188 /* RestType */) {
                    sawRest = true;
                }
                unwrappedType = unwrappedType.type;
            }
            const updated = factory.updateNamedTupleMember(namedTupleMember, namedTupleMember.dotDotDotToken || (sawRest ? factory.createToken(25 /* DotDotDotToken */) : void 0), namedTupleMember.name, namedTupleMember.questionToken || (sawOptional ? factory.createToken(57 /* QuestionToken */) : void 0), unwrappedType);
            if (updated === namedTupleMember) {
                return;
            }
            changes.replaceNode(sourceFile, namedTupleMember, updated);
        }
        var fixId20, errorCodes23;
        var init_fixIncorrectNamedTupleSyntax = __esm({
            "src/services/codefixes/fixIncorrectNamedTupleSyntax.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId20 = "fixIncorrectNamedTupleSyntax";
                errorCodes23 = [
                    Diagnostics.A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type.code,
                    Diagnostics.A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes23,
                    getCodeActions: function getCodeActionsToFixIncorrectNamedTupleSyntax(context) {
                        const { sourceFile, span } = context;
                        const namedTupleMember = getNamedTupleMember(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange9(t, sourceFile, namedTupleMember));
                        return [createCodeFixAction(fixId20, changes, Diagnostics.Move_labeled_tuple_element_modifiers_to_labels, fixId20, Diagnostics.Move_labeled_tuple_element_modifiers_to_labels)];
                    },
                    fixIds: [fixId20]
                });
            }
        });
        // src/services/codefixes/fixSpelling.ts
        function getInfo5(sourceFile, pos, context, errorCode) {
            const node = getTokenAtPosition(sourceFile, pos);
            const parent2 = node.parent;
            if ((errorCode === Diagnostics.No_overload_matches_this_call.code || errorCode === Diagnostics.Type_0_is_not_assignable_to_type_1.code) && !isJsxAttribute(parent2))
                return void 0;
            const checker = context.program.getTypeChecker();
            let suggestedSymbol;
            if (isPropertyAccessExpression(parent2) && parent2.name === node) {
                Debug.assert(isMemberName(node), "Expected an identifier for spelling (property access)");
                let containingType = checker.getTypeAtLocation(parent2.expression);
                if (parent2.flags & 32 /* OptionalChain */) {
                    containingType = checker.getNonNullableType(containingType);
                }
                suggestedSymbol = checker.getSuggestedSymbolForNonexistentProperty(node, containingType);
            }
            else if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 101 /* InKeyword */ && parent2.left === node && isPrivateIdentifier(node)) {
                const receiverType = checker.getTypeAtLocation(parent2.right);
                suggestedSymbol = checker.getSuggestedSymbolForNonexistentProperty(node, receiverType);
            }
            else if (isQualifiedName(parent2) && parent2.right === node) {
                const symbol = checker.getSymbolAtLocation(parent2.left);
                if (symbol && symbol.flags & 1536 /* Module */) {
                    suggestedSymbol = checker.getSuggestedSymbolForNonexistentModule(parent2.right, symbol);
                }
            }
            else if (isImportSpecifier(parent2) && parent2.name === node) {
                Debug.assertNode(node, isIdentifier, "Expected an identifier for spelling (import)");
                const importDeclaration = findAncestor(node, isImportDeclaration);
                const resolvedSourceFile = getResolvedSourceFileFromImportDeclaration(sourceFile, context, importDeclaration);
                if (resolvedSourceFile && resolvedSourceFile.symbol) {
                    suggestedSymbol = checker.getSuggestedSymbolForNonexistentModule(node, resolvedSourceFile.symbol);
                }
            }
            else if (isJsxAttribute(parent2) && parent2.name === node) {
                Debug.assertNode(node, isIdentifier, "Expected an identifier for JSX attribute");
                const tag = findAncestor(node, isJsxOpeningLikeElement);
                const props = checker.getContextualTypeForArgumentAtIndex(tag, 0);
                suggestedSymbol = checker.getSuggestedSymbolForNonexistentJSXAttribute(node, props);
            }
            else if (hasSyntacticModifier(parent2, 16384 /* Override */) && isClassElement(parent2) && parent2.name === node) {
                const baseDeclaration = findAncestor(node, isClassLike);
                const baseTypeNode = baseDeclaration ? getEffectiveBaseTypeNode(baseDeclaration) : void 0;
                const baseType = baseTypeNode ? checker.getTypeAtLocation(baseTypeNode) : void 0;
                if (baseType) {
                    suggestedSymbol = checker.getSuggestedSymbolForNonexistentClassMember(getTextOfNode(node), baseType);
                }
            }
            else {
                const meaning = getMeaningFromLocation(node);
                const name = getTextOfNode(node);
                Debug.assert(name !== void 0, "name should be defined");
                suggestedSymbol = checker.getSuggestedSymbolForNonexistentSymbol(node, name, convertSemanticMeaningToSymbolFlags(meaning));
            }
            return suggestedSymbol === void 0 ? void 0 : { node, suggestedSymbol };
        }
        function doChange10(changes, sourceFile, node, suggestedSymbol, target) {
            const suggestion = symbolName(suggestedSymbol);
            if (!isIdentifierText(suggestion, target) && isPropertyAccessExpression(node.parent)) {
                const valDecl = suggestedSymbol.valueDeclaration;
                if (valDecl && isNamedDeclaration(valDecl) && isPrivateIdentifier(valDecl.name)) {
                    changes.replaceNode(sourceFile, node, factory.createIdentifier(suggestion));
                }
                else {
                    changes.replaceNode(sourceFile, node.parent, factory.createElementAccessExpression(node.parent.expression, factory.createStringLiteral(suggestion)));
                }
            }
            else {
                changes.replaceNode(sourceFile, node, factory.createIdentifier(suggestion));
            }
        }
        function convertSemanticMeaningToSymbolFlags(meaning) {
            let flags = 0;
            if (meaning & 4 /* Namespace */) {
                flags |= 1920 /* Namespace */;
            }
            if (meaning & 2 /* Type */) {
                flags |= 788968 /* Type */;
            }
            if (meaning & 1 /* Value */) {
                flags |= 111551 /* Value */;
            }
            return flags;
        }
        function getResolvedSourceFileFromImportDeclaration(sourceFile, context, importDeclaration) {
            if (!importDeclaration || !isStringLiteralLike(importDeclaration.moduleSpecifier))
                return void 0;
            const resolvedModule = getResolvedModule(sourceFile, importDeclaration.moduleSpecifier.text, getModeForUsageLocation(sourceFile, importDeclaration.moduleSpecifier));
            if (!resolvedModule)
                return void 0;
            return context.program.getSourceFile(resolvedModule.resolvedFileName);
        }
        var fixId21, errorCodes24;
        var init_fixSpelling = __esm({
            "src/services/codefixes/fixSpelling.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId21 = "fixSpelling";
                errorCodes24 = [
                    Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2.code,
                    Diagnostics.Property_0_may_not_exist_on_type_1_Did_you_mean_2.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_1.code,
                    Diagnostics.Could_not_find_name_0_Did_you_mean_1.code,
                    Diagnostics.Cannot_find_namespace_0_Did_you_mean_1.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0.code,
                    Diagnostics._0_has_no_exported_member_named_1_Did_you_mean_2.code,
                    Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1.code,
                    Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1.code,
                    // for JSX class components
                    Diagnostics.No_overload_matches_this_call.code,
                    // for JSX FC
                    Diagnostics.Type_0_is_not_assignable_to_type_1.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes24,
                    getCodeActions(context) {
                        const { sourceFile, errorCode } = context;
                        const info = getInfo5(sourceFile, context.span.start, context, errorCode);
                        if (!info)
                            return void 0;
                        const { node, suggestedSymbol } = info;
                        const target = getEmitScriptTarget(context.host.getCompilationSettings());
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange10(t, sourceFile, node, suggestedSymbol, target));
                        return [createCodeFixAction("spelling", changes, [Diagnostics.Change_spelling_to_0, symbolName(suggestedSymbol)], fixId21, Diagnostics.Fix_all_detected_spelling_errors)];
                    },
                    fixIds: [fixId21],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes24, (changes, diag2) => {
                        const info = getInfo5(diag2.file, diag2.start, context, diag2.code);
                        const target = getEmitScriptTarget(context.host.getCompilationSettings());
                        if (info)
                            doChange10(changes, context.sourceFile, info.node, info.suggestedSymbol, target);
                    })
                });
            }
        });
        // src/services/codefixes/returnValueCorrect.ts
        function createObjectTypeFromLabeledExpression(checker, label, expression) {
            const member = checker.createSymbol(4 /* Property */, label.escapedText);
            member.links.type = checker.getTypeAtLocation(expression);
            const members = createSymbolTable([member]);
            return checker.createAnonymousType(
            /*symbol*/
            void 0, members, [], [], []);
        }
        function getFixInfo(checker, declaration, expectType, isFunctionType) {
            if (!declaration.body || !isBlock(declaration.body) || length(declaration.body.statements) !== 1)
                return void 0;
            const firstStatement = first(declaration.body.statements);
            if (isExpressionStatement(firstStatement) && checkFixedAssignableTo(checker, declaration, checker.getTypeAtLocation(firstStatement.expression), expectType, isFunctionType)) {
                return {
                    declaration,
                    kind: 0 /* MissingReturnStatement */,
                    expression: firstStatement.expression,
                    statement: firstStatement,
                    commentSource: firstStatement.expression
                };
            }
            else if (isLabeledStatement(firstStatement) && isExpressionStatement(firstStatement.statement)) {
                const node = factory.createObjectLiteralExpression([factory.createPropertyAssignment(firstStatement.label, firstStatement.statement.expression)]);
                const nodeType = createObjectTypeFromLabeledExpression(checker, firstStatement.label, firstStatement.statement.expression);
                if (checkFixedAssignableTo(checker, declaration, nodeType, expectType, isFunctionType)) {
                    return isArrowFunction(declaration) ? {
                        declaration,
                        kind: 1 /* MissingParentheses */,
                        expression: node,
                        statement: firstStatement,
                        commentSource: firstStatement.statement.expression
                    } : {
                        declaration,
                        kind: 0 /* MissingReturnStatement */,
                        expression: node,
                        statement: firstStatement,
                        commentSource: firstStatement.statement.expression
                    };
                }
            }
            else if (isBlock(firstStatement) && length(firstStatement.statements) === 1) {
                const firstBlockStatement = first(firstStatement.statements);
                if (isLabeledStatement(firstBlockStatement) && isExpressionStatement(firstBlockStatement.statement)) {
                    const node = factory.createObjectLiteralExpression([factory.createPropertyAssignment(firstBlockStatement.label, firstBlockStatement.statement.expression)]);
                    const nodeType = createObjectTypeFromLabeledExpression(checker, firstBlockStatement.label, firstBlockStatement.statement.expression);
                    if (checkFixedAssignableTo(checker, declaration, nodeType, expectType, isFunctionType)) {
                        return {
                            declaration,
                            kind: 0 /* MissingReturnStatement */,
                            expression: node,
                            statement: firstStatement,
                            commentSource: firstBlockStatement
                        };
                    }
                }
            }
            return void 0;
        }
        function checkFixedAssignableTo(checker, declaration, exprType, type, isFunctionType) {
            if (isFunctionType) {
                const sig = checker.getSignatureFromDeclaration(declaration);
                if (sig) {
                    if (hasSyntacticModifier(declaration, 512 /* Async */)) {
                        exprType = checker.createPromiseType(exprType);
                    }
                    const newSig = checker.createSignature(declaration, sig.typeParameters, sig.thisParameter, sig.parameters, exprType, 
                    /*typePredicate*/
                    void 0, sig.minArgumentCount, sig.flags);
                    exprType = checker.createAnonymousType(
                    /*symbol*/
                    void 0, createSymbolTable(), [newSig], [], []);
                }
                else {
                    exprType = checker.getAnyType();
                }
            }
            return checker.isTypeAssignableTo(exprType, type);
        }
        function getInfo6(checker, sourceFile, position, errorCode) {
            const node = getTokenAtPosition(sourceFile, position);
            if (!node.parent)
                return void 0;
            const declaration = findAncestor(node.parent, isFunctionLikeDeclaration);
            switch (errorCode) {
                case Diagnostics.A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value.code:
                    if (!declaration || !declaration.body || !declaration.type || !rangeContainsRange(declaration.type, node))
                        return void 0;
                    return getFixInfo(checker, declaration, checker.getTypeFromTypeNode(declaration.type), 
                    /* isFunctionType */
                    false);
                case Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code:
                    if (!declaration || !isCallExpression(declaration.parent) || !declaration.body)
                        return void 0;
                    const pos = declaration.parent.arguments.indexOf(declaration);
                    const type = checker.getContextualTypeForArgumentAtIndex(declaration.parent, pos);
                    if (!type)
                        return void 0;
                    return getFixInfo(checker, declaration, type, 
                    /* isFunctionType */
                    true);
                case Diagnostics.Type_0_is_not_assignable_to_type_1.code:
                    if (!isDeclarationName(node) || !isVariableLike(node.parent) && !isJsxAttribute(node.parent))
                        return void 0;
                    const initializer = getVariableLikeInitializer(node.parent);
                    if (!initializer || !isFunctionLikeDeclaration(initializer) || !initializer.body)
                        return void 0;
                    return getFixInfo(checker, initializer, checker.getTypeAtLocation(node.parent), 
                    /* isFunctionType */
                    true);
            }
            return void 0;
        }
        function getVariableLikeInitializer(declaration) {
            switch (declaration.kind) {
                case 257 /* VariableDeclaration */:
                case 166 /* Parameter */:
                case 205 /* BindingElement */:
                case 169 /* PropertyDeclaration */:
                case 299 /* PropertyAssignment */:
                    return declaration.initializer;
                case 288 /* JsxAttribute */:
                    return declaration.initializer && (isJsxExpression(declaration.initializer) ? declaration.initializer.expression : void 0);
                case 300 /* ShorthandPropertyAssignment */:
                case 168 /* PropertySignature */:
                case 302 /* EnumMember */:
                case 351 /* JSDocPropertyTag */:
                case 344 /* JSDocParameterTag */:
                    return void 0;
            }
        }
        function addReturnStatement(changes, sourceFile, expression, statement) {
            suppressLeadingAndTrailingTrivia(expression);
            const probablyNeedSemi = probablyUsesSemicolons(sourceFile);
            changes.replaceNode(sourceFile, statement, factory.createReturnStatement(expression), {
                leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude,
                trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Exclude,
                suffix: probablyNeedSemi ? ";" : void 0
            });
        }
        function removeBlockBodyBrace(changes, sourceFile, declaration, expression, commentSource, withParen) {
            const newBody = withParen || needsParentheses(expression) ? factory.createParenthesizedExpression(expression) : expression;
            suppressLeadingAndTrailingTrivia(commentSource);
            copyComments(commentSource, newBody);
            changes.replaceNode(sourceFile, declaration.body, newBody);
        }
        function wrapBlockWithParen(changes, sourceFile, declaration, expression) {
            changes.replaceNode(sourceFile, declaration.body, factory.createParenthesizedExpression(expression));
        }
        function getActionForfixAddReturnStatement(context, expression, statement) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addReturnStatement(t, context.sourceFile, expression, statement));
            return createCodeFixAction(fixId22, changes, Diagnostics.Add_a_return_statement, fixIdAddReturnStatement, Diagnostics.Add_all_missing_return_statement);
        }
        function getActionForFixRemoveBracesFromArrowFunctionBody(context, declaration, expression, commentSource) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => removeBlockBodyBrace(t, context.sourceFile, declaration, expression, commentSource, 
            /* withParen */
            false));
            return createCodeFixAction(fixId22, changes, Diagnostics.Remove_braces_from_arrow_function_body, fixRemoveBracesFromArrowFunctionBody, Diagnostics.Remove_braces_from_all_arrow_function_bodies_with_relevant_issues);
        }
        function getActionForfixWrapTheBlockWithParen(context, declaration, expression) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => wrapBlockWithParen(t, context.sourceFile, declaration, expression));
            return createCodeFixAction(fixId22, changes, Diagnostics.Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal, fixIdWrapTheBlockWithParen, Diagnostics.Wrap_all_object_literal_with_parentheses);
        }
        var fixId22, fixIdAddReturnStatement, fixRemoveBracesFromArrowFunctionBody, fixIdWrapTheBlockWithParen, errorCodes25;
        var init_returnValueCorrect = __esm({
            "src/services/codefixes/returnValueCorrect.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId22 = "returnValueCorrect";
                fixIdAddReturnStatement = "fixAddReturnStatement";
                fixRemoveBracesFromArrowFunctionBody = "fixRemoveBracesFromArrowFunctionBody";
                fixIdWrapTheBlockWithParen = "fixWrapTheBlockWithParen";
                errorCodes25 = [
                    Diagnostics.A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes25,
                    fixIds: [fixIdAddReturnStatement, fixRemoveBracesFromArrowFunctionBody, fixIdWrapTheBlockWithParen],
                    getCodeActions: function getCodeActionsToCorrectReturnValue(context) {
                        const { program, sourceFile, span: { start }, errorCode } = context;
                        const info = getInfo6(program.getTypeChecker(), sourceFile, start, errorCode);
                        if (!info)
                            return void 0;
                        if (info.kind === 0 /* MissingReturnStatement */) {
                            return append([getActionForfixAddReturnStatement(context, info.expression, info.statement)], isArrowFunction(info.declaration) ? getActionForFixRemoveBracesFromArrowFunctionBody(context, info.declaration, info.expression, info.commentSource) : void 0);
                        }
                        else {
                            return [getActionForfixWrapTheBlockWithParen(context, info.declaration, info.expression)];
                        }
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes25, (changes, diag2) => {
                        const info = getInfo6(context.program.getTypeChecker(), diag2.file, diag2.start, diag2.code);
                        if (!info)
                            return void 0;
                        switch (context.fixId) {
                            case fixIdAddReturnStatement:
                                addReturnStatement(changes, diag2.file, info.expression, info.statement);
                                break;
                            case fixRemoveBracesFromArrowFunctionBody:
                                if (!isArrowFunction(info.declaration))
                                    return void 0;
                                removeBlockBodyBrace(changes, diag2.file, info.declaration, info.expression, info.commentSource, 
                                /* withParen */
                                false);
                                break;
                            case fixIdWrapTheBlockWithParen:
                                if (!isArrowFunction(info.declaration))
                                    return void 0;
                                wrapBlockWithParen(changes, diag2.file, info.declaration, info.expression);
                                break;
                            default:
                                Debug.fail(JSON.stringify(context.fixId));
                        }
                    })
                });
            }
        });
        // src/services/codefixes/fixAddMissingMember.ts
        function getInfo7(sourceFile, tokenPos, errorCode, checker, program) {
            var _a2;
            const token = getTokenAtPosition(sourceFile, tokenPos);
            const parent2 = token.parent;
            if (errorCode === Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code) {
                if (!(token.kind === 18 /* OpenBraceToken */ && isObjectLiteralExpression(parent2) && isCallExpression(parent2.parent)))
                    return void 0;
                const argIndex = findIndex(parent2.parent.arguments, (arg) => arg === parent2);
                if (argIndex < 0)
                    return void 0;
                const signature = checker.getResolvedSignature(parent2.parent);
                if (!(signature && signature.declaration && signature.parameters[argIndex]))
                    return void 0;
                const param = signature.parameters[argIndex].valueDeclaration;
                if (!(param && isParameter(param) && isIdentifier(param.name)))
                    return void 0;
                const properties = arrayFrom(checker.getUnmatchedProperties(checker.getTypeAtLocation(parent2), checker.getParameterType(signature, argIndex), 
                /* requireOptionalProperties */
                false, 
                /* matchDiscriminantProperties */
                false));
                if (!length(properties))
                    return void 0;
                return { kind: 3 /* ObjectLiteral */, token: param.name, properties, parentDeclaration: parent2 };
            }
            if (!isMemberName(token))
                return void 0;
            if (isIdentifier(token) && hasInitializer(parent2) && parent2.initializer && isObjectLiteralExpression(parent2.initializer)) {
                const properties = arrayFrom(checker.getUnmatchedProperties(checker.getTypeAtLocation(parent2.initializer), checker.getTypeAtLocation(token), 
                /* requireOptionalProperties */
                false, 
                /* matchDiscriminantProperties */
                false));
                if (!length(properties))
                    return void 0;
                return { kind: 3 /* ObjectLiteral */, token, properties, parentDeclaration: parent2.initializer };
            }
            if (isIdentifier(token) && isJsxOpeningLikeElement(token.parent)) {
                const target = getEmitScriptTarget(program.getCompilerOptions());
                const attributes = getUnmatchedAttributes(checker, target, token.parent);
                if (!length(attributes))
                    return void 0;
                return { kind: 4 /* JsxAttributes */, token, attributes, parentDeclaration: token.parent };
            }
            if (isIdentifier(token)) {
                const type = (_a2 = checker.getContextualType(token)) == null ? void 0 : _a2.getNonNullableType();
                if (type && getObjectFlags(type) & 16 /* Anonymous */) {
                    const signature = firstOrUndefined(checker.getSignaturesOfType(type, 0 /* Call */));
                    if (signature === void 0)
                        return void 0;
                    return { kind: 5 /* Signature */, token, signature, sourceFile, parentDeclaration: findScope(token) };
                }
                if (isCallExpression(parent2) && parent2.expression === token) {
                    return { kind: 2 /* Function */, token, call: parent2, sourceFile, modifierFlags: 0 /* None */, parentDeclaration: findScope(token) };
                }
            }
            if (!isPropertyAccessExpression(parent2))
                return void 0;
            const leftExpressionType = skipConstraint(checker.getTypeAtLocation(parent2.expression));
            const symbol = leftExpressionType.symbol;
            if (!symbol || !symbol.declarations)
                return void 0;
            if (isIdentifier(token) && isCallExpression(parent2.parent)) {
                const moduleDeclaration = find(symbol.declarations, isModuleDeclaration);
                const moduleDeclarationSourceFile = moduleDeclaration == null ? void 0 : moduleDeclaration.getSourceFile();
                if (moduleDeclaration && moduleDeclarationSourceFile && !isSourceFileFromLibrary(program, moduleDeclarationSourceFile)) {
                    return { kind: 2 /* Function */, token, call: parent2.parent, sourceFile, modifierFlags: 1 /* Export */, parentDeclaration: moduleDeclaration };
                }
                const moduleSourceFile = find(symbol.declarations, isSourceFile);
                if (sourceFile.commonJsModuleIndicator)
                    return void 0;
                if (moduleSourceFile && !isSourceFileFromLibrary(program, moduleSourceFile)) {
                    return { kind: 2 /* Function */, token, call: parent2.parent, sourceFile: moduleSourceFile, modifierFlags: 1 /* Export */, parentDeclaration: moduleSourceFile };
                }
            }
            const classDeclaration = find(symbol.declarations, isClassLike);
            if (!classDeclaration && isPrivateIdentifier(token))
                return void 0;
            const declaration = classDeclaration || find(symbol.declarations, (d) => isInterfaceDeclaration(d) || isTypeLiteralNode(d));
            if (declaration && !isSourceFileFromLibrary(program, declaration.getSourceFile())) {
                const makeStatic = !isTypeLiteralNode(declaration) && (leftExpressionType.target || leftExpressionType) !== checker.getDeclaredTypeOfSymbol(symbol);
                if (makeStatic && (isPrivateIdentifier(token) || isInterfaceDeclaration(declaration)))
                    return void 0;
                const declSourceFile = declaration.getSourceFile();
                const modifierFlags = isTypeLiteralNode(declaration) ? 0 /* None */ : (makeStatic ? 32 /* Static */ : 0 /* None */) | (startsWithUnderscore(token.text) ? 8 /* Private */ : 0 /* None */);
                const isJSFile = isSourceFileJS(declSourceFile);
                const call = tryCast(parent2.parent, isCallExpression);
                return { kind: 0 /* TypeLikeDeclaration */, token, call, modifierFlags, parentDeclaration: declaration, declSourceFile, isJSFile };
            }
            const enumDeclaration = find(symbol.declarations, isEnumDeclaration);
            if (enumDeclaration && !(leftExpressionType.flags & 1056 /* EnumLike */) && !isPrivateIdentifier(token) && !isSourceFileFromLibrary(program, enumDeclaration.getSourceFile())) {
                return { kind: 1 /* Enum */, token, parentDeclaration: enumDeclaration };
            }
            return void 0;
        }
        function getActionsForMissingMemberDeclaration(context, info) {
            return info.isJSFile ? singleElementArray(createActionForAddMissingMemberInJavascriptFile(context, info)) : createActionsForAddMissingMemberInTypeScriptFile(context, info);
        }
        function createActionForAddMissingMemberInJavascriptFile(context, { parentDeclaration, declSourceFile, modifierFlags, token }) {
            if (isInterfaceDeclaration(parentDeclaration) || isTypeLiteralNode(parentDeclaration)) {
                return void 0;
            }
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingMemberInJs(t, declSourceFile, parentDeclaration, token, !!(modifierFlags & 32 /* Static */)));
            if (changes.length === 0) {
                return void 0;
            }
            const diagnostic = modifierFlags & 32 /* Static */ ? Diagnostics.Initialize_static_property_0 : isPrivateIdentifier(token) ? Diagnostics.Declare_a_private_field_named_0 : Diagnostics.Initialize_property_0_in_the_constructor;
            return createCodeFixAction(fixMissingMember, changes, [diagnostic, token.text], fixMissingMember, Diagnostics.Add_all_missing_members);
        }
        function addMissingMemberInJs(changeTracker, sourceFile, classDeclaration, token, makeStatic) {
            const tokenName = token.text;
            if (makeStatic) {
                if (classDeclaration.kind === 228 /* ClassExpression */) {
                    return;
                }
                const className = classDeclaration.name.getText();
                const staticInitialization = initializePropertyToUndefined(factory.createIdentifier(className), tokenName);
                changeTracker.insertNodeAfter(sourceFile, classDeclaration, staticInitialization);
            }
            else if (isPrivateIdentifier(token)) {
                const property = factory.createPropertyDeclaration(
                /*modifiers*/
                void 0, tokenName, 
                /*questionToken*/
                void 0, 
                /*type*/
                void 0, 
                /*initializer*/
                void 0);
                const lastProp = getNodeToInsertPropertyAfter(classDeclaration);
                if (lastProp) {
                    changeTracker.insertNodeAfter(sourceFile, lastProp, property);
                }
                else {
                    changeTracker.insertMemberAtStart(sourceFile, classDeclaration, property);
                }
            }
            else {
                const classConstructor = getFirstConstructorWithBody(classDeclaration);
                if (!classConstructor) {
                    return;
                }
                const propertyInitialization = initializePropertyToUndefined(factory.createThis(), tokenName);
                changeTracker.insertNodeAtConstructorEnd(sourceFile, classConstructor, propertyInitialization);
            }
        }
        function initializePropertyToUndefined(obj, propertyName) {
            return factory.createExpressionStatement(factory.createAssignment(factory.createPropertyAccessExpression(obj, propertyName), createUndefined()));
        }
        function createActionsForAddMissingMemberInTypeScriptFile(context, { parentDeclaration, declSourceFile, modifierFlags, token }) {
            const memberName = token.text;
            const isStatic2 = modifierFlags & 32 /* Static */;
            const typeNode = getTypeNode2(context.program.getTypeChecker(), parentDeclaration, token);
            const addPropertyDeclarationChanges = (modifierFlags2) => ts_textChanges_exports.ChangeTracker.with(context, (t) => addPropertyDeclaration(t, declSourceFile, parentDeclaration, memberName, typeNode, modifierFlags2));
            const actions2 = [createCodeFixAction(fixMissingMember, addPropertyDeclarationChanges(modifierFlags & 32 /* Static */), [isStatic2 ? Diagnostics.Declare_static_property_0 : Diagnostics.Declare_property_0, memberName], fixMissingMember, Diagnostics.Add_all_missing_members)];
            if (isStatic2 || isPrivateIdentifier(token)) {
                return actions2;
            }
            if (modifierFlags & 8 /* Private */) {
                actions2.unshift(createCodeFixActionWithoutFixAll(fixMissingMember, addPropertyDeclarationChanges(8 /* Private */), [Diagnostics.Declare_private_property_0, memberName]));
            }
            actions2.push(createAddIndexSignatureAction(context, declSourceFile, parentDeclaration, token.text, typeNode));
            return actions2;
        }
        function getTypeNode2(checker, node, token) {
            let typeNode;
            if (token.parent.parent.kind === 223 /* BinaryExpression */) {
                const binaryExpression = token.parent.parent;
                const otherExpression = token.parent === binaryExpression.left ? binaryExpression.right : binaryExpression.left;
                const widenedType = checker.getWidenedType(checker.getBaseTypeOfLiteralType(checker.getTypeAtLocation(otherExpression)));
                typeNode = checker.typeToTypeNode(widenedType, node, 1 /* NoTruncation */);
            }
            else {
                const contextualType = checker.getContextualType(token.parent);
                typeNode = contextualType ? checker.typeToTypeNode(contextualType, 
                /*enclosingDeclaration*/
                void 0, 1 /* NoTruncation */) : void 0;
            }
            return typeNode || factory.createKeywordTypeNode(131 /* AnyKeyword */);
        }
        function addPropertyDeclaration(changeTracker, sourceFile, node, tokenName, typeNode, modifierFlags) {
            const modifiers = modifierFlags ? factory.createNodeArray(factory.createModifiersFromModifierFlags(modifierFlags)) : void 0;
            const property = isClassLike(node) ? factory.createPropertyDeclaration(modifiers, tokenName, 
            /*questionToken*/
            void 0, typeNode, 
            /*initializer*/
            void 0) : factory.createPropertySignature(
            /*modifiers*/
            void 0, tokenName, 
            /*questionToken*/
            void 0, typeNode);
            const lastProp = getNodeToInsertPropertyAfter(node);
            if (lastProp) {
                changeTracker.insertNodeAfter(sourceFile, lastProp, property);
            }
            else {
                changeTracker.insertMemberAtStart(sourceFile, node, property);
            }
        }
        function getNodeToInsertPropertyAfter(node) {
            let res;
            for (const member of node.members) {
                if (!isPropertyDeclaration(member))
                    break;
                res = member;
            }
            return res;
        }
        function createAddIndexSignatureAction(context, sourceFile, node, tokenName, typeNode) {
            const stringTypeNode = factory.createKeywordTypeNode(152 /* StringKeyword */);
            const indexingParameter = factory.createParameterDeclaration(
            /*modifiers*/
            void 0, 
            /*dotDotDotToken*/
            void 0, "x", 
            /*questionToken*/
            void 0, stringTypeNode, 
            /*initializer*/
            void 0);
            const indexSignature = factory.createIndexSignature(
            /*modifiers*/
            void 0, [indexingParameter], typeNode);
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => t.insertMemberAtStart(sourceFile, node, indexSignature));
            return createCodeFixActionWithoutFixAll(fixMissingMember, changes, [Diagnostics.Add_index_signature_for_property_0, tokenName]);
        }
        function getActionsForMissingMethodDeclaration(context, info) {
            const { parentDeclaration, declSourceFile, modifierFlags, token, call } = info;
            if (call === void 0) {
                return void 0;
            }
            if (isPrivateIdentifier(token)) {
                return void 0;
            }
            const methodName = token.text;
            const addMethodDeclarationChanges = (modifierFlags2) => ts_textChanges_exports.ChangeTracker.with(context, (t) => addMethodDeclaration(context, t, call, token, modifierFlags2, parentDeclaration, declSourceFile));
            const actions2 = [createCodeFixAction(fixMissingMember, addMethodDeclarationChanges(modifierFlags & 32 /* Static */), [modifierFlags & 32 /* Static */ ? Diagnostics.Declare_static_method_0 : Diagnostics.Declare_method_0, methodName], fixMissingMember, Diagnostics.Add_all_missing_members)];
            if (modifierFlags & 8 /* Private */) {
                actions2.unshift(createCodeFixActionWithoutFixAll(fixMissingMember, addMethodDeclarationChanges(8 /* Private */), [Diagnostics.Declare_private_method_0, methodName]));
            }
            return actions2;
        }
        function addMethodDeclaration(context, changes, callExpression, name, modifierFlags, parentDeclaration, sourceFile) {
            const importAdder = createImportAdder(sourceFile, context.program, context.preferences, context.host);
            const kind = isClassLike(parentDeclaration) ? 171 /* MethodDeclaration */ : 170 /* MethodSignature */;
            const signatureDeclaration = createSignatureDeclarationFromCallExpression(kind, context, importAdder, callExpression, name, modifierFlags, parentDeclaration);
            const containingMethodDeclaration = tryGetContainingMethodDeclaration(parentDeclaration, callExpression);
            if (containingMethodDeclaration) {
                changes.insertNodeAfter(sourceFile, containingMethodDeclaration, signatureDeclaration);
            }
            else {
                changes.insertMemberAtStart(sourceFile, parentDeclaration, signatureDeclaration);
            }
            importAdder.writeFixes(changes);
        }
        function addEnumMemberDeclaration(changes, checker, { token, parentDeclaration }) {
            const hasStringInitializer = some(parentDeclaration.members, (member) => {
                const type = checker.getTypeAtLocation(member);
                return !!(type && type.flags & 402653316 /* StringLike */);
            });
            const enumMember = factory.createEnumMember(token, hasStringInitializer ? factory.createStringLiteral(token.text) : void 0);
            changes.replaceNode(parentDeclaration.getSourceFile(), parentDeclaration, factory.updateEnumDeclaration(parentDeclaration, parentDeclaration.modifiers, parentDeclaration.name, concatenate(parentDeclaration.members, singleElementArray(enumMember))), {
                leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.IncludeAll,
                trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Exclude
            });
        }
        function addFunctionDeclaration(changes, context, info) {
            const quotePreference = getQuotePreference(context.sourceFile, context.preferences);
            const importAdder = createImportAdder(context.sourceFile, context.program, context.preferences, context.host);
            const functionDeclaration = info.kind === 2 /* Function */ ? createSignatureDeclarationFromCallExpression(259 /* FunctionDeclaration */, context, importAdder, info.call, idText(info.token), info.modifierFlags, info.parentDeclaration) : createSignatureDeclarationFromSignature(259 /* FunctionDeclaration */, context, quotePreference, info.signature, createStubbedBody(Diagnostics.Function_not_implemented.message, quotePreference), info.token, 
            /*modifiers*/
            void 0, 
            /*optional*/
            void 0, 
            /*enclosingDeclaration*/
            void 0, importAdder);
            if (functionDeclaration === void 0) {
                Debug.fail("fixMissingFunctionDeclaration codefix got unexpected error.");
            }
            isReturnStatement(info.parentDeclaration) ? changes.insertNodeBefore(info.sourceFile, info.parentDeclaration, functionDeclaration, 
            /*blankLineBetween*/
            true) : changes.insertNodeAtEndOfScope(info.sourceFile, info.parentDeclaration, functionDeclaration);
            importAdder.writeFixes(changes);
        }
        function addJsxAttributes(changes, context, info) {
            const importAdder = createImportAdder(context.sourceFile, context.program, context.preferences, context.host);
            const quotePreference = getQuotePreference(context.sourceFile, context.preferences);
            const checker = context.program.getTypeChecker();
            const jsxAttributesNode = info.parentDeclaration.attributes;
            const hasSpreadAttribute = some(jsxAttributesNode.properties, isJsxSpreadAttribute);
            const attrs = map(info.attributes, (attr) => {
                const value = tryGetValueFromType(context, checker, importAdder, quotePreference, checker.getTypeOfSymbol(attr), info.parentDeclaration);
                const name = factory.createIdentifier(attr.name);
                const jsxAttribute = factory.createJsxAttribute(name, factory.createJsxExpression(
                /*dotDotDotToken*/
                void 0, value));
                setParent(name, jsxAttribute);
                return jsxAttribute;
            });
            const jsxAttributes = factory.createJsxAttributes(hasSpreadAttribute ? [...attrs, ...jsxAttributesNode.properties] : [...jsxAttributesNode.properties, ...attrs]);
            const options = { prefix: jsxAttributesNode.pos === jsxAttributesNode.end ? " " : void 0 };
            changes.replaceNode(context.sourceFile, jsxAttributesNode, jsxAttributes, options);
            importAdder.writeFixes(changes);
        }
        function addObjectLiteralProperties(changes, context, info) {
            const importAdder = createImportAdder(context.sourceFile, context.program, context.preferences, context.host);
            const quotePreference = getQuotePreference(context.sourceFile, context.preferences);
            const target = getEmitScriptTarget(context.program.getCompilerOptions());
            const checker = context.program.getTypeChecker();
            const props = map(info.properties, (prop) => {
                const initializer = tryGetValueFromType(context, checker, importAdder, quotePreference, checker.getTypeOfSymbol(prop), info.parentDeclaration);
                return factory.createPropertyAssignment(createPropertyNameFromSymbol(prop, target, quotePreference, checker), initializer);
            });
            const options = {
                leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude,
                trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Exclude,
                indentation: info.indentation
            };
            changes.replaceNode(context.sourceFile, info.parentDeclaration, factory.createObjectLiteralExpression([...info.parentDeclaration.properties, ...props], 
            /*multiLine*/
            true), options);
            importAdder.writeFixes(changes);
        }
        function tryGetValueFromType(context, checker, importAdder, quotePreference, type, enclosingDeclaration) {
            if (type.flags & 3 /* AnyOrUnknown */) {
                return createUndefined();
            }
            if (type.flags & (4 /* String */ | 134217728 /* TemplateLiteral */)) {
                return factory.createStringLiteral("", 
                /* isSingleQuote */
                quotePreference === 0 /* Single */);
            }
            if (type.flags & 8 /* Number */) {
                return factory.createNumericLiteral(0);
            }
            if (type.flags & 64 /* BigInt */) {
                return factory.createBigIntLiteral("0n");
            }
            if (type.flags & 16 /* Boolean */) {
                return factory.createFalse();
            }
            if (type.flags & 1056 /* EnumLike */) {
                const enumMember = type.symbol.exports ? firstOrUndefinedIterator(type.symbol.exports.values()) : type.symbol;
                const name = checker.symbolToExpression(type.symbol.parent ? type.symbol.parent : type.symbol, 111551 /* Value */, 
                /*enclosingDeclaration*/
                void 0, 
                /*flags*/
                void 0);
                return enumMember === void 0 || name === void 0 ? factory.createNumericLiteral(0) : factory.createPropertyAccessExpression(name, checker.symbolToString(enumMember));
            }
            if (type.flags & 256 /* NumberLiteral */) {
                return factory.createNumericLiteral(type.value);
            }
            if (type.flags & 2048 /* BigIntLiteral */) {
                return factory.createBigIntLiteral(type.value);
            }
            if (type.flags & 128 /* StringLiteral */) {
                return factory.createStringLiteral(type.value, 
                /* isSingleQuote */
                quotePreference === 0 /* Single */);
            }
            if (type.flags & 512 /* BooleanLiteral */) {
                return type === checker.getFalseType() || type === checker.getFalseType(
                /*fresh*/
                true) ? factory.createFalse() : factory.createTrue();
            }
            if (type.flags & 65536 /* Null */) {
                return factory.createNull();
            }
            if (type.flags & 1048576 /* Union */) {
                const expression = firstDefined(type.types, (t) => tryGetValueFromType(context, checker, importAdder, quotePreference, t, enclosingDeclaration));
                return expression != null ? expression : createUndefined();
            }
            if (checker.isArrayLikeType(type)) {
                return factory.createArrayLiteralExpression();
            }
            if (isObjectLiteralType(type)) {
                const props = map(checker.getPropertiesOfType(type), (prop) => {
                    const initializer = tryGetValueFromType(context, checker, importAdder, quotePreference, checker.getTypeOfSymbol(prop), enclosingDeclaration);
                    return factory.createPropertyAssignment(prop.name, initializer);
                });
                return factory.createObjectLiteralExpression(props, 
                /*multiLine*/
                true);
            }
            if (getObjectFlags(type) & 16 /* Anonymous */) {
                const decl = find(type.symbol.declarations || emptyArray, or(isFunctionTypeNode, isMethodSignature, isMethodDeclaration));
                if (decl === void 0)
                    return createUndefined();
                const signature = checker.getSignaturesOfType(type, 0 /* Call */);
                if (signature === void 0)
                    return createUndefined();
                const func = createSignatureDeclarationFromSignature(215 /* FunctionExpression */, context, quotePreference, signature[0], createStubbedBody(Diagnostics.Function_not_implemented.message, quotePreference), 
                /*name*/
                void 0, 
                /*modifiers*/
                void 0, 
                /*optional*/
                void 0, 
                /*enclosingDeclaration*/
                enclosingDeclaration, importAdder);
                return func != null ? func : createUndefined();
            }
            if (getObjectFlags(type) & 1 /* Class */) {
                const classDeclaration = getClassLikeDeclarationOfSymbol(type.symbol);
                if (classDeclaration === void 0 || hasAbstractModifier(classDeclaration))
                    return createUndefined();
                const constructorDeclaration = getFirstConstructorWithBody(classDeclaration);
                if (constructorDeclaration && length(constructorDeclaration.parameters))
                    return createUndefined();
                return factory.createNewExpression(factory.createIdentifier(type.symbol.name), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                void 0);
            }
            return createUndefined();
        }
        function createUndefined() {
            return factory.createIdentifier("undefined");
        }
        function isObjectLiteralType(type) {
            return type.flags & 524288 /* Object */ && (getObjectFlags(type) & 128 /* ObjectLiteral */ || type.symbol && tryCast(singleOrUndefined(type.symbol.declarations), isTypeLiteralNode));
        }
        function getUnmatchedAttributes(checker, target, source) {
            const attrsType = checker.getContextualType(source.attributes);
            if (attrsType === void 0)
                return emptyArray;
            const targetProps = attrsType.getProperties();
            if (!length(targetProps))
                return emptyArray;
            const seenNames = /* @__PURE__ */ new Set();
            for (const sourceProp of source.attributes.properties) {
                if (isJsxAttribute(sourceProp)) {
                    seenNames.add(sourceProp.name.escapedText);
                }
                if (isJsxSpreadAttribute(sourceProp)) {
                    const type = checker.getTypeAtLocation(sourceProp.expression);
                    for (const prop of type.getProperties()) {
                        seenNames.add(prop.escapedName);
                    }
                }
            }
            return filter(targetProps, (targetProp) => isIdentifierText(targetProp.name, target, 1 /* JSX */) && !(targetProp.flags & 16777216 /* Optional */ || getCheckFlags(targetProp) & 48 /* Partial */ || seenNames.has(targetProp.escapedName)));
        }
        function tryGetContainingMethodDeclaration(node, callExpression) {
            if (isTypeLiteralNode(node)) {
                return void 0;
            }
            const declaration = findAncestor(callExpression, (n) => isMethodDeclaration(n) || isConstructorDeclaration(n));
            return declaration && declaration.parent === node ? declaration : void 0;
        }
        function createPropertyNameFromSymbol(symbol, target, quotePreference, checker) {
            if (isTransientSymbol(symbol)) {
                const prop = checker.symbolToNode(symbol, 111551 /* Value */, 
                /*enclosingDeclaration*/
                void 0, 1073741824 /* WriteComputedProps */);
                if (prop && isComputedPropertyName(prop))
                    return prop;
            }
            return createPropertyNameNodeForIdentifierOrLiteral(symbol.name, target, quotePreference === 0 /* Single */);
        }
        function findScope(node) {
            if (findAncestor(node, isJsxExpression)) {
                const returnStatement = findAncestor(node.parent, isReturnStatement);
                if (returnStatement)
                    return returnStatement;
            }
            return getSourceFileOfNode(node);
        }
        var fixMissingMember, fixMissingProperties, fixMissingAttributes, fixMissingFunctionDeclaration, errorCodes26;
        var init_fixAddMissingMember = __esm({
            "src/services/codefixes/fixAddMissingMember.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixMissingMember = "fixMissingMember";
                fixMissingProperties = "fixMissingProperties";
                fixMissingAttributes = "fixMissingAttributes";
                fixMissingFunctionDeclaration = "fixMissingFunctionDeclaration";
                errorCodes26 = [
                    Diagnostics.Property_0_does_not_exist_on_type_1.code,
                    Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2.code,
                    Diagnostics.Property_0_is_missing_in_type_1_but_required_in_type_2.code,
                    Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2.code,
                    Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,
                    Diagnostics.Cannot_find_name_0.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes26,
                    getCodeActions(context) {
                        const typeChecker = context.program.getTypeChecker();
                        const info = getInfo7(context.sourceFile, context.span.start, context.errorCode, typeChecker, context.program);
                        if (!info) {
                            return void 0;
                        }
                        if (info.kind === 3 /* ObjectLiteral */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addObjectLiteralProperties(t, context, info));
                            return [createCodeFixAction(fixMissingProperties, changes, Diagnostics.Add_missing_properties, fixMissingProperties, Diagnostics.Add_all_missing_properties)];
                        }
                        if (info.kind === 4 /* JsxAttributes */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addJsxAttributes(t, context, info));
                            return [createCodeFixAction(fixMissingAttributes, changes, Diagnostics.Add_missing_attributes, fixMissingAttributes, Diagnostics.Add_all_missing_attributes)];
                        }
                        if (info.kind === 2 /* Function */ || info.kind === 5 /* Signature */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addFunctionDeclaration(t, context, info));
                            return [createCodeFixAction(fixMissingFunctionDeclaration, changes, [Diagnostics.Add_missing_function_declaration_0, info.token.text], fixMissingFunctionDeclaration, Diagnostics.Add_all_missing_function_declarations)];
                        }
                        if (info.kind === 1 /* Enum */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addEnumMemberDeclaration(t, context.program.getTypeChecker(), info));
                            return [createCodeFixAction(fixMissingMember, changes, [Diagnostics.Add_missing_enum_member_0, info.token.text], fixMissingMember, Diagnostics.Add_all_missing_members)];
                        }
                        return concatenate(getActionsForMissingMethodDeclaration(context, info), getActionsForMissingMemberDeclaration(context, info));
                    },
                    fixIds: [fixMissingMember, fixMissingFunctionDeclaration, fixMissingProperties, fixMissingAttributes],
                    getAllCodeActions: (context) => {
                        const { program, fixId: fixId51 } = context;
                        const checker = program.getTypeChecker();
                        const seen = /* @__PURE__ */ new Map();
                        const typeDeclToMembers = /* @__PURE__ */ new Map();
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            eachDiagnostic(context, errorCodes26, (diag2) => {
                                const info = getInfo7(diag2.file, diag2.start, diag2.code, checker, context.program);
                                if (!info || !addToSeen(seen, getNodeId(info.parentDeclaration) + "#" + info.token.text)) {
                                    return;
                                }
                                if (fixId51 === fixMissingFunctionDeclaration && (info.kind === 2 /* Function */ || info.kind === 5 /* Signature */)) {
                                    addFunctionDeclaration(changes, context, info);
                                }
                                else if (fixId51 === fixMissingProperties && info.kind === 3 /* ObjectLiteral */) {
                                    addObjectLiteralProperties(changes, context, info);
                                }
                                else if (fixId51 === fixMissingAttributes && info.kind === 4 /* JsxAttributes */) {
                                    addJsxAttributes(changes, context, info);
                                }
                                else {
                                    if (info.kind === 1 /* Enum */) {
                                        addEnumMemberDeclaration(changes, checker, info);
                                    }
                                    if (info.kind === 0 /* TypeLikeDeclaration */) {
                                        const { parentDeclaration, token } = info;
                                        const infos = getOrUpdate(typeDeclToMembers, parentDeclaration, () => []);
                                        if (!infos.some((i) => i.token.text === token.text)) {
                                            infos.push(info);
                                        }
                                    }
                                }
                            });
                            typeDeclToMembers.forEach((infos, declaration) => {
                                const supers = isTypeLiteralNode(declaration) ? void 0 : getAllSupers(declaration, checker);
                                for (const info of infos) {
                                    if (supers == null ? void 0 : supers.some((superClassOrInterface) => {
                                        const superInfos = typeDeclToMembers.get(superClassOrInterface);
                                        return !!superInfos && superInfos.some(({ token: token2 }) => token2.text === info.token.text);
                                    }))
                                        continue;
                                    const { parentDeclaration, declSourceFile, modifierFlags, token, call, isJSFile } = info;
                                    if (call && !isPrivateIdentifier(token)) {
                                        addMethodDeclaration(context, changes, call, token, modifierFlags & 32 /* Static */, parentDeclaration, declSourceFile);
                                    }
                                    else {
                                        if (isJSFile && !isInterfaceDeclaration(parentDeclaration) && !isTypeLiteralNode(parentDeclaration)) {
                                            addMissingMemberInJs(changes, declSourceFile, parentDeclaration, token, !!(modifierFlags & 32 /* Static */));
                                        }
                                        else {
                                            const typeNode = getTypeNode2(checker, parentDeclaration, token);
                                            addPropertyDeclaration(changes, declSourceFile, parentDeclaration, token.text, typeNode, modifierFlags & 32 /* Static */);
                                        }
                                    }
                                }
                            });
                        }));
                    }
                });
            }
        });
        // src/services/codefixes/fixAddMissingNewOperator.ts
        function addMissingNewOperator(changes, sourceFile, span) {
            const call = cast(findAncestorMatchingSpan2(sourceFile, span), isCallExpression);
            const newExpression = factory.createNewExpression(call.expression, call.typeArguments, call.arguments);
            changes.replaceNode(sourceFile, call, newExpression);
        }
        function findAncestorMatchingSpan2(sourceFile, span) {
            let token = getTokenAtPosition(sourceFile, span.start);
            const end = textSpanEnd(span);
            while (token.end < end) {
                token = token.parent;
            }
            return token;
        }
        var fixId23, errorCodes27;
        var init_fixAddMissingNewOperator = __esm({
            "src/services/codefixes/fixAddMissingNewOperator.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId23 = "addMissingNewOperator";
                errorCodes27 = [Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new.code];
                registerCodeFix({
                    errorCodes: errorCodes27,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingNewOperator(t, sourceFile, span));
                        return [createCodeFixAction(fixId23, changes, Diagnostics.Add_missing_new_operator_to_call, fixId23, Diagnostics.Add_missing_new_operator_to_all_calls)];
                    },
                    fixIds: [fixId23],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes27, (changes, diag2) => addMissingNewOperator(changes, context.sourceFile, diag2))
                });
            }
        });
        // src/services/codefixes/fixCannotFindModule.ts
        function getInstallCommand(fileName, packageName) {
            return { type: "install package", file: fileName, packageName };
        }
        function tryGetImportedPackageName(sourceFile, pos) {
            const moduleSpecifierText = tryCast(getTokenAtPosition(sourceFile, pos), isStringLiteral);
            if (!moduleSpecifierText)
                return void 0;
            const moduleName = moduleSpecifierText.text;
            const { packageName } = parsePackageName(moduleName);
            return isExternalModuleNameRelative(packageName) ? void 0 : packageName;
        }
        function getTypesPackageNameToInstall(packageName, host, diagCode) {
            var _a2;
            return diagCode === errorCodeCannotFindModule ? ts_JsTyping_exports.nodeCoreModules.has(packageName) ? "@types/node" : void 0 : ((_a2 = host.isKnownTypesPackageName) == null ? void 0 : _a2.call(host, packageName)) ? getTypesPackageName(packageName) : void 0;
        }
        var fixName2, fixIdInstallTypesPackage, errorCodeCannotFindModule, errorCodes28;
        var init_fixCannotFindModule = __esm({
            "src/services/codefixes/fixCannotFindModule.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName2 = "fixCannotFindModule";
                fixIdInstallTypesPackage = "installTypesPackage";
                errorCodeCannotFindModule = Diagnostics.Cannot_find_module_0_or_its_corresponding_type_declarations.code;
                errorCodes28 = [
                    errorCodeCannotFindModule,
                    Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes28,
                    getCodeActions: function getCodeActionsToFixNotFoundModule(context) {
                        const { host, sourceFile, span: { start } } = context;
                        const packageName = tryGetImportedPackageName(sourceFile, start);
                        if (packageName === void 0)
                            return void 0;
                        const typesPackageName = getTypesPackageNameToInstall(packageName, host, context.errorCode);
                        return typesPackageName === void 0 ? [] : [createCodeFixAction(fixName2, 
                            /*changes*/
                            [], [Diagnostics.Install_0, typesPackageName], fixIdInstallTypesPackage, Diagnostics.Install_all_missing_types_packages, getInstallCommand(sourceFile.fileName, typesPackageName))];
                    },
                    fixIds: [fixIdInstallTypesPackage],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes28, (_changes, diag2, commands) => {
                            const packageName = tryGetImportedPackageName(diag2.file, diag2.start);
                            if (packageName === void 0)
                                return void 0;
                            switch (context.fixId) {
                                case fixIdInstallTypesPackage: {
                                    const pkg = getTypesPackageNameToInstall(packageName, context.host, diag2.code);
                                    if (pkg) {
                                        commands.push(getInstallCommand(diag2.file.fileName, pkg));
                                    }
                                    break;
                                }
                                default:
                                    Debug.fail(`Bad fixId: ${context.fixId}`);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixClassDoesntImplementInheritedAbstractMember.ts
        function getClass2(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            return cast(token.parent, isClassLike);
        }
        function addMissingMembers(classDeclaration, sourceFile, context, changeTracker, preferences) {
            const extendsNode = getEffectiveBaseTypeNode(classDeclaration);
            const checker = context.program.getTypeChecker();
            const instantiatedExtendsType = checker.getTypeAtLocation(extendsNode);
            const abstractAndNonPrivateExtendsSymbols = checker.getPropertiesOfType(instantiatedExtendsType).filter(symbolPointsToNonPrivateAndAbstractMember);
            const importAdder = createImportAdder(sourceFile, context.program, preferences, context.host);
            createMissingMemberNodes(classDeclaration, abstractAndNonPrivateExtendsSymbols, sourceFile, context, preferences, importAdder, (member) => changeTracker.insertMemberAtStart(sourceFile, classDeclaration, member));
            importAdder.writeFixes(changeTracker);
        }
        function symbolPointsToNonPrivateAndAbstractMember(symbol) {
            const flags = getSyntacticModifierFlags(first(symbol.getDeclarations()));
            return !(flags & 8 /* Private */) && !!(flags & 256 /* Abstract */);
        }
        var errorCodes29, fixId24;
        var init_fixClassDoesntImplementInheritedAbstractMember = __esm({
            "src/services/codefixes/fixClassDoesntImplementInheritedAbstractMember.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes29 = [
                    Diagnostics.Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2.code,
                    Diagnostics.Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1.code
                ];
                fixId24 = "fixClassDoesntImplementInheritedAbstractMember";
                registerCodeFix({
                    errorCodes: errorCodes29,
                    getCodeActions: function getCodeActionsToFixClassNotImplementingInheritedMembers(context) {
                        const { sourceFile, span } = context;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingMembers(getClass2(sourceFile, span.start), sourceFile, context, t, context.preferences));
                        return changes.length === 0 ? void 0 : [createCodeFixAction(fixId24, changes, Diagnostics.Implement_inherited_abstract_class, fixId24, Diagnostics.Implement_all_inherited_abstract_classes)];
                    },
                    fixIds: [fixId24],
                    getAllCodeActions: function getAllCodeActionsToFixClassDoesntImplementInheritedAbstractMember(context) {
                        const seenClassDeclarations = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes29, (changes, diag2) => {
                            const classDeclaration = getClass2(diag2.file, diag2.start);
                            if (addToSeen(seenClassDeclarations, getNodeId(classDeclaration))) {
                                addMissingMembers(classDeclaration, context.sourceFile, context, changes, context.preferences);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixClassSuperMustPrecedeThisAccess.ts
        function doChange11(changes, sourceFile, constructor, superCall) {
            changes.insertNodeAtConstructorStart(sourceFile, constructor, superCall);
            changes.delete(sourceFile, superCall);
        }
        function getNodes(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (token.kind !== 108 /* ThisKeyword */)
                return void 0;
            const constructor = getContainingFunction(token);
            const superCall = findSuperCall(constructor.body);
            return superCall && !superCall.expression.arguments.some((arg) => isPropertyAccessExpression(arg) && arg.expression === token) ? { constructor, superCall } : void 0;
        }
        function findSuperCall(n) {
            return isExpressionStatement(n) && isSuperCall(n.expression) ? n : isFunctionLike(n) ? void 0 : forEachChild(n, findSuperCall);
        }
        var fixId25, errorCodes30;
        var init_fixClassSuperMustPrecedeThisAccess = __esm({
            "src/services/codefixes/fixClassSuperMustPrecedeThisAccess.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId25 = "classSuperMustPrecedeThisAccess";
                errorCodes30 = [Diagnostics.super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class.code];
                registerCodeFix({
                    errorCodes: errorCodes30,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const nodes = getNodes(sourceFile, span.start);
                        if (!nodes)
                            return void 0;
                        const { constructor, superCall } = nodes;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange11(t, sourceFile, constructor, superCall));
                        return [createCodeFixAction(fixId25, changes, Diagnostics.Make_super_call_the_first_statement_in_the_constructor, fixId25, Diagnostics.Make_all_super_calls_the_first_statement_in_their_constructor)];
                    },
                    fixIds: [fixId25],
                    getAllCodeActions(context) {
                        const { sourceFile } = context;
                        const seenClasses = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes30, (changes, diag2) => {
                            const nodes = getNodes(diag2.file, diag2.start);
                            if (!nodes)
                                return;
                            const { constructor, superCall } = nodes;
                            if (addToSeen(seenClasses, getNodeId(constructor.parent))) {
                                doChange11(changes, sourceFile, constructor, superCall);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixConstructorForDerivedNeedSuperCall.ts
        function getNode(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            Debug.assert(isConstructorDeclaration(token.parent), "token should be at the constructor declaration");
            return token.parent;
        }
        function doChange12(changes, sourceFile, ctr) {
            const superCall = factory.createExpressionStatement(factory.createCallExpression(factory.createSuper(), 
            /*typeArguments*/
            void 0, 
            /*argumentsArray*/
            emptyArray));
            changes.insertNodeAtConstructorStart(sourceFile, ctr, superCall);
        }
        var fixId26, errorCodes31;
        var init_fixConstructorForDerivedNeedSuperCall = __esm({
            "src/services/codefixes/fixConstructorForDerivedNeedSuperCall.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId26 = "constructorForDerivedNeedSuperCall";
                errorCodes31 = [Diagnostics.Constructors_for_derived_classes_must_contain_a_super_call.code];
                registerCodeFix({
                    errorCodes: errorCodes31,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const ctr = getNode(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange12(t, sourceFile, ctr));
                        return [createCodeFixAction(fixId26, changes, Diagnostics.Add_missing_super_call, fixId26, Diagnostics.Add_all_missing_super_calls)];
                    },
                    fixIds: [fixId26],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes31, (changes, diag2) => doChange12(changes, context.sourceFile, getNode(diag2.file, diag2.start)))
                });
            }
        });
        // src/services/codefixes/fixEnableJsxFlag.ts
        function doChange13(changeTracker, configFile) {
            setJsonCompilerOptionValue(changeTracker, configFile, "jsx", factory.createStringLiteral("react"));
        }
        var fixID, errorCodes32;
        var init_fixEnableJsxFlag = __esm({
            "src/services/codefixes/fixEnableJsxFlag.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixID = "fixEnableJsxFlag";
                errorCodes32 = [Diagnostics.Cannot_use_JSX_unless_the_jsx_flag_is_provided.code];
                registerCodeFix({
                    errorCodes: errorCodes32,
                    getCodeActions: function getCodeActionsToFixEnableJsxFlag(context) {
                        const { configFile } = context.program.getCompilerOptions();
                        if (configFile === void 0) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changeTracker) => doChange13(changeTracker, configFile));
                        return [
                            createCodeFixActionWithoutFixAll(fixID, changes, Diagnostics.Enable_the_jsx_flag_in_your_configuration_file)
                        ];
                    },
                    fixIds: [fixID],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes32, (changes) => {
                        const { configFile } = context.program.getCompilerOptions();
                        if (configFile === void 0) {
                            return void 0;
                        }
                        doChange13(changes, configFile);
                    })
                });
            }
        });
        // src/services/codefixes/fixNaNEquality.ts
        function getInfo8(program, sourceFile, span) {
            const diag2 = find(program.getSemanticDiagnostics(sourceFile), (diag3) => diag3.start === span.start && diag3.length === span.length);
            if (diag2 === void 0 || diag2.relatedInformation === void 0)
                return;
            const related = find(diag2.relatedInformation, (related2) => related2.code === Diagnostics.Did_you_mean_0.code);
            if (related === void 0 || related.file === void 0 || related.start === void 0 || related.length === void 0)
                return;
            const token = findAncestorMatchingSpan(related.file, createTextSpan(related.start, related.length));
            if (token === void 0)
                return;
            if (isExpression(token) && isBinaryExpression(token.parent)) {
                return { suggestion: getSuggestion(related.messageText), expression: token.parent, arg: token };
            }
            return void 0;
        }
        function doChange14(changes, sourceFile, arg, expression) {
            const callExpression = factory.createCallExpression(factory.createPropertyAccessExpression(factory.createIdentifier("Number"), factory.createIdentifier("isNaN")), 
            /*typeArguments*/
            void 0, [arg]);
            const operator = expression.operatorToken.kind;
            changes.replaceNode(sourceFile, expression, operator === 37 /* ExclamationEqualsEqualsToken */ || operator === 35 /* ExclamationEqualsToken */ ? factory.createPrefixUnaryExpression(53 /* ExclamationToken */, callExpression) : callExpression);
        }
        function getSuggestion(messageText) {
            const [_, suggestion] = flattenDiagnosticMessageText(messageText, "\n", 0).match(/\'(.*)\'/) || [];
            return suggestion;
        }
        var fixId27, errorCodes33;
        var init_fixNaNEquality = __esm({
            "src/services/codefixes/fixNaNEquality.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId27 = "fixNaNEquality";
                errorCodes33 = [
                    Diagnostics.This_condition_will_always_return_0.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes33,
                    getCodeActions(context) {
                        const { sourceFile, span, program } = context;
                        const info = getInfo8(program, sourceFile, span);
                        if (info === void 0)
                            return;
                        const { suggestion, expression, arg } = info;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange14(t, sourceFile, arg, expression));
                        return [createCodeFixAction(fixId27, changes, [Diagnostics.Use_0, suggestion], fixId27, Diagnostics.Use_Number_isNaN_in_all_conditions)];
                    },
                    fixIds: [fixId27],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes33, (changes, diag2) => {
                            const info = getInfo8(context.program, diag2.file, createTextSpan(diag2.start, diag2.length));
                            if (info) {
                                doChange14(changes, diag2.file, info.arg, info.expression);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixModuleAndTargetOptions.ts
        var init_fixModuleAndTargetOptions = __esm({
            "src/services/codefixes/fixModuleAndTargetOptions.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                registerCodeFix({
                    errorCodes: [
                        Diagnostics.Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_or_nodenext_and_the_target_option_is_set_to_es2017_or_higher.code,
                        Diagnostics.Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_or_nodenext_and_the_target_option_is_set_to_es2017_or_higher.code
                    ],
                    getCodeActions: function getCodeActionsToFixModuleAndTarget(context) {
                        const compilerOptions = context.program.getCompilerOptions();
                        const { configFile } = compilerOptions;
                        if (configFile === void 0) {
                            return void 0;
                        }
                        const codeFixes = [];
                        const moduleKind = getEmitModuleKind(compilerOptions);
                        const moduleOutOfRange = moduleKind >= 5 /* ES2015 */ && moduleKind < 99 /* ESNext */;
                        if (moduleOutOfRange) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => {
                                setJsonCompilerOptionValue(changes2, configFile, "module", factory.createStringLiteral("esnext"));
                            });
                            codeFixes.push(createCodeFixActionWithoutFixAll("fixModuleOption", changes, [Diagnostics.Set_the_module_option_in_your_configuration_file_to_0, "esnext"]));
                        }
                        const target = getEmitScriptTarget(compilerOptions);
                        const targetOutOfRange = target < 4 /* ES2017 */ || target > 99 /* ESNext */;
                        if (targetOutOfRange) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (tracker) => {
                                const configObject = getTsConfigObjectLiteralExpression(configFile);
                                if (!configObject)
                                    return;
                                const options = [["target", factory.createStringLiteral("es2017")]];
                                if (moduleKind === 1 /* CommonJS */) {
                                    options.push(["module", factory.createStringLiteral("commonjs")]);
                                }
                                setJsonCompilerOptionValues(tracker, configFile, options);
                            });
                            codeFixes.push(createCodeFixActionWithoutFixAll("fixTargetOption", changes, [Diagnostics.Set_the_target_option_in_your_configuration_file_to_0, "es2017"]));
                        }
                        return codeFixes.length ? codeFixes : void 0;
                    }
                });
            }
        });
        // src/services/codefixes/fixPropertyAssignment.ts
        function doChange15(changes, sourceFile, node) {
            changes.replaceNode(sourceFile, node, factory.createPropertyAssignment(node.name, node.objectAssignmentInitializer));
        }
        function getProperty2(sourceFile, pos) {
            return cast(getTokenAtPosition(sourceFile, pos).parent, isShorthandPropertyAssignment);
        }
        var fixId28, errorCodes34;
        var init_fixPropertyAssignment = __esm({
            "src/services/codefixes/fixPropertyAssignment.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId28 = "fixPropertyAssignment";
                errorCodes34 = [
                    Diagnostics.Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes34,
                    fixIds: [fixId28],
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const property = getProperty2(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange15(t, context.sourceFile, property));
                        return [createCodeFixAction(fixId28, changes, [Diagnostics.Change_0_to_1, "=", ":"], fixId28, [Diagnostics.Switch_each_misused_0_to_1, "=", ":"])];
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes34, (changes, diag2) => doChange15(changes, diag2.file, getProperty2(diag2.file, diag2.start)))
                });
            }
        });
        // src/services/codefixes/fixExtendsInterfaceBecomesImplements.ts
        function getNodes2(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const heritageClauses = getContainingClass(token).heritageClauses;
            const extendsToken = heritageClauses[0].getFirstToken();
            return extendsToken.kind === 94 /* ExtendsKeyword */ ? { extendsToken, heritageClauses } : void 0;
        }
        function doChanges2(changes, sourceFile, extendsToken, heritageClauses) {
            changes.replaceNode(sourceFile, extendsToken, factory.createToken(117 /* ImplementsKeyword */));
            if (heritageClauses.length === 2 && heritageClauses[0].token === 94 /* ExtendsKeyword */ && heritageClauses[1].token === 117 /* ImplementsKeyword */) {
                const implementsToken = heritageClauses[1].getFirstToken();
                const implementsFullStart = implementsToken.getFullStart();
                changes.replaceRange(sourceFile, { pos: implementsFullStart, end: implementsFullStart }, factory.createToken(27 /* CommaToken */));
                const text = sourceFile.text;
                let end = implementsToken.end;
                while (end < text.length && isWhiteSpaceSingleLine(text.charCodeAt(end))) {
                    end++;
                }
                changes.deleteRange(sourceFile, { pos: implementsToken.getStart(), end });
            }
        }
        var fixId29, errorCodes35;
        var init_fixExtendsInterfaceBecomesImplements = __esm({
            "src/services/codefixes/fixExtendsInterfaceBecomesImplements.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId29 = "extendsInterfaceBecomesImplements";
                errorCodes35 = [Diagnostics.Cannot_extend_an_interface_0_Did_you_mean_implements.code];
                registerCodeFix({
                    errorCodes: errorCodes35,
                    getCodeActions(context) {
                        const { sourceFile } = context;
                        const nodes = getNodes2(sourceFile, context.span.start);
                        if (!nodes)
                            return void 0;
                        const { extendsToken, heritageClauses } = nodes;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChanges2(t, sourceFile, extendsToken, heritageClauses));
                        return [createCodeFixAction(fixId29, changes, Diagnostics.Change_extends_to_implements, fixId29, Diagnostics.Change_all_extended_interfaces_to_implements)];
                    },
                    fixIds: [fixId29],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes35, (changes, diag2) => {
                        const nodes = getNodes2(diag2.file, diag2.start);
                        if (nodes)
                            doChanges2(changes, diag2.file, nodes.extendsToken, nodes.heritageClauses);
                    })
                });
            }
        });
        // src/services/codefixes/fixForgottenThisPropertyAccess.ts
        function getInfo9(sourceFile, pos, diagCode) {
            const node = getTokenAtPosition(sourceFile, pos);
            if (isIdentifier(node) || isPrivateIdentifier(node)) {
                return { node, className: diagCode === didYouMeanStaticMemberCode ? getContainingClass(node).name.text : void 0 };
            }
        }
        function doChange16(changes, sourceFile, { node, className }) {
            suppressLeadingAndTrailingTrivia(node);
            changes.replaceNode(sourceFile, node, factory.createPropertyAccessExpression(className ? factory.createIdentifier(className) : factory.createThis(), node));
        }
        var fixId30, didYouMeanStaticMemberCode, errorCodes36;
        var init_fixForgottenThisPropertyAccess = __esm({
            "src/services/codefixes/fixForgottenThisPropertyAccess.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId30 = "forgottenThisPropertyAccess";
                didYouMeanStaticMemberCode = Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0.code;
                errorCodes36 = [
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0.code,
                    Diagnostics.Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression.code,
                    didYouMeanStaticMemberCode
                ];
                registerCodeFix({
                    errorCodes: errorCodes36,
                    getCodeActions(context) {
                        const { sourceFile } = context;
                        const info = getInfo9(sourceFile, context.span.start, context.errorCode);
                        if (!info) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange16(t, sourceFile, info));
                        return [createCodeFixAction(fixId30, changes, [Diagnostics.Add_0_to_unresolved_variable, info.className || "this"], fixId30, Diagnostics.Add_qualifier_to_all_unresolved_variables_matching_a_member_name)];
                    },
                    fixIds: [fixId30],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes36, (changes, diag2) => {
                        const info = getInfo9(diag2.file, diag2.start, diag2.code);
                        if (info)
                            doChange16(changes, context.sourceFile, info);
                    })
                });
            }
        });
        // src/services/codefixes/fixInvalidJsxCharacters.ts
        function isValidCharacter(character) {
            return hasProperty(htmlEntity, character);
        }
        function doChange17(changes, preferences, sourceFile, start, useHtmlEntity) {
            const character = sourceFile.getText()[start];
            if (!isValidCharacter(character)) {
                return;
            }
            const replacement = useHtmlEntity ? htmlEntity[character] : `{${quote(sourceFile, preferences, character)}}`;
            changes.replaceRangeWithText(sourceFile, { pos: start, end: start + 1 }, replacement);
        }
        var fixIdExpression, fixIdHtmlEntity, errorCodes37, htmlEntity;
        var init_fixInvalidJsxCharacters = __esm({
            "src/services/codefixes/fixInvalidJsxCharacters.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixIdExpression = "fixInvalidJsxCharacters_expression";
                fixIdHtmlEntity = "fixInvalidJsxCharacters_htmlEntity";
                errorCodes37 = [
                    Diagnostics.Unexpected_token_Did_you_mean_or_gt.code,
                    Diagnostics.Unexpected_token_Did_you_mean_or_rbrace.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes37,
                    fixIds: [fixIdExpression, fixIdHtmlEntity],
                    getCodeActions(context) {
                        const { sourceFile, preferences, span } = context;
                        const changeToExpression = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange17(t, preferences, sourceFile, span.start, 
                        /* useHtmlEntity */
                        false));
                        const changeToHtmlEntity = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange17(t, preferences, sourceFile, span.start, 
                        /* useHtmlEntity */
                        true));
                        return [
                            createCodeFixAction(fixIdExpression, changeToExpression, Diagnostics.Wrap_invalid_character_in_an_expression_container, fixIdExpression, Diagnostics.Wrap_all_invalid_characters_in_an_expression_container),
                            createCodeFixAction(fixIdHtmlEntity, changeToHtmlEntity, Diagnostics.Convert_invalid_character_to_its_html_entity_code, fixIdHtmlEntity, Diagnostics.Convert_all_invalid_characters_to_HTML_entity_code)
                        ];
                    },
                    getAllCodeActions(context) {
                        return codeFixAll(context, errorCodes37, (changes, diagnostic) => doChange17(changes, context.preferences, diagnostic.file, diagnostic.start, context.fixId === fixIdHtmlEntity));
                    }
                });
                htmlEntity = {
                    ">": "&gt;",
                    "}": "&rbrace;"
                };
            }
        });
        // src/services/codefixes/fixUnmatchedParameter.ts
        function getDeleteAction(context, { name, jsDocHost, jsDocParameterTag }) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (changeTracker) => changeTracker.filterJSDocTags(context.sourceFile, jsDocHost, (t) => t !== jsDocParameterTag));
            return createCodeFixAction(deleteUnmatchedParameter, changes, [Diagnostics.Delete_unused_param_tag_0, name.getText(context.sourceFile)], deleteUnmatchedParameter, Diagnostics.Delete_all_unused_param_tags);
        }
        function getRenameAction(context, { name, jsDocHost, signature, jsDocParameterTag }) {
            if (!length(signature.parameters))
                return void 0;
            const sourceFile = context.sourceFile;
            const tags = getJSDocTags(signature);
            const names = /* @__PURE__ */ new Set();
            for (const tag of tags) {
                if (isJSDocParameterTag(tag) && isIdentifier(tag.name)) {
                    names.add(tag.name.escapedText);
                }
            }
            const parameterName = firstDefined(signature.parameters, (p) => isIdentifier(p.name) && !names.has(p.name.escapedText) ? p.name.getText(sourceFile) : void 0);
            if (parameterName === void 0)
                return void 0;
            const newJSDocParameterTag = factory.updateJSDocParameterTag(jsDocParameterTag, jsDocParameterTag.tagName, factory.createIdentifier(parameterName), jsDocParameterTag.isBracketed, jsDocParameterTag.typeExpression, jsDocParameterTag.isNameFirst, jsDocParameterTag.comment);
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (changeTracker) => changeTracker.replaceJSDocComment(sourceFile, jsDocHost, map(tags, (t) => t === jsDocParameterTag ? newJSDocParameterTag : t)));
            return createCodeFixActionWithoutFixAll(renameUnmatchedParameter, changes, [Diagnostics.Rename_param_tag_name_0_to_1, name.getText(sourceFile), parameterName]);
        }
        function getInfo10(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (token.parent && isJSDocParameterTag(token.parent) && isIdentifier(token.parent.name)) {
                const jsDocParameterTag = token.parent;
                const jsDocHost = getJSDocHost(jsDocParameterTag);
                const signature = getHostSignatureFromJSDoc(jsDocParameterTag);
                if (jsDocHost && signature) {
                    return { jsDocHost, signature, name: token.parent.name, jsDocParameterTag };
                }
            }
            return void 0;
        }
        var deleteUnmatchedParameter, renameUnmatchedParameter, errorCodes38;
        var init_fixUnmatchedParameter = __esm({
            "src/services/codefixes/fixUnmatchedParameter.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                deleteUnmatchedParameter = "deleteUnmatchedParameter";
                renameUnmatchedParameter = "renameUnmatchedParameter";
                errorCodes38 = [
                    Diagnostics.JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name.code
                ];
                registerCodeFix({
                    fixIds: [deleteUnmatchedParameter, renameUnmatchedParameter],
                    errorCodes: errorCodes38,
                    getCodeActions: function getCodeActionsToFixUnmatchedParameter(context) {
                        const { sourceFile, span } = context;
                        const actions2 = [];
                        const info = getInfo10(sourceFile, span.start);
                        if (info) {
                            append(actions2, getDeleteAction(context, info));
                            append(actions2, getRenameAction(context, info));
                            return actions2;
                        }
                        return void 0;
                    },
                    getAllCodeActions: function getAllCodeActionsToFixUnmatchedParameter(context) {
                        const tagsToSignature = /* @__PURE__ */ new Map();
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            eachDiagnostic(context, errorCodes38, ({ file, start }) => {
                                const info = getInfo10(file, start);
                                if (info) {
                                    tagsToSignature.set(info.signature, append(tagsToSignature.get(info.signature), info.jsDocParameterTag));
                                }
                            });
                            tagsToSignature.forEach((tags, signature) => {
                                if (context.fixId === deleteUnmatchedParameter) {
                                    const tagsSet = new Set(tags);
                                    changes.filterJSDocTags(signature.getSourceFile(), signature, (t) => !tagsSet.has(t));
                                }
                            });
                        }));
                    }
                });
            }
        });
        // src/services/codefixes/fixUnreferenceableDecoratorMetadata.ts
        function getImportDeclaration(sourceFile, program, start) {
            const identifier = tryCast(getTokenAtPosition(sourceFile, start), isIdentifier);
            if (!identifier || identifier.parent.kind !== 180 /* TypeReference */)
                return;
            const checker = program.getTypeChecker();
            const symbol = checker.getSymbolAtLocation(identifier);
            return find((symbol == null ? void 0 : symbol.declarations) || emptyArray, or(isImportClause, isImportSpecifier, isImportEqualsDeclaration));
        }
        function doTypeOnlyImportChange(changes, sourceFile, importDeclaration, program) {
            if (importDeclaration.kind === 268 /* ImportEqualsDeclaration */) {
                changes.insertModifierBefore(sourceFile, 154 /* TypeKeyword */, importDeclaration.name);
                return;
            }
            const importClause = importDeclaration.kind === 270 /* ImportClause */ ? importDeclaration : importDeclaration.parent.parent;
            if (importClause.name && importClause.namedBindings) {
                return;
            }
            const checker = program.getTypeChecker();
            const importsValue = !!forEachImportClauseDeclaration(importClause, (decl) => {
                if (skipAlias(decl.symbol, checker).flags & 111551 /* Value */)
                    return true;
            });
            if (importsValue) {
                return;
            }
            changes.insertModifierBefore(sourceFile, 154 /* TypeKeyword */, importClause);
        }
        function doNamespaceImportChange(changes, sourceFile, importDeclaration, program) {
            ts_refactor_exports.doChangeNamedToNamespaceOrDefault(sourceFile, program, changes, importDeclaration.parent);
        }
        var fixId31, errorCodes39;
        var init_fixUnreferenceableDecoratorMetadata = __esm({
            "src/services/codefixes/fixUnreferenceableDecoratorMetadata.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId31 = "fixUnreferenceableDecoratorMetadata";
                errorCodes39 = [Diagnostics.A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_when_isolatedModules_and_emitDecoratorMetadata_are_enabled.code];
                registerCodeFix({
                    errorCodes: errorCodes39,
                    getCodeActions: (context) => {
                        const importDeclaration = getImportDeclaration(context.sourceFile, context.program, context.span.start);
                        if (!importDeclaration)
                            return;
                        const namespaceChanges = ts_textChanges_exports.ChangeTracker.with(context, (t) => importDeclaration.kind === 273 /* ImportSpecifier */ && doNamespaceImportChange(t, context.sourceFile, importDeclaration, context.program));
                        const typeOnlyChanges = ts_textChanges_exports.ChangeTracker.with(context, (t) => doTypeOnlyImportChange(t, context.sourceFile, importDeclaration, context.program));
                        let actions2;
                        if (namespaceChanges.length) {
                            actions2 = append(actions2, createCodeFixActionWithoutFixAll(fixId31, namespaceChanges, Diagnostics.Convert_named_imports_to_namespace_import));
                        }
                        if (typeOnlyChanges.length) {
                            actions2 = append(actions2, createCodeFixActionWithoutFixAll(fixId31, typeOnlyChanges, Diagnostics.Convert_to_type_only_import));
                        }
                        return actions2;
                    },
                    fixIds: [fixId31]
                });
            }
        });
        // src/services/codefixes/fixUnusedIdentifier.ts
        function changeInferToUnknown(changes, sourceFile, token) {
            changes.replaceNode(sourceFile, token.parent, factory.createKeywordTypeNode(157 /* UnknownKeyword */));
        }
        function createDeleteFix(changes, diag2) {
            return createCodeFixAction(fixName3, changes, diag2, fixIdDelete, Diagnostics.Delete_all_unused_declarations);
        }
        function deleteTypeParameters(changes, sourceFile, token) {
            changes.delete(sourceFile, Debug.checkDefined(cast(token.parent, isDeclarationWithTypeParameterChildren).typeParameters, "The type parameter to delete should exist"));
        }
        function isImport(token) {
            return token.kind === 100 /* ImportKeyword */ || token.kind === 79 /* Identifier */ && (token.parent.kind === 273 /* ImportSpecifier */ || token.parent.kind === 270 /* ImportClause */);
        }
        function tryGetFullImport(token) {
            return token.kind === 100 /* ImportKeyword */ ? tryCast(token.parent, isImportDeclaration) : void 0;
        }
        function canDeleteEntireVariableStatement(sourceFile, token) {
            return isVariableDeclarationList(token.parent) && first(token.parent.getChildren(sourceFile)) === token;
        }
        function deleteEntireVariableStatement(changes, sourceFile, node) {
            changes.delete(sourceFile, node.parent.kind === 240 /* VariableStatement */ ? node.parent : node);
        }
        function deleteDestructuringElements(changes, sourceFile, node) {
            forEach(node.elements, (n) => changes.delete(sourceFile, n));
        }
        function tryPrefixDeclaration(changes, errorCode, sourceFile, token) {
            if (errorCode === Diagnostics.Property_0_is_declared_but_its_value_is_never_read.code)
                return;
            if (token.kind === 138 /* InferKeyword */) {
                token = cast(token.parent, isInferTypeNode).typeParameter.name;
            }
            if (isIdentifier(token) && canPrefix(token)) {
                changes.replaceNode(sourceFile, token, factory.createIdentifier(`_${token.text}`));
                if (isParameter(token.parent)) {
                    getJSDocParameterTags(token.parent).forEach((tag) => {
                        if (isIdentifier(tag.name)) {
                            changes.replaceNode(sourceFile, tag.name, factory.createIdentifier(`_${tag.name.text}`));
                        }
                    });
                }
            }
        }
        function canPrefix(token) {
            switch (token.parent.kind) {
                case 166 /* Parameter */:
                case 165 /* TypeParameter */:
                    return true;
                case 257 /* VariableDeclaration */: {
                    const varDecl = token.parent;
                    switch (varDecl.parent.parent.kind) {
                        case 247 /* ForOfStatement */:
                        case 246 /* ForInStatement */:
                            return true;
                    }
                }
            }
            return false;
        }
        function tryDeleteDeclaration(sourceFile, token, changes, checker, sourceFiles, program, cancellationToken, isFixAll) {
            tryDeleteDeclarationWorker(token, changes, sourceFile, checker, sourceFiles, program, cancellationToken, isFixAll);
            if (isIdentifier(token)) {
                ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(token, checker, sourceFile, (ref) => {
                    if (isPropertyAccessExpression(ref.parent) && ref.parent.name === ref)
                        ref = ref.parent;
                    if (!isFixAll && mayDeleteExpression(ref)) {
                        changes.delete(sourceFile, ref.parent.parent);
                    }
                });
            }
        }
        function tryDeleteDeclarationWorker(token, changes, sourceFile, checker, sourceFiles, program, cancellationToken, isFixAll) {
            const { parent: parent2 } = token;
            if (isParameter(parent2)) {
                tryDeleteParameter(changes, sourceFile, parent2, checker, sourceFiles, program, cancellationToken, isFixAll);
            }
            else if (!(isFixAll && isIdentifier(token) && ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(token, checker, sourceFile))) {
                const node = isImportClause(parent2) ? token : isComputedPropertyName(parent2) ? parent2.parent : parent2;
                Debug.assert(node !== sourceFile, "should not delete whole source file");
                changes.delete(sourceFile, node);
            }
        }
        function tryDeleteParameter(changes, sourceFile, parameter, checker, sourceFiles, program, cancellationToken, isFixAll = false) {
            if (mayDeleteParameter(checker, sourceFile, parameter, sourceFiles, program, cancellationToken, isFixAll)) {
                if (parameter.modifiers && parameter.modifiers.length > 0 && (!isIdentifier(parameter.name) || ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(parameter.name, checker, sourceFile))) {
                    for (const modifier of parameter.modifiers) {
                        if (isModifier(modifier)) {
                            changes.deleteModifier(sourceFile, modifier);
                        }
                    }
                }
                else if (!parameter.initializer && isNotProvidedArguments(parameter, checker, sourceFiles)) {
                    changes.delete(sourceFile, parameter);
                }
            }
        }
        function isNotProvidedArguments(parameter, checker, sourceFiles) {
            const index = parameter.parent.parameters.indexOf(parameter);
            return !ts_FindAllReferences_exports.Core.someSignatureUsage(parameter.parent, sourceFiles, checker, (_, call) => !call || call.arguments.length > index);
        }
        function mayDeleteParameter(checker, sourceFile, parameter, sourceFiles, program, cancellationToken, isFixAll) {
            const { parent: parent2 } = parameter;
            switch (parent2.kind) {
                case 171 /* MethodDeclaration */:
                case 173 /* Constructor */:
                    const index = parent2.parameters.indexOf(parameter);
                    const referent = isMethodDeclaration(parent2) ? parent2.name : parent2;
                    const entries = ts_FindAllReferences_exports.Core.getReferencedSymbolsForNode(parent2.pos, referent, program, sourceFiles, cancellationToken);
                    if (entries) {
                        for (const entry of entries) {
                            for (const reference of entry.references) {
                                if (reference.kind === ts_FindAllReferences_exports.EntryKind.Node) {
                                    const isSuperCall2 = isSuperKeyword(reference.node) && isCallExpression(reference.node.parent) && reference.node.parent.arguments.length > index;
                                    const isSuperMethodCall = isPropertyAccessExpression(reference.node.parent) && isSuperKeyword(reference.node.parent.expression) && isCallExpression(reference.node.parent.parent) && reference.node.parent.parent.arguments.length > index;
                                    const isOverriddenMethod = (isMethodDeclaration(reference.node.parent) || isMethodSignature(reference.node.parent)) && reference.node.parent !== parameter.parent && reference.node.parent.parameters.length > index;
                                    if (isSuperCall2 || isSuperMethodCall || isOverriddenMethod)
                                        return false;
                                }
                            }
                        }
                    }
                    return true;
                case 259 /* FunctionDeclaration */: {
                    if (parent2.name && isCallbackLike(checker, sourceFile, parent2.name)) {
                        return isLastParameter(parent2, parameter, isFixAll);
                    }
                    return true;
                }
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                    return isLastParameter(parent2, parameter, isFixAll);
                case 175 /* SetAccessor */:
                    return false;
                case 174 /* GetAccessor */:
                    return true;
                default:
                    return Debug.failBadSyntaxKind(parent2);
            }
        }
        function isCallbackLike(checker, sourceFile, name) {
            return !!ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(name, checker, sourceFile, (reference) => isIdentifier(reference) && isCallExpression(reference.parent) && reference.parent.arguments.indexOf(reference) >= 0);
        }
        function isLastParameter(func, parameter, isFixAll) {
            const parameters = func.parameters;
            const index = parameters.indexOf(parameter);
            Debug.assert(index !== -1, "The parameter should already be in the list");
            return isFixAll ? parameters.slice(index + 1).every((p) => isIdentifier(p.name) && !p.symbol.isReferenced) : index === parameters.length - 1;
        }
        function mayDeleteExpression(node) {
            return (isBinaryExpression(node.parent) && node.parent.left === node || (isPostfixUnaryExpression(node.parent) || isPrefixUnaryExpression(node.parent)) && node.parent.operand === node) && isExpressionStatement(node.parent.parent);
        }
        var fixName3, fixIdPrefix, fixIdDelete, fixIdDeleteImports, fixIdInfer, errorCodes40;
        var init_fixUnusedIdentifier = __esm({
            "src/services/codefixes/fixUnusedIdentifier.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName3 = "unusedIdentifier";
                fixIdPrefix = "unusedIdentifier_prefix";
                fixIdDelete = "unusedIdentifier_delete";
                fixIdDeleteImports = "unusedIdentifier_deleteImports";
                fixIdInfer = "unusedIdentifier_infer";
                errorCodes40 = [
                    Diagnostics._0_is_declared_but_its_value_is_never_read.code,
                    Diagnostics._0_is_declared_but_never_used.code,
                    Diagnostics.Property_0_is_declared_but_its_value_is_never_read.code,
                    Diagnostics.All_imports_in_import_declaration_are_unused.code,
                    Diagnostics.All_destructured_elements_are_unused.code,
                    Diagnostics.All_variables_are_unused.code,
                    Diagnostics.All_type_parameters_are_unused.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes40,
                    getCodeActions(context) {
                        const { errorCode, sourceFile, program, cancellationToken } = context;
                        const checker = program.getTypeChecker();
                        const sourceFiles = program.getSourceFiles();
                        const token = getTokenAtPosition(sourceFile, context.span.start);
                        if (isJSDocTemplateTag(token)) {
                            return [createDeleteFix(ts_textChanges_exports.ChangeTracker.with(context, (t) => t.delete(sourceFile, token)), Diagnostics.Remove_template_tag)];
                        }
                        if (token.kind === 29 /* LessThanToken */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => deleteTypeParameters(t, sourceFile, token));
                            return [createDeleteFix(changes, Diagnostics.Remove_type_parameters)];
                        }
                        const importDecl = tryGetFullImport(token);
                        if (importDecl) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => t.delete(sourceFile, importDecl));
                            return [createCodeFixAction(fixName3, changes, [Diagnostics.Remove_import_from_0, showModuleSpecifier(importDecl)], fixIdDeleteImports, Diagnostics.Delete_all_unused_imports)];
                        }
                        else if (isImport(token)) {
                            const deletion = ts_textChanges_exports.ChangeTracker.with(context, (t) => tryDeleteDeclaration(sourceFile, token, t, checker, sourceFiles, program, cancellationToken, 
                            /*isFixAll*/
                            false));
                            if (deletion.length) {
                                return [createCodeFixAction(fixName3, deletion, [Diagnostics.Remove_unused_declaration_for_Colon_0, token.getText(sourceFile)], fixIdDeleteImports, Diagnostics.Delete_all_unused_imports)];
                            }
                        }
                        if (isObjectBindingPattern(token.parent) || isArrayBindingPattern(token.parent)) {
                            if (isParameter(token.parent.parent)) {
                                const elements = token.parent.elements;
                                const diagnostic = [
                                    elements.length > 1 ? Diagnostics.Remove_unused_declarations_for_Colon_0 : Diagnostics.Remove_unused_declaration_for_Colon_0,
                                    map(elements, (e) => e.getText(sourceFile)).join(", ")
                                ];
                                return [
                                    createDeleteFix(ts_textChanges_exports.ChangeTracker.with(context, (t) => deleteDestructuringElements(t, sourceFile, token.parent)), diagnostic)
                                ];
                            }
                            return [
                                createDeleteFix(ts_textChanges_exports.ChangeTracker.with(context, (t) => t.delete(sourceFile, token.parent.parent)), Diagnostics.Remove_unused_destructuring_declaration)
                            ];
                        }
                        if (canDeleteEntireVariableStatement(sourceFile, token)) {
                            return [
                                createDeleteFix(ts_textChanges_exports.ChangeTracker.with(context, (t) => deleteEntireVariableStatement(t, sourceFile, token.parent)), Diagnostics.Remove_variable_statement)
                            ];
                        }
                        const result = [];
                        if (token.kind === 138 /* InferKeyword */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => changeInferToUnknown(t, sourceFile, token));
                            const name = cast(token.parent, isInferTypeNode).typeParameter.name.text;
                            result.push(createCodeFixAction(fixName3, changes, [Diagnostics.Replace_infer_0_with_unknown, name], fixIdInfer, Diagnostics.Replace_all_unused_infer_with_unknown));
                        }
                        else {
                            const deletion = ts_textChanges_exports.ChangeTracker.with(context, (t) => tryDeleteDeclaration(sourceFile, token, t, checker, sourceFiles, program, cancellationToken, 
                            /*isFixAll*/
                            false));
                            if (deletion.length) {
                                const name = isComputedPropertyName(token.parent) ? token.parent : token;
                                result.push(createDeleteFix(deletion, [Diagnostics.Remove_unused_declaration_for_Colon_0, name.getText(sourceFile)]));
                            }
                        }
                        const prefix = ts_textChanges_exports.ChangeTracker.with(context, (t) => tryPrefixDeclaration(t, errorCode, sourceFile, token));
                        if (prefix.length) {
                            result.push(createCodeFixAction(fixName3, prefix, [Diagnostics.Prefix_0_with_an_underscore, token.getText(sourceFile)], fixIdPrefix, Diagnostics.Prefix_all_unused_declarations_with_where_possible));
                        }
                        return result;
                    },
                    fixIds: [fixIdPrefix, fixIdDelete, fixIdDeleteImports, fixIdInfer],
                    getAllCodeActions: (context) => {
                        const { sourceFile, program, cancellationToken } = context;
                        const checker = program.getTypeChecker();
                        const sourceFiles = program.getSourceFiles();
                        return codeFixAll(context, errorCodes40, (changes, diag2) => {
                            const token = getTokenAtPosition(sourceFile, diag2.start);
                            switch (context.fixId) {
                                case fixIdPrefix:
                                    tryPrefixDeclaration(changes, diag2.code, sourceFile, token);
                                    break;
                                case fixIdDeleteImports: {
                                    const importDecl = tryGetFullImport(token);
                                    if (importDecl) {
                                        changes.delete(sourceFile, importDecl);
                                    }
                                    else if (isImport(token)) {
                                        tryDeleteDeclaration(sourceFile, token, changes, checker, sourceFiles, program, cancellationToken, 
                                        /*isFixAll*/
                                        true);
                                    }
                                    break;
                                }
                                case fixIdDelete: {
                                    if (token.kind === 138 /* InferKeyword */ || isImport(token)) {
                                        break;
                                    }
                                    else if (isJSDocTemplateTag(token)) {
                                        changes.delete(sourceFile, token);
                                    }
                                    else if (token.kind === 29 /* LessThanToken */) {
                                        deleteTypeParameters(changes, sourceFile, token);
                                    }
                                    else if (isObjectBindingPattern(token.parent)) {
                                        if (token.parent.parent.initializer) {
                                            break;
                                        }
                                        else if (!isParameter(token.parent.parent) || isNotProvidedArguments(token.parent.parent, checker, sourceFiles)) {
                                            changes.delete(sourceFile, token.parent.parent);
                                        }
                                    }
                                    else if (isArrayBindingPattern(token.parent.parent) && token.parent.parent.parent.initializer) {
                                        break;
                                    }
                                    else if (canDeleteEntireVariableStatement(sourceFile, token)) {
                                        deleteEntireVariableStatement(changes, sourceFile, token.parent);
                                    }
                                    else {
                                        tryDeleteDeclaration(sourceFile, token, changes, checker, sourceFiles, program, cancellationToken, 
                                        /*isFixAll*/
                                        true);
                                    }
                                    break;
                                }
                                case fixIdInfer:
                                    if (token.kind === 138 /* InferKeyword */) {
                                        changeInferToUnknown(changes, sourceFile, token);
                                    }
                                    break;
                                default:
                                    Debug.fail(JSON.stringify(context.fixId));
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixUnreachableCode.ts
        function doChange18(changes, sourceFile, start, length2, errorCode) {
            const token = getTokenAtPosition(sourceFile, start);
            const statement = findAncestor(token, isStatement);
            if (statement.getStart(sourceFile) !== token.getStart(sourceFile)) {
                const logData = JSON.stringify({
                    statementKind: Debug.formatSyntaxKind(statement.kind),
                    tokenKind: Debug.formatSyntaxKind(token.kind),
                    errorCode,
                    start,
                    length: length2
                });
                Debug.fail("Token and statement should start at the same point. " + logData);
            }
            const container = (isBlock(statement.parent) ? statement.parent : statement).parent;
            if (!isBlock(statement.parent) || statement === first(statement.parent.statements)) {
                switch (container.kind) {
                    case 242 /* IfStatement */:
                        if (container.elseStatement) {
                            if (isBlock(statement.parent)) {
                                break;
                            }
                            else {
                                changes.replaceNode(sourceFile, statement, factory.createBlock(emptyArray));
                            }
                            return;
                        }
                    case 244 /* WhileStatement */:
                    case 245 /* ForStatement */:
                        changes.delete(sourceFile, container);
                        return;
                }
            }
            if (isBlock(statement.parent)) {
                const end = start + length2;
                const lastStatement = Debug.checkDefined(lastWhere(sliceAfter(statement.parent.statements, statement), (s) => s.pos < end), "Some statement should be last");
                changes.deleteNodeRange(sourceFile, statement, lastStatement);
            }
            else {
                changes.delete(sourceFile, statement);
            }
        }
        function lastWhere(a, pred) {
            let last2;
            for (const value of a) {
                if (!pred(value))
                    break;
                last2 = value;
            }
            return last2;
        }
        var fixId32, errorCodes41;
        var init_fixUnreachableCode = __esm({
            "src/services/codefixes/fixUnreachableCode.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId32 = "fixUnreachableCode";
                errorCodes41 = [Diagnostics.Unreachable_code_detected.code];
                registerCodeFix({
                    errorCodes: errorCodes41,
                    getCodeActions(context) {
                        const syntacticDiagnostics = context.program.getSyntacticDiagnostics(context.sourceFile, context.cancellationToken);
                        if (syntacticDiagnostics.length)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange18(t, context.sourceFile, context.span.start, context.span.length, context.errorCode));
                        return [createCodeFixAction(fixId32, changes, Diagnostics.Remove_unreachable_code, fixId32, Diagnostics.Remove_all_unreachable_code)];
                    },
                    fixIds: [fixId32],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes41, (changes, diag2) => doChange18(changes, diag2.file, diag2.start, diag2.length, diag2.code))
                });
            }
        });
        // src/services/codefixes/fixUnusedLabel.ts
        function doChange19(changes, sourceFile, start) {
            const token = getTokenAtPosition(sourceFile, start);
            const labeledStatement = cast(token.parent, isLabeledStatement);
            const pos = token.getStart(sourceFile);
            const statementPos = labeledStatement.statement.getStart(sourceFile);
            const end = positionsAreOnSameLine(pos, statementPos, sourceFile) ? statementPos : skipTrivia(sourceFile.text, findChildOfKind(labeledStatement, 58 /* ColonToken */, sourceFile).end, 
            /*stopAfterLineBreak*/
            true);
            changes.deleteRange(sourceFile, { pos, end });
        }
        var fixId33, errorCodes42;
        var init_fixUnusedLabel = __esm({
            "src/services/codefixes/fixUnusedLabel.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId33 = "fixUnusedLabel";
                errorCodes42 = [Diagnostics.Unused_label.code];
                registerCodeFix({
                    errorCodes: errorCodes42,
                    getCodeActions(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange19(t, context.sourceFile, context.span.start));
                        return [createCodeFixAction(fixId33, changes, Diagnostics.Remove_unused_label, fixId33, Diagnostics.Remove_all_unused_labels)];
                    },
                    fixIds: [fixId33],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes42, (changes, diag2) => doChange19(changes, diag2.file, diag2.start))
                });
            }
        });
        // src/services/codefixes/fixJSDocTypes.ts
        function doChange20(changes, sourceFile, oldTypeNode, newType, checker) {
            changes.replaceNode(sourceFile, oldTypeNode, checker.typeToTypeNode(newType, 
            /*enclosingDeclaration*/
            oldTypeNode, 
            /*flags*/
            void 0));
        }
        function getInfo11(sourceFile, pos, checker) {
            const decl = findAncestor(getTokenAtPosition(sourceFile, pos), isTypeContainer);
            const typeNode = decl && decl.type;
            return typeNode && { typeNode, type: getType(checker, typeNode) };
        }
        function isTypeContainer(node) {
            switch (node.kind) {
                case 231 /* AsExpression */:
                case 176 /* CallSignature */:
                case 177 /* ConstructSignature */:
                case 259 /* FunctionDeclaration */:
                case 174 /* GetAccessor */:
                case 178 /* IndexSignature */:
                case 197 /* MappedType */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 166 /* Parameter */:
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                case 175 /* SetAccessor */:
                case 262 /* TypeAliasDeclaration */:
                case 213 /* TypeAssertionExpression */:
                case 257 /* VariableDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function getType(checker, node) {
            if (isJSDocNullableType(node)) {
                const type = checker.getTypeFromTypeNode(node.type);
                if (type === checker.getNeverType() || type === checker.getVoidType()) {
                    return type;
                }
                return checker.getUnionType(append([type, checker.getUndefinedType()], node.postfix ? void 0 : checker.getNullType()));
            }
            return checker.getTypeFromTypeNode(node);
        }
        var fixIdPlain, fixIdNullable, errorCodes43;
        var init_fixJSDocTypes = __esm({
            "src/services/codefixes/fixJSDocTypes.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixIdPlain = "fixJSDocTypes_plain";
                fixIdNullable = "fixJSDocTypes_nullable";
                errorCodes43 = [
                    Diagnostics.JSDoc_types_can_only_be_used_inside_documentation_comments.code,
                    Diagnostics._0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1.code,
                    Diagnostics._0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes43,
                    getCodeActions(context) {
                        const { sourceFile } = context;
                        const checker = context.program.getTypeChecker();
                        const info = getInfo11(sourceFile, context.span.start, checker);
                        if (!info)
                            return void 0;
                        const { typeNode, type } = info;
                        const original = typeNode.getText(sourceFile);
                        const actions2 = [fix(type, fixIdPlain, Diagnostics.Change_all_jsdoc_style_types_to_TypeScript)];
                        if (typeNode.kind === 317 /* JSDocNullableType */) {
                            actions2.push(fix(type, fixIdNullable, Diagnostics.Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types));
                        }
                        return actions2;
                        function fix(type2, fixId51, fixAllDescription) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange20(t, sourceFile, typeNode, type2, checker));
                            return createCodeFixAction("jdocTypes", changes, [Diagnostics.Change_0_to_1, original, checker.typeToString(type2)], fixId51, fixAllDescription);
                        }
                    },
                    fixIds: [fixIdPlain, fixIdNullable],
                    getAllCodeActions(context) {
                        const { fixId: fixId51, program, sourceFile } = context;
                        const checker = program.getTypeChecker();
                        return codeFixAll(context, errorCodes43, (changes, err) => {
                            const info = getInfo11(err.file, err.start, checker);
                            if (!info)
                                return;
                            const { typeNode, type } = info;
                            const fixedType = typeNode.kind === 317 /* JSDocNullableType */ && fixId51 === fixIdNullable ? checker.getNullableType(type, 32768 /* Undefined */) : type;
                            doChange20(changes, sourceFile, typeNode, fixedType, checker);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixMissingCallParentheses.ts
        function doChange21(changes, sourceFile, name) {
            changes.replaceNodeWithText(sourceFile, name, `${name.text}()`);
        }
        function getCallName(sourceFile, start) {
            const token = getTokenAtPosition(sourceFile, start);
            if (isPropertyAccessExpression(token.parent)) {
                let current = token.parent;
                while (isPropertyAccessExpression(current.parent)) {
                    current = current.parent;
                }
                return current.name;
            }
            if (isIdentifier(token)) {
                return token;
            }
            return void 0;
        }
        var fixId34, errorCodes44;
        var init_fixMissingCallParentheses = __esm({
            "src/services/codefixes/fixMissingCallParentheses.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId34 = "fixMissingCallParentheses";
                errorCodes44 = [
                    Diagnostics.This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes44,
                    fixIds: [fixId34],
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const callName = getCallName(sourceFile, span.start);
                        if (!callName)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange21(t, context.sourceFile, callName));
                        return [createCodeFixAction(fixId34, changes, Diagnostics.Add_missing_call_parentheses, fixId34, Diagnostics.Add_all_missing_call_parentheses)];
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes44, (changes, diag2) => {
                        const callName = getCallName(diag2.file, diag2.start);
                        if (callName)
                            doChange21(changes, diag2.file, callName);
                    })
                });
            }
        });
        // src/services/codefixes/fixAwaitInSyncFunction.ts
        function getReturnType(expr) {
            if (expr.type) {
                return expr.type;
            }
            if (isVariableDeclaration(expr.parent) && expr.parent.type && isFunctionTypeNode(expr.parent.type)) {
                return expr.parent.type.type;
            }
        }
        function getNodes3(sourceFile, start) {
            const token = getTokenAtPosition(sourceFile, start);
            const containingFunction = getContainingFunction(token);
            if (!containingFunction) {
                return;
            }
            let insertBefore;
            switch (containingFunction.kind) {
                case 171 /* MethodDeclaration */:
                    insertBefore = containingFunction.name;
                    break;
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                    insertBefore = findChildOfKind(containingFunction, 98 /* FunctionKeyword */, sourceFile);
                    break;
                case 216 /* ArrowFunction */:
                    const kind = containingFunction.typeParameters ? 29 /* LessThanToken */ : 20 /* OpenParenToken */;
                    insertBefore = findChildOfKind(containingFunction, kind, sourceFile) || first(containingFunction.parameters);
                    break;
                default:
                    return;
            }
            return insertBefore && {
                insertBefore,
                returnType: getReturnType(containingFunction)
            };
        }
        function doChange22(changes, sourceFile, { insertBefore, returnType }) {
            if (returnType) {
                const entityName = getEntityNameFromTypeNode(returnType);
                if (!entityName || entityName.kind !== 79 /* Identifier */ || entityName.text !== "Promise") {
                    changes.replaceNode(sourceFile, returnType, factory.createTypeReferenceNode("Promise", factory.createNodeArray([returnType])));
                }
            }
            changes.insertModifierBefore(sourceFile, 132 /* AsyncKeyword */, insertBefore);
        }
        var fixId35, errorCodes45;
        var init_fixAwaitInSyncFunction = __esm({
            "src/services/codefixes/fixAwaitInSyncFunction.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId35 = "fixAwaitInSyncFunction";
                errorCodes45 = [
                    Diagnostics.await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code,
                    Diagnostics.for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes45,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const nodes = getNodes3(sourceFile, span.start);
                        if (!nodes)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange22(t, sourceFile, nodes));
                        return [createCodeFixAction(fixId35, changes, Diagnostics.Add_async_modifier_to_containing_function, fixId35, Diagnostics.Add_all_missing_async_modifiers)];
                    },
                    fixIds: [fixId35],
                    getAllCodeActions: function getAllCodeActionsToFixAwaitInSyncFunction(context) {
                        const seen = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes45, (changes, diag2) => {
                            const nodes = getNodes3(diag2.file, diag2.start);
                            if (!nodes || !addToSeen(seen, getNodeId(nodes.insertBefore)))
                                return;
                            doChange22(changes, context.sourceFile, nodes);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixPropertyOverrideAccessor.ts
        function doChange23(file, start, length2, code, context) {
            let startPosition;
            let endPosition;
            if (code === Diagnostics._0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property.code) {
                startPosition = start;
                endPosition = start + length2;
            }
            else if (code === Diagnostics._0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor.code) {
                const checker = context.program.getTypeChecker();
                const node = getTokenAtPosition(file, start).parent;
                Debug.assert(isAccessor(node), "error span of fixPropertyOverrideAccessor should only be on an accessor");
                const containingClass = node.parent;
                Debug.assert(isClassLike(containingClass), "erroneous accessors should only be inside classes");
                const base = singleOrUndefined(getAllSupers(containingClass, checker));
                if (!base)
                    return [];
                const name = unescapeLeadingUnderscores(getTextOfPropertyName(node.name));
                const baseProp = checker.getPropertyOfType(checker.getTypeAtLocation(base), name);
                if (!baseProp || !baseProp.valueDeclaration)
                    return [];
                startPosition = baseProp.valueDeclaration.pos;
                endPosition = baseProp.valueDeclaration.end;
                file = getSourceFileOfNode(baseProp.valueDeclaration);
            }
            else {
                Debug.fail("fixPropertyOverrideAccessor codefix got unexpected error code " + code);
            }
            return generateAccessorFromProperty(file, context.program, startPosition, endPosition, context, Diagnostics.Generate_get_and_set_accessors.message);
        }
        var errorCodes46, fixId36;
        var init_fixPropertyOverrideAccessor = __esm({
            "src/services/codefixes/fixPropertyOverrideAccessor.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes46 = [
                    Diagnostics._0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property.code,
                    Diagnostics._0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor.code
                ];
                fixId36 = "fixPropertyOverrideAccessor";
                registerCodeFix({
                    errorCodes: errorCodes46,
                    getCodeActions(context) {
                        const edits = doChange23(context.sourceFile, context.span.start, context.span.length, context.errorCode, context);
                        if (edits) {
                            return [createCodeFixAction(fixId36, edits, Diagnostics.Generate_get_and_set_accessors, fixId36, Diagnostics.Generate_get_and_set_accessors_for_all_overriding_properties)];
                        }
                    },
                    fixIds: [fixId36],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes46, (changes, diag2) => {
                        const edits = doChange23(diag2.file, diag2.start, diag2.length, diag2.code, context);
                        if (edits) {
                            for (const edit of edits) {
                                changes.pushRaw(context.sourceFile, edit);
                            }
                        }
                    })
                });
            }
        });
        // src/services/codefixes/inferFromUsage.ts
        function getDiagnostic(errorCode, token) {
            switch (errorCode) {
                case Diagnostics.Parameter_0_implicitly_has_an_1_type.code:
                case Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return isSetAccessorDeclaration(getContainingFunction(token)) ? Diagnostics.Infer_type_of_0_from_usage : Diagnostics.Infer_parameter_types_from_usage;
                case Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code:
                case Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Infer_parameter_types_from_usage;
                case Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code:
                    return Diagnostics.Infer_this_type_of_0_from_usage;
                default:
                    return Diagnostics.Infer_type_of_0_from_usage;
            }
        }
        function mapSuggestionDiagnostic(errorCode) {
            switch (errorCode) {
                case Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined.code;
                case Diagnostics.Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Variable_0_implicitly_has_an_1_type.code;
                case Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Parameter_0_implicitly_has_an_1_type.code;
                case Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code;
                case Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage.code:
                    return Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation.code;
                case Diagnostics._0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type.code;
                case Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage.code:
                    return Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation.code;
                case Diagnostics.Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Member_0_implicitly_has_an_1_type.code;
            }
            return errorCode;
        }
        function doChange24(changes, sourceFile, token, errorCode, program, cancellationToken, markSeen, host, preferences) {
            if (!isParameterPropertyModifier(token.kind) && token.kind !== 79 /* Identifier */ && token.kind !== 25 /* DotDotDotToken */ && token.kind !== 108 /* ThisKeyword */) {
                return void 0;
            }
            const { parent: parent2 } = token;
            const importAdder = createImportAdder(sourceFile, program, preferences, host);
            errorCode = mapSuggestionDiagnostic(errorCode);
            switch (errorCode) {
                case Diagnostics.Member_0_implicitly_has_an_1_type.code:
                case Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined.code:
                    if (isVariableDeclaration(parent2) && markSeen(parent2) || isPropertyDeclaration(parent2) || isPropertySignature(parent2)) {
                        annotateVariableDeclaration(changes, importAdder, sourceFile, parent2, program, host, cancellationToken);
                        importAdder.writeFixes(changes);
                        return parent2;
                    }
                    if (isPropertyAccessExpression(parent2)) {
                        const type = inferTypeForVariableFromUsage(parent2.name, program, cancellationToken);
                        const typeNode = getTypeNodeIfAccessible(type, parent2, program, host);
                        if (typeNode) {
                            const typeTag = factory.createJSDocTypeTag(
                            /*tagName*/
                            void 0, factory.createJSDocTypeExpression(typeNode), 
                            /*comment*/
                            void 0);
                            changes.addJSDocTags(sourceFile, cast(parent2.parent.parent, isExpressionStatement), [typeTag]);
                        }
                        importAdder.writeFixes(changes);
                        return parent2;
                    }
                    return void 0;
                case Diagnostics.Variable_0_implicitly_has_an_1_type.code: {
                    const symbol = program.getTypeChecker().getSymbolAtLocation(token);
                    if (symbol && symbol.valueDeclaration && isVariableDeclaration(symbol.valueDeclaration) && markSeen(symbol.valueDeclaration)) {
                        annotateVariableDeclaration(changes, importAdder, getSourceFileOfNode(symbol.valueDeclaration), symbol.valueDeclaration, program, host, cancellationToken);
                        importAdder.writeFixes(changes);
                        return symbol.valueDeclaration;
                    }
                    return void 0;
                }
            }
            const containingFunction = getContainingFunction(token);
            if (containingFunction === void 0) {
                return void 0;
            }
            let declaration;
            switch (errorCode) {
                case Diagnostics.Parameter_0_implicitly_has_an_1_type.code:
                    if (isSetAccessorDeclaration(containingFunction)) {
                        annotateSetAccessor(changes, importAdder, sourceFile, containingFunction, program, host, cancellationToken);
                        declaration = containingFunction;
                        break;
                    }
                case Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code:
                    if (markSeen(containingFunction)) {
                        const param = cast(parent2, isParameter);
                        annotateParameters(changes, importAdder, sourceFile, param, containingFunction, program, host, cancellationToken);
                        declaration = param;
                    }
                    break;
                case Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation.code:
                case Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type.code:
                    if (isGetAccessorDeclaration(containingFunction) && isIdentifier(containingFunction.name)) {
                        annotate(changes, importAdder, sourceFile, containingFunction, inferTypeForVariableFromUsage(containingFunction.name, program, cancellationToken), program, host);
                        declaration = containingFunction;
                    }
                    break;
                case Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation.code:
                    if (isSetAccessorDeclaration(containingFunction)) {
                        annotateSetAccessor(changes, importAdder, sourceFile, containingFunction, program, host, cancellationToken);
                        declaration = containingFunction;
                    }
                    break;
                case Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code:
                    if (ts_textChanges_exports.isThisTypeAnnotatable(containingFunction) && markSeen(containingFunction)) {
                        annotateThis(changes, sourceFile, containingFunction, program, host, cancellationToken);
                        declaration = containingFunction;
                    }
                    break;
                default:
                    return Debug.fail(String(errorCode));
            }
            importAdder.writeFixes(changes);
            return declaration;
        }
        function annotateVariableDeclaration(changes, importAdder, sourceFile, declaration, program, host, cancellationToken) {
            if (isIdentifier(declaration.name)) {
                annotate(changes, importAdder, sourceFile, declaration, inferTypeForVariableFromUsage(declaration.name, program, cancellationToken), program, host);
            }
        }
        function annotateParameters(changes, importAdder, sourceFile, parameterDeclaration, containingFunction, program, host, cancellationToken) {
            if (!isIdentifier(parameterDeclaration.name)) {
                return;
            }
            const parameterInferences = inferTypeForParametersFromUsage(containingFunction, sourceFile, program, cancellationToken);
            Debug.assert(containingFunction.parameters.length === parameterInferences.length, "Parameter count and inference count should match");
            if (isInJSFile(containingFunction)) {
                annotateJSDocParameters(changes, sourceFile, parameterInferences, program, host);
            }
            else {
                const needParens = isArrowFunction(containingFunction) && !findChildOfKind(containingFunction, 20 /* OpenParenToken */, sourceFile);
                if (needParens)
                    changes.insertNodeBefore(sourceFile, first(containingFunction.parameters), factory.createToken(20 /* OpenParenToken */));
                for (const { declaration, type } of parameterInferences) {
                    if (declaration && !declaration.type && !declaration.initializer) {
                        annotate(changes, importAdder, sourceFile, declaration, type, program, host);
                    }
                }
                if (needParens)
                    changes.insertNodeAfter(sourceFile, last(containingFunction.parameters), factory.createToken(21 /* CloseParenToken */));
            }
        }
        function annotateThis(changes, sourceFile, containingFunction, program, host, cancellationToken) {
            const references = getFunctionReferences(containingFunction, sourceFile, program, cancellationToken);
            if (!references || !references.length) {
                return;
            }
            const thisInference = inferTypeFromReferences(program, references, cancellationToken).thisParameter();
            const typeNode = getTypeNodeIfAccessible(thisInference, containingFunction, program, host);
            if (!typeNode) {
                return;
            }
            if (isInJSFile(containingFunction)) {
                annotateJSDocThis(changes, sourceFile, containingFunction, typeNode);
            }
            else {
                changes.tryInsertThisTypeAnnotation(sourceFile, containingFunction, typeNode);
            }
        }
        function annotateJSDocThis(changes, sourceFile, containingFunction, typeNode) {
            changes.addJSDocTags(sourceFile, containingFunction, [
                factory.createJSDocThisTag(
                /*tagName*/
                void 0, factory.createJSDocTypeExpression(typeNode))
            ]);
        }
        function annotateSetAccessor(changes, importAdder, sourceFile, setAccessorDeclaration, program, host, cancellationToken) {
            const param = firstOrUndefined(setAccessorDeclaration.parameters);
            if (param && isIdentifier(setAccessorDeclaration.name) && isIdentifier(param.name)) {
                let type = inferTypeForVariableFromUsage(setAccessorDeclaration.name, program, cancellationToken);
                if (type === program.getTypeChecker().getAnyType()) {
                    type = inferTypeForVariableFromUsage(param.name, program, cancellationToken);
                }
                if (isInJSFile(setAccessorDeclaration)) {
                    annotateJSDocParameters(changes, sourceFile, [{ declaration: param, type }], program, host);
                }
                else {
                    annotate(changes, importAdder, sourceFile, param, type, program, host);
                }
            }
        }
        function annotate(changes, importAdder, sourceFile, declaration, type, program, host) {
            const typeNode = getTypeNodeIfAccessible(type, declaration, program, host);
            if (typeNode) {
                if (isInJSFile(sourceFile) && declaration.kind !== 168 /* PropertySignature */) {
                    const parent2 = isVariableDeclaration(declaration) ? tryCast(declaration.parent.parent, isVariableStatement) : declaration;
                    if (!parent2) {
                        return;
                    }
                    const typeExpression = factory.createJSDocTypeExpression(typeNode);
                    const typeTag = isGetAccessorDeclaration(declaration) ? factory.createJSDocReturnTag(
                    /*tagName*/
                    void 0, typeExpression, 
                    /*comment*/
                    void 0) : factory.createJSDocTypeTag(
                    /*tagName*/
                    void 0, typeExpression, 
                    /*comment*/
                    void 0);
                    changes.addJSDocTags(sourceFile, parent2, [typeTag]);
                }
                else if (!tryReplaceImportTypeNodeWithAutoImport(typeNode, declaration, sourceFile, changes, importAdder, getEmitScriptTarget(program.getCompilerOptions()))) {
                    changes.tryInsertTypeAnnotation(sourceFile, declaration, typeNode);
                }
            }
        }
        function tryReplaceImportTypeNodeWithAutoImport(typeNode, declaration, sourceFile, changes, importAdder, scriptTarget) {
            const importableReference = tryGetAutoImportableReferenceFromTypeNode(typeNode, scriptTarget);
            if (importableReference && changes.tryInsertTypeAnnotation(sourceFile, declaration, importableReference.typeNode)) {
                forEach(importableReference.symbols, (s) => importAdder.addImportFromExportedSymbol(s, 
                /*usageIsTypeOnly*/
                true));
                return true;
            }
            return false;
        }
        function annotateJSDocParameters(changes, sourceFile, parameterInferences, program, host) {
            const signature = parameterInferences.length && parameterInferences[0].declaration.parent;
            if (!signature) {
                return;
            }
            const inferences = mapDefined(parameterInferences, (inference) => {
                const param = inference.declaration;
                if (param.initializer || getJSDocType(param) || !isIdentifier(param.name)) {
                    return;
                }
                const typeNode = inference.type && getTypeNodeIfAccessible(inference.type, param, program, host);
                if (typeNode) {
                    const name = factory.cloneNode(param.name);
                    setEmitFlags(name, 3072 /* NoComments */ | 4096 /* NoNestedComments */);
                    return { name: factory.cloneNode(param.name), param, isOptional: !!inference.isOptional, typeNode };
                }
            });
            if (!inferences.length) {
                return;
            }
            if (isArrowFunction(signature) || isFunctionExpression(signature)) {
                const needParens = isArrowFunction(signature) && !findChildOfKind(signature, 20 /* OpenParenToken */, sourceFile);
                if (needParens) {
                    changes.insertNodeBefore(sourceFile, first(signature.parameters), factory.createToken(20 /* OpenParenToken */));
                }
                forEach(inferences, ({ typeNode, param }) => {
                    const typeTag = factory.createJSDocTypeTag(
                    /*tagName*/
                    void 0, factory.createJSDocTypeExpression(typeNode));
                    const jsDoc = factory.createJSDocComment(
                    /*comment*/
                    void 0, [typeTag]);
                    changes.insertNodeAt(sourceFile, param.getStart(sourceFile), jsDoc, { suffix: " " });
                });
                if (needParens) {
                    changes.insertNodeAfter(sourceFile, last(signature.parameters), factory.createToken(21 /* CloseParenToken */));
                }
            }
            else {
                const paramTags = map(inferences, ({ name, typeNode, isOptional }) => factory.createJSDocParameterTag(
                /*tagName*/
                void 0, name, 
                /*isBracketed*/
                !!isOptional, factory.createJSDocTypeExpression(typeNode), 
                /* isNameFirst */
                false, 
                /*comment*/
                void 0));
                changes.addJSDocTags(sourceFile, signature, paramTags);
            }
        }
        function getReferences(token, program, cancellationToken) {
            return mapDefined(ts_FindAllReferences_exports.getReferenceEntriesForNode(-1, token, program, program.getSourceFiles(), cancellationToken), (entry) => entry.kind !== ts_FindAllReferences_exports.EntryKind.Span ? tryCast(entry.node, isIdentifier) : void 0);
        }
        function inferTypeForVariableFromUsage(token, program, cancellationToken) {
            const references = getReferences(token, program, cancellationToken);
            return inferTypeFromReferences(program, references, cancellationToken).single();
        }
        function inferTypeForParametersFromUsage(func, sourceFile, program, cancellationToken) {
            const references = getFunctionReferences(func, sourceFile, program, cancellationToken);
            return references && inferTypeFromReferences(program, references, cancellationToken).parameters(func) || func.parameters.map((p) => ({
                declaration: p,
                type: isIdentifier(p.name) ? inferTypeForVariableFromUsage(p.name, program, cancellationToken) : program.getTypeChecker().getAnyType()
            }));
        }
        function getFunctionReferences(containingFunction, sourceFile, program, cancellationToken) {
            let searchToken;
            switch (containingFunction.kind) {
                case 173 /* Constructor */:
                    searchToken = findChildOfKind(containingFunction, 135 /* ConstructorKeyword */, sourceFile);
                    break;
                case 216 /* ArrowFunction */:
                case 215 /* FunctionExpression */:
                    const parent2 = containingFunction.parent;
                    searchToken = (isVariableDeclaration(parent2) || isPropertyDeclaration(parent2)) && isIdentifier(parent2.name) ? parent2.name : containingFunction.name;
                    break;
                case 259 /* FunctionDeclaration */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                    searchToken = containingFunction.name;
                    break;
            }
            if (!searchToken) {
                return void 0;
            }
            return getReferences(searchToken, program, cancellationToken);
        }
        function inferTypeFromReferences(program, references, cancellationToken) {
            const checker = program.getTypeChecker();
            const builtinConstructors = {
                string: () => checker.getStringType(),
                number: () => checker.getNumberType(),
                Array: (t) => checker.createArrayType(t),
                Promise: (t) => checker.createPromiseType(t)
            };
            const builtins = [
                checker.getStringType(),
                checker.getNumberType(),
                checker.createArrayType(checker.getAnyType()),
                checker.createPromiseType(checker.getAnyType())
            ];
            return {
                single: single2,
                parameters,
                thisParameter
            };
            function createEmptyUsage() {
                return {
                    isNumber: void 0,
                    isString: void 0,
                    isNumberOrString: void 0,
                    candidateTypes: void 0,
                    properties: void 0,
                    calls: void 0,
                    constructs: void 0,
                    numberIndex: void 0,
                    stringIndex: void 0,
                    candidateThisTypes: void 0,
                    inferredTypes: void 0
                };
            }
            function combineUsages(usages) {
                const combinedProperties = /* @__PURE__ */ new Map();
                for (const u of usages) {
                    if (u.properties) {
                        u.properties.forEach((p, name) => {
                            if (!combinedProperties.has(name)) {
                                combinedProperties.set(name, []);
                            }
                            combinedProperties.get(name).push(p);
                        });
                    }
                }
                const properties = /* @__PURE__ */ new Map();
                combinedProperties.forEach((ps, name) => {
                    properties.set(name, combineUsages(ps));
                });
                return {
                    isNumber: usages.some((u) => u.isNumber),
                    isString: usages.some((u) => u.isString),
                    isNumberOrString: usages.some((u) => u.isNumberOrString),
                    candidateTypes: flatMap(usages, (u) => u.candidateTypes),
                    properties,
                    calls: flatMap(usages, (u) => u.calls),
                    constructs: flatMap(usages, (u) => u.constructs),
                    numberIndex: forEach(usages, (u) => u.numberIndex),
                    stringIndex: forEach(usages, (u) => u.stringIndex),
                    candidateThisTypes: flatMap(usages, (u) => u.candidateThisTypes),
                    inferredTypes: void 0
                    // clear type cache
                };
            }
            function single2() {
                return combineTypes(inferTypesFromReferencesSingle(references));
            }
            function parameters(declaration) {
                if (references.length === 0 || !declaration.parameters) {
                    return void 0;
                }
                const usage = createEmptyUsage();
                for (const reference of references) {
                    cancellationToken.throwIfCancellationRequested();
                    calculateUsageOfNode(reference, usage);
                }
                const calls = [...usage.constructs || [], ...usage.calls || []];
                return declaration.parameters.map((parameter, parameterIndex) => {
                    const types = [];
                    const isRest = isRestParameter(parameter);
                    let isOptional = false;
                    for (const call of calls) {
                        if (call.argumentTypes.length <= parameterIndex) {
                            isOptional = isInJSFile(declaration);
                            types.push(checker.getUndefinedType());
                        }
                        else if (isRest) {
                            for (let i = parameterIndex; i < call.argumentTypes.length; i++) {
                                types.push(checker.getBaseTypeOfLiteralType(call.argumentTypes[i]));
                            }
                        }
                        else {
                            types.push(checker.getBaseTypeOfLiteralType(call.argumentTypes[parameterIndex]));
                        }
                    }
                    if (isIdentifier(parameter.name)) {
                        const inferred = inferTypesFromReferencesSingle(getReferences(parameter.name, program, cancellationToken));
                        types.push(...isRest ? mapDefined(inferred, checker.getElementTypeOfArrayType) : inferred);
                    }
                    const type = combineTypes(types);
                    return {
                        type: isRest ? checker.createArrayType(type) : type,
                        isOptional: isOptional && !isRest,
                        declaration: parameter
                    };
                });
            }
            function thisParameter() {
                const usage = createEmptyUsage();
                for (const reference of references) {
                    cancellationToken.throwIfCancellationRequested();
                    calculateUsageOfNode(reference, usage);
                }
                return combineTypes(usage.candidateThisTypes || emptyArray);
            }
            function inferTypesFromReferencesSingle(references2) {
                const usage = createEmptyUsage();
                for (const reference of references2) {
                    cancellationToken.throwIfCancellationRequested();
                    calculateUsageOfNode(reference, usage);
                }
                return inferTypes(usage);
            }
            function calculateUsageOfNode(node, usage) {
                while (isRightSideOfQualifiedNameOrPropertyAccess(node)) {
                    node = node.parent;
                }
                switch (node.parent.kind) {
                    case 241 /* ExpressionStatement */:
                        inferTypeFromExpressionStatement(node, usage);
                        break;
                    case 222 /* PostfixUnaryExpression */:
                        usage.isNumber = true;
                        break;
                    case 221 /* PrefixUnaryExpression */:
                        inferTypeFromPrefixUnaryExpression(node.parent, usage);
                        break;
                    case 223 /* BinaryExpression */:
                        inferTypeFromBinaryExpression(node, node.parent, usage);
                        break;
                    case 292 /* CaseClause */:
                    case 293 /* DefaultClause */:
                        inferTypeFromSwitchStatementLabel(node.parent, usage);
                        break;
                    case 210 /* CallExpression */:
                    case 211 /* NewExpression */:
                        if (node.parent.expression === node) {
                            inferTypeFromCallExpression(node.parent, usage);
                        }
                        else {
                            inferTypeFromContextualType(node, usage);
                        }
                        break;
                    case 208 /* PropertyAccessExpression */:
                        inferTypeFromPropertyAccessExpression(node.parent, usage);
                        break;
                    case 209 /* ElementAccessExpression */:
                        inferTypeFromPropertyElementExpression(node.parent, node, usage);
                        break;
                    case 299 /* PropertyAssignment */:
                    case 300 /* ShorthandPropertyAssignment */:
                        inferTypeFromPropertyAssignment(node.parent, usage);
                        break;
                    case 169 /* PropertyDeclaration */:
                        inferTypeFromPropertyDeclaration(node.parent, usage);
                        break;
                    case 257 /* VariableDeclaration */: {
                        const { name, initializer } = node.parent;
                        if (node === name) {
                            if (initializer) {
                                addCandidateType(usage, checker.getTypeAtLocation(initializer));
                            }
                            break;
                        }
                    }
                    default:
                        return inferTypeFromContextualType(node, usage);
                }
            }
            function inferTypeFromContextualType(node, usage) {
                if (isExpressionNode(node)) {
                    addCandidateType(usage, checker.getContextualType(node));
                }
            }
            function inferTypeFromExpressionStatement(node, usage) {
                addCandidateType(usage, isCallExpression(node) ? checker.getVoidType() : checker.getAnyType());
            }
            function inferTypeFromPrefixUnaryExpression(node, usage) {
                switch (node.operator) {
                    case 45 /* PlusPlusToken */:
                    case 46 /* MinusMinusToken */:
                    case 40 /* MinusToken */:
                    case 54 /* TildeToken */:
                        usage.isNumber = true;
                        break;
                    case 39 /* PlusToken */:
                        usage.isNumberOrString = true;
                        break;
                }
            }
            function inferTypeFromBinaryExpression(node, parent2, usage) {
                switch (parent2.operatorToken.kind) {
                    case 42 /* AsteriskAsteriskToken */:
                    case 41 /* AsteriskToken */:
                    case 43 /* SlashToken */:
                    case 44 /* PercentToken */:
                    case 47 /* LessThanLessThanToken */:
                    case 48 /* GreaterThanGreaterThanToken */:
                    case 49 /* GreaterThanGreaterThanGreaterThanToken */:
                    case 50 /* AmpersandToken */:
                    case 51 /* BarToken */:
                    case 52 /* CaretToken */:
                    case 65 /* MinusEqualsToken */:
                    case 67 /* AsteriskAsteriskEqualsToken */:
                    case 66 /* AsteriskEqualsToken */:
                    case 68 /* SlashEqualsToken */:
                    case 69 /* PercentEqualsToken */:
                    case 73 /* AmpersandEqualsToken */:
                    case 74 /* BarEqualsToken */:
                    case 78 /* CaretEqualsToken */:
                    case 70 /* LessThanLessThanEqualsToken */:
                    case 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                    case 71 /* GreaterThanGreaterThanEqualsToken */:
                    case 40 /* MinusToken */:
                    case 29 /* LessThanToken */:
                    case 32 /* LessThanEqualsToken */:
                    case 31 /* GreaterThanToken */:
                    case 33 /* GreaterThanEqualsToken */:
                        const operandType = checker.getTypeAtLocation(parent2.left === node ? parent2.right : parent2.left);
                        if (operandType.flags & 1056 /* EnumLike */) {
                            addCandidateType(usage, operandType);
                        }
                        else {
                            usage.isNumber = true;
                        }
                        break;
                    case 64 /* PlusEqualsToken */:
                    case 39 /* PlusToken */:
                        const otherOperandType = checker.getTypeAtLocation(parent2.left === node ? parent2.right : parent2.left);
                        if (otherOperandType.flags & 1056 /* EnumLike */) {
                            addCandidateType(usage, otherOperandType);
                        }
                        else if (otherOperandType.flags & 296 /* NumberLike */) {
                            usage.isNumber = true;
                        }
                        else if (otherOperandType.flags & 402653316 /* StringLike */) {
                            usage.isString = true;
                        }
                        else if (otherOperandType.flags & 1 /* Any */) {
                        }
                        else {
                            usage.isNumberOrString = true;
                        }
                        break;
                    case 63 /* EqualsToken */:
                    case 34 /* EqualsEqualsToken */:
                    case 36 /* EqualsEqualsEqualsToken */:
                    case 37 /* ExclamationEqualsEqualsToken */:
                    case 35 /* ExclamationEqualsToken */:
                        addCandidateType(usage, checker.getTypeAtLocation(parent2.left === node ? parent2.right : parent2.left));
                        break;
                    case 101 /* InKeyword */:
                        if (node === parent2.left) {
                            usage.isString = true;
                        }
                        break;
                    case 56 /* BarBarToken */:
                    case 60 /* QuestionQuestionToken */:
                        if (node === parent2.left && (node.parent.parent.kind === 257 /* VariableDeclaration */ || isAssignmentExpression(node.parent.parent, 
                        /*excludeCompoundAssignment*/
                        true))) {
                            addCandidateType(usage, checker.getTypeAtLocation(parent2.right));
                        }
                        break;
                    case 55 /* AmpersandAmpersandToken */:
                    case 27 /* CommaToken */:
                    case 102 /* InstanceOfKeyword */:
                        break;
                }
            }
            function inferTypeFromSwitchStatementLabel(parent2, usage) {
                addCandidateType(usage, checker.getTypeAtLocation(parent2.parent.parent.expression));
            }
            function inferTypeFromCallExpression(parent2, usage) {
                const call = {
                    argumentTypes: [],
                    return_: createEmptyUsage()
                };
                if (parent2.arguments) {
                    for (const argument of parent2.arguments) {
                        call.argumentTypes.push(checker.getTypeAtLocation(argument));
                    }
                }
                calculateUsageOfNode(parent2, call.return_);
                if (parent2.kind === 210 /* CallExpression */) {
                    (usage.calls || (usage.calls = [])).push(call);
                }
                else {
                    (usage.constructs || (usage.constructs = [])).push(call);
                }
            }
            function inferTypeFromPropertyAccessExpression(parent2, usage) {
                const name = escapeLeadingUnderscores(parent2.name.text);
                if (!usage.properties) {
                    usage.properties = /* @__PURE__ */ new Map();
                }
                const propertyUsage = usage.properties.get(name) || createEmptyUsage();
                calculateUsageOfNode(parent2, propertyUsage);
                usage.properties.set(name, propertyUsage);
            }
            function inferTypeFromPropertyElementExpression(parent2, node, usage) {
                if (node === parent2.argumentExpression) {
                    usage.isNumberOrString = true;
                    return;
                }
                else {
                    const indexType = checker.getTypeAtLocation(parent2.argumentExpression);
                    const indexUsage = createEmptyUsage();
                    calculateUsageOfNode(parent2, indexUsage);
                    if (indexType.flags & 296 /* NumberLike */) {
                        usage.numberIndex = indexUsage;
                    }
                    else {
                        usage.stringIndex = indexUsage;
                    }
                }
            }
            function inferTypeFromPropertyAssignment(assignment, usage) {
                const nodeWithRealType = isVariableDeclaration(assignment.parent.parent) ? assignment.parent.parent : assignment.parent;
                addCandidateThisType(usage, checker.getTypeAtLocation(nodeWithRealType));
            }
            function inferTypeFromPropertyDeclaration(declaration, usage) {
                addCandidateThisType(usage, checker.getTypeAtLocation(declaration.parent));
            }
            function removeLowPriorityInferences(inferences, priorities) {
                const toRemove = [];
                for (const i of inferences) {
                    for (const { high, low } of priorities) {
                        if (high(i)) {
                            Debug.assert(!low(i), "Priority can't have both low and high");
                            toRemove.push(low);
                        }
                    }
                }
                return inferences.filter((i) => toRemove.every((f) => !f(i)));
            }
            function combineFromUsage(usage) {
                return combineTypes(inferTypes(usage));
            }
            function combineTypes(inferences) {
                if (!inferences.length)
                    return checker.getAnyType();
                const stringNumber = checker.getUnionType([checker.getStringType(), checker.getNumberType()]);
                const priorities = [
                    {
                        high: (t) => t === checker.getStringType() || t === checker.getNumberType(),
                        low: (t) => t === stringNumber
                    },
                    {
                        high: (t) => !(t.flags & (1 /* Any */ | 16384 /* Void */)),
                        low: (t) => !!(t.flags & (1 /* Any */ | 16384 /* Void */))
                    },
                    {
                        high: (t) => !(t.flags & (98304 /* Nullable */ | 1 /* Any */ | 16384 /* Void */)) && !(getObjectFlags(t) & 16 /* Anonymous */),
                        low: (t) => !!(getObjectFlags(t) & 16 /* Anonymous */)
                    }
                ];
                let good = removeLowPriorityInferences(inferences, priorities);
                const anons = good.filter((i) => getObjectFlags(i) & 16 /* Anonymous */);
                if (anons.length) {
                    good = good.filter((i) => !(getObjectFlags(i) & 16 /* Anonymous */));
                    good.push(combineAnonymousTypes(anons));
                }
                return checker.getWidenedType(checker.getUnionType(good.map(checker.getBaseTypeOfLiteralType), 2 /* Subtype */));
            }
            function combineAnonymousTypes(anons) {
                if (anons.length === 1) {
                    return anons[0];
                }
                const calls = [];
                const constructs = [];
                const stringIndices = [];
                const numberIndices = [];
                let stringIndexReadonly = false;
                let numberIndexReadonly = false;
                const props = createMultiMap();
                for (const anon2 of anons) {
                    for (const p of checker.getPropertiesOfType(anon2)) {
                        props.add(p.name, p.valueDeclaration ? checker.getTypeOfSymbolAtLocation(p, p.valueDeclaration) : checker.getAnyType());
                    }
                    calls.push(...checker.getSignaturesOfType(anon2, 0 /* Call */));
                    constructs.push(...checker.getSignaturesOfType(anon2, 1 /* Construct */));
                    const stringIndexInfo = checker.getIndexInfoOfType(anon2, 0 /* String */);
                    if (stringIndexInfo) {
                        stringIndices.push(stringIndexInfo.type);
                        stringIndexReadonly = stringIndexReadonly || stringIndexInfo.isReadonly;
                    }
                    const numberIndexInfo = checker.getIndexInfoOfType(anon2, 1 /* Number */);
                    if (numberIndexInfo) {
                        numberIndices.push(numberIndexInfo.type);
                        numberIndexReadonly = numberIndexReadonly || numberIndexInfo.isReadonly;
                    }
                }
                const members = mapEntries(props, (name, types) => {
                    const isOptional = types.length < anons.length ? 16777216 /* Optional */ : 0;
                    const s = checker.createSymbol(4 /* Property */ | isOptional, name);
                    s.links.type = checker.getUnionType(types);
                    return [name, s];
                });
                const indexInfos = [];
                if (stringIndices.length)
                    indexInfos.push(checker.createIndexInfo(checker.getStringType(), checker.getUnionType(stringIndices), stringIndexReadonly));
                if (numberIndices.length)
                    indexInfos.push(checker.createIndexInfo(checker.getNumberType(), checker.getUnionType(numberIndices), numberIndexReadonly));
                return checker.createAnonymousType(anons[0].symbol, members, calls, constructs, indexInfos);
            }
            function inferTypes(usage) {
                var _a2, _b, _c;
                const types = [];
                if (usage.isNumber) {
                    types.push(checker.getNumberType());
                }
                if (usage.isString) {
                    types.push(checker.getStringType());
                }
                if (usage.isNumberOrString) {
                    types.push(checker.getUnionType([checker.getStringType(), checker.getNumberType()]));
                }
                if (usage.numberIndex) {
                    types.push(checker.createArrayType(combineFromUsage(usage.numberIndex)));
                }
                if (((_a2 = usage.properties) == null ? void 0 : _a2.size) || ((_b = usage.constructs) == null ? void 0 : _b.length) || usage.stringIndex) {
                    types.push(inferStructuralType(usage));
                }
                const candidateTypes = (usage.candidateTypes || []).map((t) => checker.getBaseTypeOfLiteralType(t));
                const callsType = ((_c = usage.calls) == null ? void 0 : _c.length) ? inferStructuralType(usage) : void 0;
                if (callsType && candidateTypes) {
                    types.push(checker.getUnionType([callsType, ...candidateTypes], 2 /* Subtype */));
                }
                else {
                    if (callsType) {
                        types.push(callsType);
                    }
                    if (length(candidateTypes)) {
                        types.push(...candidateTypes);
                    }
                }
                types.push(...inferNamedTypesFromProperties(usage));
                return types;
            }
            function inferStructuralType(usage) {
                const members = /* @__PURE__ */ new Map();
                if (usage.properties) {
                    usage.properties.forEach((u, name) => {
                        const symbol = checker.createSymbol(4 /* Property */, name);
                        symbol.links.type = combineFromUsage(u);
                        members.set(name, symbol);
                    });
                }
                const callSignatures = usage.calls ? [getSignatureFromCalls(usage.calls)] : [];
                const constructSignatures = usage.constructs ? [getSignatureFromCalls(usage.constructs)] : [];
                const indexInfos = usage.stringIndex ? [checker.createIndexInfo(checker.getStringType(), combineFromUsage(usage.stringIndex), 
                    /*isReadonly*/
                    false)] : [];
                return checker.createAnonymousType(
                /*symbol*/
                void 0, members, callSignatures, constructSignatures, indexInfos);
            }
            function inferNamedTypesFromProperties(usage) {
                if (!usage.properties || !usage.properties.size)
                    return [];
                const types = builtins.filter((t) => allPropertiesAreAssignableToUsage(t, usage));
                if (0 < types.length && types.length < 3) {
                    return types.map((t) => inferInstantiationFromUsage(t, usage));
                }
                return [];
            }
            function allPropertiesAreAssignableToUsage(type, usage) {
                if (!usage.properties)
                    return false;
                return !forEachEntry(usage.properties, (propUsage, name) => {
                    const source = checker.getTypeOfPropertyOfType(type, name);
                    if (!source) {
                        return true;
                    }
                    if (propUsage.calls) {
                        const sigs = checker.getSignaturesOfType(source, 0 /* Call */);
                        return !sigs.length || !checker.isTypeAssignableTo(source, getFunctionFromCalls(propUsage.calls));
                    }
                    else {
                        return !checker.isTypeAssignableTo(source, combineFromUsage(propUsage));
                    }
                });
            }
            function inferInstantiationFromUsage(type, usage) {
                if (!(getObjectFlags(type) & 4 /* Reference */) || !usage.properties) {
                    return type;
                }
                const generic = type.target;
                const singleTypeParameter = singleOrUndefined(generic.typeParameters);
                if (!singleTypeParameter)
                    return type;
                const types = [];
                usage.properties.forEach((propUsage, name) => {
                    const genericPropertyType = checker.getTypeOfPropertyOfType(generic, name);
                    Debug.assert(!!genericPropertyType, "generic should have all the properties of its reference.");
                    types.push(...inferTypeParameters(genericPropertyType, combineFromUsage(propUsage), singleTypeParameter));
                });
                return builtinConstructors[type.symbol.escapedName](combineTypes(types));
            }
            function inferTypeParameters(genericType, usageType, typeParameter) {
                if (genericType === typeParameter) {
                    return [usageType];
                }
                else if (genericType.flags & 3145728 /* UnionOrIntersection */) {
                    return flatMap(genericType.types, (t) => inferTypeParameters(t, usageType, typeParameter));
                }
                else if (getObjectFlags(genericType) & 4 /* Reference */ && getObjectFlags(usageType) & 4 /* Reference */) {
                    const genericArgs = checker.getTypeArguments(genericType);
                    const usageArgs = checker.getTypeArguments(usageType);
                    const types = [];
                    if (genericArgs && usageArgs) {
                        for (let i = 0; i < genericArgs.length; i++) {
                            if (usageArgs[i]) {
                                types.push(...inferTypeParameters(genericArgs[i], usageArgs[i], typeParameter));
                            }
                        }
                    }
                    return types;
                }
                const genericSigs = checker.getSignaturesOfType(genericType, 0 /* Call */);
                const usageSigs = checker.getSignaturesOfType(usageType, 0 /* Call */);
                if (genericSigs.length === 1 && usageSigs.length === 1) {
                    return inferFromSignatures(genericSigs[0], usageSigs[0], typeParameter);
                }
                return [];
            }
            function inferFromSignatures(genericSig, usageSig, typeParameter) {
                var _a2;
                const types = [];
                for (let i = 0; i < genericSig.parameters.length; i++) {
                    const genericParam = genericSig.parameters[i];
                    const usageParam = usageSig.parameters[i];
                    const isRest = genericSig.declaration && isRestParameter(genericSig.declaration.parameters[i]);
                    if (!usageParam) {
                        break;
                    }
                    let genericParamType = genericParam.valueDeclaration ? checker.getTypeOfSymbolAtLocation(genericParam, genericParam.valueDeclaration) : checker.getAnyType();
                    const elementType = isRest && checker.getElementTypeOfArrayType(genericParamType);
                    if (elementType) {
                        genericParamType = elementType;
                    }
                    const targetType = ((_a2 = tryCast(usageParam, isTransientSymbol)) == null ? void 0 : _a2.links.type) || (usageParam.valueDeclaration ? checker.getTypeOfSymbolAtLocation(usageParam, usageParam.valueDeclaration) : checker.getAnyType());
                    types.push(...inferTypeParameters(genericParamType, targetType, typeParameter));
                }
                const genericReturn = checker.getReturnTypeOfSignature(genericSig);
                const usageReturn = checker.getReturnTypeOfSignature(usageSig);
                types.push(...inferTypeParameters(genericReturn, usageReturn, typeParameter));
                return types;
            }
            function getFunctionFromCalls(calls) {
                return checker.createAnonymousType(
                /*symbol*/
                void 0, createSymbolTable(), [getSignatureFromCalls(calls)], emptyArray, emptyArray);
            }
            function getSignatureFromCalls(calls) {
                const parameters2 = [];
                const length2 = Math.max(...calls.map((c) => c.argumentTypes.length));
                for (let i = 0; i < length2; i++) {
                    const symbol = checker.createSymbol(1 /* FunctionScopedVariable */, escapeLeadingUnderscores(`arg${i}`));
                    symbol.links.type = combineTypes(calls.map((call) => call.argumentTypes[i] || checker.getUndefinedType()));
                    if (calls.some((call) => call.argumentTypes[i] === void 0)) {
                        symbol.flags |= 16777216 /* Optional */;
                    }
                    parameters2.push(symbol);
                }
                const returnType = combineFromUsage(combineUsages(calls.map((call) => call.return_)));
                return checker.createSignature(
                /*declaration*/
                void 0, 
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, parameters2, returnType, 
                /*typePredicate*/
                void 0, length2, 0 /* None */);
            }
            function addCandidateType(usage, type) {
                if (type && !(type.flags & 1 /* Any */) && !(type.flags & 131072 /* Never */)) {
                    (usage.candidateTypes || (usage.candidateTypes = [])).push(type);
                }
            }
            function addCandidateThisType(usage, type) {
                if (type && !(type.flags & 1 /* Any */) && !(type.flags & 131072 /* Never */)) {
                    (usage.candidateThisTypes || (usage.candidateThisTypes = [])).push(type);
                }
            }
        }
        var fixId37, errorCodes47;
        var init_inferFromUsage = __esm({
            "src/services/codefixes/inferFromUsage.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId37 = "inferFromUsage";
                errorCodes47 = [
                    // Variable declarations
                    Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined.code,
                    // Variable uses
                    Diagnostics.Variable_0_implicitly_has_an_1_type.code,
                    // Parameter declarations
                    Diagnostics.Parameter_0_implicitly_has_an_1_type.code,
                    Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code,
                    // Get Accessor declarations
                    Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation.code,
                    Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type.code,
                    // Set Accessor declarations
                    Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation.code,
                    // Property declarations
                    Diagnostics.Member_0_implicitly_has_an_1_type.code,
                    //// Suggestions
                    // Variable declarations
                    Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage.code,
                    // Variable uses
                    Diagnostics.Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code,
                    // Parameter declarations
                    Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code,
                    Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage.code,
                    // Get Accessor declarations
                    Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage.code,
                    Diagnostics._0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage.code,
                    // Set Accessor declarations
                    Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage.code,
                    // Property declarations
                    Diagnostics.Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code,
                    // Function expressions and declarations
                    Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes47,
                    getCodeActions(context) {
                        const { sourceFile, program, span: { start }, errorCode, cancellationToken, host, preferences } = context;
                        const token = getTokenAtPosition(sourceFile, start);
                        let declaration;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => {
                            declaration = doChange24(changes2, sourceFile, token, errorCode, program, cancellationToken, 
                            /*markSeen*/
                            returnTrue, host, preferences);
                        });
                        const name = declaration && getNameOfDeclaration(declaration);
                        return !name || changes.length === 0 ? void 0 : [createCodeFixAction(fixId37, changes, [getDiagnostic(errorCode, token), getTextOfNode(name)], fixId37, Diagnostics.Infer_all_types_from_usage)];
                    },
                    fixIds: [fixId37],
                    getAllCodeActions(context) {
                        const { sourceFile, program, cancellationToken, host, preferences } = context;
                        const markSeen = nodeSeenTracker();
                        return codeFixAll(context, errorCodes47, (changes, err) => {
                            doChange24(changes, sourceFile, getTokenAtPosition(err.file, err.start), err.code, program, cancellationToken, markSeen, host, preferences);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixReturnTypeInAsyncFunction.ts
        function getInfo12(sourceFile, checker, pos) {
            if (isInJSFile(sourceFile)) {
                return void 0;
            }
            const token = getTokenAtPosition(sourceFile, pos);
            const func = findAncestor(token, isFunctionLikeDeclaration);
            const returnTypeNode = func == null ? void 0 : func.type;
            if (!returnTypeNode) {
                return void 0;
            }
            const returnType = checker.getTypeFromTypeNode(returnTypeNode);
            const promisedType = checker.getAwaitedType(returnType) || checker.getVoidType();
            const promisedTypeNode = checker.typeToTypeNode(promisedType, 
            /*enclosingDeclaration*/
            returnTypeNode, 
            /*flags*/
            void 0);
            if (promisedTypeNode) {
                return { returnTypeNode, returnType, promisedTypeNode, promisedType };
            }
        }
        function doChange25(changes, sourceFile, returnTypeNode, promisedTypeNode) {
            changes.replaceNode(sourceFile, returnTypeNode, factory.createTypeReferenceNode("Promise", [promisedTypeNode]));
        }
        var fixId38, errorCodes48;
        var init_fixReturnTypeInAsyncFunction = __esm({
            "src/services/codefixes/fixReturnTypeInAsyncFunction.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId38 = "fixReturnTypeInAsyncFunction";
                errorCodes48 = [
                    Diagnostics.The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes48,
                    fixIds: [fixId38],
                    getCodeActions: function getCodeActionsToFixReturnTypeInAsyncFunction(context) {
                        const { sourceFile, program, span } = context;
                        const checker = program.getTypeChecker();
                        const info = getInfo12(sourceFile, program.getTypeChecker(), span.start);
                        if (!info) {
                            return void 0;
                        }
                        const { returnTypeNode, returnType, promisedTypeNode, promisedType } = info;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange25(t, sourceFile, returnTypeNode, promisedTypeNode));
                        return [createCodeFixAction(fixId38, changes, [
                                Diagnostics.Replace_0_with_Promise_1,
                                checker.typeToString(returnType),
                                checker.typeToString(promisedType)
                            ], fixId38, Diagnostics.Fix_all_incorrect_return_type_of_an_async_functions)];
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes48, (changes, diag2) => {
                        const info = getInfo12(diag2.file, context.program.getTypeChecker(), diag2.start);
                        if (info) {
                            doChange25(changes, diag2.file, info.returnTypeNode, info.promisedTypeNode);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/disableJsDiagnostics.ts
        function makeChange8(changes, sourceFile, position, seenLines) {
            const { line: lineNumber } = getLineAndCharacterOfPosition(sourceFile, position);
            if (!seenLines || tryAddToSet(seenLines, lineNumber)) {
                changes.insertCommentBeforeLine(sourceFile, lineNumber, position, " @ts-ignore");
            }
        }
        var fixName4, fixId39, errorCodes49;
        var init_disableJsDiagnostics = __esm({
            "src/services/codefixes/disableJsDiagnostics.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName4 = "disableJsDiagnostics";
                fixId39 = "disableJsDiagnostics";
                errorCodes49 = mapDefined(Object.keys(Diagnostics), (key) => {
                    const diag2 = Diagnostics[key];
                    return diag2.category === 1 /* Error */ ? diag2.code : void 0;
                });
                registerCodeFix({
                    errorCodes: errorCodes49,
                    getCodeActions: function getCodeActionsToDisableJsDiagnostics(context) {
                        const { sourceFile, program, span, host, formatContext } = context;
                        if (!isInJSFile(sourceFile) || !isCheckJsEnabledForFile(sourceFile, program.getCompilerOptions())) {
                            return void 0;
                        }
                        const newLineCharacter = sourceFile.checkJsDirective ? "" : getNewLineOrDefaultFromHost(host, formatContext.options);
                        const fixes = [
                            // fixId unnecessary because adding `// @ts-nocheck` even once will ignore every error in the file.
                            createCodeFixActionWithoutFixAll(fixName4, [createFileTextChanges(sourceFile.fileName, [
                                    createTextChange(sourceFile.checkJsDirective ? createTextSpanFromBounds(sourceFile.checkJsDirective.pos, sourceFile.checkJsDirective.end) : createTextSpan(0, 0), `// @ts-nocheck${newLineCharacter}`)
                                ])], Diagnostics.Disable_checking_for_this_file)
                        ];
                        if (ts_textChanges_exports.isValidLocationToAddComment(sourceFile, span.start)) {
                            fixes.unshift(createCodeFixAction(fixName4, ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange8(t, sourceFile, span.start)), Diagnostics.Ignore_this_error_message, fixId39, Diagnostics.Add_ts_ignore_to_all_error_messages));
                        }
                        return fixes;
                    },
                    fixIds: [fixId39],
                    getAllCodeActions: (context) => {
                        const seenLines = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes49, (changes, diag2) => {
                            if (ts_textChanges_exports.isValidLocationToAddComment(diag2.file, diag2.start)) {
                                makeChange8(changes, diag2.file, diag2.start, seenLines);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/helpers.ts
        function createMissingMemberNodes(classDeclaration, possiblyMissingSymbols, sourceFile, context, preferences, importAdder, addClassElement) {
            const classMembers = classDeclaration.symbol.members;
            for (const symbol of possiblyMissingSymbols) {
                if (!classMembers.has(symbol.escapedName)) {
                    addNewNodeForMemberSymbol(symbol, classDeclaration, sourceFile, context, preferences, importAdder, addClassElement, 
                    /* body */
                    void 0);
                }
            }
        }
        function getNoopSymbolTrackerWithResolver(context) {
            return {
                trackSymbol: () => false,
                moduleResolverHost: getModuleSpecifierResolverHost(context.program, context.host)
            };
        }
        function addNewNodeForMemberSymbol(symbol, enclosingDeclaration, sourceFile, context, preferences, importAdder, addClassElement, body, preserveOptional = 3 /* All */, isAmbient = false) {
            var _a2;
            const declarations = symbol.getDeclarations();
            const declaration = declarations == null ? void 0 : declarations[0];
            const checker = context.program.getTypeChecker();
            const scriptTarget = getEmitScriptTarget(context.program.getCompilerOptions());
            const kind = (_a2 = declaration == null ? void 0 : declaration.kind) != null ? _a2 : 168 /* PropertySignature */;
            const declarationName = getSynthesizedDeepClone(getNameOfDeclaration(declaration), 
            /*includeTrivia*/
            false);
            const effectiveModifierFlags = declaration ? getEffectiveModifierFlags(declaration) : 0 /* None */;
            let modifierFlags = effectiveModifierFlags & 4 /* Public */ ? 4 /* Public */ : effectiveModifierFlags & 16 /* Protected */ ? 16 /* Protected */ : 0 /* None */;
            if (declaration && isAutoAccessorPropertyDeclaration(declaration)) {
                modifierFlags |= 128 /* Accessor */;
            }
            const modifiers = createModifiers();
            const type = checker.getWidenedType(checker.getTypeOfSymbolAtLocation(symbol, enclosingDeclaration));
            const optional = !!(symbol.flags & 16777216 /* Optional */);
            const ambient = !!(enclosingDeclaration.flags & 16777216 /* Ambient */) || isAmbient;
            const quotePreference = getQuotePreference(sourceFile, preferences);
            switch (kind) {
                case 168 /* PropertySignature */:
                case 169 /* PropertyDeclaration */:
                    const flags = quotePreference === 0 /* Single */ ? 268435456 /* UseSingleQuotesForStringLiteralType */ : void 0;
                    let typeNode = checker.typeToTypeNode(type, enclosingDeclaration, flags, getNoopSymbolTrackerWithResolver(context));
                    if (importAdder) {
                        const importableReference = tryGetAutoImportableReferenceFromTypeNode(typeNode, scriptTarget);
                        if (importableReference) {
                            typeNode = importableReference.typeNode;
                            importSymbols(importAdder, importableReference.symbols);
                        }
                    }
                    addClassElement(factory.createPropertyDeclaration(modifiers, declaration ? createName(declarationName) : symbol.getName(), optional && preserveOptional & 2 /* Property */ ? factory.createToken(57 /* QuestionToken */) : void 0, typeNode, 
                    /*initializer*/
                    void 0));
                    break;
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */: {
                    Debug.assertIsDefined(declarations);
                    let typeNode2 = checker.typeToTypeNode(type, enclosingDeclaration, 
                    /*flags*/
                    void 0, getNoopSymbolTrackerWithResolver(context));
                    const allAccessors = getAllAccessorDeclarations(declarations, declaration);
                    const orderedAccessors = allAccessors.secondAccessor ? [allAccessors.firstAccessor, allAccessors.secondAccessor] : [allAccessors.firstAccessor];
                    if (importAdder) {
                        const importableReference = tryGetAutoImportableReferenceFromTypeNode(typeNode2, scriptTarget);
                        if (importableReference) {
                            typeNode2 = importableReference.typeNode;
                            importSymbols(importAdder, importableReference.symbols);
                        }
                    }
                    for (const accessor of orderedAccessors) {
                        if (isGetAccessorDeclaration(accessor)) {
                            addClassElement(factory.createGetAccessorDeclaration(modifiers, createName(declarationName), emptyArray, createTypeNode(typeNode2), createBody(body, quotePreference, ambient)));
                        }
                        else {
                            Debug.assertNode(accessor, isSetAccessorDeclaration, "The counterpart to a getter should be a setter");
                            const parameter = getSetAccessorValueParameter(accessor);
                            const parameterName = parameter && isIdentifier(parameter.name) ? idText(parameter.name) : void 0;
                            addClassElement(factory.createSetAccessorDeclaration(modifiers, createName(declarationName), createDummyParameters(1, [parameterName], [createTypeNode(typeNode2)], 1, 
                            /*inJs*/
                            false), createBody(body, quotePreference, ambient)));
                        }
                    }
                    break;
                }
                case 170 /* MethodSignature */:
                case 171 /* MethodDeclaration */:
                    Debug.assertIsDefined(declarations);
                    const signatures = type.isUnion() ? flatMap(type.types, (t) => t.getCallSignatures()) : type.getCallSignatures();
                    if (!some(signatures)) {
                        break;
                    }
                    if (declarations.length === 1) {
                        Debug.assert(signatures.length === 1, "One declaration implies one signature");
                        const signature = signatures[0];
                        outputMethod(quotePreference, signature, modifiers, createName(declarationName), createBody(body, quotePreference, ambient));
                        break;
                    }
                    for (const signature of signatures) {
                        outputMethod(quotePreference, signature, modifiers, createName(declarationName));
                    }
                    if (!ambient) {
                        if (declarations.length > signatures.length) {
                            const signature = checker.getSignatureFromDeclaration(declarations[declarations.length - 1]);
                            outputMethod(quotePreference, signature, modifiers, createName(declarationName), createBody(body, quotePreference));
                        }
                        else {
                            Debug.assert(declarations.length === signatures.length, "Declarations and signatures should match count");
                            addClassElement(createMethodImplementingSignatures(checker, context, enclosingDeclaration, signatures, createName(declarationName), optional && !!(preserveOptional & 1 /* Method */), modifiers, quotePreference, body));
                        }
                    }
                    break;
            }
            function outputMethod(quotePreference2, signature, modifiers2, name, body2) {
                const method = createSignatureDeclarationFromSignature(171 /* MethodDeclaration */, context, quotePreference2, signature, body2, name, modifiers2, optional && !!(preserveOptional & 1 /* Method */), enclosingDeclaration, importAdder);
                if (method)
                    addClassElement(method);
            }
            function createModifiers() {
                let modifiers2;
                if (modifierFlags) {
                    modifiers2 = combine(modifiers2, factory.createModifiersFromModifierFlags(modifierFlags));
                }
                if (shouldAddOverrideKeyword()) {
                    modifiers2 = append(modifiers2, factory.createToken(161 /* OverrideKeyword */));
                }
                return modifiers2 && factory.createNodeArray(modifiers2);
            }
            function shouldAddOverrideKeyword() {
                return !!(context.program.getCompilerOptions().noImplicitOverride && declaration && hasAbstractModifier(declaration));
            }
            function createName(node) {
                if (isIdentifier(node) && node.escapedText === "constructor") {
                    return factory.createComputedPropertyName(factory.createStringLiteral(idText(node), quotePreference === 0 /* Single */));
                }
                return getSynthesizedDeepClone(node, 
                /*includeTrivia*/
                false);
            }
            function createBody(block, quotePreference2, ambient2) {
                return ambient2 ? void 0 : getSynthesizedDeepClone(block, 
                /*includeTrivia*/
                false) || createStubbedMethodBody(quotePreference2);
            }
            function createTypeNode(typeNode) {
                return getSynthesizedDeepClone(typeNode, 
                /*includeTrivia*/
                false);
            }
        }
        function createSignatureDeclarationFromSignature(kind, context, quotePreference, signature, body, name, modifiers, optional, enclosingDeclaration, importAdder) {
            const program = context.program;
            const checker = program.getTypeChecker();
            const scriptTarget = getEmitScriptTarget(program.getCompilerOptions());
            const isJs = isInJSFile(enclosingDeclaration);
            const flags = 1 /* NoTruncation */ | 256 /* SuppressAnyReturnType */ | 524288 /* AllowEmptyTuple */ | (quotePreference === 0 /* Single */ ? 268435456 /* UseSingleQuotesForStringLiteralType */ : 0 /* None */);
            const signatureDeclaration = checker.signatureToSignatureDeclaration(signature, kind, enclosingDeclaration, flags, getNoopSymbolTrackerWithResolver(context));
            if (!signatureDeclaration) {
                return void 0;
            }
            let typeParameters = isJs ? void 0 : signatureDeclaration.typeParameters;
            let parameters = signatureDeclaration.parameters;
            let type = isJs ? void 0 : signatureDeclaration.type;
            if (importAdder) {
                if (typeParameters) {
                    const newTypeParameters = sameMap(typeParameters, (typeParameterDecl) => {
                        let constraint = typeParameterDecl.constraint;
                        let defaultType = typeParameterDecl.default;
                        if (constraint) {
                            const importableReference = tryGetAutoImportableReferenceFromTypeNode(constraint, scriptTarget);
                            if (importableReference) {
                                constraint = importableReference.typeNode;
                                importSymbols(importAdder, importableReference.symbols);
                            }
                        }
                        if (defaultType) {
                            const importableReference = tryGetAutoImportableReferenceFromTypeNode(defaultType, scriptTarget);
                            if (importableReference) {
                                defaultType = importableReference.typeNode;
                                importSymbols(importAdder, importableReference.symbols);
                            }
                        }
                        return factory.updateTypeParameterDeclaration(typeParameterDecl, typeParameterDecl.modifiers, typeParameterDecl.name, constraint, defaultType);
                    });
                    if (typeParameters !== newTypeParameters) {
                        typeParameters = setTextRange(factory.createNodeArray(newTypeParameters, typeParameters.hasTrailingComma), typeParameters);
                    }
                }
                const newParameters = sameMap(parameters, (parameterDecl) => {
                    let type2 = isJs ? void 0 : parameterDecl.type;
                    if (type2) {
                        const importableReference = tryGetAutoImportableReferenceFromTypeNode(type2, scriptTarget);
                        if (importableReference) {
                            type2 = importableReference.typeNode;
                            importSymbols(importAdder, importableReference.symbols);
                        }
                    }
                    return factory.updateParameterDeclaration(parameterDecl, parameterDecl.modifiers, parameterDecl.dotDotDotToken, parameterDecl.name, isJs ? void 0 : parameterDecl.questionToken, type2, parameterDecl.initializer);
                });
                if (parameters !== newParameters) {
                    parameters = setTextRange(factory.createNodeArray(newParameters, parameters.hasTrailingComma), parameters);
                }
                if (type) {
                    const importableReference = tryGetAutoImportableReferenceFromTypeNode(type, scriptTarget);
                    if (importableReference) {
                        type = importableReference.typeNode;
                        importSymbols(importAdder, importableReference.symbols);
                    }
                }
            }
            const questionToken = optional ? factory.createToken(57 /* QuestionToken */) : void 0;
            const asteriskToken = signatureDeclaration.asteriskToken;
            if (isFunctionExpression(signatureDeclaration)) {
                return factory.updateFunctionExpression(signatureDeclaration, modifiers, signatureDeclaration.asteriskToken, tryCast(name, isIdentifier), typeParameters, parameters, type, body != null ? body : signatureDeclaration.body);
            }
            if (isArrowFunction(signatureDeclaration)) {
                return factory.updateArrowFunction(signatureDeclaration, modifiers, typeParameters, parameters, type, signatureDeclaration.equalsGreaterThanToken, body != null ? body : signatureDeclaration.body);
            }
            if (isMethodDeclaration(signatureDeclaration)) {
                return factory.updateMethodDeclaration(signatureDeclaration, modifiers, asteriskToken, name != null ? name : factory.createIdentifier(""), questionToken, typeParameters, parameters, type, body);
            }
            if (isFunctionDeclaration(signatureDeclaration)) {
                return factory.updateFunctionDeclaration(signatureDeclaration, modifiers, signatureDeclaration.asteriskToken, tryCast(name, isIdentifier), typeParameters, parameters, type, body != null ? body : signatureDeclaration.body);
            }
            return void 0;
        }
        function createSignatureDeclarationFromCallExpression(kind, context, importAdder, call, name, modifierFlags, contextNode) {
            const quotePreference = getQuotePreference(context.sourceFile, context.preferences);
            const scriptTarget = getEmitScriptTarget(context.program.getCompilerOptions());
            const tracker = getNoopSymbolTrackerWithResolver(context);
            const checker = context.program.getTypeChecker();
            const isJs = isInJSFile(contextNode);
            const { typeArguments, arguments: args, parent: parent2 } = call;
            const contextualType = isJs ? void 0 : checker.getContextualType(call);
            const names = map(args, (arg) => isIdentifier(arg) ? arg.text : isPropertyAccessExpression(arg) && isIdentifier(arg.name) ? arg.name.text : void 0);
            const instanceTypes = isJs ? [] : map(args, (arg) => checker.getTypeAtLocation(arg));
            const { argumentTypeNodes, argumentTypeParameters } = getArgumentTypesAndTypeParameters(checker, importAdder, instanceTypes, contextNode, scriptTarget, 
            /*flags*/
            void 0, tracker);
            const modifiers = modifierFlags ? factory.createNodeArray(factory.createModifiersFromModifierFlags(modifierFlags)) : void 0;
            const asteriskToken = isYieldExpression(parent2) ? factory.createToken(41 /* AsteriskToken */) : void 0;
            const typeParameters = isJs ? void 0 : createTypeParametersForArguments(checker, argumentTypeParameters, typeArguments);
            const parameters = createDummyParameters(args.length, names, argumentTypeNodes, 
            /*minArgumentCount*/
            void 0, isJs);
            const type = isJs || contextualType === void 0 ? void 0 : checker.typeToTypeNode(contextualType, contextNode, 
            /*flags*/
            void 0, tracker);
            switch (kind) {
                case 171 /* MethodDeclaration */:
                    return factory.createMethodDeclaration(modifiers, asteriskToken, name, 
                    /*questionToken*/
                    void 0, typeParameters, parameters, type, createStubbedMethodBody(quotePreference));
                case 170 /* MethodSignature */:
                    return factory.createMethodSignature(modifiers, name, 
                    /*questionToken*/
                    void 0, typeParameters, parameters, type === void 0 ? factory.createKeywordTypeNode(157 /* UnknownKeyword */) : type);
                case 259 /* FunctionDeclaration */:
                    return factory.createFunctionDeclaration(modifiers, asteriskToken, name, typeParameters, parameters, type, createStubbedBody(Diagnostics.Function_not_implemented.message, quotePreference));
                default:
                    Debug.fail("Unexpected kind");
            }
        }
        function createTypeParametersForArguments(checker, argumentTypeParameters, typeArguments) {
            const usedNames = new Set(argumentTypeParameters.map((pair) => pair[0]));
            const constraintsByName = new Map(argumentTypeParameters);
            if (typeArguments) {
                const typeArgumentsWithNewTypes = typeArguments.filter((typeArgument) => !argumentTypeParameters.some((pair) => {
                    var _a2;
                    return checker.getTypeAtLocation(typeArgument) === ((_a2 = pair[1]) == null ? void 0 : _a2.argumentType);
                }));
                const targetSize = usedNames.size + typeArgumentsWithNewTypes.length;
                for (let i = 0; usedNames.size < targetSize; i += 1) {
                    usedNames.add(createTypeParameterName(i));
                }
            }
            return arrayFrom(usedNames.values(), (usedName) => {
                var _a2;
                return factory.createTypeParameterDeclaration(
                /*modifiers*/
                void 0, usedName, (_a2 = constraintsByName.get(usedName)) == null ? void 0 : _a2.constraint);
            });
        }
        function createTypeParameterName(index) {
            return 84 /* T */ + index <= 90 /* Z */ ? String.fromCharCode(84 /* T */ + index) : `T${index}`;
        }
        function typeToAutoImportableTypeNode(checker, importAdder, type, contextNode, scriptTarget, flags, tracker) {
            let typeNode = checker.typeToTypeNode(type, contextNode, flags, tracker);
            if (typeNode && isImportTypeNode(typeNode)) {
                const importableReference = tryGetAutoImportableReferenceFromTypeNode(typeNode, scriptTarget);
                if (importableReference) {
                    importSymbols(importAdder, importableReference.symbols);
                    typeNode = importableReference.typeNode;
                }
            }
            return getSynthesizedDeepClone(typeNode);
        }
        function typeContainsTypeParameter(type) {
            if (type.isUnionOrIntersection()) {
                return type.types.some(typeContainsTypeParameter);
            }
            return type.flags & 262144 /* TypeParameter */;
        }
        function getArgumentTypesAndTypeParameters(checker, importAdder, instanceTypes, contextNode, scriptTarget, flags, tracker) {
            const argumentTypeNodes = [];
            const argumentTypeParameters = /* @__PURE__ */ new Map();
            for (let i = 0; i < instanceTypes.length; i += 1) {
                const instanceType = instanceTypes[i];
                if (instanceType.isUnionOrIntersection() && instanceType.types.some(typeContainsTypeParameter)) {
                    const synthesizedTypeParameterName = createTypeParameterName(i);
                    argumentTypeNodes.push(factory.createTypeReferenceNode(synthesizedTypeParameterName));
                    argumentTypeParameters.set(synthesizedTypeParameterName, void 0);
                    continue;
                }
                const widenedInstanceType = checker.getBaseTypeOfLiteralType(instanceType);
                const argumentTypeNode = typeToAutoImportableTypeNode(checker, importAdder, widenedInstanceType, contextNode, scriptTarget, flags, tracker);
                if (!argumentTypeNode) {
                    continue;
                }
                argumentTypeNodes.push(argumentTypeNode);
                const argumentTypeParameter = getFirstTypeParameterName(instanceType);
                const instanceTypeConstraint = instanceType.isTypeParameter() && instanceType.constraint && !isAnonymousObjectConstraintType(instanceType.constraint) ? typeToAutoImportableTypeNode(checker, importAdder, instanceType.constraint, contextNode, scriptTarget, flags, tracker) : void 0;
                if (argumentTypeParameter) {
                    argumentTypeParameters.set(argumentTypeParameter, { argumentType: instanceType, constraint: instanceTypeConstraint });
                }
            }
            return { argumentTypeNodes, argumentTypeParameters: arrayFrom(argumentTypeParameters.entries()) };
        }
        function isAnonymousObjectConstraintType(type) {
            return type.flags & 524288 /* Object */ && type.objectFlags === 16 /* Anonymous */;
        }
        function getFirstTypeParameterName(type) {
            var _a2;
            if (type.flags & (1048576 /* Union */ | 2097152 /* Intersection */)) {
                for (const subType of type.types) {
                    const subTypeName = getFirstTypeParameterName(subType);
                    if (subTypeName) {
                        return subTypeName;
                    }
                }
            }
            return type.flags & 262144 /* TypeParameter */ ? (_a2 = type.getSymbol()) == null ? void 0 : _a2.getName() : void 0;
        }
        function createDummyParameters(argCount, names, types, minArgumentCount, inJs) {
            const parameters = [];
            const parameterNameCounts = /* @__PURE__ */ new Map();
            for (let i = 0; i < argCount; i++) {
                const parameterName = (names == null ? void 0 : names[i]) || `arg${i}`;
                const parameterNameCount = parameterNameCounts.get(parameterName);
                parameterNameCounts.set(parameterName, (parameterNameCount || 0) + 1);
                const newParameter = factory.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotDotDotToken*/
                void 0, 
                /*name*/
                parameterName + (parameterNameCount || ""), 
                /*questionToken*/
                minArgumentCount !== void 0 && i >= minArgumentCount ? factory.createToken(57 /* QuestionToken */) : void 0, 
                /*type*/
                inJs ? void 0 : (types == null ? void 0 : types[i]) || factory.createKeywordTypeNode(157 /* UnknownKeyword */), 
                /*initializer*/
                void 0);
                parameters.push(newParameter);
            }
            return parameters;
        }
        function createMethodImplementingSignatures(checker, context, enclosingDeclaration, signatures, name, optional, modifiers, quotePreference, body) {
            let maxArgsSignature = signatures[0];
            let minArgumentCount = signatures[0].minArgumentCount;
            let someSigHasRestParameter = false;
            for (const sig of signatures) {
                minArgumentCount = Math.min(sig.minArgumentCount, minArgumentCount);
                if (signatureHasRestParameter(sig)) {
                    someSigHasRestParameter = true;
                }
                if (sig.parameters.length >= maxArgsSignature.parameters.length && (!signatureHasRestParameter(sig) || signatureHasRestParameter(maxArgsSignature))) {
                    maxArgsSignature = sig;
                }
            }
            const maxNonRestArgs = maxArgsSignature.parameters.length - (signatureHasRestParameter(maxArgsSignature) ? 1 : 0);
            const maxArgsParameterSymbolNames = maxArgsSignature.parameters.map((symbol) => symbol.name);
            const parameters = createDummyParameters(maxNonRestArgs, maxArgsParameterSymbolNames, 
            /* types */
            void 0, minArgumentCount, 
            /*inJs*/
            false);
            if (someSigHasRestParameter) {
                const restParameter = factory.createParameterDeclaration(
                /*modifiers*/
                void 0, factory.createToken(25 /* DotDotDotToken */), maxArgsParameterSymbolNames[maxNonRestArgs] || "rest", 
                /*questionToken*/
                maxNonRestArgs >= minArgumentCount ? factory.createToken(57 /* QuestionToken */) : void 0, factory.createArrayTypeNode(factory.createKeywordTypeNode(157 /* UnknownKeyword */)), 
                /*initializer*/
                void 0);
                parameters.push(restParameter);
            }
            return createStubbedMethod(modifiers, name, optional, 
            /*typeParameters*/
            void 0, parameters, getReturnTypeFromSignatures(signatures, checker, context, enclosingDeclaration), quotePreference, body);
        }
        function getReturnTypeFromSignatures(signatures, checker, context, enclosingDeclaration) {
            if (length(signatures)) {
                const type = checker.getUnionType(map(signatures, checker.getReturnTypeOfSignature));
                return checker.typeToTypeNode(type, enclosingDeclaration, 1 /* NoTruncation */, getNoopSymbolTrackerWithResolver(context));
            }
        }
        function createStubbedMethod(modifiers, name, optional, typeParameters, parameters, returnType, quotePreference, body) {
            return factory.createMethodDeclaration(modifiers, 
            /*asteriskToken*/
            void 0, name, optional ? factory.createToken(57 /* QuestionToken */) : void 0, typeParameters, parameters, returnType, body || createStubbedMethodBody(quotePreference));
        }
        function createStubbedMethodBody(quotePreference) {
            return createStubbedBody(Diagnostics.Method_not_implemented.message, quotePreference);
        }
        function createStubbedBody(text, quotePreference) {
            return factory.createBlock([factory.createThrowStatement(factory.createNewExpression(factory.createIdentifier("Error"), 
                /*typeArguments*/
                void 0, 
                // TODO Handle auto quote preference.
                [factory.createStringLiteral(text, 
                    /*isSingleQuote*/
                    quotePreference === 0 /* Single */)]))], 
            /*multiline*/
            true);
        }
        function setJsonCompilerOptionValues(changeTracker, configFile, options) {
            const tsconfigObjectLiteral = getTsConfigObjectLiteralExpression(configFile);
            if (!tsconfigObjectLiteral)
                return void 0;
            const compilerOptionsProperty = findJsonProperty(tsconfigObjectLiteral, "compilerOptions");
            if (compilerOptionsProperty === void 0) {
                changeTracker.insertNodeAtObjectStart(configFile, tsconfigObjectLiteral, createJsonPropertyAssignment("compilerOptions", factory.createObjectLiteralExpression(options.map(([optionName, optionValue]) => createJsonPropertyAssignment(optionName, optionValue)), 
                /*multiLine*/
                true)));
                return;
            }
            const compilerOptions = compilerOptionsProperty.initializer;
            if (!isObjectLiteralExpression(compilerOptions)) {
                return;
            }
            for (const [optionName, optionValue] of options) {
                const optionProperty = findJsonProperty(compilerOptions, optionName);
                if (optionProperty === void 0) {
                    changeTracker.insertNodeAtObjectStart(configFile, compilerOptions, createJsonPropertyAssignment(optionName, optionValue));
                }
                else {
                    changeTracker.replaceNode(configFile, optionProperty.initializer, optionValue);
                }
            }
        }
        function setJsonCompilerOptionValue(changeTracker, configFile, optionName, optionValue) {
            setJsonCompilerOptionValues(changeTracker, configFile, [[optionName, optionValue]]);
        }
        function createJsonPropertyAssignment(name, initializer) {
            return factory.createPropertyAssignment(factory.createStringLiteral(name), initializer);
        }
        function findJsonProperty(obj, name) {
            return find(obj.properties, (p) => isPropertyAssignment(p) && !!p.name && isStringLiteral(p.name) && p.name.text === name);
        }
        function tryGetAutoImportableReferenceFromTypeNode(importTypeNode, scriptTarget) {
            let symbols;
            const typeNode = visitNode(importTypeNode, visit, isTypeNode);
            if (symbols && typeNode) {
                return { typeNode, symbols };
            }
            function visit(node) {
                if (isLiteralImportTypeNode(node) && node.qualifier) {
                    const firstIdentifier = getFirstIdentifier(node.qualifier);
                    const name = getNameForExportedSymbol(firstIdentifier.symbol, scriptTarget);
                    const qualifier = name !== firstIdentifier.text ? replaceFirstIdentifierOfEntityName(node.qualifier, factory.createIdentifier(name)) : node.qualifier;
                    symbols = append(symbols, firstIdentifier.symbol);
                    const typeArguments = visitNodes2(node.typeArguments, visit, isTypeNode);
                    return factory.createTypeReferenceNode(qualifier, typeArguments);
                }
                return visitEachChild(node, visit, nullTransformationContext);
            }
        }
        function replaceFirstIdentifierOfEntityName(name, newIdentifier) {
            if (name.kind === 79 /* Identifier */) {
                return newIdentifier;
            }
            return factory.createQualifiedName(replaceFirstIdentifierOfEntityName(name.left, newIdentifier), name.right);
        }
        function importSymbols(importAdder, symbols) {
            symbols.forEach((s) => importAdder.addImportFromExportedSymbol(s, 
            /*isValidTypeOnlyUseSite*/
            true));
        }
        function findAncestorMatchingSpan(sourceFile, span) {
            const end = textSpanEnd(span);
            let token = getTokenAtPosition(sourceFile, span.start);
            while (token.end < end) {
                token = token.parent;
            }
            return token;
        }
        var PreserveOptionalFlags;
        var init_helpers = __esm({
            "src/services/codefixes/helpers.ts"() {
                "use strict";
                init_ts4();
                PreserveOptionalFlags = /* @__PURE__ */ ((PreserveOptionalFlags2) => {
                    PreserveOptionalFlags2[PreserveOptionalFlags2["Method"] = 1] = "Method";
                    PreserveOptionalFlags2[PreserveOptionalFlags2["Property"] = 2] = "Property";
                    PreserveOptionalFlags2[PreserveOptionalFlags2["All"] = 3] = "All";
                    return PreserveOptionalFlags2;
                })(PreserveOptionalFlags || {});
            }
        });
        // src/services/codefixes/generateAccessors.ts
        function generateAccessorFromProperty(file, program, start, end, context, _actionName) {
            const fieldInfo = getAccessorConvertiblePropertyAtPosition(file, program, start, end);
            if (!fieldInfo || ts_refactor_exports.isRefactorErrorInfo(fieldInfo))
                return void 0;
            const changeTracker = ts_textChanges_exports.ChangeTracker.fromContext(context);
            const { isStatic: isStatic2, isReadonly, fieldName, accessorName, originalName, type, container, declaration } = fieldInfo;
            suppressLeadingAndTrailingTrivia(fieldName);
            suppressLeadingAndTrailingTrivia(accessorName);
            suppressLeadingAndTrailingTrivia(declaration);
            suppressLeadingAndTrailingTrivia(container);
            let accessorModifiers;
            let fieldModifiers;
            if (isClassLike(container)) {
                const modifierFlags = getEffectiveModifierFlags(declaration);
                if (isSourceFileJS(file)) {
                    const modifiers = factory.createModifiersFromModifierFlags(modifierFlags);
                    accessorModifiers = modifiers;
                    fieldModifiers = modifiers;
                }
                else {
                    accessorModifiers = factory.createModifiersFromModifierFlags(prepareModifierFlagsForAccessor(modifierFlags));
                    fieldModifiers = factory.createModifiersFromModifierFlags(prepareModifierFlagsForField(modifierFlags));
                }
                if (canHaveDecorators(declaration)) {
                    fieldModifiers = concatenate(getDecorators(declaration), fieldModifiers);
                }
            }
            updateFieldDeclaration(changeTracker, file, declaration, type, fieldName, fieldModifiers);
            const getAccessor = generateGetAccessor(fieldName, accessorName, type, accessorModifiers, isStatic2, container);
            suppressLeadingAndTrailingTrivia(getAccessor);
            insertAccessor(changeTracker, file, getAccessor, declaration, container);
            if (isReadonly) {
                const constructor = getFirstConstructorWithBody(container);
                if (constructor) {
                    updateReadonlyPropertyInitializerStatementConstructor(changeTracker, file, constructor, fieldName.text, originalName);
                }
            }
            else {
                const setAccessor = generateSetAccessor(fieldName, accessorName, type, accessorModifiers, isStatic2, container);
                suppressLeadingAndTrailingTrivia(setAccessor);
                insertAccessor(changeTracker, file, setAccessor, declaration, container);
            }
            return changeTracker.getChanges();
        }
        function isConvertibleName(name) {
            return isIdentifier(name) || isStringLiteral(name);
        }
        function isAcceptedDeclaration(node) {
            return isParameterPropertyDeclaration(node, node.parent) || isPropertyDeclaration(node) || isPropertyAssignment(node);
        }
        function createPropertyName(name, originalName) {
            return isIdentifier(originalName) ? factory.createIdentifier(name) : factory.createStringLiteral(name);
        }
        function createAccessorAccessExpression(fieldName, isStatic2, container) {
            const leftHead = isStatic2 ? container.name : factory.createThis();
            return isIdentifier(fieldName) ? factory.createPropertyAccessExpression(leftHead, fieldName) : factory.createElementAccessExpression(leftHead, factory.createStringLiteralFromNode(fieldName));
        }
        function prepareModifierFlagsForAccessor(modifierFlags) {
            modifierFlags &= ~64 /* Readonly */;
            modifierFlags &= ~8 /* Private */;
            if (!(modifierFlags & 16 /* Protected */)) {
                modifierFlags |= 4 /* Public */;
            }
            return modifierFlags;
        }
        function prepareModifierFlagsForField(modifierFlags) {
            modifierFlags &= ~4 /* Public */;
            modifierFlags &= ~16 /* Protected */;
            modifierFlags |= 8 /* Private */;
            return modifierFlags;
        }
        function getAccessorConvertiblePropertyAtPosition(file, program, start, end, considerEmptySpans = true) {
            const node = getTokenAtPosition(file, start);
            const cursorRequest = start === end && considerEmptySpans;
            const declaration = findAncestor(node.parent, isAcceptedDeclaration);
            const meaning = 28 /* AccessibilityModifier */ | 32 /* Static */ | 64 /* Readonly */;
            if (!declaration || !(nodeOverlapsWithStartEnd(declaration.name, file, start, end) || cursorRequest)) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Could_not_find_property_for_which_to_generate_accessor)
                };
            }
            if (!isConvertibleName(declaration.name)) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Name_is_not_valid)
                };
            }
            if ((getEffectiveModifierFlags(declaration) & 126975 /* Modifier */ | meaning) !== meaning) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Can_only_convert_property_with_modifier)
                };
            }
            const name = declaration.name.text;
            const startWithUnderscore = startsWithUnderscore(name);
            const fieldName = createPropertyName(startWithUnderscore ? name : getUniqueName(`_${name}`, file), declaration.name);
            const accessorName = createPropertyName(startWithUnderscore ? getUniqueName(name.substring(1), file) : name, declaration.name);
            return {
                isStatic: hasStaticModifier(declaration),
                isReadonly: hasEffectiveReadonlyModifier(declaration),
                type: getDeclarationType(declaration, program),
                container: declaration.kind === 166 /* Parameter */ ? declaration.parent.parent : declaration.parent,
                originalName: declaration.name.text,
                declaration,
                fieldName,
                accessorName,
                renameAccessor: startWithUnderscore
            };
        }
        function generateGetAccessor(fieldName, accessorName, type, modifiers, isStatic2, container) {
            return factory.createGetAccessorDeclaration(modifiers, accessorName, [], type, factory.createBlock([
                factory.createReturnStatement(createAccessorAccessExpression(fieldName, isStatic2, container))
            ], 
            /*multiLine*/
            true));
        }
        function generateSetAccessor(fieldName, accessorName, type, modifiers, isStatic2, container) {
            return factory.createSetAccessorDeclaration(modifiers, accessorName, [factory.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotDotDotToken*/
                void 0, factory.createIdentifier("value"), 
                /*questionToken*/
                void 0, type)], factory.createBlock([
                factory.createExpressionStatement(factory.createAssignment(createAccessorAccessExpression(fieldName, isStatic2, container), factory.createIdentifier("value")))
            ], 
            /*multiLine*/
            true));
        }
        function updatePropertyDeclaration(changeTracker, file, declaration, type, fieldName, modifiers) {
            const property = factory.updatePropertyDeclaration(declaration, modifiers, fieldName, declaration.questionToken || declaration.exclamationToken, type, declaration.initializer);
            changeTracker.replaceNode(file, declaration, property);
        }
        function updatePropertyAssignmentDeclaration(changeTracker, file, declaration, fieldName) {
            let assignment = factory.updatePropertyAssignment(declaration, fieldName, declaration.initializer);
            if (assignment.modifiers || assignment.questionToken || assignment.exclamationToken) {
                if (assignment === declaration)
                    assignment = factory.cloneNode(assignment);
                assignment.modifiers = void 0;
                assignment.questionToken = void 0;
                assignment.exclamationToken = void 0;
            }
            changeTracker.replacePropertyAssignment(file, declaration, assignment);
        }
        function updateFieldDeclaration(changeTracker, file, declaration, type, fieldName, modifiers) {
            if (isPropertyDeclaration(declaration)) {
                updatePropertyDeclaration(changeTracker, file, declaration, type, fieldName, modifiers);
            }
            else if (isPropertyAssignment(declaration)) {
                updatePropertyAssignmentDeclaration(changeTracker, file, declaration, fieldName);
            }
            else {
                changeTracker.replaceNode(file, declaration, factory.updateParameterDeclaration(declaration, modifiers, declaration.dotDotDotToken, cast(fieldName, isIdentifier), declaration.questionToken, declaration.type, declaration.initializer));
            }
        }
        function insertAccessor(changeTracker, file, accessor, declaration, container) {
            isParameterPropertyDeclaration(declaration, declaration.parent) ? changeTracker.insertMemberAtStart(file, container, accessor) : isPropertyAssignment(declaration) ? changeTracker.insertNodeAfterComma(file, declaration, accessor) : changeTracker.insertNodeAfter(file, declaration, accessor);
        }
        function updateReadonlyPropertyInitializerStatementConstructor(changeTracker, file, constructor, fieldName, originalName) {
            if (!constructor.body)
                return;
            constructor.body.forEachChild(function recur(node) {
                if (isElementAccessExpression(node) && node.expression.kind === 108 /* ThisKeyword */ && isStringLiteral(node.argumentExpression) && node.argumentExpression.text === originalName && isWriteAccess(node)) {
                    changeTracker.replaceNode(file, node.argumentExpression, factory.createStringLiteral(fieldName));
                }
                if (isPropertyAccessExpression(node) && node.expression.kind === 108 /* ThisKeyword */ && node.name.text === originalName && isWriteAccess(node)) {
                    changeTracker.replaceNode(file, node.name, factory.createIdentifier(fieldName));
                }
                if (!isFunctionLike(node) && !isClassLike(node)) {
                    node.forEachChild(recur);
                }
            });
        }
        function getDeclarationType(declaration, program) {
            const typeNode = getTypeAnnotationNode(declaration);
            if (isPropertyDeclaration(declaration) && typeNode && declaration.questionToken) {
                const typeChecker = program.getTypeChecker();
                const type = typeChecker.getTypeFromTypeNode(typeNode);
                if (!typeChecker.isTypeAssignableTo(typeChecker.getUndefinedType(), type)) {
                    const types = isUnionTypeNode(typeNode) ? typeNode.types : [typeNode];
                    return factory.createUnionTypeNode([...types, factory.createKeywordTypeNode(155 /* UndefinedKeyword */)]);
                }
            }
            return typeNode;
        }
        function getAllSupers(decl, checker) {
            const res = [];
            while (decl) {
                const superElement = getClassExtendsHeritageElement(decl);
                const superSymbol = superElement && checker.getSymbolAtLocation(superElement.expression);
                if (!superSymbol)
                    break;
                const symbol = superSymbol.flags & 2097152 /* Alias */ ? checker.getAliasedSymbol(superSymbol) : superSymbol;
                const superDecl = symbol.declarations && find(symbol.declarations, isClassLike);
                if (!superDecl)
                    break;
                res.push(superDecl);
                decl = superDecl;
            }
            return res;
        }
        var init_generateAccessors = __esm({
            "src/services/codefixes/generateAccessors.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/codefixes/fixInvalidImportSyntax.ts
        function getCodeFixesForImportDeclaration(context, node) {
            const sourceFile = getSourceFileOfNode(node);
            const namespace = getNamespaceDeclarationNode(node);
            const opts = context.program.getCompilerOptions();
            const variations = [];
            variations.push(createAction(context, sourceFile, node, makeImport(namespace.name, 
            /*namedImports*/
            void 0, node.moduleSpecifier, getQuotePreference(sourceFile, context.preferences))));
            if (getEmitModuleKind(opts) === 1 /* CommonJS */) {
                variations.push(createAction(context, sourceFile, node, factory.createImportEqualsDeclaration(
                /*modifiers*/
                void 0, 
                /*isTypeOnly*/
                false, namespace.name, factory.createExternalModuleReference(node.moduleSpecifier))));
            }
            return variations;
        }
        function createAction(context, sourceFile, node, replacement) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(sourceFile, node, replacement));
            return createCodeFixActionWithoutFixAll(fixName5, changes, [Diagnostics.Replace_import_with_0, changes[0].textChanges[0].newText]);
        }
        function getActionsForUsageOfInvalidImport(context) {
            const sourceFile = context.sourceFile;
            const targetKind = Diagnostics.This_expression_is_not_callable.code === context.errorCode ? 210 /* CallExpression */ : 211 /* NewExpression */;
            const node = findAncestor(getTokenAtPosition(sourceFile, context.span.start), (a) => a.kind === targetKind);
            if (!node) {
                return [];
            }
            const expr = node.expression;
            return getImportCodeFixesForExpression(context, expr);
        }
        function getActionsForInvalidImportLocation(context) {
            const sourceFile = context.sourceFile;
            const node = findAncestor(getTokenAtPosition(sourceFile, context.span.start), (a) => a.getStart() === context.span.start && a.getEnd() === context.span.start + context.span.length);
            if (!node) {
                return [];
            }
            return getImportCodeFixesForExpression(context, node);
        }
        function getImportCodeFixesForExpression(context, expr) {
            const type = context.program.getTypeChecker().getTypeAtLocation(expr);
            if (!(type.symbol && isTransientSymbol(type.symbol) && type.symbol.links.originatingImport)) {
                return [];
            }
            const fixes = [];
            const relatedImport = type.symbol.links.originatingImport;
            if (!isImportCall(relatedImport)) {
                addRange(fixes, getCodeFixesForImportDeclaration(context, relatedImport));
            }
            if (isExpression(expr) && !(isNamedDeclaration(expr.parent) && expr.parent.name === expr)) {
                const sourceFile = context.sourceFile;
                const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(sourceFile, expr, factory.createPropertyAccessExpression(expr, "default"), {}));
                fixes.push(createCodeFixActionWithoutFixAll(fixName5, changes, Diagnostics.Use_synthetic_default_member));
            }
            return fixes;
        }
        var fixName5;
        var init_fixInvalidImportSyntax = __esm({
            "src/services/codefixes/fixInvalidImportSyntax.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName5 = "invalidImportSyntax";
                registerCodeFix({
                    errorCodes: [
                        Diagnostics.This_expression_is_not_callable.code,
                        Diagnostics.This_expression_is_not_constructable.code
                    ],
                    getCodeActions: getActionsForUsageOfInvalidImport
                });
                registerCodeFix({
                    errorCodes: [
                        // The following error codes cover pretty much all assignability errors that could involve an expression
                        Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,
                        Diagnostics.Type_0_does_not_satisfy_the_constraint_1.code,
                        Diagnostics.Type_0_is_not_assignable_to_type_1.code,
                        Diagnostics.Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated.code,
                        Diagnostics.Type_predicate_0_is_not_assignable_to_1.code,
                        Diagnostics.Property_0_of_type_1_is_not_assignable_to_2_index_type_3.code,
                        Diagnostics._0_index_type_1_is_not_assignable_to_2_index_type_3.code,
                        Diagnostics.Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2.code,
                        Diagnostics.Property_0_in_type_1_is_not_assignable_to_type_2.code,
                        Diagnostics.Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property.code,
                        Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1.code
                    ],
                    getCodeActions: getActionsForInvalidImportLocation
                });
            }
        });
        // src/services/codefixes/fixStrictClassInitialization.ts
        function getInfo13(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (isIdentifier(token) && isPropertyDeclaration(token.parent)) {
                const type = getEffectiveTypeAnnotationNode(token.parent);
                if (type) {
                    return { type, prop: token.parent, isJs: isInJSFile(token.parent) };
                }
            }
            return void 0;
        }
        function getActionForAddMissingDefiniteAssignmentAssertion(context, info) {
            if (info.isJs)
                return void 0;
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addDefiniteAssignmentAssertion(t, context.sourceFile, info.prop));
            return createCodeFixAction(fixName6, changes, [Diagnostics.Add_definite_assignment_assertion_to_property_0, info.prop.getText()], fixIdAddDefiniteAssignmentAssertions, Diagnostics.Add_definite_assignment_assertions_to_all_uninitialized_properties);
        }
        function addDefiniteAssignmentAssertion(changeTracker, propertyDeclarationSourceFile, propertyDeclaration) {
            suppressLeadingAndTrailingTrivia(propertyDeclaration);
            const property = factory.updatePropertyDeclaration(propertyDeclaration, propertyDeclaration.modifiers, propertyDeclaration.name, factory.createToken(53 /* ExclamationToken */), propertyDeclaration.type, propertyDeclaration.initializer);
            changeTracker.replaceNode(propertyDeclarationSourceFile, propertyDeclaration, property);
        }
        function getActionForAddMissingUndefinedType(context, info) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addUndefinedType(t, context.sourceFile, info));
            return createCodeFixAction(fixName6, changes, [Diagnostics.Add_undefined_type_to_property_0, info.prop.name.getText()], fixIdAddUndefinedType, Diagnostics.Add_undefined_type_to_all_uninitialized_properties);
        }
        function addUndefinedType(changeTracker, sourceFile, info) {
            const undefinedTypeNode = factory.createKeywordTypeNode(155 /* UndefinedKeyword */);
            const types = isUnionTypeNode(info.type) ? info.type.types.concat(undefinedTypeNode) : [info.type, undefinedTypeNode];
            const unionTypeNode = factory.createUnionTypeNode(types);
            if (info.isJs) {
                changeTracker.addJSDocTags(sourceFile, info.prop, [factory.createJSDocTypeTag(
                    /*tagName*/
                    void 0, factory.createJSDocTypeExpression(unionTypeNode))]);
            }
            else {
                changeTracker.replaceNode(sourceFile, info.type, unionTypeNode);
            }
        }
        function getActionForAddMissingInitializer(context, info) {
            if (info.isJs)
                return void 0;
            const checker = context.program.getTypeChecker();
            const initializer = getInitializer(checker, info.prop);
            if (!initializer)
                return void 0;
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addInitializer(t, context.sourceFile, info.prop, initializer));
            return createCodeFixAction(fixName6, changes, [Diagnostics.Add_initializer_to_property_0, info.prop.name.getText()], fixIdAddInitializer, Diagnostics.Add_initializers_to_all_uninitialized_properties);
        }
        function addInitializer(changeTracker, propertyDeclarationSourceFile, propertyDeclaration, initializer) {
            suppressLeadingAndTrailingTrivia(propertyDeclaration);
            const property = factory.updatePropertyDeclaration(propertyDeclaration, propertyDeclaration.modifiers, propertyDeclaration.name, propertyDeclaration.questionToken, propertyDeclaration.type, initializer);
            changeTracker.replaceNode(propertyDeclarationSourceFile, propertyDeclaration, property);
        }
        function getInitializer(checker, propertyDeclaration) {
            return getDefaultValueFromType(checker, checker.getTypeFromTypeNode(propertyDeclaration.type));
        }
        function getDefaultValueFromType(checker, type) {
            if (type.flags & 512 /* BooleanLiteral */) {
                return type === checker.getFalseType() || type === checker.getFalseType(
                /*fresh*/
                true) ? factory.createFalse() : factory.createTrue();
            }
            else if (type.isStringLiteral()) {
                return factory.createStringLiteral(type.value);
            }
            else if (type.isNumberLiteral()) {
                return factory.createNumericLiteral(type.value);
            }
            else if (type.flags & 2048 /* BigIntLiteral */) {
                return factory.createBigIntLiteral(type.value);
            }
            else if (type.isUnion()) {
                return firstDefined(type.types, (t) => getDefaultValueFromType(checker, t));
            }
            else if (type.isClass()) {
                const classDeclaration = getClassLikeDeclarationOfSymbol(type.symbol);
                if (!classDeclaration || hasSyntacticModifier(classDeclaration, 256 /* Abstract */))
                    return void 0;
                const constructorDeclaration = getFirstConstructorWithBody(classDeclaration);
                if (constructorDeclaration && constructorDeclaration.parameters.length)
                    return void 0;
                return factory.createNewExpression(factory.createIdentifier(type.symbol.name), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                void 0);
            }
            else if (checker.isArrayLikeType(type)) {
                return factory.createArrayLiteralExpression();
            }
            return void 0;
        }
        var fixName6, fixIdAddDefiniteAssignmentAssertions, fixIdAddUndefinedType, fixIdAddInitializer, errorCodes50;
        var init_fixStrictClassInitialization = __esm({
            "src/services/codefixes/fixStrictClassInitialization.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName6 = "strictClassInitialization";
                fixIdAddDefiniteAssignmentAssertions = "addMissingPropertyDefiniteAssignmentAssertions";
                fixIdAddUndefinedType = "addMissingPropertyUndefinedType";
                fixIdAddInitializer = "addMissingPropertyInitializer";
                errorCodes50 = [Diagnostics.Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor.code];
                registerCodeFix({
                    errorCodes: errorCodes50,
                    getCodeActions: function getCodeActionsForStrictClassInitializationErrors(context) {
                        const info = getInfo13(context.sourceFile, context.span.start);
                        if (!info)
                            return;
                        const result = [];
                        append(result, getActionForAddMissingUndefinedType(context, info));
                        append(result, getActionForAddMissingDefiniteAssignmentAssertion(context, info));
                        append(result, getActionForAddMissingInitializer(context, info));
                        return result;
                    },
                    fixIds: [fixIdAddDefiniteAssignmentAssertions, fixIdAddUndefinedType, fixIdAddInitializer],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes50, (changes, diag2) => {
                            const info = getInfo13(diag2.file, diag2.start);
                            if (!info)
                                return;
                            switch (context.fixId) {
                                case fixIdAddDefiniteAssignmentAssertions:
                                    addDefiniteAssignmentAssertion(changes, diag2.file, info.prop);
                                    break;
                                case fixIdAddUndefinedType:
                                    addUndefinedType(changes, diag2.file, info);
                                    break;
                                case fixIdAddInitializer:
                                    const checker = context.program.getTypeChecker();
                                    const initializer = getInitializer(checker, info.prop);
                                    if (!initializer)
                                        return;
                                    addInitializer(changes, diag2.file, info.prop, initializer);
                                    break;
                                default:
                                    Debug.fail(JSON.stringify(context.fixId));
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/requireInTs.ts
        function doChange26(changes, sourceFile, info) {
            const { allowSyntheticDefaults, defaultImportName, namedImports, statement, required } = info;
            changes.replaceNode(sourceFile, statement, defaultImportName && !allowSyntheticDefaults ? factory.createImportEqualsDeclaration(
            /*modifiers*/
            void 0, 
            /*isTypeOnly*/
            false, defaultImportName, factory.createExternalModuleReference(required)) : factory.createImportDeclaration(
            /*modifiers*/
            void 0, factory.createImportClause(
            /*isTypeOnly*/
            false, defaultImportName, namedImports), required, 
            /*assertClause*/
            void 0));
        }
        function getInfo14(sourceFile, program, pos) {
            const { parent: parent2 } = getTokenAtPosition(sourceFile, pos);
            if (!isRequireCall(parent2, 
            /*checkArgumentIsStringLiteralLike*/
            true)) {
                throw Debug.failBadSyntaxKind(parent2);
            }
            const decl = cast(parent2.parent, isVariableDeclaration);
            const defaultImportName = tryCast(decl.name, isIdentifier);
            const namedImports = isObjectBindingPattern(decl.name) ? tryCreateNamedImportsFromObjectBindingPattern(decl.name) : void 0;
            if (defaultImportName || namedImports) {
                return {
                    allowSyntheticDefaults: getAllowSyntheticDefaultImports(program.getCompilerOptions()),
                    defaultImportName,
                    namedImports,
                    statement: cast(decl.parent.parent, isVariableStatement),
                    required: first(parent2.arguments)
                };
            }
        }
        function tryCreateNamedImportsFromObjectBindingPattern(node) {
            const importSpecifiers = [];
            for (const element of node.elements) {
                if (!isIdentifier(element.name) || element.initializer) {
                    return void 0;
                }
                importSpecifiers.push(factory.createImportSpecifier(
                /*isTypeOnly*/
                false, tryCast(element.propertyName, isIdentifier), element.name));
            }
            if (importSpecifiers.length) {
                return factory.createNamedImports(importSpecifiers);
            }
        }
        var fixId40, errorCodes51;
        var init_requireInTs = __esm({
            "src/services/codefixes/requireInTs.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId40 = "requireInTs";
                errorCodes51 = [Diagnostics.require_call_may_be_converted_to_an_import.code];
                registerCodeFix({
                    errorCodes: errorCodes51,
                    getCodeActions(context) {
                        const info = getInfo14(context.sourceFile, context.program, context.span.start);
                        if (!info) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange26(t, context.sourceFile, info));
                        return [createCodeFixAction(fixId40, changes, Diagnostics.Convert_require_to_import, fixId40, Diagnostics.Convert_all_require_to_import)];
                    },
                    fixIds: [fixId40],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes51, (changes, diag2) => {
                        const info = getInfo14(diag2.file, context.program, diag2.start);
                        if (info) {
                            doChange26(changes, context.sourceFile, info);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/useDefaultImport.ts
        function getInfo15(sourceFile, pos) {
            const name = getTokenAtPosition(sourceFile, pos);
            if (!isIdentifier(name))
                return void 0;
            const { parent: parent2 } = name;
            if (isImportEqualsDeclaration(parent2) && isExternalModuleReference(parent2.moduleReference)) {
                return { importNode: parent2, name, moduleSpecifier: parent2.moduleReference.expression };
            }
            else if (isNamespaceImport(parent2)) {
                const importNode = parent2.parent.parent;
                return { importNode, name, moduleSpecifier: importNode.moduleSpecifier };
            }
        }
        function doChange27(changes, sourceFile, info, preferences) {
            changes.replaceNode(sourceFile, info.importNode, makeImport(info.name, 
            /*namedImports*/
            void 0, info.moduleSpecifier, getQuotePreference(sourceFile, preferences)));
        }
        var fixId41, errorCodes52;
        var init_useDefaultImport = __esm({
            "src/services/codefixes/useDefaultImport.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId41 = "useDefaultImport";
                errorCodes52 = [Diagnostics.Import_may_be_converted_to_a_default_import.code];
                registerCodeFix({
                    errorCodes: errorCodes52,
                    getCodeActions(context) {
                        const { sourceFile, span: { start } } = context;
                        const info = getInfo15(sourceFile, start);
                        if (!info)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange27(t, sourceFile, info, context.preferences));
                        return [createCodeFixAction(fixId41, changes, Diagnostics.Convert_to_default_import, fixId41, Diagnostics.Convert_all_to_default_imports)];
                    },
                    fixIds: [fixId41],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes52, (changes, diag2) => {
                        const info = getInfo15(diag2.file, diag2.start);
                        if (info)
                            doChange27(changes, diag2.file, info, context.preferences);
                    })
                });
            }
        });
        // src/services/codefixes/useBigintLiteral.ts
        function makeChange9(changeTracker, sourceFile, span) {
            const numericLiteral = tryCast(getTokenAtPosition(sourceFile, span.start), isNumericLiteral);
            if (!numericLiteral) {
                return;
            }
            const newText = numericLiteral.getText(sourceFile) + "n";
            changeTracker.replaceNode(sourceFile, numericLiteral, factory.createBigIntLiteral(newText));
        }
        var fixId42, errorCodes53;
        var init_useBigintLiteral = __esm({
            "src/services/codefixes/useBigintLiteral.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId42 = "useBigintLiteral";
                errorCodes53 = [
                    Diagnostics.Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes53,
                    getCodeActions: function getCodeActionsToUseBigintLiteral(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange9(t, context.sourceFile, context.span));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixId42, changes, Diagnostics.Convert_to_a_bigint_numeric_literal, fixId42, Diagnostics.Convert_all_to_bigint_numeric_literals)];
                        }
                    },
                    fixIds: [fixId42],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes53, (changes, diag2) => makeChange9(changes, diag2.file, diag2));
                    }
                });
            }
        });
        // src/services/codefixes/fixAddModuleReferTypeMissingTypeof.ts
        function getImportTypeNode(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            Debug.assert(token.kind === 100 /* ImportKeyword */, "This token should be an ImportKeyword");
            Debug.assert(token.parent.kind === 202 /* ImportType */, "Token parent should be an ImportType");
            return token.parent;
        }
        function doChange28(changes, sourceFile, importType) {
            const newTypeNode = factory.updateImportTypeNode(importType, importType.argument, importType.assertions, importType.qualifier, importType.typeArguments, 
            /* isTypeOf */
            true);
            changes.replaceNode(sourceFile, importType, newTypeNode);
        }
        var fixIdAddMissingTypeof, fixId43, errorCodes54;
        var init_fixAddModuleReferTypeMissingTypeof = __esm({
            "src/services/codefixes/fixAddModuleReferTypeMissingTypeof.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixIdAddMissingTypeof = "fixAddModuleReferTypeMissingTypeof";
                fixId43 = fixIdAddMissingTypeof;
                errorCodes54 = [Diagnostics.Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0.code];
                registerCodeFix({
                    errorCodes: errorCodes54,
                    getCodeActions: function getCodeActionsToAddMissingTypeof(context) {
                        const { sourceFile, span } = context;
                        const importType = getImportTypeNode(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange28(t, sourceFile, importType));
                        return [createCodeFixAction(fixId43, changes, Diagnostics.Add_missing_typeof, fixId43, Diagnostics.Add_missing_typeof)];
                    },
                    fixIds: [fixId43],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes54, (changes, diag2) => doChange28(changes, context.sourceFile, getImportTypeNode(diag2.file, diag2.start)))
                });
            }
        });
        // src/services/codefixes/wrapJsxInFragment.ts
        function findNodeToFix(sourceFile, pos) {
            const lessThanToken = getTokenAtPosition(sourceFile, pos);
            const firstJsxElementOrOpenElement = lessThanToken.parent;
            let binaryExpr = firstJsxElementOrOpenElement.parent;
            if (!isBinaryExpression(binaryExpr)) {
                binaryExpr = binaryExpr.parent;
                if (!isBinaryExpression(binaryExpr))
                    return void 0;
            }
            if (!nodeIsMissing(binaryExpr.operatorToken))
                return void 0;
            return binaryExpr;
        }
        function doChange29(changeTracker, sf, node) {
            const jsx = flattenInvalidBinaryExpr(node);
            if (jsx)
                changeTracker.replaceNode(sf, node, factory.createJsxFragment(factory.createJsxOpeningFragment(), jsx, factory.createJsxJsxClosingFragment()));
        }
        function flattenInvalidBinaryExpr(node) {
            const children = [];
            let current = node;
            while (true) {
                if (isBinaryExpression(current) && nodeIsMissing(current.operatorToken) && current.operatorToken.kind === 27 /* CommaToken */) {
                    children.push(current.left);
                    if (isJsxChild(current.right)) {
                        children.push(current.right);
                        return children;
                    }
                    else if (isBinaryExpression(current.right)) {
                        current = current.right;
                        continue;
                    }
                    else
                        return void 0;
                }
                else
                    return void 0;
            }
        }
        var fixID2, errorCodes55;
        var init_wrapJsxInFragment = __esm({
            "src/services/codefixes/wrapJsxInFragment.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixID2 = "wrapJsxInFragment";
                errorCodes55 = [Diagnostics.JSX_expressions_must_have_one_parent_element.code];
                registerCodeFix({
                    errorCodes: errorCodes55,
                    getCodeActions: function getCodeActionsToWrapJsxInFragment(context) {
                        const { sourceFile, span } = context;
                        const node = findNodeToFix(sourceFile, span.start);
                        if (!node)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange29(t, sourceFile, node));
                        return [createCodeFixAction(fixID2, changes, Diagnostics.Wrap_in_JSX_fragment, fixID2, Diagnostics.Wrap_all_unparented_JSX_in_JSX_fragment)];
                    },
                    fixIds: [fixID2],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes55, (changes, diag2) => {
                        const node = findNodeToFix(context.sourceFile, diag2.start);
                        if (!node)
                            return void 0;
                        doChange29(changes, context.sourceFile, node);
                    })
                });
            }
        });
        // src/services/codefixes/convertToMappedObjectType.ts
        function getInfo16(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const indexSignature = tryCast(token.parent.parent, isIndexSignatureDeclaration);
            if (!indexSignature)
                return void 0;
            const container = isInterfaceDeclaration(indexSignature.parent) ? indexSignature.parent : tryCast(indexSignature.parent.parent, isTypeAliasDeclaration);
            if (!container)
                return void 0;
            return { indexSignature, container };
        }
        function createTypeAliasFromInterface(declaration, type) {
            return factory.createTypeAliasDeclaration(declaration.modifiers, declaration.name, declaration.typeParameters, type);
        }
        function doChange30(changes, sourceFile, { indexSignature, container }) {
            const members = isInterfaceDeclaration(container) ? container.members : container.type.members;
            const otherMembers = members.filter((member) => !isIndexSignatureDeclaration(member));
            const parameter = first(indexSignature.parameters);
            const mappedTypeParameter = factory.createTypeParameterDeclaration(
            /*modifiers*/
            void 0, cast(parameter.name, isIdentifier), parameter.type);
            const mappedIntersectionType = factory.createMappedTypeNode(hasEffectiveReadonlyModifier(indexSignature) ? factory.createModifier(146 /* ReadonlyKeyword */) : void 0, mappedTypeParameter, 
            /*nameType*/
            void 0, indexSignature.questionToken, indexSignature.type, 
            /*members*/
            void 0);
            const intersectionType = factory.createIntersectionTypeNode([
                ...getAllSuperTypeNodes(container),
                mappedIntersectionType,
                ...otherMembers.length ? [factory.createTypeLiteralNode(otherMembers)] : emptyArray
            ]);
            changes.replaceNode(sourceFile, container, createTypeAliasFromInterface(container, intersectionType));
        }
        var fixId44, errorCodes56;
        var init_convertToMappedObjectType = __esm({
            "src/services/codefixes/convertToMappedObjectType.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId44 = "fixConvertToMappedObjectType";
                errorCodes56 = [Diagnostics.An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_object_type_instead.code];
                registerCodeFix({
                    errorCodes: errorCodes56,
                    getCodeActions: function getCodeActionsToConvertToMappedTypeObject(context) {
                        const { sourceFile, span } = context;
                        const info = getInfo16(sourceFile, span.start);
                        if (!info)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange30(t, sourceFile, info));
                        const name = idText(info.container.name);
                        return [createCodeFixAction(fixId44, changes, [Diagnostics.Convert_0_to_mapped_object_type, name], fixId44, [Diagnostics.Convert_0_to_mapped_object_type, name])];
                    },
                    fixIds: [fixId44],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes56, (changes, diag2) => {
                        const info = getInfo16(diag2.file, diag2.start);
                        if (info)
                            doChange30(changes, diag2.file, info);
                    })
                });
            }
        });
        // src/services/codefixes/removeAccidentalCallParentheses.ts
        var fixId45, errorCodes57;
        var init_removeAccidentalCallParentheses = __esm({
            "src/services/codefixes/removeAccidentalCallParentheses.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId45 = "removeAccidentalCallParentheses";
                errorCodes57 = [
                    Diagnostics.This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes57,
                    getCodeActions(context) {
                        const callExpression = findAncestor(getTokenAtPosition(context.sourceFile, context.span.start), isCallExpression);
                        if (!callExpression) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                            t.deleteRange(context.sourceFile, { pos: callExpression.expression.end, end: callExpression.end });
                        });
                        return [createCodeFixActionWithoutFixAll(fixId45, changes, Diagnostics.Remove_parentheses)];
                    },
                    fixIds: [fixId45]
                });
            }
        });
        // src/services/codefixes/removeUnnecessaryAwait.ts
        function makeChange10(changeTracker, sourceFile, span) {
            const awaitKeyword = tryCast(getTokenAtPosition(sourceFile, span.start), (node) => node.kind === 133 /* AwaitKeyword */);
            const awaitExpression = awaitKeyword && tryCast(awaitKeyword.parent, isAwaitExpression);
            if (!awaitExpression) {
                return;
            }
            let expressionToReplace = awaitExpression;
            const hasSurroundingParens = isParenthesizedExpression(awaitExpression.parent);
            if (hasSurroundingParens) {
                const leftMostExpression = getLeftmostExpression(awaitExpression.expression, 
                /*stopAtCallExpressions*/
                false);
                if (isIdentifier(leftMostExpression)) {
                    const precedingToken = findPrecedingToken(awaitExpression.parent.pos, sourceFile);
                    if (precedingToken && precedingToken.kind !== 103 /* NewKeyword */) {
                        expressionToReplace = awaitExpression.parent;
                    }
                }
            }
            changeTracker.replaceNode(sourceFile, expressionToReplace, awaitExpression.expression);
        }
        var fixId46, errorCodes58;
        var init_removeUnnecessaryAwait = __esm({
            "src/services/codefixes/removeUnnecessaryAwait.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId46 = "removeUnnecessaryAwait";
                errorCodes58 = [
                    Diagnostics.await_has_no_effect_on_the_type_of_this_expression.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes58,
                    getCodeActions: function getCodeActionsToRemoveUnnecessaryAwait(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange10(t, context.sourceFile, context.span));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixId46, changes, Diagnostics.Remove_unnecessary_await, fixId46, Diagnostics.Remove_all_unnecessary_uses_of_await)];
                        }
                    },
                    fixIds: [fixId46],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes58, (changes, diag2) => makeChange10(changes, diag2.file, diag2));
                    }
                });
            }
        });
        // src/services/codefixes/splitTypeOnlyImport.ts
        function getImportDeclaration2(sourceFile, span) {
            return findAncestor(getTokenAtPosition(sourceFile, span.start), isImportDeclaration);
        }
        function splitTypeOnlyImport(changes, importDeclaration, context) {
            if (!importDeclaration) {
                return;
            }
            const importClause = Debug.checkDefined(importDeclaration.importClause);
            changes.replaceNode(context.sourceFile, importDeclaration, factory.updateImportDeclaration(importDeclaration, importDeclaration.modifiers, factory.updateImportClause(importClause, importClause.isTypeOnly, importClause.name, 
            /*namedBindings*/
            void 0), importDeclaration.moduleSpecifier, importDeclaration.assertClause));
            changes.insertNodeAfter(context.sourceFile, importDeclaration, factory.createImportDeclaration(
            /*modifiers*/
            void 0, factory.updateImportClause(importClause, importClause.isTypeOnly, 
            /*name*/
            void 0, importClause.namedBindings), importDeclaration.moduleSpecifier, importDeclaration.assertClause));
        }
        var errorCodes59, fixId47;
        var init_splitTypeOnlyImport = __esm({
            "src/services/codefixes/splitTypeOnlyImport.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes59 = [Diagnostics.A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both.code];
                fixId47 = "splitTypeOnlyImport";
                registerCodeFix({
                    errorCodes: errorCodes59,
                    fixIds: [fixId47],
                    getCodeActions: function getCodeActionsToSplitTypeOnlyImport(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                            return splitTypeOnlyImport(t, getImportDeclaration2(context.sourceFile, context.span), context);
                        });
                        if (changes.length) {
                            return [createCodeFixAction(fixId47, changes, Diagnostics.Split_into_two_separate_import_declarations, fixId47, Diagnostics.Split_all_invalid_type_only_imports)];
                        }
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes59, (changes, error) => {
                        splitTypeOnlyImport(changes, getImportDeclaration2(context.sourceFile, error), context);
                    })
                });
            }
        });
        // src/services/codefixes/convertConstToLet.ts
        function getInfo17(sourceFile, pos, program) {
            var _a2;
            const checker = program.getTypeChecker();
            const symbol = checker.getSymbolAtLocation(getTokenAtPosition(sourceFile, pos));
            if (symbol === void 0)
                return;
            const declaration = tryCast((_a2 = symbol == null ? void 0 : symbol.valueDeclaration) == null ? void 0 : _a2.parent, isVariableDeclarationList);
            if (declaration === void 0)
                return;
            const constToken = findChildOfKind(declaration, 85 /* ConstKeyword */, sourceFile);
            if (constToken === void 0)
                return;
            return { symbol, token: constToken };
        }
        function doChange31(changes, sourceFile, token) {
            changes.replaceNode(sourceFile, token, factory.createToken(119 /* LetKeyword */));
        }
        var fixId48, errorCodes60;
        var init_convertConstToLet = __esm({
            "src/services/codefixes/convertConstToLet.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId48 = "fixConvertConstToLet";
                errorCodes60 = [Diagnostics.Cannot_assign_to_0_because_it_is_a_constant.code];
                registerCodeFix({
                    errorCodes: errorCodes60,
                    getCodeActions: function getCodeActionsToConvertConstToLet(context) {
                        const { sourceFile, span, program } = context;
                        const info = getInfo17(sourceFile, span.start, program);
                        if (info === void 0)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange31(t, sourceFile, info.token));
                        return [createCodeFixActionMaybeFixAll(fixId48, changes, Diagnostics.Convert_const_to_let, fixId48, Diagnostics.Convert_all_const_to_let)];
                    },
                    getAllCodeActions: (context) => {
                        const { program } = context;
                        const seen = /* @__PURE__ */ new Map();
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            eachDiagnostic(context, errorCodes60, (diag2) => {
                                const info = getInfo17(diag2.file, diag2.start, program);
                                if (info) {
                                    if (addToSeen(seen, getSymbolId(info.symbol))) {
                                        return doChange31(changes, diag2.file, info.token);
                                    }
                                }
                                return void 0;
                            });
                        }));
                    },
                    fixIds: [fixId48]
                });
            }
        });
        // src/services/codefixes/fixExpectedComma.ts
        function getInfo18(sourceFile, pos, _) {
            const node = getTokenAtPosition(sourceFile, pos);
            return node.kind === 26 /* SemicolonToken */ && node.parent && (isObjectLiteralExpression(node.parent) || isArrayLiteralExpression(node.parent)) ? { node } : void 0;
        }
        function doChange32(changes, sourceFile, { node }) {
            const newNode = factory.createToken(27 /* CommaToken */);
            changes.replaceNode(sourceFile, node, newNode);
        }
        var fixId49, expectedErrorCode, errorCodes61;
        var init_fixExpectedComma = __esm({
            "src/services/codefixes/fixExpectedComma.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId49 = "fixExpectedComma";
                expectedErrorCode = Diagnostics._0_expected.code;
                errorCodes61 = [expectedErrorCode];
                registerCodeFix({
                    errorCodes: errorCodes61,
                    getCodeActions(context) {
                        const { sourceFile } = context;
                        const info = getInfo18(sourceFile, context.span.start, context.errorCode);
                        if (!info)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange32(t, sourceFile, info));
                        return [createCodeFixAction(fixId49, changes, [Diagnostics.Change_0_to_1, ";", ","], fixId49, [Diagnostics.Change_0_to_1, ";", ","])];
                    },
                    fixIds: [fixId49],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes61, (changes, diag2) => {
                        const info = getInfo18(diag2.file, diag2.start, diag2.code);
                        if (info)
                            doChange32(changes, context.sourceFile, info);
                    })
                });
            }
        });
        // src/services/codefixes/fixAddVoidToPromise.ts
        function makeChange11(changes, sourceFile, span, program, seen) {
            const node = getTokenAtPosition(sourceFile, span.start);
            if (!isIdentifier(node) || !isCallExpression(node.parent) || node.parent.expression !== node || node.parent.arguments.length !== 0)
                return;
            const checker = program.getTypeChecker();
            const symbol = checker.getSymbolAtLocation(node);
            const decl = symbol == null ? void 0 : symbol.valueDeclaration;
            if (!decl || !isParameter(decl) || !isNewExpression(decl.parent.parent))
                return;
            if (seen == null ? void 0 : seen.has(decl))
                return;
            seen == null ? void 0 : seen.add(decl);
            const typeArguments = getEffectiveTypeArguments(decl.parent.parent);
            if (some(typeArguments)) {
                const typeArgument = typeArguments[0];
                const needsParens = !isUnionTypeNode(typeArgument) && !isParenthesizedTypeNode(typeArgument) && isParenthesizedTypeNode(factory.createUnionTypeNode([typeArgument, factory.createKeywordTypeNode(114 /* VoidKeyword */)]).types[0]);
                if (needsParens) {
                    changes.insertText(sourceFile, typeArgument.pos, "(");
                }
                changes.insertText(sourceFile, typeArgument.end, needsParens ? ") | void" : " | void");
            }
            else {
                const signature = checker.getResolvedSignature(node.parent);
                const parameter = signature == null ? void 0 : signature.parameters[0];
                const parameterType = parameter && checker.getTypeOfSymbolAtLocation(parameter, decl.parent.parent);
                if (isInJSFile(decl)) {
                    if (!parameterType || parameterType.flags & 3 /* AnyOrUnknown */) {
                        changes.insertText(sourceFile, decl.parent.parent.end, `)`);
                        changes.insertText(sourceFile, skipTrivia(sourceFile.text, decl.parent.parent.pos), `/** @type {Promise<void>} */(`);
                    }
                }
                else {
                    if (!parameterType || parameterType.flags & 2 /* Unknown */) {
                        changes.insertText(sourceFile, decl.parent.parent.expression.end, "<void>");
                    }
                }
            }
        }
        function getEffectiveTypeArguments(node) {
            var _a2;
            if (isInJSFile(node)) {
                if (isParenthesizedExpression(node.parent)) {
                    const jsDocType = (_a2 = getJSDocTypeTag(node.parent)) == null ? void 0 : _a2.typeExpression.type;
                    if (jsDocType && isTypeReferenceNode(jsDocType) && isIdentifier(jsDocType.typeName) && idText(jsDocType.typeName) === "Promise") {
                        return jsDocType.typeArguments;
                    }
                }
            }
            else {
                return node.typeArguments;
            }
        }
        var fixName7, fixId50, errorCodes62;
        var init_fixAddVoidToPromise = __esm({
            "src/services/codefixes/fixAddVoidToPromise.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName7 = "addVoidToPromise";
                fixId50 = "addVoidToPromise";
                errorCodes62 = [
                    Diagnostics.Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_without_arguments.code,
                    Diagnostics.Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes62,
                    fixIds: [fixId50],
                    getCodeActions(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange11(t, context.sourceFile, context.span, context.program));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixName7, changes, Diagnostics.Add_void_to_Promise_resolved_without_a_value, fixId50, Diagnostics.Add_void_to_all_Promises_resolved_without_a_value)];
                        }
                    },
                    getAllCodeActions(context) {
                        return codeFixAll(context, errorCodes62, (changes, diag2) => makeChange11(changes, diag2.file, diag2, context.program, /* @__PURE__ */ new Set()));
                    }
                });
            }
        });
        // src/services/_namespaces/ts.codefix.ts
        var ts_codefix_exports = {};
        __export(ts_codefix_exports, {
            PreserveOptionalFlags: () => PreserveOptionalFlags,
            addNewNodeForMemberSymbol: () => addNewNodeForMemberSymbol,
            codeFixAll: () => codeFixAll,
            createCodeFixAction: () => createCodeFixAction,
            createCodeFixActionMaybeFixAll: () => createCodeFixActionMaybeFixAll,
            createCodeFixActionWithoutFixAll: () => createCodeFixActionWithoutFixAll,
            createCombinedCodeActions: () => createCombinedCodeActions,
            createFileTextChanges: () => createFileTextChanges,
            createImportAdder: () => createImportAdder,
            createImportSpecifierResolver: () => createImportSpecifierResolver,
            createJsonPropertyAssignment: () => createJsonPropertyAssignment,
            createMissingMemberNodes: () => createMissingMemberNodes,
            createSignatureDeclarationFromCallExpression: () => createSignatureDeclarationFromCallExpression,
            createSignatureDeclarationFromSignature: () => createSignatureDeclarationFromSignature,
            createStubbedBody: () => createStubbedBody,
            eachDiagnostic: () => eachDiagnostic,
            findAncestorMatchingSpan: () => findAncestorMatchingSpan,
            findJsonProperty: () => findJsonProperty,
            generateAccessorFromProperty: () => generateAccessorFromProperty,
            getAccessorConvertiblePropertyAtPosition: () => getAccessorConvertiblePropertyAtPosition,
            getAllFixes: () => getAllFixes,
            getAllSupers: () => getAllSupers,
            getArgumentTypesAndTypeParameters: () => getArgumentTypesAndTypeParameters,
            getFixes: () => getFixes,
            getImportCompletionAction: () => getImportCompletionAction,
            getImportKind: () => getImportKind,
            getNoopSymbolTrackerWithResolver: () => getNoopSymbolTrackerWithResolver,
            getPromoteTypeOnlyCompletionAction: () => getPromoteTypeOnlyCompletionAction,
            getSupportedErrorCodes: () => getSupportedErrorCodes,
            importFixName: () => importFixName,
            importSymbols: () => importSymbols,
            moduleSpecifierToValidIdentifier: () => moduleSpecifierToValidIdentifier,
            moduleSymbolToValidIdentifier: () => moduleSymbolToValidIdentifier,
            parameterShouldGetTypeFromJSDoc: () => parameterShouldGetTypeFromJSDoc,
            registerCodeFix: () => registerCodeFix,
            setJsonCompilerOptionValue: () => setJsonCompilerOptionValue,
            setJsonCompilerOptionValues: () => setJsonCompilerOptionValues,
            tryGetAutoImportableReferenceFromTypeNode: () => tryGetAutoImportableReferenceFromTypeNode,
            typeToAutoImportableTypeNode: () => typeToAutoImportableTypeNode
        });
        var init_ts_codefix = __esm({
            "src/services/_namespaces/ts.codefix.ts"() {
                "use strict";
                init_codeFixProvider();
                init_addConvertToUnknownForNonOverlappingTypes();
                init_addEmptyExportDeclaration();
                init_addMissingAsync();
                init_addMissingAwait();
                init_addMissingConst();
                init_addMissingDeclareProperty();
                init_addMissingInvocationForDecorator();
                init_addNameToNamelessParameter();
                init_addOptionalPropertyUndefined();
                init_annotateWithTypeFromJSDoc();
                init_convertFunctionToEs6Class();
                init_convertToAsyncFunction();
                init_convertToEsModule();
                init_correctQualifiedNameToIndexedAccessType();
                init_convertToTypeOnlyExport();
                init_convertToTypeOnlyImport();
                init_convertLiteralTypeToMappedType();
                init_fixClassIncorrectlyImplementsInterface();
                init_importFixes();
                init_fixAddMissingConstraint();
                init_fixOverrideModifier();
                init_fixNoPropertyAccessFromIndexSignature();
                init_fixImplicitThis();
                init_fixImportNonExportedMember();
                init_fixIncorrectNamedTupleSyntax();
                init_fixSpelling();
                init_returnValueCorrect();
                init_fixAddMissingMember();
                init_fixAddMissingNewOperator();
                init_fixCannotFindModule();
                init_fixClassDoesntImplementInheritedAbstractMember();
                init_fixClassSuperMustPrecedeThisAccess();
                init_fixConstructorForDerivedNeedSuperCall();
                init_fixEnableJsxFlag();
                init_fixNaNEquality();
                init_fixModuleAndTargetOptions();
                init_fixPropertyAssignment();
                init_fixExtendsInterfaceBecomesImplements();
                init_fixForgottenThisPropertyAccess();
                init_fixInvalidJsxCharacters();
                init_fixUnmatchedParameter();
                init_fixUnreferenceableDecoratorMetadata();
                init_fixUnusedIdentifier();
                init_fixUnreachableCode();
                init_fixUnusedLabel();
                init_fixJSDocTypes();
                init_fixMissingCallParentheses();
                init_fixAwaitInSyncFunction();
                init_fixPropertyOverrideAccessor();
                init_inferFromUsage();
                init_fixReturnTypeInAsyncFunction();
                init_disableJsDiagnostics();
                init_helpers();
                init_generateAccessors();
                init_fixInvalidImportSyntax();
                init_fixStrictClassInitialization();
                init_requireInTs();
                init_useDefaultImport();
                init_useBigintLiteral();
                init_fixAddModuleReferTypeMissingTypeof();
                init_wrapJsxInFragment();
                init_convertToMappedObjectType();
                init_removeAccidentalCallParentheses();
                init_removeUnnecessaryAwait();
                init_splitTypeOnlyImport();
                init_convertConstToLet();
                init_fixExpectedComma();
                init_fixAddVoidToPromise();
            }
        });
        // src/services/completions.ts
        function originIsThisType(origin) {
            return !!(origin.kind & 1 /* ThisType */);
        }
        function originIsSymbolMember(origin) {
            return !!(origin.kind & 2 /* SymbolMember */);
        }
        function originIsExport(origin) {
            return !!(origin && origin.kind & 4 /* Export */);
        }
        function originIsResolvedExport(origin) {
            return !!(origin && origin.kind === 32 /* ResolvedExport */);
        }
        function originIncludesSymbolName(origin) {
            return originIsExport(origin) || originIsResolvedExport(origin) || originIsComputedPropertyName(origin);
        }
        function originIsPackageJsonImport(origin) {
            return (originIsExport(origin) || originIsResolvedExport(origin)) && !!origin.isFromPackageJson;
        }
        function originIsPromise(origin) {
            return !!(origin.kind & 8 /* Promise */);
        }
        function originIsNullableMember(origin) {
            return !!(origin.kind & 16 /* Nullable */);
        }
        function originIsTypeOnlyAlias(origin) {
            return !!(origin && origin.kind & 64 /* TypeOnlyAlias */);
        }
        function originIsObjectLiteralMethod(origin) {
            return !!(origin && origin.kind & 128 /* ObjectLiteralMethod */);
        }
        function originIsIgnore(origin) {
            return !!(origin && origin.kind & 256 /* Ignore */);
        }
        function originIsComputedPropertyName(origin) {
            return !!(origin && origin.kind & 512 /* ComputedPropertyName */);
        }
        function resolvingModuleSpecifiers(logPrefix, host, resolver, program, position, preferences, isForImportStatementCompletion, isValidTypeOnlyUseSite, cb) {
            var _a2, _b, _c;
            const start = timestamp();
            const needsFullResolution = isForImportStatementCompletion || moduleResolutionSupportsPackageJsonExportsAndImports(getEmitModuleResolutionKind(program.getCompilerOptions()));
            let skippedAny = false;
            let ambientCount = 0;
            let resolvedCount = 0;
            let resolvedFromCacheCount = 0;
            let cacheAttemptCount = 0;
            const result = cb({
                tryResolve,
                skippedAny: () => skippedAny,
                resolvedAny: () => resolvedCount > 0,
                resolvedBeyondLimit: () => resolvedCount > moduleSpecifierResolutionLimit
            });
            const hitRateMessage = cacheAttemptCount ? ` (${(resolvedFromCacheCount / cacheAttemptCount * 100).toFixed(1)}% hit rate)` : "";
            (_a2 = host.log) == null ? void 0 : _a2.call(host, `${logPrefix}: resolved ${resolvedCount} module specifiers, plus ${ambientCount} ambient and ${resolvedFromCacheCount} from cache${hitRateMessage}`);
            (_b = host.log) == null ? void 0 : _b.call(host, `${logPrefix}: response is ${skippedAny ? "incomplete" : "complete"}`);
            (_c = host.log) == null ? void 0 : _c.call(host, `${logPrefix}: ${timestamp() - start}`);
            return result;
            function tryResolve(exportInfo, isFromAmbientModule) {
                if (isFromAmbientModule) {
                    const result3 = resolver.getModuleSpecifierForBestExportInfo(exportInfo, position, isValidTypeOnlyUseSite);
                    if (result3) {
                        ambientCount++;
                    }
                    return result3 || "failed";
                }
                const shouldResolveModuleSpecifier = needsFullResolution || preferences.allowIncompleteCompletions && resolvedCount < moduleSpecifierResolutionLimit;
                const shouldGetModuleSpecifierFromCache = !shouldResolveModuleSpecifier && preferences.allowIncompleteCompletions && cacheAttemptCount < moduleSpecifierResolutionCacheAttemptLimit;
                const result2 = shouldResolveModuleSpecifier || shouldGetModuleSpecifierFromCache ? resolver.getModuleSpecifierForBestExportInfo(exportInfo, position, isValidTypeOnlyUseSite, shouldGetModuleSpecifierFromCache) : void 0;
                if (!shouldResolveModuleSpecifier && !shouldGetModuleSpecifierFromCache || shouldGetModuleSpecifierFromCache && !result2) {
                    skippedAny = true;
                }
                resolvedCount += (result2 == null ? void 0 : result2.computedWithoutCacheCount) || 0;
                resolvedFromCacheCount += exportInfo.length - ((result2 == null ? void 0 : result2.computedWithoutCacheCount) || 0);
                if (shouldGetModuleSpecifierFromCache) {
                    cacheAttemptCount++;
                }
                return result2 || (needsFullResolution ? "failed" : "skipped");
            }
        }
        function getCompletionsAtPosition(host, program, log, sourceFile, position, preferences, triggerCharacter, completionKind, cancellationToken, formatContext, includeSymbol = false) {
            var _a2;
            const { previousToken } = getRelevantTokens(position, sourceFile);
            if (triggerCharacter && !isInString(sourceFile, position, previousToken) && !isValidTrigger(sourceFile, triggerCharacter, previousToken, position)) {
                return void 0;
            }
            if (triggerCharacter === " ") {
                if (preferences.includeCompletionsForImportStatements && preferences.includeCompletionsWithInsertText) {
                    return { isGlobalCompletion: true, isMemberCompletion: false, isNewIdentifierLocation: true, isIncomplete: true, entries: [] };
                }
                return void 0;
            }
            const compilerOptions = program.getCompilerOptions();
            const incompleteCompletionsCache = preferences.allowIncompleteCompletions ? (_a2 = host.getIncompleteCompletionsCache) == null ? void 0 : _a2.call(host) : void 0;
            if (incompleteCompletionsCache && completionKind === 3 /* TriggerForIncompleteCompletions */ && previousToken && isIdentifier(previousToken)) {
                const incompleteContinuation = continuePreviousIncompleteResponse(incompleteCompletionsCache, sourceFile, previousToken, program, host, preferences, cancellationToken, position);
                if (incompleteContinuation) {
                    return incompleteContinuation;
                }
            }
            else {
                incompleteCompletionsCache == null ? void 0 : incompleteCompletionsCache.clear();
            }
            const stringCompletions = ts_Completions_StringCompletions_exports.getStringLiteralCompletions(sourceFile, position, previousToken, compilerOptions, host, program, log, preferences, includeSymbol);
            if (stringCompletions) {
                return stringCompletions;
            }
            if (previousToken && isBreakOrContinueStatement(previousToken.parent) && (previousToken.kind === 81 /* BreakKeyword */ || previousToken.kind === 86 /* ContinueKeyword */ || previousToken.kind === 79 /* Identifier */)) {
                return getLabelCompletionAtPosition(previousToken.parent);
            }
            const completionData = getCompletionData(program, log, sourceFile, compilerOptions, position, preferences, 
            /*detailsEntryId*/
            void 0, host, formatContext, cancellationToken);
            if (!completionData) {
                return void 0;
            }
            switch (completionData.kind) {
                case 0 /* Data */:
                    const response = completionInfoFromData(sourceFile, host, program, compilerOptions, log, completionData, preferences, formatContext, position, includeSymbol);
                    if (response == null ? void 0 : response.isIncomplete) {
                        incompleteCompletionsCache == null ? void 0 : incompleteCompletionsCache.set(response);
                    }
                    return response;
                case 1 /* JsDocTagName */:
                    return jsdocCompletionInfo(ts_JsDoc_exports.getJSDocTagNameCompletions());
                case 2 /* JsDocTag */:
                    return jsdocCompletionInfo(ts_JsDoc_exports.getJSDocTagCompletions());
                case 3 /* JsDocParameterName */:
                    return jsdocCompletionInfo(ts_JsDoc_exports.getJSDocParameterNameCompletions(completionData.tag));
                case 4 /* Keywords */:
                    return specificKeywordCompletionInfo(completionData.keywordCompletions, completionData.isNewIdentifierLocation);
                default:
                    return Debug.assertNever(completionData);
            }
        }
        function compareCompletionEntries(entryInArray, entryToInsert) {
            var _a2, _b;
            let result = compareStringsCaseSensitiveUI(entryInArray.sortText, entryToInsert.sortText);
            if (result === 0 /* EqualTo */) {
                result = compareStringsCaseSensitiveUI(entryInArray.name, entryToInsert.name);
            }
            if (result === 0 /* EqualTo */ && ((_a2 = entryInArray.data) == null ? void 0 : _a2.moduleSpecifier) && ((_b = entryToInsert.data) == null ? void 0 : _b.moduleSpecifier)) {
                result = compareNumberOfDirectorySeparators(entryInArray.data.moduleSpecifier, entryToInsert.data.moduleSpecifier);
            }
            if (result === 0 /* EqualTo */) {
                return -1 /* LessThan */;
            }
            return result;
        }
        function completionEntryDataIsResolved(data) {
            return !!(data == null ? void 0 : data.moduleSpecifier);
        }
        function continuePreviousIncompleteResponse(cache, file, location, program, host, preferences, cancellationToken, position) {
            const previousResponse = cache.get();
            if (!previousResponse)
                return void 0;
            const touchNode = getTouchingPropertyName(file, position);
            const lowerCaseTokenText = location.text.toLowerCase();
            const exportMap = getExportInfoMap(file, host, program, preferences, cancellationToken);
            const newEntries = resolvingModuleSpecifiers("continuePreviousIncompleteResponse", host, ts_codefix_exports.createImportSpecifierResolver(file, program, host, preferences), program, location.getStart(), preferences, 
            /*isForImportStatementCompletion*/
            false, isValidTypeOnlyAliasUseSite(location), (context) => {
                const entries = mapDefined(previousResponse.entries, (entry) => {
                    var _a2;
                    if (!entry.hasAction || !entry.source || !entry.data || completionEntryDataIsResolved(entry.data)) {
                        return entry;
                    }
                    if (!charactersFuzzyMatchInString(entry.name, lowerCaseTokenText)) {
                        return void 0;
                    }
                    const { origin } = Debug.checkDefined(getAutoImportSymbolFromCompletionEntryData(entry.name, entry.data, program, host));
                    const info = exportMap.get(file.path, entry.data.exportMapKey);
                    const result = info && context.tryResolve(info, !isExternalModuleNameRelative(stripQuotes(origin.moduleSymbol.name)));
                    if (result === "skipped")
                        return entry;
                    if (!result || result === "failed") {
                        (_a2 = host.log) == null ? void 0 : _a2.call(host, `Unexpected failure resolving auto import for '${entry.name}' from '${entry.source}'`);
                        return void 0;
                    }
                    const newOrigin = {
                        ...origin,
                        kind: 32 /* ResolvedExport */,
                        moduleSpecifier: result.moduleSpecifier
                    };
                    entry.data = originToCompletionEntryData(newOrigin);
                    entry.source = getSourceFromOrigin(newOrigin);
                    entry.sourceDisplay = [textPart(newOrigin.moduleSpecifier)];
                    return entry;
                });
                if (!context.skippedAny()) {
                    previousResponse.isIncomplete = void 0;
                }
                return entries;
            });
            previousResponse.entries = newEntries;
            previousResponse.flags = (previousResponse.flags || 0) | 4 /* IsContinuation */;
            previousResponse.optionalReplacementSpan = getOptionalReplacementSpan(touchNode);
            return previousResponse;
        }
        function jsdocCompletionInfo(entries) {
            return { isGlobalCompletion: false, isMemberCompletion: false, isNewIdentifierLocation: false, entries };
        }
        function keywordToCompletionEntry(keyword) {
            return {
                name: tokenToString(keyword),
                kind: "keyword" /* keyword */,
                kindModifiers: "" /* none */,
                sortText: SortText.GlobalsOrKeywords
            };
        }
        function specificKeywordCompletionInfo(entries, isNewIdentifierLocation) {
            return {
                isGlobalCompletion: false,
                isMemberCompletion: false,
                isNewIdentifierLocation,
                entries: entries.slice()
            };
        }
        function keywordCompletionData(keywordFilters, filterOutTsOnlyKeywords, isNewIdentifierLocation) {
            return {
                kind: 4 /* Keywords */,
                keywordCompletions: getKeywordCompletions(keywordFilters, filterOutTsOnlyKeywords),
                isNewIdentifierLocation
            };
        }
        function keywordFiltersFromSyntaxKind(keywordCompletion) {
            switch (keywordCompletion) {
                case 154 /* TypeKeyword */:
                    return 8 /* TypeKeyword */;
                default:
                    Debug.fail("Unknown mapping from SyntaxKind to KeywordCompletionFilters");
            }
        }
        function getOptionalReplacementSpan(location) {
            return (location == null ? void 0 : location.kind) === 79 /* Identifier */ ? createTextSpanFromNode(location) : void 0;
        }
        function completionInfoFromData(sourceFile, host, program, compilerOptions, log, completionData, preferences, formatContext, position, includeSymbol) {
            const { symbols, contextToken, completionKind, isInSnippetScope, isNewIdentifierLocation, location, propertyAccessToConvert, keywordFilters, symbolToOriginInfoMap, recommendedCompletion, isJsxInitializer, isTypeOnlyLocation, isJsxIdentifierExpected, isRightOfOpenTag, isRightOfDotOrQuestionDot, importStatementCompletion, insideJsDocTagTypeExpression, symbolToSortTextMap, hasUnresolvedAutoImports } = completionData;
            let literals = completionData.literals;
            const checker = program.getTypeChecker();
            if (getLanguageVariant(sourceFile.scriptKind) === 1 /* JSX */) {
                const completionInfo = getJsxClosingTagCompletion(location, sourceFile);
                if (completionInfo) {
                    return completionInfo;
                }
            }
            const caseClause = findAncestor(contextToken, isCaseClause);
            if (caseClause && (isCaseKeyword(contextToken) || isNodeDescendantOf(contextToken, caseClause.expression))) {
                const tracker = newCaseClauseTracker(checker, caseClause.parent.clauses);
                literals = literals.filter((literal) => !tracker.hasValue(literal));
                symbols.forEach((symbol, i) => {
                    if (symbol.valueDeclaration && isEnumMember(symbol.valueDeclaration)) {
                        const value = checker.getConstantValue(symbol.valueDeclaration);
                        if (value !== void 0 && tracker.hasValue(value)) {
                            symbolToOriginInfoMap[i] = { kind: 256 /* Ignore */ };
                        }
                    }
                });
            }
            const entries = createSortedArray();
            const isChecked = isCheckedFile(sourceFile, compilerOptions);
            if (isChecked && !isNewIdentifierLocation && (!symbols || symbols.length === 0) && keywordFilters === 0 /* None */) {
                return void 0;
            }
            const uniqueNames = getCompletionEntriesFromSymbols(symbols, entries, 
            /*replacementToken*/
            void 0, contextToken, location, position, sourceFile, host, program, getEmitScriptTarget(compilerOptions), log, completionKind, preferences, compilerOptions, formatContext, isTypeOnlyLocation, propertyAccessToConvert, isJsxIdentifierExpected, isJsxInitializer, importStatementCompletion, recommendedCompletion, symbolToOriginInfoMap, symbolToSortTextMap, isJsxIdentifierExpected, isRightOfOpenTag, includeSymbol);
            if (keywordFilters !== 0 /* None */) {
                for (const keywordEntry of getKeywordCompletions(keywordFilters, !insideJsDocTagTypeExpression && isSourceFileJS(sourceFile))) {
                    if (isTypeOnlyLocation && isTypeKeyword(stringToToken(keywordEntry.name)) || !uniqueNames.has(keywordEntry.name)) {
                        uniqueNames.add(keywordEntry.name);
                        insertSorted(entries, keywordEntry, compareCompletionEntries, 
                        /*allowDuplicates*/
                        true);
                    }
                }
            }
            for (const keywordEntry of getContextualKeywords(contextToken, position)) {
                if (!uniqueNames.has(keywordEntry.name)) {
                    uniqueNames.add(keywordEntry.name);
                    insertSorted(entries, keywordEntry, compareCompletionEntries, 
                    /*allowDuplicates*/
                    true);
                }
            }
            for (const literal of literals) {
                const literalEntry = createCompletionEntryForLiteral(sourceFile, preferences, literal);
                uniqueNames.add(literalEntry.name);
                insertSorted(entries, literalEntry, compareCompletionEntries, 
                /*allowDuplicates*/
                true);
            }
            if (!isChecked) {
                getJSCompletionEntries(sourceFile, location.pos, uniqueNames, getEmitScriptTarget(compilerOptions), entries);
            }
            let caseBlock;
            if (preferences.includeCompletionsWithInsertText && contextToken && !isRightOfOpenTag && !isRightOfDotOrQuestionDot && (caseBlock = findAncestor(contextToken, isCaseBlock))) {
                const cases = getExhaustiveCaseSnippets(caseBlock, sourceFile, preferences, compilerOptions, host, program, formatContext);
                if (cases) {
                    entries.push(cases.entry);
                }
            }
            return {
                flags: completionData.flags,
                isGlobalCompletion: isInSnippetScope,
                isIncomplete: preferences.allowIncompleteCompletions && hasUnresolvedAutoImports ? true : void 0,
                isMemberCompletion: isMemberCompletionKind(completionKind),
                isNewIdentifierLocation,
                optionalReplacementSpan: getOptionalReplacementSpan(location),
                entries
            };
        }
        function isCheckedFile(sourceFile, compilerOptions) {
            return !isSourceFileJS(sourceFile) || !!isCheckJsEnabledForFile(sourceFile, compilerOptions);
        }
        function getExhaustiveCaseSnippets(caseBlock, sourceFile, preferences, options, host, program, formatContext) {
            const clauses = caseBlock.clauses;
            const checker = program.getTypeChecker();
            const switchType = checker.getTypeAtLocation(caseBlock.parent.expression);
            if (switchType && switchType.isUnion() && every(switchType.types, (type) => type.isLiteral())) {
                const tracker = newCaseClauseTracker(checker, clauses);
                const target = getEmitScriptTarget(options);
                const quotePreference = getQuotePreference(sourceFile, preferences);
                const importAdder = ts_codefix_exports.createImportAdder(sourceFile, program, preferences, host);
                const elements = [];
                for (const type of switchType.types) {
                    if (type.flags & 1024 /* EnumLiteral */) {
                        Debug.assert(type.symbol, "An enum member type should have a symbol");
                        Debug.assert(type.symbol.parent, "An enum member type should have a parent symbol (the enum symbol)");
                        const enumValue = type.symbol.valueDeclaration && checker.getConstantValue(type.symbol.valueDeclaration);
                        if (enumValue !== void 0) {
                            if (tracker.hasValue(enumValue)) {
                                continue;
                            }
                            tracker.addValue(enumValue);
                        }
                        const typeNode = ts_codefix_exports.typeToAutoImportableTypeNode(checker, importAdder, type, caseBlock, target);
                        if (!typeNode) {
                            return void 0;
                        }
                        const expr = typeNodeToExpression(typeNode, target, quotePreference);
                        if (!expr) {
                            return void 0;
                        }
                        elements.push(expr);
                    }
                    else if (!tracker.hasValue(type.value)) {
                        switch (typeof type.value) {
                            case "object":
                                elements.push(type.value.negative ? factory.createPrefixUnaryExpression(40 /* MinusToken */, factory.createBigIntLiteral({ negative: false, base10Value: type.value.base10Value })) : factory.createBigIntLiteral(type.value));
                                break;
                            case "number":
                                elements.push(type.value < 0 ? factory.createPrefixUnaryExpression(40 /* MinusToken */, factory.createNumericLiteral(-type.value)) : factory.createNumericLiteral(type.value));
                                break;
                            case "string":
                                elements.push(factory.createStringLiteral(type.value, quotePreference === 0 /* Single */));
                                break;
                        }
                    }
                }
                if (elements.length === 0) {
                    return void 0;
                }
                const newClauses = map(elements, (element) => factory.createCaseClause(element, []));
                const newLineChar = getNewLineOrDefaultFromHost(host, formatContext == null ? void 0 : formatContext.options);
                const printer = createSnippetPrinter({
                    removeComments: true,
                    module: options.module,
                    target: options.target,
                    newLine: getNewLineKind(newLineChar)
                });
                const printNode = formatContext ? (node) => printer.printAndFormatNode(4 /* Unspecified */, node, sourceFile, formatContext) : (node) => printer.printNode(4 /* Unspecified */, node, sourceFile);
                const insertText = map(newClauses, (clause, i) => {
                    if (preferences.includeCompletionsWithSnippetText) {
                        return `${printNode(clause)}$${i + 1}`;
                    }
                    return `${printNode(clause)}`;
                }).join(newLineChar);
                const firstClause = printer.printNode(4 /* Unspecified */, newClauses[0], sourceFile);
                return {
                    entry: {
                        name: `${firstClause} ...`,
                        kind: "" /* unknown */,
                        sortText: SortText.GlobalsOrKeywords,
                        insertText,
                        hasAction: importAdder.hasFixes() || void 0,
                        source: "SwitchCases/" /* SwitchCases */,
                        isSnippet: preferences.includeCompletionsWithSnippetText ? true : void 0
                    },
                    importAdder
                };
            }
            return void 0;
        }
        function typeNodeToExpression(typeNode, languageVersion, quotePreference) {
            switch (typeNode.kind) {
                case 180 /* TypeReference */:
                    const typeName = typeNode.typeName;
                    return entityNameToExpression(typeName, languageVersion, quotePreference);
                case 196 /* IndexedAccessType */:
                    const objectExpression = typeNodeToExpression(typeNode.objectType, languageVersion, quotePreference);
                    const indexExpression = typeNodeToExpression(typeNode.indexType, languageVersion, quotePreference);
                    return objectExpression && indexExpression && factory.createElementAccessExpression(objectExpression, indexExpression);
                case 198 /* LiteralType */:
                    const literal = typeNode.literal;
                    switch (literal.kind) {
                        case 10 /* StringLiteral */:
                            return factory.createStringLiteral(literal.text, quotePreference === 0 /* Single */);
                        case 8 /* NumericLiteral */:
                            return factory.createNumericLiteral(literal.text, literal.numericLiteralFlags);
                    }
                    return void 0;
                case 193 /* ParenthesizedType */:
                    const exp = typeNodeToExpression(typeNode.type, languageVersion, quotePreference);
                    return exp && (isIdentifier(exp) ? exp : factory.createParenthesizedExpression(exp));
                case 183 /* TypeQuery */:
                    return entityNameToExpression(typeNode.exprName, languageVersion, quotePreference);
                case 202 /* ImportType */:
                    Debug.fail(`We should not get an import type after calling 'codefix.typeToAutoImportableTypeNode'.`);
            }
            return void 0;
        }
        function entityNameToExpression(entityName, languageVersion, quotePreference) {
            if (isIdentifier(entityName)) {
                return entityName;
            }
            const unescapedName = unescapeLeadingUnderscores(entityName.right.escapedText);
            if (canUsePropertyAccess(unescapedName, languageVersion)) {
                return factory.createPropertyAccessExpression(entityNameToExpression(entityName.left, languageVersion, quotePreference), unescapedName);
            }
            else {
                return factory.createElementAccessExpression(entityNameToExpression(entityName.left, languageVersion, quotePreference), factory.createStringLiteral(unescapedName, quotePreference === 0 /* Single */));
            }
        }
        function isMemberCompletionKind(kind) {
            switch (kind) {
                case 0 /* ObjectPropertyDeclaration */:
                case 3 /* MemberLike */:
                case 2 /* PropertyAccess */:
                    return true;
                default:
                    return false;
            }
        }
        function getJsxClosingTagCompletion(location, sourceFile) {
            const jsxClosingElement = findAncestor(location, (node) => {
                switch (node.kind) {
                    case 284 /* JsxClosingElement */:
                        return true;
                    case 43 /* SlashToken */:
                    case 31 /* GreaterThanToken */:
                    case 79 /* Identifier */:
                    case 208 /* PropertyAccessExpression */:
                        return false;
                    default:
                        return "quit";
                }
            });
            if (jsxClosingElement) {
                const hasClosingAngleBracket = !!findChildOfKind(jsxClosingElement, 31 /* GreaterThanToken */, sourceFile);
                const tagName = jsxClosingElement.parent.openingElement.tagName;
                const closingTag = tagName.getText(sourceFile);
                const fullClosingTag = closingTag + (hasClosingAngleBracket ? "" : ">");
                const replacementSpan = createTextSpanFromNode(jsxClosingElement.tagName);
                const entry = {
                    name: fullClosingTag,
                    kind: "class" /* classElement */,
                    kindModifiers: void 0,
                    sortText: SortText.LocationPriority
                };
                return { isGlobalCompletion: false, isMemberCompletion: true, isNewIdentifierLocation: false, optionalReplacementSpan: replacementSpan, entries: [entry] };
            }
            return;
        }
        function getJSCompletionEntries(sourceFile, position, uniqueNames, target, entries) {
            getNameTable(sourceFile).forEach((pos, name) => {
                if (pos === position) {
                    return;
                }
                const realName = unescapeLeadingUnderscores(name);
                if (!uniqueNames.has(realName) && isIdentifierText(realName, target)) {
                    uniqueNames.add(realName);
                    insertSorted(entries, {
                        name: realName,
                        kind: "warning" /* warning */,
                        kindModifiers: "",
                        sortText: SortText.JavascriptIdentifiers,
                        isFromUncheckedFile: true
                    }, compareCompletionEntries);
                }
            });
        }
        function completionNameForLiteral(sourceFile, preferences, literal) {
            return typeof literal === "object" ? pseudoBigIntToString(literal) + "n" : isString(literal) ? quote(sourceFile, preferences, literal) : JSON.stringify(literal);
        }
        function createCompletionEntryForLiteral(sourceFile, preferences, literal) {
            return { name: completionNameForLiteral(sourceFile, preferences, literal), kind: "string" /* string */, kindModifiers: "" /* none */, sortText: SortText.LocationPriority };
        }
        function createCompletionEntry(symbol, sortText, replacementToken, contextToken, location, position, sourceFile, host, program, name, needsConvertPropertyAccess, origin, recommendedCompletion, propertyAccessToConvert, isJsxInitializer, importStatementCompletion, useSemicolons, options, preferences, completionKind, formatContext, isJsxIdentifierExpected, isRightOfOpenTag, includeSymbol) {
            let insertText;
            let replacementSpan = getReplacementSpanForContextToken(replacementToken);
            let data;
            let isSnippet;
            let source = getSourceFromOrigin(origin);
            let sourceDisplay;
            let hasAction;
            let labelDetails;
            const typeChecker = program.getTypeChecker();
            const insertQuestionDot = origin && originIsNullableMember(origin);
            const useBraces = origin && originIsSymbolMember(origin) || needsConvertPropertyAccess;
            if (origin && originIsThisType(origin)) {
                insertText = needsConvertPropertyAccess ? `this${insertQuestionDot ? "?." : ""}[${quotePropertyName(sourceFile, preferences, name)}]` : `this${insertQuestionDot ? "?." : "."}${name}`;
            }
            else if ((useBraces || insertQuestionDot) && propertyAccessToConvert) {
                insertText = useBraces ? needsConvertPropertyAccess ? `[${quotePropertyName(sourceFile, preferences, name)}]` : `[${name}]` : name;
                if (insertQuestionDot || propertyAccessToConvert.questionDotToken) {
                    insertText = `?.${insertText}`;
                }
                const dot = findChildOfKind(propertyAccessToConvert, 24 /* DotToken */, sourceFile) || findChildOfKind(propertyAccessToConvert, 28 /* QuestionDotToken */, sourceFile);
                if (!dot) {
                    return void 0;
                }
                const end = startsWith(name, propertyAccessToConvert.name.text) ? propertyAccessToConvert.name.end : dot.end;
                replacementSpan = createTextSpanFromBounds(dot.getStart(sourceFile), end);
            }
            if (isJsxInitializer) {
                if (insertText === void 0)
                    insertText = name;
                insertText = `{${insertText}}`;
                if (typeof isJsxInitializer !== "boolean") {
                    replacementSpan = createTextSpanFromNode(isJsxInitializer, sourceFile);
                }
            }
            if (origin && originIsPromise(origin) && propertyAccessToConvert) {
                if (insertText === void 0)
                    insertText = name;
                const precedingToken = findPrecedingToken(propertyAccessToConvert.pos, sourceFile);
                let awaitText = "";
                if (precedingToken && positionIsASICandidate(precedingToken.end, precedingToken.parent, sourceFile)) {
                    awaitText = ";";
                }
                awaitText += `(await ${propertyAccessToConvert.expression.getText()})`;
                insertText = needsConvertPropertyAccess ? `${awaitText}${insertText}` : `${awaitText}${insertQuestionDot ? "?." : "."}${insertText}`;
                const isInAwaitExpression = tryCast(propertyAccessToConvert.parent, isAwaitExpression);
                const wrapNode = isInAwaitExpression ? propertyAccessToConvert.parent : propertyAccessToConvert.expression;
                replacementSpan = createTextSpanFromBounds(wrapNode.getStart(sourceFile), propertyAccessToConvert.end);
            }
            if (originIsResolvedExport(origin)) {
                sourceDisplay = [textPart(origin.moduleSpecifier)];
                if (importStatementCompletion) {
                    ({ insertText, replacementSpan } = getInsertTextAndReplacementSpanForImportCompletion(name, importStatementCompletion, origin, useSemicolons, sourceFile, options, preferences));
                    isSnippet = preferences.includeCompletionsWithSnippetText ? true : void 0;
                }
            }
            if ((origin == null ? void 0 : origin.kind) === 64 /* TypeOnlyAlias */) {
                hasAction = true;
            }
            if (preferences.includeCompletionsWithClassMemberSnippets && preferences.includeCompletionsWithInsertText && completionKind === 3 /* MemberLike */ && isClassLikeMemberCompletion(symbol, location, sourceFile)) {
                let importAdder;
                ({ insertText, isSnippet, importAdder, replacementSpan } = getEntryForMemberCompletion(host, program, options, preferences, name, symbol, location, position, contextToken, formatContext));
                sortText = SortText.ClassMemberSnippets;
                if (importAdder == null ? void 0 : importAdder.hasFixes()) {
                    hasAction = true;
                    source = "ClassMemberSnippet/" /* ClassMemberSnippet */;
                }
            }
            if (origin && originIsObjectLiteralMethod(origin)) {
                ({ insertText, isSnippet, labelDetails } = origin);
                if (!preferences.useLabelDetailsInCompletionEntries) {
                    name = name + labelDetails.detail;
                    labelDetails = void 0;
                }
                source = "ObjectLiteralMethodSnippet/" /* ObjectLiteralMethodSnippet */;
                sortText = SortText.SortBelow(sortText);
            }
            if (isJsxIdentifierExpected && !isRightOfOpenTag && preferences.includeCompletionsWithSnippetText && preferences.jsxAttributeCompletionStyle && preferences.jsxAttributeCompletionStyle !== "none" && !(isJsxAttribute(location.parent) && location.parent.initializer)) {
                let useBraces2 = preferences.jsxAttributeCompletionStyle === "braces";
                const type = typeChecker.getTypeOfSymbolAtLocation(symbol, location);
                if (preferences.jsxAttributeCompletionStyle === "auto" && !(type.flags & 528 /* BooleanLike */) && !(type.flags & 1048576 /* Union */ && find(type.types, (type2) => !!(type2.flags & 528 /* BooleanLike */)))) {
                    if (type.flags & 402653316 /* StringLike */ || type.flags & 1048576 /* Union */ && every(type.types, (type2) => !!(type2.flags & (402653316 /* StringLike */ | 32768 /* Undefined */) || isStringAndEmptyAnonymousObjectIntersection(type2)))) {
                        insertText = `${escapeSnippetText(name)}=${quote(sourceFile, preferences, "$1")}`;
                        isSnippet = true;
                    }
                    else {
                        useBraces2 = true;
                    }
                }
                if (useBraces2) {
                    insertText = `${escapeSnippetText(name)}={$1}`;
                    isSnippet = true;
                }
            }
            if (insertText !== void 0 && !preferences.includeCompletionsWithInsertText) {
                return void 0;
            }
            if (originIsExport(origin) || originIsResolvedExport(origin)) {
                data = originToCompletionEntryData(origin);
                hasAction = !importStatementCompletion;
            }
            return {
                name,
                kind: ts_SymbolDisplay_exports.getSymbolKind(typeChecker, symbol, location),
                kindModifiers: ts_SymbolDisplay_exports.getSymbolModifiers(typeChecker, symbol),
                sortText,
                source,
                hasAction: hasAction ? true : void 0,
                isRecommended: isRecommendedCompletionMatch(symbol, recommendedCompletion, typeChecker) || void 0,
                insertText,
                replacementSpan,
                sourceDisplay,
                labelDetails,
                isSnippet,
                isPackageJsonImport: originIsPackageJsonImport(origin) || void 0,
                isImportStatementCompletion: !!importStatementCompletion || void 0,
                data,
                ...includeSymbol ? { symbol } : void 0
            };
        }
        function isClassLikeMemberCompletion(symbol, location, sourceFile) {
            if (isInJSFile(location)) {
                return false;
            }
            const memberFlags = 106500 /* ClassMember */ & 900095 /* EnumMemberExcludes */;
            return !!(symbol.flags & memberFlags) && (isClassLike(location) || location.parent && location.parent.parent && isClassElement(location.parent) && location === location.parent.name && location.parent.getLastToken(sourceFile) === location.parent.name && isClassLike(location.parent.parent) || location.parent && isSyntaxList(location) && isClassLike(location.parent));
        }
        function getEntryForMemberCompletion(host, program, options, preferences, name, symbol, location, position, contextToken, formatContext) {
            const classLikeDeclaration = findAncestor(location, isClassLike);
            if (!classLikeDeclaration) {
                return { insertText: name };
            }
            let isSnippet;
            let replacementSpan;
            let insertText = name;
            const checker = program.getTypeChecker();
            const sourceFile = location.getSourceFile();
            const printer = createSnippetPrinter({
                removeComments: true,
                module: options.module,
                target: options.target,
                omitTrailingSemicolon: false,
                newLine: getNewLineKind(getNewLineOrDefaultFromHost(host, formatContext == null ? void 0 : formatContext.options))
            });
            const importAdder = ts_codefix_exports.createImportAdder(sourceFile, program, preferences, host);
            let body;
            if (preferences.includeCompletionsWithSnippetText) {
                isSnippet = true;
                const emptyStmt = factory.createEmptyStatement();
                body = factory.createBlock([emptyStmt], 
                /* multiline */
                true);
                setSnippetElement(emptyStmt, { kind: 0 /* TabStop */, order: 0 });
            }
            else {
                body = factory.createBlock([], 
                /* multiline */
                true);
            }
            let modifiers = 0 /* None */;
            const { modifiers: presentModifiers, span: modifiersSpan } = getPresentModifiers(contextToken, sourceFile, position);
            const isAbstract = !!(presentModifiers & 256 /* Abstract */);
            const completionNodes = [];
            ts_codefix_exports.addNewNodeForMemberSymbol(symbol, classLikeDeclaration, sourceFile, { program, host }, preferences, importAdder, 
            // `addNewNodeForMemberSymbol` calls this callback function for each new member node
            // it adds for the given member symbol.
            // We store these member nodes in the `completionNodes` array.
            // Note: there might be:
            //  - No nodes if `addNewNodeForMemberSymbol` cannot figure out a node for the member;
            //  - One node;
            //  - More than one node if the member is overloaded (e.g. a method with overload signatures).
            (node) => {
                let requiredModifiers = 0 /* None */;
                if (isAbstract) {
                    requiredModifiers |= 256 /* Abstract */;
                }
                if (isClassElement(node) && checker.getMemberOverrideModifierStatus(classLikeDeclaration, node, symbol) === 1 /* NeedsOverride */) {
                    requiredModifiers |= 16384 /* Override */;
                }
                if (!completionNodes.length) {
                    modifiers = node.modifierFlagsCache | requiredModifiers | presentModifiers;
                }
                node = factory.updateModifiers(node, modifiers);
                completionNodes.push(node);
            }, body, ts_codefix_exports.PreserveOptionalFlags.Property, isAbstract);
            if (completionNodes.length) {
                const format = 1 /* MultiLine */ | 131072 /* NoTrailingNewLine */;
                replacementSpan = modifiersSpan;
                if (formatContext) {
                    insertText = printer.printAndFormatSnippetList(format, factory.createNodeArray(completionNodes), sourceFile, formatContext);
                }
                else {
                    insertText = printer.printSnippetList(format, factory.createNodeArray(completionNodes), sourceFile);
                }
            }
            return { insertText, isSnippet, importAdder, replacementSpan };
        }
        function getPresentModifiers(contextToken, sourceFile, position) {
            if (!contextToken || getLineAndCharacterOfPosition(sourceFile, position).line > getLineAndCharacterOfPosition(sourceFile, contextToken.getEnd()).line) {
                return { modifiers: 0 /* None */ };
            }
            let modifiers = 0 /* None */;
            let span;
            let contextMod;
            if (contextMod = isModifierLike2(contextToken)) {
                modifiers |= modifierToFlag(contextMod);
                span = createTextSpanFromNode(contextToken);
            }
            if (isPropertyDeclaration(contextToken.parent)) {
                modifiers |= modifiersToFlags(contextToken.parent.modifiers) & 126975 /* Modifier */;
                span = createTextSpanFromNode(contextToken.parent);
            }
            return { modifiers, span };
        }
        function isModifierLike2(node) {
            if (isModifier(node)) {
                return node.kind;
            }
            if (isIdentifier(node)) {
                const originalKeywordKind = identifierToKeywordKind(node);
                if (originalKeywordKind && isModifierKind(originalKeywordKind)) {
                    return originalKeywordKind;
                }
            }
            return void 0;
        }
        function getEntryForObjectLiteralMethodCompletion(symbol, name, enclosingDeclaration, program, host, options, preferences, formatContext) {
            const isSnippet = preferences.includeCompletionsWithSnippetText || void 0;
            let insertText = name;
            const sourceFile = enclosingDeclaration.getSourceFile();
            const method = createObjectLiteralMethod(symbol, enclosingDeclaration, sourceFile, program, host, preferences);
            if (!method) {
                return void 0;
            }
            const printer = createSnippetPrinter({
                removeComments: true,
                module: options.module,
                target: options.target,
                omitTrailingSemicolon: false,
                newLine: getNewLineKind(getNewLineOrDefaultFromHost(host, formatContext == null ? void 0 : formatContext.options))
            });
            if (formatContext) {
                insertText = printer.printAndFormatSnippetList(16 /* CommaDelimited */ | 64 /* AllowTrailingComma */, factory.createNodeArray([method], 
                /*hasTrailingComma*/
                true), sourceFile, formatContext);
            }
            else {
                insertText = printer.printSnippetList(16 /* CommaDelimited */ | 64 /* AllowTrailingComma */, factory.createNodeArray([method], 
                /*hasTrailingComma*/
                true), sourceFile);
            }
            const signaturePrinter = createPrinter({
                removeComments: true,
                module: options.module,
                target: options.target,
                omitTrailingSemicolon: true
            });
            const methodSignature = factory.createMethodSignature(
            /*modifiers*/
            void 0, 
            /*name*/
            "", method.questionToken, method.typeParameters, method.parameters, method.type);
            const labelDetails = { detail: signaturePrinter.printNode(4 /* Unspecified */, methodSignature, sourceFile) };
            return { isSnippet, insertText, labelDetails };
        }
        function createObjectLiteralMethod(symbol, enclosingDeclaration, sourceFile, program, host, preferences) {
            const declarations = symbol.getDeclarations();
            if (!(declarations && declarations.length)) {
                return void 0;
            }
            const checker = program.getTypeChecker();
            const declaration = declarations[0];
            const name = getSynthesizedDeepClone(getNameOfDeclaration(declaration), 
            /*includeTrivia*/
            false);
            const type = checker.getWidenedType(checker.getTypeOfSymbolAtLocation(symbol, enclosingDeclaration));
            const quotePreference = getQuotePreference(sourceFile, preferences);
            const builderFlags = 33554432 /* OmitThisParameter */ | (quotePreference === 0 /* Single */ ? 268435456 /* UseSingleQuotesForStringLiteralType */ : 0 /* None */);
            switch (declaration.kind) {
                case 168 /* PropertySignature */:
                case 169 /* PropertyDeclaration */:
                case 170 /* MethodSignature */:
                case 171 /* MethodDeclaration */: {
                    let effectiveType = type.flags & 1048576 /* Union */ && type.types.length < 10 ? checker.getUnionType(type.types, 2 /* Subtype */) : type;
                    if (effectiveType.flags & 1048576 /* Union */) {
                        const functionTypes = filter(effectiveType.types, (type2) => checker.getSignaturesOfType(type2, 0 /* Call */).length > 0);
                        if (functionTypes.length === 1) {
                            effectiveType = functionTypes[0];
                        }
                        else {
                            return void 0;
                        }
                    }
                    const signatures = checker.getSignaturesOfType(effectiveType, 0 /* Call */);
                    if (signatures.length !== 1) {
                        return void 0;
                    }
                    const typeNode = checker.typeToTypeNode(effectiveType, enclosingDeclaration, builderFlags, ts_codefix_exports.getNoopSymbolTrackerWithResolver({ program, host }));
                    if (!typeNode || !isFunctionTypeNode(typeNode)) {
                        return void 0;
                    }
                    let body;
                    if (preferences.includeCompletionsWithSnippetText) {
                        const emptyStmt = factory.createEmptyStatement();
                        body = factory.createBlock([emptyStmt], 
                        /* multiline */
                        true);
                        setSnippetElement(emptyStmt, { kind: 0 /* TabStop */, order: 0 });
                    }
                    else {
                        body = factory.createBlock([], 
                        /* multiline */
                        true);
                    }
                    const parameters = typeNode.parameters.map((typedParam) => factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, typedParam.dotDotDotToken, typedParam.name, 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, typedParam.initializer));
                    return factory.createMethodDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, name, 
                    /*questionToken*/
                    void 0, 
                    /*typeParameters*/
                    void 0, parameters, 
                    /*type*/
                    void 0, body);
                }
                default:
                    return void 0;
            }
        }
        function createSnippetPrinter(printerOptions) {
            let escapes;
            const baseWriter = ts_textChanges_exports.createWriter(getNewLineCharacter(printerOptions));
            const printer = createPrinter(printerOptions, baseWriter);
            const writer = {
                ...baseWriter,
                write: (s) => escapingWrite(s, () => baseWriter.write(s)),
                nonEscapingWrite: baseWriter.write,
                writeLiteral: (s) => escapingWrite(s, () => baseWriter.writeLiteral(s)),
                writeStringLiteral: (s) => escapingWrite(s, () => baseWriter.writeStringLiteral(s)),
                writeSymbol: (s, symbol) => escapingWrite(s, () => baseWriter.writeSymbol(s, symbol)),
                writeParameter: (s) => escapingWrite(s, () => baseWriter.writeParameter(s)),
                writeComment: (s) => escapingWrite(s, () => baseWriter.writeComment(s)),
                writeProperty: (s) => escapingWrite(s, () => baseWriter.writeProperty(s))
            };
            return {
                printSnippetList,
                printAndFormatSnippetList,
                printNode,
                printAndFormatNode
            };
            function escapingWrite(s, write) {
                const escaped = escapeSnippetText(s);
                if (escaped !== s) {
                    const start = baseWriter.getTextPos();
                    write();
                    const end = baseWriter.getTextPos();
                    escapes = append(escapes || (escapes = []), { newText: escaped, span: { start, length: end - start } });
                }
                else {
                    write();
                }
            }
            function printSnippetList(format, list, sourceFile) {
                const unescaped = printUnescapedSnippetList(format, list, sourceFile);
                return escapes ? ts_textChanges_exports.applyChanges(unescaped, escapes) : unescaped;
            }
            function printUnescapedSnippetList(format, list, sourceFile) {
                escapes = void 0;
                writer.clear();
                printer.writeList(format, list, sourceFile, writer);
                return writer.getText();
            }
            function printAndFormatSnippetList(format, list, sourceFile, formatContext) {
                const syntheticFile = {
                    text: printUnescapedSnippetList(format, list, sourceFile),
                    getLineAndCharacterOfPosition(pos) {
                        return getLineAndCharacterOfPosition(this, pos);
                    }
                };
                const formatOptions = getFormatCodeSettingsForWriting(formatContext, sourceFile);
                const changes = flatMap(list, (node) => {
                    const nodeWithPos = ts_textChanges_exports.assignPositionsToNode(node);
                    return ts_formatting_exports.formatNodeGivenIndentation(nodeWithPos, syntheticFile, sourceFile.languageVariant, 
                    /* indentation */
                    0, 
                    /* delta */
                    0, { ...formatContext, options: formatOptions });
                });
                const allChanges = escapes ? stableSort(concatenate(changes, escapes), (a, b) => compareTextSpans(a.span, b.span)) : changes;
                return ts_textChanges_exports.applyChanges(syntheticFile.text, allChanges);
            }
            function printNode(hint, node, sourceFile) {
                const unescaped = printUnescapedNode(hint, node, sourceFile);
                return escapes ? ts_textChanges_exports.applyChanges(unescaped, escapes) : unescaped;
            }
            function printUnescapedNode(hint, node, sourceFile) {
                escapes = void 0;
                writer.clear();
                printer.writeNode(hint, node, sourceFile, writer);
                return writer.getText();
            }
            function printAndFormatNode(hint, node, sourceFile, formatContext) {
                const syntheticFile = {
                    text: printUnescapedNode(hint, node, sourceFile),
                    getLineAndCharacterOfPosition(pos) {
                        return getLineAndCharacterOfPosition(this, pos);
                    }
                };
                const formatOptions = getFormatCodeSettingsForWriting(formatContext, sourceFile);
                const nodeWithPos = ts_textChanges_exports.assignPositionsToNode(node);
                const changes = ts_formatting_exports.formatNodeGivenIndentation(nodeWithPos, syntheticFile, sourceFile.languageVariant, 
                /* indentation */
                0, 
                /* delta */
                0, { ...formatContext, options: formatOptions });
                const allChanges = escapes ? stableSort(concatenate(changes, escapes), (a, b) => compareTextSpans(a.span, b.span)) : changes;
                return ts_textChanges_exports.applyChanges(syntheticFile.text, allChanges);
            }
        }
        function originToCompletionEntryData(origin) {
            const ambientModuleName = origin.fileName ? void 0 : stripQuotes(origin.moduleSymbol.name);
            const isPackageJsonImport = origin.isFromPackageJson ? true : void 0;
            if (originIsResolvedExport(origin)) {
                const resolvedData = {
                    exportName: origin.exportName,
                    exportMapKey: origin.exportMapKey,
                    moduleSpecifier: origin.moduleSpecifier,
                    ambientModuleName,
                    fileName: origin.fileName,
                    isPackageJsonImport
                };
                return resolvedData;
            }
            const unresolvedData = {
                exportName: origin.exportName,
                exportMapKey: origin.exportMapKey,
                fileName: origin.fileName,
                ambientModuleName: origin.fileName ? void 0 : stripQuotes(origin.moduleSymbol.name),
                isPackageJsonImport: origin.isFromPackageJson ? true : void 0
            };
            return unresolvedData;
        }
        function completionEntryDataToSymbolOriginInfo(data, completionName, moduleSymbol) {
            const isDefaultExport = data.exportName === "default" /* Default */;
            const isFromPackageJson = !!data.isPackageJsonImport;
            if (completionEntryDataIsResolved(data)) {
                const resolvedOrigin = {
                    kind: 32 /* ResolvedExport */,
                    exportName: data.exportName,
                    exportMapKey: data.exportMapKey,
                    moduleSpecifier: data.moduleSpecifier,
                    symbolName: completionName,
                    fileName: data.fileName,
                    moduleSymbol,
                    isDefaultExport,
                    isFromPackageJson
                };
                return resolvedOrigin;
            }
            const unresolvedOrigin = {
                kind: 4 /* Export */,
                exportName: data.exportName,
                exportMapKey: data.exportMapKey,
                symbolName: completionName,
                fileName: data.fileName,
                moduleSymbol,
                isDefaultExport,
                isFromPackageJson
            };
            return unresolvedOrigin;
        }
        function getInsertTextAndReplacementSpanForImportCompletion(name, importStatementCompletion, origin, useSemicolons, sourceFile, options, preferences) {
            const replacementSpan = importStatementCompletion.replacementSpan;
            const quotedModuleSpecifier = quote(sourceFile, preferences, escapeSnippetText(origin.moduleSpecifier));
            const exportKind = origin.isDefaultExport ? 1 /* Default */ : origin.exportName === "export=" /* ExportEquals */ ? 2 /* ExportEquals */ : 0 /* Named */;
            const tabStop = preferences.includeCompletionsWithSnippetText ? "$1" : "";
            const importKind = ts_codefix_exports.getImportKind(sourceFile, exportKind, options, 
            /*forceImportKeyword*/
            true);
            const isImportSpecifierTypeOnly = importStatementCompletion.couldBeTypeOnlyImportSpecifier;
            const topLevelTypeOnlyText = importStatementCompletion.isTopLevelTypeOnly ? ` ${tokenToString(154 /* TypeKeyword */)} ` : " ";
            const importSpecifierTypeOnlyText = isImportSpecifierTypeOnly ? `${tokenToString(154 /* TypeKeyword */)} ` : "";
            const suffix = useSemicolons ? ";" : "";
            switch (importKind) {
                case 3 /* CommonJS */:
                    return { replacementSpan, insertText: `import${topLevelTypeOnlyText}${escapeSnippetText(name)}${tabStop} = require(${quotedModuleSpecifier})${suffix}` };
                case 1 /* Default */:
                    return { replacementSpan, insertText: `import${topLevelTypeOnlyText}${escapeSnippetText(name)}${tabStop} from ${quotedModuleSpecifier}${suffix}` };
                case 2 /* Namespace */:
                    return { replacementSpan, insertText: `import${topLevelTypeOnlyText}* as ${escapeSnippetText(name)} from ${quotedModuleSpecifier}${suffix}` };
                case 0 /* Named */:
                    return { replacementSpan, insertText: `import${topLevelTypeOnlyText}{ ${importSpecifierTypeOnlyText}${escapeSnippetText(name)}${tabStop} } from ${quotedModuleSpecifier}${suffix}` };
            }
        }
        function quotePropertyName(sourceFile, preferences, name) {
            if (/^\d+$/.test(name)) {
                return name;
            }
            return quote(sourceFile, preferences, name);
        }
        function isRecommendedCompletionMatch(localSymbol, recommendedCompletion, checker) {
            return localSymbol === recommendedCompletion || !!(localSymbol.flags & 1048576 /* ExportValue */) && checker.getExportSymbolOfSymbol(localSymbol) === recommendedCompletion;
        }
        function getSourceFromOrigin(origin) {
            if (originIsExport(origin)) {
                return stripQuotes(origin.moduleSymbol.name);
            }
            if (originIsResolvedExport(origin)) {
                return origin.moduleSpecifier;
            }
            if ((origin == null ? void 0 : origin.kind) === 1 /* ThisType */) {
                return "ThisProperty/" /* ThisProperty */;
            }
            if ((origin == null ? void 0 : origin.kind) === 64 /* TypeOnlyAlias */) {
                return "TypeOnlyAlias/" /* TypeOnlyAlias */;
            }
        }
        function getCompletionEntriesFromSymbols(symbols, entries, replacementToken, contextToken, location, position, sourceFile, host, program, target, log, kind, preferences, compilerOptions, formatContext, isTypeOnlyLocation, propertyAccessToConvert, jsxIdentifierExpected, isJsxInitializer, importStatementCompletion, recommendedCompletion, symbolToOriginInfoMap, symbolToSortTextMap, isJsxIdentifierExpected, isRightOfOpenTag, includeSymbol = false) {
            var _a2;
            const start = timestamp();
            const variableDeclaration = getVariableDeclaration(location);
            const useSemicolons = probablyUsesSemicolons(sourceFile);
            const typeChecker = program.getTypeChecker();
            const uniques = /* @__PURE__ */ new Map();
            for (let i = 0; i < symbols.length; i++) {
                const symbol = symbols[i];
                const origin = symbolToOriginInfoMap == null ? void 0 : symbolToOriginInfoMap[i];
                const info = getCompletionEntryDisplayNameForSymbol(symbol, target, origin, kind, !!jsxIdentifierExpected);
                if (!info || uniques.get(info.name) && (!origin || !originIsObjectLiteralMethod(origin)) || kind === 1 /* Global */ && symbolToSortTextMap && !shouldIncludeSymbol(symbol, symbolToSortTextMap)) {
                    continue;
                }
                const { name, needsConvertPropertyAccess } = info;
                const originalSortText = (_a2 = symbolToSortTextMap == null ? void 0 : symbolToSortTextMap[getSymbolId(symbol)]) != null ? _a2 : SortText.LocationPriority;
                const sortText = isDeprecated(symbol, typeChecker) ? SortText.Deprecated(originalSortText) : originalSortText;
                const entry = createCompletionEntry(symbol, sortText, replacementToken, contextToken, location, position, sourceFile, host, program, name, needsConvertPropertyAccess, origin, recommendedCompletion, propertyAccessToConvert, isJsxInitializer, importStatementCompletion, useSemicolons, compilerOptions, preferences, kind, formatContext, isJsxIdentifierExpected, isRightOfOpenTag, includeSymbol);
                if (!entry) {
                    continue;
                }
                const shouldShadowLaterSymbols = (!origin || originIsTypeOnlyAlias(origin)) && !(symbol.parent === void 0 && !some(symbol.declarations, (d) => d.getSourceFile() === location.getSourceFile()));
                uniques.set(name, shouldShadowLaterSymbols);
                insertSorted(entries, entry, compareCompletionEntries, 
                /*allowDuplicates*/
                true);
            }
            log("getCompletionsAtPosition: getCompletionEntriesFromSymbols: " + (timestamp() - start));
            return {
                has: (name) => uniques.has(name),
                add: (name) => uniques.set(name, true)
            };
            function shouldIncludeSymbol(symbol, symbolToSortTextMap2) {
                let allFlags = symbol.flags;
                if (!isSourceFile(location)) {
                    if (isExportAssignment(location.parent)) {
                        return true;
                    }
                    if (variableDeclaration && symbol.valueDeclaration === variableDeclaration) {
                        return false;
                    }
                    const symbolOrigin = skipAlias(symbol, typeChecker);
                    if (!!sourceFile.externalModuleIndicator && !compilerOptions.allowUmdGlobalAccess && symbolToSortTextMap2[getSymbolId(symbol)] === SortText.GlobalsOrKeywords && (symbolToSortTextMap2[getSymbolId(symbolOrigin)] === SortText.AutoImportSuggestions || symbolToSortTextMap2[getSymbolId(symbolOrigin)] === SortText.LocationPriority)) {
                        return false;
                    }
                    allFlags |= getCombinedLocalAndExportSymbolFlags(symbolOrigin);
                    if (isInRightSideOfInternalImportEqualsDeclaration(location)) {
                        return !!(allFlags & 1920 /* Namespace */);
                    }
                    if (isTypeOnlyLocation) {
                        return symbolCanBeReferencedAtTypeLocation(symbol, typeChecker);
                    }
                }
                return !!(allFlags & 111551 /* Value */);
            }
        }
        function getLabelCompletionAtPosition(node) {
            const entries = getLabelStatementCompletions(node);
            if (entries.length) {
                return { isGlobalCompletion: false, isMemberCompletion: false, isNewIdentifierLocation: false, entries };
            }
        }
        function getLabelStatementCompletions(node) {
            const entries = [];
            const uniques = /* @__PURE__ */ new Map();
            let current = node;
            while (current) {
                if (isFunctionLike(current)) {
                    break;
                }
                if (isLabeledStatement(current)) {
                    const name = current.label.text;
                    if (!uniques.has(name)) {
                        uniques.set(name, true);
                        entries.push({
                            name,
                            kindModifiers: "" /* none */,
                            kind: "label" /* label */,
                            sortText: SortText.LocationPriority
                        });
                    }
                }
                current = current.parent;
            }
            return entries;
        }
        function getSymbolCompletionFromEntryId(program, log, sourceFile, position, entryId, host, preferences) {
            if (entryId.source === "SwitchCases/" /* SwitchCases */) {
                return { type: "cases" };
            }
            if (entryId.data) {
                const autoImport = getAutoImportSymbolFromCompletionEntryData(entryId.name, entryId.data, program, host);
                if (autoImport) {
                    const { contextToken: contextToken2, previousToken: previousToken2 } = getRelevantTokens(position, sourceFile);
                    return {
                        type: "symbol",
                        symbol: autoImport.symbol,
                        location: getTouchingPropertyName(sourceFile, position),
                        previousToken: previousToken2,
                        contextToken: contextToken2,
                        isJsxInitializer: false,
                        isTypeOnlyLocation: false,
                        origin: autoImport.origin
                    };
                }
            }
            const compilerOptions = program.getCompilerOptions();
            const completionData = getCompletionData(program, log, sourceFile, compilerOptions, position, { includeCompletionsForModuleExports: true, includeCompletionsWithInsertText: true }, entryId, host, 
            /*formatContext*/
            void 0);
            if (!completionData) {
                return { type: "none" };
            }
            if (completionData.kind !== 0 /* Data */) {
                return { type: "request", request: completionData };
            }
            const { symbols, literals, location, completionKind, symbolToOriginInfoMap, contextToken, previousToken, isJsxInitializer, isTypeOnlyLocation } = completionData;
            const literal = find(literals, (l) => completionNameForLiteral(sourceFile, preferences, l) === entryId.name);
            if (literal !== void 0)
                return { type: "literal", literal };
            return firstDefined(symbols, (symbol, index) => {
                const origin = symbolToOriginInfoMap[index];
                const info = getCompletionEntryDisplayNameForSymbol(symbol, getEmitScriptTarget(compilerOptions), origin, completionKind, completionData.isJsxIdentifierExpected);
                return info && info.name === entryId.name && (entryId.source === "ClassMemberSnippet/" /* ClassMemberSnippet */ && symbol.flags & 106500 /* ClassMember */ || entryId.source === "ObjectLiteralMethodSnippet/" /* ObjectLiteralMethodSnippet */ && symbol.flags & (4 /* Property */ | 8192 /* Method */) || getSourceFromOrigin(origin) === entryId.source) ? { type: "symbol", symbol, location, origin, contextToken, previousToken, isJsxInitializer, isTypeOnlyLocation } : void 0;
            }) || { type: "none" };
        }
        function getCompletionEntryDetails(program, log, sourceFile, position, entryId, host, formatContext, preferences, cancellationToken) {
            const typeChecker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            const { name, source, data } = entryId;
            const { previousToken, contextToken } = getRelevantTokens(position, sourceFile);
            if (isInString(sourceFile, position, previousToken)) {
                return ts_Completions_StringCompletions_exports.getStringLiteralCompletionDetails(name, sourceFile, position, previousToken, typeChecker, compilerOptions, host, cancellationToken, preferences);
            }
            const symbolCompletion = getSymbolCompletionFromEntryId(program, log, sourceFile, position, entryId, host, preferences);
            switch (symbolCompletion.type) {
                case "request": {
                    const { request } = symbolCompletion;
                    switch (request.kind) {
                        case 1 /* JsDocTagName */:
                            return ts_JsDoc_exports.getJSDocTagNameCompletionDetails(name);
                        case 2 /* JsDocTag */:
                            return ts_JsDoc_exports.getJSDocTagCompletionDetails(name);
                        case 3 /* JsDocParameterName */:
                            return ts_JsDoc_exports.getJSDocParameterNameCompletionDetails(name);
                        case 4 /* Keywords */:
                            return some(request.keywordCompletions, (c) => c.name === name) ? createSimpleDetails(name, "keyword" /* keyword */, 5 /* keyword */) : void 0;
                        default:
                            return Debug.assertNever(request);
                    }
                }
                case "symbol": {
                    const { symbol, location, contextToken: contextToken2, origin, previousToken: previousToken2 } = symbolCompletion;
                    const { codeActions, sourceDisplay } = getCompletionEntryCodeActionsAndSourceDisplay(name, location, contextToken2, origin, symbol, program, host, compilerOptions, sourceFile, position, previousToken2, formatContext, preferences, data, source, cancellationToken);
                    const symbolName2 = originIsComputedPropertyName(origin) ? origin.symbolName : symbol.name;
                    return createCompletionDetailsForSymbol(symbol, symbolName2, typeChecker, sourceFile, location, cancellationToken, codeActions, sourceDisplay);
                }
                case "literal": {
                    const { literal } = symbolCompletion;
                    return createSimpleDetails(completionNameForLiteral(sourceFile, preferences, literal), "string" /* string */, typeof literal === "string" ? 8 /* stringLiteral */ : 7 /* numericLiteral */);
                }
                case "cases": {
                    const { entry, importAdder } = getExhaustiveCaseSnippets(contextToken.parent, sourceFile, preferences, program.getCompilerOptions(), host, program, 
                    /*formatContext*/
                    void 0);
                    if (importAdder.hasFixes()) {
                        const changes = ts_textChanges_exports.ChangeTracker.with({ host, formatContext, preferences }, importAdder.writeFixes);
                        return {
                            name: entry.name,
                            kind: "" /* unknown */,
                            kindModifiers: "",
                            displayParts: [],
                            sourceDisplay: void 0,
                            codeActions: [{
                                    changes,
                                    description: diagnosticToString([Diagnostics.Includes_imports_of_types_referenced_by_0, name])
                                }]
                        };
                    }
                    return {
                        name: entry.name,
                        kind: "" /* unknown */,
                        kindModifiers: "",
                        displayParts: [],
                        sourceDisplay: void 0
                    };
                }
                case "none":
                    return allKeywordsCompletions().some((c) => c.name === name) ? createSimpleDetails(name, "keyword" /* keyword */, 5 /* keyword */) : void 0;
                default:
                    Debug.assertNever(symbolCompletion);
            }
        }
        function createSimpleDetails(name, kind, kind2) {
            return createCompletionDetails(name, "" /* none */, kind, [displayPart(name, kind2)]);
        }
        function createCompletionDetailsForSymbol(symbol, name, checker, sourceFile, location, cancellationToken, codeActions, sourceDisplay) {
            const { displayParts, documentation, symbolKind, tags } = checker.runWithCancellationToken(cancellationToken, (checker2) => ts_SymbolDisplay_exports.getSymbolDisplayPartsDocumentationAndSymbolKind(checker2, symbol, sourceFile, location, location, 7 /* All */));
            return createCompletionDetails(name, ts_SymbolDisplay_exports.getSymbolModifiers(checker, symbol), symbolKind, displayParts, documentation, tags, codeActions, sourceDisplay);
        }
        function createCompletionDetails(name, kindModifiers, kind, displayParts, documentation, tags, codeActions, source) {
            return { name, kindModifiers, kind, displayParts, documentation, tags, codeActions, source, sourceDisplay: source };
        }
        function getCompletionEntryCodeActionsAndSourceDisplay(name, location, contextToken, origin, symbol, program, host, compilerOptions, sourceFile, position, previousToken, formatContext, preferences, data, source, cancellationToken) {
            if (data == null ? void 0 : data.moduleSpecifier) {
                if (previousToken && getImportStatementCompletionInfo(contextToken || previousToken).replacementSpan) {
                    return { codeActions: void 0, sourceDisplay: [textPart(data.moduleSpecifier)] };
                }
            }
            if (source === "ClassMemberSnippet/" /* ClassMemberSnippet */) {
                const { importAdder } = getEntryForMemberCompletion(host, program, compilerOptions, preferences, name, symbol, location, position, contextToken, formatContext);
                if (importAdder) {
                    const changes = ts_textChanges_exports.ChangeTracker.with({ host, formatContext, preferences }, importAdder.writeFixes);
                    return {
                        sourceDisplay: void 0,
                        codeActions: [{
                                changes,
                                description: diagnosticToString([Diagnostics.Includes_imports_of_types_referenced_by_0, name])
                            }]
                    };
                }
            }
            if (originIsTypeOnlyAlias(origin)) {
                const codeAction2 = ts_codefix_exports.getPromoteTypeOnlyCompletionAction(sourceFile, origin.declaration.name, program, host, formatContext, preferences);
                Debug.assertIsDefined(codeAction2, "Expected to have a code action for promoting type-only alias");
                return { codeActions: [codeAction2], sourceDisplay: void 0 };
            }
            if (!origin || !(originIsExport(origin) || originIsResolvedExport(origin))) {
                return { codeActions: void 0, sourceDisplay: void 0 };
            }
            const checker = origin.isFromPackageJson ? host.getPackageJsonAutoImportProvider().getTypeChecker() : program.getTypeChecker();
            const { moduleSymbol } = origin;
            const targetSymbol = checker.getMergedSymbol(skipAlias(symbol.exportSymbol || symbol, checker));
            const isJsxOpeningTagName = (contextToken == null ? void 0 : contextToken.kind) === 29 /* LessThanToken */ && isJsxOpeningLikeElement(contextToken.parent);
            const { moduleSpecifier, codeAction } = ts_codefix_exports.getImportCompletionAction(targetSymbol, moduleSymbol, data == null ? void 0 : data.exportMapKey, sourceFile, name, isJsxOpeningTagName, host, program, formatContext, previousToken && isIdentifier(previousToken) ? previousToken.getStart(sourceFile) : position, preferences, cancellationToken);
            Debug.assert(!(data == null ? void 0 : data.moduleSpecifier) || moduleSpecifier === data.moduleSpecifier);
            return { sourceDisplay: [textPart(moduleSpecifier)], codeActions: [codeAction] };
        }
        function getCompletionEntrySymbol(program, log, sourceFile, position, entryId, host, preferences) {
            const completion = getSymbolCompletionFromEntryId(program, log, sourceFile, position, entryId, host, preferences);
            return completion.type === "symbol" ? completion.symbol : void 0;
        }
        function getRecommendedCompletion(previousToken, contextualType, checker) {
            return firstDefined(contextualType && (contextualType.isUnion() ? contextualType.types : [contextualType]), (type) => {
                const symbol = type && type.symbol;
                return symbol && (symbol.flags & (8 /* EnumMember */ | 384 /* Enum */ | 32 /* Class */) && !isAbstractConstructorSymbol(symbol)) ? getFirstSymbolInChain(symbol, previousToken, checker) : void 0;
            });
        }
        function getContextualType(previousToken, position, sourceFile, checker) {
            const { parent: parent2 } = previousToken;
            switch (previousToken.kind) {
                case 79 /* Identifier */:
                    return getContextualTypeFromParent(previousToken, checker);
                case 63 /* EqualsToken */:
                    switch (parent2.kind) {
                        case 257 /* VariableDeclaration */:
                            return checker.getContextualType(parent2.initializer);
                        case 223 /* BinaryExpression */:
                            return checker.getTypeAtLocation(parent2.left);
                        case 288 /* JsxAttribute */:
                            return checker.getContextualTypeForJsxAttribute(parent2);
                        default:
                            return void 0;
                    }
                case 103 /* NewKeyword */:
                    return checker.getContextualType(parent2);
                case 82 /* CaseKeyword */:
                    const caseClause = tryCast(parent2, isCaseClause);
                    return caseClause ? getSwitchedType(caseClause, checker) : void 0;
                case 18 /* OpenBraceToken */:
                    return isJsxExpression(parent2) && !isJsxElement(parent2.parent) && !isJsxFragment(parent2.parent) ? checker.getContextualTypeForJsxAttribute(parent2.parent) : void 0;
                default:
                    const argInfo = ts_SignatureHelp_exports.getArgumentInfoForCompletions(previousToken, position, sourceFile);
                    return argInfo ? (
                    // At `,`, treat this as the next argument after the comma.
                    checker.getContextualTypeForArgumentAtIndex(argInfo.invocation, argInfo.argumentIndex + (previousToken.kind === 27 /* CommaToken */ ? 1 : 0))) : isEqualityOperatorKind(previousToken.kind) && isBinaryExpression(parent2) && isEqualityOperatorKind(parent2.operatorToken.kind) ? (
                    // completion at `x ===/**/` should be for the right side
                    checker.getTypeAtLocation(parent2.left)) : checker.getContextualType(previousToken);
            }
        }
        function getFirstSymbolInChain(symbol, enclosingDeclaration, checker) {
            const chain = checker.getAccessibleSymbolChain(symbol, enclosingDeclaration, 
            /*meaning*/
            67108863 /* All */, 
            /*useOnlyExternalAliasing*/
            false);
            if (chain)
                return first(chain);
            return symbol.parent && (isModuleSymbol(symbol.parent) ? symbol : getFirstSymbolInChain(symbol.parent, enclosingDeclaration, checker));
        }
        function isModuleSymbol(symbol) {
            var _a2;
            return !!((_a2 = symbol.declarations) == null ? void 0 : _a2.some((d) => d.kind === 308 /* SourceFile */));
        }
        function getCompletionData(program, log, sourceFile, compilerOptions, position, preferences, detailsEntryId, host, formatContext, cancellationToken) {
            const typeChecker = program.getTypeChecker();
            const inCheckedFile = isCheckedFile(sourceFile, compilerOptions);
            let start = timestamp();
            let currentToken = getTokenAtPosition(sourceFile, position);
            log("getCompletionData: Get current token: " + (timestamp() - start));
            start = timestamp();
            const insideComment = isInComment(sourceFile, position, currentToken);
            log("getCompletionData: Is inside comment: " + (timestamp() - start));
            let insideJsDocTagTypeExpression = false;
            let isInSnippetScope = false;
            if (insideComment) {
                if (hasDocComment(sourceFile, position)) {
                    if (sourceFile.text.charCodeAt(position - 1) === 64 /* at */) {
                        return { kind: 1 /* JsDocTagName */ };
                    }
                    else {
                        const lineStart = getLineStartPositionForPosition(position, sourceFile);
                        if (!/[^\*|\s(/)]/.test(sourceFile.text.substring(lineStart, position))) {
                            return { kind: 2 /* JsDocTag */ };
                        }
                    }
                }
                const tag = getJsDocTagAtPosition(currentToken, position);
                if (tag) {
                    if (tag.tagName.pos <= position && position <= tag.tagName.end) {
                        return { kind: 1 /* JsDocTagName */ };
                    }
                    const typeExpression = tryGetTypeExpressionFromTag(tag);
                    if (typeExpression) {
                        currentToken = getTokenAtPosition(sourceFile, position);
                        if (!currentToken || !isDeclarationName(currentToken) && (currentToken.parent.kind !== 351 /* JSDocPropertyTag */ || currentToken.parent.name !== currentToken)) {
                            insideJsDocTagTypeExpression = isCurrentlyEditingNode(typeExpression);
                        }
                    }
                    if (!insideJsDocTagTypeExpression && isJSDocParameterTag(tag) && (nodeIsMissing(tag.name) || tag.name.pos <= position && position <= tag.name.end)) {
                        return { kind: 3 /* JsDocParameterName */, tag };
                    }
                }
                if (!insideJsDocTagTypeExpression) {
                    log("Returning an empty list because completion was inside a regular comment or plain text part of a JsDoc comment.");
                    return void 0;
                }
            }
            start = timestamp();
            const isJsOnlyLocation = !insideJsDocTagTypeExpression && isSourceFileJS(sourceFile);
            const tokens = getRelevantTokens(position, sourceFile);
            const previousToken = tokens.previousToken;
            let contextToken = tokens.contextToken;
            log("getCompletionData: Get previous token: " + (timestamp() - start));
            let node = currentToken;
            let propertyAccessToConvert;
            let isRightOfDot = false;
            let isRightOfQuestionDot = false;
            let isRightOfOpenTag = false;
            let isStartingCloseTag = false;
            let isJsxInitializer = false;
            let isJsxIdentifierExpected = false;
            let importStatementCompletion;
            let location = getTouchingPropertyName(sourceFile, position);
            let keywordFilters = 0 /* None */;
            let isNewIdentifierLocation = false;
            let flags = 0 /* None */;
            if (contextToken) {
                const importStatementCompletionInfo = getImportStatementCompletionInfo(contextToken);
                if (importStatementCompletionInfo.keywordCompletion) {
                    if (importStatementCompletionInfo.isKeywordOnlyCompletion) {
                        return {
                            kind: 4 /* Keywords */,
                            keywordCompletions: [keywordToCompletionEntry(importStatementCompletionInfo.keywordCompletion)],
                            isNewIdentifierLocation: importStatementCompletionInfo.isNewIdentifierLocation
                        };
                    }
                    keywordFilters = keywordFiltersFromSyntaxKind(importStatementCompletionInfo.keywordCompletion);
                }
                if (importStatementCompletionInfo.replacementSpan && preferences.includeCompletionsForImportStatements && preferences.includeCompletionsWithInsertText) {
                    flags |= 2 /* IsImportStatementCompletion */;
                    importStatementCompletion = importStatementCompletionInfo;
                    isNewIdentifierLocation = importStatementCompletionInfo.isNewIdentifierLocation;
                }
                if (!importStatementCompletionInfo.replacementSpan && isCompletionListBlocker(contextToken)) {
                    log("Returning an empty list because completion was requested in an invalid position.");
                    return keywordFilters ? keywordCompletionData(keywordFilters, isJsOnlyLocation, isNewIdentifierDefinitionLocation()) : void 0;
                }
                let parent2 = contextToken.parent;
                if (contextToken.kind === 24 /* DotToken */ || contextToken.kind === 28 /* QuestionDotToken */) {
                    isRightOfDot = contextToken.kind === 24 /* DotToken */;
                    isRightOfQuestionDot = contextToken.kind === 28 /* QuestionDotToken */;
                    switch (parent2.kind) {
                        case 208 /* PropertyAccessExpression */:
                            propertyAccessToConvert = parent2;
                            node = propertyAccessToConvert.expression;
                            const leftmostAccessExpression = getLeftmostAccessExpression(propertyAccessToConvert);
                            if (nodeIsMissing(leftmostAccessExpression) || (isCallExpression(node) || isFunctionLike(node)) && node.end === contextToken.pos && node.getChildCount(sourceFile) && last(node.getChildren(sourceFile)).kind !== 21 /* CloseParenToken */) {
                                return void 0;
                            }
                            break;
                        case 163 /* QualifiedName */:
                            node = parent2.left;
                            break;
                        case 264 /* ModuleDeclaration */:
                            node = parent2.name;
                            break;
                        case 202 /* ImportType */:
                            node = parent2;
                            break;
                        case 233 /* MetaProperty */:
                            node = parent2.getFirstToken(sourceFile);
                            Debug.assert(node.kind === 100 /* ImportKeyword */ || node.kind === 103 /* NewKeyword */);
                            break;
                        default:
                            return void 0;
                    }
                }
                else if (!importStatementCompletion) {
                    if (parent2 && parent2.kind === 208 /* PropertyAccessExpression */) {
                        contextToken = parent2;
                        parent2 = parent2.parent;
                    }
                    if (currentToken.parent === location) {
                        switch (currentToken.kind) {
                            case 31 /* GreaterThanToken */:
                                if (currentToken.parent.kind === 281 /* JsxElement */ || currentToken.parent.kind === 283 /* JsxOpeningElement */) {
                                    location = currentToken;
                                }
                                break;
                            case 43 /* SlashToken */:
                                if (currentToken.parent.kind === 282 /* JsxSelfClosingElement */) {
                                    location = currentToken;
                                }
                                break;
                        }
                    }
                    switch (parent2.kind) {
                        case 284 /* JsxClosingElement */:
                            if (contextToken.kind === 43 /* SlashToken */) {
                                isStartingCloseTag = true;
                                location = contextToken;
                            }
                            break;
                        case 223 /* BinaryExpression */:
                            if (!binaryExpressionMayBeOpenTag(parent2)) {
                                break;
                            }
                        case 282 /* JsxSelfClosingElement */:
                        case 281 /* JsxElement */:
                        case 283 /* JsxOpeningElement */:
                            isJsxIdentifierExpected = true;
                            if (contextToken.kind === 29 /* LessThanToken */) {
                                isRightOfOpenTag = true;
                                location = contextToken;
                            }
                            break;
                        case 291 /* JsxExpression */:
                        case 290 /* JsxSpreadAttribute */:
                            if (previousToken.kind === 19 /* CloseBraceToken */ || previousToken.kind === 79 /* Identifier */ && previousToken.parent.kind === 288 /* JsxAttribute */) {
                                isJsxIdentifierExpected = true;
                            }
                            break;
                        case 288 /* JsxAttribute */:
                            if (parent2.initializer === previousToken && previousToken.end < position) {
                                isJsxIdentifierExpected = true;
                                break;
                            }
                            switch (previousToken.kind) {
                                case 63 /* EqualsToken */:
                                    isJsxInitializer = true;
                                    break;
                                case 79 /* Identifier */:
                                    isJsxIdentifierExpected = true;
                                    if (parent2 !== previousToken.parent && !parent2.initializer && findChildOfKind(parent2, 63 /* EqualsToken */, sourceFile)) {
                                        isJsxInitializer = previousToken;
                                    }
                            }
                            break;
                    }
                }
            }
            const semanticStart = timestamp();
            let completionKind = 5 /* None */;
            let isNonContextualObjectLiteral = false;
            let hasUnresolvedAutoImports = false;
            let symbols = [];
            let importSpecifierResolver;
            const symbolToOriginInfoMap = [];
            const symbolToSortTextMap = [];
            const seenPropertySymbols = /* @__PURE__ */ new Map();
            const isTypeOnlyLocation = isTypeOnlyCompletion();
            const getModuleSpecifierResolutionHost = memoizeOne((isFromPackageJson) => {
                return createModuleSpecifierResolutionHost(isFromPackageJson ? host.getPackageJsonAutoImportProvider() : program, host);
            });
            if (isRightOfDot || isRightOfQuestionDot) {
                getTypeScriptMemberSymbols();
            }
            else if (isRightOfOpenTag) {
                symbols = typeChecker.getJsxIntrinsicTagNamesAt(location);
                Debug.assertEachIsDefined(symbols, "getJsxIntrinsicTagNames() should all be defined");
                tryGetGlobalSymbols();
                completionKind = 1 /* Global */;
                keywordFilters = 0 /* None */;
            }
            else if (isStartingCloseTag) {
                const tagName = contextToken.parent.parent.openingElement.tagName;
                const tagSymbol = typeChecker.getSymbolAtLocation(tagName);
                if (tagSymbol) {
                    symbols = [tagSymbol];
                }
                completionKind = 1 /* Global */;
                keywordFilters = 0 /* None */;
            }
            else {
                if (!tryGetGlobalSymbols()) {
                    return keywordFilters ? keywordCompletionData(keywordFilters, isJsOnlyLocation, isNewIdentifierLocation) : void 0;
                }
            }
            log("getCompletionData: Semantic work: " + (timestamp() - semanticStart));
            const contextualType = previousToken && getContextualType(previousToken, position, sourceFile, typeChecker);
            const literals = mapDefined(contextualType && (contextualType.isUnion() ? contextualType.types : [contextualType]), (t) => t.isLiteral() && !(t.flags & 1024 /* EnumLiteral */) ? t.value : void 0);
            const recommendedCompletion = previousToken && contextualType && getRecommendedCompletion(previousToken, contextualType, typeChecker);
            return {
                kind: 0 /* Data */,
                symbols,
                completionKind,
                isInSnippetScope,
                propertyAccessToConvert,
                isNewIdentifierLocation,
                location,
                keywordFilters,
                literals,
                symbolToOriginInfoMap,
                recommendedCompletion,
                previousToken,
                contextToken,
                isJsxInitializer,
                insideJsDocTagTypeExpression,
                symbolToSortTextMap,
                isTypeOnlyLocation,
                isJsxIdentifierExpected,
                isRightOfOpenTag,
                isRightOfDotOrQuestionDot: isRightOfDot || isRightOfQuestionDot,
                importStatementCompletion,
                hasUnresolvedAutoImports,
                flags
            };
            function isTagWithTypeExpression(tag) {
                switch (tag.kind) {
                    case 344 /* JSDocParameterTag */:
                    case 351 /* JSDocPropertyTag */:
                    case 345 /* JSDocReturnTag */:
                    case 347 /* JSDocTypeTag */:
                    case 349 /* JSDocTypedefTag */:
                    case 352 /* JSDocThrowsTag */:
                    case 353 /* JSDocSatisfiesTag */:
                        return true;
                    case 348 /* JSDocTemplateTag */:
                        return !!tag.constraint;
                    default:
                        return false;
                }
            }
            function tryGetTypeExpressionFromTag(tag) {
                if (isTagWithTypeExpression(tag)) {
                    const typeExpression = isJSDocTemplateTag(tag) ? tag.constraint : tag.typeExpression;
                    return typeExpression && typeExpression.kind === 312 /* JSDocTypeExpression */ ? typeExpression : void 0;
                }
                if (isJSDocAugmentsTag(tag) || isJSDocImplementsTag(tag)) {
                    return tag.class;
                }
                return void 0;
            }
            function getTypeScriptMemberSymbols() {
                completionKind = 2 /* PropertyAccess */;
                const isImportType = isLiteralImportTypeNode(node);
                const isTypeLocation = insideJsDocTagTypeExpression || isImportType && !node.isTypeOf || isPartOfTypeNode(node.parent) || isPossiblyTypeArgumentPosition(contextToken, sourceFile, typeChecker);
                const isRhsOfImportDeclaration = isInRightSideOfInternalImportEqualsDeclaration(node);
                if (isEntityName(node) || isImportType || isPropertyAccessExpression(node)) {
                    const isNamespaceName = isModuleDeclaration(node.parent);
                    if (isNamespaceName)
                        isNewIdentifierLocation = true;
                    let symbol = typeChecker.getSymbolAtLocation(node);
                    if (symbol) {
                        symbol = skipAlias(symbol, typeChecker);
                        if (symbol.flags & (1536 /* Module */ | 384 /* Enum */)) {
                            const exportedSymbols = typeChecker.getExportsOfModule(symbol);
                            Debug.assertEachIsDefined(exportedSymbols, "getExportsOfModule() should all be defined");
                            const isValidValueAccess = (symbol2) => typeChecker.isValidPropertyAccess(isImportType ? node : node.parent, symbol2.name);
                            const isValidTypeAccess = (symbol2) => symbolCanBeReferencedAtTypeLocation(symbol2, typeChecker);
                            const isValidAccess = isNamespaceName ? (symbol2) => {
                                var _a2;
                                return !!(symbol2.flags & 1920 /* Namespace */) && !((_a2 = symbol2.declarations) == null ? void 0 : _a2.every((d) => d.parent === node.parent));
                            } : isRhsOfImportDeclaration ? (
                            // Any kind is allowed when dotting off namespace in internal import equals declaration
                            (symbol2) => isValidTypeAccess(symbol2) || isValidValueAccess(symbol2)) : isTypeLocation ? isValidTypeAccess : isValidValueAccess;
                            for (const exportedSymbol of exportedSymbols) {
                                if (isValidAccess(exportedSymbol)) {
                                    symbols.push(exportedSymbol);
                                }
                            }
                            if (!isTypeLocation && symbol.declarations && symbol.declarations.some((d) => d.kind !== 308 /* SourceFile */ && d.kind !== 264 /* ModuleDeclaration */ && d.kind !== 263 /* EnumDeclaration */)) {
                                let type = typeChecker.getTypeOfSymbolAtLocation(symbol, node).getNonOptionalType();
                                let insertQuestionDot = false;
                                if (type.isNullableType()) {
                                    const canCorrectToQuestionDot = isRightOfDot && !isRightOfQuestionDot && preferences.includeAutomaticOptionalChainCompletions !== false;
                                    if (canCorrectToQuestionDot || isRightOfQuestionDot) {
                                        type = type.getNonNullableType();
                                        if (canCorrectToQuestionDot) {
                                            insertQuestionDot = true;
                                        }
                                    }
                                }
                                addTypeProperties(type, !!(node.flags & 32768 /* AwaitContext */), insertQuestionDot);
                            }
                            return;
                        }
                    }
                }
                if (!isTypeLocation) {
                    typeChecker.tryGetThisTypeAt(node, 
                    /*includeGlobalThis*/
                    false);
                    let type = typeChecker.getTypeAtLocation(node).getNonOptionalType();
                    let insertQuestionDot = false;
                    if (type.isNullableType()) {
                        const canCorrectToQuestionDot = isRightOfDot && !isRightOfQuestionDot && preferences.includeAutomaticOptionalChainCompletions !== false;
                        if (canCorrectToQuestionDot || isRightOfQuestionDot) {
                            type = type.getNonNullableType();
                            if (canCorrectToQuestionDot) {
                                insertQuestionDot = true;
                            }
                        }
                    }
                    addTypeProperties(type, !!(node.flags & 32768 /* AwaitContext */), insertQuestionDot);
                }
            }
            function addTypeProperties(type, insertAwait, insertQuestionDot) {
                isNewIdentifierLocation = !!type.getStringIndexType();
                if (isRightOfQuestionDot && some(type.getCallSignatures())) {
                    isNewIdentifierLocation = true;
                }
                const propertyAccess = node.kind === 202 /* ImportType */ ? node : node.parent;
                if (inCheckedFile) {
                    for (const symbol of type.getApparentProperties()) {
                        if (typeChecker.isValidPropertyAccessForCompletions(propertyAccess, type, symbol)) {
                            addPropertySymbol(symbol, 
                            /* insertAwait */
                            false, insertQuestionDot);
                        }
                    }
                }
                else {
                    symbols.push(...filter(getPropertiesForCompletion(type, typeChecker), (s) => typeChecker.isValidPropertyAccessForCompletions(propertyAccess, type, s)));
                }
                if (insertAwait && preferences.includeCompletionsWithInsertText) {
                    const promiseType = typeChecker.getPromisedTypeOfPromise(type);
                    if (promiseType) {
                        for (const symbol of promiseType.getApparentProperties()) {
                            if (typeChecker.isValidPropertyAccessForCompletions(propertyAccess, promiseType, symbol)) {
                                addPropertySymbol(symbol, 
                                /* insertAwait */
                                true, insertQuestionDot);
                            }
                        }
                    }
                }
            }
            function addPropertySymbol(symbol, insertAwait, insertQuestionDot) {
                var _a2;
                const computedPropertyName = firstDefined(symbol.declarations, (decl) => tryCast(getNameOfDeclaration(decl), isComputedPropertyName));
                if (computedPropertyName) {
                    const leftMostName = getLeftMostName(computedPropertyName.expression);
                    const nameSymbol = leftMostName && typeChecker.getSymbolAtLocation(leftMostName);
                    const firstAccessibleSymbol = nameSymbol && getFirstSymbolInChain(nameSymbol, contextToken, typeChecker);
                    if (firstAccessibleSymbol && addToSeen(seenPropertySymbols, getSymbolId(firstAccessibleSymbol))) {
                        const index = symbols.length;
                        symbols.push(firstAccessibleSymbol);
                        const moduleSymbol = firstAccessibleSymbol.parent;
                        if (!moduleSymbol || !isExternalModuleSymbol(moduleSymbol) || typeChecker.tryGetMemberInModuleExportsAndProperties(firstAccessibleSymbol.name, moduleSymbol) !== firstAccessibleSymbol) {
                            symbolToOriginInfoMap[index] = { kind: getNullableSymbolOriginInfoKind(2 /* SymbolMemberNoExport */) };
                        }
                        else {
                            const fileName = isExternalModuleNameRelative(stripQuotes(moduleSymbol.name)) ? (_a2 = getSourceFileOfModule(moduleSymbol)) == null ? void 0 : _a2.fileName : void 0;
                            const { moduleSpecifier } = (importSpecifierResolver || (importSpecifierResolver = ts_codefix_exports.createImportSpecifierResolver(sourceFile, program, host, preferences))).getModuleSpecifierForBestExportInfo([{
                                    exportKind: 0 /* Named */,
                                    moduleFileName: fileName,
                                    isFromPackageJson: false,
                                    moduleSymbol,
                                    symbol: firstAccessibleSymbol,
                                    targetFlags: skipAlias(firstAccessibleSymbol, typeChecker).flags
                                }], position, isValidTypeOnlyAliasUseSite(location)) || {};
                            if (moduleSpecifier) {
                                const origin = {
                                    kind: getNullableSymbolOriginInfoKind(6 /* SymbolMemberExport */),
                                    moduleSymbol,
                                    isDefaultExport: false,
                                    symbolName: firstAccessibleSymbol.name,
                                    exportName: firstAccessibleSymbol.name,
                                    fileName,
                                    moduleSpecifier
                                };
                                symbolToOriginInfoMap[index] = origin;
                            }
                        }
                    }
                    else if (preferences.includeCompletionsWithInsertText) {
                        addSymbolOriginInfo(symbol);
                        addSymbolSortInfo(symbol);
                        symbols.push(symbol);
                    }
                }
                else {
                    addSymbolOriginInfo(symbol);
                    addSymbolSortInfo(symbol);
                    symbols.push(symbol);
                }
                function addSymbolSortInfo(symbol2) {
                    if (isStaticProperty(symbol2)) {
                        symbolToSortTextMap[getSymbolId(symbol2)] = SortText.LocalDeclarationPriority;
                    }
                }
                function addSymbolOriginInfo(symbol2) {
                    if (preferences.includeCompletionsWithInsertText) {
                        if (insertAwait && addToSeen(seenPropertySymbols, getSymbolId(symbol2))) {
                            symbolToOriginInfoMap[symbols.length] = { kind: getNullableSymbolOriginInfoKind(8 /* Promise */) };
                        }
                        else if (insertQuestionDot) {
                            symbolToOriginInfoMap[symbols.length] = { kind: 16 /* Nullable */ };
                        }
                    }
                }
                function getNullableSymbolOriginInfoKind(kind) {
                    return insertQuestionDot ? kind | 16 /* Nullable */ : kind;
                }
            }
            function getLeftMostName(e) {
                return isIdentifier(e) ? e : isPropertyAccessExpression(e) ? getLeftMostName(e.expression) : void 0;
            }
            function tryGetGlobalSymbols() {
                const result = tryGetObjectTypeLiteralInTypeArgumentCompletionSymbols() || tryGetObjectLikeCompletionSymbols() || tryGetImportCompletionSymbols() || tryGetImportOrExportClauseCompletionSymbols() || tryGetLocalNamedExportCompletionSymbols() || tryGetConstructorCompletion() || tryGetClassLikeCompletionSymbols() || tryGetJsxCompletionSymbols() || (getGlobalCompletions(), 1 /* Success */);
                return result === 1 /* Success */;
            }
            function tryGetConstructorCompletion() {
                if (!tryGetConstructorLikeCompletionContainer(contextToken))
                    return 0 /* Continue */;
                completionKind = 5 /* None */;
                isNewIdentifierLocation = true;
                keywordFilters = 4 /* ConstructorParameterKeywords */;
                return 1 /* Success */;
            }
            function tryGetJsxCompletionSymbols() {
                const jsxContainer = tryGetContainingJsxElement(contextToken);
                const attrsType = jsxContainer && typeChecker.getContextualType(jsxContainer.attributes);
                if (!attrsType)
                    return 0 /* Continue */;
                const completionsType = jsxContainer && typeChecker.getContextualType(jsxContainer.attributes, 4 /* Completions */);
                symbols = concatenate(symbols, filterJsxAttributes(getPropertiesForObjectExpression(attrsType, completionsType, jsxContainer.attributes, typeChecker), jsxContainer.attributes.properties));
                setSortTextToOptionalMember();
                completionKind = 3 /* MemberLike */;
                isNewIdentifierLocation = false;
                return 1 /* Success */;
            }
            function tryGetImportCompletionSymbols() {
                if (!importStatementCompletion)
                    return 0 /* Continue */;
                isNewIdentifierLocation = true;
                collectAutoImports();
                return 1 /* Success */;
            }
            function getGlobalCompletions() {
                keywordFilters = tryGetFunctionLikeBodyCompletionContainer(contextToken) ? 5 /* FunctionLikeBodyKeywords */ : 1 /* All */;
                completionKind = 1 /* Global */;
                isNewIdentifierLocation = isNewIdentifierDefinitionLocation();
                if (previousToken !== contextToken) {
                    Debug.assert(!!previousToken, "Expected 'contextToken' to be defined when different from 'previousToken'.");
                }
                const adjustedPosition = previousToken !== contextToken ? previousToken.getStart() : position;
                const scopeNode = getScopeNode(contextToken, adjustedPosition, sourceFile) || sourceFile;
                isInSnippetScope = isSnippetScope(scopeNode);
                const symbolMeanings = (isTypeOnlyLocation ? 0 /* None */ : 111551 /* Value */) | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */;
                const typeOnlyAliasNeedsPromotion = previousToken && !isValidTypeOnlyAliasUseSite(previousToken);
                symbols = concatenate(symbols, typeChecker.getSymbolsInScope(scopeNode, symbolMeanings));
                Debug.assertEachIsDefined(symbols, "getSymbolsInScope() should all be defined");
                for (let i = 0; i < symbols.length; i++) {
                    const symbol = symbols[i];
                    if (!typeChecker.isArgumentsSymbol(symbol) && !some(symbol.declarations, (d) => d.getSourceFile() === sourceFile)) {
                        symbolToSortTextMap[getSymbolId(symbol)] = SortText.GlobalsOrKeywords;
                    }
                    if (typeOnlyAliasNeedsPromotion && !(symbol.flags & 111551 /* Value */)) {
                        const typeOnlyAliasDeclaration = symbol.declarations && find(symbol.declarations, isTypeOnlyImportDeclaration);
                        if (typeOnlyAliasDeclaration) {
                            const origin = { kind: 64 /* TypeOnlyAlias */, declaration: typeOnlyAliasDeclaration };
                            symbolToOriginInfoMap[i] = origin;
                        }
                    }
                }
                if (preferences.includeCompletionsWithInsertText && scopeNode.kind !== 308 /* SourceFile */) {
                    const thisType = typeChecker.tryGetThisTypeAt(scopeNode, 
                    /*includeGlobalThis*/
                    false, isClassLike(scopeNode.parent) ? scopeNode : void 0);
                    if (thisType && !isProbablyGlobalType(thisType, sourceFile, typeChecker)) {
                        for (const symbol of getPropertiesForCompletion(thisType, typeChecker)) {
                            symbolToOriginInfoMap[symbols.length] = { kind: 1 /* ThisType */ };
                            symbols.push(symbol);
                            symbolToSortTextMap[getSymbolId(symbol)] = SortText.SuggestedClassMembers;
                        }
                    }
                }
                collectAutoImports();
                if (isTypeOnlyLocation) {
                    keywordFilters = contextToken && isAssertionExpression(contextToken.parent) ? 6 /* TypeAssertionKeywords */ : 7 /* TypeKeywords */;
                }
            }
            function shouldOfferImportCompletions() {
                if (importStatementCompletion)
                    return true;
                if (isNonContextualObjectLiteral)
                    return false;
                if (!preferences.includeCompletionsForModuleExports)
                    return false;
                if (sourceFile.externalModuleIndicator || sourceFile.commonJsModuleIndicator)
                    return true;
                if (compilerOptionsIndicateEsModules(program.getCompilerOptions()))
                    return true;
                return programContainsModules(program);
            }
            function isSnippetScope(scopeNode) {
                switch (scopeNode.kind) {
                    case 308 /* SourceFile */:
                    case 225 /* TemplateExpression */:
                    case 291 /* JsxExpression */:
                    case 238 /* Block */:
                        return true;
                    default:
                        return isStatement(scopeNode);
                }
            }
            function isTypeOnlyCompletion() {
                return insideJsDocTagTypeExpression || !!importStatementCompletion && isTypeOnlyImportOrExportDeclaration(location.parent) || !isContextTokenValueLocation(contextToken) && (isPossiblyTypeArgumentPosition(contextToken, sourceFile, typeChecker) || isPartOfTypeNode(location) || isContextTokenTypeLocation(contextToken));
            }
            function isContextTokenValueLocation(contextToken2) {
                return contextToken2 && (contextToken2.kind === 112 /* TypeOfKeyword */ && (contextToken2.parent.kind === 183 /* TypeQuery */ || isTypeOfExpression(contextToken2.parent)) || contextToken2.kind === 129 /* AssertsKeyword */ && contextToken2.parent.kind === 179 /* TypePredicate */);
            }
            function isContextTokenTypeLocation(contextToken2) {
                if (contextToken2) {
                    const parentKind = contextToken2.parent.kind;
                    switch (contextToken2.kind) {
                        case 58 /* ColonToken */:
                            return parentKind === 169 /* PropertyDeclaration */ || parentKind === 168 /* PropertySignature */ || parentKind === 166 /* Parameter */ || parentKind === 257 /* VariableDeclaration */ || isFunctionLikeKind(parentKind);
                        case 63 /* EqualsToken */:
                            return parentKind === 262 /* TypeAliasDeclaration */;
                        case 128 /* AsKeyword */:
                            return parentKind === 231 /* AsExpression */;
                        case 29 /* LessThanToken */:
                            return parentKind === 180 /* TypeReference */ || parentKind === 213 /* TypeAssertionExpression */;
                        case 94 /* ExtendsKeyword */:
                            return parentKind === 165 /* TypeParameter */;
                        case 150 /* SatisfiesKeyword */:
                            return parentKind === 235 /* SatisfiesExpression */;
                    }
                }
                return false;
            }
            function collectAutoImports() {
                var _a2, _b;
                if (!shouldOfferImportCompletions())
                    return;
                Debug.assert(!(detailsEntryId == null ? void 0 : detailsEntryId.data), "Should not run 'collectAutoImports' when faster path is available via `data`");
                if (detailsEntryId && !detailsEntryId.source) {
                    return;
                }
                flags |= 1 /* MayIncludeAutoImports */;
                const isAfterTypeOnlyImportSpecifierModifier = previousToken === contextToken && importStatementCompletion;
                const lowerCaseTokenText = isAfterTypeOnlyImportSpecifierModifier ? "" : previousToken && isIdentifier(previousToken) ? previousToken.text.toLowerCase() : "";
                const moduleSpecifierCache = (_a2 = host.getModuleSpecifierCache) == null ? void 0 : _a2.call(host);
                const exportInfo = getExportInfoMap(sourceFile, host, program, preferences, cancellationToken);
                const packageJsonAutoImportProvider = (_b = host.getPackageJsonAutoImportProvider) == null ? void 0 : _b.call(host);
                const packageJsonFilter = detailsEntryId ? void 0 : createPackageJsonImportFilter(sourceFile, preferences, host);
                resolvingModuleSpecifiers("collectAutoImports", host, importSpecifierResolver || (importSpecifierResolver = ts_codefix_exports.createImportSpecifierResolver(sourceFile, program, host, preferences)), program, position, preferences, !!importStatementCompletion, isValidTypeOnlyAliasUseSite(location), (context) => {
                    exportInfo.search(sourceFile.path, 
                    /*preferCapitalized*/
                    isRightOfOpenTag, (symbolName2, targetFlags) => {
                        if (!isIdentifierText(symbolName2, getEmitScriptTarget(host.getCompilationSettings())))
                            return false;
                        if (!detailsEntryId && isStringANonContextualKeyword(symbolName2))
                            return false;
                        if (!isTypeOnlyLocation && !importStatementCompletion && !(targetFlags & 111551 /* Value */))
                            return false;
                        if (isTypeOnlyLocation && !(targetFlags & (1536 /* Module */ | 788968 /* Type */)))
                            return false;
                        const firstChar = symbolName2.charCodeAt(0);
                        if (isRightOfOpenTag && (firstChar < 65 /* A */ || firstChar > 90 /* Z */))
                            return false;
                        if (detailsEntryId)
                            return true;
                        return charactersFuzzyMatchInString(symbolName2, lowerCaseTokenText);
                    }, (info, symbolName2, isFromAmbientModule, exportMapKey) => {
                        if (detailsEntryId && !some(info, (i) => detailsEntryId.source === stripQuotes(i.moduleSymbol.name))) {
                            return;
                        }
                        info = filter(info, isImportableExportInfo);
                        if (!info.length) {
                            return;
                        }
                        const result = context.tryResolve(info, isFromAmbientModule) || {};
                        if (result === "failed")
                            return;
                        let exportInfo2 = info[0], moduleSpecifier;
                        if (result !== "skipped") {
                            ({ exportInfo: exportInfo2 = info[0], moduleSpecifier } = result);
                        }
                        const isDefaultExport = exportInfo2.exportKind === 1 /* Default */;
                        const symbol = isDefaultExport && getLocalSymbolForExportDefault(exportInfo2.symbol) || exportInfo2.symbol;
                        pushAutoImportSymbol(symbol, {
                            kind: moduleSpecifier ? 32 /* ResolvedExport */ : 4 /* Export */,
                            moduleSpecifier,
                            symbolName: symbolName2,
                            exportMapKey,
                            exportName: exportInfo2.exportKind === 2 /* ExportEquals */ ? "export=" /* ExportEquals */ : exportInfo2.symbol.name,
                            fileName: exportInfo2.moduleFileName,
                            isDefaultExport,
                            moduleSymbol: exportInfo2.moduleSymbol,
                            isFromPackageJson: exportInfo2.isFromPackageJson
                        });
                    });
                    hasUnresolvedAutoImports = context.skippedAny();
                    flags |= context.resolvedAny() ? 8 /* ResolvedModuleSpecifiers */ : 0;
                    flags |= context.resolvedBeyondLimit() ? 16 /* ResolvedModuleSpecifiersBeyondLimit */ : 0;
                });
                function isImportableExportInfo(info) {
                    const moduleFile = tryCast(info.moduleSymbol.valueDeclaration, isSourceFile);
                    if (!moduleFile) {
                        const moduleName = stripQuotes(info.moduleSymbol.name);
                        if (ts_JsTyping_exports.nodeCoreModules.has(moduleName) && startsWith(moduleName, "node:") !== shouldUseUriStyleNodeCoreModules(sourceFile, program)) {
                            return false;
                        }
                        return packageJsonFilter ? packageJsonFilter.allowsImportingAmbientModule(info.moduleSymbol, getModuleSpecifierResolutionHost(info.isFromPackageJson)) : true;
                    }
                    return isImportableFile(info.isFromPackageJson ? packageJsonAutoImportProvider : program, sourceFile, moduleFile, preferences, packageJsonFilter, getModuleSpecifierResolutionHost(info.isFromPackageJson), moduleSpecifierCache);
                }
            }
            function pushAutoImportSymbol(symbol, origin) {
                const symbolId = getSymbolId(symbol);
                if (symbolToSortTextMap[symbolId] === SortText.GlobalsOrKeywords) {
                    return;
                }
                symbolToOriginInfoMap[symbols.length] = origin;
                symbolToSortTextMap[symbolId] = importStatementCompletion ? SortText.LocationPriority : SortText.AutoImportSuggestions;
                symbols.push(symbol);
            }
            function collectObjectLiteralMethodSymbols(members, enclosingDeclaration) {
                if (isInJSFile(location)) {
                    return;
                }
                members.forEach((member) => {
                    if (!isObjectLiteralMethodSymbol(member)) {
                        return;
                    }
                    const displayName = getCompletionEntryDisplayNameForSymbol(member, getEmitScriptTarget(compilerOptions), 
                    /*origin*/
                    void 0, 0 /* ObjectPropertyDeclaration */, 
                    /*jsxIdentifierExpected*/
                    false);
                    if (!displayName) {
                        return;
                    }
                    const { name } = displayName;
                    const entryProps = getEntryForObjectLiteralMethodCompletion(member, name, enclosingDeclaration, program, host, compilerOptions, preferences, formatContext);
                    if (!entryProps) {
                        return;
                    }
                    const origin = { kind: 128 /* ObjectLiteralMethod */, ...entryProps };
                    flags |= 32 /* MayIncludeMethodSnippets */;
                    symbolToOriginInfoMap[symbols.length] = origin;
                    symbols.push(member);
                });
            }
            function isObjectLiteralMethodSymbol(symbol) {
                if (!(symbol.flags & (4 /* Property */ | 8192 /* Method */))) {
                    return false;
                }
                return true;
            }
            function getScopeNode(initialToken, position2, sourceFile2) {
                let scope = initialToken;
                while (scope && !positionBelongsToNode(scope, position2, sourceFile2)) {
                    scope = scope.parent;
                }
                return scope;
            }
            function isCompletionListBlocker(contextToken2) {
                const start2 = timestamp();
                const result = isInStringOrRegularExpressionOrTemplateLiteral(contextToken2) || isSolelyIdentifierDefinitionLocation(contextToken2) || isDotOfNumericLiteral(contextToken2) || isInJsxText(contextToken2) || isBigIntLiteral(contextToken2);
                log("getCompletionsAtPosition: isCompletionListBlocker: " + (timestamp() - start2));
                return result;
            }
            function isInJsxText(contextToken2) {
                if (contextToken2.kind === 11 /* JsxText */) {
                    return true;
                }
                if (contextToken2.kind === 31 /* GreaterThanToken */ && contextToken2.parent) {
                    if (location === contextToken2.parent && (location.kind === 283 /* JsxOpeningElement */ || location.kind === 282 /* JsxSelfClosingElement */)) {
                        return false;
                    }
                    if (contextToken2.parent.kind === 283 /* JsxOpeningElement */) {
                        return location.parent.kind !== 283 /* JsxOpeningElement */;
                    }
                    if (contextToken2.parent.kind === 284 /* JsxClosingElement */ || contextToken2.parent.kind === 282 /* JsxSelfClosingElement */) {
                        return !!contextToken2.parent.parent && contextToken2.parent.parent.kind === 281 /* JsxElement */;
                    }
                }
                return false;
            }
            function isNewIdentifierDefinitionLocation() {
                if (contextToken) {
                    const containingNodeKind = contextToken.parent.kind;
                    const tokenKind = keywordForNode(contextToken);
                    switch (tokenKind) {
                        case 27 /* CommaToken */:
                            return containingNodeKind === 210 /* CallExpression */ || containingNodeKind === 173 /* Constructor */ || containingNodeKind === 211 /* NewExpression */ || containingNodeKind === 206 /* ArrayLiteralExpression */ || containingNodeKind === 223 /* BinaryExpression */ || containingNodeKind === 181 /* FunctionType */ || containingNodeKind === 207 /* ObjectLiteralExpression */;
                        case 20 /* OpenParenToken */:
                            return containingNodeKind === 210 /* CallExpression */ || containingNodeKind === 173 /* Constructor */ || containingNodeKind === 211 /* NewExpression */ || containingNodeKind === 214 /* ParenthesizedExpression */ || containingNodeKind === 193 /* ParenthesizedType */;
                        case 22 /* OpenBracketToken */:
                            return containingNodeKind === 206 /* ArrayLiteralExpression */ || containingNodeKind === 178 /* IndexSignature */ || containingNodeKind === 164 /* ComputedPropertyName */;
                        case 142 /* ModuleKeyword */:
                        case 143 /* NamespaceKeyword */:
                        case 100 /* ImportKeyword */:
                            return true;
                        case 24 /* DotToken */:
                            return containingNodeKind === 264 /* ModuleDeclaration */;
                        case 18 /* OpenBraceToken */:
                            return containingNodeKind === 260 /* ClassDeclaration */ || containingNodeKind === 207 /* ObjectLiteralExpression */;
                        case 63 /* EqualsToken */:
                            return containingNodeKind === 257 /* VariableDeclaration */ || containingNodeKind === 223 /* BinaryExpression */;
                        case 15 /* TemplateHead */:
                            return containingNodeKind === 225 /* TemplateExpression */;
                        case 16 /* TemplateMiddle */:
                            return containingNodeKind === 236 /* TemplateSpan */;
                        case 132 /* AsyncKeyword */:
                            return containingNodeKind === 171 /* MethodDeclaration */ || containingNodeKind === 300 /* ShorthandPropertyAssignment */;
                        case 41 /* AsteriskToken */:
                            return containingNodeKind === 171 /* MethodDeclaration */;
                    }
                    if (isClassMemberCompletionKeyword(tokenKind)) {
                        return true;
                    }
                }
                return false;
            }
            function isInStringOrRegularExpressionOrTemplateLiteral(contextToken2) {
                return (isRegularExpressionLiteral(contextToken2) || isStringTextContainingNode(contextToken2)) && (rangeContainsPositionExclusive(contextToken2, position) || position === contextToken2.end && (!!contextToken2.isUnterminated || isRegularExpressionLiteral(contextToken2)));
            }
            function tryGetObjectTypeLiteralInTypeArgumentCompletionSymbols() {
                const typeLiteralNode = tryGetTypeLiteralNode(contextToken);
                if (!typeLiteralNode)
                    return 0 /* Continue */;
                const intersectionTypeNode = isIntersectionTypeNode(typeLiteralNode.parent) ? typeLiteralNode.parent : void 0;
                const containerTypeNode = intersectionTypeNode || typeLiteralNode;
                const containerExpectedType = getConstraintOfTypeArgumentProperty(containerTypeNode, typeChecker);
                if (!containerExpectedType)
                    return 0 /* Continue */;
                const containerActualType = typeChecker.getTypeFromTypeNode(containerTypeNode);
                const members = getPropertiesForCompletion(containerExpectedType, typeChecker);
                const existingMembers = getPropertiesForCompletion(containerActualType, typeChecker);
                const existingMemberEscapedNames = /* @__PURE__ */ new Set();
                existingMembers.forEach((s) => existingMemberEscapedNames.add(s.escapedName));
                symbols = concatenate(symbols, filter(members, (s) => !existingMemberEscapedNames.has(s.escapedName)));
                completionKind = 0 /* ObjectPropertyDeclaration */;
                isNewIdentifierLocation = true;
                return 1 /* Success */;
            }
            function tryGetObjectLikeCompletionSymbols() {
                const symbolsStartIndex = symbols.length;
                const objectLikeContainer = tryGetObjectLikeCompletionContainer(contextToken);
                if (!objectLikeContainer)
                    return 0 /* Continue */;
                completionKind = 0 /* ObjectPropertyDeclaration */;
                let typeMembers;
                let existingMembers;
                if (objectLikeContainer.kind === 207 /* ObjectLiteralExpression */) {
                    const instantiatedType = tryGetObjectLiteralContextualType(objectLikeContainer, typeChecker);
                    if (instantiatedType === void 0) {
                        if (objectLikeContainer.flags & 33554432 /* InWithStatement */) {
                            return 2 /* Fail */;
                        }
                        isNonContextualObjectLiteral = true;
                        return 0 /* Continue */;
                    }
                    const completionsType = typeChecker.getContextualType(objectLikeContainer, 4 /* Completions */);
                    const hasStringIndexType = (completionsType || instantiatedType).getStringIndexType();
                    const hasNumberIndextype = (completionsType || instantiatedType).getNumberIndexType();
                    isNewIdentifierLocation = !!hasStringIndexType || !!hasNumberIndextype;
                    typeMembers = getPropertiesForObjectExpression(instantiatedType, completionsType, objectLikeContainer, typeChecker);
                    existingMembers = objectLikeContainer.properties;
                    if (typeMembers.length === 0) {
                        if (!hasNumberIndextype) {
                            isNonContextualObjectLiteral = true;
                            return 0 /* Continue */;
                        }
                    }
                }
                else {
                    Debug.assert(objectLikeContainer.kind === 203 /* ObjectBindingPattern */);
                    isNewIdentifierLocation = false;
                    const rootDeclaration = getRootDeclaration(objectLikeContainer.parent);
                    if (!isVariableLike(rootDeclaration))
                        return Debug.fail("Root declaration is not variable-like.");
                    let canGetType = hasInitializer(rootDeclaration) || !!getEffectiveTypeAnnotationNode(rootDeclaration) || rootDeclaration.parent.parent.kind === 247 /* ForOfStatement */;
                    if (!canGetType && rootDeclaration.kind === 166 /* Parameter */) {
                        if (isExpression(rootDeclaration.parent)) {
                            canGetType = !!typeChecker.getContextualType(rootDeclaration.parent);
                        }
                        else if (rootDeclaration.parent.kind === 171 /* MethodDeclaration */ || rootDeclaration.parent.kind === 175 /* SetAccessor */) {
                            canGetType = isExpression(rootDeclaration.parent.parent) && !!typeChecker.getContextualType(rootDeclaration.parent.parent);
                        }
                    }
                    if (canGetType) {
                        const typeForObject = typeChecker.getTypeAtLocation(objectLikeContainer);
                        if (!typeForObject)
                            return 2 /* Fail */;
                        typeMembers = typeChecker.getPropertiesOfType(typeForObject).filter((propertySymbol) => {
                            return typeChecker.isPropertyAccessible(objectLikeContainer, 
                            /*isSuper*/
                            false, 
                            /*writing*/
                            false, typeForObject, propertySymbol);
                        });
                        existingMembers = objectLikeContainer.elements;
                    }
                }
                if (typeMembers && typeMembers.length > 0) {
                    const filteredMembers = filterObjectMembersList(typeMembers, Debug.checkDefined(existingMembers));
                    symbols = concatenate(symbols, filteredMembers);
                    setSortTextToOptionalMember();
                    if (objectLikeContainer.kind === 207 /* ObjectLiteralExpression */ && preferences.includeCompletionsWithObjectLiteralMethodSnippets && preferences.includeCompletionsWithInsertText) {
                        transformObjectLiteralMembersSortText(symbolsStartIndex);
                        collectObjectLiteralMethodSymbols(filteredMembers, objectLikeContainer);
                    }
                }
                return 1 /* Success */;
            }
            function tryGetImportOrExportClauseCompletionSymbols() {
                if (!contextToken)
                    return 0 /* Continue */;
                const namedImportsOrExports = contextToken.kind === 18 /* OpenBraceToken */ || contextToken.kind === 27 /* CommaToken */ ? tryCast(contextToken.parent, isNamedImportsOrExports) : isTypeKeywordTokenOrIdentifier(contextToken) ? tryCast(contextToken.parent.parent, isNamedImportsOrExports) : void 0;
                if (!namedImportsOrExports)
                    return 0 /* Continue */;
                if (!isTypeKeywordTokenOrIdentifier(contextToken)) {
                    keywordFilters = 8 /* TypeKeyword */;
                }
                const { moduleSpecifier } = namedImportsOrExports.kind === 272 /* NamedImports */ ? namedImportsOrExports.parent.parent : namedImportsOrExports.parent;
                if (!moduleSpecifier) {
                    isNewIdentifierLocation = true;
                    return namedImportsOrExports.kind === 272 /* NamedImports */ ? 2 /* Fail */ : 0 /* Continue */;
                }
                const moduleSpecifierSymbol = typeChecker.getSymbolAtLocation(moduleSpecifier);
                if (!moduleSpecifierSymbol) {
                    isNewIdentifierLocation = true;
                    return 2 /* Fail */;
                }
                completionKind = 3 /* MemberLike */;
                isNewIdentifierLocation = false;
                const exports = typeChecker.getExportsAndPropertiesOfModule(moduleSpecifierSymbol);
                const existing = new Set(namedImportsOrExports.elements.filter((n) => !isCurrentlyEditingNode(n)).map((n) => (n.propertyName || n.name).escapedText));
                const uniques = exports.filter((e) => e.escapedName !== "default" /* Default */ && !existing.has(e.escapedName));
                symbols = concatenate(symbols, uniques);
                if (!uniques.length) {
                    keywordFilters = 0 /* None */;
                }
                return 1 /* Success */;
            }
            function tryGetLocalNamedExportCompletionSymbols() {
                var _a2;
                const namedExports = contextToken && (contextToken.kind === 18 /* OpenBraceToken */ || contextToken.kind === 27 /* CommaToken */) ? tryCast(contextToken.parent, isNamedExports) : void 0;
                if (!namedExports) {
                    return 0 /* Continue */;
                }
                const localsContainer = findAncestor(namedExports, or(isSourceFile, isModuleDeclaration));
                completionKind = 5 /* None */;
                isNewIdentifierLocation = false;
                (_a2 = localsContainer.locals) == null ? void 0 : _a2.forEach((symbol, name) => {
                    var _a3, _b;
                    symbols.push(symbol);
                    if ((_b = (_a3 = localsContainer.symbol) == null ? void 0 : _a3.exports) == null ? void 0 : _b.has(name)) {
                        symbolToSortTextMap[getSymbolId(symbol)] = SortText.OptionalMember;
                    }
                });
                return 1 /* Success */;
            }
            function tryGetClassLikeCompletionSymbols() {
                const decl = tryGetObjectTypeDeclarationCompletionContainer(sourceFile, contextToken, location, position);
                if (!decl)
                    return 0 /* Continue */;
                completionKind = 3 /* MemberLike */;
                isNewIdentifierLocation = true;
                keywordFilters = contextToken.kind === 41 /* AsteriskToken */ ? 0 /* None */ : isClassLike(decl) ? 2 /* ClassElementKeywords */ : 3 /* InterfaceElementKeywords */;
                if (!isClassLike(decl))
                    return 1 /* Success */;
                const classElement = contextToken.kind === 26 /* SemicolonToken */ ? contextToken.parent.parent : contextToken.parent;
                let classElementModifierFlags = isClassElement(classElement) ? getEffectiveModifierFlags(classElement) : 0 /* None */;
                if (contextToken.kind === 79 /* Identifier */ && !isCurrentlyEditingNode(contextToken)) {
                    switch (contextToken.getText()) {
                        case "private":
                            classElementModifierFlags = classElementModifierFlags | 8 /* Private */;
                            break;
                        case "static":
                            classElementModifierFlags = classElementModifierFlags | 32 /* Static */;
                            break;
                        case "override":
                            classElementModifierFlags = classElementModifierFlags | 16384 /* Override */;
                            break;
                    }
                }
                if (isClassStaticBlockDeclaration(classElement)) {
                    classElementModifierFlags |= 32 /* Static */;
                }
                if (!(classElementModifierFlags & 8 /* Private */)) {
                    const baseTypeNodes = isClassLike(decl) && classElementModifierFlags & 16384 /* Override */ ? singleElementArray(getEffectiveBaseTypeNode(decl)) : getAllSuperTypeNodes(decl);
                    const baseSymbols = flatMap(baseTypeNodes, (baseTypeNode) => {
                        const type = typeChecker.getTypeAtLocation(baseTypeNode);
                        return classElementModifierFlags & 32 /* Static */ ? (type == null ? void 0 : type.symbol) && typeChecker.getPropertiesOfType(typeChecker.getTypeOfSymbolAtLocation(type.symbol, decl)) : type && typeChecker.getPropertiesOfType(type);
                    });
                    symbols = concatenate(symbols, filterClassMembersList(baseSymbols, decl.members, classElementModifierFlags));
                    forEach(symbols, (symbol, index) => {
                        const declaration = symbol == null ? void 0 : symbol.valueDeclaration;
                        if (declaration && isClassElement(declaration) && declaration.name && isComputedPropertyName(declaration.name)) {
                            const origin = {
                                kind: 512 /* ComputedPropertyName */,
                                symbolName: typeChecker.symbolToString(symbol)
                            };
                            symbolToOriginInfoMap[index] = origin;
                        }
                    });
                }
                return 1 /* Success */;
            }
            function isConstructorParameterCompletion(node2) {
                return !!node2.parent && isParameter(node2.parent) && isConstructorDeclaration(node2.parent.parent) && (isParameterPropertyModifier(node2.kind) || isDeclarationName(node2));
            }
            function tryGetConstructorLikeCompletionContainer(contextToken2) {
                if (contextToken2) {
                    const parent2 = contextToken2.parent;
                    switch (contextToken2.kind) {
                        case 20 /* OpenParenToken */:
                        case 27 /* CommaToken */:
                            return isConstructorDeclaration(contextToken2.parent) ? contextToken2.parent : void 0;
                        default:
                            if (isConstructorParameterCompletion(contextToken2)) {
                                return parent2.parent;
                            }
                    }
                }
                return void 0;
            }
            function tryGetFunctionLikeBodyCompletionContainer(contextToken2) {
                if (contextToken2) {
                    let prev;
                    const container = findAncestor(contextToken2.parent, (node2) => {
                        if (isClassLike(node2)) {
                            return "quit";
                        }
                        if (isFunctionLikeDeclaration(node2) && prev === node2.body) {
                            return true;
                        }
                        prev = node2;
                        return false;
                    });
                    return container && container;
                }
            }
            function tryGetContainingJsxElement(contextToken2) {
                if (contextToken2) {
                    const parent2 = contextToken2.parent;
                    switch (contextToken2.kind) {
                        case 31 /* GreaterThanToken */:
                        case 30 /* LessThanSlashToken */:
                        case 43 /* SlashToken */:
                        case 79 /* Identifier */:
                        case 208 /* PropertyAccessExpression */:
                        case 289 /* JsxAttributes */:
                        case 288 /* JsxAttribute */:
                        case 290 /* JsxSpreadAttribute */:
                            if (parent2 && (parent2.kind === 282 /* JsxSelfClosingElement */ || parent2.kind === 283 /* JsxOpeningElement */)) {
                                if (contextToken2.kind === 31 /* GreaterThanToken */) {
                                    const precedingToken = findPrecedingToken(contextToken2.pos, sourceFile, 
                                    /*startNode*/
                                    void 0);
                                    if (!parent2.typeArguments || precedingToken && precedingToken.kind === 43 /* SlashToken */)
                                        break;
                                }
                                return parent2;
                            }
                            else if (parent2.kind === 288 /* JsxAttribute */) {
                                return parent2.parent.parent;
                            }
                            break;
                        case 10 /* StringLiteral */:
                            if (parent2 && (parent2.kind === 288 /* JsxAttribute */ || parent2.kind === 290 /* JsxSpreadAttribute */)) {
                                return parent2.parent.parent;
                            }
                            break;
                        case 19 /* CloseBraceToken */:
                            if (parent2 && parent2.kind === 291 /* JsxExpression */ && parent2.parent && parent2.parent.kind === 288 /* JsxAttribute */) {
                                return parent2.parent.parent.parent;
                            }
                            if (parent2 && parent2.kind === 290 /* JsxSpreadAttribute */) {
                                return parent2.parent.parent;
                            }
                            break;
                    }
                }
                return void 0;
            }
            function isSolelyIdentifierDefinitionLocation(contextToken2) {
                const parent2 = contextToken2.parent;
                const containingNodeKind = parent2.kind;
                switch (contextToken2.kind) {
                    case 27 /* CommaToken */:
                        return containingNodeKind === 257 /* VariableDeclaration */ || isVariableDeclarationListButNotTypeArgument(contextToken2) || containingNodeKind === 240 /* VariableStatement */ || containingNodeKind === 263 /* EnumDeclaration */ || // enum a { foo, |
                            isFunctionLikeButNotConstructor(containingNodeKind) || containingNodeKind === 261 /* InterfaceDeclaration */ || // interface A<T, |
                            containingNodeKind === 204 /* ArrayBindingPattern */ || // var [x, y|
                            containingNodeKind === 262 /* TypeAliasDeclaration */ || // type Map, K, |
                            // class A<T, |
                            // var C = class D<T, |
                            isClassLike(parent2) && !!parent2.typeParameters && parent2.typeParameters.end >= contextToken2.pos;
                    case 24 /* DotToken */:
                        return containingNodeKind === 204 /* ArrayBindingPattern */;
                    case 58 /* ColonToken */:
                        return containingNodeKind === 205 /* BindingElement */;
                    case 22 /* OpenBracketToken */:
                        return containingNodeKind === 204 /* ArrayBindingPattern */;
                    case 20 /* OpenParenToken */:
                        return containingNodeKind === 295 /* CatchClause */ || isFunctionLikeButNotConstructor(containingNodeKind);
                    case 18 /* OpenBraceToken */:
                        return containingNodeKind === 263 /* EnumDeclaration */;
                    case 29 /* LessThanToken */:
                        return containingNodeKind === 260 /* ClassDeclaration */ || // class A< |
                            containingNodeKind === 228 /* ClassExpression */ || // var C = class D< |
                            containingNodeKind === 261 /* InterfaceDeclaration */ || // interface A< |
                            containingNodeKind === 262 /* TypeAliasDeclaration */ || // type List< |
                            isFunctionLikeKind(containingNodeKind);
                    case 124 /* StaticKeyword */:
                        return containingNodeKind === 169 /* PropertyDeclaration */ && !isClassLike(parent2.parent);
                    case 25 /* DotDotDotToken */:
                        return containingNodeKind === 166 /* Parameter */ || !!parent2.parent && parent2.parent.kind === 204 /* ArrayBindingPattern */;
                    case 123 /* PublicKeyword */:
                    case 121 /* PrivateKeyword */:
                    case 122 /* ProtectedKeyword */:
                        return containingNodeKind === 166 /* Parameter */ && !isConstructorDeclaration(parent2.parent);
                    case 128 /* AsKeyword */:
                        return containingNodeKind === 273 /* ImportSpecifier */ || containingNodeKind === 278 /* ExportSpecifier */ || containingNodeKind === 271 /* NamespaceImport */;
                    case 137 /* GetKeyword */:
                    case 151 /* SetKeyword */:
                        return !isFromObjectTypeDeclaration(contextToken2);
                    case 79 /* Identifier */:
                        if (containingNodeKind === 273 /* ImportSpecifier */ && contextToken2 === parent2.name && contextToken2.text === "type") {
                            return false;
                        }
                        break;
                    case 84 /* ClassKeyword */:
                    case 92 /* EnumKeyword */:
                    case 118 /* InterfaceKeyword */:
                    case 98 /* FunctionKeyword */:
                    case 113 /* VarKeyword */:
                    case 100 /* ImportKeyword */:
                    case 119 /* LetKeyword */:
                    case 85 /* ConstKeyword */:
                    case 138 /* InferKeyword */:
                        return true;
                    case 154 /* TypeKeyword */:
                        return containingNodeKind !== 273 /* ImportSpecifier */;
                    case 41 /* AsteriskToken */:
                        return isFunctionLike(contextToken2.parent) && !isMethodDeclaration(contextToken2.parent);
                }
                if (isClassMemberCompletionKeyword(keywordForNode(contextToken2)) && isFromObjectTypeDeclaration(contextToken2)) {
                    return false;
                }
                if (isConstructorParameterCompletion(contextToken2)) {
                    if (!isIdentifier(contextToken2) || isParameterPropertyModifier(keywordForNode(contextToken2)) || isCurrentlyEditingNode(contextToken2)) {
                        return false;
                    }
                }
                switch (keywordForNode(contextToken2)) {
                    case 126 /* AbstractKeyword */:
                    case 84 /* ClassKeyword */:
                    case 85 /* ConstKeyword */:
                    case 136 /* DeclareKeyword */:
                    case 92 /* EnumKeyword */:
                    case 98 /* FunctionKeyword */:
                    case 118 /* InterfaceKeyword */:
                    case 119 /* LetKeyword */:
                    case 121 /* PrivateKeyword */:
                    case 122 /* ProtectedKeyword */:
                    case 123 /* PublicKeyword */:
                    case 124 /* StaticKeyword */:
                    case 113 /* VarKeyword */:
                        return true;
                    case 132 /* AsyncKeyword */:
                        return isPropertyDeclaration(contextToken2.parent);
                }
                const ancestorClassLike = findAncestor(contextToken2.parent, isClassLike);
                if (ancestorClassLike && contextToken2 === previousToken && isPreviousPropertyDeclarationTerminated(contextToken2, position)) {
                    return false;
                }
                const ancestorPropertyDeclaraion = getAncestor(contextToken2.parent, 169 /* PropertyDeclaration */);
                if (ancestorPropertyDeclaraion && contextToken2 !== previousToken && isClassLike(previousToken.parent.parent) && position <= previousToken.end) {
                    if (isPreviousPropertyDeclarationTerminated(contextToken2, previousToken.end)) {
                        return false;
                    }
                    else if (contextToken2.kind !== 63 /* EqualsToken */ && (isInitializedProperty(ancestorPropertyDeclaraion) || hasType(ancestorPropertyDeclaraion))) {
                        return true;
                    }
                }
                return isDeclarationName(contextToken2) && !isShorthandPropertyAssignment(contextToken2.parent) && !isJsxAttribute(contextToken2.parent) && !(isClassLike(contextToken2.parent) && (contextToken2 !== previousToken || position > previousToken.end));
            }
            function isPreviousPropertyDeclarationTerminated(contextToken2, position2) {
                return contextToken2.kind !== 63 /* EqualsToken */ && (contextToken2.kind === 26 /* SemicolonToken */ || !positionsAreOnSameLine(contextToken2.end, position2, sourceFile));
            }
            function isFunctionLikeButNotConstructor(kind) {
                return isFunctionLikeKind(kind) && kind !== 173 /* Constructor */;
            }
            function isDotOfNumericLiteral(contextToken2) {
                if (contextToken2.kind === 8 /* NumericLiteral */) {
                    const text = contextToken2.getFullText();
                    return text.charAt(text.length - 1) === ".";
                }
                return false;
            }
            function isVariableDeclarationListButNotTypeArgument(node2) {
                return node2.parent.kind === 258 /* VariableDeclarationList */ && !isPossiblyTypeArgumentPosition(node2, sourceFile, typeChecker);
            }
            function filterObjectMembersList(contextualMemberSymbols, existingMembers) {
                if (existingMembers.length === 0) {
                    return contextualMemberSymbols;
                }
                const membersDeclaredBySpreadAssignment = /* @__PURE__ */ new Set();
                const existingMemberNames = /* @__PURE__ */ new Set();
                for (const m of existingMembers) {
                    if (m.kind !== 299 /* PropertyAssignment */ && m.kind !== 300 /* ShorthandPropertyAssignment */ && m.kind !== 205 /* BindingElement */ && m.kind !== 171 /* MethodDeclaration */ && m.kind !== 174 /* GetAccessor */ && m.kind !== 175 /* SetAccessor */ && m.kind !== 301 /* SpreadAssignment */) {
                        continue;
                    }
                    if (isCurrentlyEditingNode(m)) {
                        continue;
                    }
                    let existingName;
                    if (isSpreadAssignment(m)) {
                        setMembersDeclaredBySpreadAssignment(m, membersDeclaredBySpreadAssignment);
                    }
                    else if (isBindingElement(m) && m.propertyName) {
                        if (m.propertyName.kind === 79 /* Identifier */) {
                            existingName = m.propertyName.escapedText;
                        }
                    }
                    else {
                        const name = getNameOfDeclaration(m);
                        existingName = name && isPropertyNameLiteral(name) ? getEscapedTextOfIdentifierOrLiteral(name) : void 0;
                    }
                    if (existingName !== void 0) {
                        existingMemberNames.add(existingName);
                    }
                }
                const filteredSymbols = contextualMemberSymbols.filter((m) => !existingMemberNames.has(m.escapedName));
                setSortTextToMemberDeclaredBySpreadAssignment(membersDeclaredBySpreadAssignment, filteredSymbols);
                return filteredSymbols;
            }
            function setMembersDeclaredBySpreadAssignment(declaration, membersDeclaredBySpreadAssignment) {
                const expression = declaration.expression;
                const symbol = typeChecker.getSymbolAtLocation(expression);
                const type = symbol && typeChecker.getTypeOfSymbolAtLocation(symbol, expression);
                const properties = type && type.properties;
                if (properties) {
                    properties.forEach((property) => {
                        membersDeclaredBySpreadAssignment.add(property.name);
                    });
                }
            }
            function setSortTextToOptionalMember() {
                symbols.forEach((m) => {
                    var _a2;
                    if (m.flags & 16777216 /* Optional */) {
                        const symbolId = getSymbolId(m);
                        symbolToSortTextMap[symbolId] = (_a2 = symbolToSortTextMap[symbolId]) != null ? _a2 : SortText.OptionalMember;
                    }
                });
            }
            function setSortTextToMemberDeclaredBySpreadAssignment(membersDeclaredBySpreadAssignment, contextualMemberSymbols) {
                if (membersDeclaredBySpreadAssignment.size === 0) {
                    return;
                }
                for (const contextualMemberSymbol of contextualMemberSymbols) {
                    if (membersDeclaredBySpreadAssignment.has(contextualMemberSymbol.name)) {
                        symbolToSortTextMap[getSymbolId(contextualMemberSymbol)] = SortText.MemberDeclaredBySpreadAssignment;
                    }
                }
            }
            function transformObjectLiteralMembersSortText(start2) {
                var _a2;
                for (let i = start2; i < symbols.length; i++) {
                    const symbol = symbols[i];
                    const symbolId = getSymbolId(symbol);
                    const origin = symbolToOriginInfoMap == null ? void 0 : symbolToOriginInfoMap[i];
                    const target = getEmitScriptTarget(compilerOptions);
                    const displayName = getCompletionEntryDisplayNameForSymbol(symbol, target, origin, 0 /* ObjectPropertyDeclaration */, 
                    /*jsxIdentifierExpected*/
                    false);
                    if (displayName) {
                        const originalSortText = (_a2 = symbolToSortTextMap[symbolId]) != null ? _a2 : SortText.LocationPriority;
                        const { name } = displayName;
                        symbolToSortTextMap[symbolId] = SortText.ObjectLiteralProperty(originalSortText, name);
                    }
                }
            }
            function filterClassMembersList(baseSymbols, existingMembers, currentClassElementModifierFlags) {
                const existingMemberNames = /* @__PURE__ */ new Set();
                for (const m of existingMembers) {
                    if (m.kind !== 169 /* PropertyDeclaration */ && m.kind !== 171 /* MethodDeclaration */ && m.kind !== 174 /* GetAccessor */ && m.kind !== 175 /* SetAccessor */) {
                        continue;
                    }
                    if (isCurrentlyEditingNode(m)) {
                        continue;
                    }
                    if (hasEffectiveModifier(m, 8 /* Private */)) {
                        continue;
                    }
                    if (isStatic(m) !== !!(currentClassElementModifierFlags & 32 /* Static */)) {
                        continue;
                    }
                    const existingName = getPropertyNameForPropertyNameNode(m.name);
                    if (existingName) {
                        existingMemberNames.add(existingName);
                    }
                }
                return baseSymbols.filter((propertySymbol) => !existingMemberNames.has(propertySymbol.escapedName) && !!propertySymbol.declarations && !(getDeclarationModifierFlagsFromSymbol(propertySymbol) & 8 /* Private */) && !(propertySymbol.valueDeclaration && isPrivateIdentifierClassElementDeclaration(propertySymbol.valueDeclaration)));
            }
            function filterJsxAttributes(symbols2, attributes) {
                const seenNames = /* @__PURE__ */ new Set();
                const membersDeclaredBySpreadAssignment = /* @__PURE__ */ new Set();
                for (const attr of attributes) {
                    if (isCurrentlyEditingNode(attr)) {
                        continue;
                    }
                    if (attr.kind === 288 /* JsxAttribute */) {
                        seenNames.add(attr.name.escapedText);
                    }
                    else if (isJsxSpreadAttribute(attr)) {
                        setMembersDeclaredBySpreadAssignment(attr, membersDeclaredBySpreadAssignment);
                    }
                }
                const filteredSymbols = symbols2.filter((a) => !seenNames.has(a.escapedName));
                setSortTextToMemberDeclaredBySpreadAssignment(membersDeclaredBySpreadAssignment, filteredSymbols);
                return filteredSymbols;
            }
            function isCurrentlyEditingNode(node2) {
                return node2.getStart(sourceFile) <= position && position <= node2.getEnd();
            }
        }
        function tryGetObjectLikeCompletionContainer(contextToken) {
            if (contextToken) {
                const { parent: parent2 } = contextToken;
                switch (contextToken.kind) {
                    case 18 /* OpenBraceToken */:
                    case 27 /* CommaToken */:
                        if (isObjectLiteralExpression(parent2) || isObjectBindingPattern(parent2)) {
                            return parent2;
                        }
                        break;
                    case 41 /* AsteriskToken */:
                        return isMethodDeclaration(parent2) ? tryCast(parent2.parent, isObjectLiteralExpression) : void 0;
                    case 79 /* Identifier */:
                        return contextToken.text === "async" && isShorthandPropertyAssignment(contextToken.parent) ? contextToken.parent.parent : void 0;
                }
            }
            return void 0;
        }
        function getRelevantTokens(position, sourceFile) {
            const previousToken = findPrecedingToken(position, sourceFile);
            if (previousToken && position <= previousToken.end && (isMemberName(previousToken) || isKeyword(previousToken.kind))) {
                const contextToken = findPrecedingToken(previousToken.getFullStart(), sourceFile, 
                /*startNode*/
                void 0);
                return { contextToken, previousToken };
            }
            return { contextToken: previousToken, previousToken };
        }
        function getAutoImportSymbolFromCompletionEntryData(name, data, program, host) {
            const containingProgram = data.isPackageJsonImport ? host.getPackageJsonAutoImportProvider() : program;
            const checker = containingProgram.getTypeChecker();
            const moduleSymbol = data.ambientModuleName ? checker.tryFindAmbientModule(data.ambientModuleName) : data.fileName ? checker.getMergedSymbol(Debug.checkDefined(containingProgram.getSourceFile(data.fileName)).symbol) : void 0;
            if (!moduleSymbol)
                return void 0;
            let symbol = data.exportName === "export=" /* ExportEquals */ ? checker.resolveExternalModuleSymbol(moduleSymbol) : checker.tryGetMemberInModuleExportsAndProperties(data.exportName, moduleSymbol);
            if (!symbol)
                return void 0;
            const isDefaultExport = data.exportName === "default" /* Default */;
            symbol = isDefaultExport && getLocalSymbolForExportDefault(symbol) || symbol;
            return { symbol, origin: completionEntryDataToSymbolOriginInfo(data, name, moduleSymbol) };
        }
        function getCompletionEntryDisplayNameForSymbol(symbol, target, origin, kind, jsxIdentifierExpected) {
            if (originIsIgnore(origin)) {
                return void 0;
            }
            const name = originIncludesSymbolName(origin) ? origin.symbolName : symbol.name;
            if (name === void 0 || symbol.flags & 1536 /* Module */ && isSingleOrDoubleQuote(name.charCodeAt(0)) || isKnownSymbol(symbol)) {
                return void 0;
            }
            const validNameResult = { name, needsConvertPropertyAccess: false };
            if (isIdentifierText(name, target, jsxIdentifierExpected ? 1 /* JSX */ : 0 /* Standard */) || symbol.valueDeclaration && isPrivateIdentifierClassElementDeclaration(symbol.valueDeclaration)) {
                return validNameResult;
            }
            switch (kind) {
                case 3 /* MemberLike */:
                    return originIsComputedPropertyName(origin) ? { name: origin.symbolName, needsConvertPropertyAccess: false } : void 0;
                case 0 /* ObjectPropertyDeclaration */:
                    return { name: JSON.stringify(name), needsConvertPropertyAccess: false };
                case 2 /* PropertyAccess */:
                case 1 /* Global */:
                    return name.charCodeAt(0) === 32 /* space */ ? void 0 : { name, needsConvertPropertyAccess: true };
                case 5 /* None */:
                case 4 /* String */:
                    return validNameResult;
                default:
                    Debug.assertNever(kind);
            }
        }
        function getKeywordCompletions(keywordFilter, filterOutTsOnlyKeywords) {
            if (!filterOutTsOnlyKeywords)
                return getTypescriptKeywordCompletions(keywordFilter);
            const index = keywordFilter + 8 /* Last */ + 1;
            return _keywordCompletions[index] || (_keywordCompletions[index] = getTypescriptKeywordCompletions(keywordFilter).filter((entry) => !isTypeScriptOnlyKeyword(stringToToken(entry.name))));
        }
        function getTypescriptKeywordCompletions(keywordFilter) {
            return _keywordCompletions[keywordFilter] || (_keywordCompletions[keywordFilter] = allKeywordsCompletions().filter((entry) => {
                const kind = stringToToken(entry.name);
                switch (keywordFilter) {
                    case 0 /* None */:
                        return false;
                    case 1 /* All */:
                        return isFunctionLikeBodyKeyword(kind) || kind === 136 /* DeclareKeyword */ || kind === 142 /* ModuleKeyword */ || kind === 154 /* TypeKeyword */ || kind === 143 /* NamespaceKeyword */ || kind === 126 /* AbstractKeyword */ || isTypeKeyword(kind) && kind !== 155 /* UndefinedKeyword */;
                    case 5 /* FunctionLikeBodyKeywords */:
                        return isFunctionLikeBodyKeyword(kind);
                    case 2 /* ClassElementKeywords */:
                        return isClassMemberCompletionKeyword(kind);
                    case 3 /* InterfaceElementKeywords */:
                        return isInterfaceOrTypeLiteralCompletionKeyword(kind);
                    case 4 /* ConstructorParameterKeywords */:
                        return isParameterPropertyModifier(kind);
                    case 6 /* TypeAssertionKeywords */:
                        return isTypeKeyword(kind) || kind === 85 /* ConstKeyword */;
                    case 7 /* TypeKeywords */:
                        return isTypeKeyword(kind);
                    case 8 /* TypeKeyword */:
                        return kind === 154 /* TypeKeyword */;
                    default:
                        return Debug.assertNever(keywordFilter);
                }
            }));
        }
        function isTypeScriptOnlyKeyword(kind) {
            switch (kind) {
                case 126 /* AbstractKeyword */:
                case 131 /* AnyKeyword */:
                case 160 /* BigIntKeyword */:
                case 134 /* BooleanKeyword */:
                case 136 /* DeclareKeyword */:
                case 92 /* EnumKeyword */:
                case 159 /* GlobalKeyword */:
                case 117 /* ImplementsKeyword */:
                case 138 /* InferKeyword */:
                case 118 /* InterfaceKeyword */:
                case 140 /* IsKeyword */:
                case 141 /* KeyOfKeyword */:
                case 142 /* ModuleKeyword */:
                case 143 /* NamespaceKeyword */:
                case 144 /* NeverKeyword */:
                case 148 /* NumberKeyword */:
                case 149 /* ObjectKeyword */:
                case 161 /* OverrideKeyword */:
                case 121 /* PrivateKeyword */:
                case 122 /* ProtectedKeyword */:
                case 123 /* PublicKeyword */:
                case 146 /* ReadonlyKeyword */:
                case 152 /* StringKeyword */:
                case 153 /* SymbolKeyword */:
                case 154 /* TypeKeyword */:
                case 156 /* UniqueKeyword */:
                case 157 /* UnknownKeyword */:
                    return true;
                default:
                    return false;
            }
        }
        function isInterfaceOrTypeLiteralCompletionKeyword(kind) {
            return kind === 146 /* ReadonlyKeyword */;
        }
        function isClassMemberCompletionKeyword(kind) {
            switch (kind) {
                case 126 /* AbstractKeyword */:
                case 127 /* AccessorKeyword */:
                case 135 /* ConstructorKeyword */:
                case 137 /* GetKeyword */:
                case 151 /* SetKeyword */:
                case 132 /* AsyncKeyword */:
                case 136 /* DeclareKeyword */:
                case 161 /* OverrideKeyword */:
                    return true;
                default:
                    return isClassMemberModifier(kind);
            }
        }
        function isFunctionLikeBodyKeyword(kind) {
            return kind === 132 /* AsyncKeyword */ || kind === 133 /* AwaitKeyword */ || kind === 128 /* AsKeyword */ || kind === 150 /* SatisfiesKeyword */ || kind === 154 /* TypeKeyword */ || !isContextualKeyword(kind) && !isClassMemberCompletionKeyword(kind);
        }
        function keywordForNode(node) {
            var _a2;
            return isIdentifier(node) ? (_a2 = identifierToKeywordKind(node)) != null ? _a2 : 0 /* Unknown */ : node.kind;
        }
        function getContextualKeywords(contextToken, position) {
            const entries = [];
            if (contextToken) {
                const file = contextToken.getSourceFile();
                const parent2 = contextToken.parent;
                const tokenLine = file.getLineAndCharacterOfPosition(contextToken.end).line;
                const currentLine = file.getLineAndCharacterOfPosition(position).line;
                if ((isImportDeclaration(parent2) || isExportDeclaration(parent2) && parent2.moduleSpecifier) && contextToken === parent2.moduleSpecifier && tokenLine === currentLine) {
                    entries.push({
                        name: tokenToString(130 /* AssertKeyword */),
                        kind: "keyword" /* keyword */,
                        kindModifiers: "" /* none */,
                        sortText: SortText.GlobalsOrKeywords
                    });
                }
            }
            return entries;
        }
        function getJsDocTagAtPosition(node, position) {
            return findAncestor(node, (n) => isJSDocTag(n) && rangeContainsPosition(n, position) ? true : isJSDoc(n) ? "quit" : false);
        }
        function getPropertiesForObjectExpression(contextualType, completionsType, obj, checker) {
            const hasCompletionsType = completionsType && completionsType !== contextualType;
            const type = hasCompletionsType && !(completionsType.flags & 3 /* AnyOrUnknown */) ? checker.getUnionType([contextualType, completionsType]) : contextualType;
            const properties = getApparentProperties(type, obj, checker);
            return type.isClass() && containsNonPublicProperties(properties) ? [] : hasCompletionsType ? filter(properties, hasDeclarationOtherThanSelf) : properties;
            function hasDeclarationOtherThanSelf(member) {
                if (!length(member.declarations))
                    return true;
                return some(member.declarations, (decl) => decl.parent !== obj);
            }
        }
        function getApparentProperties(type, node, checker) {
            if (!type.isUnion())
                return type.getApparentProperties();
            return checker.getAllPossiblePropertiesOfTypes(filter(type.types, (memberType) => !(memberType.flags & 134348796 /* Primitive */ || checker.isArrayLikeType(memberType) || checker.isTypeInvalidDueToUnionDiscriminant(memberType, node) || checker.typeHasCallOrConstructSignatures(memberType) || memberType.isClass() && containsNonPublicProperties(memberType.getApparentProperties()))));
        }
        function containsNonPublicProperties(props) {
            return some(props, (p) => !!(getDeclarationModifierFlagsFromSymbol(p) & 24 /* NonPublicAccessibilityModifier */));
        }
        function getPropertiesForCompletion(type, checker) {
            return type.isUnion() ? Debug.checkEachDefined(checker.getAllPossiblePropertiesOfTypes(type.types), "getAllPossiblePropertiesOfTypes() should all be defined") : Debug.checkEachDefined(type.getApparentProperties(), "getApparentProperties() should all be defined");
        }
        function tryGetObjectTypeDeclarationCompletionContainer(sourceFile, contextToken, location, position) {
            var _a2;
            switch (location.kind) {
                case 354 /* SyntaxList */:
                    return tryCast(location.parent, isObjectTypeDeclaration);
                case 1 /* EndOfFileToken */:
                    const cls = tryCast(lastOrUndefined(cast(location.parent, isSourceFile).statements), isObjectTypeDeclaration);
                    if (cls && !findChildOfKind(cls, 19 /* CloseBraceToken */, sourceFile)) {
                        return cls;
                    }
                    break;
                case 79 /* Identifier */: {
                    const originalKeywordKind = identifierToKeywordKind(location);
                    if (originalKeywordKind) {
                        return void 0;
                    }
                    if (isPropertyDeclaration(location.parent) && location.parent.initializer === location) {
                        return void 0;
                    }
                    if (isFromObjectTypeDeclaration(location)) {
                        return findAncestor(location, isObjectTypeDeclaration);
                    }
                }
            }
            if (!contextToken)
                return void 0;
            if (location.kind === 135 /* ConstructorKeyword */ || isIdentifier(contextToken) && isPropertyDeclaration(contextToken.parent) && isClassLike(location)) {
                return findAncestor(contextToken, isClassLike);
            }
            switch (contextToken.kind) {
                case 63 /* EqualsToken */:
                    return void 0;
                case 26 /* SemicolonToken */:
                case 19 /* CloseBraceToken */:
                    return isFromObjectTypeDeclaration(location) && location.parent.name === location ? location.parent.parent : tryCast(location, isObjectTypeDeclaration);
                case 18 /* OpenBraceToken */:
                case 27 /* CommaToken */:
                    return tryCast(contextToken.parent, isObjectTypeDeclaration);
                default:
                    if (isObjectTypeDeclaration(location)) {
                        if (getLineAndCharacterOfPosition(sourceFile, contextToken.getEnd()).line !== getLineAndCharacterOfPosition(sourceFile, position).line) {
                            return location;
                        }
                        const isValidKeyword = isClassLike(contextToken.parent.parent) ? isClassMemberCompletionKeyword : isInterfaceOrTypeLiteralCompletionKeyword;
                        return isValidKeyword(contextToken.kind) || contextToken.kind === 41 /* AsteriskToken */ || isIdentifier(contextToken) && isValidKeyword((_a2 = identifierToKeywordKind(contextToken)) != null ? _a2 : 0 /* Unknown */) ? contextToken.parent.parent : void 0;
                    }
                    return void 0;
            }
        }
        function tryGetTypeLiteralNode(node) {
            if (!node)
                return void 0;
            const parent2 = node.parent;
            switch (node.kind) {
                case 18 /* OpenBraceToken */:
                    if (isTypeLiteralNode(parent2)) {
                        return parent2;
                    }
                    break;
                case 26 /* SemicolonToken */:
                case 27 /* CommaToken */:
                case 79 /* Identifier */:
                    if (parent2.kind === 168 /* PropertySignature */ && isTypeLiteralNode(parent2.parent)) {
                        return parent2.parent;
                    }
                    break;
            }
            return void 0;
        }
        function getConstraintOfTypeArgumentProperty(node, checker) {
            if (!node)
                return void 0;
            if (isTypeNode(node) && isTypeReferenceType(node.parent)) {
                return checker.getTypeArgumentConstraint(node);
            }
            const t = getConstraintOfTypeArgumentProperty(node.parent, checker);
            if (!t)
                return void 0;
            switch (node.kind) {
                case 168 /* PropertySignature */:
                    return checker.getTypeOfPropertyOfContextualType(t, node.symbol.escapedName);
                case 190 /* IntersectionType */:
                case 184 /* TypeLiteral */:
                case 189 /* UnionType */:
                    return t;
            }
        }
        function isFromObjectTypeDeclaration(node) {
            return node.parent && isClassOrTypeElement(node.parent) && isObjectTypeDeclaration(node.parent.parent);
        }
        function isValidTrigger(sourceFile, triggerCharacter, contextToken, position) {
            switch (triggerCharacter) {
                case ".":
                case "@":
                    return true;
                case '"':
                case "'":
                case "`":
                    return !!contextToken && isStringLiteralOrTemplate(contextToken) && position === contextToken.getStart(sourceFile) + 1;
                case "#":
                    return !!contextToken && isPrivateIdentifier(contextToken) && !!getContainingClass(contextToken);
                case "<":
                    return !!contextToken && contextToken.kind === 29 /* LessThanToken */ && (!isBinaryExpression(contextToken.parent) || binaryExpressionMayBeOpenTag(contextToken.parent));
                case "/":
                    return !!contextToken && (isStringLiteralLike(contextToken) ? !!tryGetImportFromModuleSpecifier(contextToken) : contextToken.kind === 43 /* SlashToken */ && isJsxClosingElement(contextToken.parent));
                case " ":
                    return !!contextToken && isImportKeyword(contextToken) && contextToken.parent.kind === 308 /* SourceFile */;
                default:
                    return Debug.assertNever(triggerCharacter);
            }
        }
        function binaryExpressionMayBeOpenTag({ left }) {
            return nodeIsMissing(left);
        }
        function isProbablyGlobalType(type, sourceFile, checker) {
            const selfSymbol = checker.resolveName("self", 
            /*location*/
            void 0, 111551 /* Value */, 
            /*excludeGlobals*/
            false);
            if (selfSymbol && checker.getTypeOfSymbolAtLocation(selfSymbol, sourceFile) === type) {
                return true;
            }
            const globalSymbol = checker.resolveName("global", 
            /*location*/
            void 0, 111551 /* Value */, 
            /*excludeGlobals*/
            false);
            if (globalSymbol && checker.getTypeOfSymbolAtLocation(globalSymbol, sourceFile) === type) {
                return true;
            }
            const globalThisSymbol = checker.resolveName("globalThis", 
            /*location*/
            void 0, 111551 /* Value */, 
            /*excludeGlobals*/
            false);
            if (globalThisSymbol && checker.getTypeOfSymbolAtLocation(globalThisSymbol, sourceFile) === type) {
                return true;
            }
            return false;
        }
        function isStaticProperty(symbol) {
            return !!(symbol.valueDeclaration && getEffectiveModifierFlags(symbol.valueDeclaration) & 32 /* Static */ && isClassLike(symbol.valueDeclaration.parent));
        }
        function tryGetObjectLiteralContextualType(node, typeChecker) {
            const type = typeChecker.getContextualType(node);
            if (type) {
                return type;
            }
            const parent2 = walkUpParenthesizedExpressions(node.parent);
            if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 63 /* EqualsToken */ && node === parent2.left) {
                return typeChecker.getTypeAtLocation(parent2);
            }
            if (isExpression(parent2)) {
                return typeChecker.getContextualType(parent2);
            }
            return void 0;
        }
        function getImportStatementCompletionInfo(contextToken) {
            var _a2, _b, _c;
            let keywordCompletion;
            let isKeywordOnlyCompletion = false;
            const candidate = getCandidate();
            return {
                isKeywordOnlyCompletion,
                keywordCompletion,
                isNewIdentifierLocation: !!(candidate || keywordCompletion === 154 /* TypeKeyword */),
                isTopLevelTypeOnly: !!((_b = (_a2 = tryCast(candidate, isImportDeclaration)) == null ? void 0 : _a2.importClause) == null ? void 0 : _b.isTypeOnly) || !!((_c = tryCast(candidate, isImportEqualsDeclaration)) == null ? void 0 : _c.isTypeOnly),
                couldBeTypeOnlyImportSpecifier: !!candidate && couldBeTypeOnlyImportSpecifier(candidate, contextToken),
                replacementSpan: getSingleLineReplacementSpanForImportCompletionNode(candidate)
            };
            function getCandidate() {
                const parent2 = contextToken.parent;
                if (isImportEqualsDeclaration(parent2)) {
                    keywordCompletion = contextToken.kind === 154 /* TypeKeyword */ ? void 0 : 154 /* TypeKeyword */;
                    return isModuleSpecifierMissingOrEmpty(parent2.moduleReference) ? parent2 : void 0;
                }
                if (couldBeTypeOnlyImportSpecifier(parent2, contextToken) && canCompleteFromNamedBindings(parent2.parent)) {
                    return parent2;
                }
                if (isNamedImports(parent2) || isNamespaceImport(parent2)) {
                    if (!parent2.parent.isTypeOnly && (contextToken.kind === 18 /* OpenBraceToken */ || contextToken.kind === 100 /* ImportKeyword */ || contextToken.kind === 27 /* CommaToken */)) {
                        keywordCompletion = 154 /* TypeKeyword */;
                    }
                    if (canCompleteFromNamedBindings(parent2)) {
                        if (contextToken.kind === 19 /* CloseBraceToken */ || contextToken.kind === 79 /* Identifier */) {
                            isKeywordOnlyCompletion = true;
                            keywordCompletion = 158 /* FromKeyword */;
                        }
                        else {
                            return parent2.parent.parent;
                        }
                    }
                    return void 0;
                }
                if (isImportKeyword(contextToken) && isSourceFile(parent2)) {
                    keywordCompletion = 154 /* TypeKeyword */;
                    return contextToken;
                }
                if (isImportKeyword(contextToken) && isImportDeclaration(parent2)) {
                    keywordCompletion = 154 /* TypeKeyword */;
                    return isModuleSpecifierMissingOrEmpty(parent2.moduleSpecifier) ? parent2 : void 0;
                }
                return void 0;
            }
        }
        function getSingleLineReplacementSpanForImportCompletionNode(node) {
            var _a2, _b, _c;
            if (!node)
                return void 0;
            const top = (_a2 = findAncestor(node, or(isImportDeclaration, isImportEqualsDeclaration))) != null ? _a2 : node;
            const sourceFile = top.getSourceFile();
            if (rangeIsOnSingleLine(top, sourceFile)) {
                return createTextSpanFromNode(top, sourceFile);
            }
            Debug.assert(top.kind !== 100 /* ImportKeyword */ && top.kind !== 273 /* ImportSpecifier */);
            const potentialSplitPoint = top.kind === 269 /* ImportDeclaration */ ? (_c = getPotentiallyInvalidImportSpecifier((_b = top.importClause) == null ? void 0 : _b.namedBindings)) != null ? _c : top.moduleSpecifier : top.moduleReference;
            const withoutModuleSpecifier = {
                pos: top.getFirstToken().getStart(),
                end: potentialSplitPoint.pos
            };
            if (rangeIsOnSingleLine(withoutModuleSpecifier, sourceFile)) {
                return createTextSpanFromRange(withoutModuleSpecifier);
            }
        }
        function getPotentiallyInvalidImportSpecifier(namedBindings) {
            var _a2;
            return find((_a2 = tryCast(namedBindings, isNamedImports)) == null ? void 0 : _a2.elements, (e) => {
                var _a3;
                return !e.propertyName && isStringANonContextualKeyword(e.name.text) && ((_a3 = findPrecedingToken(e.name.pos, namedBindings.getSourceFile(), namedBindings)) == null ? void 0 : _a3.kind) !== 27 /* CommaToken */;
            });
        }
        function couldBeTypeOnlyImportSpecifier(importSpecifier, contextToken) {
            return isImportSpecifier(importSpecifier) && (importSpecifier.isTypeOnly || contextToken === importSpecifier.name && isTypeKeywordTokenOrIdentifier(contextToken));
        }
        function canCompleteFromNamedBindings(namedBindings) {
            if (!isModuleSpecifierMissingOrEmpty(namedBindings.parent.parent.moduleSpecifier) || namedBindings.parent.name) {
                return false;
            }
            if (isNamedImports(namedBindings)) {
                const invalidNamedImport = getPotentiallyInvalidImportSpecifier(namedBindings);
                const validImports = invalidNamedImport ? namedBindings.elements.indexOf(invalidNamedImport) : namedBindings.elements.length;
                return validImports < 2;
            }
            return true;
        }
        function isModuleSpecifierMissingOrEmpty(specifier) {
            var _a2;
            if (nodeIsMissing(specifier))
                return true;
            return !((_a2 = tryCast(isExternalModuleReference(specifier) ? specifier.expression : specifier, isStringLiteralLike)) == null ? void 0 : _a2.text);
        }
        function getVariableDeclaration(property) {
            const variableDeclaration = findAncestor(property, (node) => isFunctionBlock(node) || isArrowFunctionBody(node) || isBindingPattern(node) ? "quit" : isVariableDeclaration(node));
            return variableDeclaration;
        }
        function isArrowFunctionBody(node) {
            return node.parent && isArrowFunction(node.parent) && node.parent.body === node;
        }
        function symbolCanBeReferencedAtTypeLocation(symbol, checker, seenModules = /* @__PURE__ */ new Map()) {
            return nonAliasCanBeReferencedAtTypeLocation(symbol) || nonAliasCanBeReferencedAtTypeLocation(skipAlias(symbol.exportSymbol || symbol, checker));
            function nonAliasCanBeReferencedAtTypeLocation(symbol2) {
                return !!(symbol2.flags & 788968 /* Type */) || checker.isUnknownSymbol(symbol2) || !!(symbol2.flags & 1536 /* Module */) && addToSeen(seenModules, getSymbolId(symbol2)) && checker.getExportsOfModule(symbol2).some((e) => symbolCanBeReferencedAtTypeLocation(e, checker, seenModules));
            }
        }
        function isDeprecated(symbol, checker) {
            const declarations = skipAlias(symbol, checker).declarations;
            return !!length(declarations) && every(declarations, isDeprecatedDeclaration);
        }
        function charactersFuzzyMatchInString(identifierString, lowercaseCharacters) {
            if (lowercaseCharacters.length === 0) {
                return true;
            }
            let matchedFirstCharacter = false;
            let prevChar;
            let characterIndex = 0;
            const len = identifierString.length;
            for (let strIndex = 0; strIndex < len; strIndex++) {
                const strChar = identifierString.charCodeAt(strIndex);
                const testChar = lowercaseCharacters.charCodeAt(characterIndex);
                if (strChar === testChar || strChar === toUpperCharCode(testChar)) {
                    matchedFirstCharacter || (matchedFirstCharacter = prevChar === void 0 || // Beginning of word
                        97 /* a */ <= prevChar && prevChar <= 122 /* z */ && 65 /* A */ <= strChar && strChar <= 90 /* Z */ || // camelCase transition
                        prevChar === 95 /* _ */ && strChar !== 95 /* _ */);
                    if (matchedFirstCharacter) {
                        characterIndex++;
                    }
                    if (characterIndex === lowercaseCharacters.length) {
                        return true;
                    }
                }
                prevChar = strChar;
            }
            return false;
        }
        function toUpperCharCode(charCode) {
            if (97 /* a */ <= charCode && charCode <= 122 /* z */) {
                return charCode - 32;
            }
            return charCode;
        }
        var moduleSpecifierResolutionLimit, moduleSpecifierResolutionCacheAttemptLimit, SortText, CompletionSource, SymbolOriginInfoKind, CompletionKind, _keywordCompletions, allKeywordsCompletions;
        var init_completions = __esm({
            "src/services/completions.ts"() {
                "use strict";
                init_ts4();
                init_ts_Completions();
                moduleSpecifierResolutionLimit = 100;
                moduleSpecifierResolutionCacheAttemptLimit = 1e3;
                SortText = {
                    // Presets
                    LocalDeclarationPriority: "10",
                    LocationPriority: "11",
                    OptionalMember: "12",
                    MemberDeclaredBySpreadAssignment: "13",
                    SuggestedClassMembers: "14",
                    GlobalsOrKeywords: "15",
                    AutoImportSuggestions: "16",
                    ClassMemberSnippets: "17",
                    JavascriptIdentifiers: "18",
                    // Transformations
                    Deprecated(sortText) {
                        return "z" + sortText;
                    },
                    ObjectLiteralProperty(presetSortText, symbolDisplayName) {
                        return `${presetSortText}\0${symbolDisplayName}\0`;
                    },
                    SortBelow(sortText) {
                        return sortText + "1";
                    }
                };
                CompletionSource = /* @__PURE__ */ ((CompletionSource2) => {
                    CompletionSource2["ThisProperty"] = "ThisProperty/";
                    CompletionSource2["ClassMemberSnippet"] = "ClassMemberSnippet/";
                    CompletionSource2["TypeOnlyAlias"] = "TypeOnlyAlias/";
                    CompletionSource2["ObjectLiteralMethodSnippet"] = "ObjectLiteralMethodSnippet/";
                    CompletionSource2["SwitchCases"] = "SwitchCases/";
                    return CompletionSource2;
                })(CompletionSource || {});
                SymbolOriginInfoKind = /* @__PURE__ */ ((SymbolOriginInfoKind2) => {
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["ThisType"] = 1] = "ThisType";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["SymbolMember"] = 2] = "SymbolMember";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["Export"] = 4] = "Export";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["Promise"] = 8] = "Promise";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["Nullable"] = 16] = "Nullable";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["ResolvedExport"] = 32] = "ResolvedExport";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["TypeOnlyAlias"] = 64] = "TypeOnlyAlias";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["ObjectLiteralMethod"] = 128] = "ObjectLiteralMethod";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["Ignore"] = 256] = "Ignore";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["ComputedPropertyName"] = 512] = "ComputedPropertyName";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["SymbolMemberNoExport"] = 2 /* SymbolMember */] = "SymbolMemberNoExport";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["SymbolMemberExport"] = 6] = "SymbolMemberExport";
                    return SymbolOriginInfoKind2;
                })(SymbolOriginInfoKind || {});
                CompletionKind = /* @__PURE__ */ ((CompletionKind2) => {
                    CompletionKind2[CompletionKind2["ObjectPropertyDeclaration"] = 0] = "ObjectPropertyDeclaration";
                    CompletionKind2[CompletionKind2["Global"] = 1] = "Global";
                    CompletionKind2[CompletionKind2["PropertyAccess"] = 2] = "PropertyAccess";
                    CompletionKind2[CompletionKind2["MemberLike"] = 3] = "MemberLike";
                    CompletionKind2[CompletionKind2["String"] = 4] = "String";
                    CompletionKind2[CompletionKind2["None"] = 5] = "None";
                    return CompletionKind2;
                })(CompletionKind || {});
                _keywordCompletions = [];
                allKeywordsCompletions = memoize(() => {
                    const res = [];
                    for (let i = 81 /* FirstKeyword */; i <= 162 /* LastKeyword */; i++) {
                        res.push({
                            name: tokenToString(i),
                            kind: "keyword" /* keyword */,
                            kindModifiers: "" /* none */,
                            sortText: SortText.GlobalsOrKeywords
                        });
                    }
                    return res;
                });
            }
        });
        // src/services/stringCompletions.ts
        function createNameAndKindSet() {
            const map2 = /* @__PURE__ */ new Map();
            function add(value) {
                const existing = map2.get(value.name);
                if (!existing || kindPrecedence[existing.kind] < kindPrecedence[value.kind]) {
                    map2.set(value.name, value);
                }
            }
            return {
                add,
                has: map2.has.bind(map2),
                values: map2.values.bind(map2)
            };
        }
        function getStringLiteralCompletions(sourceFile, position, contextToken, options, host, program, log, preferences, includeSymbol) {
            if (isInReferenceComment(sourceFile, position)) {
                const entries = getTripleSlashReferenceCompletion(sourceFile, position, options, host);
                return entries && convertPathCompletions(entries);
            }
            if (isInString(sourceFile, position, contextToken)) {
                if (!contextToken || !isStringLiteralLike(contextToken))
                    return void 0;
                const entries = getStringLiteralCompletionEntries(sourceFile, contextToken, position, program.getTypeChecker(), options, host, preferences);
                return convertStringLiteralCompletions(entries, contextToken, sourceFile, host, program, log, options, preferences, position, includeSymbol);
            }
        }
        function convertStringLiteralCompletions(completion, contextToken, sourceFile, host, program, log, options, preferences, position, includeSymbol) {
            if (completion === void 0) {
                return void 0;
            }
            const optionalReplacementSpan = createTextSpanFromStringLiteralLikeContent(contextToken);
            switch (completion.kind) {
                case 0 /* Paths */:
                    return convertPathCompletions(completion.paths);
                case 1 /* Properties */: {
                    const entries = createSortedArray();
                    getCompletionEntriesFromSymbols(completion.symbols, entries, contextToken, contextToken, sourceFile, position, sourceFile, host, program, 99 /* ESNext */, log, 4 /* String */, preferences, options, 
                    /*formatContext*/
                    void 0, 
                    /*isTypeOnlyLocation */
                    void 0, 
                    /*propertyAccessToConvert*/
                    void 0, 
                    /*jsxIdentifierExpected*/
                    void 0, 
                    /*isJsxInitializer*/
                    void 0, 
                    /*importStatementCompletion*/
                    void 0, 
                    /*recommendedCompletion*/
                    void 0, 
                    /*symbolToOriginInfoMap*/
                    void 0, 
                    /*symbolToSortTextMap*/
                    void 0, 
                    /*isJsxIdentifierExpected*/
                    void 0, 
                    /*isRightOfOpenTag*/
                    void 0, includeSymbol);
                    return { isGlobalCompletion: false, isMemberCompletion: true, isNewIdentifierLocation: completion.hasIndexSignature, optionalReplacementSpan, entries };
                }
                case 2 /* Types */: {
                    const entries = completion.types.map((type) => ({
                        name: type.value,
                        kindModifiers: "" /* none */,
                        kind: "string" /* string */,
                        sortText: SortText.LocationPriority,
                        replacementSpan: getReplacementSpanForContextToken(contextToken)
                    }));
                    return { isGlobalCompletion: false, isMemberCompletion: false, isNewIdentifierLocation: completion.isNewIdentifier, optionalReplacementSpan, entries };
                }
                default:
                    return Debug.assertNever(completion);
            }
        }
        function getStringLiteralCompletionDetails(name, sourceFile, position, contextToken, checker, options, host, cancellationToken, preferences) {
            if (!contextToken || !isStringLiteralLike(contextToken))
                return void 0;
            const completions = getStringLiteralCompletionEntries(sourceFile, contextToken, position, checker, options, host, preferences);
            return completions && stringLiteralCompletionDetails(name, contextToken, completions, sourceFile, checker, cancellationToken);
        }
        function stringLiteralCompletionDetails(name, location, completion, sourceFile, checker, cancellationToken) {
            switch (completion.kind) {
                case 0 /* Paths */: {
                    const match = find(completion.paths, (p) => p.name === name);
                    return match && createCompletionDetails(name, kindModifiersFromExtension(match.extension), match.kind, [textPart(name)]);
                }
                case 1 /* Properties */: {
                    const match = find(completion.symbols, (s) => s.name === name);
                    return match && createCompletionDetailsForSymbol(match, match.name, checker, sourceFile, location, cancellationToken);
                }
                case 2 /* Types */:
                    return find(completion.types, (t) => t.value === name) ? createCompletionDetails(name, "" /* none */, "string" /* string */, [textPart(name)]) : void 0;
                default:
                    return Debug.assertNever(completion);
            }
        }
        function convertPathCompletions(pathCompletions) {
            const isGlobalCompletion = false;
            const isNewIdentifierLocation = true;
            const entries = pathCompletions.map(({ name, kind, span, extension }) => ({ name, kind, kindModifiers: kindModifiersFromExtension(extension), sortText: SortText.LocationPriority, replacementSpan: span }));
            return { isGlobalCompletion, isMemberCompletion: false, isNewIdentifierLocation, entries };
        }
        function kindModifiersFromExtension(extension) {
            switch (extension) {
                case ".d.ts" /* Dts */:
                    return ".d.ts" /* dtsModifier */;
                case ".js" /* Js */:
                    return ".js" /* jsModifier */;
                case ".json" /* Json */:
                    return ".json" /* jsonModifier */;
                case ".jsx" /* Jsx */:
                    return ".jsx" /* jsxModifier */;
                case ".ts" /* Ts */:
                    return ".ts" /* tsModifier */;
                case ".tsx" /* Tsx */:
                    return ".tsx" /* tsxModifier */;
                case ".d.mts" /* Dmts */:
                    return ".d.mts" /* dmtsModifier */;
                case ".mjs" /* Mjs */:
                    return ".mjs" /* mjsModifier */;
                case ".mts" /* Mts */:
                    return ".mts" /* mtsModifier */;
                case ".d.cts" /* Dcts */:
                    return ".d.cts" /* dctsModifier */;
                case ".cjs" /* Cjs */:
                    return ".cjs" /* cjsModifier */;
                case ".cts" /* Cts */:
                    return ".cts" /* ctsModifier */;
                case ".tsbuildinfo" /* TsBuildInfo */:
                    return Debug.fail(`Extension ${".tsbuildinfo" /* TsBuildInfo */} is unsupported.`);
                case void 0:
                    return "" /* none */;
                default:
                    return Debug.assertNever(extension);
            }
        }
        function getStringLiteralCompletionEntries(sourceFile, node, position, typeChecker, compilerOptions, host, preferences) {
            const parent2 = walkUpParentheses(node.parent);
            switch (parent2.kind) {
                case 198 /* LiteralType */: {
                    const grandParent = walkUpParentheses(parent2.parent);
                    switch (grandParent.kind) {
                        case 230 /* ExpressionWithTypeArguments */:
                        case 180 /* TypeReference */: {
                            const typeArgument = findAncestor(parent2, (n) => n.parent === grandParent);
                            if (typeArgument) {
                                return { kind: 2 /* Types */, types: getStringLiteralTypes(typeChecker.getTypeArgumentConstraint(typeArgument)), isNewIdentifier: false };
                            }
                            return void 0;
                        }
                        case 196 /* IndexedAccessType */:
                            const { indexType, objectType } = grandParent;
                            if (!rangeContainsPosition(indexType, position)) {
                                return void 0;
                            }
                            return stringLiteralCompletionsFromProperties(typeChecker.getTypeFromTypeNode(objectType));
                        case 202 /* ImportType */:
                            return { kind: 0 /* Paths */, paths: getStringLiteralCompletionsFromModuleNames(sourceFile, node, compilerOptions, host, typeChecker, preferences) };
                        case 189 /* UnionType */: {
                            if (!isTypeReferenceNode(grandParent.parent)) {
                                return void 0;
                            }
                            const alreadyUsedTypes = getAlreadyUsedTypesInStringLiteralUnion(grandParent, parent2);
                            const types = getStringLiteralTypes(typeChecker.getTypeArgumentConstraint(grandParent)).filter((t) => !contains(alreadyUsedTypes, t.value));
                            return { kind: 2 /* Types */, types, isNewIdentifier: false };
                        }
                        default:
                            return void 0;
                    }
                }
                case 299 /* PropertyAssignment */:
                    if (isObjectLiteralExpression(parent2.parent) && parent2.name === node) {
                        return stringLiteralCompletionsForObjectLiteral(typeChecker, parent2.parent);
                    }
                    return fromContextualType() || fromContextualType(0 /* None */);
                case 209 /* ElementAccessExpression */: {
                    const { expression, argumentExpression } = parent2;
                    if (node === skipParentheses(argumentExpression)) {
                        return stringLiteralCompletionsFromProperties(typeChecker.getTypeAtLocation(expression));
                    }
                    return void 0;
                }
                case 210 /* CallExpression */:
                case 211 /* NewExpression */:
                case 288 /* JsxAttribute */:
                    if (!isRequireCallArgument(node) && !isImportCall(parent2)) {
                        const argumentInfo = ts_SignatureHelp_exports.getArgumentInfoForCompletions(parent2.kind === 288 /* JsxAttribute */ ? parent2.parent : node, position, sourceFile);
                        return argumentInfo && getStringLiteralCompletionsFromSignature(argumentInfo.invocation, node, argumentInfo, typeChecker) || fromContextualType();
                    }
                case 269 /* ImportDeclaration */:
                case 275 /* ExportDeclaration */:
                case 280 /* ExternalModuleReference */:
                    return { kind: 0 /* Paths */, paths: getStringLiteralCompletionsFromModuleNames(sourceFile, node, compilerOptions, host, typeChecker, preferences) };
                case 292 /* CaseClause */:
                    const tracker = newCaseClauseTracker(typeChecker, parent2.parent.clauses);
                    const contextualTypes = fromContextualType();
                    if (!contextualTypes) {
                        return;
                    }
                    const literals = contextualTypes.types.filter((literal) => !tracker.hasValue(literal.value));
                    return { kind: 2 /* Types */, types: literals, isNewIdentifier: false };
                default:
                    return fromContextualType() || fromContextualType(0 /* None */);
            }
            function fromContextualType(contextFlags = 4 /* Completions */) {
                const types = getStringLiteralTypes(getContextualTypeFromParent(node, typeChecker, contextFlags));
                if (!types.length) {
                    return;
                }
                return { kind: 2 /* Types */, types, isNewIdentifier: false };
            }
        }
        function walkUpParentheses(node) {
            switch (node.kind) {
                case 193 /* ParenthesizedType */:
                    return walkUpParenthesizedTypes(node);
                case 214 /* ParenthesizedExpression */:
                    return walkUpParenthesizedExpressions(node);
                default:
                    return node;
            }
        }
        function getAlreadyUsedTypesInStringLiteralUnion(union, current) {
            return mapDefined(union.types, (type) => type !== current && isLiteralTypeNode(type) && isStringLiteral(type.literal) ? type.literal.text : void 0);
        }
        function getStringLiteralCompletionsFromSignature(call, arg, argumentInfo, checker) {
            let isNewIdentifier = false;
            const uniques = /* @__PURE__ */ new Map();
            const candidates = [];
            const editingArgument = isJsxOpeningLikeElement(call) ? Debug.checkDefined(findAncestor(arg.parent, isJsxAttribute)) : arg;
            checker.getResolvedSignatureForStringLiteralCompletions(call, editingArgument, candidates);
            const types = flatMap(candidates, (candidate) => {
                if (!signatureHasRestParameter(candidate) && argumentInfo.argumentCount > candidate.parameters.length)
                    return;
                let type = candidate.getTypeParameterAtPosition(argumentInfo.argumentIndex);
                if (isJsxOpeningLikeElement(call)) {
                    const propType = checker.getTypeOfPropertyOfType(type, editingArgument.name.text);
                    if (propType) {
                        type = propType;
                    }
                }
                isNewIdentifier = isNewIdentifier || !!(type.flags & 4 /* String */);
                return getStringLiteralTypes(type, uniques);
            });
            return length(types) ? { kind: 2 /* Types */, types, isNewIdentifier } : void 0;
        }
        function stringLiteralCompletionsFromProperties(type) {
            return type && {
                kind: 1 /* Properties */,
                symbols: filter(type.getApparentProperties(), (prop) => !(prop.valueDeclaration && isPrivateIdentifierClassElementDeclaration(prop.valueDeclaration))),
                hasIndexSignature: hasIndexSignature(type)
            };
        }
        function stringLiteralCompletionsForObjectLiteral(checker, objectLiteralExpression) {
            const contextualType = checker.getContextualType(objectLiteralExpression);
            if (!contextualType)
                return void 0;
            const completionsType = checker.getContextualType(objectLiteralExpression, 4 /* Completions */);
            const symbols = getPropertiesForObjectExpression(contextualType, completionsType, objectLiteralExpression, checker);
            return {
                kind: 1 /* Properties */,
                symbols,
                hasIndexSignature: hasIndexSignature(contextualType)
            };
        }
        function getStringLiteralTypes(type, uniques = /* @__PURE__ */ new Map()) {
            if (!type)
                return emptyArray;
            type = skipConstraint(type);
            return type.isUnion() ? flatMap(type.types, (t) => getStringLiteralTypes(t, uniques)) : type.isStringLiteral() && !(type.flags & 1024 /* EnumLiteral */) && addToSeen(uniques, type.value) ? [type] : emptyArray;
        }
        function nameAndKind(name, kind, extension) {
            return { name, kind, extension };
        }
        function directoryResult(name) {
            return nameAndKind(name, "directory" /* directory */, 
            /*extension*/
            void 0);
        }
        function addReplacementSpans(text, textStart, names) {
            const span = getDirectoryFragmentTextSpan(text, textStart);
            const wholeSpan = text.length === 0 ? void 0 : createTextSpan(textStart, text.length);
            return names.map(({ name, kind, extension }) => Math.max(name.indexOf(directorySeparator), name.indexOf(altDirectorySeparator)) !== -1 ? { name, kind, extension, span: wholeSpan } : { name, kind, extension, span });
        }
        function getStringLiteralCompletionsFromModuleNames(sourceFile, node, compilerOptions, host, typeChecker, preferences) {
            return addReplacementSpans(node.text, node.getStart(sourceFile) + 1, getStringLiteralCompletionsFromModuleNamesWorker(sourceFile, node, compilerOptions, host, typeChecker, preferences));
        }
        function getStringLiteralCompletionsFromModuleNamesWorker(sourceFile, node, compilerOptions, host, typeChecker, preferences) {
            const literalValue = normalizeSlashes(node.text);
            const mode = isStringLiteralLike(node) ? getModeForUsageLocation(sourceFile, node) : void 0;
            const scriptPath = sourceFile.path;
            const scriptDirectory = getDirectoryPath(scriptPath);
            const extensionOptions = getExtensionOptions(compilerOptions, 1 /* ModuleSpecifier */, sourceFile, typeChecker, preferences, mode);
            return isPathRelativeToScript(literalValue) || !compilerOptions.baseUrl && (isRootedDiskPath(literalValue) || isUrl(literalValue)) ? getCompletionEntriesForRelativeModules(literalValue, scriptDirectory, compilerOptions, host, scriptPath, extensionOptions) : getCompletionEntriesForNonRelativeModules(literalValue, scriptDirectory, mode, compilerOptions, host, extensionOptions, typeChecker);
        }
        function getExtensionOptions(compilerOptions, referenceKind, importingSourceFile, typeChecker, preferences, resolutionMode) {
            return {
                extensionsToSearch: flatten(getSupportedExtensionsForModuleResolution(compilerOptions, typeChecker)),
                referenceKind,
                importingSourceFile,
                endingPreference: preferences == null ? void 0 : preferences.importModuleSpecifierEnding,
                resolutionMode
            };
        }
        function getCompletionEntriesForRelativeModules(literalValue, scriptDirectory, compilerOptions, host, scriptPath, extensionOptions) {
            if (compilerOptions.rootDirs) {
                return getCompletionEntriesForDirectoryFragmentWithRootDirs(compilerOptions.rootDirs, literalValue, scriptDirectory, extensionOptions, compilerOptions, host, scriptPath);
            }
            else {
                return arrayFrom(getCompletionEntriesForDirectoryFragment(literalValue, scriptDirectory, extensionOptions, host, 
                /*moduleSpecifierIsRelative*/
                false, scriptPath).values());
            }
        }
        function getSupportedExtensionsForModuleResolution(compilerOptions, typeChecker) {
            const ambientModulesExtensions = !typeChecker ? [] : mapDefined(typeChecker.getAmbientModules(), (module2) => {
                const name = module2.name.slice(1, -1);
                if (!name.startsWith("*.") || name.includes("/"))
                    return;
                return name.slice(1);
            });
            const extensions = [...getSupportedExtensions(compilerOptions), ambientModulesExtensions];
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            return moduleResolutionUsesNodeModules(moduleResolution) ? getSupportedExtensionsWithJsonIfResolveJsonModule(compilerOptions, extensions) : extensions;
        }
        function getBaseDirectoriesFromRootDirs(rootDirs, basePath, scriptDirectory, ignoreCase) {
            rootDirs = rootDirs.map((rootDirectory) => normalizePath(isRootedDiskPath(rootDirectory) ? rootDirectory : combinePaths(basePath, rootDirectory)));
            const relativeDirectory = firstDefined(rootDirs, (rootDirectory) => containsPath(rootDirectory, scriptDirectory, basePath, ignoreCase) ? scriptDirectory.substr(rootDirectory.length) : void 0);
            return deduplicate([...rootDirs.map((rootDirectory) => combinePaths(rootDirectory, relativeDirectory)), scriptDirectory], equateStringsCaseSensitive, compareStringsCaseSensitive);
        }
        function getCompletionEntriesForDirectoryFragmentWithRootDirs(rootDirs, fragment, scriptDirectory, extensionOptions, compilerOptions, host, exclude) {
            const basePath = compilerOptions.project || host.getCurrentDirectory();
            const ignoreCase = !(host.useCaseSensitiveFileNames && host.useCaseSensitiveFileNames());
            const baseDirectories = getBaseDirectoriesFromRootDirs(rootDirs, basePath, scriptDirectory, ignoreCase);
            return flatMap(baseDirectories, (baseDirectory) => arrayFrom(getCompletionEntriesForDirectoryFragment(fragment, baseDirectory, extensionOptions, host, 
            /*moduleSpecifierIsRelative*/
            true, exclude).values()));
        }
        function getCompletionEntriesForDirectoryFragment(fragment, scriptDirectory, extensionOptions, host, moduleSpecifierIsRelative, exclude, result = createNameAndKindSet()) {
            var _a2;
            if (fragment === void 0) {
                fragment = "";
            }
            fragment = normalizeSlashes(fragment);
            if (!hasTrailingDirectorySeparator(fragment)) {
                fragment = getDirectoryPath(fragment);
            }
            if (fragment === "") {
                fragment = "." + directorySeparator;
            }
            fragment = ensureTrailingDirectorySeparator(fragment);
            const absolutePath = resolvePath(scriptDirectory, fragment);
            const baseDirectory = hasTrailingDirectorySeparator(absolutePath) ? absolutePath : getDirectoryPath(absolutePath);
            if (!moduleSpecifierIsRelative) {
                const packageJsonPath = findPackageJson(baseDirectory, host);
                if (packageJsonPath) {
                    const packageJson = readJson(packageJsonPath, host);
                    const typesVersions = packageJson.typesVersions;
                    if (typeof typesVersions === "object") {
                        const versionPaths = (_a2 = getPackageJsonTypesVersionsPaths(typesVersions)) == null ? void 0 : _a2.paths;
                        if (versionPaths) {
                            const packageDirectory = getDirectoryPath(packageJsonPath);
                            const pathInPackage = absolutePath.slice(ensureTrailingDirectorySeparator(packageDirectory).length);
                            if (addCompletionEntriesFromPaths(result, pathInPackage, packageDirectory, extensionOptions, host, versionPaths)) {
                                return result;
                            }
                        }
                    }
                }
            }
            const ignoreCase = !(host.useCaseSensitiveFileNames && host.useCaseSensitiveFileNames());
            if (!tryDirectoryExists(host, baseDirectory))
                return result;
            const files = tryReadDirectory(host, baseDirectory, extensionOptions.extensionsToSearch, 
            /*exclude*/
            void 0, 
            /*include*/
            ["./*"]);
            if (files) {
                for (let filePath of files) {
                    filePath = normalizePath(filePath);
                    if (exclude && comparePaths(filePath, exclude, scriptDirectory, ignoreCase) === 0 /* EqualTo */) {
                        continue;
                    }
                    const { name, extension } = getFilenameWithExtensionOption(getBaseFileName(filePath), host.getCompilationSettings(), extensionOptions);
                    result.add(nameAndKind(name, "script" /* scriptElement */, extension));
                }
            }
            const directories = tryGetDirectories(host, baseDirectory);
            if (directories) {
                for (const directory of directories) {
                    const directoryName = getBaseFileName(normalizePath(directory));
                    if (directoryName !== "@types") {
                        result.add(directoryResult(directoryName));
                    }
                }
            }
            return result;
        }
        function getFilenameWithExtensionOption(name, compilerOptions, extensionOptions) {
            const nonJsResult = ts_moduleSpecifiers_exports.tryGetRealFileNameForNonJsDeclarationFileName(name);
            if (nonJsResult) {
                return { name: nonJsResult, extension: tryGetExtensionFromPath2(nonJsResult) };
            }
            if (extensionOptions.referenceKind === 0 /* Filename */) {
                return { name, extension: tryGetExtensionFromPath2(name) };
            }
            const endingPreference = getModuleSpecifierEndingPreference(extensionOptions.endingPreference, extensionOptions.resolutionMode, compilerOptions, extensionOptions.importingSourceFile);
            if (endingPreference === 3 /* TsExtension */) {
                if (fileExtensionIsOneOf(name, supportedTSImplementationExtensions)) {
                    return { name, extension: tryGetExtensionFromPath2(name) };
                }
                const outputExtension2 = ts_moduleSpecifiers_exports.tryGetJSExtensionForFile(name, compilerOptions);
                return outputExtension2 ? { name: changeExtension(name, outputExtension2), extension: outputExtension2 } : { name, extension: tryGetExtensionFromPath2(name) };
            }
            if ((endingPreference === 0 /* Minimal */ || endingPreference === 1 /* Index */) && fileExtensionIsOneOf(name, [".js" /* Js */, ".jsx" /* Jsx */, ".ts" /* Ts */, ".tsx" /* Tsx */, ".d.ts" /* Dts */])) {
                return { name: removeFileExtension(name), extension: tryGetExtensionFromPath2(name) };
            }
            const outputExtension = ts_moduleSpecifiers_exports.tryGetJSExtensionForFile(name, compilerOptions);
            return outputExtension ? { name: changeExtension(name, outputExtension), extension: outputExtension } : { name, extension: tryGetExtensionFromPath2(name) };
        }
        function addCompletionEntriesFromPaths(result, fragment, baseDirectory, extensionOptions, host, paths) {
            const getPatternsForKey = (key) => paths[key];
            const comparePaths2 = (a, b) => {
                const patternA = tryParsePattern(a);
                const patternB = tryParsePattern(b);
                const lengthA = typeof patternA === "object" ? patternA.prefix.length : a.length;
                const lengthB = typeof patternB === "object" ? patternB.prefix.length : b.length;
                return compareValues(lengthB, lengthA);
            };
            return addCompletionEntriesFromPathsOrExports(result, fragment, baseDirectory, extensionOptions, host, getOwnKeys(paths), getPatternsForKey, comparePaths2);
        }
        function addCompletionEntriesFromPathsOrExports(result, fragment, baseDirectory, extensionOptions, host, keys, getPatternsForKey, comparePaths2) {
            let pathResults = [];
            let matchedPath;
            for (const key of keys) {
                if (key === ".")
                    continue;
                const keyWithoutLeadingDotSlash = key.replace(/^\.\//, "");
                const patterns = getPatternsForKey(key);
                if (patterns) {
                    const pathPattern = tryParsePattern(keyWithoutLeadingDotSlash);
                    if (!pathPattern)
                        continue;
                    const isMatch = typeof pathPattern === "object" && isPatternMatch(pathPattern, fragment);
                    const isLongestMatch = isMatch && (matchedPath === void 0 || comparePaths2(key, matchedPath) === -1 /* LessThan */);
                    if (isLongestMatch) {
                        matchedPath = key;
                        pathResults = pathResults.filter((r) => !r.matchedPattern);
                    }
                    if (typeof pathPattern === "string" || matchedPath === void 0 || comparePaths2(key, matchedPath) !== 1 /* GreaterThan */) {
                        pathResults.push({
                            matchedPattern: isMatch,
                            results: getCompletionsForPathMapping(keyWithoutLeadingDotSlash, patterns, fragment, baseDirectory, extensionOptions, host).map(({ name, kind, extension }) => nameAndKind(name, kind, extension))
                        });
                    }
                }
            }
            pathResults.forEach((pathResult) => pathResult.results.forEach((r) => result.add(r)));
            return matchedPath !== void 0;
        }
        function getCompletionEntriesForNonRelativeModules(fragment, scriptPath, mode, compilerOptions, host, extensionOptions, typeChecker) {
            const { baseUrl, paths } = compilerOptions;
            const result = createNameAndKindSet();
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            if (baseUrl) {
                const projectDir = compilerOptions.project || host.getCurrentDirectory();
                const absolute = normalizePath(combinePaths(projectDir, baseUrl));
                getCompletionEntriesForDirectoryFragment(fragment, absolute, extensionOptions, host, 
                /*moduleSpecifierIsRelative*/
                false, 
                /*exclude*/
                void 0, result);
                if (paths) {
                    addCompletionEntriesFromPaths(result, fragment, absolute, extensionOptions, host, paths);
                }
            }
            const fragmentDirectory = getFragmentDirectory(fragment);
            for (const ambientName of getAmbientModuleCompletions(fragment, fragmentDirectory, typeChecker)) {
                result.add(nameAndKind(ambientName, "external module name" /* externalModuleName */, 
                /*extension*/
                void 0));
            }
            getCompletionEntriesFromTypings(host, compilerOptions, scriptPath, fragmentDirectory, extensionOptions, result);
            if (moduleResolutionUsesNodeModules(moduleResolution)) {
                let foundGlobal = false;
                if (fragmentDirectory === void 0) {
                    for (const moduleName of enumerateNodeModulesVisibleToScript(host, scriptPath)) {
                        const moduleResult = nameAndKind(moduleName, "external module name" /* externalModuleName */, 
                        /*extension*/
                        void 0);
                        if (!result.has(moduleResult.name)) {
                            foundGlobal = true;
                            result.add(moduleResult);
                        }
                    }
                }
                if (!foundGlobal) {
                    let ancestorLookup = (ancestor) => {
                        const nodeModules = combinePaths(ancestor, "node_modules");
                        if (tryDirectoryExists(host, nodeModules)) {
                            getCompletionEntriesForDirectoryFragment(fragment, nodeModules, extensionOptions, host, 
                            /*moduleSpecifierIsRelative*/
                            false, 
                            /*exclude*/
                            void 0, result);
                        }
                    };
                    if (fragmentDirectory && getResolvePackageJsonExports(compilerOptions)) {
                        const nodeModulesDirectoryLookup = ancestorLookup;
                        ancestorLookup = (ancestor) => {
                            const components = getPathComponents(fragment);
                            components.shift();
                            let packagePath = components.shift();
                            if (!packagePath) {
                                return nodeModulesDirectoryLookup(ancestor);
                            }
                            if (startsWith(packagePath, "@")) {
                                const subName = components.shift();
                                if (!subName) {
                                    return nodeModulesDirectoryLookup(ancestor);
                                }
                                packagePath = combinePaths(packagePath, subName);
                            }
                            const packageDirectory = combinePaths(ancestor, "node_modules", packagePath);
                            const packageFile = combinePaths(packageDirectory, "package.json");
                            if (tryFileExists(host, packageFile)) {
                                const packageJson = readJson(packageFile, host);
                                const exports = packageJson.exports;
                                if (exports) {
                                    if (typeof exports !== "object" || exports === null) {
                                        return;
                                    }
                                    const keys = getOwnKeys(exports);
                                    const fragmentSubpath = components.join("/") + (components.length && hasTrailingDirectorySeparator(fragment) ? "/" : "");
                                    const conditions = mode === 99 /* ESNext */ ? ["node", "import", "types"] : ["node", "require", "types"];
                                    addCompletionEntriesFromPathsOrExports(result, fragmentSubpath, packageDirectory, extensionOptions, host, keys, (key) => singleElementArray(getPatternFromFirstMatchingCondition(exports[key], conditions)), comparePatternKeys);
                                    return;
                                }
                            }
                            return nodeModulesDirectoryLookup(ancestor);
                        };
                    }
                    forEachAncestorDirectory(scriptPath, ancestorLookup);
                }
            }
            return arrayFrom(result.values());
        }
        function getPatternFromFirstMatchingCondition(target, conditions) {
            if (typeof target === "string") {
                return target;
            }
            if (target && typeof target === "object" && !isArray(target)) {
                for (const condition in target) {
                    if (condition === "default" || conditions.indexOf(condition) > -1 || isApplicableVersionedTypesKey(conditions, condition)) {
                        const pattern = target[condition];
                        return getPatternFromFirstMatchingCondition(pattern, conditions);
                    }
                }
            }
        }
        function getFragmentDirectory(fragment) {
            return containsSlash(fragment) ? hasTrailingDirectorySeparator(fragment) ? fragment : getDirectoryPath(fragment) : void 0;
        }
        function getCompletionsForPathMapping(path, patterns, fragment, packageDirectory, extensionOptions, host) {
            if (!endsWith(path, "*")) {
                return !stringContains(path, "*") ? justPathMappingName(path, "script" /* scriptElement */) : emptyArray;
            }
            const pathPrefix = path.slice(0, path.length - 1);
            const remainingFragment = tryRemovePrefix(fragment, pathPrefix);
            if (remainingFragment === void 0) {
                const starIsFullPathComponent = path[path.length - 2] === "/";
                return starIsFullPathComponent ? justPathMappingName(pathPrefix, "directory" /* directory */) : flatMap(patterns, (pattern) => {
                    var _a2;
                    return (_a2 = getModulesForPathsPattern("", packageDirectory, pattern, extensionOptions, host)) == null ? void 0 : _a2.map(({ name, ...rest }) => ({ name: pathPrefix + name, ...rest }));
                });
            }
            return flatMap(patterns, (pattern) => getModulesForPathsPattern(remainingFragment, packageDirectory, pattern, extensionOptions, host));
            function justPathMappingName(name, kind) {
                return startsWith(name, fragment) ? [{ name: removeTrailingDirectorySeparator(name), kind, extension: void 0 }] : emptyArray;
            }
        }
        function getModulesForPathsPattern(fragment, packageDirectory, pattern, extensionOptions, host) {
            if (!host.readDirectory) {
                return void 0;
            }
            const parsed = tryParsePattern(pattern);
            if (parsed === void 0 || isString(parsed)) {
                return void 0;
            }
            const normalizedPrefix = resolvePath(parsed.prefix);
            const normalizedPrefixDirectory = hasTrailingDirectorySeparator(parsed.prefix) ? normalizedPrefix : getDirectoryPath(normalizedPrefix);
            const normalizedPrefixBase = hasTrailingDirectorySeparator(parsed.prefix) ? "" : getBaseFileName(normalizedPrefix);
            const fragmentHasPath = containsSlash(fragment);
            const fragmentDirectory = fragmentHasPath ? hasTrailingDirectorySeparator(fragment) ? fragment : getDirectoryPath(fragment) : void 0;
            const expandedPrefixDirectory = fragmentHasPath ? combinePaths(normalizedPrefixDirectory, normalizedPrefixBase + fragmentDirectory) : normalizedPrefixDirectory;
            const normalizedSuffix = normalizePath(parsed.suffix);
            const baseDirectory = normalizePath(combinePaths(packageDirectory, expandedPrefixDirectory));
            const completePrefix = fragmentHasPath ? baseDirectory : ensureTrailingDirectorySeparator(baseDirectory) + normalizedPrefixBase;
            const includeGlob = normalizedSuffix ? "**/*" + normalizedSuffix : "./*";
            const matches = mapDefined(tryReadDirectory(host, baseDirectory, extensionOptions.extensionsToSearch, 
            /*exclude*/
            void 0, [includeGlob]), (match) => {
                const trimmedWithPattern = trimPrefixAndSuffix(match);
                if (trimmedWithPattern) {
                    if (containsSlash(trimmedWithPattern)) {
                        return directoryResult(getPathComponents(removeLeadingDirectorySeparator(trimmedWithPattern))[1]);
                    }
                    const { name, extension } = getFilenameWithExtensionOption(trimmedWithPattern, host.getCompilationSettings(), extensionOptions);
                    return nameAndKind(name, "script" /* scriptElement */, extension);
                }
            });
            const directories = normalizedSuffix ? emptyArray : mapDefined(tryGetDirectories(host, baseDirectory), (dir) => dir === "node_modules" ? void 0 : directoryResult(dir));
            return [...matches, ...directories];
            function trimPrefixAndSuffix(path) {
                const inner = withoutStartAndEnd(normalizePath(path), completePrefix, normalizedSuffix);
                return inner === void 0 ? void 0 : removeLeadingDirectorySeparator(inner);
            }
        }
        function withoutStartAndEnd(s, start, end) {
            return startsWith(s, start) && endsWith(s, end) ? s.slice(start.length, s.length - end.length) : void 0;
        }
        function removeLeadingDirectorySeparator(path) {
            return path[0] === directorySeparator ? path.slice(1) : path;
        }
        function getAmbientModuleCompletions(fragment, fragmentDirectory, checker) {
            const ambientModules = checker.getAmbientModules().map((sym) => stripQuotes(sym.name));
            const nonRelativeModuleNames = ambientModules.filter((moduleName) => startsWith(moduleName, fragment) && moduleName.indexOf("*") < 0);
            if (fragmentDirectory !== void 0) {
                const moduleNameWithSeparator = ensureTrailingDirectorySeparator(fragmentDirectory);
                return nonRelativeModuleNames.map((nonRelativeModuleName) => removePrefix(nonRelativeModuleName, moduleNameWithSeparator));
            }
            return nonRelativeModuleNames;
        }
        function getTripleSlashReferenceCompletion(sourceFile, position, compilerOptions, host) {
            const token = getTokenAtPosition(sourceFile, position);
            const commentRanges = getLeadingCommentRanges(sourceFile.text, token.pos);
            const range = commentRanges && find(commentRanges, (commentRange) => position >= commentRange.pos && position <= commentRange.end);
            if (!range) {
                return void 0;
            }
            const text = sourceFile.text.slice(range.pos, position);
            const match = tripleSlashDirectiveFragmentRegex.exec(text);
            if (!match) {
                return void 0;
            }
            const [, prefix, kind, toComplete] = match;
            const scriptPath = getDirectoryPath(sourceFile.path);
            const names = kind === "path" ? getCompletionEntriesForDirectoryFragment(toComplete, scriptPath, getExtensionOptions(compilerOptions, 0 /* Filename */, sourceFile), host, 
            /*moduleSpecifierIsRelative*/
            true, sourceFile.path) : kind === "types" ? getCompletionEntriesFromTypings(host, compilerOptions, scriptPath, getFragmentDirectory(toComplete), getExtensionOptions(compilerOptions, 1 /* ModuleSpecifier */, sourceFile)) : Debug.fail();
            return addReplacementSpans(toComplete, range.pos + prefix.length, arrayFrom(names.values()));
        }
        function getCompletionEntriesFromTypings(host, options, scriptPath, fragmentDirectory, extensionOptions, result = createNameAndKindSet()) {
            const seen = /* @__PURE__ */ new Map();
            const typeRoots = tryAndIgnoreErrors(() => getEffectiveTypeRoots(options, host)) || emptyArray;
            for (const root of typeRoots) {
                getCompletionEntriesFromDirectories(root);
            }
            for (const packageJson of findPackageJsons(scriptPath, host)) {
                const typesDir = combinePaths(getDirectoryPath(packageJson), "node_modules/@types");
                getCompletionEntriesFromDirectories(typesDir);
            }
            return result;
            function getCompletionEntriesFromDirectories(directory) {
                if (!tryDirectoryExists(host, directory))
                    return;
                for (const typeDirectoryName of tryGetDirectories(host, directory)) {
                    const packageName = unmangleScopedPackageName(typeDirectoryName);
                    if (options.types && !contains(options.types, packageName))
                        continue;
                    if (fragmentDirectory === void 0) {
                        if (!seen.has(packageName)) {
                            result.add(nameAndKind(packageName, "external module name" /* externalModuleName */, 
                            /*extension*/
                            void 0));
                            seen.set(packageName, true);
                        }
                    }
                    else {
                        const baseDirectory = combinePaths(directory, typeDirectoryName);
                        const remainingFragment = tryRemoveDirectoryPrefix(fragmentDirectory, packageName, hostGetCanonicalFileName(host));
                        if (remainingFragment !== void 0) {
                            getCompletionEntriesForDirectoryFragment(remainingFragment, baseDirectory, extensionOptions, host, 
                            /*moduleSpecifierIsRelative*/
                            false, 
                            /*exclude*/
                            void 0, result);
                        }
                    }
                }
            }
        }
        function enumerateNodeModulesVisibleToScript(host, scriptPath) {
            if (!host.readFile || !host.fileExists)
                return emptyArray;
            const result = [];
            for (const packageJson of findPackageJsons(scriptPath, host)) {
                const contents = readJson(packageJson, host);
                for (const key of nodeModulesDependencyKeys) {
                    const dependencies = contents[key];
                    if (!dependencies)
                        continue;
                    for (const dep in dependencies) {
                        if (hasProperty(dependencies, dep) && !startsWith(dep, "@types/")) {
                            result.push(dep);
                        }
                    }
                }
            }
            return result;
        }
        function getDirectoryFragmentTextSpan(text, textStart) {
            const index = Math.max(text.lastIndexOf(directorySeparator), text.lastIndexOf(altDirectorySeparator));
            const offset = index !== -1 ? index + 1 : 0;
            const length2 = text.length - offset;
            return length2 === 0 || isIdentifierText(text.substr(offset, length2), 99 /* ESNext */) ? void 0 : createTextSpan(textStart + offset, length2);
        }
        function isPathRelativeToScript(path) {
            if (path && path.length >= 2 && path.charCodeAt(0) === 46 /* dot */) {
                const slashIndex = path.length >= 3 && path.charCodeAt(1) === 46 /* dot */ ? 2 : 1;
                const slashCharCode = path.charCodeAt(slashIndex);
                return slashCharCode === 47 /* slash */ || slashCharCode === 92 /* backslash */;
            }
            return false;
        }
        function containsSlash(fragment) {
            return stringContains(fragment, directorySeparator);
        }
        function isRequireCallArgument(node) {
            return isCallExpression(node.parent) && firstOrUndefined(node.parent.arguments) === node && isIdentifier(node.parent.expression) && node.parent.expression.escapedText === "require";
        }
        var kindPrecedence, tripleSlashDirectiveFragmentRegex, nodeModulesDependencyKeys;
        var init_stringCompletions = __esm({
            "src/services/stringCompletions.ts"() {
                "use strict";
                init_ts4();
                init_ts_Completions();
                kindPrecedence = {
                    ["directory" /* directory */]: 0,
                    ["script" /* scriptElement */]: 1,
                    ["external module name" /* externalModuleName */]: 2
                };
                tripleSlashDirectiveFragmentRegex = /^(\/\/\/\s*<reference\s+(path|types)\s*=\s*(?:'|"))([^\3"]*)$/;
                nodeModulesDependencyKeys = ["dependencies", "devDependencies", "peerDependencies", "optionalDependencies"];
            }
        });
        // src/services/_namespaces/ts.Completions.StringCompletions.ts
        var ts_Completions_StringCompletions_exports = {};
        __export(ts_Completions_StringCompletions_exports, {
            getStringLiteralCompletionDetails: () => getStringLiteralCompletionDetails,
            getStringLiteralCompletions: () => getStringLiteralCompletions
        });
        var init_ts_Completions_StringCompletions = __esm({
            "src/services/_namespaces/ts.Completions.StringCompletions.ts"() {
                "use strict";
                init_stringCompletions();
            }
        });
        // src/services/_namespaces/ts.Completions.ts
        var ts_Completions_exports = {};
        __export(ts_Completions_exports, {
            CompletionKind: () => CompletionKind,
            CompletionSource: () => CompletionSource,
            SortText: () => SortText,
            StringCompletions: () => ts_Completions_StringCompletions_exports,
            SymbolOriginInfoKind: () => SymbolOriginInfoKind,
            createCompletionDetails: () => createCompletionDetails,
            createCompletionDetailsForSymbol: () => createCompletionDetailsForSymbol,
            getCompletionEntriesFromSymbols: () => getCompletionEntriesFromSymbols,
            getCompletionEntryDetails: () => getCompletionEntryDetails,
            getCompletionEntrySymbol: () => getCompletionEntrySymbol,
            getCompletionsAtPosition: () => getCompletionsAtPosition,
            getPropertiesForObjectExpression: () => getPropertiesForObjectExpression,
            moduleSpecifierResolutionCacheAttemptLimit: () => moduleSpecifierResolutionCacheAttemptLimit,
            moduleSpecifierResolutionLimit: () => moduleSpecifierResolutionLimit
        });
        var init_ts_Completions = __esm({
            "src/services/_namespaces/ts.Completions.ts"() {
                "use strict";
                init_completions();
                init_ts_Completions_StringCompletions();
            }
        });
        // src/services/importTracker.ts
        function createImportTracker(sourceFiles, sourceFilesSet, checker, cancellationToken) {
            const allDirectImports = getDirectImportsMap(sourceFiles, checker, cancellationToken);
            return (exportSymbol, exportInfo, isForRename) => {
                const { directImports, indirectUsers } = getImportersForExport(sourceFiles, sourceFilesSet, allDirectImports, exportInfo, checker, cancellationToken);
                return { indirectUsers, ...getSearchesFromDirectImports(directImports, exportSymbol, exportInfo.exportKind, checker, isForRename) };
            };
        }
        function getImportersForExport(sourceFiles, sourceFilesSet, allDirectImports, { exportingModuleSymbol, exportKind }, checker, cancellationToken) {
            const markSeenDirectImport = nodeSeenTracker();
            const markSeenIndirectUser = nodeSeenTracker();
            const directImports = [];
            const isAvailableThroughGlobal = !!exportingModuleSymbol.globalExports;
            const indirectUserDeclarations = isAvailableThroughGlobal ? void 0 : [];
            handleDirectImports(exportingModuleSymbol);
            return { directImports, indirectUsers: getIndirectUsers() };
            function getIndirectUsers() {
                if (isAvailableThroughGlobal) {
                    return sourceFiles;
                }
                if (exportingModuleSymbol.declarations) {
                    for (const decl of exportingModuleSymbol.declarations) {
                        if (isExternalModuleAugmentation(decl) && sourceFilesSet.has(decl.getSourceFile().fileName)) {
                            addIndirectUser(decl);
                        }
                    }
                }
                return indirectUserDeclarations.map(getSourceFileOfNode);
            }
            function handleDirectImports(exportingModuleSymbol2) {
                const theseDirectImports = getDirectImports(exportingModuleSymbol2);
                if (theseDirectImports) {
                    for (const direct of theseDirectImports) {
                        if (!markSeenDirectImport(direct)) {
                            continue;
                        }
                        if (cancellationToken)
                            cancellationToken.throwIfCancellationRequested();
                        switch (direct.kind) {
                            case 210 /* CallExpression */:
                                if (isImportCall(direct)) {
                                    handleImportCall(direct);
                                    break;
                                }
                                if (!isAvailableThroughGlobal) {
                                    const parent2 = direct.parent;
                                    if (exportKind === 2 /* ExportEquals */ && parent2.kind === 257 /* VariableDeclaration */) {
                                        const { name } = parent2;
                                        if (name.kind === 79 /* Identifier */) {
                                            directImports.push(name);
                                            break;
                                        }
                                    }
                                }
                                break;
                            case 79 /* Identifier */:
                                break;
                            case 268 /* ImportEqualsDeclaration */:
                                handleNamespaceImport(direct, direct.name, hasSyntacticModifier(direct, 1 /* Export */), 
                                /*alreadyAddedDirect*/
                                false);
                                break;
                            case 269 /* ImportDeclaration */:
                                directImports.push(direct);
                                const namedBindings = direct.importClause && direct.importClause.namedBindings;
                                if (namedBindings && namedBindings.kind === 271 /* NamespaceImport */) {
                                    handleNamespaceImport(direct, namedBindings.name, 
                                    /*isReExport*/
                                    false, 
                                    /*alreadyAddedDirect*/
                                    true);
                                }
                                else if (!isAvailableThroughGlobal && isDefaultImport(direct)) {
                                    addIndirectUser(getSourceFileLikeForImportDeclaration(direct));
                                }
                                break;
                            case 275 /* ExportDeclaration */:
                                if (!direct.exportClause) {
                                    handleDirectImports(getContainingModuleSymbol(direct, checker));
                                }
                                else if (direct.exportClause.kind === 277 /* NamespaceExport */) {
                                    addIndirectUser(getSourceFileLikeForImportDeclaration(direct), 
                                    /** addTransitiveDependencies */
                                    true);
                                }
                                else {
                                    directImports.push(direct);
                                }
                                break;
                            case 202 /* ImportType */:
                                if (!isAvailableThroughGlobal && direct.isTypeOf && !direct.qualifier && isExported2(direct)) {
                                    addIndirectUser(direct.getSourceFile(), 
                                    /** addTransitiveDependencies */
                                    true);
                                }
                                directImports.push(direct);
                                break;
                            default:
                                Debug.failBadSyntaxKind(direct, "Unexpected import kind.");
                        }
                    }
                }
            }
            function handleImportCall(importCall) {
                const top = findAncestor(importCall, isAmbientModuleDeclaration) || importCall.getSourceFile();
                addIndirectUser(top, 
                /** addTransitiveDependencies */
                !!isExported2(importCall, 
                /** stopAtAmbientModule */
                true));
            }
            function isExported2(node, stopAtAmbientModule = false) {
                return findAncestor(node, (node2) => {
                    if (stopAtAmbientModule && isAmbientModuleDeclaration(node2))
                        return "quit";
                    return canHaveModifiers(node2) && some(node2.modifiers, isExportModifier);
                });
            }
            function handleNamespaceImport(importDeclaration, name, isReExport, alreadyAddedDirect) {
                if (exportKind === 2 /* ExportEquals */) {
                    if (!alreadyAddedDirect)
                        directImports.push(importDeclaration);
                }
                else if (!isAvailableThroughGlobal) {
                    const sourceFileLike = getSourceFileLikeForImportDeclaration(importDeclaration);
                    Debug.assert(sourceFileLike.kind === 308 /* SourceFile */ || sourceFileLike.kind === 264 /* ModuleDeclaration */);
                    if (isReExport || findNamespaceReExports(sourceFileLike, name, checker)) {
                        addIndirectUser(sourceFileLike, 
                        /** addTransitiveDependencies */
                        true);
                    }
                    else {
                        addIndirectUser(sourceFileLike);
                    }
                }
            }
            function addIndirectUser(sourceFileLike, addTransitiveDependencies = false) {
                Debug.assert(!isAvailableThroughGlobal);
                const isNew = markSeenIndirectUser(sourceFileLike);
                if (!isNew)
                    return;
                indirectUserDeclarations.push(sourceFileLike);
                if (!addTransitiveDependencies)
                    return;
                const moduleSymbol = checker.getMergedSymbol(sourceFileLike.symbol);
                if (!moduleSymbol)
                    return;
                Debug.assert(!!(moduleSymbol.flags & 1536 /* Module */));
                const directImports2 = getDirectImports(moduleSymbol);
                if (directImports2) {
                    for (const directImport of directImports2) {
                        if (!isImportTypeNode(directImport)) {
                            addIndirectUser(getSourceFileLikeForImportDeclaration(directImport), 
                            /** addTransitiveDependencies */
                            true);
                        }
                    }
                }
            }
            function getDirectImports(moduleSymbol) {
                return allDirectImports.get(getSymbolId(moduleSymbol).toString());
            }
        }
        function getSearchesFromDirectImports(directImports, exportSymbol, exportKind, checker, isForRename) {
            const importSearches = [];
            const singleReferences = [];
            function addSearch(location, symbol) {
                importSearches.push([location, symbol]);
            }
            if (directImports) {
                for (const decl of directImports) {
                    handleImport(decl);
                }
            }
            return { importSearches, singleReferences };
            function handleImport(decl) {
                if (decl.kind === 268 /* ImportEqualsDeclaration */) {
                    if (isExternalModuleImportEquals(decl)) {
                        handleNamespaceImportLike(decl.name);
                    }
                    return;
                }
                if (decl.kind === 79 /* Identifier */) {
                    handleNamespaceImportLike(decl);
                    return;
                }
                if (decl.kind === 202 /* ImportType */) {
                    if (decl.qualifier) {
                        const firstIdentifier = getFirstIdentifier(decl.qualifier);
                        if (firstIdentifier.escapedText === symbolName(exportSymbol)) {
                            singleReferences.push(firstIdentifier);
                        }
                    }
                    else if (exportKind === 2 /* ExportEquals */) {
                        singleReferences.push(decl.argument.literal);
                    }
                    return;
                }
                if (decl.moduleSpecifier.kind !== 10 /* StringLiteral */) {
                    return;
                }
                if (decl.kind === 275 /* ExportDeclaration */) {
                    if (decl.exportClause && isNamedExports(decl.exportClause)) {
                        searchForNamedImport(decl.exportClause);
                    }
                    return;
                }
                const { name, namedBindings } = decl.importClause || { name: void 0, namedBindings: void 0 };
                if (namedBindings) {
                    switch (namedBindings.kind) {
                        case 271 /* NamespaceImport */:
                            handleNamespaceImportLike(namedBindings.name);
                            break;
                        case 272 /* NamedImports */:
                            if (exportKind === 0 /* Named */ || exportKind === 1 /* Default */) {
                                searchForNamedImport(namedBindings);
                            }
                            break;
                        default:
                            Debug.assertNever(namedBindings);
                    }
                }
                if (name && (exportKind === 1 /* Default */ || exportKind === 2 /* ExportEquals */) && (!isForRename || name.escapedText === symbolEscapedNameNoDefault(exportSymbol))) {
                    const defaultImportAlias = checker.getSymbolAtLocation(name);
                    addSearch(name, defaultImportAlias);
                }
            }
            function handleNamespaceImportLike(importName) {
                if (exportKind === 2 /* ExportEquals */ && (!isForRename || isNameMatch(importName.escapedText))) {
                    addSearch(importName, checker.getSymbolAtLocation(importName));
                }
            }
            function searchForNamedImport(namedBindings) {
                if (!namedBindings) {
                    return;
                }
                for (const element of namedBindings.elements) {
                    const { name, propertyName } = element;
                    if (!isNameMatch((propertyName || name).escapedText)) {
                        continue;
                    }
                    if (propertyName) {
                        singleReferences.push(propertyName);
                        if (!isForRename || name.escapedText === exportSymbol.escapedName) {
                            addSearch(name, checker.getSymbolAtLocation(name));
                        }
                    }
                    else {
                        const localSymbol = element.kind === 278 /* ExportSpecifier */ && element.propertyName ? checker.getExportSpecifierLocalTargetSymbol(element) : checker.getSymbolAtLocation(name);
                        addSearch(name, localSymbol);
                    }
                }
            }
            function isNameMatch(name) {
                return name === exportSymbol.escapedName || exportKind !== 0 /* Named */ && name === "default" /* Default */;
            }
        }
        function findNamespaceReExports(sourceFileLike, name, checker) {
            const namespaceImportSymbol = checker.getSymbolAtLocation(name);
            return !!forEachPossibleImportOrExportStatement(sourceFileLike, (statement) => {
                if (!isExportDeclaration(statement))
                    return;
                const { exportClause, moduleSpecifier } = statement;
                return !moduleSpecifier && exportClause && isNamedExports(exportClause) && exportClause.elements.some((element) => checker.getExportSpecifierLocalTargetSymbol(element) === namespaceImportSymbol);
            });
        }
        function findModuleReferences(program, sourceFiles, searchModuleSymbol) {
            var _a2;
            const refs = [];
            const checker = program.getTypeChecker();
            for (const referencingFile of sourceFiles) {
                const searchSourceFile = searchModuleSymbol.valueDeclaration;
                if ((searchSourceFile == null ? void 0 : searchSourceFile.kind) === 308 /* SourceFile */) {
                    for (const ref of referencingFile.referencedFiles) {
                        if (program.getSourceFileFromReference(referencingFile, ref) === searchSourceFile) {
                            refs.push({ kind: "reference", referencingFile, ref });
                        }
                    }
                    for (const ref of referencingFile.typeReferenceDirectives) {
                        const referenced = (_a2 = program.getResolvedTypeReferenceDirectives().get(ref.fileName, ref.resolutionMode || referencingFile.impliedNodeFormat)) == null ? void 0 : _a2.resolvedTypeReferenceDirective;
                        if (referenced !== void 0 && referenced.resolvedFileName === searchSourceFile.fileName) {
                            refs.push({ kind: "reference", referencingFile, ref });
                        }
                    }
                }
                forEachImport(referencingFile, (_importDecl, moduleSpecifier) => {
                    const moduleSymbol = checker.getSymbolAtLocation(moduleSpecifier);
                    if (moduleSymbol === searchModuleSymbol) {
                        refs.push({ kind: "import", literal: moduleSpecifier });
                    }
                });
            }
            return refs;
        }
        function getDirectImportsMap(sourceFiles, checker, cancellationToken) {
            const map2 = /* @__PURE__ */ new Map();
            for (const sourceFile of sourceFiles) {
                if (cancellationToken)
                    cancellationToken.throwIfCancellationRequested();
                forEachImport(sourceFile, (importDecl, moduleSpecifier) => {
                    const moduleSymbol = checker.getSymbolAtLocation(moduleSpecifier);
                    if (moduleSymbol) {
                        const id = getSymbolId(moduleSymbol).toString();
                        let imports = map2.get(id);
                        if (!imports) {
                            map2.set(id, imports = []);
                        }
                        imports.push(importDecl);
                    }
                });
            }
            return map2;
        }
        function forEachPossibleImportOrExportStatement(sourceFileLike, action) {
            return forEach(sourceFileLike.kind === 308 /* SourceFile */ ? sourceFileLike.statements : sourceFileLike.body.statements, (statement) => (
            // TODO: GH#18217
            action(statement) || isAmbientModuleDeclaration(statement) && forEach(statement.body && statement.body.statements, action)));
        }
        function forEachImport(sourceFile, action) {
            if (sourceFile.externalModuleIndicator || sourceFile.imports !== void 0) {
                for (const i of sourceFile.imports) {
                    action(importFromModuleSpecifier(i), i);
                }
            }
            else {
                forEachPossibleImportOrExportStatement(sourceFile, (statement) => {
                    switch (statement.kind) {
                        case 275 /* ExportDeclaration */:
                        case 269 /* ImportDeclaration */: {
                            const decl = statement;
                            if (decl.moduleSpecifier && isStringLiteral(decl.moduleSpecifier)) {
                                action(decl, decl.moduleSpecifier);
                            }
                            break;
                        }
                        case 268 /* ImportEqualsDeclaration */: {
                            const decl = statement;
                            if (isExternalModuleImportEquals(decl)) {
                                action(decl, decl.moduleReference.expression);
                            }
                            break;
                        }
                    }
                });
            }
        }
        function getImportOrExportSymbol(node, symbol, checker, comingFromExport) {
            return comingFromExport ? getExport() : getExport() || getImport();
            function getExport() {
                var _a2;
                const { parent: parent2 } = node;
                const grandparent = parent2.parent;
                if (symbol.exportSymbol) {
                    if (parent2.kind === 208 /* PropertyAccessExpression */) {
                        return ((_a2 = symbol.declarations) == null ? void 0 : _a2.some((d) => d === parent2)) && isBinaryExpression(grandparent) ? getSpecialPropertyExport(grandparent, 
                        /*useLhsSymbol*/
                        false) : void 0;
                    }
                    else {
                        return exportInfo(symbol.exportSymbol, getExportKindForDeclaration(parent2));
                    }
                }
                else {
                    const exportNode = getExportNode(parent2, node);
                    if (exportNode && hasSyntacticModifier(exportNode, 1 /* Export */)) {
                        if (isImportEqualsDeclaration(exportNode) && exportNode.moduleReference === node) {
                            if (comingFromExport) {
                                return void 0;
                            }
                            const lhsSymbol = checker.getSymbolAtLocation(exportNode.name);
                            return { kind: 0 /* Import */, symbol: lhsSymbol };
                        }
                        else {
                            return exportInfo(symbol, getExportKindForDeclaration(exportNode));
                        }
                    }
                    else if (isNamespaceExport(parent2)) {
                        return exportInfo(symbol, 0 /* Named */);
                    }
                    else if (isExportAssignment(parent2)) {
                        return getExportAssignmentExport(parent2);
                    }
                    else if (isExportAssignment(grandparent)) {
                        return getExportAssignmentExport(grandparent);
                    }
                    else if (isBinaryExpression(parent2)) {
                        return getSpecialPropertyExport(parent2, 
                        /*useLhsSymbol*/
                        true);
                    }
                    else if (isBinaryExpression(grandparent)) {
                        return getSpecialPropertyExport(grandparent, 
                        /*useLhsSymbol*/
                        true);
                    }
                    else if (isJSDocTypedefTag(parent2) || isJSDocCallbackTag(parent2)) {
                        return exportInfo(symbol, 0 /* Named */);
                    }
                }
                function getExportAssignmentExport(ex) {
                    if (!ex.symbol.parent)
                        return void 0;
                    const exportKind = ex.isExportEquals ? 2 /* ExportEquals */ : 1 /* Default */;
                    return { kind: 1 /* Export */, symbol, exportInfo: { exportingModuleSymbol: ex.symbol.parent, exportKind } };
                }
                function getSpecialPropertyExport(node2, useLhsSymbol) {
                    let kind;
                    switch (getAssignmentDeclarationKind(node2)) {
                        case 1 /* ExportsProperty */:
                            kind = 0 /* Named */;
                            break;
                        case 2 /* ModuleExports */:
                            kind = 2 /* ExportEquals */;
                            break;
                        default:
                            return void 0;
                    }
                    const sym = useLhsSymbol ? checker.getSymbolAtLocation(getNameOfAccessExpression(cast(node2.left, isAccessExpression))) : symbol;
                    return sym && exportInfo(sym, kind);
                }
            }
            function getImport() {
                const isImport3 = isNodeImport(node);
                if (!isImport3)
                    return void 0;
                let importedSymbol = checker.getImmediateAliasedSymbol(symbol);
                if (!importedSymbol)
                    return void 0;
                importedSymbol = skipExportSpecifierSymbol(importedSymbol, checker);
                if (importedSymbol.escapedName === "export=") {
                    importedSymbol = getExportEqualsLocalSymbol(importedSymbol, checker);
                    if (importedSymbol === void 0)
                        return void 0;
                }
                const importedName = symbolEscapedNameNoDefault(importedSymbol);
                if (importedName === void 0 || importedName === "default" /* Default */ || importedName === symbol.escapedName) {
                    return { kind: 0 /* Import */, symbol: importedSymbol };
                }
            }
            function exportInfo(symbol2, kind) {
                const exportInfo2 = getExportInfo(symbol2, kind, checker);
                return exportInfo2 && { kind: 1 /* Export */, symbol: symbol2, exportInfo: exportInfo2 };
            }
            function getExportKindForDeclaration(node2) {
                return hasSyntacticModifier(node2, 1024 /* Default */) ? 1 /* Default */ : 0 /* Named */;
            }
        }
        function getExportEqualsLocalSymbol(importedSymbol, checker) {
            var _a2, _b;
            if (importedSymbol.flags & 2097152 /* Alias */) {
                return checker.getImmediateAliasedSymbol(importedSymbol);
            }
            const decl = Debug.checkDefined(importedSymbol.valueDeclaration);
            if (isExportAssignment(decl)) {
                return (_a2 = tryCast(decl.expression, canHaveSymbol)) == null ? void 0 : _a2.symbol;
            }
            else if (isBinaryExpression(decl)) {
                return (_b = tryCast(decl.right, canHaveSymbol)) == null ? void 0 : _b.symbol;
            }
            else if (isSourceFile(decl)) {
                return decl.symbol;
            }
            return void 0;
        }
        function getExportNode(parent2, node) {
            const declaration = isVariableDeclaration(parent2) ? parent2 : isBindingElement(parent2) ? walkUpBindingElementsAndPatterns(parent2) : void 0;
            if (declaration) {
                return parent2.name !== node ? void 0 : isCatchClause(declaration.parent) ? void 0 : isVariableStatement(declaration.parent.parent) ? declaration.parent.parent : void 0;
            }
            else {
                return parent2;
            }
        }
        function isNodeImport(node) {
            const { parent: parent2 } = node;
            switch (parent2.kind) {
                case 268 /* ImportEqualsDeclaration */:
                    return parent2.name === node && isExternalModuleImportEquals(parent2);
                case 273 /* ImportSpecifier */:
                    return !parent2.propertyName;
                case 270 /* ImportClause */:
                case 271 /* NamespaceImport */:
                    Debug.assert(parent2.name === node);
                    return true;
                case 205 /* BindingElement */:
                    return isInJSFile(node) && isVariableDeclarationInitializedToBareOrAccessedRequire(parent2.parent.parent);
                default:
                    return false;
            }
        }
        function getExportInfo(exportSymbol, exportKind, checker) {
            const moduleSymbol = exportSymbol.parent;
            if (!moduleSymbol)
                return void 0;
            const exportingModuleSymbol = checker.getMergedSymbol(moduleSymbol);
            return isExternalModuleSymbol(exportingModuleSymbol) ? { exportingModuleSymbol, exportKind } : void 0;
        }
        function skipExportSpecifierSymbol(symbol, checker) {
            if (symbol.declarations) {
                for (const declaration of symbol.declarations) {
                    if (isExportSpecifier(declaration) && !declaration.propertyName && !declaration.parent.parent.moduleSpecifier) {
                        return checker.getExportSpecifierLocalTargetSymbol(declaration) || symbol;
                    }
                    else if (isPropertyAccessExpression(declaration) && isModuleExportsAccessExpression(declaration.expression) && !isPrivateIdentifier(declaration.name)) {
                        return checker.getSymbolAtLocation(declaration);
                    }
                    else if (isShorthandPropertyAssignment(declaration) && isBinaryExpression(declaration.parent.parent) && getAssignmentDeclarationKind(declaration.parent.parent) === 2 /* ModuleExports */) {
                        return checker.getExportSpecifierLocalTargetSymbol(declaration.name);
                    }
                }
            }
            return symbol;
        }
        function getContainingModuleSymbol(importer, checker) {
            return checker.getMergedSymbol(getSourceFileLikeForImportDeclaration(importer).symbol);
        }
        function getSourceFileLikeForImportDeclaration(node) {
            if (node.kind === 210 /* CallExpression */) {
                return node.getSourceFile();
            }
            const { parent: parent2 } = node;
            if (parent2.kind === 308 /* SourceFile */) {
                return parent2;
            }
            Debug.assert(parent2.kind === 265 /* ModuleBlock */);
            return cast(parent2.parent, isAmbientModuleDeclaration);
        }
        function isAmbientModuleDeclaration(node) {
            return node.kind === 264 /* ModuleDeclaration */ && node.name.kind === 10 /* StringLiteral */;
        }
        function isExternalModuleImportEquals(eq) {
            return eq.moduleReference.kind === 280 /* ExternalModuleReference */ && eq.moduleReference.expression.kind === 10 /* StringLiteral */;
        }
        var ExportKind2, ImportExport;
        var init_importTracker = __esm({
            "src/services/importTracker.ts"() {
                "use strict";
                init_ts4();
                ExportKind2 = /* @__PURE__ */ ((ExportKind3) => {
                    ExportKind3[ExportKind3["Named"] = 0] = "Named";
                    ExportKind3[ExportKind3["Default"] = 1] = "Default";
                    ExportKind3[ExportKind3["ExportEquals"] = 2] = "ExportEquals";
                    return ExportKind3;
                })(ExportKind2 || {});
                ImportExport = /* @__PURE__ */ ((ImportExport2) => {
                    ImportExport2[ImportExport2["Import"] = 0] = "Import";
                    ImportExport2[ImportExport2["Export"] = 1] = "Export";
                    return ImportExport2;
                })(ImportExport || {});
            }
        });
        // src/services/findAllReferences.ts
        function nodeEntry(node, kind = 1 /* Node */) {
            return {
                kind,
                node: node.name || node,
                context: getContextNodeForNodeEntry(node)
            };
        }
        function isContextWithStartAndEndNode(node) {
            return node && node.kind === void 0;
        }
        function getContextNodeForNodeEntry(node) {
            if (isDeclaration(node)) {
                return getContextNode(node);
            }
            if (!node.parent)
                return void 0;
            if (!isDeclaration(node.parent) && !isExportAssignment(node.parent)) {
                if (isInJSFile(node)) {
                    const binaryExpression = isBinaryExpression(node.parent) ? node.parent : isAccessExpression(node.parent) && isBinaryExpression(node.parent.parent) && node.parent.parent.left === node.parent ? node.parent.parent : void 0;
                    if (binaryExpression && getAssignmentDeclarationKind(binaryExpression) !== 0 /* None */) {
                        return getContextNode(binaryExpression);
                    }
                }
                if (isJsxOpeningElement(node.parent) || isJsxClosingElement(node.parent)) {
                    return node.parent.parent;
                }
                else if (isJsxSelfClosingElement(node.parent) || isLabeledStatement(node.parent) || isBreakOrContinueStatement(node.parent)) {
                    return node.parent;
                }
                else if (isStringLiteralLike(node)) {
                    const validImport = tryGetImportFromModuleSpecifier(node);
                    if (validImport) {
                        const declOrStatement = findAncestor(validImport, (node2) => isDeclaration(node2) || isStatement(node2) || isJSDocTag(node2));
                        return isDeclaration(declOrStatement) ? getContextNode(declOrStatement) : declOrStatement;
                    }
                }
                const propertyName = findAncestor(node, isComputedPropertyName);
                return propertyName ? getContextNode(propertyName.parent) : void 0;
            }
            if (node.parent.name === node || // node is name of declaration, use parent
                isConstructorDeclaration(node.parent) || isExportAssignment(node.parent) || // Property name of the import export specifier or binding pattern, use parent
                (isImportOrExportSpecifier(node.parent) || isBindingElement(node.parent)) && node.parent.propertyName === node || // Is default export
                node.kind === 88 /* DefaultKeyword */ && hasSyntacticModifier(node.parent, 1025 /* ExportDefault */)) {
                return getContextNode(node.parent);
            }
            return void 0;
        }
        function getContextNode(node) {
            if (!node)
                return void 0;
            switch (node.kind) {
                case 257 /* VariableDeclaration */:
                    return !isVariableDeclarationList(node.parent) || node.parent.declarations.length !== 1 ? node : isVariableStatement(node.parent.parent) ? node.parent.parent : isForInOrOfStatement(node.parent.parent) ? getContextNode(node.parent.parent) : node.parent;
                case 205 /* BindingElement */:
                    return getContextNode(node.parent.parent);
                case 273 /* ImportSpecifier */:
                    return node.parent.parent.parent;
                case 278 /* ExportSpecifier */:
                case 271 /* NamespaceImport */:
                    return node.parent.parent;
                case 270 /* ImportClause */:
                case 277 /* NamespaceExport */:
                    return node.parent;
                case 223 /* BinaryExpression */:
                    return isExpressionStatement(node.parent) ? node.parent : node;
                case 247 /* ForOfStatement */:
                case 246 /* ForInStatement */:
                    return {
                        start: node.initializer,
                        end: node.expression
                    };
                case 299 /* PropertyAssignment */:
                case 300 /* ShorthandPropertyAssignment */:
                    return isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent) ? getContextNode(findAncestor(node.parent, (node2) => isBinaryExpression(node2) || isForInOrOfStatement(node2))) : node;
                default:
                    return node;
            }
        }
        function toContextSpan(textSpan, sourceFile, context) {
            if (!context)
                return void 0;
            const contextSpan = isContextWithStartAndEndNode(context) ? getTextSpan(context.start, sourceFile, context.end) : getTextSpan(context, sourceFile);
            return contextSpan.start !== textSpan.start || contextSpan.length !== textSpan.length ? { contextSpan } : void 0;
        }
        function findReferencedSymbols(program, cancellationToken, sourceFiles, sourceFile, position) {
            const node = getTouchingPropertyName(sourceFile, position);
            const options = { use: 1 /* References */ };
            const referencedSymbols = Core.getReferencedSymbolsForNode(position, node, program, sourceFiles, cancellationToken, options);
            const checker = program.getTypeChecker();
            const adjustedNode = Core.getAdjustedNode(node, options);
            const symbol = isDefinitionForReference(adjustedNode) ? checker.getSymbolAtLocation(adjustedNode) : void 0;
            return !referencedSymbols || !referencedSymbols.length ? void 0 : mapDefined(referencedSymbols, ({ definition, references }) => (
            // Only include referenced symbols that have a valid definition.
            definition && {
                definition: checker.runWithCancellationToken(cancellationToken, (checker2) => definitionToReferencedSymbolDefinitionInfo(definition, checker2, node)),
                references: references.map((r) => toReferencedSymbolEntry(r, symbol))
            }));
        }
        function isDefinitionForReference(node) {
            return node.kind === 88 /* DefaultKeyword */ || !!getDeclarationFromName(node) || isLiteralComputedPropertyDeclarationName(node) || node.kind === 135 /* ConstructorKeyword */ && isConstructorDeclaration(node.parent);
        }
        function getImplementationsAtPosition(program, cancellationToken, sourceFiles, sourceFile, position) {
            const node = getTouchingPropertyName(sourceFile, position);
            let referenceEntries;
            const entries = getImplementationReferenceEntries(program, cancellationToken, sourceFiles, node, position);
            if (node.parent.kind === 208 /* PropertyAccessExpression */ || node.parent.kind === 205 /* BindingElement */ || node.parent.kind === 209 /* ElementAccessExpression */ || node.kind === 106 /* SuperKeyword */) {
                referenceEntries = entries && [...entries];
            }
            else if (entries) {
                const queue = createQueue(entries);
                const seenNodes = /* @__PURE__ */ new Map();
                while (!queue.isEmpty()) {
                    const entry = queue.dequeue();
                    if (!addToSeen(seenNodes, getNodeId(entry.node))) {
                        continue;
                    }
                    referenceEntries = append(referenceEntries, entry);
                    const entries2 = getImplementationReferenceEntries(program, cancellationToken, sourceFiles, entry.node, entry.node.pos);
                    if (entries2) {
                        queue.enqueue(...entries2);
                    }
                }
            }
            const checker = program.getTypeChecker();
            return map(referenceEntries, (entry) => toImplementationLocation(entry, checker));
        }
        function getImplementationReferenceEntries(program, cancellationToken, sourceFiles, node, position) {
            if (node.kind === 308 /* SourceFile */) {
                return void 0;
            }
            const checker = program.getTypeChecker();
            if (node.parent.kind === 300 /* ShorthandPropertyAssignment */) {
                const result = [];
                Core.getReferenceEntriesForShorthandPropertyAssignment(node, checker, (node2) => result.push(nodeEntry(node2)));
                return result;
            }
            else if (node.kind === 106 /* SuperKeyword */ || isSuperProperty(node.parent)) {
                const symbol = checker.getSymbolAtLocation(node);
                return symbol.valueDeclaration && [nodeEntry(symbol.valueDeclaration)];
            }
            else {
                return getReferenceEntriesForNode(position, node, program, sourceFiles, cancellationToken, { implementations: true, use: 1 /* References */ });
            }
        }
        function findReferenceOrRenameEntries(program, cancellationToken, sourceFiles, node, position, options, convertEntry) {
            return map(flattenEntries(Core.getReferencedSymbolsForNode(position, node, program, sourceFiles, cancellationToken, options)), (entry) => convertEntry(entry, node, program.getTypeChecker()));
        }
        function getReferenceEntriesForNode(position, node, program, sourceFiles, cancellationToken, options = {}, sourceFilesSet = new Set(sourceFiles.map((f) => f.fileName))) {
            return flattenEntries(Core.getReferencedSymbolsForNode(position, node, program, sourceFiles, cancellationToken, options, sourceFilesSet));
        }
        function flattenEntries(referenceSymbols) {
            return referenceSymbols && flatMap(referenceSymbols, (r) => r.references);
        }
        function definitionToReferencedSymbolDefinitionInfo(def, checker, originalNode) {
            const info = (() => {
                switch (def.type) {
                    case 0 /* Symbol */: {
                        const { symbol } = def;
                        const { displayParts: displayParts2, kind: kind2 } = getDefinitionKindAndDisplayParts(symbol, checker, originalNode);
                        const name2 = displayParts2.map((p) => p.text).join("");
                        const declaration = symbol.declarations && firstOrUndefined(symbol.declarations);
                        const node = declaration ? getNameOfDeclaration(declaration) || declaration : originalNode;
                        return {
                            ...getFileAndTextSpanFromNode(node),
                            name: name2,
                            kind: kind2,
                            displayParts: displayParts2,
                            context: getContextNode(declaration)
                        };
                    }
                    case 1 /* Label */: {
                        const { node } = def;
                        return { ...getFileAndTextSpanFromNode(node), name: node.text, kind: "label" /* label */, displayParts: [displayPart(node.text, 17 /* text */)] };
                    }
                    case 2 /* Keyword */: {
                        const { node } = def;
                        const name2 = tokenToString(node.kind);
                        return { ...getFileAndTextSpanFromNode(node), name: name2, kind: "keyword" /* keyword */, displayParts: [{ text: name2, kind: "keyword" /* keyword */ }] };
                    }
                    case 3 /* This */: {
                        const { node } = def;
                        const symbol = checker.getSymbolAtLocation(node);
                        const displayParts2 = symbol && ts_SymbolDisplay_exports.getSymbolDisplayPartsDocumentationAndSymbolKind(checker, symbol, node.getSourceFile(), getContainerNode(node), node).displayParts || [textPart("this")];
                        return { ...getFileAndTextSpanFromNode(node), name: "this", kind: "var" /* variableElement */, displayParts: displayParts2 };
                    }
                    case 4 /* String */: {
                        const { node } = def;
                        return {
                            ...getFileAndTextSpanFromNode(node),
                            name: node.text,
                            kind: "var" /* variableElement */,
                            displayParts: [displayPart(getTextOfNode(node), 8 /* stringLiteral */)]
                        };
                    }
                    case 5 /* TripleSlashReference */: {
                        return {
                            textSpan: createTextSpanFromRange(def.reference),
                            sourceFile: def.file,
                            name: def.reference.fileName,
                            kind: "string" /* string */,
                            displayParts: [displayPart(`"${def.reference.fileName}"`, 8 /* stringLiteral */)]
                        };
                    }
                    default:
                        return Debug.assertNever(def);
                }
            })();
            const { sourceFile, textSpan, name, kind, displayParts, context } = info;
            return {
                containerKind: "" /* unknown */,
                containerName: "",
                fileName: sourceFile.fileName,
                kind,
                name,
                textSpan,
                displayParts,
                ...toContextSpan(textSpan, sourceFile, context)
            };
        }
        function getFileAndTextSpanFromNode(node) {
            const sourceFile = node.getSourceFile();
            return {
                sourceFile,
                textSpan: getTextSpan(isComputedPropertyName(node) ? node.expression : node, sourceFile)
            };
        }
        function getDefinitionKindAndDisplayParts(symbol, checker, node) {
            const meaning = Core.getIntersectingMeaningFromDeclarations(node, symbol);
            const enclosingDeclaration = symbol.declarations && firstOrUndefined(symbol.declarations) || node;
            const { displayParts, symbolKind } = ts_SymbolDisplay_exports.getSymbolDisplayPartsDocumentationAndSymbolKind(checker, symbol, enclosingDeclaration.getSourceFile(), enclosingDeclaration, enclosingDeclaration, meaning);
            return { displayParts, kind: symbolKind };
        }
        function toRenameLocation(entry, originalNode, checker, providePrefixAndSuffixText) {
            return { ...entryToDocumentSpan(entry), ...providePrefixAndSuffixText && getPrefixAndSuffixText(entry, originalNode, checker) };
        }
        function toReferencedSymbolEntry(entry, symbol) {
            const referenceEntry = toReferenceEntry(entry);
            if (!symbol)
                return referenceEntry;
            return {
                ...referenceEntry,
                isDefinition: entry.kind !== 0 /* Span */ && isDeclarationOfSymbol(entry.node, symbol)
            };
        }
        function toReferenceEntry(entry) {
            const documentSpan = entryToDocumentSpan(entry);
            if (entry.kind === 0 /* Span */) {
                return { ...documentSpan, isWriteAccess: false };
            }
            const { kind, node } = entry;
            return {
                ...documentSpan,
                isWriteAccess: isWriteAccessForReference(node),
                isInString: kind === 2 /* StringLiteral */ ? true : void 0
            };
        }
        function entryToDocumentSpan(entry) {
            if (entry.kind === 0 /* Span */) {
                return { textSpan: entry.textSpan, fileName: entry.fileName };
            }
            else {
                const sourceFile = entry.node.getSourceFile();
                const textSpan = getTextSpan(entry.node, sourceFile);
                return {
                    textSpan,
                    fileName: sourceFile.fileName,
                    ...toContextSpan(textSpan, sourceFile, entry.context)
                };
            }
        }
        function getPrefixAndSuffixText(entry, originalNode, checker) {
            if (entry.kind !== 0 /* Span */ && isIdentifier(originalNode)) {
                const { node, kind } = entry;
                const parent2 = node.parent;
                const name = originalNode.text;
                const isShorthandAssignment = isShorthandPropertyAssignment(parent2);
                if (isShorthandAssignment || isObjectBindingElementWithoutPropertyName(parent2) && parent2.name === node && parent2.dotDotDotToken === void 0) {
                    const prefixColon = { prefixText: name + ": " };
                    const suffixColon = { suffixText: ": " + name };
                    if (kind === 3 /* SearchedLocalFoundProperty */) {
                        return prefixColon;
                    }
                    if (kind === 4 /* SearchedPropertyFoundLocal */) {
                        return suffixColon;
                    }
                    if (isShorthandAssignment) {
                        const grandParent = parent2.parent;
                        if (isObjectLiteralExpression(grandParent) && isBinaryExpression(grandParent.parent) && isModuleExportsAccessExpression(grandParent.parent.left)) {
                            return prefixColon;
                        }
                        return suffixColon;
                    }
                    else {
                        return prefixColon;
                    }
                }
                else if (isImportSpecifier(parent2) && !parent2.propertyName) {
                    const originalSymbol = isExportSpecifier(originalNode.parent) ? checker.getExportSpecifierLocalTargetSymbol(originalNode.parent) : checker.getSymbolAtLocation(originalNode);
                    return contains(originalSymbol.declarations, parent2) ? { prefixText: name + " as " } : emptyOptions;
                }
                else if (isExportSpecifier(parent2) && !parent2.propertyName) {
                    return originalNode === entry.node || checker.getSymbolAtLocation(originalNode) === checker.getSymbolAtLocation(entry.node) ? { prefixText: name + " as " } : { suffixText: " as " + name };
                }
            }
            return emptyOptions;
        }
        function toImplementationLocation(entry, checker) {
            const documentSpan = entryToDocumentSpan(entry);
            if (entry.kind !== 0 /* Span */) {
                const { node } = entry;
                return {
                    ...documentSpan,
                    ...implementationKindDisplayParts(node, checker)
                };
            }
            else {
                return { ...documentSpan, kind: "" /* unknown */, displayParts: [] };
            }
        }
        function implementationKindDisplayParts(node, checker) {
            const symbol = checker.getSymbolAtLocation(isDeclaration(node) && node.name ? node.name : node);
            if (symbol) {
                return getDefinitionKindAndDisplayParts(symbol, checker, node);
            }
            else if (node.kind === 207 /* ObjectLiteralExpression */) {
                return {
                    kind: "interface" /* interfaceElement */,
                    displayParts: [punctuationPart(20 /* OpenParenToken */), textPart("object literal"), punctuationPart(21 /* CloseParenToken */)]
                };
            }
            else if (node.kind === 228 /* ClassExpression */) {
                return {
                    kind: "local class" /* localClassElement */,
                    displayParts: [punctuationPart(20 /* OpenParenToken */), textPart("anonymous local class"), punctuationPart(21 /* CloseParenToken */)]
                };
            }
            else {
                return { kind: getNodeKind(node), displayParts: [] };
            }
        }
        function toHighlightSpan(entry) {
            const documentSpan = entryToDocumentSpan(entry);
            if (entry.kind === 0 /* Span */) {
                return {
                    fileName: documentSpan.fileName,
                    span: {
                        textSpan: documentSpan.textSpan,
                        kind: "reference" /* reference */
                    }
                };
            }
            const writeAccess = isWriteAccessForReference(entry.node);
            const span = {
                textSpan: documentSpan.textSpan,
                kind: writeAccess ? "writtenReference" /* writtenReference */ : "reference" /* reference */,
                isInString: entry.kind === 2 /* StringLiteral */ ? true : void 0,
                ...documentSpan.contextSpan && { contextSpan: documentSpan.contextSpan }
            };
            return { fileName: documentSpan.fileName, span };
        }
        function getTextSpan(node, sourceFile, endNode2) {
            let start = node.getStart(sourceFile);
            let end = (endNode2 || node).getEnd();
            if (isStringLiteralLike(node) && end - start > 2) {
                Debug.assert(endNode2 === void 0);
                start += 1;
                end -= 1;
            }
            return createTextSpanFromBounds(start, end);
        }
        function getTextSpanOfEntry(entry) {
            return entry.kind === 0 /* Span */ ? entry.textSpan : getTextSpan(entry.node, entry.node.getSourceFile());
        }
        function isWriteAccessForReference(node) {
            const decl = getDeclarationFromName(node);
            return !!decl && declarationIsWriteAccess(decl) || node.kind === 88 /* DefaultKeyword */ || isWriteAccess(node);
        }
        function isDeclarationOfSymbol(node, target) {
            var _a2;
            if (!target)
                return false;
            const source = getDeclarationFromName(node) || (node.kind === 88 /* DefaultKeyword */ ? node.parent : isLiteralComputedPropertyDeclarationName(node) ? node.parent.parent : node.kind === 135 /* ConstructorKeyword */ && isConstructorDeclaration(node.parent) ? node.parent.parent : void 0);
            const commonjsSource = source && isBinaryExpression(source) ? source.left : void 0;
            return !!(source && ((_a2 = target.declarations) == null ? void 0 : _a2.some((d) => d === source || d === commonjsSource)));
        }
        function declarationIsWriteAccess(decl) {
            if (!!(decl.flags & 16777216 /* Ambient */))
                return true;
            switch (decl.kind) {
                case 223 /* BinaryExpression */:
                case 205 /* BindingElement */:
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 88 /* DefaultKeyword */:
                case 263 /* EnumDeclaration */:
                case 302 /* EnumMember */:
                case 278 /* ExportSpecifier */:
                case 270 /* ImportClause */:
                case 268 /* ImportEqualsDeclaration */:
                case 273 /* ImportSpecifier */:
                case 261 /* InterfaceDeclaration */:
                case 341 /* JSDocCallbackTag */:
                case 349 /* JSDocTypedefTag */:
                case 288 /* JsxAttribute */:
                case 264 /* ModuleDeclaration */:
                case 267 /* NamespaceExportDeclaration */:
                case 271 /* NamespaceImport */:
                case 277 /* NamespaceExport */:
                case 166 /* Parameter */:
                case 300 /* ShorthandPropertyAssignment */:
                case 262 /* TypeAliasDeclaration */:
                case 165 /* TypeParameter */:
                    return true;
                case 299 /* PropertyAssignment */:
                    return !isArrayLiteralOrObjectLiteralDestructuringPattern(decl.parent);
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 173 /* Constructor */:
                case 171 /* MethodDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    return !!decl.body;
                case 257 /* VariableDeclaration */:
                case 169 /* PropertyDeclaration */:
                    return !!decl.initializer || isCatchClause(decl.parent);
                case 170 /* MethodSignature */:
                case 168 /* PropertySignature */:
                case 351 /* JSDocPropertyTag */:
                case 344 /* JSDocParameterTag */:
                    return false;
                default:
                    return Debug.failBadSyntaxKind(decl);
            }
        }
        var DefinitionKind, EntryKind, FindReferencesUse, Core;
        var init_findAllReferences = __esm({
            "src/services/findAllReferences.ts"() {
                "use strict";
                init_ts4();
                init_ts_FindAllReferences();
                DefinitionKind = /* @__PURE__ */ ((DefinitionKind2) => {
                    DefinitionKind2[DefinitionKind2["Symbol"] = 0] = "Symbol";
                    DefinitionKind2[DefinitionKind2["Label"] = 1] = "Label";
                    DefinitionKind2[DefinitionKind2["Keyword"] = 2] = "Keyword";
                    DefinitionKind2[DefinitionKind2["This"] = 3] = "This";
                    DefinitionKind2[DefinitionKind2["String"] = 4] = "String";
                    DefinitionKind2[DefinitionKind2["TripleSlashReference"] = 5] = "TripleSlashReference";
                    return DefinitionKind2;
                })(DefinitionKind || {});
                EntryKind = /* @__PURE__ */ ((EntryKind2) => {
                    EntryKind2[EntryKind2["Span"] = 0] = "Span";
                    EntryKind2[EntryKind2["Node"] = 1] = "Node";
                    EntryKind2[EntryKind2["StringLiteral"] = 2] = "StringLiteral";
                    EntryKind2[EntryKind2["SearchedLocalFoundProperty"] = 3] = "SearchedLocalFoundProperty";
                    EntryKind2[EntryKind2["SearchedPropertyFoundLocal"] = 4] = "SearchedPropertyFoundLocal";
                    return EntryKind2;
                })(EntryKind || {});
                FindReferencesUse = /* @__PURE__ */ ((FindReferencesUse2) => {
                    FindReferencesUse2[FindReferencesUse2["Other"] = 0] = "Other";
                    FindReferencesUse2[FindReferencesUse2["References"] = 1] = "References";
                    FindReferencesUse2[FindReferencesUse2["Rename"] = 2] = "Rename";
                    return FindReferencesUse2;
                })(FindReferencesUse || {});
                ((Core2) => {
                    function getReferencedSymbolsForNode(position, node, program, sourceFiles, cancellationToken, options = {}, sourceFilesSet = new Set(sourceFiles.map((f) => f.fileName))) {
                        var _a2, _b, _c;
                        node = getAdjustedNode(node, options);
                        if (isSourceFile(node)) {
                            const resolvedRef = ts_GoToDefinition_exports.getReferenceAtPosition(node, position, program);
                            if (!(resolvedRef == null ? void 0 : resolvedRef.file)) {
                                return void 0;
                            }
                            const moduleSymbol = program.getTypeChecker().getMergedSymbol(resolvedRef.file.symbol);
                            if (moduleSymbol) {
                                return getReferencedSymbolsForModule(program, moduleSymbol, 
                                /*excludeImportTypeOfExportEquals*/
                                false, sourceFiles, sourceFilesSet);
                            }
                            const fileIncludeReasons = program.getFileIncludeReasons();
                            if (!fileIncludeReasons) {
                                return void 0;
                            }
                            return [{
                                    definition: { type: 5 /* TripleSlashReference */, reference: resolvedRef.reference, file: node },
                                    references: getReferencesForNonModule(resolvedRef.file, fileIncludeReasons, program) || emptyArray
                                }];
                        }
                        if (!options.implementations) {
                            const special = getReferencedSymbolsSpecial(node, sourceFiles, cancellationToken);
                            if (special) {
                                return special;
                            }
                        }
                        const checker = program.getTypeChecker();
                        const symbol = checker.getSymbolAtLocation(isConstructorDeclaration(node) && node.parent.name || node);
                        if (!symbol) {
                            if (!options.implementations && isStringLiteralLike(node)) {
                                if (isModuleSpecifierLike(node)) {
                                    const fileIncludeReasons = program.getFileIncludeReasons();
                                    const referencedFileName = (_c = (_b = (_a2 = node.getSourceFile().resolvedModules) == null ? void 0 : _a2.get(node.text, getModeForUsageLocation(node.getSourceFile(), node))) == null ? void 0 : _b.resolvedModule) == null ? void 0 : _c.resolvedFileName;
                                    const referencedFile = referencedFileName ? program.getSourceFile(referencedFileName) : void 0;
                                    if (referencedFile) {
                                        return [{ definition: { type: 4 /* String */, node }, references: getReferencesForNonModule(referencedFile, fileIncludeReasons, program) || emptyArray }];
                                    }
                                }
                                return getReferencesForStringLiteral(node, sourceFiles, checker, cancellationToken);
                            }
                            return void 0;
                        }
                        if (symbol.escapedName === "export=" /* ExportEquals */) {
                            return getReferencedSymbolsForModule(program, symbol.parent, 
                            /*excludeImportTypeOfExportEquals*/
                            false, sourceFiles, sourceFilesSet);
                        }
                        const moduleReferences = getReferencedSymbolsForModuleIfDeclaredBySourceFile(symbol, program, sourceFiles, cancellationToken, options, sourceFilesSet);
                        if (moduleReferences && !(symbol.flags & 33554432 /* Transient */)) {
                            return moduleReferences;
                        }
                        const aliasedSymbol = getMergedAliasedSymbolOfNamespaceExportDeclaration(node, symbol, checker);
                        const moduleReferencesOfExportTarget = aliasedSymbol && getReferencedSymbolsForModuleIfDeclaredBySourceFile(aliasedSymbol, program, sourceFiles, cancellationToken, options, sourceFilesSet);
                        const references = getReferencedSymbolsForSymbol(symbol, node, sourceFiles, sourceFilesSet, checker, cancellationToken, options);
                        return mergeReferences(program, moduleReferences, references, moduleReferencesOfExportTarget);
                    }
                    Core2.getReferencedSymbolsForNode = getReferencedSymbolsForNode;
                    function getAdjustedNode(node, options) {
                        if (options.use === 1 /* References */) {
                            node = getAdjustedReferenceLocation(node);
                        }
                        else if (options.use === 2 /* Rename */) {
                            node = getAdjustedRenameLocation(node);
                        }
                        return node;
                    }
                    Core2.getAdjustedNode = getAdjustedNode;
                    function getReferencesForFileName(fileName, program, sourceFiles, sourceFilesSet = new Set(sourceFiles.map((f) => f.fileName))) {
                        var _a2, _b;
                        const moduleSymbol = (_a2 = program.getSourceFile(fileName)) == null ? void 0 : _a2.symbol;
                        if (moduleSymbol) {
                            return ((_b = getReferencedSymbolsForModule(program, moduleSymbol, 
                            /*excludeImportTypeOfExportEquals*/
                            false, sourceFiles, sourceFilesSet)[0]) == null ? void 0 : _b.references) || emptyArray;
                        }
                        const fileIncludeReasons = program.getFileIncludeReasons();
                        const referencedFile = program.getSourceFile(fileName);
                        return referencedFile && fileIncludeReasons && getReferencesForNonModule(referencedFile, fileIncludeReasons, program) || emptyArray;
                    }
                    Core2.getReferencesForFileName = getReferencesForFileName;
                    function getReferencesForNonModule(referencedFile, refFileMap, program) {
                        let entries;
                        const references = refFileMap.get(referencedFile.path) || emptyArray;
                        for (const ref of references) {
                            if (isReferencedFile(ref)) {
                                const referencingFile = program.getSourceFileByPath(ref.file);
                                const location = getReferencedFileLocation(program.getSourceFileByPath, ref);
                                if (isReferenceFileLocation(location)) {
                                    entries = append(entries, {
                                        kind: 0 /* Span */,
                                        fileName: referencingFile.fileName,
                                        textSpan: createTextSpanFromRange(location)
                                    });
                                }
                            }
                        }
                        return entries;
                    }
                    function getMergedAliasedSymbolOfNamespaceExportDeclaration(node, symbol, checker) {
                        if (node.parent && isNamespaceExportDeclaration(node.parent)) {
                            const aliasedSymbol = checker.getAliasedSymbol(symbol);
                            const targetSymbol = checker.getMergedSymbol(aliasedSymbol);
                            if (aliasedSymbol !== targetSymbol) {
                                return targetSymbol;
                            }
                        }
                        return void 0;
                    }
                    function getReferencedSymbolsForModuleIfDeclaredBySourceFile(symbol, program, sourceFiles, cancellationToken, options, sourceFilesSet) {
                        const moduleSourceFile = symbol.flags & 1536 /* Module */ && symbol.declarations && find(symbol.declarations, isSourceFile);
                        if (!moduleSourceFile)
                            return void 0;
                        const exportEquals = symbol.exports.get("export=" /* ExportEquals */);
                        const moduleReferences = getReferencedSymbolsForModule(program, symbol, !!exportEquals, sourceFiles, sourceFilesSet);
                        if (!exportEquals || !sourceFilesSet.has(moduleSourceFile.fileName))
                            return moduleReferences;
                        const checker = program.getTypeChecker();
                        symbol = skipAlias(exportEquals, checker);
                        return mergeReferences(program, moduleReferences, getReferencedSymbolsForSymbol(symbol, 
                        /*node*/
                        void 0, sourceFiles, sourceFilesSet, checker, cancellationToken, options));
                    }
                    function mergeReferences(program, ...referencesToMerge) {
                        let result;
                        for (const references of referencesToMerge) {
                            if (!references || !references.length)
                                continue;
                            if (!result) {
                                result = references;
                                continue;
                            }
                            for (const entry of references) {
                                if (!entry.definition || entry.definition.type !== 0 /* Symbol */) {
                                    result.push(entry);
                                    continue;
                                }
                                const symbol = entry.definition.symbol;
                                const refIndex = findIndex(result, (ref) => !!ref.definition && ref.definition.type === 0 /* Symbol */ && ref.definition.symbol === symbol);
                                if (refIndex === -1) {
                                    result.push(entry);
                                    continue;
                                }
                                const reference = result[refIndex];
                                result[refIndex] = {
                                    definition: reference.definition,
                                    references: reference.references.concat(entry.references).sort((entry1, entry2) => {
                                        const entry1File = getSourceFileIndexOfEntry(program, entry1);
                                        const entry2File = getSourceFileIndexOfEntry(program, entry2);
                                        if (entry1File !== entry2File) {
                                            return compareValues(entry1File, entry2File);
                                        }
                                        const entry1Span = getTextSpanOfEntry(entry1);
                                        const entry2Span = getTextSpanOfEntry(entry2);
                                        return entry1Span.start !== entry2Span.start ? compareValues(entry1Span.start, entry2Span.start) : compareValues(entry1Span.length, entry2Span.length);
                                    })
                                };
                            }
                        }
                        return result;
                    }
                    function getSourceFileIndexOfEntry(program, entry) {
                        const sourceFile = entry.kind === 0 /* Span */ ? program.getSourceFile(entry.fileName) : entry.node.getSourceFile();
                        return program.getSourceFiles().indexOf(sourceFile);
                    }
                    function getReferencedSymbolsForModule(program, symbol, excludeImportTypeOfExportEquals, sourceFiles, sourceFilesSet) {
                        Debug.assert(!!symbol.valueDeclaration);
                        const references = mapDefined(findModuleReferences(program, sourceFiles, symbol), (reference) => {
                            if (reference.kind === "import") {
                                const parent2 = reference.literal.parent;
                                if (isLiteralTypeNode(parent2)) {
                                    const importType = cast(parent2.parent, isImportTypeNode);
                                    if (excludeImportTypeOfExportEquals && !importType.qualifier) {
                                        return void 0;
                                    }
                                }
                                return nodeEntry(reference.literal);
                            }
                            else {
                                return {
                                    kind: 0 /* Span */,
                                    fileName: reference.referencingFile.fileName,
                                    textSpan: createTextSpanFromRange(reference.ref)
                                };
                            }
                        });
                        if (symbol.declarations) {
                            for (const decl of symbol.declarations) {
                                switch (decl.kind) {
                                    case 308 /* SourceFile */:
                                        break;
                                    case 264 /* ModuleDeclaration */:
                                        if (sourceFilesSet.has(decl.getSourceFile().fileName)) {
                                            references.push(nodeEntry(decl.name));
                                        }
                                        break;
                                    default:
                                        Debug.assert(!!(symbol.flags & 33554432 /* Transient */), "Expected a module symbol to be declared by a SourceFile or ModuleDeclaration.");
                                }
                            }
                        }
                        const exported = symbol.exports.get("export=" /* ExportEquals */);
                        if (exported == null ? void 0 : exported.declarations) {
                            for (const decl of exported.declarations) {
                                const sourceFile = decl.getSourceFile();
                                if (sourceFilesSet.has(sourceFile.fileName)) {
                                    const node = isBinaryExpression(decl) && isPropertyAccessExpression(decl.left) ? decl.left.expression : isExportAssignment(decl) ? Debug.checkDefined(findChildOfKind(decl, 93 /* ExportKeyword */, sourceFile)) : getNameOfDeclaration(decl) || decl;
                                    references.push(nodeEntry(node));
                                }
                            }
                        }
                        return references.length ? [{ definition: { type: 0 /* Symbol */, symbol }, references }] : emptyArray;
                    }
                    function isReadonlyTypeOperator(node) {
                        return node.kind === 146 /* ReadonlyKeyword */ && isTypeOperatorNode(node.parent) && node.parent.operator === 146 /* ReadonlyKeyword */;
                    }
                    function getReferencedSymbolsSpecial(node, sourceFiles, cancellationToken) {
                        if (isTypeKeyword(node.kind)) {
                            if (node.kind === 114 /* VoidKeyword */ && isVoidExpression(node.parent)) {
                                return void 0;
                            }
                            if (node.kind === 146 /* ReadonlyKeyword */ && !isReadonlyTypeOperator(node)) {
                                return void 0;
                            }
                            return getAllReferencesForKeyword(sourceFiles, node.kind, cancellationToken, node.kind === 146 /* ReadonlyKeyword */ ? isReadonlyTypeOperator : void 0);
                        }
                        if (isImportMeta(node.parent) && node.parent.name === node) {
                            return getAllReferencesForImportMeta(sourceFiles, cancellationToken);
                        }
                        if (isStaticModifier(node) && isClassStaticBlockDeclaration(node.parent)) {
                            return [{ definition: { type: 2 /* Keyword */, node }, references: [nodeEntry(node)] }];
                        }
                        if (isJumpStatementTarget(node)) {
                            const labelDefinition = getTargetLabel(node.parent, node.text);
                            return labelDefinition && getLabelReferencesInNode(labelDefinition.parent, labelDefinition);
                        }
                        else if (isLabelOfLabeledStatement(node)) {
                            return getLabelReferencesInNode(node.parent, node);
                        }
                        if (isThis(node)) {
                            return getReferencesForThisKeyword(node, sourceFiles, cancellationToken);
                        }
                        if (node.kind === 106 /* SuperKeyword */) {
                            return getReferencesForSuperKeyword(node);
                        }
                        return void 0;
                    }
                    function getReferencedSymbolsForSymbol(originalSymbol, node, sourceFiles, sourceFilesSet, checker, cancellationToken, options) {
                        const symbol = node && skipPastExportOrImportSpecifierOrUnion(originalSymbol, node, checker, 
                        /*useLocalSymbolForExportSpecifier*/
                        !isForRenameWithPrefixAndSuffixText(options)) || originalSymbol;
                        const searchMeaning = node ? getIntersectingMeaningFromDeclarations(node, symbol) : 7 /* All */;
                        const result = [];
                        const state = new State(sourceFiles, sourceFilesSet, node ? getSpecialSearchKind(node) : 0 /* None */, checker, cancellationToken, searchMeaning, options, result);
                        const exportSpecifier = !isForRenameWithPrefixAndSuffixText(options) || !symbol.declarations ? void 0 : find(symbol.declarations, isExportSpecifier);
                        if (exportSpecifier) {
                            getReferencesAtExportSpecifier(exportSpecifier.name, symbol, exportSpecifier, state.createSearch(node, originalSymbol, 
                            /*comingFrom*/
                            void 0), state, 
                            /*addReferencesHere*/
                            true, 
                            /*alwaysGetReferences*/
                            true);
                        }
                        else if (node && node.kind === 88 /* DefaultKeyword */ && symbol.escapedName === "default" /* Default */ && symbol.parent) {
                            addReference(node, symbol, state);
                            searchForImportsOfExport(node, symbol, { exportingModuleSymbol: symbol.parent, exportKind: 1 /* Default */ }, state);
                        }
                        else {
                            const search = state.createSearch(node, symbol, 
                            /*comingFrom*/
                            void 0, { allSearchSymbols: node ? populateSearchSymbolSet(symbol, node, checker, options.use === 2 /* Rename */, !!options.providePrefixAndSuffixTextForRename, !!options.implementations) : [symbol] });
                            getReferencesInContainerOrFiles(symbol, state, search);
                        }
                        return result;
                    }
                    function getReferencesInContainerOrFiles(symbol, state, search) {
                        const scope = getSymbolScope(symbol);
                        if (scope) {
                            getReferencesInContainer(scope, scope.getSourceFile(), search, state, 
                            /*addReferencesHere*/
                            !(isSourceFile(scope) && !contains(state.sourceFiles, scope)));
                        }
                        else {
                            for (const sourceFile of state.sourceFiles) {
                                state.cancellationToken.throwIfCancellationRequested();
                                searchForName(sourceFile, search, state);
                            }
                        }
                    }
                    function getSpecialSearchKind(node) {
                        switch (node.kind) {
                            case 173 /* Constructor */:
                            case 135 /* ConstructorKeyword */:
                                return 1 /* Constructor */;
                            case 79 /* Identifier */:
                                if (isClassLike(node.parent)) {
                                    Debug.assert(node.parent.name === node);
                                    return 2 /* Class */;
                                }
                            default:
                                return 0 /* None */;
                        }
                    }
                    function skipPastExportOrImportSpecifierOrUnion(symbol, node, checker, useLocalSymbolForExportSpecifier) {
                        const { parent: parent2 } = node;
                        if (isExportSpecifier(parent2) && useLocalSymbolForExportSpecifier) {
                            return getLocalSymbolForExportSpecifier(node, symbol, parent2, checker);
                        }
                        return firstDefined(symbol.declarations, (decl) => {
                            if (!decl.parent) {
                                if (symbol.flags & 33554432 /* Transient */)
                                    return void 0;
                                Debug.fail(`Unexpected symbol at ${Debug.formatSyntaxKind(node.kind)}: ${Debug.formatSymbol(symbol)}`);
                            }
                            return isTypeLiteralNode(decl.parent) && isUnionTypeNode(decl.parent.parent) ? checker.getPropertyOfType(checker.getTypeFromTypeNode(decl.parent.parent), symbol.name) : void 0;
                        });
                    }
                    let SpecialSearchKind;
                    ((SpecialSearchKind2) => {
                        SpecialSearchKind2[SpecialSearchKind2["None"] = 0] = "None";
                        SpecialSearchKind2[SpecialSearchKind2["Constructor"] = 1] = "Constructor";
                        SpecialSearchKind2[SpecialSearchKind2["Class"] = 2] = "Class";
                    })(SpecialSearchKind || (SpecialSearchKind = {}));
                    function getNonModuleSymbolOfMergedModuleSymbol(symbol) {
                        if (!(symbol.flags & (1536 /* Module */ | 33554432 /* Transient */)))
                            return void 0;
                        const decl = symbol.declarations && find(symbol.declarations, (d) => !isSourceFile(d) && !isModuleDeclaration(d));
                        return decl && decl.symbol;
                    }
                    class State {
                        constructor(sourceFiles, sourceFilesSet, specialSearchKind, checker, cancellationToken, searchMeaning, options, result) {
                            this.sourceFiles = sourceFiles;
                            this.sourceFilesSet = sourceFilesSet;
                            this.specialSearchKind = specialSearchKind;
                            this.checker = checker;
                            this.cancellationToken = cancellationToken;
                            this.searchMeaning = searchMeaning;
                            this.options = options;
                            this.result = result;
                            /** Cache for `explicitlyinheritsFrom`. */
                            this.inheritsFromCache = /* @__PURE__ */ new Map();
                            /**
                             * Type nodes can contain multiple references to the same type. For example:
                             *      let x: Foo & (Foo & Bar) = ...
                             * Because we are returning the implementation locations and not the identifier locations,
                             * duplicate entries would be returned here as each of the type references is part of
                             * the same implementation. For that reason, check before we add a new entry.
                             */
                            this.markSeenContainingTypeReference = nodeSeenTracker();
                            /**
                             * It's possible that we will encounter the right side of `export { foo as bar } from "x";` more than once.
                             * For example:
                             *     // b.ts
                             *     export { foo as bar } from "./a";
                             *     import { bar } from "./b";
                             *
                             * Normally at `foo as bar` we directly add `foo` and do not locally search for it (since it doesn't declare a local).
                             * But another reference to it may appear in the same source file.
                             * See `tests/cases/fourslash/transitiveExportImports3.ts`.
                             */
                            this.markSeenReExportRHS = nodeSeenTracker();
                            this.symbolIdToReferences = [];
                            // Source file ID → symbol ID → Whether the symbol has been searched for in the source file.
                            this.sourceFileToSeenSymbols = [];
                        }
                        includesSourceFile(sourceFile) {
                            return this.sourceFilesSet.has(sourceFile.fileName);
                        }
                        /** Gets every place to look for references of an exported symbols. See `ImportsResult` in `importTracker.ts` for more documentation. */
                        getImportSearches(exportSymbol, exportInfo) {
                            if (!this.importTracker)
                                this.importTracker = createImportTracker(this.sourceFiles, this.sourceFilesSet, this.checker, this.cancellationToken);
                            return this.importTracker(exportSymbol, exportInfo, this.options.use === 2 /* Rename */);
                        }
                        /** @param allSearchSymbols set of additional symbols for use by `includes`. */
                        createSearch(location, symbol, comingFrom, searchOptions = {}) {
                            const { text = stripQuotes(symbolName(getLocalSymbolForExportDefault(symbol) || getNonModuleSymbolOfMergedModuleSymbol(symbol) || symbol)), allSearchSymbols = [symbol] } = searchOptions;
                            const escapedText = escapeLeadingUnderscores(text);
                            const parents = this.options.implementations && location ? getParentSymbolsOfPropertyAccess(location, symbol, this.checker) : void 0;
                            return { symbol, comingFrom, text, escapedText, parents, allSearchSymbols, includes: (sym) => contains(allSearchSymbols, sym) };
                        }
                        /**
                         * Callback to add references for a particular searched symbol.
                         * This initializes a reference group, so only call this if you will add at least one reference.
                         */
                        referenceAdder(searchSymbol) {
                            const symbolId = getSymbolId(searchSymbol);
                            let references = this.symbolIdToReferences[symbolId];
                            if (!references) {
                                references = this.symbolIdToReferences[symbolId] = [];
                                this.result.push({ definition: { type: 0 /* Symbol */, symbol: searchSymbol }, references });
                            }
                            return (node, kind) => references.push(nodeEntry(node, kind));
                        }
                        /** Add a reference with no associated definition. */
                        addStringOrCommentReference(fileName, textSpan) {
                            this.result.push({
                                definition: void 0,
                                references: [{ kind: 0 /* Span */, fileName, textSpan }]
                            });
                        }
                        /** Returns `true` the first time we search for a symbol in a file and `false` afterwards. */
                        markSearchedSymbols(sourceFile, symbols) {
                            const sourceId = getNodeId(sourceFile);
                            const seenSymbols = this.sourceFileToSeenSymbols[sourceId] || (this.sourceFileToSeenSymbols[sourceId] = /* @__PURE__ */ new Set());
                            let anyNewSymbols = false;
                            for (const sym of symbols) {
                                anyNewSymbols = tryAddToSet(seenSymbols, getSymbolId(sym)) || anyNewSymbols;
                            }
                            return anyNewSymbols;
                        }
                    }
                    function searchForImportsOfExport(exportLocation, exportSymbol, exportInfo, state) {
                        const { importSearches, singleReferences, indirectUsers } = state.getImportSearches(exportSymbol, exportInfo);
                        if (singleReferences.length) {
                            const addRef = state.referenceAdder(exportSymbol);
                            for (const singleRef of singleReferences) {
                                if (shouldAddSingleReference(singleRef, state))
                                    addRef(singleRef);
                            }
                        }
                        for (const [importLocation, importSymbol] of importSearches) {
                            getReferencesInSourceFile(importLocation.getSourceFile(), state.createSearch(importLocation, importSymbol, 1 /* Export */), state);
                        }
                        if (indirectUsers.length) {
                            let indirectSearch;
                            switch (exportInfo.exportKind) {
                                case 0 /* Named */:
                                    indirectSearch = state.createSearch(exportLocation, exportSymbol, 1 /* Export */);
                                    break;
                                case 1 /* Default */:
                                    indirectSearch = state.options.use === 2 /* Rename */ ? void 0 : state.createSearch(exportLocation, exportSymbol, 1 /* Export */, { text: "default" });
                                    break;
                                case 2 /* ExportEquals */:
                                    break;
                            }
                            if (indirectSearch) {
                                for (const indirectUser of indirectUsers) {
                                    searchForName(indirectUser, indirectSearch, state);
                                }
                            }
                        }
                    }
                    function eachExportReference(sourceFiles, checker, cancellationToken, exportSymbol, exportingModuleSymbol, exportName, isDefaultExport, cb) {
                        const importTracker = createImportTracker(sourceFiles, new Set(sourceFiles.map((f) => f.fileName)), checker, cancellationToken);
                        const { importSearches, indirectUsers, singleReferences } = importTracker(exportSymbol, { exportKind: isDefaultExport ? 1 /* Default */ : 0 /* Named */, exportingModuleSymbol }, 
                        /*isForRename*/
                        false);
                        for (const [importLocation] of importSearches) {
                            cb(importLocation);
                        }
                        for (const singleReference of singleReferences) {
                            if (isIdentifier(singleReference) && isImportTypeNode(singleReference.parent)) {
                                cb(singleReference);
                            }
                        }
                        for (const indirectUser of indirectUsers) {
                            for (const node of getPossibleSymbolReferenceNodes(indirectUser, isDefaultExport ? "default" : exportName)) {
                                const symbol = checker.getSymbolAtLocation(node);
                                const hasExportAssignmentDeclaration = some(symbol == null ? void 0 : symbol.declarations, (d) => tryCast(d, isExportAssignment) ? true : false);
                                if (isIdentifier(node) && !isImportOrExportSpecifier(node.parent) && (symbol === exportSymbol || hasExportAssignmentDeclaration)) {
                                    cb(node);
                                }
                            }
                        }
                    }
                    Core2.eachExportReference = eachExportReference;
                    function shouldAddSingleReference(singleRef, state) {
                        if (!hasMatchingMeaning(singleRef, state))
                            return false;
                        if (state.options.use !== 2 /* Rename */)
                            return true;
                        if (!isIdentifier(singleRef))
                            return false;
                        return !(isImportOrExportSpecifier(singleRef.parent) && singleRef.escapedText === "default" /* Default */);
                    }
                    function searchForImportedSymbol(symbol, state) {
                        if (!symbol.declarations)
                            return;
                        for (const declaration of symbol.declarations) {
                            const exportingFile = declaration.getSourceFile();
                            getReferencesInSourceFile(exportingFile, state.createSearch(declaration, symbol, 0 /* Import */), state, state.includesSourceFile(exportingFile));
                        }
                    }
                    function searchForName(sourceFile, search, state) {
                        if (getNameTable(sourceFile).get(search.escapedText) !== void 0) {
                            getReferencesInSourceFile(sourceFile, search, state);
                        }
                    }
                    function getPropertySymbolOfDestructuringAssignment(location, checker) {
                        return isArrayLiteralOrObjectLiteralDestructuringPattern(location.parent.parent) ? checker.getPropertySymbolOfDestructuringAssignment(location) : void 0;
                    }
                    function getSymbolScope(symbol) {
                        const { declarations, flags, parent: parent2, valueDeclaration } = symbol;
                        if (valueDeclaration && (valueDeclaration.kind === 215 /* FunctionExpression */ || valueDeclaration.kind === 228 /* ClassExpression */)) {
                            return valueDeclaration;
                        }
                        if (!declarations) {
                            return void 0;
                        }
                        if (flags & (4 /* Property */ | 8192 /* Method */)) {
                            const privateDeclaration = find(declarations, (d) => hasEffectiveModifier(d, 8 /* Private */) || isPrivateIdentifierClassElementDeclaration(d));
                            if (privateDeclaration) {
                                return getAncestor(privateDeclaration, 260 /* ClassDeclaration */);
                            }
                            return void 0;
                        }
                        if (declarations.some(isObjectBindingElementWithoutPropertyName)) {
                            return void 0;
                        }
                        const exposedByParent = parent2 && !(symbol.flags & 262144 /* TypeParameter */);
                        if (exposedByParent && !(isExternalModuleSymbol(parent2) && !parent2.globalExports)) {
                            return void 0;
                        }
                        let scope;
                        for (const declaration of declarations) {
                            const container = getContainerNode(declaration);
                            if (scope && scope !== container) {
                                return void 0;
                            }
                            if (!container || container.kind === 308 /* SourceFile */ && !isExternalOrCommonJsModule(container)) {
                                return void 0;
                            }
                            scope = container;
                            if (isFunctionExpression(scope)) {
                                let next;
                                while (next = getNextJSDocCommentLocation(scope)) {
                                    scope = next;
                                }
                            }
                        }
                        return exposedByParent ? scope.getSourceFile() : scope;
                    }
                    function isSymbolReferencedInFile(definition, checker, sourceFile, searchContainer = sourceFile) {
                        return eachSymbolReferenceInFile(definition, checker, sourceFile, () => true, searchContainer) || false;
                    }
                    Core2.isSymbolReferencedInFile = isSymbolReferencedInFile;
                    function eachSymbolReferenceInFile(definition, checker, sourceFile, cb, searchContainer = sourceFile) {
                        const symbol = isParameterPropertyDeclaration(definition.parent, definition.parent.parent) ? first(checker.getSymbolsOfParameterPropertyDeclaration(definition.parent, definition.text)) : checker.getSymbolAtLocation(definition);
                        if (!symbol)
                            return void 0;
                        for (const token of getPossibleSymbolReferenceNodes(sourceFile, symbol.name, searchContainer)) {
                            if (!isIdentifier(token) || token === definition || token.escapedText !== definition.escapedText)
                                continue;
                            const referenceSymbol = checker.getSymbolAtLocation(token);
                            if (referenceSymbol === symbol || checker.getShorthandAssignmentValueSymbol(token.parent) === symbol || isExportSpecifier(token.parent) && getLocalSymbolForExportSpecifier(token, referenceSymbol, token.parent, checker) === symbol) {
                                const res = cb(token);
                                if (res)
                                    return res;
                            }
                        }
                    }
                    Core2.eachSymbolReferenceInFile = eachSymbolReferenceInFile;
                    function getTopMostDeclarationNamesInFile(declarationName, sourceFile) {
                        const candidates = filter(getPossibleSymbolReferenceNodes(sourceFile, declarationName), (name) => !!getDeclarationFromName(name));
                        return candidates.reduce((topMost, decl) => {
                            const depth = getDepth(decl);
                            if (!some(topMost.declarationNames) || depth === topMost.depth) {
                                topMost.declarationNames.push(decl);
                                topMost.depth = depth;
                            }
                            else if (depth < topMost.depth) {
                                topMost.declarationNames = [decl];
                                topMost.depth = depth;
                            }
                            return topMost;
                        }, { depth: Infinity, declarationNames: [] }).declarationNames;
                        function getDepth(declaration) {
                            let depth = 0;
                            while (declaration) {
                                declaration = getContainerNode(declaration);
                                depth++;
                            }
                            return depth;
                        }
                    }
                    Core2.getTopMostDeclarationNamesInFile = getTopMostDeclarationNamesInFile;
                    function someSignatureUsage(signature, sourceFiles, checker, cb) {
                        if (!signature.name || !isIdentifier(signature.name))
                            return false;
                        const symbol = Debug.checkDefined(checker.getSymbolAtLocation(signature.name));
                        for (const sourceFile of sourceFiles) {
                            for (const name of getPossibleSymbolReferenceNodes(sourceFile, symbol.name)) {
                                if (!isIdentifier(name) || name === signature.name || name.escapedText !== signature.name.escapedText)
                                    continue;
                                const called = climbPastPropertyAccess(name);
                                const call = isCallExpression(called.parent) && called.parent.expression === called ? called.parent : void 0;
                                const referenceSymbol = checker.getSymbolAtLocation(name);
                                if (referenceSymbol && checker.getRootSymbols(referenceSymbol).some((s) => s === symbol)) {
                                    if (cb(name, call)) {
                                        return true;
                                    }
                                }
                            }
                        }
                        return false;
                    }
                    Core2.someSignatureUsage = someSignatureUsage;
                    function getPossibleSymbolReferenceNodes(sourceFile, symbolName2, container = sourceFile) {
                        return getPossibleSymbolReferencePositions(sourceFile, symbolName2, container).map((pos) => getTouchingPropertyName(sourceFile, pos));
                    }
                    function getPossibleSymbolReferencePositions(sourceFile, symbolName2, container = sourceFile) {
                        const positions = [];
                        if (!symbolName2 || !symbolName2.length) {
                            return positions;
                        }
                        const text = sourceFile.text;
                        const sourceLength = text.length;
                        const symbolNameLength = symbolName2.length;
                        let position = text.indexOf(symbolName2, container.pos);
                        while (position >= 0) {
                            if (position > container.end)
                                break;
                            const endPosition = position + symbolNameLength;
                            if ((position === 0 || !isIdentifierPart(text.charCodeAt(position - 1), 99 /* Latest */)) && (endPosition === sourceLength || !isIdentifierPart(text.charCodeAt(endPosition), 99 /* Latest */))) {
                                positions.push(position);
                            }
                            position = text.indexOf(symbolName2, position + symbolNameLength + 1);
                        }
                        return positions;
                    }
                    function getLabelReferencesInNode(container, targetLabel) {
                        const sourceFile = container.getSourceFile();
                        const labelName = targetLabel.text;
                        const references = mapDefined(getPossibleSymbolReferenceNodes(sourceFile, labelName, container), (node) => (
                        // Only pick labels that are either the target label, or have a target that is the target label
                        node === targetLabel || isJumpStatementTarget(node) && getTargetLabel(node, labelName) === targetLabel ? nodeEntry(node) : void 0));
                        return [{ definition: { type: 1 /* Label */, node: targetLabel }, references }];
                    }
                    function isValidReferencePosition(node, searchSymbolName) {
                        switch (node.kind) {
                            case 80 /* PrivateIdentifier */:
                                if (isJSDocMemberName(node.parent)) {
                                    return true;
                                }
                            case 79 /* Identifier */:
                                return node.text.length === searchSymbolName.length;
                            case 14 /* NoSubstitutionTemplateLiteral */:
                            case 10 /* StringLiteral */: {
                                const str = node;
                                return (isLiteralNameOfPropertyDeclarationOrIndexAccess(str) || isNameOfModuleDeclaration(node) || isExpressionOfExternalModuleImportEqualsDeclaration(node) || isCallExpression(node.parent) && isBindableObjectDefinePropertyCall(node.parent) && node.parent.arguments[1] === node) && str.text.length === searchSymbolName.length;
                            }
                            case 8 /* NumericLiteral */:
                                return isLiteralNameOfPropertyDeclarationOrIndexAccess(node) && node.text.length === searchSymbolName.length;
                            case 88 /* DefaultKeyword */:
                                return "default".length === searchSymbolName.length;
                            default:
                                return false;
                        }
                    }
                    function getAllReferencesForImportMeta(sourceFiles, cancellationToken) {
                        const references = flatMap(sourceFiles, (sourceFile) => {
                            cancellationToken.throwIfCancellationRequested();
                            return mapDefined(getPossibleSymbolReferenceNodes(sourceFile, "meta", sourceFile), (node) => {
                                const parent2 = node.parent;
                                if (isImportMeta(parent2)) {
                                    return nodeEntry(parent2);
                                }
                            });
                        });
                        return references.length ? [{ definition: { type: 2 /* Keyword */, node: references[0].node }, references }] : void 0;
                    }
                    function getAllReferencesForKeyword(sourceFiles, keywordKind, cancellationToken, filter2) {
                        const references = flatMap(sourceFiles, (sourceFile) => {
                            cancellationToken.throwIfCancellationRequested();
                            return mapDefined(getPossibleSymbolReferenceNodes(sourceFile, tokenToString(keywordKind), sourceFile), (referenceLocation) => {
                                if (referenceLocation.kind === keywordKind && (!filter2 || filter2(referenceLocation))) {
                                    return nodeEntry(referenceLocation);
                                }
                            });
                        });
                        return references.length ? [{ definition: { type: 2 /* Keyword */, node: references[0].node }, references }] : void 0;
                    }
                    function getReferencesInSourceFile(sourceFile, search, state, addReferencesHere = true) {
                        state.cancellationToken.throwIfCancellationRequested();
                        return getReferencesInContainer(sourceFile, sourceFile, search, state, addReferencesHere);
                    }
                    function getReferencesInContainer(container, sourceFile, search, state, addReferencesHere) {
                        if (!state.markSearchedSymbols(sourceFile, search.allSearchSymbols)) {
                            return;
                        }
                        for (const position of getPossibleSymbolReferencePositions(sourceFile, search.text, container)) {
                            getReferencesAtLocation(sourceFile, position, search, state, addReferencesHere);
                        }
                    }
                    function hasMatchingMeaning(referenceLocation, state) {
                        return !!(getMeaningFromLocation(referenceLocation) & state.searchMeaning);
                    }
                    function getReferencesAtLocation(sourceFile, position, search, state, addReferencesHere) {
                        const referenceLocation = getTouchingPropertyName(sourceFile, position);
                        if (!isValidReferencePosition(referenceLocation, search.text)) {
                            if (!state.options.implementations && (state.options.findInStrings && isInString(sourceFile, position) || state.options.findInComments && isInNonReferenceComment(sourceFile, position))) {
                                state.addStringOrCommentReference(sourceFile.fileName, createTextSpan(position, search.text.length));
                            }
                            return;
                        }
                        if (!hasMatchingMeaning(referenceLocation, state))
                            return;
                        let referenceSymbol = state.checker.getSymbolAtLocation(referenceLocation);
                        if (!referenceSymbol) {
                            return;
                        }
                        const parent2 = referenceLocation.parent;
                        if (isImportSpecifier(parent2) && parent2.propertyName === referenceLocation) {
                            return;
                        }
                        if (isExportSpecifier(parent2)) {
                            Debug.assert(referenceLocation.kind === 79 /* Identifier */);
                            getReferencesAtExportSpecifier(referenceLocation, referenceSymbol, parent2, search, state, addReferencesHere);
                            return;
                        }
                        const relatedSymbol = getRelatedSymbol(search, referenceSymbol, referenceLocation, state);
                        if (!relatedSymbol) {
                            getReferenceForShorthandProperty(referenceSymbol, search, state);
                            return;
                        }
                        switch (state.specialSearchKind) {
                            case 0 /* None */:
                                if (addReferencesHere)
                                    addReference(referenceLocation, relatedSymbol, state);
                                break;
                            case 1 /* Constructor */:
                                addConstructorReferences(referenceLocation, sourceFile, search, state);
                                break;
                            case 2 /* Class */:
                                addClassStaticThisReferences(referenceLocation, search, state);
                                break;
                            default:
                                Debug.assertNever(state.specialSearchKind);
                        }
                        if (isInJSFile(referenceLocation) && isBindingElement(referenceLocation.parent) && isVariableDeclarationInitializedToBareOrAccessedRequire(referenceLocation.parent.parent.parent)) {
                            referenceSymbol = referenceLocation.parent.symbol;
                            if (!referenceSymbol)
                                return;
                        }
                        getImportOrExportReferences(referenceLocation, referenceSymbol, search, state);
                    }
                    function getReferencesAtExportSpecifier(referenceLocation, referenceSymbol, exportSpecifier, search, state, addReferencesHere, alwaysGetReferences) {
                        Debug.assert(!alwaysGetReferences || !!state.options.providePrefixAndSuffixTextForRename, "If alwaysGetReferences is true, then prefix/suffix text must be enabled");
                        const { parent: parent2, propertyName, name } = exportSpecifier;
                        const exportDeclaration = parent2.parent;
                        const localSymbol = getLocalSymbolForExportSpecifier(referenceLocation, referenceSymbol, exportSpecifier, state.checker);
                        if (!alwaysGetReferences && !search.includes(localSymbol)) {
                            return;
                        }
                        if (!propertyName) {
                            if (!(state.options.use === 2 /* Rename */ && name.escapedText === "default" /* Default */)) {
                                addRef();
                            }
                        }
                        else if (referenceLocation === propertyName) {
                            if (!exportDeclaration.moduleSpecifier) {
                                addRef();
                            }
                            if (addReferencesHere && state.options.use !== 2 /* Rename */ && state.markSeenReExportRHS(name)) {
                                addReference(name, Debug.checkDefined(exportSpecifier.symbol), state);
                            }
                        }
                        else {
                            if (state.markSeenReExportRHS(referenceLocation)) {
                                addRef();
                            }
                        }
                        if (!isForRenameWithPrefixAndSuffixText(state.options) || alwaysGetReferences) {
                            const isDefaultExport = referenceLocation.escapedText === "default" || exportSpecifier.name.escapedText === "default";
                            const exportKind = isDefaultExport ? 1 /* Default */ : 0 /* Named */;
                            const exportSymbol = Debug.checkDefined(exportSpecifier.symbol);
                            const exportInfo = getExportInfo(exportSymbol, exportKind, state.checker);
                            if (exportInfo) {
                                searchForImportsOfExport(referenceLocation, exportSymbol, exportInfo, state);
                            }
                        }
                        if (search.comingFrom !== 1 /* Export */ && exportDeclaration.moduleSpecifier && !propertyName && !isForRenameWithPrefixAndSuffixText(state.options)) {
                            const imported = state.checker.getExportSpecifierLocalTargetSymbol(exportSpecifier);
                            if (imported)
                                searchForImportedSymbol(imported, state);
                        }
                        function addRef() {
                            if (addReferencesHere)
                                addReference(referenceLocation, localSymbol, state);
                        }
                    }
                    function getLocalSymbolForExportSpecifier(referenceLocation, referenceSymbol, exportSpecifier, checker) {
                        return isExportSpecifierAlias(referenceLocation, exportSpecifier) && checker.getExportSpecifierLocalTargetSymbol(exportSpecifier) || referenceSymbol;
                    }
                    function isExportSpecifierAlias(referenceLocation, exportSpecifier) {
                        const { parent: parent2, propertyName, name } = exportSpecifier;
                        Debug.assert(propertyName === referenceLocation || name === referenceLocation);
                        if (propertyName) {
                            return propertyName === referenceLocation;
                        }
                        else {
                            return !parent2.parent.moduleSpecifier;
                        }
                    }
                    function getImportOrExportReferences(referenceLocation, referenceSymbol, search, state) {
                        const importOrExport = getImportOrExportSymbol(referenceLocation, referenceSymbol, state.checker, search.comingFrom === 1 /* Export */);
                        if (!importOrExport)
                            return;
                        const { symbol } = importOrExport;
                        if (importOrExport.kind === 0 /* Import */) {
                            if (!isForRenameWithPrefixAndSuffixText(state.options)) {
                                searchForImportedSymbol(symbol, state);
                            }
                        }
                        else {
                            searchForImportsOfExport(referenceLocation, symbol, importOrExport.exportInfo, state);
                        }
                    }
                    function getReferenceForShorthandProperty({ flags, valueDeclaration }, search, state) {
                        const shorthandValueSymbol = state.checker.getShorthandAssignmentValueSymbol(valueDeclaration);
                        const name = valueDeclaration && getNameOfDeclaration(valueDeclaration);
                        if (!(flags & 33554432 /* Transient */) && name && search.includes(shorthandValueSymbol)) {
                            addReference(name, shorthandValueSymbol, state);
                        }
                    }
                    function addReference(referenceLocation, relatedSymbol, state) {
                        const { kind, symbol } = "kind" in relatedSymbol ? relatedSymbol : { kind: void 0, symbol: relatedSymbol };
                        if (state.options.use === 2 /* Rename */ && referenceLocation.kind === 88 /* DefaultKeyword */) {
                            return;
                        }
                        const addRef = state.referenceAdder(symbol);
                        if (state.options.implementations) {
                            addImplementationReferences(referenceLocation, addRef, state);
                        }
                        else {
                            addRef(referenceLocation, kind);
                        }
                    }
                    function addConstructorReferences(referenceLocation, sourceFile, search, state) {
                        if (isNewExpressionTarget(referenceLocation)) {
                            addReference(referenceLocation, search.symbol, state);
                        }
                        const pusher = () => state.referenceAdder(search.symbol);
                        if (isClassLike(referenceLocation.parent)) {
                            Debug.assert(referenceLocation.kind === 88 /* DefaultKeyword */ || referenceLocation.parent.name === referenceLocation);
                            findOwnConstructorReferences(search.symbol, sourceFile, pusher());
                        }
                        else {
                            const classExtending = tryGetClassByExtendingIdentifier(referenceLocation);
                            if (classExtending) {
                                findSuperConstructorAccesses(classExtending, pusher());
                                findInheritedConstructorReferences(classExtending, state);
                            }
                        }
                    }
                    function addClassStaticThisReferences(referenceLocation, search, state) {
                        addReference(referenceLocation, search.symbol, state);
                        const classLike = referenceLocation.parent;
                        if (state.options.use === 2 /* Rename */ || !isClassLike(classLike))
                            return;
                        Debug.assert(classLike.name === referenceLocation);
                        const addRef = state.referenceAdder(search.symbol);
                        for (const member of classLike.members) {
                            if (!(isMethodOrAccessor(member) && isStatic(member))) {
                                continue;
                            }
                            if (member.body) {
                                member.body.forEachChild(function cb(node) {
                                    if (node.kind === 108 /* ThisKeyword */) {
                                        addRef(node);
                                    }
                                    else if (!isFunctionLike(node) && !isClassLike(node)) {
                                        node.forEachChild(cb);
                                    }
                                });
                            }
                        }
                    }
                    function findOwnConstructorReferences(classSymbol, sourceFile, addNode) {
                        const constructorSymbol = getClassConstructorSymbol(classSymbol);
                        if (constructorSymbol && constructorSymbol.declarations) {
                            for (const decl of constructorSymbol.declarations) {
                                const ctrKeyword = findChildOfKind(decl, 135 /* ConstructorKeyword */, sourceFile);
                                Debug.assert(decl.kind === 173 /* Constructor */ && !!ctrKeyword);
                                addNode(ctrKeyword);
                            }
                        }
                        if (classSymbol.exports) {
                            classSymbol.exports.forEach((member) => {
                                const decl = member.valueDeclaration;
                                if (decl && decl.kind === 171 /* MethodDeclaration */) {
                                    const body = decl.body;
                                    if (body) {
                                        forEachDescendantOfKind(body, 108 /* ThisKeyword */, (thisKeyword) => {
                                            if (isNewExpressionTarget(thisKeyword)) {
                                                addNode(thisKeyword);
                                            }
                                        });
                                    }
                                }
                            });
                        }
                    }
                    function getClassConstructorSymbol(classSymbol) {
                        return classSymbol.members && classSymbol.members.get("__constructor" /* Constructor */);
                    }
                    function findSuperConstructorAccesses(classDeclaration, addNode) {
                        const constructor = getClassConstructorSymbol(classDeclaration.symbol);
                        if (!(constructor && constructor.declarations)) {
                            return;
                        }
                        for (const decl of constructor.declarations) {
                            Debug.assert(decl.kind === 173 /* Constructor */);
                            const body = decl.body;
                            if (body) {
                                forEachDescendantOfKind(body, 106 /* SuperKeyword */, (node) => {
                                    if (isCallExpressionTarget(node)) {
                                        addNode(node);
                                    }
                                });
                            }
                        }
                    }
                    function hasOwnConstructor(classDeclaration) {
                        return !!getClassConstructorSymbol(classDeclaration.symbol);
                    }
                    function findInheritedConstructorReferences(classDeclaration, state) {
                        if (hasOwnConstructor(classDeclaration))
                            return;
                        const classSymbol = classDeclaration.symbol;
                        const search = state.createSearch(
                        /*location*/
                        void 0, classSymbol, 
                        /*comingFrom*/
                        void 0);
                        getReferencesInContainerOrFiles(classSymbol, state, search);
                    }
                    function addImplementationReferences(refNode, addReference2, state) {
                        if (isDeclarationName(refNode) && isImplementation(refNode.parent)) {
                            addReference2(refNode);
                            return;
                        }
                        if (refNode.kind !== 79 /* Identifier */) {
                            return;
                        }
                        if (refNode.parent.kind === 300 /* ShorthandPropertyAssignment */) {
                            getReferenceEntriesForShorthandPropertyAssignment(refNode, state.checker, addReference2);
                        }
                        const containingClass = getContainingClassIfInHeritageClause(refNode);
                        if (containingClass) {
                            addReference2(containingClass);
                            return;
                        }
                        const typeNode = findAncestor(refNode, (a) => !isQualifiedName(a.parent) && !isTypeNode(a.parent) && !isTypeElement(a.parent));
                        const typeHavingNode = typeNode.parent;
                        if (hasType(typeHavingNode) && typeHavingNode.type === typeNode && state.markSeenContainingTypeReference(typeHavingNode)) {
                            if (hasInitializer(typeHavingNode)) {
                                addIfImplementation(typeHavingNode.initializer);
                            }
                            else if (isFunctionLike(typeHavingNode) && typeHavingNode.body) {
                                const body = typeHavingNode.body;
                                if (body.kind === 238 /* Block */) {
                                    forEachReturnStatement(body, (returnStatement) => {
                                        if (returnStatement.expression)
                                            addIfImplementation(returnStatement.expression);
                                    });
                                }
                                else {
                                    addIfImplementation(body);
                                }
                            }
                            else if (isAssertionExpression(typeHavingNode)) {
                                addIfImplementation(typeHavingNode.expression);
                            }
                        }
                        function addIfImplementation(e) {
                            if (isImplementationExpression(e))
                                addReference2(e);
                        }
                    }
                    function getContainingClassIfInHeritageClause(node) {
                        return isIdentifier(node) || isPropertyAccessExpression(node) ? getContainingClassIfInHeritageClause(node.parent) : isExpressionWithTypeArguments(node) ? tryCast(node.parent.parent, isClassLike) : void 0;
                    }
                    function isImplementationExpression(node) {
                        switch (node.kind) {
                            case 214 /* ParenthesizedExpression */:
                                return isImplementationExpression(node.expression);
                            case 216 /* ArrowFunction */:
                            case 215 /* FunctionExpression */:
                            case 207 /* ObjectLiteralExpression */:
                            case 228 /* ClassExpression */:
                            case 206 /* ArrayLiteralExpression */:
                                return true;
                            default:
                                return false;
                        }
                    }
                    function explicitlyInheritsFrom(symbol, parent2, cachedResults, checker) {
                        if (symbol === parent2) {
                            return true;
                        }
                        const key = getSymbolId(symbol) + "," + getSymbolId(parent2);
                        const cached = cachedResults.get(key);
                        if (cached !== void 0) {
                            return cached;
                        }
                        cachedResults.set(key, false);
                        const inherits = !!symbol.declarations && symbol.declarations.some((declaration) => getAllSuperTypeNodes(declaration).some((typeReference) => {
                            const type = checker.getTypeAtLocation(typeReference);
                            return !!type && !!type.symbol && explicitlyInheritsFrom(type.symbol, parent2, cachedResults, checker);
                        }));
                        cachedResults.set(key, inherits);
                        return inherits;
                    }
                    function getReferencesForSuperKeyword(superKeyword) {
                        let searchSpaceNode = getSuperContainer(superKeyword, 
                        /*stopOnFunctions*/
                        false);
                        if (!searchSpaceNode) {
                            return void 0;
                        }
                        let staticFlag = 32 /* Static */;
                        switch (searchSpaceNode.kind) {
                            case 169 /* PropertyDeclaration */:
                            case 168 /* PropertySignature */:
                            case 171 /* MethodDeclaration */:
                            case 170 /* MethodSignature */:
                            case 173 /* Constructor */:
                            case 174 /* GetAccessor */:
                            case 175 /* SetAccessor */:
                                staticFlag &= getSyntacticModifierFlags(searchSpaceNode);
                                searchSpaceNode = searchSpaceNode.parent;
                                break;
                            default:
                                return void 0;
                        }
                        const sourceFile = searchSpaceNode.getSourceFile();
                        const references = mapDefined(getPossibleSymbolReferenceNodes(sourceFile, "super", searchSpaceNode), (node) => {
                            if (node.kind !== 106 /* SuperKeyword */) {
                                return;
                            }
                            const container = getSuperContainer(node, 
                            /*stopOnFunctions*/
                            false);
                            return container && isStatic(container) === !!staticFlag && container.parent.symbol === searchSpaceNode.symbol ? nodeEntry(node) : void 0;
                        });
                        return [{ definition: { type: 0 /* Symbol */, symbol: searchSpaceNode.symbol }, references }];
                    }
                    function isParameterName(node) {
                        return node.kind === 79 /* Identifier */ && node.parent.kind === 166 /* Parameter */ && node.parent.name === node;
                    }
                    function getReferencesForThisKeyword(thisOrSuperKeyword, sourceFiles, cancellationToken) {
                        let searchSpaceNode = getThisContainer(thisOrSuperKeyword, 
                        /* includeArrowFunctions */
                        false, 
                        /*includeClassComputedPropertyName*/
                        false);
                        let staticFlag = 32 /* Static */;
                        switch (searchSpaceNode.kind) {
                            case 171 /* MethodDeclaration */:
                            case 170 /* MethodSignature */:
                                if (isObjectLiteralMethod(searchSpaceNode)) {
                                    staticFlag &= getSyntacticModifierFlags(searchSpaceNode);
                                    searchSpaceNode = searchSpaceNode.parent;
                                    break;
                                }
                            case 169 /* PropertyDeclaration */:
                            case 168 /* PropertySignature */:
                            case 173 /* Constructor */:
                            case 174 /* GetAccessor */:
                            case 175 /* SetAccessor */:
                                staticFlag &= getSyntacticModifierFlags(searchSpaceNode);
                                searchSpaceNode = searchSpaceNode.parent;
                                break;
                            case 308 /* SourceFile */:
                                if (isExternalModule(searchSpaceNode) || isParameterName(thisOrSuperKeyword)) {
                                    return void 0;
                                }
                            case 259 /* FunctionDeclaration */:
                            case 215 /* FunctionExpression */:
                                break;
                            default:
                                return void 0;
                        }
                        const references = flatMap(searchSpaceNode.kind === 308 /* SourceFile */ ? sourceFiles : [searchSpaceNode.getSourceFile()], (sourceFile) => {
                            cancellationToken.throwIfCancellationRequested();
                            return getPossibleSymbolReferenceNodes(sourceFile, "this", isSourceFile(searchSpaceNode) ? sourceFile : searchSpaceNode).filter((node) => {
                                if (!isThis(node)) {
                                    return false;
                                }
                                const container = getThisContainer(node, 
                                /* includeArrowFunctions */
                                false, 
                                /*includeClassComputedPropertyName*/
                                false);
                                if (!canHaveSymbol(container))
                                    return false;
                                switch (searchSpaceNode.kind) {
                                    case 215 /* FunctionExpression */:
                                    case 259 /* FunctionDeclaration */:
                                        return searchSpaceNode.symbol === container.symbol;
                                    case 171 /* MethodDeclaration */:
                                    case 170 /* MethodSignature */:
                                        return isObjectLiteralMethod(searchSpaceNode) && searchSpaceNode.symbol === container.symbol;
                                    case 228 /* ClassExpression */:
                                    case 260 /* ClassDeclaration */:
                                    case 207 /* ObjectLiteralExpression */:
                                        return container.parent && canHaveSymbol(container.parent) && searchSpaceNode.symbol === container.parent.symbol && isStatic(container) === !!staticFlag;
                                    case 308 /* SourceFile */:
                                        return container.kind === 308 /* SourceFile */ && !isExternalModule(container) && !isParameterName(node);
                                }
                            });
                        }).map((n) => nodeEntry(n));
                        const thisParameter = firstDefined(references, (r) => isParameter(r.node.parent) ? r.node : void 0);
                        return [{
                                definition: { type: 3 /* This */, node: thisParameter || thisOrSuperKeyword },
                                references
                            }];
                    }
                    function getReferencesForStringLiteral(node, sourceFiles, checker, cancellationToken) {
                        const type = getContextualTypeFromParentOrAncestorTypeNode(node, checker);
                        const references = flatMap(sourceFiles, (sourceFile) => {
                            cancellationToken.throwIfCancellationRequested();
                            return mapDefined(getPossibleSymbolReferenceNodes(sourceFile, node.text), (ref) => {
                                if (isStringLiteralLike(ref) && ref.text === node.text) {
                                    if (type) {
                                        const refType = getContextualTypeFromParentOrAncestorTypeNode(ref, checker);
                                        if (type !== checker.getStringType() && type === refType) {
                                            return nodeEntry(ref, 2 /* StringLiteral */);
                                        }
                                    }
                                    else {
                                        return isNoSubstitutionTemplateLiteral(ref) && !rangeIsOnSingleLine(ref, sourceFile) ? void 0 : nodeEntry(ref, 2 /* StringLiteral */);
                                    }
                                }
                            });
                        });
                        return [{
                                definition: { type: 4 /* String */, node },
                                references
                            }];
                    }
                    function populateSearchSymbolSet(symbol, location, checker, isForRename, providePrefixAndSuffixText, implementations) {
                        const result = [];
                        forEachRelatedSymbol(symbol, location, checker, isForRename, !(isForRename && providePrefixAndSuffixText), (sym, root, base) => {
                            if (base) {
                                if (isStaticSymbol(symbol) !== isStaticSymbol(base)) {
                                    base = void 0;
                                }
                            }
                            result.push(base || root || sym);
                        }, 
                        // when try to find implementation, implementations is true, and not allowed to find base class
                        /*allowBaseTypes*/
                        () => !implementations);
                        return result;
                    }
                    function forEachRelatedSymbol(symbol, location, checker, isForRenamePopulateSearchSymbolSet, onlyIncludeBindingElementAtReferenceLocation, cbSymbol, allowBaseTypes) {
                        const containingObjectLiteralElement = getContainingObjectLiteralElement(location);
                        if (containingObjectLiteralElement) {
                            const shorthandValueSymbol = checker.getShorthandAssignmentValueSymbol(location.parent);
                            if (shorthandValueSymbol && isForRenamePopulateSearchSymbolSet) {
                                return cbSymbol(shorthandValueSymbol, 
                                /*rootSymbol*/
                                void 0, 
                                /*baseSymbol*/
                                void 0, 3 /* SearchedLocalFoundProperty */);
                            }
                            const contextualType = checker.getContextualType(containingObjectLiteralElement.parent);
                            const res2 = contextualType && firstDefined(getPropertySymbolsFromContextualType(containingObjectLiteralElement, checker, contextualType, 
                            /*unionSymbolOk*/
                            true), (sym) => fromRoot(sym, 4 /* SearchedPropertyFoundLocal */));
                            if (res2)
                                return res2;
                            const propertySymbol = getPropertySymbolOfDestructuringAssignment(location, checker);
                            const res1 = propertySymbol && cbSymbol(propertySymbol, 
                            /*rootSymbol*/
                            void 0, 
                            /*baseSymbol*/
                            void 0, 4 /* SearchedPropertyFoundLocal */);
                            if (res1)
                                return res1;
                            const res22 = shorthandValueSymbol && cbSymbol(shorthandValueSymbol, 
                            /*rootSymbol*/
                            void 0, 
                            /*baseSymbol*/
                            void 0, 3 /* SearchedLocalFoundProperty */);
                            if (res22)
                                return res22;
                        }
                        const aliasedSymbol = getMergedAliasedSymbolOfNamespaceExportDeclaration(location, symbol, checker);
                        if (aliasedSymbol) {
                            const res2 = cbSymbol(aliasedSymbol, 
                            /*rootSymbol*/
                            void 0, 
                            /*baseSymbol*/
                            void 0, 1 /* Node */);
                            if (res2)
                                return res2;
                        }
                        const res = fromRoot(symbol);
                        if (res)
                            return res;
                        if (symbol.valueDeclaration && isParameterPropertyDeclaration(symbol.valueDeclaration, symbol.valueDeclaration.parent)) {
                            const paramProps = checker.getSymbolsOfParameterPropertyDeclaration(cast(symbol.valueDeclaration, isParameter), symbol.name);
                            Debug.assert(paramProps.length === 2 && !!(paramProps[0].flags & 1 /* FunctionScopedVariable */) && !!(paramProps[1].flags & 4 /* Property */));
                            return fromRoot(symbol.flags & 1 /* FunctionScopedVariable */ ? paramProps[1] : paramProps[0]);
                        }
                        const exportSpecifier = getDeclarationOfKind(symbol, 278 /* ExportSpecifier */);
                        if (!isForRenamePopulateSearchSymbolSet || exportSpecifier && !exportSpecifier.propertyName) {
                            const localSymbol = exportSpecifier && checker.getExportSpecifierLocalTargetSymbol(exportSpecifier);
                            if (localSymbol) {
                                const res2 = cbSymbol(localSymbol, 
                                /*rootSymbol*/
                                void 0, 
                                /*baseSymbol*/
                                void 0, 1 /* Node */);
                                if (res2)
                                    return res2;
                            }
                        }
                        if (!isForRenamePopulateSearchSymbolSet) {
                            let bindingElementPropertySymbol;
                            if (onlyIncludeBindingElementAtReferenceLocation) {
                                bindingElementPropertySymbol = isObjectBindingElementWithoutPropertyName(location.parent) ? getPropertySymbolFromBindingElement(checker, location.parent) : void 0;
                            }
                            else {
                                bindingElementPropertySymbol = getPropertySymbolOfObjectBindingPatternWithoutPropertyName(symbol, checker);
                            }
                            return bindingElementPropertySymbol && fromRoot(bindingElementPropertySymbol, 4 /* SearchedPropertyFoundLocal */);
                        }
                        Debug.assert(isForRenamePopulateSearchSymbolSet);
                        const includeOriginalSymbolOfBindingElement = onlyIncludeBindingElementAtReferenceLocation;
                        if (includeOriginalSymbolOfBindingElement) {
                            const bindingElementPropertySymbol = getPropertySymbolOfObjectBindingPatternWithoutPropertyName(symbol, checker);
                            return bindingElementPropertySymbol && fromRoot(bindingElementPropertySymbol, 4 /* SearchedPropertyFoundLocal */);
                        }
                        function fromRoot(sym, kind) {
                            return firstDefined(checker.getRootSymbols(sym), (rootSymbol) => cbSymbol(sym, rootSymbol, 
                            /*baseSymbol*/
                            void 0, kind) || (rootSymbol.parent && rootSymbol.parent.flags & (32 /* Class */ | 64 /* Interface */) && allowBaseTypes(rootSymbol) ? getPropertySymbolsFromBaseTypes(rootSymbol.parent, rootSymbol.name, checker, (base) => cbSymbol(sym, rootSymbol, base, kind)) : void 0));
                        }
                        function getPropertySymbolOfObjectBindingPatternWithoutPropertyName(symbol2, checker2) {
                            const bindingElement = getDeclarationOfKind(symbol2, 205 /* BindingElement */);
                            if (bindingElement && isObjectBindingElementWithoutPropertyName(bindingElement)) {
                                return getPropertySymbolFromBindingElement(checker2, bindingElement);
                            }
                        }
                    }
                    function getPropertySymbolsFromBaseTypes(symbol, propertyName, checker, cb) {
                        const seen = /* @__PURE__ */ new Map();
                        return recur(symbol);
                        function recur(symbol2) {
                            if (!(symbol2.flags & (32 /* Class */ | 64 /* Interface */)) || !addToSeen(seen, getSymbolId(symbol2)))
                                return;
                            return firstDefined(symbol2.declarations, (declaration) => firstDefined(getAllSuperTypeNodes(declaration), (typeReference) => {
                                const type = checker.getTypeAtLocation(typeReference);
                                const propertySymbol = type && type.symbol && checker.getPropertyOfType(type, propertyName);
                                return type && propertySymbol && (firstDefined(checker.getRootSymbols(propertySymbol), cb) || recur(type.symbol));
                            }));
                        }
                    }
                    function isStaticSymbol(symbol) {
                        if (!symbol.valueDeclaration)
                            return false;
                        const modifierFlags = getEffectiveModifierFlags(symbol.valueDeclaration);
                        return !!(modifierFlags & 32 /* Static */);
                    }
                    function getRelatedSymbol(search, referenceSymbol, referenceLocation, state) {
                        const { checker } = state;
                        return forEachRelatedSymbol(referenceSymbol, referenceLocation, checker, 
                        /*isForRenamePopulateSearchSymbolSet*/
                        false, 
                        /*onlyIncludeBindingElementAtReferenceLocation*/
                        state.options.use !== 2 /* Rename */ || !!state.options.providePrefixAndSuffixTextForRename, (sym, rootSymbol, baseSymbol, kind) => {
                            if (baseSymbol) {
                                if (isStaticSymbol(referenceSymbol) !== isStaticSymbol(baseSymbol)) {
                                    baseSymbol = void 0;
                                }
                            }
                            return search.includes(baseSymbol || rootSymbol || sym) ? { symbol: rootSymbol && !(getCheckFlags(sym) & 6 /* Synthetic */) ? rootSymbol : sym, kind } : void 0;
                        }, 
                        /*allowBaseTypes*/
                        (rootSymbol) => !(search.parents && !search.parents.some((parent2) => explicitlyInheritsFrom(rootSymbol.parent, parent2, state.inheritsFromCache, checker))));
                    }
                    function getIntersectingMeaningFromDeclarations(node, symbol) {
                        let meaning = getMeaningFromLocation(node);
                        const { declarations } = symbol;
                        if (declarations) {
                            let lastIterationMeaning;
                            do {
                                lastIterationMeaning = meaning;
                                for (const declaration of declarations) {
                                    const declarationMeaning = getMeaningFromDeclaration(declaration);
                                    if (declarationMeaning & meaning) {
                                        meaning |= declarationMeaning;
                                    }
                                }
                            } while (meaning !== lastIterationMeaning);
                        }
                        return meaning;
                    }
                    Core2.getIntersectingMeaningFromDeclarations = getIntersectingMeaningFromDeclarations;
                    function isImplementation(node) {
                        return !!(node.flags & 16777216 /* Ambient */) ? !(isInterfaceDeclaration(node) || isTypeAliasDeclaration(node)) : isVariableLike(node) ? hasInitializer(node) : isFunctionLikeDeclaration(node) ? !!node.body : isClassLike(node) || isModuleOrEnumDeclaration(node);
                    }
                    function getReferenceEntriesForShorthandPropertyAssignment(node, checker, addReference2) {
                        const refSymbol = checker.getSymbolAtLocation(node);
                        const shorthandSymbol = checker.getShorthandAssignmentValueSymbol(refSymbol.valueDeclaration);
                        if (shorthandSymbol) {
                            for (const declaration of shorthandSymbol.getDeclarations()) {
                                if (getMeaningFromDeclaration(declaration) & 1 /* Value */) {
                                    addReference2(declaration);
                                }
                            }
                        }
                    }
                    Core2.getReferenceEntriesForShorthandPropertyAssignment = getReferenceEntriesForShorthandPropertyAssignment;
                    function forEachDescendantOfKind(node, kind, action) {
                        forEachChild(node, (child) => {
                            if (child.kind === kind) {
                                action(child);
                            }
                            forEachDescendantOfKind(child, kind, action);
                        });
                    }
                    function tryGetClassByExtendingIdentifier(node) {
                        return tryGetClassExtendingExpressionWithTypeArguments(climbPastPropertyAccess(node).parent);
                    }
                    function getParentSymbolsOfPropertyAccess(location, symbol, checker) {
                        const propertyAccessExpression = isRightSideOfPropertyAccess(location) ? location.parent : void 0;
                        const lhsType = propertyAccessExpression && checker.getTypeAtLocation(propertyAccessExpression.expression);
                        const res = mapDefined(lhsType && (lhsType.isUnionOrIntersection() ? lhsType.types : lhsType.symbol === symbol.parent ? void 0 : [lhsType]), (t) => t.symbol && t.symbol.flags & (32 /* Class */ | 64 /* Interface */) ? t.symbol : void 0);
                        return res.length === 0 ? void 0 : res;
                    }
                    function isForRenameWithPrefixAndSuffixText(options) {
                        return options.use === 2 /* Rename */ && options.providePrefixAndSuffixTextForRename;
                    }
                })(Core || (Core = {}));
            }
        });
        // src/services/_namespaces/ts.FindAllReferences.ts
        var ts_FindAllReferences_exports = {};
        __export(ts_FindAllReferences_exports, {
            Core: () => Core,
            DefinitionKind: () => DefinitionKind,
            EntryKind: () => EntryKind,
            ExportKind: () => ExportKind2,
            FindReferencesUse: () => FindReferencesUse,
            ImportExport: () => ImportExport,
            createImportTracker: () => createImportTracker,
            findModuleReferences: () => findModuleReferences,
            findReferenceOrRenameEntries: () => findReferenceOrRenameEntries,
            findReferencedSymbols: () => findReferencedSymbols,
            getContextNode: () => getContextNode,
            getExportInfo: () => getExportInfo,
            getImplementationsAtPosition: () => getImplementationsAtPosition,
            getImportOrExportSymbol: () => getImportOrExportSymbol,
            getReferenceEntriesForNode: () => getReferenceEntriesForNode,
            getTextSpanOfEntry: () => getTextSpanOfEntry,
            isContextWithStartAndEndNode: () => isContextWithStartAndEndNode,
            isDeclarationOfSymbol: () => isDeclarationOfSymbol,
            nodeEntry: () => nodeEntry,
            toContextSpan: () => toContextSpan,
            toHighlightSpan: () => toHighlightSpan,
            toReferenceEntry: () => toReferenceEntry,
            toRenameLocation: () => toRenameLocation
        });
        var init_ts_FindAllReferences = __esm({
            "src/services/_namespaces/ts.FindAllReferences.ts"() {
                "use strict";
                init_importTracker();
                init_findAllReferences();
            }
        });
        // src/services/goToDefinition.ts
        function getDefinitionAtPosition(program, sourceFile, position, searchOtherFilesOnly, stopAtAlias) {
            var _a2, _b;
            const resolvedRef = getReferenceAtPosition(sourceFile, position, program);
            const fileReferenceDefinition = resolvedRef && [getDefinitionInfoForFileReference(resolvedRef.reference.fileName, resolvedRef.fileName, resolvedRef.unverified)] || emptyArray;
            if (resolvedRef == null ? void 0 : resolvedRef.file) {
                return fileReferenceDefinition;
            }
            const node = getTouchingPropertyName(sourceFile, position);
            if (node === sourceFile) {
                return void 0;
            }
            const { parent: parent2 } = node;
            const typeChecker = program.getTypeChecker();
            if (node.kind === 161 /* OverrideKeyword */ || isIdentifier(node) && isJSDocOverrideTag(parent2) && parent2.tagName === node) {
                return getDefinitionFromOverriddenMember(typeChecker, node) || emptyArray;
            }
            if (isJumpStatementTarget(node)) {
                const label = getTargetLabel(node.parent, node.text);
                return label ? [createDefinitionInfoFromName(typeChecker, label, "label" /* label */, node.text, 
                    /*containerName*/
                    void 0)] : void 0;
            }
            if (node.kind === 105 /* ReturnKeyword */) {
                const functionDeclaration = findAncestor(node.parent, (n) => isClassStaticBlockDeclaration(n) ? "quit" : isFunctionLikeDeclaration(n));
                return functionDeclaration ? [createDefinitionFromSignatureDeclaration(typeChecker, functionDeclaration)] : void 0;
            }
            if (node.kind === 133 /* AwaitKeyword */) {
                const functionDeclaration = findAncestor(node, (n) => isFunctionLikeDeclaration(n));
                const isAsyncFunction2 = functionDeclaration && some(functionDeclaration.modifiers, (node2) => node2.kind === 132 /* AsyncKeyword */);
                return isAsyncFunction2 ? [createDefinitionFromSignatureDeclaration(typeChecker, functionDeclaration)] : void 0;
            }
            if (node.kind === 125 /* YieldKeyword */) {
                const functionDeclaration = findAncestor(node, (n) => isFunctionLikeDeclaration(n));
                const isGeneratorFunction = functionDeclaration && functionDeclaration.asteriskToken;
                return isGeneratorFunction ? [createDefinitionFromSignatureDeclaration(typeChecker, functionDeclaration)] : void 0;
            }
            if (isStaticModifier(node) && isClassStaticBlockDeclaration(node.parent)) {
                const classDecl = node.parent.parent;
                const { symbol: symbol2, failedAliasResolution: failedAliasResolution2 } = getSymbol(classDecl, typeChecker, stopAtAlias);
                const staticBlocks = filter(classDecl.members, isClassStaticBlockDeclaration);
                const containerName = symbol2 ? typeChecker.symbolToString(symbol2, classDecl) : "";
                const sourceFile2 = node.getSourceFile();
                return map(staticBlocks, (staticBlock) => {
                    let { pos } = moveRangePastModifiers(staticBlock);
                    pos = skipTrivia(sourceFile2.text, pos);
                    return createDefinitionInfoFromName(typeChecker, staticBlock, "constructor" /* constructorImplementationElement */, "static {}", containerName, 
                    /*unverified*/
                    false, failedAliasResolution2, { start: pos, length: "static".length });
                });
            }
            let { symbol, failedAliasResolution } = getSymbol(node, typeChecker, stopAtAlias);
            let fallbackNode = node;
            if (searchOtherFilesOnly && failedAliasResolution) {
                const importDeclaration = forEach([node, ...(symbol == null ? void 0 : symbol.declarations) || emptyArray], (n) => findAncestor(n, isAnyImportOrBareOrAccessedRequire));
                const moduleSpecifier = importDeclaration && tryGetModuleSpecifierFromDeclaration(importDeclaration);
                if (moduleSpecifier) {
                    ({ symbol, failedAliasResolution } = getSymbol(moduleSpecifier, typeChecker, stopAtAlias));
                    fallbackNode = moduleSpecifier;
                }
            }
            if (!symbol && isModuleSpecifierLike(fallbackNode)) {
                const ref = (_b = (_a2 = sourceFile.resolvedModules) == null ? void 0 : _a2.get(fallbackNode.text, getModeForUsageLocation(sourceFile, fallbackNode))) == null ? void 0 : _b.resolvedModule;
                if (ref) {
                    return [{
                            name: fallbackNode.text,
                            fileName: ref.resolvedFileName,
                            containerName: void 0,
                            containerKind: void 0,
                            kind: "script" /* scriptElement */,
                            textSpan: createTextSpan(0, 0),
                            failedAliasResolution,
                            isAmbient: isDeclarationFileName(ref.resolvedFileName),
                            unverified: fallbackNode !== node
                        }];
                }
            }
            if (!symbol) {
                return concatenate(fileReferenceDefinition, getDefinitionInfoForIndexSignatures(node, typeChecker));
            }
            if (searchOtherFilesOnly && every(symbol.declarations, (d) => d.getSourceFile().fileName === sourceFile.fileName))
                return void 0;
            const calledDeclaration = tryGetSignatureDeclaration(typeChecker, node);
            if (calledDeclaration && !(isJsxOpeningLikeElement(node.parent) && isConstructorLike(calledDeclaration))) {
                const sigInfo = createDefinitionFromSignatureDeclaration(typeChecker, calledDeclaration, failedAliasResolution);
                if (typeChecker.getRootSymbols(symbol).some((s) => symbolMatchesSignature(s, calledDeclaration))) {
                    return [sigInfo];
                }
                else {
                    const defs = getDefinitionFromSymbol(typeChecker, symbol, node, failedAliasResolution, calledDeclaration) || emptyArray;
                    return node.kind === 106 /* SuperKeyword */ ? [sigInfo, ...defs] : [...defs, sigInfo];
                }
            }
            if (node.parent.kind === 300 /* ShorthandPropertyAssignment */) {
                const shorthandSymbol = typeChecker.getShorthandAssignmentValueSymbol(symbol.valueDeclaration);
                const definitions = (shorthandSymbol == null ? void 0 : shorthandSymbol.declarations) ? shorthandSymbol.declarations.map((decl) => createDefinitionInfo(decl, typeChecker, shorthandSymbol, node, 
                /*unverified*/
                false, failedAliasResolution)) : emptyArray;
                return concatenate(definitions, getDefinitionFromObjectLiteralElement(typeChecker, node) || emptyArray);
            }
            if (isPropertyName(node) && isBindingElement(parent2) && isObjectBindingPattern(parent2.parent) && node === (parent2.propertyName || parent2.name)) {
                const name = getNameFromPropertyName(node);
                const type = typeChecker.getTypeAtLocation(parent2.parent);
                return name === void 0 ? emptyArray : flatMap(type.isUnion() ? type.types : [type], (t) => {
                    const prop = t.getProperty(name);
                    return prop && getDefinitionFromSymbol(typeChecker, prop, node);
                });
            }
            return concatenate(fileReferenceDefinition, getDefinitionFromObjectLiteralElement(typeChecker, node) || getDefinitionFromSymbol(typeChecker, symbol, node, failedAliasResolution));
        }
        function symbolMatchesSignature(s, calledDeclaration) {
            var _a2;
            return s === calledDeclaration.symbol || s === calledDeclaration.symbol.parent || isAssignmentExpression(calledDeclaration.parent) || !isCallLikeExpression(calledDeclaration.parent) && s === ((_a2 = tryCast(calledDeclaration.parent, canHaveSymbol)) == null ? void 0 : _a2.symbol);
        }
        function getDefinitionFromObjectLiteralElement(typeChecker, node) {
            const element = getContainingObjectLiteralElement(node);
            if (element) {
                const contextualType = element && typeChecker.getContextualType(element.parent);
                if (contextualType) {
                    return flatMap(getPropertySymbolsFromContextualType(element, typeChecker, contextualType, 
                    /*unionSymbolOk*/
                    false), (propertySymbol) => getDefinitionFromSymbol(typeChecker, propertySymbol, node));
                }
            }
        }
        function getDefinitionFromOverriddenMember(typeChecker, node) {
            const classElement = findAncestor(node, isClassElement);
            if (!(classElement && classElement.name))
                return;
            const baseDeclaration = findAncestor(classElement, isClassLike);
            if (!baseDeclaration)
                return;
            const baseTypeNode = getEffectiveBaseTypeNode(baseDeclaration);
            if (!baseTypeNode)
                return;
            const expression = skipParentheses(baseTypeNode.expression);
            const base = isClassExpression(expression) ? expression.symbol : typeChecker.getSymbolAtLocation(expression);
            if (!base)
                return;
            const name = unescapeLeadingUnderscores(getTextOfPropertyName(classElement.name));
            const symbol = hasStaticModifier(classElement) ? typeChecker.getPropertyOfType(typeChecker.getTypeOfSymbol(base), name) : typeChecker.getPropertyOfType(typeChecker.getDeclaredTypeOfSymbol(base), name);
            if (!symbol)
                return;
            return getDefinitionFromSymbol(typeChecker, symbol, node);
        }
        function getReferenceAtPosition(sourceFile, position, program) {
            var _a2, _b, _c, _d;
            const referencePath = findReferenceInPosition(sourceFile.referencedFiles, position);
            if (referencePath) {
                const file = program.getSourceFileFromReference(sourceFile, referencePath);
                return file && { reference: referencePath, fileName: file.fileName, file, unverified: false };
            }
            const typeReferenceDirective = findReferenceInPosition(sourceFile.typeReferenceDirectives, position);
            if (typeReferenceDirective) {
                const reference = (_a2 = program.getResolvedTypeReferenceDirectives().get(typeReferenceDirective.fileName, typeReferenceDirective.resolutionMode || sourceFile.impliedNodeFormat)) == null ? void 0 : _a2.resolvedTypeReferenceDirective;
                const file = reference && program.getSourceFile(reference.resolvedFileName);
                return file && { reference: typeReferenceDirective, fileName: file.fileName, file, unverified: false };
            }
            const libReferenceDirective = findReferenceInPosition(sourceFile.libReferenceDirectives, position);
            if (libReferenceDirective) {
                const file = program.getLibFileFromReference(libReferenceDirective);
                return file && { reference: libReferenceDirective, fileName: file.fileName, file, unverified: false };
            }
            if ((_b = sourceFile.resolvedModules) == null ? void 0 : _b.size()) {
                const node = getTouchingToken(sourceFile, position);
                if (isModuleSpecifierLike(node) && isExternalModuleNameRelative(node.text) && sourceFile.resolvedModules.has(node.text, getModeForUsageLocation(sourceFile, node))) {
                    const verifiedFileName = (_d = (_c = sourceFile.resolvedModules.get(node.text, getModeForUsageLocation(sourceFile, node))) == null ? void 0 : _c.resolvedModule) == null ? void 0 : _d.resolvedFileName;
                    const fileName = verifiedFileName || resolvePath(getDirectoryPath(sourceFile.fileName), node.text);
                    return {
                        file: program.getSourceFile(fileName),
                        fileName,
                        reference: {
                            pos: node.getStart(),
                            end: node.getEnd(),
                            fileName: node.text
                        },
                        unverified: !verifiedFileName
                    };
                }
            }
            return void 0;
        }
        function getTypeDefinitionAtPosition(typeChecker, sourceFile, position) {
            const node = getTouchingPropertyName(sourceFile, position);
            if (node === sourceFile) {
                return void 0;
            }
            if (isImportMeta(node.parent) && node.parent.name === node) {
                return definitionFromType(typeChecker.getTypeAtLocation(node.parent), typeChecker, node.parent, 
                /*failedAliasResolution*/
                false);
            }
            const { symbol, failedAliasResolution } = getSymbol(node, typeChecker, 
            /*stopAtAlias*/
            false);
            if (!symbol)
                return void 0;
            const typeAtLocation = typeChecker.getTypeOfSymbolAtLocation(symbol, node);
            const returnType = tryGetReturnTypeOfFunction(symbol, typeAtLocation, typeChecker);
            const fromReturnType = returnType && definitionFromType(returnType, typeChecker, node, failedAliasResolution);
            const typeDefinitions = fromReturnType && fromReturnType.length !== 0 ? fromReturnType : definitionFromType(typeAtLocation, typeChecker, node, failedAliasResolution);
            return typeDefinitions.length ? typeDefinitions : !(symbol.flags & 111551 /* Value */) && symbol.flags & 788968 /* Type */ ? getDefinitionFromSymbol(typeChecker, skipAlias(symbol, typeChecker), node, failedAliasResolution) : void 0;
        }
        function definitionFromType(type, checker, node, failedAliasResolution) {
            return flatMap(type.isUnion() && !(type.flags & 32 /* Enum */) ? type.types : [type], (t) => t.symbol && getDefinitionFromSymbol(checker, t.symbol, node, failedAliasResolution));
        }
        function tryGetReturnTypeOfFunction(symbol, type, checker) {
            if (type.symbol === symbol || // At `const f = () => {}`, the symbol is `f` and the type symbol is at `() => {}`
                symbol.valueDeclaration && type.symbol && isVariableDeclaration(symbol.valueDeclaration) && symbol.valueDeclaration.initializer === type.symbol.valueDeclaration) {
                const sigs = type.getCallSignatures();
                if (sigs.length === 1)
                    return checker.getReturnTypeOfSignature(first(sigs));
            }
            return void 0;
        }
        function getDefinitionAndBoundSpan(program, sourceFile, position) {
            const definitions = getDefinitionAtPosition(program, sourceFile, position);
            if (!definitions || definitions.length === 0) {
                return void 0;
            }
            const comment = findReferenceInPosition(sourceFile.referencedFiles, position) || findReferenceInPosition(sourceFile.typeReferenceDirectives, position) || findReferenceInPosition(sourceFile.libReferenceDirectives, position);
            if (comment) {
                return { definitions, textSpan: createTextSpanFromRange(comment) };
            }
            const node = getTouchingPropertyName(sourceFile, position);
            const textSpan = createTextSpan(node.getStart(), node.getWidth());
            return { definitions, textSpan };
        }
        function getDefinitionInfoForIndexSignatures(node, checker) {
            return mapDefined(checker.getIndexInfosAtLocation(node), (info) => info.declaration && createDefinitionFromSignatureDeclaration(checker, info.declaration));
        }
        function getSymbol(node, checker, stopAtAlias) {
            const symbol = checker.getSymbolAtLocation(node);
            let failedAliasResolution = false;
            if ((symbol == null ? void 0 : symbol.declarations) && symbol.flags & 2097152 /* Alias */ && !stopAtAlias && shouldSkipAlias(node, symbol.declarations[0])) {
                const aliased = checker.getAliasedSymbol(symbol);
                if (aliased.declarations) {
                    return { symbol: aliased };
                }
                else {
                    failedAliasResolution = true;
                }
            }
            return { symbol, failedAliasResolution };
        }
        function shouldSkipAlias(node, declaration) {
            if (node.kind !== 79 /* Identifier */) {
                return false;
            }
            if (node.parent === declaration) {
                return true;
            }
            if (declaration.kind === 271 /* NamespaceImport */) {
                return false;
            }
            return true;
        }
        function isExpandoDeclaration(node) {
            if (!isAssignmentDeclaration(node))
                return false;
            const containingAssignment = findAncestor(node, (p) => {
                if (isAssignmentExpression(p))
                    return true;
                if (!isAssignmentDeclaration(p))
                    return "quit";
                return false;
            });
            return !!containingAssignment && getAssignmentDeclarationKind(containingAssignment) === 5 /* Property */;
        }
        function getDefinitionFromSymbol(typeChecker, symbol, node, failedAliasResolution, excludeDeclaration) {
            const filteredDeclarations = filter(symbol.declarations, (d) => d !== excludeDeclaration);
            const withoutExpandos = filter(filteredDeclarations, (d) => !isExpandoDeclaration(d));
            const results = some(withoutExpandos) ? withoutExpandos : filteredDeclarations;
            return getConstructSignatureDefinition() || getCallSignatureDefinition() || map(results, (declaration) => createDefinitionInfo(declaration, typeChecker, symbol, node, 
            /*unverified*/
            false, failedAliasResolution));
            function getConstructSignatureDefinition() {
                if (symbol.flags & 32 /* Class */ && !(symbol.flags & (16 /* Function */ | 3 /* Variable */)) && (isNewExpressionTarget(node) || node.kind === 135 /* ConstructorKeyword */)) {
                    const cls = find(filteredDeclarations, isClassLike) || Debug.fail("Expected declaration to have at least one class-like declaration");
                    return getSignatureDefinition(cls.members, 
                    /*selectConstructors*/
                    true);
                }
            }
            function getCallSignatureDefinition() {
                return isCallOrNewExpressionTarget(node) || isNameOfFunctionDeclaration(node) ? getSignatureDefinition(filteredDeclarations, 
                /*selectConstructors*/
                false) : void 0;
            }
            function getSignatureDefinition(signatureDeclarations, selectConstructors) {
                if (!signatureDeclarations) {
                    return void 0;
                }
                const declarations = signatureDeclarations.filter(selectConstructors ? isConstructorDeclaration : isFunctionLike);
                const declarationsWithBody = declarations.filter((d) => !!d.body);
                return declarations.length ? declarationsWithBody.length !== 0 ? declarationsWithBody.map((x) => createDefinitionInfo(x, typeChecker, symbol, node)) : [createDefinitionInfo(last(declarations), typeChecker, symbol, node, 
                    /*unverified*/
                    false, failedAliasResolution)] : void 0;
            }
        }
        function createDefinitionInfo(declaration, checker, symbol, node, unverified, failedAliasResolution) {
            const symbolName2 = checker.symbolToString(symbol);
            const symbolKind = ts_SymbolDisplay_exports.getSymbolKind(checker, symbol, node);
            const containerName = symbol.parent ? checker.symbolToString(symbol.parent, node) : "";
            return createDefinitionInfoFromName(checker, declaration, symbolKind, symbolName2, containerName, unverified, failedAliasResolution);
        }
        function createDefinitionInfoFromName(checker, declaration, symbolKind, symbolName2, containerName, unverified, failedAliasResolution, textSpan) {
            const sourceFile = declaration.getSourceFile();
            if (!textSpan) {
                const name = getNameOfDeclaration(declaration) || declaration;
                textSpan = createTextSpanFromNode(name, sourceFile);
            }
            return {
                fileName: sourceFile.fileName,
                textSpan,
                kind: symbolKind,
                name: symbolName2,
                containerKind: void 0,
                // TODO: GH#18217
                containerName,
                ...ts_FindAllReferences_exports.toContextSpan(textSpan, sourceFile, ts_FindAllReferences_exports.getContextNode(declaration)),
                isLocal: !isDefinitionVisible(checker, declaration),
                isAmbient: !!(declaration.flags & 16777216 /* Ambient */),
                unverified,
                failedAliasResolution
            };
        }
        function isDefinitionVisible(checker, declaration) {
            if (checker.isDeclarationVisible(declaration))
                return true;
            if (!declaration.parent)
                return false;
            if (hasInitializer(declaration.parent) && declaration.parent.initializer === declaration)
                return isDefinitionVisible(checker, declaration.parent);
            switch (declaration.kind) {
                case 169 /* PropertyDeclaration */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 171 /* MethodDeclaration */:
                    if (hasEffectiveModifier(declaration, 8 /* Private */))
                        return false;
                case 173 /* Constructor */:
                case 299 /* PropertyAssignment */:
                case 300 /* ShorthandPropertyAssignment */:
                case 207 /* ObjectLiteralExpression */:
                case 228 /* ClassExpression */:
                case 216 /* ArrowFunction */:
                case 215 /* FunctionExpression */:
                    return isDefinitionVisible(checker, declaration.parent);
                default:
                    return false;
            }
        }
        function createDefinitionFromSignatureDeclaration(typeChecker, decl, failedAliasResolution) {
            return createDefinitionInfo(decl, typeChecker, decl.symbol, decl, 
            /*unverified*/
            false, failedAliasResolution);
        }
        function findReferenceInPosition(refs, pos) {
            return find(refs, (ref) => textRangeContainsPositionInclusive(ref, pos));
        }
        function getDefinitionInfoForFileReference(name, targetFileName, unverified) {
            return {
                fileName: targetFileName,
                textSpan: createTextSpanFromBounds(0, 0),
                kind: "script" /* scriptElement */,
                name,
                containerName: void 0,
                containerKind: void 0,
                // TODO: GH#18217
                unverified
            };
        }
        function getAncestorCallLikeExpression(node) {
            const target = findAncestor(node, (n) => !isRightSideOfPropertyAccess(n));
            const callLike = target == null ? void 0 : target.parent;
            return callLike && isCallLikeExpression(callLike) && getInvokedExpression(callLike) === target ? callLike : void 0;
        }
        function tryGetSignatureDeclaration(typeChecker, node) {
            const callLike = getAncestorCallLikeExpression(node);
            const signature = callLike && typeChecker.getResolvedSignature(callLike);
            return tryCast(signature && signature.declaration, (d) => isFunctionLike(d) && !isFunctionTypeNode(d));
        }
        function isConstructorLike(node) {
            switch (node.kind) {
                case 173 /* Constructor */:
                case 182 /* ConstructorType */:
                case 177 /* ConstructSignature */:
                    return true;
                default:
                    return false;
            }
        }
        var init_goToDefinition = __esm({
            "src/services/goToDefinition.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/_namespaces/ts.GoToDefinition.ts
        var ts_GoToDefinition_exports = {};
        __export(ts_GoToDefinition_exports, {
            createDefinitionInfo: () => createDefinitionInfo,
            findReferenceInPosition: () => findReferenceInPosition,
            getDefinitionAndBoundSpan: () => getDefinitionAndBoundSpan,
            getDefinitionAtPosition: () => getDefinitionAtPosition,
            getReferenceAtPosition: () => getReferenceAtPosition,
            getTypeDefinitionAtPosition: () => getTypeDefinitionAtPosition
        });
        var init_ts_GoToDefinition = __esm({
            "src/services/_namespaces/ts.GoToDefinition.ts"() {
                "use strict";
                init_goToDefinition();
            }
        });
        // src/services/inlayHints.ts
        function shouldShowParameterNameHints(preferences) {
            return preferences.includeInlayParameterNameHints === "literals" || preferences.includeInlayParameterNameHints === "all";
        }
        function shouldShowLiteralParameterNameHintsOnly(preferences) {
            return preferences.includeInlayParameterNameHints === "literals";
        }
        function provideInlayHints(context) {
            const { file, program, span, cancellationToken, preferences } = context;
            const sourceFileText = file.text;
            const compilerOptions = program.getCompilerOptions();
            const checker = program.getTypeChecker();
            const result = [];
            visitor(file);
            return result;
            function visitor(node) {
                if (!node || node.getFullWidth() === 0) {
                    return;
                }
                switch (node.kind) {
                    case 264 /* ModuleDeclaration */:
                    case 260 /* ClassDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                    case 259 /* FunctionDeclaration */:
                    case 228 /* ClassExpression */:
                    case 215 /* FunctionExpression */:
                    case 171 /* MethodDeclaration */:
                    case 216 /* ArrowFunction */:
                        cancellationToken.throwIfCancellationRequested();
                }
                if (!textSpanIntersectsWith(span, node.pos, node.getFullWidth())) {
                    return;
                }
                if (isTypeNode(node) && !isExpressionWithTypeArguments(node)) {
                    return;
                }
                if (preferences.includeInlayVariableTypeHints && isVariableDeclaration(node)) {
                    visitVariableLikeDeclaration(node);
                }
                else if (preferences.includeInlayPropertyDeclarationTypeHints && isPropertyDeclaration(node)) {
                    visitVariableLikeDeclaration(node);
                }
                else if (preferences.includeInlayEnumMemberValueHints && isEnumMember(node)) {
                    visitEnumMember(node);
                }
                else if (shouldShowParameterNameHints(preferences) && (isCallExpression(node) || isNewExpression(node))) {
                    visitCallOrNewExpression(node);
                }
                else {
                    if (preferences.includeInlayFunctionParameterTypeHints && isFunctionLikeDeclaration(node) && hasContextSensitiveParameters(node)) {
                        visitFunctionLikeForParameterType(node);
                    }
                    if (preferences.includeInlayFunctionLikeReturnTypeHints && isSignatureSupportingReturnAnnotation(node)) {
                        visitFunctionDeclarationLikeForReturnType(node);
                    }
                }
                return forEachChild(node, visitor);
            }
            function isSignatureSupportingReturnAnnotation(node) {
                return isArrowFunction(node) || isFunctionExpression(node) || isFunctionDeclaration(node) || isMethodDeclaration(node) || isGetAccessorDeclaration(node);
            }
            function addParameterHints(text, position, isFirstVariadicArgument) {
                result.push({
                    text: `${isFirstVariadicArgument ? "..." : ""}${truncation(text, maxHintsLength)}:`,
                    position,
                    kind: "Parameter" /* Parameter */,
                    whitespaceAfter: true
                });
            }
            function addTypeHints(text, position) {
                result.push({
                    text: `: ${truncation(text, maxHintsLength)}`,
                    position,
                    kind: "Type" /* Type */,
                    whitespaceBefore: true
                });
            }
            function addEnumMemberValueHints(text, position) {
                result.push({
                    text: `= ${truncation(text, maxHintsLength)}`,
                    position,
                    kind: "Enum" /* Enum */,
                    whitespaceBefore: true
                });
            }
            function visitEnumMember(member) {
                if (member.initializer) {
                    return;
                }
                const enumValue = checker.getConstantValue(member);
                if (enumValue !== void 0) {
                    addEnumMemberValueHints(enumValue.toString(), member.end);
                }
            }
            function isModuleReferenceType(type) {
                return type.symbol && type.symbol.flags & 1536 /* Module */;
            }
            function visitVariableLikeDeclaration(decl) {
                if (!decl.initializer || isBindingPattern(decl.name) || isVariableDeclaration(decl) && !isHintableDeclaration(decl)) {
                    return;
                }
                const effectiveTypeAnnotation = getEffectiveTypeAnnotationNode(decl);
                if (effectiveTypeAnnotation) {
                    return;
                }
                const declarationType = checker.getTypeAtLocation(decl);
                if (isModuleReferenceType(declarationType)) {
                    return;
                }
                const typeDisplayString = printTypeInSingleLine(declarationType);
                if (typeDisplayString) {
                    const isVariableNameMatchesType = preferences.includeInlayVariableTypeHintsWhenTypeMatchesName === false && equateStringsCaseInsensitive(decl.name.getText(), typeDisplayString);
                    if (isVariableNameMatchesType) {
                        return;
                    }
                    addTypeHints(typeDisplayString, decl.name.end);
                }
            }
            function visitCallOrNewExpression(expr) {
                const args = expr.arguments;
                if (!args || !args.length) {
                    return;
                }
                const candidates = [];
                const signature = checker.getResolvedSignatureForSignatureHelp(expr, candidates);
                if (!signature || !candidates.length) {
                    return;
                }
                for (let i = 0; i < args.length; ++i) {
                    const originalArg = args[i];
                    const arg = skipParentheses(originalArg);
                    if (shouldShowLiteralParameterNameHintsOnly(preferences) && !isHintableLiteral(arg)) {
                        continue;
                    }
                    const identifierNameInfo = checker.getParameterIdentifierNameAtPosition(signature, i);
                    if (identifierNameInfo) {
                        const [parameterName, isFirstVariadicArgument] = identifierNameInfo;
                        const isParameterNameNotSameAsArgument = preferences.includeInlayParameterNameHintsWhenArgumentMatchesName || !identifierOrAccessExpressionPostfixMatchesParameterName(arg, parameterName);
                        if (!isParameterNameNotSameAsArgument && !isFirstVariadicArgument) {
                            continue;
                        }
                        const name = unescapeLeadingUnderscores(parameterName);
                        if (leadingCommentsContainsParameterName(arg, name)) {
                            continue;
                        }
                        addParameterHints(name, originalArg.getStart(), isFirstVariadicArgument);
                    }
                }
            }
            function identifierOrAccessExpressionPostfixMatchesParameterName(expr, parameterName) {
                if (isIdentifier(expr)) {
                    return expr.text === parameterName;
                }
                if (isPropertyAccessExpression(expr)) {
                    return expr.name.text === parameterName;
                }
                return false;
            }
            function leadingCommentsContainsParameterName(node, name) {
                if (!isIdentifierText(name, compilerOptions.target, getLanguageVariant(file.scriptKind))) {
                    return false;
                }
                const ranges = getLeadingCommentRanges(sourceFileText, node.pos);
                if (!(ranges == null ? void 0 : ranges.length)) {
                    return false;
                }
                const regex = leadingParameterNameCommentRegexFactory(name);
                return some(ranges, (range) => regex.test(sourceFileText.substring(range.pos, range.end)));
            }
            function isHintableLiteral(node) {
                switch (node.kind) {
                    case 221 /* PrefixUnaryExpression */: {
                        const operand = node.operand;
                        return isLiteralExpression(operand) || isIdentifier(operand) && isInfinityOrNaNString(operand.escapedText);
                    }
                    case 110 /* TrueKeyword */:
                    case 95 /* FalseKeyword */:
                    case 104 /* NullKeyword */:
                    case 14 /* NoSubstitutionTemplateLiteral */:
                    case 225 /* TemplateExpression */:
                        return true;
                    case 79 /* Identifier */: {
                        const name = node.escapedText;
                        return isUndefined(name) || isInfinityOrNaNString(name);
                    }
                }
                return isLiteralExpression(node);
            }
            function visitFunctionDeclarationLikeForReturnType(decl) {
                if (isArrowFunction(decl)) {
                    if (!findChildOfKind(decl, 20 /* OpenParenToken */, file)) {
                        return;
                    }
                }
                const effectiveTypeAnnotation = getEffectiveReturnTypeNode(decl);
                if (effectiveTypeAnnotation || !decl.body) {
                    return;
                }
                const signature = checker.getSignatureFromDeclaration(decl);
                if (!signature) {
                    return;
                }
                const returnType = checker.getReturnTypeOfSignature(signature);
                if (isModuleReferenceType(returnType)) {
                    return;
                }
                const typeDisplayString = printTypeInSingleLine(returnType);
                if (!typeDisplayString) {
                    return;
                }
                addTypeHints(typeDisplayString, getTypeAnnotationPosition(decl));
            }
            function getTypeAnnotationPosition(decl) {
                const closeParenToken = findChildOfKind(decl, 21 /* CloseParenToken */, file);
                if (closeParenToken) {
                    return closeParenToken.end;
                }
                return decl.parameters.end;
            }
            function visitFunctionLikeForParameterType(node) {
                const signature = checker.getSignatureFromDeclaration(node);
                if (!signature) {
                    return;
                }
                for (let i = 0; i < node.parameters.length && i < signature.parameters.length; ++i) {
                    const param = node.parameters[i];
                    if (!isHintableDeclaration(param)) {
                        continue;
                    }
                    const effectiveTypeAnnotation = getEffectiveTypeAnnotationNode(param);
                    if (effectiveTypeAnnotation) {
                        continue;
                    }
                    const typeDisplayString = getParameterDeclarationTypeDisplayString(signature.parameters[i]);
                    if (!typeDisplayString) {
                        continue;
                    }
                    addTypeHints(typeDisplayString, param.questionToken ? param.questionToken.end : param.name.end);
                }
            }
            function getParameterDeclarationTypeDisplayString(symbol) {
                const valueDeclaration = symbol.valueDeclaration;
                if (!valueDeclaration || !isParameter(valueDeclaration)) {
                    return void 0;
                }
                const signatureParamType = checker.getTypeOfSymbolAtLocation(symbol, valueDeclaration);
                if (isModuleReferenceType(signatureParamType)) {
                    return void 0;
                }
                return printTypeInSingleLine(signatureParamType);
            }
            function truncation(text, maxLength2) {
                if (text.length > maxLength2) {
                    return text.substr(0, maxLength2 - "...".length) + "...";
                }
                return text;
            }
            function printTypeInSingleLine(type) {
                const flags = 70221824 /* IgnoreErrors */ | 1048576 /* AllowUniqueESSymbolType */ | 16384 /* UseAliasDefinedOutsideCurrentScope */;
                const printer = createPrinterWithRemoveComments();
                return usingSingleLineStringWriter((writer) => {
                    const typeNode = checker.typeToTypeNode(type, 
                    /*enclosingDeclaration*/
                    void 0, flags);
                    Debug.assertIsDefined(typeNode, "should always get typenode");
                    printer.writeNode(4 /* Unspecified */, typeNode, 
                    /*sourceFile*/
                    file, writer);
                });
            }
            function isUndefined(name) {
                return name === "undefined";
            }
            function isHintableDeclaration(node) {
                if ((isParameterDeclaration(node) || isVariableDeclaration(node) && isVarConst(node)) && node.initializer) {
                    const initializer = skipParentheses(node.initializer);
                    return !(isHintableLiteral(initializer) || isNewExpression(initializer) || isObjectLiteralExpression(initializer) || isAssertionExpression(initializer));
                }
                return true;
            }
        }
        var maxHintsLength, leadingParameterNameCommentRegexFactory;
        var init_inlayHints = __esm({
            "src/services/inlayHints.ts"() {
                "use strict";
                init_ts4();
                maxHintsLength = 30;
                leadingParameterNameCommentRegexFactory = (name) => {
                    return new RegExp(`^\\s?/\\*\\*?\\s?${name}\\s?\\*\\/\\s?$`);
                };
            }
        });
        // src/services/_namespaces/ts.InlayHints.ts
        var ts_InlayHints_exports = {};
        __export(ts_InlayHints_exports, {
            provideInlayHints: () => provideInlayHints
        });
        var init_ts_InlayHints = __esm({
            "src/services/_namespaces/ts.InlayHints.ts"() {
                "use strict";
                init_inlayHints();
            }
        });
        // src/services/jsDoc.ts
        function getJsDocCommentsFromDeclarations(declarations, checker) {
            const parts = [];
            forEachUnique(declarations, (declaration) => {
                for (const jsdoc of getCommentHavingNodes(declaration)) {
                    const inheritDoc = isJSDoc(jsdoc) && jsdoc.tags && find(jsdoc.tags, (t) => t.kind === 330 /* JSDocTag */ && (t.tagName.escapedText === "inheritDoc" || t.tagName.escapedText === "inheritdoc"));
                    if (jsdoc.comment === void 0 && !inheritDoc || isJSDoc(jsdoc) && declaration.kind !== 349 /* JSDocTypedefTag */ && declaration.kind !== 341 /* JSDocCallbackTag */ && jsdoc.tags && jsdoc.tags.some((t) => t.kind === 349 /* JSDocTypedefTag */ || t.kind === 341 /* JSDocCallbackTag */) && !jsdoc.tags.some((t) => t.kind === 344 /* JSDocParameterTag */ || t.kind === 345 /* JSDocReturnTag */)) {
                        continue;
                    }
                    let newparts = jsdoc.comment ? getDisplayPartsFromComment(jsdoc.comment, checker) : [];
                    if (inheritDoc && inheritDoc.comment) {
                        newparts = newparts.concat(getDisplayPartsFromComment(inheritDoc.comment, checker));
                    }
                    if (!contains(parts, newparts, isIdenticalListOfDisplayParts)) {
                        parts.push(newparts);
                    }
                }
            });
            return flatten(intersperse(parts, [lineBreakPart()]));
        }
        function isIdenticalListOfDisplayParts(parts1, parts2) {
            return arraysEqual(parts1, parts2, (p1, p2) => p1.kind === p2.kind && p1.text === p2.text);
        }
        function getCommentHavingNodes(declaration) {
            switch (declaration.kind) {
                case 344 /* JSDocParameterTag */:
                case 351 /* JSDocPropertyTag */:
                    return [declaration];
                case 341 /* JSDocCallbackTag */:
                case 349 /* JSDocTypedefTag */:
                    return [declaration, declaration.parent];
                default:
                    return getJSDocCommentsAndTags(declaration);
            }
        }
        function getJsDocTagsFromDeclarations(declarations, checker) {
            const infos = [];
            forEachUnique(declarations, (declaration) => {
                const tags = getJSDocTags(declaration);
                if (tags.some((t) => t.kind === 349 /* JSDocTypedefTag */ || t.kind === 341 /* JSDocCallbackTag */) && !tags.some((t) => t.kind === 344 /* JSDocParameterTag */ || t.kind === 345 /* JSDocReturnTag */)) {
                    return;
                }
                for (const tag of tags) {
                    infos.push({ name: tag.tagName.text, text: getCommentDisplayParts(tag, checker) });
                }
            });
            return infos;
        }
        function getDisplayPartsFromComment(comment, checker) {
            if (typeof comment === "string") {
                return [textPart(comment)];
            }
            return flatMap(comment, (node) => node.kind === 324 /* JSDocText */ ? [textPart(node.text)] : buildLinkParts(node, checker));
        }
        function getCommentDisplayParts(tag, checker) {
            const { comment, kind } = tag;
            const namePart = getTagNameDisplayPart(kind);
            switch (kind) {
                case 352 /* JSDocThrowsTag */:
                    const typeExpression = tag.typeExpression;
                    return typeExpression ? withNode(typeExpression) : comment === void 0 ? void 0 : getDisplayPartsFromComment(comment, checker);
                case 332 /* JSDocImplementsTag */:
                    return withNode(tag.class);
                case 331 /* JSDocAugmentsTag */:
                    return withNode(tag.class);
                case 348 /* JSDocTemplateTag */:
                    const templateTag = tag;
                    const displayParts = [];
                    if (templateTag.constraint) {
                        displayParts.push(textPart(templateTag.constraint.getText()));
                    }
                    if (length(templateTag.typeParameters)) {
                        if (length(displayParts)) {
                            displayParts.push(spacePart());
                        }
                        const lastTypeParameter = templateTag.typeParameters[templateTag.typeParameters.length - 1];
                        forEach(templateTag.typeParameters, (tp) => {
                            displayParts.push(namePart(tp.getText()));
                            if (lastTypeParameter !== tp) {
                                displayParts.push(...[punctuationPart(27 /* CommaToken */), spacePart()]);
                            }
                        });
                    }
                    if (comment) {
                        displayParts.push(...[spacePart(), ...getDisplayPartsFromComment(comment, checker)]);
                    }
                    return displayParts;
                case 347 /* JSDocTypeTag */:
                case 353 /* JSDocSatisfiesTag */:
                    return withNode(tag.typeExpression);
                case 349 /* JSDocTypedefTag */:
                case 341 /* JSDocCallbackTag */:
                case 351 /* JSDocPropertyTag */:
                case 344 /* JSDocParameterTag */:
                case 350 /* JSDocSeeTag */:
                    const { name } = tag;
                    return name ? withNode(name) : comment === void 0 ? void 0 : getDisplayPartsFromComment(comment, checker);
                default:
                    return comment === void 0 ? void 0 : getDisplayPartsFromComment(comment, checker);
            }
            function withNode(node) {
                return addComment(node.getText());
            }
            function addComment(s) {
                if (comment) {
                    if (s.match(/^https?$/)) {
                        return [textPart(s), ...getDisplayPartsFromComment(comment, checker)];
                    }
                    else {
                        return [namePart(s), spacePart(), ...getDisplayPartsFromComment(comment, checker)];
                    }
                }
                else {
                    return [textPart(s)];
                }
            }
        }
        function getTagNameDisplayPart(kind) {
            switch (kind) {
                case 344 /* JSDocParameterTag */:
                    return parameterNamePart;
                case 351 /* JSDocPropertyTag */:
                    return propertyNamePart;
                case 348 /* JSDocTemplateTag */:
                    return typeParameterNamePart;
                case 349 /* JSDocTypedefTag */:
                case 341 /* JSDocCallbackTag */:
                    return typeAliasNamePart;
                default:
                    return textPart;
            }
        }
        function getJSDocTagNameCompletions() {
            return jsDocTagNameCompletionEntries || (jsDocTagNameCompletionEntries = map(jsDocTagNames, (tagName) => {
                return {
                    name: tagName,
                    kind: "keyword" /* keyword */,
                    kindModifiers: "",
                    sortText: ts_Completions_exports.SortText.LocationPriority
                };
            }));
        }
        function getJSDocTagCompletions() {
            return jsDocTagCompletionEntries || (jsDocTagCompletionEntries = map(jsDocTagNames, (tagName) => {
                return {
                    name: `@${tagName}`,
                    kind: "keyword" /* keyword */,
                    kindModifiers: "",
                    sortText: ts_Completions_exports.SortText.LocationPriority
                };
            }));
        }
        function getJSDocTagCompletionDetails(name) {
            return {
                name,
                kind: "" /* unknown */,
                // TODO: should have its own kind?
                kindModifiers: "",
                displayParts: [textPart(name)],
                documentation: emptyArray,
                tags: void 0,
                codeActions: void 0
            };
        }
        function getJSDocParameterNameCompletions(tag) {
            if (!isIdentifier(tag.name)) {
                return emptyArray;
            }
            const nameThusFar = tag.name.text;
            const jsdoc = tag.parent;
            const fn = jsdoc.parent;
            if (!isFunctionLike(fn))
                return [];
            return mapDefined(fn.parameters, (param) => {
                if (!isIdentifier(param.name))
                    return void 0;
                const name = param.name.text;
                if (jsdoc.tags.some((t) => t !== tag && isJSDocParameterTag(t) && isIdentifier(t.name) && t.name.escapedText === name) || nameThusFar !== void 0 && !startsWith(name, nameThusFar)) {
                    return void 0;
                }
                return { name, kind: "parameter" /* parameterElement */, kindModifiers: "", sortText: ts_Completions_exports.SortText.LocationPriority };
            });
        }
        function getJSDocParameterNameCompletionDetails(name) {
            return {
                name,
                kind: "parameter" /* parameterElement */,
                kindModifiers: "",
                displayParts: [textPart(name)],
                documentation: emptyArray,
                tags: void 0,
                codeActions: void 0
            };
        }
        function getDocCommentTemplateAtPosition(newLine, sourceFile, position, options) {
            const tokenAtPos = getTokenAtPosition(sourceFile, position);
            const existingDocComment = findAncestor(tokenAtPos, isJSDoc);
            if (existingDocComment && (existingDocComment.comment !== void 0 || length(existingDocComment.tags))) {
                return void 0;
            }
            const tokenStart = tokenAtPos.getStart(sourceFile);
            if (!existingDocComment && tokenStart < position) {
                return void 0;
            }
            const commentOwnerInfo = getCommentOwnerInfo(tokenAtPos, options);
            if (!commentOwnerInfo) {
                return void 0;
            }
            const { commentOwner, parameters, hasReturn: hasReturn2 } = commentOwnerInfo;
            const commentOwnerJsDoc = hasJSDocNodes(commentOwner) && commentOwner.jsDoc ? commentOwner.jsDoc : void 0;
            const lastJsDoc = lastOrUndefined(commentOwnerJsDoc);
            if (commentOwner.getStart(sourceFile) < position || lastJsDoc && existingDocComment && lastJsDoc !== existingDocComment) {
                return void 0;
            }
            const indentationStr = getIndentationStringAtPosition(sourceFile, position);
            const isJavaScriptFile = hasJSFileExtension(sourceFile.fileName);
            const tags = (parameters ? parameterDocComments(parameters || [], isJavaScriptFile, indentationStr, newLine) : "") + (hasReturn2 ? returnsDocComment(indentationStr, newLine) : "");
            const openComment = "/**";
            const closeComment = " */";
            const hasTag = (commentOwnerJsDoc || []).some((jsDoc) => !!jsDoc.tags);
            if (tags && !hasTag) {
                const preamble = openComment + newLine + indentationStr + " * ";
                const endLine = tokenStart === position ? newLine + indentationStr : "";
                const result = preamble + newLine + tags + indentationStr + closeComment + endLine;
                return { newText: result, caretOffset: preamble.length };
            }
            return { newText: openComment + closeComment, caretOffset: 3 };
        }
        function getIndentationStringAtPosition(sourceFile, position) {
            const { text } = sourceFile;
            const lineStart = getLineStartPositionForPosition(position, sourceFile);
            let pos = lineStart;
            for (; pos <= position && isWhiteSpaceSingleLine(text.charCodeAt(pos)); pos++)
                ;
            return text.slice(lineStart, pos);
        }
        function parameterDocComments(parameters, isJavaScriptFile, indentationStr, newLine) {
            return parameters.map(({ name, dotDotDotToken }, i) => {
                const paramName = name.kind === 79 /* Identifier */ ? name.text : "param" + i;
                const type = isJavaScriptFile ? dotDotDotToken ? "{...any} " : "{any} " : "";
                return `${indentationStr} * @param ${type}${paramName}${newLine}`;
            }).join("");
        }
        function returnsDocComment(indentationStr, newLine) {
            return `${indentationStr} * @returns${newLine}`;
        }
        function getCommentOwnerInfo(tokenAtPos, options) {
            return forEachAncestor(tokenAtPos, (n) => getCommentOwnerInfoWorker(n, options));
        }
        function getCommentOwnerInfoWorker(commentOwner, options) {
            switch (commentOwner.kind) {
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 171 /* MethodDeclaration */:
                case 173 /* Constructor */:
                case 170 /* MethodSignature */:
                case 216 /* ArrowFunction */:
                    const host = commentOwner;
                    return { commentOwner, parameters: host.parameters, hasReturn: hasReturn(host, options) };
                case 299 /* PropertyAssignment */:
                    return getCommentOwnerInfoWorker(commentOwner.initializer, options);
                case 260 /* ClassDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 263 /* EnumDeclaration */:
                case 302 /* EnumMember */:
                case 262 /* TypeAliasDeclaration */:
                    return { commentOwner };
                case 168 /* PropertySignature */: {
                    const host2 = commentOwner;
                    return host2.type && isFunctionTypeNode(host2.type) ? { commentOwner, parameters: host2.type.parameters, hasReturn: hasReturn(host2.type, options) } : { commentOwner };
                }
                case 240 /* VariableStatement */: {
                    const varStatement = commentOwner;
                    const varDeclarations = varStatement.declarationList.declarations;
                    const host2 = varDeclarations.length === 1 && varDeclarations[0].initializer ? getRightHandSideOfAssignment(varDeclarations[0].initializer) : void 0;
                    return host2 ? { commentOwner, parameters: host2.parameters, hasReturn: hasReturn(host2, options) } : { commentOwner };
                }
                case 308 /* SourceFile */:
                    return "quit";
                case 264 /* ModuleDeclaration */:
                    return commentOwner.parent.kind === 264 /* ModuleDeclaration */ ? void 0 : { commentOwner };
                case 241 /* ExpressionStatement */:
                    return getCommentOwnerInfoWorker(commentOwner.expression, options);
                case 223 /* BinaryExpression */: {
                    const be = commentOwner;
                    if (getAssignmentDeclarationKind(be) === 0 /* None */) {
                        return "quit";
                    }
                    return isFunctionLike(be.right) ? { commentOwner, parameters: be.right.parameters, hasReturn: hasReturn(be.right, options) } : { commentOwner };
                }
                case 169 /* PropertyDeclaration */:
                    const init = commentOwner.initializer;
                    if (init && (isFunctionExpression(init) || isArrowFunction(init))) {
                        return { commentOwner, parameters: init.parameters, hasReturn: hasReturn(init, options) };
                    }
            }
        }
        function hasReturn(node, options) {
            return !!(options == null ? void 0 : options.generateReturnInDocTemplate) && (isFunctionTypeNode(node) || isArrowFunction(node) && isExpression(node.body) || isFunctionLikeDeclaration(node) && node.body && isBlock(node.body) && !!forEachReturnStatement(node.body, (n) => n));
        }
        function getRightHandSideOfAssignment(rightHandSide) {
            while (rightHandSide.kind === 214 /* ParenthesizedExpression */) {
                rightHandSide = rightHandSide.expression;
            }
            switch (rightHandSide.kind) {
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                    return rightHandSide;
                case 228 /* ClassExpression */:
                    return find(rightHandSide.members, isConstructorDeclaration);
            }
        }
        var jsDocTagNames, jsDocTagNameCompletionEntries, jsDocTagCompletionEntries, getJSDocTagNameCompletionDetails;
        var init_jsDoc = __esm({
            "src/services/jsDoc.ts"() {
                "use strict";
                init_ts4();
                jsDocTagNames = [
                    "abstract",
                    "access",
                    "alias",
                    "argument",
                    "async",
                    "augments",
                    "author",
                    "borrows",
                    "callback",
                    "class",
                    "classdesc",
                    "constant",
                    "constructor",
                    "constructs",
                    "copyright",
                    "default",
                    "deprecated",
                    "description",
                    "emits",
                    "enum",
                    "event",
                    "example",
                    "exports",
                    "extends",
                    "external",
                    "field",
                    "file",
                    "fileoverview",
                    "fires",
                    "function",
                    "generator",
                    "global",
                    "hideconstructor",
                    "host",
                    "ignore",
                    "implements",
                    "inheritdoc",
                    "inner",
                    "instance",
                    "interface",
                    "kind",
                    "lends",
                    "license",
                    "link",
                    "linkcode",
                    "linkplain",
                    "listens",
                    "member",
                    "memberof",
                    "method",
                    "mixes",
                    "module",
                    "name",
                    "namespace",
                    "overload",
                    "override",
                    "package",
                    "param",
                    "private",
                    "prop",
                    "property",
                    "protected",
                    "public",
                    "readonly",
                    "requires",
                    "returns",
                    "satisfies",
                    "see",
                    "since",
                    "static",
                    "summary",
                    "template",
                    "this",
                    "throws",
                    "todo",
                    "tutorial",
                    "type",
                    "typedef",
                    "var",
                    "variation",
                    "version",
                    "virtual",
                    "yields"
                ];
                getJSDocTagNameCompletionDetails = getJSDocTagCompletionDetails;
            }
        });
        // src/services/_namespaces/ts.JsDoc.ts
        var ts_JsDoc_exports = {};
        __export(ts_JsDoc_exports, {
            getDocCommentTemplateAtPosition: () => getDocCommentTemplateAtPosition,
            getJSDocParameterNameCompletionDetails: () => getJSDocParameterNameCompletionDetails,
            getJSDocParameterNameCompletions: () => getJSDocParameterNameCompletions,
            getJSDocTagCompletionDetails: () => getJSDocTagCompletionDetails,
            getJSDocTagCompletions: () => getJSDocTagCompletions,
            getJSDocTagNameCompletionDetails: () => getJSDocTagNameCompletionDetails,
            getJSDocTagNameCompletions: () => getJSDocTagNameCompletions,
            getJsDocCommentsFromDeclarations: () => getJsDocCommentsFromDeclarations,
            getJsDocTagsFromDeclarations: () => getJsDocTagsFromDeclarations
        });
        var init_ts_JsDoc = __esm({
            "src/services/_namespaces/ts.JsDoc.ts"() {
                "use strict";
                init_jsDoc();
            }
        });
        // src/services/organizeImports.ts
        function organizeImports(sourceFile, formatContext, host, program, preferences, mode) {
            const changeTracker = ts_textChanges_exports.ChangeTracker.fromContext({ host, formatContext, preferences });
            const shouldSort = mode === "SortAndCombine" /* SortAndCombine */ || mode === "All" /* All */;
            const shouldCombine = shouldSort;
            const shouldRemove = mode === "RemoveUnused" /* RemoveUnused */ || mode === "All" /* All */;
            const topLevelImportGroupDecls = groupImportsByNewlineContiguous(sourceFile, sourceFile.statements.filter(isImportDeclaration));
            const comparer = getOrganizeImportsComparerWithDetection(preferences, shouldSort ? () => detectSortingWorker(topLevelImportGroupDecls, preferences) === 2 /* CaseInsensitive */ : void 0);
            const processImportsOfSameModuleSpecifier = (importGroup) => {
                if (shouldRemove)
                    importGroup = removeUnusedImports(importGroup, sourceFile, program);
                if (shouldCombine)
                    importGroup = coalesceImportsWorker(importGroup, comparer, sourceFile);
                if (shouldSort)
                    importGroup = stableSort(importGroup, (s1, s2) => compareImportsOrRequireStatements(s1, s2, comparer));
                return importGroup;
            };
            topLevelImportGroupDecls.forEach((importGroupDecl) => organizeImportsWorker(importGroupDecl, processImportsOfSameModuleSpecifier));
            if (mode !== "RemoveUnused" /* RemoveUnused */) {
                const topLevelExportDecls = sourceFile.statements.filter(isExportDeclaration);
                organizeImportsWorker(topLevelExportDecls, (group2) => coalesceExportsWorker(group2, comparer));
            }
            for (const ambientModule of sourceFile.statements.filter(isAmbientModule)) {
                if (!ambientModule.body)
                    continue;
                const ambientModuleImportGroupDecls = groupImportsByNewlineContiguous(sourceFile, ambientModule.body.statements.filter(isImportDeclaration));
                ambientModuleImportGroupDecls.forEach((importGroupDecl) => organizeImportsWorker(importGroupDecl, processImportsOfSameModuleSpecifier));
                if (mode !== "RemoveUnused" /* RemoveUnused */) {
                    const ambientModuleExportDecls = ambientModule.body.statements.filter(isExportDeclaration);
                    organizeImportsWorker(ambientModuleExportDecls, (group2) => coalesceExportsWorker(group2, comparer));
                }
            }
            return changeTracker.getChanges();
            function organizeImportsWorker(oldImportDecls, coalesce) {
                if (length(oldImportDecls) === 0) {
                    return;
                }
                suppressLeadingTrivia(oldImportDecls[0]);
                const oldImportGroups = shouldCombine ? group(oldImportDecls, (importDecl) => getExternalModuleName2(importDecl.moduleSpecifier)) : [oldImportDecls];
                const sortedImportGroups = shouldSort ? stableSort(oldImportGroups, (group1, group2) => compareModuleSpecifiersWorker(group1[0].moduleSpecifier, group2[0].moduleSpecifier, comparer)) : oldImportGroups;
                const newImportDecls = flatMap(sortedImportGroups, (importGroup) => getExternalModuleName2(importGroup[0].moduleSpecifier) ? coalesce(importGroup) : importGroup);
                if (newImportDecls.length === 0) {
                    changeTracker.deleteNodes(sourceFile, oldImportDecls, {
                        leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude,
                        trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include
                    }, 
                    /*hasTrailingComment*/
                    true);
                }
                else {
                    const replaceOptions = {
                        leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude,
                        // Leave header comment in place
                        trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include,
                        suffix: getNewLineOrDefaultFromHost(host, formatContext.options)
                    };
                    changeTracker.replaceNodeWithNodes(sourceFile, oldImportDecls[0], newImportDecls, replaceOptions);
                    const hasTrailingComment = changeTracker.nodeHasTrailingComment(sourceFile, oldImportDecls[0], replaceOptions);
                    changeTracker.deleteNodes(sourceFile, oldImportDecls.slice(1), {
                        trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include
                    }, hasTrailingComment);
                }
            }
        }
        function groupImportsByNewlineContiguous(sourceFile, importDecls) {
            const scanner2 = createScanner(sourceFile.languageVersion, 
            /*skipTrivia*/
            false, sourceFile.languageVariant);
            const groupImports = [];
            let groupIndex = 0;
            for (const topLevelImportDecl of importDecls) {
                if (groupImports[groupIndex] && isNewGroup(sourceFile, topLevelImportDecl, scanner2)) {
                    groupIndex++;
                }
                if (!groupImports[groupIndex]) {
                    groupImports[groupIndex] = [];
                }
                groupImports[groupIndex].push(topLevelImportDecl);
            }
            return groupImports;
        }
        function isNewGroup(sourceFile, topLevelImportDecl, scanner2) {
            const startPos = topLevelImportDecl.getFullStart();
            const endPos = topLevelImportDecl.getStart();
            scanner2.setText(sourceFile.text, startPos, endPos - startPos);
            let numberOfNewLines = 0;
            while (scanner2.getTokenPos() < endPos) {
                const tokenKind = scanner2.scan();
                if (tokenKind === 4 /* NewLineTrivia */) {
                    numberOfNewLines++;
                    if (numberOfNewLines >= 2) {
                        return true;
                    }
                }
            }
            return false;
        }
        function removeUnusedImports(oldImports, sourceFile, program) {
            const typeChecker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            const jsxNamespace = typeChecker.getJsxNamespace(sourceFile);
            const jsxFragmentFactory = typeChecker.getJsxFragmentFactory(sourceFile);
            const jsxElementsPresent = !!(sourceFile.transformFlags & 2 /* ContainsJsx */);
            const usedImports = [];
            for (const importDecl of oldImports) {
                const { importClause, moduleSpecifier } = importDecl;
                if (!importClause) {
                    usedImports.push(importDecl);
                    continue;
                }
                let { name, namedBindings } = importClause;
                if (name && !isDeclarationUsed(name)) {
                    name = void 0;
                }
                if (namedBindings) {
                    if (isNamespaceImport(namedBindings)) {
                        if (!isDeclarationUsed(namedBindings.name)) {
                            namedBindings = void 0;
                        }
                    }
                    else {
                        const newElements = namedBindings.elements.filter((e) => isDeclarationUsed(e.name));
                        if (newElements.length < namedBindings.elements.length) {
                            namedBindings = newElements.length ? factory.updateNamedImports(namedBindings, newElements) : void 0;
                        }
                    }
                }
                if (name || namedBindings) {
                    usedImports.push(updateImportDeclarationAndClause(importDecl, name, namedBindings));
                }
                else if (hasModuleDeclarationMatchingSpecifier(sourceFile, moduleSpecifier)) {
                    if (sourceFile.isDeclarationFile) {
                        usedImports.push(factory.createImportDeclaration(importDecl.modifiers, 
                        /*importClause*/
                        void 0, moduleSpecifier, 
                        /*assertClause*/
                        void 0));
                    }
                    else {
                        usedImports.push(importDecl);
                    }
                }
            }
            return usedImports;
            function isDeclarationUsed(identifier) {
                return jsxElementsPresent && (identifier.text === jsxNamespace || jsxFragmentFactory && identifier.text === jsxFragmentFactory) && jsxModeNeedsExplicitImport(compilerOptions.jsx) || ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(identifier, typeChecker, sourceFile);
            }
        }
        function hasModuleDeclarationMatchingSpecifier(sourceFile, moduleSpecifier) {
            const moduleSpecifierText = isStringLiteral(moduleSpecifier) && moduleSpecifier.text;
            return isString(moduleSpecifierText) && some(sourceFile.moduleAugmentations, (moduleName) => isStringLiteral(moduleName) && moduleName.text === moduleSpecifierText);
        }
        function getExternalModuleName2(specifier) {
            return specifier !== void 0 && isStringLiteralLike(specifier) ? specifier.text : void 0;
        }
        function coalesceImports(importGroup, ignoreCase, sourceFile) {
            const comparer = getOrganizeImportsOrdinalStringComparer(ignoreCase);
            return coalesceImportsWorker(importGroup, comparer, sourceFile);
        }
        function coalesceImportsWorker(importGroup, comparer, sourceFile) {
            if (importGroup.length === 0) {
                return importGroup;
            }
            const { importWithoutClause, typeOnlyImports, regularImports } = getCategorizedImports(importGroup);
            const coalescedImports = [];
            if (importWithoutClause) {
                coalescedImports.push(importWithoutClause);
            }
            for (const group2 of [regularImports, typeOnlyImports]) {
                const isTypeOnly = group2 === typeOnlyImports;
                const { defaultImports, namespaceImports, namedImports } = group2;
                if (!isTypeOnly && defaultImports.length === 1 && namespaceImports.length === 1 && namedImports.length === 0) {
                    const defaultImport = defaultImports[0];
                    coalescedImports.push(updateImportDeclarationAndClause(defaultImport, defaultImport.importClause.name, namespaceImports[0].importClause.namedBindings));
                    continue;
                }
                const sortedNamespaceImports = stableSort(namespaceImports, (i1, i2) => comparer(i1.importClause.namedBindings.name.text, i2.importClause.namedBindings.name.text));
                for (const namespaceImport of sortedNamespaceImports) {
                    coalescedImports.push(updateImportDeclarationAndClause(namespaceImport, 
                    /*name*/
                    void 0, namespaceImport.importClause.namedBindings));
                }
                const firstDefaultImport = firstOrUndefined(defaultImports);
                const firstNamedImport = firstOrUndefined(namedImports);
                const importDecl = firstDefaultImport != null ? firstDefaultImport : firstNamedImport;
                if (!importDecl) {
                    continue;
                }
                let newDefaultImport;
                const newImportSpecifiers = [];
                if (defaultImports.length === 1) {
                    newDefaultImport = defaultImports[0].importClause.name;
                }
                else {
                    for (const defaultImport of defaultImports) {
                        newImportSpecifiers.push(factory.createImportSpecifier(
                        /*isTypeOnly*/
                        false, factory.createIdentifier("default"), defaultImport.importClause.name));
                    }
                }
                newImportSpecifiers.push(...getNewImportSpecifiers(namedImports));
                const sortedImportSpecifiers = factory.createNodeArray(sortSpecifiers(newImportSpecifiers, comparer), firstNamedImport == null ? void 0 : firstNamedImport.importClause.namedBindings.elements.hasTrailingComma);
                const newNamedImports = sortedImportSpecifiers.length === 0 ? newDefaultImport ? void 0 : factory.createNamedImports(emptyArray) : firstNamedImport ? factory.updateNamedImports(firstNamedImport.importClause.namedBindings, sortedImportSpecifiers) : factory.createNamedImports(sortedImportSpecifiers);
                if (sourceFile && newNamedImports && (firstNamedImport == null ? void 0 : firstNamedImport.importClause.namedBindings) && !rangeIsOnSingleLine(firstNamedImport.importClause.namedBindings, sourceFile)) {
                    setEmitFlags(newNamedImports, 2 /* MultiLine */);
                }
                if (isTypeOnly && newDefaultImport && newNamedImports) {
                    coalescedImports.push(updateImportDeclarationAndClause(importDecl, newDefaultImport, 
                    /*namedBindings*/
                    void 0));
                    coalescedImports.push(updateImportDeclarationAndClause(firstNamedImport != null ? firstNamedImport : importDecl, 
                    /*name*/
                    void 0, newNamedImports));
                }
                else {
                    coalescedImports.push(updateImportDeclarationAndClause(importDecl, newDefaultImport, newNamedImports));
                }
            }
            return coalescedImports;
        }
        function getCategorizedImports(importGroup) {
            let importWithoutClause;
            const typeOnlyImports = { defaultImports: [], namespaceImports: [], namedImports: [] };
            const regularImports = { defaultImports: [], namespaceImports: [], namedImports: [] };
            for (const importDeclaration of importGroup) {
                if (importDeclaration.importClause === void 0) {
                    importWithoutClause = importWithoutClause || importDeclaration;
                    continue;
                }
                const group2 = importDeclaration.importClause.isTypeOnly ? typeOnlyImports : regularImports;
                const { name, namedBindings } = importDeclaration.importClause;
                if (name) {
                    group2.defaultImports.push(importDeclaration);
                }
                if (namedBindings) {
                    if (isNamespaceImport(namedBindings)) {
                        group2.namespaceImports.push(importDeclaration);
                    }
                    else {
                        group2.namedImports.push(importDeclaration);
                    }
                }
            }
            return {
                importWithoutClause,
                typeOnlyImports,
                regularImports
            };
        }
        function coalesceExports(exportGroup, ignoreCase) {
            const comparer = getOrganizeImportsOrdinalStringComparer(ignoreCase);
            return coalesceExportsWorker(exportGroup, comparer);
        }
        function coalesceExportsWorker(exportGroup, comparer) {
            if (exportGroup.length === 0) {
                return exportGroup;
            }
            const { exportWithoutClause, namedExports, typeOnlyExports } = getCategorizedExports(exportGroup);
            const coalescedExports = [];
            if (exportWithoutClause) {
                coalescedExports.push(exportWithoutClause);
            }
            for (const exportGroup2 of [namedExports, typeOnlyExports]) {
                if (exportGroup2.length === 0) {
                    continue;
                }
                const newExportSpecifiers = [];
                newExportSpecifiers.push(...flatMap(exportGroup2, (i) => i.exportClause && isNamedExports(i.exportClause) ? i.exportClause.elements : emptyArray));
                const sortedExportSpecifiers = sortSpecifiers(newExportSpecifiers, comparer);
                const exportDecl = exportGroup2[0];
                coalescedExports.push(factory.updateExportDeclaration(exportDecl, exportDecl.modifiers, exportDecl.isTypeOnly, exportDecl.exportClause && (isNamedExports(exportDecl.exportClause) ? factory.updateNamedExports(exportDecl.exportClause, sortedExportSpecifiers) : factory.updateNamespaceExport(exportDecl.exportClause, exportDecl.exportClause.name)), exportDecl.moduleSpecifier, exportDecl.assertClause));
            }
            return coalescedExports;
            function getCategorizedExports(exportGroup2) {
                let exportWithoutClause2;
                const namedExports2 = [];
                const typeOnlyExports2 = [];
                for (const exportDeclaration of exportGroup2) {
                    if (exportDeclaration.exportClause === void 0) {
                        exportWithoutClause2 = exportWithoutClause2 || exportDeclaration;
                    }
                    else if (exportDeclaration.isTypeOnly) {
                        typeOnlyExports2.push(exportDeclaration);
                    }
                    else {
                        namedExports2.push(exportDeclaration);
                    }
                }
                return {
                    exportWithoutClause: exportWithoutClause2,
                    namedExports: namedExports2,
                    typeOnlyExports: typeOnlyExports2
                };
            }
        }
        function updateImportDeclarationAndClause(importDeclaration, name, namedBindings) {
            return factory.updateImportDeclaration(importDeclaration, importDeclaration.modifiers, factory.updateImportClause(importDeclaration.importClause, importDeclaration.importClause.isTypeOnly, name, namedBindings), 
            // TODO: GH#18217
            importDeclaration.moduleSpecifier, importDeclaration.assertClause);
        }
        function sortSpecifiers(specifiers, comparer) {
            return stableSort(specifiers, (s1, s2) => compareImportOrExportSpecifiers(s1, s2, comparer));
        }
        function compareImportOrExportSpecifiers(s1, s2, comparer) {
            return compareBooleans(s1.isTypeOnly, s2.isTypeOnly) || comparer(s1.name.text, s2.name.text);
        }
        function compareModuleSpecifiers2(m1, m2, ignoreCase) {
            const comparer = getOrganizeImportsOrdinalStringComparer(!!ignoreCase);
            return compareModuleSpecifiersWorker(m1, m2, comparer);
        }
        function compareModuleSpecifiersWorker(m1, m2, comparer) {
            const name1 = m1 === void 0 ? void 0 : getExternalModuleName2(m1);
            const name2 = m2 === void 0 ? void 0 : getExternalModuleName2(m2);
            return compareBooleans(name1 === void 0, name2 === void 0) || compareBooleans(isExternalModuleNameRelative(name1), isExternalModuleNameRelative(name2)) || // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion
                comparer(name1, name2);
        }
        function getModuleSpecifierExpression(declaration) {
            var _a2;
            switch (declaration.kind) {
                case 268 /* ImportEqualsDeclaration */:
                    return (_a2 = tryCast(declaration.moduleReference, isExternalModuleReference)) == null ? void 0 : _a2.expression;
                case 269 /* ImportDeclaration */:
                    return declaration.moduleSpecifier;
                case 240 /* VariableStatement */:
                    return declaration.declarationList.declarations[0].initializer.arguments[0];
            }
        }
        function detectSorting(sourceFile, preferences) {
            return detectSortingWorker(groupImportsByNewlineContiguous(sourceFile, sourceFile.statements.filter(isImportDeclaration)), preferences);
        }
        function detectSortingWorker(importGroups, preferences) {
            const collateCaseSensitive = getOrganizeImportsComparer(preferences, 
            /*ignoreCase*/
            false);
            const collateCaseInsensitive = getOrganizeImportsComparer(preferences, 
            /*ignoreCase*/
            true);
            let sortState = 3 /* Both */;
            let seenUnsortedGroup = false;
            for (const importGroup of importGroups) {
                if (importGroup.length > 1) {
                    const moduleSpecifierSort = detectSortCaseSensitivity(importGroup, (i) => {
                        var _a2, _b;
                        return (_b = (_a2 = tryCast(i.moduleSpecifier, isStringLiteral)) == null ? void 0 : _a2.text) != null ? _b : "";
                    }, collateCaseSensitive, collateCaseInsensitive);
                    if (moduleSpecifierSort) {
                        sortState &= moduleSpecifierSort;
                        seenUnsortedGroup = true;
                    }
                    if (!sortState) {
                        return sortState;
                    }
                }
                const declarationWithNamedImports = find(importGroup, (i) => {
                    var _a2, _b;
                    return ((_b = tryCast((_a2 = i.importClause) == null ? void 0 : _a2.namedBindings, isNamedImports)) == null ? void 0 : _b.elements.length) > 1;
                });
                if (declarationWithNamedImports) {
                    const namedImportSort = detectImportSpecifierSorting(declarationWithNamedImports.importClause.namedBindings.elements, preferences);
                    if (namedImportSort) {
                        sortState &= namedImportSort;
                        seenUnsortedGroup = true;
                    }
                    if (!sortState) {
                        return sortState;
                    }
                }
                if (sortState !== 3 /* Both */) {
                    return sortState;
                }
            }
            return seenUnsortedGroup ? 0 /* None */ : sortState;
        }
        function detectImportDeclarationSorting(imports, preferences) {
            const collateCaseSensitive = getOrganizeImportsComparer(preferences, 
            /*ignoreCase*/
            false);
            const collateCaseInsensitive = getOrganizeImportsComparer(preferences, 
            /*ignoreCase*/
            true);
            return detectSortCaseSensitivity(imports, (s) => getExternalModuleName2(getModuleSpecifierExpression(s)) || "", collateCaseSensitive, collateCaseInsensitive);
        }
        function getImportDeclarationInsertionIndex(sortedImports, newImport, comparer) {
            const index = binarySearch(sortedImports, newImport, identity, (a, b) => compareImportsOrRequireStatements(a, b, comparer));
            return index < 0 ? ~index : index;
        }
        function getImportSpecifierInsertionIndex(sortedImports, newImport, comparer) {
            const index = binarySearch(sortedImports, newImport, identity, (s1, s2) => compareImportOrExportSpecifiers(s1, s2, comparer));
            return index < 0 ? ~index : index;
        }
        function compareImportsOrRequireStatements(s1, s2, comparer) {
            return compareModuleSpecifiersWorker(getModuleSpecifierExpression(s1), getModuleSpecifierExpression(s2), comparer) || compareImportKind(s1, s2);
        }
        function compareImportKind(s1, s2) {
            return compareValues(getImportKindOrder(s1), getImportKindOrder(s2));
        }
        function getImportKindOrder(s1) {
            var _a2;
            switch (s1.kind) {
                case 269 /* ImportDeclaration */:
                    if (!s1.importClause)
                        return 0;
                    if (s1.importClause.isTypeOnly)
                        return 1;
                    if (((_a2 = s1.importClause.namedBindings) == null ? void 0 : _a2.kind) === 271 /* NamespaceImport */)
                        return 2;
                    if (s1.importClause.name)
                        return 3;
                    return 4;
                case 268 /* ImportEqualsDeclaration */:
                    return 5;
                case 240 /* VariableStatement */:
                    return 6;
            }
        }
        function getNewImportSpecifiers(namedImports) {
            return flatMap(namedImports, (namedImport) => map(tryGetNamedBindingElements(namedImport), (importSpecifier) => importSpecifier.name && importSpecifier.propertyName && importSpecifier.name.escapedText === importSpecifier.propertyName.escapedText ? factory.updateImportSpecifier(importSpecifier, importSpecifier.isTypeOnly, 
            /*propertyName*/
            void 0, importSpecifier.name) : importSpecifier));
        }
        function tryGetNamedBindingElements(namedImport) {
            var _a2;
            return ((_a2 = namedImport.importClause) == null ? void 0 : _a2.namedBindings) && isNamedImports(namedImport.importClause.namedBindings) ? namedImport.importClause.namedBindings.elements : void 0;
        }
        function getOrganizeImportsOrdinalStringComparer(ignoreCase) {
            return ignoreCase ? compareStringsCaseInsensitiveEslintCompatible : compareStringsCaseSensitive;
        }
        function getOrganizeImportsUnicodeStringComparer(ignoreCase, preferences) {
            var _a2, _b, _c;
            const resolvedLocale = getOrganizeImportsLocale(preferences);
            const caseFirst = (_a2 = preferences.organizeImportsCaseFirst) != null ? _a2 : false;
            const numeric = (_b = preferences.organizeImportsNumericCollation) != null ? _b : false;
            const accents = (_c = preferences.organizeImportsAccentCollation) != null ? _c : true;
            const sensitivity = ignoreCase ? accents ? "accent" : "base" : accents ? "variant" : "case";
            const collator = new Intl.Collator(resolvedLocale, {
                usage: "sort",
                caseFirst: caseFirst || "false",
                sensitivity,
                numeric
            });
            return collator.compare;
        }
        function getOrganizeImportsLocale(preferences) {
            let locale = preferences.organizeImportsLocale;
            if (locale === "auto")
                locale = getUILocale();
            if (locale === void 0)
                locale = "en";
            const supportedLocales = Intl.Collator.supportedLocalesOf(locale);
            const resolvedLocale = supportedLocales.length ? supportedLocales[0] : "en";
            return resolvedLocale;
        }
        function getOrganizeImportsComparer(preferences, ignoreCase) {
            var _a2;
            const collation = (_a2 = preferences.organizeImportsCollation) != null ? _a2 : "ordinal";
            return collation === "unicode" ? getOrganizeImportsUnicodeStringComparer(ignoreCase, preferences) : getOrganizeImportsOrdinalStringComparer(ignoreCase);
        }
        function getOrganizeImportsComparerWithDetection(preferences, detectIgnoreCase) {
            var _a2;
            const ignoreCase = typeof preferences.organizeImportsIgnoreCase === "boolean" ? preferences.organizeImportsIgnoreCase : (_a2 = detectIgnoreCase == null ? void 0 : detectIgnoreCase()) != null ? _a2 : false;
            return getOrganizeImportsComparer(preferences, ignoreCase);
        }
        var ImportSpecifierSortingCache, detectImportSpecifierSorting;
        var init_organizeImports = __esm({
            "src/services/organizeImports.ts"() {
                "use strict";
                init_ts4();
                ImportSpecifierSortingCache = class {
                    has([specifiers, preferences]) {
                        if (this._lastPreferences !== preferences || !this._cache)
                            return false;
                        return this._cache.has(specifiers);
                    }
                    get([specifiers, preferences]) {
                        if (this._lastPreferences !== preferences || !this._cache)
                            return void 0;
                        return this._cache.get(specifiers);
                    }
                    set([specifiers, preferences], value) {
                        var _a2;
                        if (this._lastPreferences !== preferences) {
                            this._lastPreferences = preferences;
                            this._cache = void 0;
                        }
                        (_a2 = this._cache) != null ? _a2 : this._cache = /* @__PURE__ */ new WeakMap();
                        this._cache.set(specifiers, value);
                    }
                };
                detectImportSpecifierSorting = memoizeCached((specifiers, preferences) => {
                    if (!arrayIsSorted(specifiers, (s1, s2) => compareBooleans(s1.isTypeOnly, s2.isTypeOnly))) {
                        return 0 /* None */;
                    }
                    const collateCaseSensitive = getOrganizeImportsComparer(preferences, 
                    /*ignoreCase*/
                    false);
                    const collateCaseInsensitive = getOrganizeImportsComparer(preferences, 
                    /*ignoreCase*/
                    true);
                    return detectSortCaseSensitivity(specifiers, (specifier) => specifier.name.text, collateCaseSensitive, collateCaseInsensitive);
                }, new ImportSpecifierSortingCache());
            }
        });
        // src/services/_namespaces/ts.OrganizeImports.ts
        var ts_OrganizeImports_exports = {};
        __export(ts_OrganizeImports_exports, {
            coalesceExports: () => coalesceExports,
            coalesceImports: () => coalesceImports,
            compareImportOrExportSpecifiers: () => compareImportOrExportSpecifiers,
            compareImportsOrRequireStatements: () => compareImportsOrRequireStatements,
            compareModuleSpecifiers: () => compareModuleSpecifiers2,
            detectImportDeclarationSorting: () => detectImportDeclarationSorting,
            detectImportSpecifierSorting: () => detectImportSpecifierSorting,
            detectSorting: () => detectSorting,
            getImportDeclarationInsertionIndex: () => getImportDeclarationInsertionIndex,
            getImportSpecifierInsertionIndex: () => getImportSpecifierInsertionIndex,
            getOrganizeImportsComparer: () => getOrganizeImportsComparer,
            organizeImports: () => organizeImports
        });
        var init_ts_OrganizeImports = __esm({
            "src/services/_namespaces/ts.OrganizeImports.ts"() {
                "use strict";
                init_organizeImports();
            }
        });
        // src/services/outliningElementsCollector.ts
        function collectElements(sourceFile, cancellationToken) {
            const res = [];
            addNodeOutliningSpans(sourceFile, cancellationToken, res);
            addRegionOutliningSpans(sourceFile, res);
            return res.sort((span1, span2) => span1.textSpan.start - span2.textSpan.start);
        }
        function addNodeOutliningSpans(sourceFile, cancellationToken, out) {
            let depthRemaining = 40;
            let current = 0;
            const statements = [...sourceFile.statements, sourceFile.endOfFileToken];
            const n = statements.length;
            while (current < n) {
                while (current < n && !isAnyImportSyntax(statements[current])) {
                    visitNode3(statements[current]);
                    current++;
                }
                if (current === n)
                    break;
                const firstImport = current;
                while (current < n && isAnyImportSyntax(statements[current])) {
                    visitNode3(statements[current]);
                    current++;
                }
                const lastImport = current - 1;
                if (lastImport !== firstImport) {
                    out.push(createOutliningSpanFromBounds(findChildOfKind(statements[firstImport], 100 /* ImportKeyword */, sourceFile).getStart(sourceFile), statements[lastImport].getEnd(), "imports" /* Imports */));
                }
            }
            function visitNode3(n2) {
                var _a2;
                if (depthRemaining === 0)
                    return;
                cancellationToken.throwIfCancellationRequested();
                if (isDeclaration(n2) || isVariableStatement(n2) || isReturnStatement(n2) || isCallOrNewExpression(n2) || n2.kind === 1 /* EndOfFileToken */) {
                    addOutliningForLeadingCommentsForNode(n2, sourceFile, cancellationToken, out);
                }
                if (isFunctionLike(n2) && isBinaryExpression(n2.parent) && isPropertyAccessExpression(n2.parent.left)) {
                    addOutliningForLeadingCommentsForNode(n2.parent.left, sourceFile, cancellationToken, out);
                }
                if (isBlock(n2) || isModuleBlock(n2)) {
                    addOutliningForLeadingCommentsForPos(n2.statements.end, sourceFile, cancellationToken, out);
                }
                if (isClassLike(n2) || isInterfaceDeclaration(n2)) {
                    addOutliningForLeadingCommentsForPos(n2.members.end, sourceFile, cancellationToken, out);
                }
                const span = getOutliningSpanForNode(n2, sourceFile);
                if (span)
                    out.push(span);
                depthRemaining--;
                if (isCallExpression(n2)) {
                    depthRemaining++;
                    visitNode3(n2.expression);
                    depthRemaining--;
                    n2.arguments.forEach(visitNode3);
                    (_a2 = n2.typeArguments) == null ? void 0 : _a2.forEach(visitNode3);
                }
                else if (isIfStatement(n2) && n2.elseStatement && isIfStatement(n2.elseStatement)) {
                    visitNode3(n2.expression);
                    visitNode3(n2.thenStatement);
                    depthRemaining++;
                    visitNode3(n2.elseStatement);
                    depthRemaining--;
                }
                else {
                    n2.forEachChild(visitNode3);
                }
                depthRemaining++;
            }
        }
        function addRegionOutliningSpans(sourceFile, out) {
            const regions = [];
            const lineStarts = sourceFile.getLineStarts();
            for (const currentLineStart of lineStarts) {
                const lineEnd = sourceFile.getLineEndOfPosition(currentLineStart);
                const lineText = sourceFile.text.substring(currentLineStart, lineEnd);
                const result = isRegionDelimiter(lineText);
                if (!result || isInComment(sourceFile, currentLineStart)) {
                    continue;
                }
                if (!result[1]) {
                    const span = createTextSpanFromBounds(sourceFile.text.indexOf("//", currentLineStart), lineEnd);
                    regions.push(createOutliningSpan(span, "region" /* Region */, span, 
                    /*autoCollapse*/
                    false, result[2] || "#region"));
                }
                else {
                    const region = regions.pop();
                    if (region) {
                        region.textSpan.length = lineEnd - region.textSpan.start;
                        region.hintSpan.length = lineEnd - region.textSpan.start;
                        out.push(region);
                    }
                }
            }
        }
        function isRegionDelimiter(lineText) {
            lineText = trimStringStart(lineText);
            if (!startsWith(lineText, "//")) {
                return null;
            }
            lineText = trimString(lineText.slice(2));
            return regionDelimiterRegExp.exec(lineText);
        }
        function addOutliningForLeadingCommentsForPos(pos, sourceFile, cancellationToken, out) {
            const comments = getLeadingCommentRanges(sourceFile.text, pos);
            if (!comments)
                return;
            let firstSingleLineCommentStart = -1;
            let lastSingleLineCommentEnd = -1;
            let singleLineCommentCount = 0;
            const sourceText = sourceFile.getFullText();
            for (const { kind, pos: pos2, end } of comments) {
                cancellationToken.throwIfCancellationRequested();
                switch (kind) {
                    case 2 /* SingleLineCommentTrivia */:
                        const commentText = sourceText.slice(pos2, end);
                        if (isRegionDelimiter(commentText)) {
                            combineAndAddMultipleSingleLineComments();
                            singleLineCommentCount = 0;
                            break;
                        }
                        if (singleLineCommentCount === 0) {
                            firstSingleLineCommentStart = pos2;
                        }
                        lastSingleLineCommentEnd = end;
                        singleLineCommentCount++;
                        break;
                    case 3 /* MultiLineCommentTrivia */:
                        combineAndAddMultipleSingleLineComments();
                        out.push(createOutliningSpanFromBounds(pos2, end, "comment" /* Comment */));
                        singleLineCommentCount = 0;
                        break;
                    default:
                        Debug.assertNever(kind);
                }
            }
            combineAndAddMultipleSingleLineComments();
            function combineAndAddMultipleSingleLineComments() {
                if (singleLineCommentCount > 1) {
                    out.push(createOutliningSpanFromBounds(firstSingleLineCommentStart, lastSingleLineCommentEnd, "comment" /* Comment */));
                }
            }
        }
        function addOutliningForLeadingCommentsForNode(n, sourceFile, cancellationToken, out) {
            if (isJsxText(n))
                return;
            addOutliningForLeadingCommentsForPos(n.pos, sourceFile, cancellationToken, out);
        }
        function createOutliningSpanFromBounds(pos, end, kind) {
            return createOutliningSpan(createTextSpanFromBounds(pos, end), kind);
        }
        function getOutliningSpanForNode(n, sourceFile) {
            switch (n.kind) {
                case 238 /* Block */:
                    if (isFunctionLike(n.parent)) {
                        return functionSpan(n.parent, n, sourceFile);
                    }
                    switch (n.parent.kind) {
                        case 243 /* DoStatement */:
                        case 246 /* ForInStatement */:
                        case 247 /* ForOfStatement */:
                        case 245 /* ForStatement */:
                        case 242 /* IfStatement */:
                        case 244 /* WhileStatement */:
                        case 251 /* WithStatement */:
                        case 295 /* CatchClause */:
                            return spanForNode(n.parent);
                        case 255 /* TryStatement */:
                            const tryStatement = n.parent;
                            if (tryStatement.tryBlock === n) {
                                return spanForNode(n.parent);
                            }
                            else if (tryStatement.finallyBlock === n) {
                                const node = findChildOfKind(tryStatement, 96 /* FinallyKeyword */, sourceFile);
                                if (node)
                                    return spanForNode(node);
                            }
                        default:
                            return createOutliningSpan(createTextSpanFromNode(n, sourceFile), "code" /* Code */);
                    }
                case 265 /* ModuleBlock */:
                    return spanForNode(n.parent);
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 261 /* InterfaceDeclaration */:
                case 263 /* EnumDeclaration */:
                case 266 /* CaseBlock */:
                case 184 /* TypeLiteral */:
                case 203 /* ObjectBindingPattern */:
                    return spanForNode(n);
                case 186 /* TupleType */:
                    return spanForNode(n, 
                    /*autoCollapse*/
                    false, 
                    /*useFullStart*/
                    !isTupleTypeNode(n.parent), 22 /* OpenBracketToken */);
                case 292 /* CaseClause */:
                case 293 /* DefaultClause */:
                    return spanForNodeArray(n.statements);
                case 207 /* ObjectLiteralExpression */:
                    return spanForObjectOrArrayLiteral(n);
                case 206 /* ArrayLiteralExpression */:
                    return spanForObjectOrArrayLiteral(n, 22 /* OpenBracketToken */);
                case 281 /* JsxElement */:
                    return spanForJSXElement(n);
                case 285 /* JsxFragment */:
                    return spanForJSXFragment(n);
                case 282 /* JsxSelfClosingElement */:
                case 283 /* JsxOpeningElement */:
                    return spanForJSXAttributes(n.attributes);
                case 225 /* TemplateExpression */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                    return spanForTemplateLiteral(n);
                case 204 /* ArrayBindingPattern */:
                    return spanForNode(n, 
                    /*autoCollapse*/
                    false, 
                    /*useFullStart*/
                    !isBindingElement(n.parent), 22 /* OpenBracketToken */);
                case 216 /* ArrowFunction */:
                    return spanForArrowFunction(n);
                case 210 /* CallExpression */:
                    return spanForCallExpression(n);
                case 214 /* ParenthesizedExpression */:
                    return spanForParenthesizedExpression(n);
                case 272 /* NamedImports */:
                case 276 /* NamedExports */:
                case 296 /* AssertClause */:
                    return spanForNamedImportsOrExportsOrAssertClause(n);
            }
            function spanForNamedImportsOrExportsOrAssertClause(node) {
                if (!node.elements.length) {
                    return void 0;
                }
                const openToken = findChildOfKind(node, 18 /* OpenBraceToken */, sourceFile);
                const closeToken = findChildOfKind(node, 19 /* CloseBraceToken */, sourceFile);
                if (!openToken || !closeToken || positionsAreOnSameLine(openToken.pos, closeToken.pos, sourceFile)) {
                    return void 0;
                }
                return spanBetweenTokens(openToken, closeToken, node, sourceFile, 
                /*autoCollapse*/
                false, 
                /*useFullStart*/
                false);
            }
            function spanForCallExpression(node) {
                if (!node.arguments.length) {
                    return void 0;
                }
                const openToken = findChildOfKind(node, 20 /* OpenParenToken */, sourceFile);
                const closeToken = findChildOfKind(node, 21 /* CloseParenToken */, sourceFile);
                if (!openToken || !closeToken || positionsAreOnSameLine(openToken.pos, closeToken.pos, sourceFile)) {
                    return void 0;
                }
                return spanBetweenTokens(openToken, closeToken, node, sourceFile, 
                /*autoCollapse*/
                false, 
                /*useFullStart*/
                true);
            }
            function spanForArrowFunction(node) {
                if (isBlock(node.body) || isParenthesizedExpression(node.body) || positionsAreOnSameLine(node.body.getFullStart(), node.body.getEnd(), sourceFile)) {
                    return void 0;
                }
                const textSpan = createTextSpanFromBounds(node.body.getFullStart(), node.body.getEnd());
                return createOutliningSpan(textSpan, "code" /* Code */, createTextSpanFromNode(node));
            }
            function spanForJSXElement(node) {
                const textSpan = createTextSpanFromBounds(node.openingElement.getStart(sourceFile), node.closingElement.getEnd());
                const tagName = node.openingElement.tagName.getText(sourceFile);
                const bannerText = "<" + tagName + ">...</" + tagName + ">";
                return createOutliningSpan(textSpan, "code" /* Code */, textSpan, 
                /*autoCollapse*/
                false, bannerText);
            }
            function spanForJSXFragment(node) {
                const textSpan = createTextSpanFromBounds(node.openingFragment.getStart(sourceFile), node.closingFragment.getEnd());
                const bannerText = "<>...</>";
                return createOutliningSpan(textSpan, "code" /* Code */, textSpan, 
                /*autoCollapse*/
                false, bannerText);
            }
            function spanForJSXAttributes(node) {
                if (node.properties.length === 0) {
                    return void 0;
                }
                return createOutliningSpanFromBounds(node.getStart(sourceFile), node.getEnd(), "code" /* Code */);
            }
            function spanForTemplateLiteral(node) {
                if (node.kind === 14 /* NoSubstitutionTemplateLiteral */ && node.text.length === 0) {
                    return void 0;
                }
                return createOutliningSpanFromBounds(node.getStart(sourceFile), node.getEnd(), "code" /* Code */);
            }
            function spanForObjectOrArrayLiteral(node, open = 18 /* OpenBraceToken */) {
                return spanForNode(node, 
                /*autoCollapse*/
                false, 
                /*useFullStart*/
                !isArrayLiteralExpression(node.parent) && !isCallExpression(node.parent), open);
            }
            function spanForNode(hintSpanNode, autoCollapse = false, useFullStart = true, open = 18 /* OpenBraceToken */, close = open === 18 /* OpenBraceToken */ ? 19 /* CloseBraceToken */ : 23 /* CloseBracketToken */) {
                const openToken = findChildOfKind(n, open, sourceFile);
                const closeToken = findChildOfKind(n, close, sourceFile);
                return openToken && closeToken && spanBetweenTokens(openToken, closeToken, hintSpanNode, sourceFile, autoCollapse, useFullStart);
            }
            function spanForNodeArray(nodeArray) {
                return nodeArray.length ? createOutliningSpan(createTextSpanFromRange(nodeArray), "code" /* Code */) : void 0;
            }
            function spanForParenthesizedExpression(node) {
                if (positionsAreOnSameLine(node.getStart(), node.getEnd(), sourceFile))
                    return void 0;
                const textSpan = createTextSpanFromBounds(node.getStart(), node.getEnd());
                return createOutliningSpan(textSpan, "code" /* Code */, createTextSpanFromNode(node));
            }
        }
        function functionSpan(node, body, sourceFile) {
            const openToken = tryGetFunctionOpenToken(node, body, sourceFile);
            const closeToken = findChildOfKind(body, 19 /* CloseBraceToken */, sourceFile);
            return openToken && closeToken && spanBetweenTokens(openToken, closeToken, node, sourceFile, 
            /*autoCollapse*/
            node.kind !== 216 /* ArrowFunction */);
        }
        function spanBetweenTokens(openToken, closeToken, hintSpanNode, sourceFile, autoCollapse = false, useFullStart = true) {
            const textSpan = createTextSpanFromBounds(useFullStart ? openToken.getFullStart() : openToken.getStart(sourceFile), closeToken.getEnd());
            return createOutliningSpan(textSpan, "code" /* Code */, createTextSpanFromNode(hintSpanNode, sourceFile), autoCollapse);
        }
        function createOutliningSpan(textSpan, kind, hintSpan = textSpan, autoCollapse = false, bannerText = "...") {
            return { textSpan, kind, hintSpan, bannerText, autoCollapse };
        }
        function tryGetFunctionOpenToken(node, body, sourceFile) {
            if (isNodeArrayMultiLine(node.parameters, sourceFile)) {
                const openParenToken = findChildOfKind(node, 20 /* OpenParenToken */, sourceFile);
                if (openParenToken) {
                    return openParenToken;
                }
            }
            return findChildOfKind(body, 18 /* OpenBraceToken */, sourceFile);
        }
        var regionDelimiterRegExp;
        var init_outliningElementsCollector = __esm({
            "src/services/outliningElementsCollector.ts"() {
                "use strict";
                init_ts4();
                regionDelimiterRegExp = /^#(end)?region(?:\s+(.*))?(?:\r)?$/;
            }
        });
        // src/services/_namespaces/ts.OutliningElementsCollector.ts
        var ts_OutliningElementsCollector_exports = {};
        __export(ts_OutliningElementsCollector_exports, {
            collectElements: () => collectElements
        });
        var init_ts_OutliningElementsCollector = __esm({
            "src/services/_namespaces/ts.OutliningElementsCollector.ts"() {
                "use strict";
                init_outliningElementsCollector();
            }
        });
        // src/services/refactorProvider.ts
        function registerRefactor(name, refactor) {
            refactors.set(name, refactor);
        }
        function getApplicableRefactors(context) {
            return arrayFrom(flatMapIterator(refactors.values(), (refactor) => {
                var _a2;
                return context.cancellationToken && context.cancellationToken.isCancellationRequested() || !((_a2 = refactor.kinds) == null ? void 0 : _a2.some((kind) => refactorKindBeginsWith(kind, context.kind))) ? void 0 : refactor.getAvailableActions(context);
            }));
        }
        function getEditsForRefactor(context, refactorName13, actionName2) {
            const refactor = refactors.get(refactorName13);
            return refactor && refactor.getEditsForAction(context, actionName2);
        }
        var refactors;
        var init_refactorProvider = __esm({
            "src/services/refactorProvider.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactors = /* @__PURE__ */ new Map();
            }
        });
        // src/services/refactors/convertExport.ts
        function getInfo19(context, considerPartialSpans = true) {
            const { file, program } = context;
            const span = getRefactorContextSpan(context);
            const token = getTokenAtPosition(file, span.start);
            const exportNode = !!(token.parent && getSyntacticModifierFlags(token.parent) & 1 /* Export */) && considerPartialSpans ? token.parent : getParentNodeInSpan(token, file, span);
            if (!exportNode || !isSourceFile(exportNode.parent) && !(isModuleBlock(exportNode.parent) && isAmbientModule(exportNode.parent.parent))) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_export_statement) };
            }
            const checker = program.getTypeChecker();
            const exportingModuleSymbol = getExportingModuleSymbol(exportNode.parent, checker);
            const flags = getSyntacticModifierFlags(exportNode) || (isExportAssignment(exportNode) && !exportNode.isExportEquals ? 1025 /* ExportDefault */ : 0 /* None */);
            const wasDefault = !!(flags & 1024 /* Default */);
            if (!(flags & 1 /* Export */) || !wasDefault && exportingModuleSymbol.exports.has("default" /* Default */)) {
                return { error: getLocaleSpecificMessage(Diagnostics.This_file_already_has_a_default_export) };
            }
            const noSymbolError = (id) => isIdentifier(id) && checker.getSymbolAtLocation(id) ? void 0 : { error: getLocaleSpecificMessage(Diagnostics.Can_only_convert_named_export) };
            switch (exportNode.kind) {
                case 259 /* FunctionDeclaration */:
                case 260 /* ClassDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 263 /* EnumDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 264 /* ModuleDeclaration */: {
                    const node = exportNode;
                    if (!node.name)
                        return void 0;
                    return noSymbolError(node.name) || { exportNode: node, exportName: node.name, wasDefault, exportingModuleSymbol };
                }
                case 240 /* VariableStatement */: {
                    const vs = exportNode;
                    if (!(vs.declarationList.flags & 2 /* Const */) || vs.declarationList.declarations.length !== 1) {
                        return void 0;
                    }
                    const decl = first(vs.declarationList.declarations);
                    if (!decl.initializer)
                        return void 0;
                    Debug.assert(!wasDefault, "Can't have a default flag here");
                    return noSymbolError(decl.name) || { exportNode: vs, exportName: decl.name, wasDefault, exportingModuleSymbol };
                }
                case 274 /* ExportAssignment */: {
                    const node = exportNode;
                    if (node.isExportEquals)
                        return void 0;
                    return noSymbolError(node.expression) || { exportNode: node, exportName: node.expression, wasDefault, exportingModuleSymbol };
                }
                default:
                    return void 0;
            }
        }
        function doChange33(exportingSourceFile, program, info, changes, cancellationToken) {
            changeExport(exportingSourceFile, info, changes, program.getTypeChecker());
            changeImports(program, info, changes, cancellationToken);
        }
        function changeExport(exportingSourceFile, { wasDefault, exportNode, exportName }, changes, checker) {
            if (wasDefault) {
                if (isExportAssignment(exportNode) && !exportNode.isExportEquals) {
                    const exp = exportNode.expression;
                    const spec = makeExportSpecifier(exp.text, exp.text);
                    changes.replaceNode(exportingSourceFile, exportNode, factory.createExportDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*isTypeOnly*/
                    false, factory.createNamedExports([spec])));
                }
                else {
                    changes.delete(exportingSourceFile, Debug.checkDefined(findModifier(exportNode, 88 /* DefaultKeyword */), "Should find a default keyword in modifier list"));
                }
            }
            else {
                const exportKeyword = Debug.checkDefined(findModifier(exportNode, 93 /* ExportKeyword */), "Should find an export keyword in modifier list");
                switch (exportNode.kind) {
                    case 259 /* FunctionDeclaration */:
                    case 260 /* ClassDeclaration */:
                    case 261 /* InterfaceDeclaration */:
                        changes.insertNodeAfter(exportingSourceFile, exportKeyword, factory.createToken(88 /* DefaultKeyword */));
                        break;
                    case 240 /* VariableStatement */:
                        const decl = first(exportNode.declarationList.declarations);
                        if (!ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(exportName, checker, exportingSourceFile) && !decl.type) {
                            changes.replaceNode(exportingSourceFile, exportNode, factory.createExportDefault(Debug.checkDefined(decl.initializer, "Initializer was previously known to be present")));
                            break;
                        }
                    case 263 /* EnumDeclaration */:
                    case 262 /* TypeAliasDeclaration */:
                    case 264 /* ModuleDeclaration */:
                        changes.deleteModifier(exportingSourceFile, exportKeyword);
                        changes.insertNodeAfter(exportingSourceFile, exportNode, factory.createExportDefault(factory.createIdentifier(exportName.text)));
                        break;
                    default:
                        Debug.fail(`Unexpected exportNode kind ${exportNode.kind}`);
                }
            }
        }
        function changeImports(program, { wasDefault, exportName, exportingModuleSymbol }, changes, cancellationToken) {
            const checker = program.getTypeChecker();
            const exportSymbol = Debug.checkDefined(checker.getSymbolAtLocation(exportName), "Export name should resolve to a symbol");
            ts_FindAllReferences_exports.Core.eachExportReference(program.getSourceFiles(), checker, cancellationToken, exportSymbol, exportingModuleSymbol, exportName.text, wasDefault, (ref) => {
                if (exportName === ref)
                    return;
                const importingSourceFile = ref.getSourceFile();
                if (wasDefault) {
                    changeDefaultToNamedImport(importingSourceFile, ref, changes, exportName.text);
                }
                else {
                    changeNamedToDefaultImport(importingSourceFile, ref, changes);
                }
            });
        }
        function changeDefaultToNamedImport(importingSourceFile, ref, changes, exportName) {
            const { parent: parent2 } = ref;
            switch (parent2.kind) {
                case 208 /* PropertyAccessExpression */:
                    changes.replaceNode(importingSourceFile, ref, factory.createIdentifier(exportName));
                    break;
                case 273 /* ImportSpecifier */:
                case 278 /* ExportSpecifier */: {
                    const spec = parent2;
                    changes.replaceNode(importingSourceFile, spec, makeImportSpecifier2(exportName, spec.name.text));
                    break;
                }
                case 270 /* ImportClause */: {
                    const clause = parent2;
                    Debug.assert(clause.name === ref, "Import clause name should match provided ref");
                    const spec = makeImportSpecifier2(exportName, ref.text);
                    const { namedBindings } = clause;
                    if (!namedBindings) {
                        changes.replaceNode(importingSourceFile, ref, factory.createNamedImports([spec]));
                    }
                    else if (namedBindings.kind === 271 /* NamespaceImport */) {
                        changes.deleteRange(importingSourceFile, { pos: ref.getStart(importingSourceFile), end: namedBindings.getStart(importingSourceFile) });
                        const quotePreference = isStringLiteral(clause.parent.moduleSpecifier) ? quotePreferenceFromString(clause.parent.moduleSpecifier, importingSourceFile) : 1 /* Double */;
                        const newImport = makeImport(
                        /*default*/
                        void 0, [makeImportSpecifier2(exportName, ref.text)], clause.parent.moduleSpecifier, quotePreference);
                        changes.insertNodeAfter(importingSourceFile, clause.parent, newImport);
                    }
                    else {
                        changes.delete(importingSourceFile, ref);
                        changes.insertNodeAtEndOfList(importingSourceFile, namedBindings.elements, spec);
                    }
                    break;
                }
                case 202 /* ImportType */:
                    const importTypeNode = parent2;
                    changes.replaceNode(importingSourceFile, parent2, factory.createImportTypeNode(importTypeNode.argument, importTypeNode.assertions, factory.createIdentifier(exportName), importTypeNode.typeArguments, importTypeNode.isTypeOf));
                    break;
                default:
                    Debug.failBadSyntaxKind(parent2);
            }
        }
        function changeNamedToDefaultImport(importingSourceFile, ref, changes) {
            const parent2 = ref.parent;
            switch (parent2.kind) {
                case 208 /* PropertyAccessExpression */:
                    changes.replaceNode(importingSourceFile, ref, factory.createIdentifier("default"));
                    break;
                case 273 /* ImportSpecifier */: {
                    const defaultImport = factory.createIdentifier(parent2.name.text);
                    if (parent2.parent.elements.length === 1) {
                        changes.replaceNode(importingSourceFile, parent2.parent, defaultImport);
                    }
                    else {
                        changes.delete(importingSourceFile, parent2);
                        changes.insertNodeBefore(importingSourceFile, parent2.parent, defaultImport);
                    }
                    break;
                }
                case 278 /* ExportSpecifier */: {
                    changes.replaceNode(importingSourceFile, parent2, makeExportSpecifier("default", parent2.name.text));
                    break;
                }
                default:
                    Debug.assertNever(parent2, `Unexpected parent kind ${parent2.kind}`);
            }
        }
        function makeImportSpecifier2(propertyName, name) {
            return factory.createImportSpecifier(
            /*isTypeOnly*/
            false, propertyName === name ? void 0 : factory.createIdentifier(propertyName), factory.createIdentifier(name));
        }
        function makeExportSpecifier(propertyName, name) {
            return factory.createExportSpecifier(
            /*isTypeOnly*/
            false, propertyName === name ? void 0 : factory.createIdentifier(propertyName), factory.createIdentifier(name));
        }
        function getExportingModuleSymbol(parent2, checker) {
            if (isSourceFile(parent2)) {
                return parent2.symbol;
            }
            const symbol = parent2.parent.symbol;
            if (symbol.valueDeclaration && isExternalModuleAugmentation(symbol.valueDeclaration)) {
                return checker.getMergedSymbol(symbol);
            }
            return symbol;
        }
        var refactorName, defaultToNamedAction, namedToDefaultAction;
        var init_convertExport = __esm({
            "src/services/refactors/convertExport.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName = "Convert export";
                defaultToNamedAction = {
                    name: "Convert default export to named export",
                    description: Diagnostics.Convert_default_export_to_named_export.message,
                    kind: "refactor.rewrite.export.named"
                };
                namedToDefaultAction = {
                    name: "Convert named export to default export",
                    description: Diagnostics.Convert_named_export_to_default_export.message,
                    kind: "refactor.rewrite.export.default"
                };
                registerRefactor(refactorName, {
                    kinds: [
                        defaultToNamedAction.kind,
                        namedToDefaultAction.kind
                    ],
                    getAvailableActions: function getRefactorActionsToConvertBetweenNamedAndDefaultExports(context) {
                        const info = getInfo19(context, context.triggerReason === "invoked");
                        if (!info)
                            return emptyArray;
                        if (!isRefactorErrorInfo(info)) {
                            const action = info.wasDefault ? defaultToNamedAction : namedToDefaultAction;
                            return [{ name: refactorName, description: action.description, actions: [action] }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return [
                                { name: refactorName, description: Diagnostics.Convert_default_export_to_named_export.message, actions: [
                                        { ...defaultToNamedAction, notApplicableReason: info.error },
                                        { ...namedToDefaultAction, notApplicableReason: info.error }
                                    ] }
                            ];
                        }
                        return emptyArray;
                    },
                    getEditsForAction: function getRefactorEditsToConvertBetweenNamedAndDefaultExports(context, actionName2) {
                        Debug.assert(actionName2 === defaultToNamedAction.name || actionName2 === namedToDefaultAction.name, "Unexpected action name");
                        const info = getInfo19(context);
                        Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
                        const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange33(context.file, context.program, info, t, context.cancellationToken));
                        return { edits, renameFilename: void 0, renameLocation: void 0 };
                    }
                });
            }
        });
        // src/services/refactors/convertImport.ts
        function getImportConversionInfo(context, considerPartialSpans = true) {
            const { file } = context;
            const span = getRefactorContextSpan(context);
            const token = getTokenAtPosition(file, span.start);
            const importDecl = considerPartialSpans ? findAncestor(token, isImportDeclaration) : getParentNodeInSpan(token, file, span);
            if (!importDecl || !isImportDeclaration(importDecl))
                return { error: "Selection is not an import declaration." };
            const end = span.start + span.length;
            const nextToken = findNextToken(importDecl, importDecl.parent, file);
            if (nextToken && end > nextToken.getStart())
                return void 0;
            const { importClause } = importDecl;
            if (!importClause) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_import_clause) };
            }
            if (!importClause.namedBindings) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_namespace_import_or_named_imports) };
            }
            if (importClause.namedBindings.kind === 271 /* NamespaceImport */) {
                return { convertTo: 0 /* Named */, import: importClause.namedBindings };
            }
            const shouldUseDefault = getShouldUseDefault(context.program, importClause);
            return shouldUseDefault ? { convertTo: 1 /* Default */, import: importClause.namedBindings } : { convertTo: 2 /* Namespace */, import: importClause.namedBindings };
        }
        function getShouldUseDefault(program, importClause) {
            return getAllowSyntheticDefaultImports(program.getCompilerOptions()) && isExportEqualsModule(importClause.parent.moduleSpecifier, program.getTypeChecker());
        }
        function doChange34(sourceFile, program, changes, info) {
            const checker = program.getTypeChecker();
            if (info.convertTo === 0 /* Named */) {
                doChangeNamespaceToNamed(sourceFile, checker, changes, info.import, getAllowSyntheticDefaultImports(program.getCompilerOptions()));
            }
            else {
                doChangeNamedToNamespaceOrDefault(sourceFile, program, changes, info.import, info.convertTo === 1 /* Default */);
            }
        }
        function doChangeNamespaceToNamed(sourceFile, checker, changes, toConvert, allowSyntheticDefaultImports) {
            let usedAsNamespaceOrDefault = false;
            const nodesToReplace = [];
            const conflictingNames = /* @__PURE__ */ new Map();
            ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(toConvert.name, checker, sourceFile, (id) => {
                if (!isPropertyAccessOrQualifiedName(id.parent)) {
                    usedAsNamespaceOrDefault = true;
                }
                else {
                    const exportName = getRightOfPropertyAccessOrQualifiedName(id.parent).text;
                    if (checker.resolveName(exportName, id, 67108863 /* All */, 
                    /*excludeGlobals*/
                    true)) {
                        conflictingNames.set(exportName, true);
                    }
                    Debug.assert(getLeftOfPropertyAccessOrQualifiedName(id.parent) === id, "Parent expression should match id");
                    nodesToReplace.push(id.parent);
                }
            });
            const exportNameToImportName = /* @__PURE__ */ new Map();
            for (const propertyAccessOrQualifiedName of nodesToReplace) {
                const exportName = getRightOfPropertyAccessOrQualifiedName(propertyAccessOrQualifiedName).text;
                let importName = exportNameToImportName.get(exportName);
                if (importName === void 0) {
                    exportNameToImportName.set(exportName, importName = conflictingNames.has(exportName) ? getUniqueName(exportName, sourceFile) : exportName);
                }
                changes.replaceNode(sourceFile, propertyAccessOrQualifiedName, factory.createIdentifier(importName));
            }
            const importSpecifiers = [];
            exportNameToImportName.forEach((name, propertyName) => {
                importSpecifiers.push(factory.createImportSpecifier(
                /*isTypeOnly*/
                false, name === propertyName ? void 0 : factory.createIdentifier(propertyName), factory.createIdentifier(name)));
            });
            const importDecl = toConvert.parent.parent;
            if (usedAsNamespaceOrDefault && !allowSyntheticDefaultImports) {
                changes.insertNodeAfter(sourceFile, importDecl, updateImport(importDecl, 
                /*defaultImportName*/
                void 0, importSpecifiers));
            }
            else {
                changes.replaceNode(sourceFile, importDecl, updateImport(importDecl, usedAsNamespaceOrDefault ? factory.createIdentifier(toConvert.name.text) : void 0, importSpecifiers));
            }
        }
        function getRightOfPropertyAccessOrQualifiedName(propertyAccessOrQualifiedName) {
            return isPropertyAccessExpression(propertyAccessOrQualifiedName) ? propertyAccessOrQualifiedName.name : propertyAccessOrQualifiedName.right;
        }
        function getLeftOfPropertyAccessOrQualifiedName(propertyAccessOrQualifiedName) {
            return isPropertyAccessExpression(propertyAccessOrQualifiedName) ? propertyAccessOrQualifiedName.expression : propertyAccessOrQualifiedName.left;
        }
        function doChangeNamedToNamespaceOrDefault(sourceFile, program, changes, toConvert, shouldUseDefault = getShouldUseDefault(program, toConvert.parent)) {
            const checker = program.getTypeChecker();
            const importDecl = toConvert.parent.parent;
            const { moduleSpecifier } = importDecl;
            const toConvertSymbols = /* @__PURE__ */ new Set();
            toConvert.elements.forEach((namedImport) => {
                const symbol = checker.getSymbolAtLocation(namedImport.name);
                if (symbol) {
                    toConvertSymbols.add(symbol);
                }
            });
            const preferredName = moduleSpecifier && isStringLiteral(moduleSpecifier) ? ts_codefix_exports.moduleSpecifierToValidIdentifier(moduleSpecifier.text, 99 /* ESNext */) : "module";
            function hasNamespaceNameConflict(namedImport) {
                return !!ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(namedImport.name, checker, sourceFile, (id) => {
                    const symbol = checker.resolveName(preferredName, id, 67108863 /* All */, 
                    /*excludeGlobals*/
                    true);
                    if (symbol) {
                        if (toConvertSymbols.has(symbol)) {
                            return isExportSpecifier(id.parent);
                        }
                        return true;
                    }
                    return false;
                });
            }
            const namespaceNameConflicts = toConvert.elements.some(hasNamespaceNameConflict);
            const namespaceImportName = namespaceNameConflicts ? getUniqueName(preferredName, sourceFile) : preferredName;
            const neededNamedImports = /* @__PURE__ */ new Set();
            for (const element of toConvert.elements) {
                const propertyName = (element.propertyName || element.name).text;
                ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(element.name, checker, sourceFile, (id) => {
                    const access = factory.createPropertyAccessExpression(factory.createIdentifier(namespaceImportName), propertyName);
                    if (isShorthandPropertyAssignment(id.parent)) {
                        changes.replaceNode(sourceFile, id.parent, factory.createPropertyAssignment(id.text, access));
                    }
                    else if (isExportSpecifier(id.parent)) {
                        neededNamedImports.add(element);
                    }
                    else {
                        changes.replaceNode(sourceFile, id, access);
                    }
                });
            }
            changes.replaceNode(sourceFile, toConvert, shouldUseDefault ? factory.createIdentifier(namespaceImportName) : factory.createNamespaceImport(factory.createIdentifier(namespaceImportName)));
            if (neededNamedImports.size) {
                const newNamedImports = arrayFrom(neededNamedImports.values(), (element) => factory.createImportSpecifier(element.isTypeOnly, element.propertyName && factory.createIdentifier(element.propertyName.text), factory.createIdentifier(element.name.text)));
                changes.insertNodeAfter(sourceFile, toConvert.parent.parent, updateImport(importDecl, 
                /*defaultImportName*/
                void 0, newNamedImports));
            }
        }
        function isExportEqualsModule(moduleSpecifier, checker) {
            const externalModule = checker.resolveExternalModuleName(moduleSpecifier);
            if (!externalModule)
                return false;
            const exportEquals = checker.resolveExternalModuleSymbol(externalModule);
            return externalModule !== exportEquals;
        }
        function updateImport(old, defaultImportName, elements) {
            return factory.createImportDeclaration(
            /*modifiers*/
            void 0, factory.createImportClause(
            /*isTypeOnly*/
            false, defaultImportName, elements && elements.length ? factory.createNamedImports(elements) : void 0), old.moduleSpecifier, 
            /*assertClause*/
            void 0);
        }
        var refactorName2, actions;
        var init_convertImport = __esm({
            "src/services/refactors/convertImport.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName2 = "Convert import";
                actions = {
                    [0 /* Named */]: {
                        name: "Convert namespace import to named imports",
                        description: Diagnostics.Convert_namespace_import_to_named_imports.message,
                        kind: "refactor.rewrite.import.named"
                    },
                    [2 /* Namespace */]: {
                        name: "Convert named imports to namespace import",
                        description: Diagnostics.Convert_named_imports_to_namespace_import.message,
                        kind: "refactor.rewrite.import.namespace"
                    },
                    [1 /* Default */]: {
                        name: "Convert named imports to default import",
                        description: Diagnostics.Convert_named_imports_to_default_import.message,
                        kind: "refactor.rewrite.import.default"
                    }
                };
                registerRefactor(refactorName2, {
                    kinds: getOwnValues(actions).map((a) => a.kind),
                    getAvailableActions: function getRefactorActionsToConvertBetweenNamedAndNamespacedImports(context) {
                        const info = getImportConversionInfo(context, context.triggerReason === "invoked");
                        if (!info)
                            return emptyArray;
                        if (!isRefactorErrorInfo(info)) {
                            const action = actions[info.convertTo];
                            return [{ name: refactorName2, description: action.description, actions: [action] }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return getOwnValues(actions).map((action) => ({
                                name: refactorName2,
                                description: action.description,
                                actions: [{ ...action, notApplicableReason: info.error }]
                            }));
                        }
                        return emptyArray;
                    },
                    getEditsForAction: function getRefactorEditsToConvertBetweenNamedAndNamespacedImports(context, actionName2) {
                        Debug.assert(some(getOwnValues(actions), (action) => action.name === actionName2), "Unexpected action name");
                        const info = getImportConversionInfo(context);
                        Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
                        const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange34(context.file, context.program, t, info));
                        return { edits, renameFilename: void 0, renameLocation: void 0 };
                    }
                });
            }
        });
        // src/services/refactors/extractType.ts
        function getRangeToExtract(context, considerEmptySpans = true) {
            const { file, startPosition } = context;
            const isJS = isSourceFileJS(file);
            const current = getTokenAtPosition(file, startPosition);
            const range = createTextRangeFromSpan(getRefactorContextSpan(context));
            const cursorRequest = range.pos === range.end && considerEmptySpans;
            const selection = findAncestor(current, (node) => node.parent && isTypeNode(node) && !rangeContainsSkipTrivia(range, node.parent, file) && (cursorRequest || nodeOverlapsWithStartEnd(current, file, range.pos, range.end)));
            if (!selection || !isTypeNode(selection))
                return { error: getLocaleSpecificMessage(Diagnostics.Selection_is_not_a_valid_type_node) };
            const checker = context.program.getTypeChecker();
            const enclosingNode = getEnclosingNode(selection, isJS);
            if (enclosingNode === void 0)
                return { error: getLocaleSpecificMessage(Diagnostics.No_type_could_be_extracted_from_this_type_node) };
            const typeParameters = collectTypeParameters(checker, selection, enclosingNode, file);
            if (!typeParameters)
                return { error: getLocaleSpecificMessage(Diagnostics.No_type_could_be_extracted_from_this_type_node) };
            const typeElements = flattenTypeLiteralNodeReference(checker, selection);
            return { isJS, selection, enclosingNode, typeParameters, typeElements };
        }
        function flattenTypeLiteralNodeReference(checker, node) {
            if (!node)
                return void 0;
            if (isIntersectionTypeNode(node)) {
                const result = [];
                const seen = /* @__PURE__ */ new Map();
                for (const type of node.types) {
                    const flattenedTypeMembers = flattenTypeLiteralNodeReference(checker, type);
                    if (!flattenedTypeMembers || !flattenedTypeMembers.every((type2) => type2.name && addToSeen(seen, getNameFromPropertyName(type2.name)))) {
                        return void 0;
                    }
                    addRange(result, flattenedTypeMembers);
                }
                return result;
            }
            else if (isParenthesizedTypeNode(node)) {
                return flattenTypeLiteralNodeReference(checker, node.type);
            }
            else if (isTypeLiteralNode(node)) {
                return node.members;
            }
            return void 0;
        }
        function rangeContainsSkipTrivia(r1, node, file) {
            return rangeContainsStartEnd(r1, skipTrivia(file.text, node.pos), node.end);
        }
        function collectTypeParameters(checker, selection, enclosingNode, file) {
            const result = [];
            return visitor(selection) ? void 0 : result;
            function visitor(node) {
                if (isTypeReferenceNode(node)) {
                    if (isIdentifier(node.typeName)) {
                        const typeName = node.typeName;
                        const symbol = checker.resolveName(typeName.text, typeName, 262144 /* TypeParameter */, 
                        /* excludeGlobals */
                        true);
                        for (const decl of (symbol == null ? void 0 : symbol.declarations) || emptyArray) {
                            if (isTypeParameterDeclaration(decl) && decl.getSourceFile() === file) {
                                if (decl.name.escapedText === typeName.escapedText && rangeContainsSkipTrivia(decl, selection, file)) {
                                    return true;
                                }
                                if (rangeContainsSkipTrivia(enclosingNode, decl, file) && !rangeContainsSkipTrivia(selection, decl, file)) {
                                    pushIfUnique(result, decl);
                                    break;
                                }
                            }
                        }
                    }
                }
                else if (isInferTypeNode(node)) {
                    const conditionalTypeNode = findAncestor(node, (n) => isConditionalTypeNode(n) && rangeContainsSkipTrivia(n.extendsType, node, file));
                    if (!conditionalTypeNode || !rangeContainsSkipTrivia(selection, conditionalTypeNode, file)) {
                        return true;
                    }
                }
                else if (isTypePredicateNode(node) || isThisTypeNode(node)) {
                    const functionLikeNode = findAncestor(node.parent, isFunctionLike);
                    if (functionLikeNode && functionLikeNode.type && rangeContainsSkipTrivia(functionLikeNode.type, node, file) && !rangeContainsSkipTrivia(selection, functionLikeNode, file)) {
                        return true;
                    }
                }
                else if (isTypeQueryNode(node)) {
                    if (isIdentifier(node.exprName)) {
                        const symbol = checker.resolveName(node.exprName.text, node.exprName, 111551 /* Value */, 
                        /* excludeGlobals */
                        false);
                        if ((symbol == null ? void 0 : symbol.valueDeclaration) && rangeContainsSkipTrivia(enclosingNode, symbol.valueDeclaration, file) && !rangeContainsSkipTrivia(selection, symbol.valueDeclaration, file)) {
                            return true;
                        }
                    }
                    else {
                        if (isThisIdentifier(node.exprName.left) && !rangeContainsSkipTrivia(selection, node.parent, file)) {
                            return true;
                        }
                    }
                }
                if (file && isTupleTypeNode(node) && getLineAndCharacterOfPosition(file, node.pos).line === getLineAndCharacterOfPosition(file, node.end).line) {
                    setEmitFlags(node, 1 /* SingleLine */);
                }
                return forEachChild(node, visitor);
            }
        }
        function doTypeAliasChange(changes, file, name, info) {
            const { enclosingNode, selection, typeParameters } = info;
            const newTypeNode = factory.createTypeAliasDeclaration(
            /* modifiers */
            void 0, name, typeParameters.map((id) => factory.updateTypeParameterDeclaration(id, id.modifiers, id.name, id.constraint, 
            /* defaultType */
            void 0)), selection);
            changes.insertNodeBefore(file, enclosingNode, ignoreSourceNewlines(newTypeNode), 
            /* blankLineBetween */
            true);
            changes.replaceNode(file, selection, factory.createTypeReferenceNode(name, typeParameters.map((id) => factory.createTypeReferenceNode(id.name, 
            /* typeArguments */
            void 0))), { leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude, trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.ExcludeWhitespace });
        }
        function doInterfaceChange(changes, file, name, info) {
            var _a2;
            const { enclosingNode, selection, typeParameters, typeElements } = info;
            const newTypeNode = factory.createInterfaceDeclaration(
            /* modifiers */
            void 0, name, typeParameters, 
            /* heritageClauses */
            void 0, typeElements);
            setTextRange(newTypeNode, (_a2 = typeElements[0]) == null ? void 0 : _a2.parent);
            changes.insertNodeBefore(file, enclosingNode, ignoreSourceNewlines(newTypeNode), 
            /* blankLineBetween */
            true);
            changes.replaceNode(file, selection, factory.createTypeReferenceNode(name, typeParameters.map((id) => factory.createTypeReferenceNode(id.name, 
            /* typeArguments */
            void 0))), { leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude, trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.ExcludeWhitespace });
        }
        function doTypedefChange(changes, context, file, name, info) {
            var _a2;
            const { enclosingNode, selection, typeParameters } = info;
            setEmitFlags(selection, 3072 /* NoComments */ | 4096 /* NoNestedComments */);
            const node = factory.createJSDocTypedefTag(factory.createIdentifier("typedef"), factory.createJSDocTypeExpression(selection), factory.createIdentifier(name));
            const templates = [];
            forEach(typeParameters, (typeParameter) => {
                const constraint = getEffectiveConstraintOfTypeParameter(typeParameter);
                const parameter = factory.createTypeParameterDeclaration(
                /*modifiers*/
                void 0, typeParameter.name);
                const template = factory.createJSDocTemplateTag(factory.createIdentifier("template"), constraint && cast(constraint, isJSDocTypeExpression), [parameter]);
                templates.push(template);
            });
            const jsDoc = factory.createJSDocComment(
            /* comment */
            void 0, factory.createNodeArray(concatenate(templates, [node])));
            if (isJSDoc(enclosingNode)) {
                const pos = enclosingNode.getStart(file);
                const newLineCharacter = getNewLineOrDefaultFromHost(context.host, (_a2 = context.formatContext) == null ? void 0 : _a2.options);
                changes.insertNodeAt(file, enclosingNode.getStart(file), jsDoc, {
                    suffix: newLineCharacter + newLineCharacter + file.text.slice(getPrecedingNonSpaceCharacterPosition(file.text, pos - 1), pos)
                });
            }
            else {
                changes.insertNodeBefore(file, enclosingNode, jsDoc, 
                /* blankLineBetween */
                true);
            }
            changes.replaceNode(file, selection, factory.createTypeReferenceNode(name, typeParameters.map((id) => factory.createTypeReferenceNode(id.name, 
            /* typeArguments */
            void 0))));
        }
        function getEnclosingNode(node, isJS) {
            return findAncestor(node, isStatement) || (isJS ? findAncestor(node, isJSDoc) : void 0);
        }
        var refactorName3, extractToTypeAliasAction, extractToInterfaceAction, extractToTypeDefAction;
        var init_extractType = __esm({
            "src/services/refactors/extractType.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName3 = "Extract type";
                extractToTypeAliasAction = {
                    name: "Extract to type alias",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_to_type_alias),
                    kind: "refactor.extract.type"
                };
                extractToInterfaceAction = {
                    name: "Extract to interface",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_to_interface),
                    kind: "refactor.extract.interface"
                };
                extractToTypeDefAction = {
                    name: "Extract to typedef",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_to_typedef),
                    kind: "refactor.extract.typedef"
                };
                registerRefactor(refactorName3, {
                    kinds: [
                        extractToTypeAliasAction.kind,
                        extractToInterfaceAction.kind,
                        extractToTypeDefAction.kind
                    ],
                    getAvailableActions: function getRefactorActionsToExtractType(context) {
                        const info = getRangeToExtract(context, context.triggerReason === "invoked");
                        if (!info)
                            return emptyArray;
                        if (!isRefactorErrorInfo(info)) {
                            return [{
                                    name: refactorName3,
                                    description: getLocaleSpecificMessage(Diagnostics.Extract_type),
                                    actions: info.isJS ? [extractToTypeDefAction] : append([extractToTypeAliasAction], info.typeElements && extractToInterfaceAction)
                                }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return [{
                                    name: refactorName3,
                                    description: getLocaleSpecificMessage(Diagnostics.Extract_type),
                                    actions: [
                                        { ...extractToTypeDefAction, notApplicableReason: info.error },
                                        { ...extractToTypeAliasAction, notApplicableReason: info.error },
                                        { ...extractToInterfaceAction, notApplicableReason: info.error }
                                    ]
                                }];
                        }
                        return emptyArray;
                    },
                    getEditsForAction: function getRefactorEditsToExtractType(context, actionName2) {
                        const { file } = context;
                        const info = getRangeToExtract(context);
                        Debug.assert(info && !isRefactorErrorInfo(info), "Expected to find a range to extract");
                        const name = getUniqueName("NewType", file);
                        const edits = ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            switch (actionName2) {
                                case extractToTypeAliasAction.name:
                                    Debug.assert(!info.isJS, "Invalid actionName/JS combo");
                                    return doTypeAliasChange(changes, file, name, info);
                                case extractToTypeDefAction.name:
                                    Debug.assert(info.isJS, "Invalid actionName/JS combo");
                                    return doTypedefChange(changes, context, file, name, info);
                                case extractToInterfaceAction.name:
                                    Debug.assert(!info.isJS && !!info.typeElements, "Invalid actionName/JS combo");
                                    return doInterfaceChange(changes, file, name, info);
                                default:
                                    Debug.fail("Unexpected action name");
                            }
                        });
                        const renameFilename = file.fileName;
                        const renameLocation = getRenameLocation(edits, renameFilename, name, 
                        /*preferLastLocation*/
                        false);
                        return { edits, renameFilename, renameLocation };
                    }
                });
            }
        });
        // src/services/refactors/helpers.ts
        function isRefactorErrorInfo(info) {
            return info.error !== void 0;
        }
        function refactorKindBeginsWith(known, requested) {
            if (!requested)
                return true;
            return known.substr(0, requested.length) === requested;
        }
        var init_helpers2 = __esm({
            "src/services/refactors/helpers.ts"() {
                "use strict";
            }
        });
        // src/services/refactors/moveToNewFile.ts
        function getRangeToMove(context) {
            const { file } = context;
            const range = createTextRangeFromSpan(getRefactorContextSpan(context));
            const { statements } = file;
            const startNodeIndex = findIndex(statements, (s) => s.end > range.pos);
            if (startNodeIndex === -1)
                return void 0;
            const startStatement = statements[startNodeIndex];
            if (isNamedDeclaration(startStatement) && startStatement.name && rangeContainsRange(startStatement.name, range)) {
                return { toMove: [statements[startNodeIndex]], afterLast: statements[startNodeIndex + 1] };
            }
            if (range.pos > startStatement.getStart(file))
                return void 0;
            const afterEndNodeIndex = findIndex(statements, (s) => s.end > range.end, startNodeIndex);
            if (afterEndNodeIndex !== -1 && (afterEndNodeIndex === 0 || statements[afterEndNodeIndex].getStart(file) < range.end))
                return void 0;
            return {
                toMove: statements.slice(startNodeIndex, afterEndNodeIndex === -1 ? statements.length : afterEndNodeIndex),
                afterLast: afterEndNodeIndex === -1 ? void 0 : statements[afterEndNodeIndex]
            };
        }
        function doChange35(oldFile, program, toMove, changes, host, preferences) {
            const checker = program.getTypeChecker();
            const usage = getUsageInfo(oldFile, toMove.all, checker);
            const currentDirectory = getDirectoryPath(oldFile.fileName);
            const extension = extensionFromPath(oldFile.fileName);
            const newFilename = combinePaths(
            // new file is always placed in the same directory as the old file
            currentDirectory, 
            // ensures the filename computed below isn't already taken
            makeUniqueFilename(
            // infers a name for the new file from the symbols being moved
            inferNewFilename(usage.oldFileImportsFromNewFile, usage.movedSymbols), extension, currentDirectory, host)) + extension;
            changes.createNewFile(oldFile, newFilename, getNewStatementsAndRemoveFromOldFile(oldFile, usage, changes, toMove, program, host, newFilename, preferences));
            addNewFileToTsconfig(program, changes, oldFile.fileName, newFilename, hostGetCanonicalFileName(host));
        }
        function getStatementsToMove(context) {
            const rangeToMove = getRangeToMove(context);
            if (rangeToMove === void 0)
                return void 0;
            const all = [];
            const ranges = [];
            const { toMove, afterLast } = rangeToMove;
            getRangesWhere(toMove, isAllowedStatementToMove, (start, afterEndIndex) => {
                for (let i = start; i < afterEndIndex; i++)
                    all.push(toMove[i]);
                ranges.push({ first: toMove[start], afterLast });
            });
            return all.length === 0 ? void 0 : { all, ranges };
        }
        function isAllowedStatementToMove(statement) {
            return !isPureImport(statement) && !isPrologueDirective(statement);
        }
        function isPureImport(node) {
            switch (node.kind) {
                case 269 /* ImportDeclaration */:
                    return true;
                case 268 /* ImportEqualsDeclaration */:
                    return !hasSyntacticModifier(node, 1 /* Export */);
                case 240 /* VariableStatement */:
                    return node.declarationList.declarations.every((d) => !!d.initializer && isRequireCall(d.initializer, 
                    /*checkArgumentIsStringLiteralLike*/
                    true));
                default:
                    return false;
            }
        }
        function addNewFileToTsconfig(program, changes, oldFileName, newFileNameWithExtension, getCanonicalFileName) {
            const cfg = program.getCompilerOptions().configFile;
            if (!cfg)
                return;
            const newFileAbsolutePath = normalizePath(combinePaths(oldFileName, "..", newFileNameWithExtension));
            const newFilePath = getRelativePathFromFile(cfg.fileName, newFileAbsolutePath, getCanonicalFileName);
            const cfgObject = cfg.statements[0] && tryCast(cfg.statements[0].expression, isObjectLiteralExpression);
            const filesProp = cfgObject && find(cfgObject.properties, (prop) => isPropertyAssignment(prop) && isStringLiteral(prop.name) && prop.name.text === "files");
            if (filesProp && isArrayLiteralExpression(filesProp.initializer)) {
                changes.insertNodeInListAfter(cfg, last(filesProp.initializer.elements), factory.createStringLiteral(newFilePath), filesProp.initializer.elements);
            }
        }
        function getNewStatementsAndRemoveFromOldFile(oldFile, usage, changes, toMove, program, host, newFilename, preferences) {
            const checker = program.getTypeChecker();
            const prologueDirectives = takeWhile(oldFile.statements, isPrologueDirective);
            if (oldFile.externalModuleIndicator === void 0 && oldFile.commonJsModuleIndicator === void 0 && usage.oldImportsNeededByNewFile.size() === 0) {
                deleteMovedStatements(oldFile, toMove.ranges, changes);
                return [...prologueDirectives, ...toMove.all];
            }
            const useEsModuleSyntax = !!oldFile.externalModuleIndicator;
            const quotePreference = getQuotePreference(oldFile, preferences);
            const importsFromNewFile = createOldFileImportsFromNewFile(oldFile, usage.oldFileImportsFromNewFile, newFilename, program, host, useEsModuleSyntax, quotePreference);
            if (importsFromNewFile) {
                insertImports(changes, oldFile, importsFromNewFile, 
                /*blankLineBetween*/
                true, preferences);
            }
            deleteUnusedOldImports(oldFile, toMove.all, changes, usage.unusedImportsFromOldFile, checker);
            deleteMovedStatements(oldFile, toMove.ranges, changes);
            updateImportsInOtherFiles(changes, program, host, oldFile, usage.movedSymbols, newFilename);
            const imports = getNewFileImportsAndAddExportInOldFile(oldFile, usage.oldImportsNeededByNewFile, usage.newFileImportsFromOldFile, changes, checker, program, host, useEsModuleSyntax, quotePreference);
            const body = addExports(oldFile, toMove.all, usage.oldFileImportsFromNewFile, useEsModuleSyntax);
            if (imports.length && body.length) {
                return [
                    ...prologueDirectives,
                    ...imports,
                    4 /* NewLineTrivia */,
                    ...body
                ];
            }
            return [
                ...prologueDirectives,
                ...imports,
                ...body
            ];
        }
        function deleteMovedStatements(sourceFile, moved, changes) {
            for (const { first: first2, afterLast } of moved) {
                changes.deleteNodeRangeExcludingEnd(sourceFile, first2, afterLast);
            }
        }
        function deleteUnusedOldImports(oldFile, toMove, changes, toDelete, checker) {
            for (const statement of oldFile.statements) {
                if (contains(toMove, statement))
                    continue;
                forEachImportInStatement(statement, (i) => deleteUnusedImports(oldFile, i, changes, (name) => toDelete.has(checker.getSymbolAtLocation(name))));
            }
        }
        function updateImportsInOtherFiles(changes, program, host, oldFile, movedSymbols, newFilename) {
            const checker = program.getTypeChecker();
            for (const sourceFile of program.getSourceFiles()) {
                if (sourceFile === oldFile)
                    continue;
                for (const statement of sourceFile.statements) {
                    forEachImportInStatement(statement, (importNode) => {
                        if (checker.getSymbolAtLocation(moduleSpecifierFromImport(importNode)) !== oldFile.symbol)
                            return;
                        const shouldMove = (name) => {
                            const symbol = isBindingElement(name.parent) ? getPropertySymbolFromBindingElement(checker, name.parent) : skipAlias(checker.getSymbolAtLocation(name), checker);
                            return !!symbol && movedSymbols.has(symbol);
                        };
                        deleteUnusedImports(sourceFile, importNode, changes, shouldMove);
                        const pathToNewFileWithExtension = resolvePath(getDirectoryPath(oldFile.path), newFilename);
                        const newModuleSpecifier = getModuleSpecifier(program.getCompilerOptions(), sourceFile, sourceFile.path, pathToNewFileWithExtension, createModuleSpecifierResolutionHost(program, host));
                        const newImportDeclaration = filterImport(importNode, factory.createStringLiteral(newModuleSpecifier), shouldMove);
                        if (newImportDeclaration)
                            changes.insertNodeAfter(sourceFile, statement, newImportDeclaration);
                        const ns = getNamespaceLikeImport(importNode);
                        if (ns)
                            updateNamespaceLikeImport(changes, sourceFile, checker, movedSymbols, newModuleSpecifier, ns, importNode);
                    });
                }
            }
        }
        function getNamespaceLikeImport(node) {
            switch (node.kind) {
                case 269 /* ImportDeclaration */:
                    return node.importClause && node.importClause.namedBindings && node.importClause.namedBindings.kind === 271 /* NamespaceImport */ ? node.importClause.namedBindings.name : void 0;
                case 268 /* ImportEqualsDeclaration */:
                    return node.name;
                case 257 /* VariableDeclaration */:
                    return tryCast(node.name, isIdentifier);
                default:
                    return Debug.assertNever(node, `Unexpected node kind ${node.kind}`);
            }
        }
        function updateNamespaceLikeImport(changes, sourceFile, checker, movedSymbols, newModuleSpecifier, oldImportId, oldImportNode) {
            const preferredNewNamespaceName = ts_codefix_exports.moduleSpecifierToValidIdentifier(newModuleSpecifier, 99 /* ESNext */);
            let needUniqueName = false;
            const toChange = [];
            ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(oldImportId, checker, sourceFile, (ref) => {
                if (!isPropertyAccessExpression(ref.parent))
                    return;
                needUniqueName = needUniqueName || !!checker.resolveName(preferredNewNamespaceName, ref, 67108863 /* All */, 
                /*excludeGlobals*/
                true);
                if (movedSymbols.has(checker.getSymbolAtLocation(ref.parent.name))) {
                    toChange.push(ref);
                }
            });
            if (toChange.length) {
                const newNamespaceName = needUniqueName ? getUniqueName(preferredNewNamespaceName, sourceFile) : preferredNewNamespaceName;
                for (const ref of toChange) {
                    changes.replaceNode(sourceFile, ref, factory.createIdentifier(newNamespaceName));
                }
                changes.insertNodeAfter(sourceFile, oldImportNode, updateNamespaceLikeImportNode(oldImportNode, preferredNewNamespaceName, newModuleSpecifier));
            }
        }
        function updateNamespaceLikeImportNode(node, newNamespaceName, newModuleSpecifier) {
            const newNamespaceId = factory.createIdentifier(newNamespaceName);
            const newModuleString = factory.createStringLiteral(newModuleSpecifier);
            switch (node.kind) {
                case 269 /* ImportDeclaration */:
                    return factory.createImportDeclaration(
                    /*modifiers*/
                    void 0, factory.createImportClause(
                    /*isTypeOnly*/
                    false, 
                    /*name*/
                    void 0, factory.createNamespaceImport(newNamespaceId)), newModuleString, 
                    /*assertClause*/
                    void 0);
                case 268 /* ImportEqualsDeclaration */:
                    return factory.createImportEqualsDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*isTypeOnly*/
                    false, newNamespaceId, factory.createExternalModuleReference(newModuleString));
                case 257 /* VariableDeclaration */:
                    return factory.createVariableDeclaration(newNamespaceId, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, createRequireCall(newModuleString));
                default:
                    return Debug.assertNever(node, `Unexpected node kind ${node.kind}`);
            }
        }
        function moduleSpecifierFromImport(i) {
            return i.kind === 269 /* ImportDeclaration */ ? i.moduleSpecifier : i.kind === 268 /* ImportEqualsDeclaration */ ? i.moduleReference.expression : i.initializer.arguments[0];
        }
        function forEachImportInStatement(statement, cb) {
            if (isImportDeclaration(statement)) {
                if (isStringLiteral(statement.moduleSpecifier))
                    cb(statement);
            }
            else if (isImportEqualsDeclaration(statement)) {
                if (isExternalModuleReference(statement.moduleReference) && isStringLiteralLike(statement.moduleReference.expression)) {
                    cb(statement);
                }
            }
            else if (isVariableStatement(statement)) {
                for (const decl of statement.declarationList.declarations) {
                    if (decl.initializer && isRequireCall(decl.initializer, 
                    /*checkArgumentIsStringLiteralLike*/
                    true)) {
                        cb(decl);
                    }
                }
            }
        }
        function createOldFileImportsFromNewFile(sourceFile, newFileNeedExport, newFileNameWithExtension, program, host, useEs6Imports, quotePreference) {
            let defaultImport;
            const imports = [];
            newFileNeedExport.forEach((symbol) => {
                if (symbol.escapedName === "default" /* Default */) {
                    defaultImport = factory.createIdentifier(symbolNameNoDefault(symbol));
                }
                else {
                    imports.push(symbol.name);
                }
            });
            return makeImportOrRequire(sourceFile, defaultImport, imports, newFileNameWithExtension, program, host, useEs6Imports, quotePreference);
        }
        function makeImportOrRequire(sourceFile, defaultImport, imports, newFileNameWithExtension, program, host, useEs6Imports, quotePreference) {
            const pathToNewFile = resolvePath(getDirectoryPath(sourceFile.path), newFileNameWithExtension);
            const pathToNewFileWithCorrectExtension = getModuleSpecifier(program.getCompilerOptions(), sourceFile, sourceFile.path, pathToNewFile, createModuleSpecifierResolutionHost(program, host));
            if (useEs6Imports) {
                const specifiers = imports.map((i) => factory.createImportSpecifier(
                /*isTypeOnly*/
                false, 
                /*propertyName*/
                void 0, factory.createIdentifier(i)));
                return makeImportIfNecessary(defaultImport, specifiers, pathToNewFileWithCorrectExtension, quotePreference);
            }
            else {
                Debug.assert(!defaultImport, "No default import should exist");
                const bindingElements = imports.map((i) => factory.createBindingElement(
                /*dotDotDotToken*/
                void 0, 
                /*propertyName*/
                void 0, i));
                return bindingElements.length ? makeVariableStatement(factory.createObjectBindingPattern(bindingElements), 
                /*type*/
                void 0, createRequireCall(factory.createStringLiteral(pathToNewFileWithCorrectExtension))) : void 0;
            }
        }
        function makeVariableStatement(name, type, initializer, flags = 2 /* Const */) {
            return factory.createVariableStatement(
            /*modifiers*/
            void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(name, 
                /*exclamationToken*/
                void 0, type, initializer)], flags));
        }
        function createRequireCall(moduleSpecifier) {
            return factory.createCallExpression(factory.createIdentifier("require"), 
            /*typeArguments*/
            void 0, [moduleSpecifier]);
        }
        function addExports(sourceFile, toMove, needExport, useEs6Exports) {
            return flatMap(toMove, (statement) => {
                if (isTopLevelDeclarationStatement(statement) && !isExported(sourceFile, statement, useEs6Exports) && forEachTopLevelDeclaration(statement, (d) => {
                    var _a2;
                    return needExport.has(Debug.checkDefined((_a2 = tryCast(d, canHaveSymbol)) == null ? void 0 : _a2.symbol));
                })) {
                    const exports = addExport(statement, useEs6Exports);
                    if (exports)
                        return exports;
                }
                return statement;
            });
        }
        function deleteUnusedImports(sourceFile, importDecl, changes, isUnused) {
            switch (importDecl.kind) {
                case 269 /* ImportDeclaration */:
                    deleteUnusedImportsInDeclaration(sourceFile, importDecl, changes, isUnused);
                    break;
                case 268 /* ImportEqualsDeclaration */:
                    if (isUnused(importDecl.name)) {
                        changes.delete(sourceFile, importDecl);
                    }
                    break;
                case 257 /* VariableDeclaration */:
                    deleteUnusedImportsInVariableDeclaration(sourceFile, importDecl, changes, isUnused);
                    break;
                default:
                    Debug.assertNever(importDecl, `Unexpected import decl kind ${importDecl.kind}`);
            }
        }
        function deleteUnusedImportsInDeclaration(sourceFile, importDecl, changes, isUnused) {
            if (!importDecl.importClause)
                return;
            const { name, namedBindings } = importDecl.importClause;
            const defaultUnused = !name || isUnused(name);
            const namedBindingsUnused = !namedBindings || (namedBindings.kind === 271 /* NamespaceImport */ ? isUnused(namedBindings.name) : namedBindings.elements.length !== 0 && namedBindings.elements.every((e) => isUnused(e.name)));
            if (defaultUnused && namedBindingsUnused) {
                changes.delete(sourceFile, importDecl);
            }
            else {
                if (name && defaultUnused) {
                    changes.delete(sourceFile, name);
                }
                if (namedBindings) {
                    if (namedBindingsUnused) {
                        changes.replaceNode(sourceFile, importDecl.importClause, factory.updateImportClause(importDecl.importClause, importDecl.importClause.isTypeOnly, name, 
                        /*namedBindings*/
                        void 0));
                    }
                    else if (namedBindings.kind === 272 /* NamedImports */) {
                        for (const element of namedBindings.elements) {
                            if (isUnused(element.name))
                                changes.delete(sourceFile, element);
                        }
                    }
                }
            }
        }
        function deleteUnusedImportsInVariableDeclaration(sourceFile, varDecl, changes, isUnused) {
            const { name } = varDecl;
            switch (name.kind) {
                case 79 /* Identifier */:
                    if (isUnused(name)) {
                        if (varDecl.initializer && isRequireCall(varDecl.initializer, 
                        /*requireStringLiteralLikeArgument*/
                        true)) {
                            changes.delete(sourceFile, isVariableDeclarationList(varDecl.parent) && length(varDecl.parent.declarations) === 1 ? varDecl.parent.parent : varDecl);
                        }
                        else {
                            changes.delete(sourceFile, name);
                        }
                    }
                    break;
                case 204 /* ArrayBindingPattern */:
                    break;
                case 203 /* ObjectBindingPattern */:
                    if (name.elements.every((e) => isIdentifier(e.name) && isUnused(e.name))) {
                        changes.delete(sourceFile, isVariableDeclarationList(varDecl.parent) && varDecl.parent.declarations.length === 1 ? varDecl.parent.parent : varDecl);
                    }
                    else {
                        for (const element of name.elements) {
                            if (isIdentifier(element.name) && isUnused(element.name)) {
                                changes.delete(sourceFile, element.name);
                            }
                        }
                    }
                    break;
            }
        }
        function getNewFileImportsAndAddExportInOldFile(oldFile, importsToCopy, newFileImportsFromOldFile, changes, checker, program, host, useEsModuleSyntax, quotePreference) {
            const copiedOldImports = [];
            for (const oldStatement of oldFile.statements) {
                forEachImportInStatement(oldStatement, (i) => {
                    append(copiedOldImports, filterImport(i, moduleSpecifierFromImport(i), (name) => importsToCopy.has(checker.getSymbolAtLocation(name))));
                });
            }
            let oldFileDefault;
            const oldFileNamedImports = [];
            const markSeenTop = nodeSeenTracker();
            newFileImportsFromOldFile.forEach((symbol) => {
                if (!symbol.declarations) {
                    return;
                }
                for (const decl of symbol.declarations) {
                    if (!isTopLevelDeclaration(decl))
                        continue;
                    const name = nameOfTopLevelDeclaration(decl);
                    if (!name)
                        continue;
                    const top = getTopLevelDeclarationStatement(decl);
                    if (markSeenTop(top)) {
                        addExportToChanges(oldFile, top, name, changes, useEsModuleSyntax);
                    }
                    if (hasSyntacticModifier(decl, 1024 /* Default */)) {
                        oldFileDefault = name;
                    }
                    else {
                        oldFileNamedImports.push(name.text);
                    }
                }
            });
            append(copiedOldImports, makeImportOrRequire(oldFile, oldFileDefault, oldFileNamedImports, getBaseFileName(oldFile.fileName), program, host, useEsModuleSyntax, quotePreference));
            return copiedOldImports;
        }
        function makeUniqueFilename(proposedFilename, extension, inDirectory, host) {
            let newFilename = proposedFilename;
            for (let i = 1;; i++) {
                const name = combinePaths(inDirectory, newFilename + extension);
                if (!host.fileExists(name))
                    return newFilename;
                newFilename = `${proposedFilename}.${i}`;
            }
        }
        function inferNewFilename(importsFromNewFile, movedSymbols) {
            return importsFromNewFile.forEachEntry(symbolNameNoDefault) || movedSymbols.forEachEntry(symbolNameNoDefault) || "newFile";
        }
        function getUsageInfo(oldFile, toMove, checker) {
            const movedSymbols = new SymbolSet();
            const oldImportsNeededByNewFile = new SymbolSet();
            const newFileImportsFromOldFile = new SymbolSet();
            const containsJsx = find(toMove, (statement) => !!(statement.transformFlags & 2 /* ContainsJsx */));
            const jsxNamespaceSymbol = getJsxNamespaceSymbol(containsJsx);
            if (jsxNamespaceSymbol) {
                oldImportsNeededByNewFile.add(jsxNamespaceSymbol);
            }
            for (const statement of toMove) {
                forEachTopLevelDeclaration(statement, (decl) => {
                    movedSymbols.add(Debug.checkDefined(isExpressionStatement(decl) ? checker.getSymbolAtLocation(decl.expression.left) : decl.symbol, "Need a symbol here"));
                });
            }
            for (const statement of toMove) {
                forEachReference(statement, checker, (symbol) => {
                    if (!symbol.declarations)
                        return;
                    for (const decl of symbol.declarations) {
                        if (isInImport(decl)) {
                            oldImportsNeededByNewFile.add(symbol);
                        }
                        else if (isTopLevelDeclaration(decl) && sourceFileOfTopLevelDeclaration(decl) === oldFile && !movedSymbols.has(symbol)) {
                            newFileImportsFromOldFile.add(symbol);
                        }
                    }
                });
            }
            const unusedImportsFromOldFile = oldImportsNeededByNewFile.clone();
            const oldFileImportsFromNewFile = new SymbolSet();
            for (const statement of oldFile.statements) {
                if (contains(toMove, statement))
                    continue;
                if (jsxNamespaceSymbol && !!(statement.transformFlags & 2 /* ContainsJsx */)) {
                    unusedImportsFromOldFile.delete(jsxNamespaceSymbol);
                }
                forEachReference(statement, checker, (symbol) => {
                    if (movedSymbols.has(symbol))
                        oldFileImportsFromNewFile.add(symbol);
                    unusedImportsFromOldFile.delete(symbol);
                });
            }
            return { movedSymbols, newFileImportsFromOldFile, oldFileImportsFromNewFile, oldImportsNeededByNewFile, unusedImportsFromOldFile };
            function getJsxNamespaceSymbol(containsJsx2) {
                if (containsJsx2 === void 0) {
                    return void 0;
                }
                const jsxNamespace = checker.getJsxNamespace(containsJsx2);
                const jsxNamespaceSymbol2 = checker.resolveName(jsxNamespace, containsJsx2, 1920 /* Namespace */, 
                /*excludeGlobals*/
                true);
                return !!jsxNamespaceSymbol2 && some(jsxNamespaceSymbol2.declarations, isInImport) ? jsxNamespaceSymbol2 : void 0;
            }
        }
        function isInImport(decl) {
            switch (decl.kind) {
                case 268 /* ImportEqualsDeclaration */:
                case 273 /* ImportSpecifier */:
                case 270 /* ImportClause */:
                case 271 /* NamespaceImport */:
                    return true;
                case 257 /* VariableDeclaration */:
                    return isVariableDeclarationInImport(decl);
                case 205 /* BindingElement */:
                    return isVariableDeclaration(decl.parent.parent) && isVariableDeclarationInImport(decl.parent.parent);
                default:
                    return false;
            }
        }
        function isVariableDeclarationInImport(decl) {
            return isSourceFile(decl.parent.parent.parent) && !!decl.initializer && isRequireCall(decl.initializer, 
            /*checkArgumentIsStringLiteralLike*/
            true);
        }
        function filterImport(i, moduleSpecifier, keep) {
            switch (i.kind) {
                case 269 /* ImportDeclaration */: {
                    const clause = i.importClause;
                    if (!clause)
                        return void 0;
                    const defaultImport = clause.name && keep(clause.name) ? clause.name : void 0;
                    const namedBindings = clause.namedBindings && filterNamedBindings(clause.namedBindings, keep);
                    return defaultImport || namedBindings ? factory.createImportDeclaration(
                    /*modifiers*/
                    void 0, factory.createImportClause(clause.isTypeOnly, defaultImport, namedBindings), moduleSpecifier, 
                    /*assertClause*/
                    void 0) : void 0;
                }
                case 268 /* ImportEqualsDeclaration */:
                    return keep(i.name) ? i : void 0;
                case 257 /* VariableDeclaration */: {
                    const name = filterBindingName(i.name, keep);
                    return name ? makeVariableStatement(name, i.type, createRequireCall(moduleSpecifier), i.parent.flags) : void 0;
                }
                default:
                    return Debug.assertNever(i, `Unexpected import kind ${i.kind}`);
            }
        }
        function filterNamedBindings(namedBindings, keep) {
            if (namedBindings.kind === 271 /* NamespaceImport */) {
                return keep(namedBindings.name) ? namedBindings : void 0;
            }
            else {
                const newElements = namedBindings.elements.filter((e) => keep(e.name));
                return newElements.length ? factory.createNamedImports(newElements) : void 0;
            }
        }
        function filterBindingName(name, keep) {
            switch (name.kind) {
                case 79 /* Identifier */:
                    return keep(name) ? name : void 0;
                case 204 /* ArrayBindingPattern */:
                    return name;
                case 203 /* ObjectBindingPattern */: {
                    const newElements = name.elements.filter((prop) => prop.propertyName || !isIdentifier(prop.name) || keep(prop.name));
                    return newElements.length ? factory.createObjectBindingPattern(newElements) : void 0;
                }
            }
        }
        function forEachReference(node, checker, onReference) {
            node.forEachChild(function cb(node2) {
                if (isIdentifier(node2) && !isDeclarationName(node2)) {
                    const sym = checker.getSymbolAtLocation(node2);
                    if (sym)
                        onReference(sym);
                }
                else {
                    node2.forEachChild(cb);
                }
            });
        }
        function isTopLevelDeclaration(node) {
            return isNonVariableTopLevelDeclaration(node) && isSourceFile(node.parent) || isVariableDeclaration(node) && isSourceFile(node.parent.parent.parent);
        }
        function sourceFileOfTopLevelDeclaration(node) {
            return isVariableDeclaration(node) ? node.parent.parent.parent : node.parent;
        }
        function isTopLevelDeclarationStatement(node) {
            Debug.assert(isSourceFile(node.parent), "Node parent should be a SourceFile");
            return isNonVariableTopLevelDeclaration(node) || isVariableStatement(node);
        }
        function isNonVariableTopLevelDeclaration(node) {
            switch (node.kind) {
                case 259 /* FunctionDeclaration */:
                case 260 /* ClassDeclaration */:
                case 264 /* ModuleDeclaration */:
                case 263 /* EnumDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 268 /* ImportEqualsDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function forEachTopLevelDeclaration(statement, cb) {
            switch (statement.kind) {
                case 259 /* FunctionDeclaration */:
                case 260 /* ClassDeclaration */:
                case 264 /* ModuleDeclaration */:
                case 263 /* EnumDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 268 /* ImportEqualsDeclaration */:
                    return cb(statement);
                case 240 /* VariableStatement */:
                    return firstDefined(statement.declarationList.declarations, (decl) => forEachTopLevelDeclarationInBindingName(decl.name, cb));
                case 241 /* ExpressionStatement */: {
                    const { expression } = statement;
                    return isBinaryExpression(expression) && getAssignmentDeclarationKind(expression) === 1 /* ExportsProperty */ ? cb(statement) : void 0;
                }
            }
        }
        function forEachTopLevelDeclarationInBindingName(name, cb) {
            switch (name.kind) {
                case 79 /* Identifier */:
                    return cb(cast(name.parent, (x) => isVariableDeclaration(x) || isBindingElement(x)));
                case 204 /* ArrayBindingPattern */:
                case 203 /* ObjectBindingPattern */:
                    return firstDefined(name.elements, (em) => isOmittedExpression(em) ? void 0 : forEachTopLevelDeclarationInBindingName(em.name, cb));
                default:
                    return Debug.assertNever(name, `Unexpected name kind ${name.kind}`);
            }
        }
        function nameOfTopLevelDeclaration(d) {
            return isExpressionStatement(d) ? tryCast(d.expression.left.name, isIdentifier) : tryCast(d.name, isIdentifier);
        }
        function getTopLevelDeclarationStatement(d) {
            switch (d.kind) {
                case 257 /* VariableDeclaration */:
                    return d.parent.parent;
                case 205 /* BindingElement */:
                    return getTopLevelDeclarationStatement(cast(d.parent.parent, (p) => isVariableDeclaration(p) || isBindingElement(p)));
                default:
                    return d;
            }
        }
        function addExportToChanges(sourceFile, decl, name, changes, useEs6Exports) {
            if (isExported(sourceFile, decl, useEs6Exports, name))
                return;
            if (useEs6Exports) {
                if (!isExpressionStatement(decl))
                    changes.insertExportModifier(sourceFile, decl);
            }
            else {
                const names = getNamesToExportInCommonJS(decl);
                if (names.length !== 0)
                    changes.insertNodesAfter(sourceFile, decl, names.map(createExportAssignment));
            }
        }
        function isExported(sourceFile, decl, useEs6Exports, name) {
            var _a2;
            if (useEs6Exports) {
                return !isExpressionStatement(decl) && hasSyntacticModifier(decl, 1 /* Export */) || !!(name && ((_a2 = sourceFile.symbol.exports) == null ? void 0 : _a2.has(name.escapedText)));
            }
            return !!sourceFile.symbol && !!sourceFile.symbol.exports && getNamesToExportInCommonJS(decl).some((name2) => sourceFile.symbol.exports.has(escapeLeadingUnderscores(name2)));
        }
        function addExport(decl, useEs6Exports) {
            return useEs6Exports ? [addEs6Export(decl)] : addCommonjsExport(decl);
        }
        function addEs6Export(d) {
            const modifiers = canHaveModifiers(d) ? concatenate([factory.createModifier(93 /* ExportKeyword */)], getModifiers(d)) : void 0;
            switch (d.kind) {
                case 259 /* FunctionDeclaration */:
                    return factory.updateFunctionDeclaration(d, modifiers, d.asteriskToken, d.name, d.typeParameters, d.parameters, d.type, d.body);
                case 260 /* ClassDeclaration */:
                    const decorators = canHaveDecorators(d) ? getDecorators(d) : void 0;
                    return factory.updateClassDeclaration(d, concatenate(decorators, modifiers), d.name, d.typeParameters, d.heritageClauses, d.members);
                case 240 /* VariableStatement */:
                    return factory.updateVariableStatement(d, modifiers, d.declarationList);
                case 264 /* ModuleDeclaration */:
                    return factory.updateModuleDeclaration(d, modifiers, d.name, d.body);
                case 263 /* EnumDeclaration */:
                    return factory.updateEnumDeclaration(d, modifiers, d.name, d.members);
                case 262 /* TypeAliasDeclaration */:
                    return factory.updateTypeAliasDeclaration(d, modifiers, d.name, d.typeParameters, d.type);
                case 261 /* InterfaceDeclaration */:
                    return factory.updateInterfaceDeclaration(d, modifiers, d.name, d.typeParameters, d.heritageClauses, d.members);
                case 268 /* ImportEqualsDeclaration */:
                    return factory.updateImportEqualsDeclaration(d, modifiers, d.isTypeOnly, d.name, d.moduleReference);
                case 241 /* ExpressionStatement */:
                    return Debug.fail();
                default:
                    return Debug.assertNever(d, `Unexpected declaration kind ${d.kind}`);
            }
        }
        function addCommonjsExport(decl) {
            return [decl, ...getNamesToExportInCommonJS(decl).map(createExportAssignment)];
        }
        function getNamesToExportInCommonJS(decl) {
            switch (decl.kind) {
                case 259 /* FunctionDeclaration */:
                case 260 /* ClassDeclaration */:
                    return [decl.name.text];
                case 240 /* VariableStatement */:
                    return mapDefined(decl.declarationList.declarations, (d) => isIdentifier(d.name) ? d.name.text : void 0);
                case 264 /* ModuleDeclaration */:
                case 263 /* EnumDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                case 261 /* InterfaceDeclaration */:
                case 268 /* ImportEqualsDeclaration */:
                    return emptyArray;
                case 241 /* ExpressionStatement */:
                    return Debug.fail("Can't export an ExpressionStatement");
                default:
                    return Debug.assertNever(decl, `Unexpected decl kind ${decl.kind}`);
            }
        }
        function createExportAssignment(name) {
            return factory.createExpressionStatement(factory.createBinaryExpression(factory.createPropertyAccessExpression(factory.createIdentifier("exports"), factory.createIdentifier(name)), 63 /* EqualsToken */, factory.createIdentifier(name)));
        }
        var refactorName4, description, moveToNewFileAction, SymbolSet;
        var init_moveToNewFile = __esm({
            "src/services/refactors/moveToNewFile.ts"() {
                "use strict";
                init_moduleSpecifiers();
                init_ts4();
                init_ts_refactor();
                refactorName4 = "Move to a new file";
                description = getLocaleSpecificMessage(Diagnostics.Move_to_a_new_file);
                moveToNewFileAction = {
                    name: refactorName4,
                    description,
                    kind: "refactor.move.newFile"
                };
                registerRefactor(refactorName4, {
                    kinds: [moveToNewFileAction.kind],
                    getAvailableActions: function getRefactorActionsToMoveToNewFile(context) {
                        const statements = getStatementsToMove(context);
                        if (context.preferences.allowTextChangesInNewFiles && statements) {
                            return [{ name: refactorName4, description, actions: [moveToNewFileAction] }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return [{
                                    name: refactorName4,
                                    description,
                                    actions: [{ ...moveToNewFileAction, notApplicableReason: getLocaleSpecificMessage(Diagnostics.Selection_is_not_a_valid_statement_or_statements) }]
                                }];
                        }
                        return emptyArray;
                    },
                    getEditsForAction: function getRefactorEditsToMoveToNewFile(context, actionName2) {
                        Debug.assert(actionName2 === refactorName4, "Wrong refactor invoked");
                        const statements = Debug.checkDefined(getStatementsToMove(context));
                        const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange35(context.file, context.program, statements, t, context.host, context.preferences));
                        return { edits, renameFilename: void 0, renameLocation: void 0 };
                    }
                });
                SymbolSet = class {
                    constructor() {
                        this.map = /* @__PURE__ */ new Map();
                    }
                    add(symbol) {
                        this.map.set(String(getSymbolId(symbol)), symbol);
                    }
                    has(symbol) {
                        return this.map.has(String(getSymbolId(symbol)));
                    }
                    delete(symbol) {
                        this.map.delete(String(getSymbolId(symbol)));
                    }
                    forEach(cb) {
                        this.map.forEach(cb);
                    }
                    forEachEntry(cb) {
                        return forEachEntry(this.map, cb);
                    }
                    clone() {
                        const clone2 = new SymbolSet();
                        copyEntries(this.map, clone2.map);
                        return clone2;
                    }
                    size() {
                        return this.map.size;
                    }
                };
            }
        });
        // src/services/refactors/convertOverloadListToSingleSignature.ts
        function getRefactorActionsToConvertOverloadsToOneSignature(context) {
            const { file, startPosition, program } = context;
            const info = getConvertableOverloadListAtPosition(file, startPosition, program);
            if (!info)
                return emptyArray;
            return [{
                    name: refactorName5,
                    description: refactorDescription,
                    actions: [functionOverloadAction]
                }];
        }
        function getRefactorEditsToConvertOverloadsToOneSignature(context) {
            const { file, startPosition, program } = context;
            const signatureDecls = getConvertableOverloadListAtPosition(file, startPosition, program);
            if (!signatureDecls)
                return void 0;
            const checker = program.getTypeChecker();
            const lastDeclaration = signatureDecls[signatureDecls.length - 1];
            let updated = lastDeclaration;
            switch (lastDeclaration.kind) {
                case 170 /* MethodSignature */: {
                    updated = factory.updateMethodSignature(lastDeclaration, lastDeclaration.modifiers, lastDeclaration.name, lastDeclaration.questionToken, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type);
                    break;
                }
                case 171 /* MethodDeclaration */: {
                    updated = factory.updateMethodDeclaration(lastDeclaration, lastDeclaration.modifiers, lastDeclaration.asteriskToken, lastDeclaration.name, lastDeclaration.questionToken, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type, lastDeclaration.body);
                    break;
                }
                case 176 /* CallSignature */: {
                    updated = factory.updateCallSignature(lastDeclaration, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type);
                    break;
                }
                case 173 /* Constructor */: {
                    updated = factory.updateConstructorDeclaration(lastDeclaration, lastDeclaration.modifiers, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.body);
                    break;
                }
                case 177 /* ConstructSignature */: {
                    updated = factory.updateConstructSignature(lastDeclaration, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type);
                    break;
                }
                case 259 /* FunctionDeclaration */: {
                    updated = factory.updateFunctionDeclaration(lastDeclaration, lastDeclaration.modifiers, lastDeclaration.asteriskToken, lastDeclaration.name, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type, lastDeclaration.body);
                    break;
                }
                default:
                    return Debug.failBadSyntaxKind(lastDeclaration, "Unhandled signature kind in overload list conversion refactoring");
            }
            if (updated === lastDeclaration) {
                return;
            }
            const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                t.replaceNodeRange(file, signatureDecls[0], signatureDecls[signatureDecls.length - 1], updated);
            });
            return { renameFilename: void 0, renameLocation: void 0, edits };
            function getNewParametersForCombinedSignature(signatureDeclarations) {
                const lastSig = signatureDeclarations[signatureDeclarations.length - 1];
                if (isFunctionLikeDeclaration(lastSig) && lastSig.body) {
                    signatureDeclarations = signatureDeclarations.slice(0, signatureDeclarations.length - 1);
                }
                return factory.createNodeArray([
                    factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, factory.createToken(25 /* DotDotDotToken */), "args", 
                    /*questionToken*/
                    void 0, factory.createUnionTypeNode(map(signatureDeclarations, convertSignatureParametersToTuple)))
                ]);
            }
            function convertSignatureParametersToTuple(decl) {
                const members = map(decl.parameters, convertParameterToNamedTupleMember);
                return setEmitFlags(factory.createTupleTypeNode(members), some(members, (m) => !!length(getSyntheticLeadingComments(m))) ? 0 /* None */ : 1 /* SingleLine */);
            }
            function convertParameterToNamedTupleMember(p) {
                Debug.assert(isIdentifier(p.name));
                const result = setTextRange(factory.createNamedTupleMember(p.dotDotDotToken, p.name, p.questionToken, p.type || factory.createKeywordTypeNode(131 /* AnyKeyword */)), p);
                const parameterDocComment = p.symbol && p.symbol.getDocumentationComment(checker);
                if (parameterDocComment) {
                    const newComment = displayPartsToString(parameterDocComment);
                    if (newComment.length) {
                        setSyntheticLeadingComments(result, [{
                                text: `*
${newComment.split("\n").map((c) => ` * ${c}`).join("\n")}
 `,
                                kind: 3 /* MultiLineCommentTrivia */,
                                pos: -1,
                                end: -1,
                                hasTrailingNewLine: true,
                                hasLeadingNewline: true
                            }]);
                    }
                }
                return result;
            }
        }
        function isConvertableSignatureDeclaration(d) {
            switch (d.kind) {
                case 170 /* MethodSignature */:
                case 171 /* MethodDeclaration */:
                case 176 /* CallSignature */:
                case 173 /* Constructor */:
                case 177 /* ConstructSignature */:
                case 259 /* FunctionDeclaration */:
                    return true;
            }
            return false;
        }
        function getConvertableOverloadListAtPosition(file, startPosition, program) {
            const node = getTokenAtPosition(file, startPosition);
            const containingDecl = findAncestor(node, isConvertableSignatureDeclaration);
            if (!containingDecl) {
                return;
            }
            if (isFunctionLikeDeclaration(containingDecl) && containingDecl.body && rangeContainsPosition(containingDecl.body, startPosition)) {
                return;
            }
            const checker = program.getTypeChecker();
            const signatureSymbol = containingDecl.symbol;
            if (!signatureSymbol) {
                return;
            }
            const decls = signatureSymbol.declarations;
            if (length(decls) <= 1) {
                return;
            }
            if (!every(decls, (d) => getSourceFileOfNode(d) === file)) {
                return;
            }
            if (!isConvertableSignatureDeclaration(decls[0])) {
                return;
            }
            const kindOne = decls[0].kind;
            if (!every(decls, (d) => d.kind === kindOne)) {
                return;
            }
            const signatureDecls = decls;
            if (some(signatureDecls, (d) => !!d.typeParameters || some(d.parameters, (p) => !!p.modifiers || !isIdentifier(p.name)))) {
                return;
            }
            const signatures = mapDefined(signatureDecls, (d) => checker.getSignatureFromDeclaration(d));
            if (length(signatures) !== length(decls)) {
                return;
            }
            const returnOne = checker.getReturnTypeOfSignature(signatures[0]);
            if (!every(signatures, (s) => checker.getReturnTypeOfSignature(s) === returnOne)) {
                return;
            }
            return signatureDecls;
        }
        var refactorName5, refactorDescription, functionOverloadAction;
        var init_convertOverloadListToSingleSignature = __esm({
            "src/services/refactors/convertOverloadListToSingleSignature.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName5 = "Convert overload list to single signature";
                refactorDescription = Diagnostics.Convert_overload_list_to_single_signature.message;
                functionOverloadAction = {
                    name: refactorName5,
                    description: refactorDescription,
                    kind: "refactor.rewrite.function.overloadList"
                };
                registerRefactor(refactorName5, {
                    kinds: [functionOverloadAction.kind],
                    getEditsForAction: getRefactorEditsToConvertOverloadsToOneSignature,
                    getAvailableActions: getRefactorActionsToConvertOverloadsToOneSignature
                });
            }
        });
        // src/services/refactors/addOrRemoveBracesToArrowFunction.ts
        function getRefactorActionsToRemoveFunctionBraces(context) {
            const { file, startPosition, triggerReason } = context;
            const info = getConvertibleArrowFunctionAtPosition(file, startPosition, triggerReason === "invoked");
            if (!info)
                return emptyArray;
            if (!isRefactorErrorInfo(info)) {
                return [{
                        name: refactorName6,
                        description: refactorDescription2,
                        actions: [
                            info.addBraces ? addBracesAction : removeBracesAction
                        ]
                    }];
            }
            if (context.preferences.provideRefactorNotApplicableReason) {
                return [{
                        name: refactorName6,
                        description: refactorDescription2,
                        actions: [
                            { ...addBracesAction, notApplicableReason: info.error },
                            { ...removeBracesAction, notApplicableReason: info.error }
                        ]
                    }];
            }
            return emptyArray;
        }
        function getRefactorEditsToRemoveFunctionBraces(context, actionName2) {
            const { file, startPosition } = context;
            const info = getConvertibleArrowFunctionAtPosition(file, startPosition);
            Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
            const { expression, returnStatement, func } = info;
            let body;
            if (actionName2 === addBracesAction.name) {
                const returnStatement2 = factory.createReturnStatement(expression);
                body = factory.createBlock([returnStatement2], 
                /* multiLine */
                true);
                copyLeadingComments(expression, returnStatement2, file, 3 /* MultiLineCommentTrivia */, 
                /* hasTrailingNewLine */
                true);
            }
            else if (actionName2 === removeBracesAction.name && returnStatement) {
                const actualExpression = expression || factory.createVoidZero();
                body = needsParentheses(actualExpression) ? factory.createParenthesizedExpression(actualExpression) : actualExpression;
                copyTrailingAsLeadingComments(returnStatement, body, file, 3 /* MultiLineCommentTrivia */, 
                /* hasTrailingNewLine */
                false);
                copyLeadingComments(returnStatement, body, file, 3 /* MultiLineCommentTrivia */, 
                /* hasTrailingNewLine */
                false);
                copyTrailingComments(returnStatement, body, file, 3 /* MultiLineCommentTrivia */, 
                /* hasTrailingNewLine */
                false);
            }
            else {
                Debug.fail("invalid action");
            }
            const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                t.replaceNode(file, func.body, body);
            });
            return { renameFilename: void 0, renameLocation: void 0, edits };
        }
        function getConvertibleArrowFunctionAtPosition(file, startPosition, considerFunctionBodies = true, kind) {
            const node = getTokenAtPosition(file, startPosition);
            const func = getContainingFunction(node);
            if (!func) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Could_not_find_a_containing_arrow_function)
                };
            }
            if (!isArrowFunction(func)) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Containing_function_is_not_an_arrow_function)
                };
            }
            if (!rangeContainsRange(func, node) || rangeContainsRange(func.body, node) && !considerFunctionBodies) {
                return void 0;
            }
            if (refactorKindBeginsWith(addBracesAction.kind, kind) && isExpression(func.body)) {
                return { func, addBraces: true, expression: func.body };
            }
            else if (refactorKindBeginsWith(removeBracesAction.kind, kind) && isBlock(func.body) && func.body.statements.length === 1) {
                const firstStatement = first(func.body.statements);
                if (isReturnStatement(firstStatement)) {
                    return { func, addBraces: false, expression: firstStatement.expression, returnStatement: firstStatement };
                }
            }
            return void 0;
        }
        var refactorName6, refactorDescription2, addBracesAction, removeBracesAction;
        var init_addOrRemoveBracesToArrowFunction = __esm({
            "src/services/refactors/addOrRemoveBracesToArrowFunction.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName6 = "Add or remove braces in an arrow function";
                refactorDescription2 = Diagnostics.Add_or_remove_braces_in_an_arrow_function.message;
                addBracesAction = {
                    name: "Add braces to arrow function",
                    description: Diagnostics.Add_braces_to_arrow_function.message,
                    kind: "refactor.rewrite.arrow.braces.add"
                };
                removeBracesAction = {
                    name: "Remove braces from arrow function",
                    description: Diagnostics.Remove_braces_from_arrow_function.message,
                    kind: "refactor.rewrite.arrow.braces.remove"
                };
                registerRefactor(refactorName6, {
                    kinds: [removeBracesAction.kind],
                    getEditsForAction: getRefactorEditsToRemoveFunctionBraces,
                    getAvailableActions: getRefactorActionsToRemoveFunctionBraces
                });
            }
        });
        // src/services/_namespaces/ts.refactor.addOrRemoveBracesToArrowFunction.ts
        var ts_refactor_addOrRemoveBracesToArrowFunction_exports = {};
        var init_ts_refactor_addOrRemoveBracesToArrowFunction = __esm({
            "src/services/_namespaces/ts.refactor.addOrRemoveBracesToArrowFunction.ts"() {
                "use strict";
                init_convertOverloadListToSingleSignature();
                init_addOrRemoveBracesToArrowFunction();
            }
        });
        // src/services/refactors/convertArrowFunctionOrFunctionExpression.ts
        function getRefactorActionsToConvertFunctionExpressions(context) {
            const { file, startPosition, program, kind } = context;
            const info = getFunctionInfo(file, startPosition, program);
            if (!info)
                return emptyArray;
            const { selectedVariableDeclaration, func } = info;
            const possibleActions = [];
            const errors = [];
            if (refactorKindBeginsWith(toNamedFunctionAction.kind, kind)) {
                const error = selectedVariableDeclaration || isArrowFunction(func) && isVariableDeclaration(func.parent) ? void 0 : getLocaleSpecificMessage(Diagnostics.Could_not_convert_to_named_function);
                if (error) {
                    errors.push({ ...toNamedFunctionAction, notApplicableReason: error });
                }
                else {
                    possibleActions.push(toNamedFunctionAction);
                }
            }
            if (refactorKindBeginsWith(toAnonymousFunctionAction.kind, kind)) {
                const error = !selectedVariableDeclaration && isArrowFunction(func) ? void 0 : getLocaleSpecificMessage(Diagnostics.Could_not_convert_to_anonymous_function);
                if (error) {
                    errors.push({ ...toAnonymousFunctionAction, notApplicableReason: error });
                }
                else {
                    possibleActions.push(toAnonymousFunctionAction);
                }
            }
            if (refactorKindBeginsWith(toArrowFunctionAction.kind, kind)) {
                const error = isFunctionExpression(func) ? void 0 : getLocaleSpecificMessage(Diagnostics.Could_not_convert_to_arrow_function);
                if (error) {
                    errors.push({ ...toArrowFunctionAction, notApplicableReason: error });
                }
                else {
                    possibleActions.push(toArrowFunctionAction);
                }
            }
            return [{
                    name: refactorName7,
                    description: refactorDescription3,
                    actions: possibleActions.length === 0 && context.preferences.provideRefactorNotApplicableReason ? errors : possibleActions
                }];
        }
        function getRefactorEditsToConvertFunctionExpressions(context, actionName2) {
            const { file, startPosition, program } = context;
            const info = getFunctionInfo(file, startPosition, program);
            if (!info)
                return void 0;
            const { func } = info;
            const edits = [];
            switch (actionName2) {
                case toAnonymousFunctionAction.name:
                    edits.push(...getEditInfoForConvertToAnonymousFunction(context, func));
                    break;
                case toNamedFunctionAction.name:
                    const variableInfo = getVariableInfo(func);
                    if (!variableInfo)
                        return void 0;
                    edits.push(...getEditInfoForConvertToNamedFunction(context, func, variableInfo));
                    break;
                case toArrowFunctionAction.name:
                    if (!isFunctionExpression(func))
                        return void 0;
                    edits.push(...getEditInfoForConvertToArrowFunction(context, func));
                    break;
                default:
                    return Debug.fail("invalid action");
            }
            return { renameFilename: void 0, renameLocation: void 0, edits };
        }
        function containingThis(node) {
            let containsThis = false;
            node.forEachChild(function checkThis(child) {
                if (isThis(child)) {
                    containsThis = true;
                    return;
                }
                if (!isClassLike(child) && !isFunctionDeclaration(child) && !isFunctionExpression(child)) {
                    forEachChild(child, checkThis);
                }
            });
            return containsThis;
        }
        function getFunctionInfo(file, startPosition, program) {
            const token = getTokenAtPosition(file, startPosition);
            const typeChecker = program.getTypeChecker();
            const func = tryGetFunctionFromVariableDeclaration(file, typeChecker, token.parent);
            if (func && !containingThis(func.body) && !typeChecker.containsArgumentsReference(func)) {
                return { selectedVariableDeclaration: true, func };
            }
            const maybeFunc = getContainingFunction(token);
            if (maybeFunc && (isFunctionExpression(maybeFunc) || isArrowFunction(maybeFunc)) && !rangeContainsRange(maybeFunc.body, token) && !containingThis(maybeFunc.body) && !typeChecker.containsArgumentsReference(maybeFunc)) {
                if (isFunctionExpression(maybeFunc) && isFunctionReferencedInFile(file, typeChecker, maybeFunc))
                    return void 0;
                return { selectedVariableDeclaration: false, func: maybeFunc };
            }
            return void 0;
        }
        function isSingleVariableDeclaration(parent2) {
            return isVariableDeclaration(parent2) || isVariableDeclarationList(parent2) && parent2.declarations.length === 1;
        }
        function tryGetFunctionFromVariableDeclaration(sourceFile, typeChecker, parent2) {
            if (!isSingleVariableDeclaration(parent2)) {
                return void 0;
            }
            const variableDeclaration = isVariableDeclaration(parent2) ? parent2 : first(parent2.declarations);
            const initializer = variableDeclaration.initializer;
            if (initializer && (isArrowFunction(initializer) || isFunctionExpression(initializer) && !isFunctionReferencedInFile(sourceFile, typeChecker, initializer))) {
                return initializer;
            }
            return void 0;
        }
        function convertToBlock(body) {
            if (isExpression(body)) {
                const returnStatement = factory.createReturnStatement(body);
                const file = body.getSourceFile();
                setTextRange(returnStatement, body);
                suppressLeadingAndTrailingTrivia(returnStatement);
                copyTrailingAsLeadingComments(body, returnStatement, file, 
                /* commentKind */
                void 0, 
                /* hasTrailingNewLine */
                true);
                return factory.createBlock([returnStatement], 
                /* multiLine */
                true);
            }
            else {
                return body;
            }
        }
        function getVariableInfo(func) {
            const variableDeclaration = func.parent;
            if (!isVariableDeclaration(variableDeclaration) || !isVariableDeclarationInVariableStatement(variableDeclaration))
                return void 0;
            const variableDeclarationList = variableDeclaration.parent;
            const statement = variableDeclarationList.parent;
            if (!isVariableDeclarationList(variableDeclarationList) || !isVariableStatement(statement) || !isIdentifier(variableDeclaration.name))
                return void 0;
            return { variableDeclaration, variableDeclarationList, statement, name: variableDeclaration.name };
        }
        function getEditInfoForConvertToAnonymousFunction(context, func) {
            const { file } = context;
            const body = convertToBlock(func.body);
            const newNode = factory.createFunctionExpression(func.modifiers, func.asteriskToken, 
            /* name */
            void 0, func.typeParameters, func.parameters, func.type, body);
            return ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(file, func, newNode));
        }
        function getEditInfoForConvertToNamedFunction(context, func, variableInfo) {
            const { file } = context;
            const body = convertToBlock(func.body);
            const { variableDeclaration, variableDeclarationList, statement, name } = variableInfo;
            suppressLeadingTrivia(statement);
            const modifiersFlags = getCombinedModifierFlags(variableDeclaration) & 1 /* Export */ | getEffectiveModifierFlags(func);
            const modifiers = factory.createModifiersFromModifierFlags(modifiersFlags);
            const newNode = factory.createFunctionDeclaration(length(modifiers) ? modifiers : void 0, func.asteriskToken, name, func.typeParameters, func.parameters, func.type, body);
            if (variableDeclarationList.declarations.length === 1) {
                return ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(file, statement, newNode));
            }
            else {
                return ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                    t.delete(file, variableDeclaration);
                    t.insertNodeAfter(file, statement, newNode);
                });
            }
        }
        function getEditInfoForConvertToArrowFunction(context, func) {
            const { file } = context;
            const statements = func.body.statements;
            const head = statements[0];
            let body;
            if (canBeConvertedToExpression(func.body, head)) {
                body = head.expression;
                suppressLeadingAndTrailingTrivia(body);
                copyComments(head, body);
            }
            else {
                body = func.body;
            }
            const newNode = factory.createArrowFunction(func.modifiers, func.typeParameters, func.parameters, func.type, factory.createToken(38 /* EqualsGreaterThanToken */), body);
            return ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(file, func, newNode));
        }
        function canBeConvertedToExpression(body, head) {
            return body.statements.length === 1 && (isReturnStatement(head) && !!head.expression);
        }
        function isFunctionReferencedInFile(sourceFile, typeChecker, node) {
            return !!node.name && ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(node.name, typeChecker, sourceFile);
        }
        var refactorName7, refactorDescription3, toAnonymousFunctionAction, toNamedFunctionAction, toArrowFunctionAction;
        var init_convertArrowFunctionOrFunctionExpression = __esm({
            "src/services/refactors/convertArrowFunctionOrFunctionExpression.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName7 = "Convert arrow function or function expression";
                refactorDescription3 = getLocaleSpecificMessage(Diagnostics.Convert_arrow_function_or_function_expression);
                toAnonymousFunctionAction = {
                    name: "Convert to anonymous function",
                    description: getLocaleSpecificMessage(Diagnostics.Convert_to_anonymous_function),
                    kind: "refactor.rewrite.function.anonymous"
                };
                toNamedFunctionAction = {
                    name: "Convert to named function",
                    description: getLocaleSpecificMessage(Diagnostics.Convert_to_named_function),
                    kind: "refactor.rewrite.function.named"
                };
                toArrowFunctionAction = {
                    name: "Convert to arrow function",
                    description: getLocaleSpecificMessage(Diagnostics.Convert_to_arrow_function),
                    kind: "refactor.rewrite.function.arrow"
                };
                registerRefactor(refactorName7, {
                    kinds: [
                        toAnonymousFunctionAction.kind,
                        toNamedFunctionAction.kind,
                        toArrowFunctionAction.kind
                    ],
                    getEditsForAction: getRefactorEditsToConvertFunctionExpressions,
                    getAvailableActions: getRefactorActionsToConvertFunctionExpressions
                });
            }
        });
        // src/services/_namespaces/ts.refactor.convertArrowFunctionOrFunctionExpression.ts
        var ts_refactor_convertArrowFunctionOrFunctionExpression_exports = {};
        var init_ts_refactor_convertArrowFunctionOrFunctionExpression = __esm({
            "src/services/_namespaces/ts.refactor.convertArrowFunctionOrFunctionExpression.ts"() {
                "use strict";
                init_convertArrowFunctionOrFunctionExpression();
            }
        });
        // src/services/refactors/convertParamsToDestructuredObject.ts
        function getRefactorActionsToConvertParametersToDestructuredObject(context) {
            const { file, startPosition } = context;
            const isJSFile = isSourceFileJS(file);
            if (isJSFile)
                return emptyArray;
            const functionDeclaration = getFunctionDeclarationAtPosition(file, startPosition, context.program.getTypeChecker());
            if (!functionDeclaration)
                return emptyArray;
            return [{
                    name: refactorName8,
                    description: refactorDescription4,
                    actions: [toDestructuredAction]
                }];
        }
        function getRefactorEditsToConvertParametersToDestructuredObject(context, actionName2) {
            Debug.assert(actionName2 === refactorName8, "Unexpected action name");
            const { file, startPosition, program, cancellationToken, host } = context;
            const functionDeclaration = getFunctionDeclarationAtPosition(file, startPosition, program.getTypeChecker());
            if (!functionDeclaration || !cancellationToken)
                return void 0;
            const groupedReferences = getGroupedReferences(functionDeclaration, program, cancellationToken);
            if (groupedReferences.valid) {
                const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange36(file, program, host, t, functionDeclaration, groupedReferences));
                return { renameFilename: void 0, renameLocation: void 0, edits };
            }
            return { edits: [] };
        }
        function doChange36(sourceFile, program, host, changes, functionDeclaration, groupedReferences) {
            const signature = groupedReferences.signature;
            const newFunctionDeclarationParams = map(createNewParameters(functionDeclaration, program, host), (param) => getSynthesizedDeepClone(param));
            if (signature) {
                const newSignatureParams = map(createNewParameters(signature, program, host), (param) => getSynthesizedDeepClone(param));
                replaceParameters(signature, newSignatureParams);
            }
            replaceParameters(functionDeclaration, newFunctionDeclarationParams);
            const functionCalls = sortAndDeduplicate(groupedReferences.functionCalls, 
            /*comparer*/
            (a, b) => compareValues(a.pos, b.pos));
            for (const call of functionCalls) {
                if (call.arguments && call.arguments.length) {
                    const newArgument = getSynthesizedDeepClone(createNewArgument(functionDeclaration, call.arguments), 
                    /*includeTrivia*/
                    true);
                    changes.replaceNodeRange(getSourceFileOfNode(call), first(call.arguments), last(call.arguments), newArgument, { leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.IncludeAll, trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include });
                }
            }
            function replaceParameters(declarationOrSignature, parameterDeclarations) {
                changes.replaceNodeRangeWithNodes(sourceFile, first(declarationOrSignature.parameters), last(declarationOrSignature.parameters), parameterDeclarations, {
                    joiner: ", ",
                    // indentation is set to 0 because otherwise the object parameter will be indented if there is a `this` parameter
                    indentation: 0,
                    leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.IncludeAll,
                    trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include
                });
            }
        }
        function getGroupedReferences(functionDeclaration, program, cancellationToken) {
            const functionNames = getFunctionNames(functionDeclaration);
            const classNames = isConstructorDeclaration(functionDeclaration) ? getClassNames(functionDeclaration) : [];
            const names = deduplicate([...functionNames, ...classNames], equateValues);
            const checker = program.getTypeChecker();
            const references = flatMap(names, 
            /*mapfn*/
            (name) => ts_FindAllReferences_exports.getReferenceEntriesForNode(-1, name, program, program.getSourceFiles(), cancellationToken));
            const groupedReferences = groupReferences(references);
            if (!every(groupedReferences.declarations, 
            /*callback*/
            (decl) => contains(names, decl))) {
                groupedReferences.valid = false;
            }
            return groupedReferences;
            function groupReferences(referenceEntries) {
                const classReferences = { accessExpressions: [], typeUsages: [] };
                const groupedReferences2 = { functionCalls: [], declarations: [], classReferences, valid: true };
                const functionSymbols = map(functionNames, getSymbolTargetAtLocation);
                const classSymbols = map(classNames, getSymbolTargetAtLocation);
                const isConstructor = isConstructorDeclaration(functionDeclaration);
                const contextualSymbols = map(functionNames, (name) => getSymbolForContextualType(name, checker));
                for (const entry of referenceEntries) {
                    if (entry.kind === ts_FindAllReferences_exports.EntryKind.Span) {
                        groupedReferences2.valid = false;
                        continue;
                    }
                    if (contains(contextualSymbols, getSymbolTargetAtLocation(entry.node))) {
                        if (isValidMethodSignature(entry.node.parent)) {
                            groupedReferences2.signature = entry.node.parent;
                            continue;
                        }
                        const call = entryToFunctionCall(entry);
                        if (call) {
                            groupedReferences2.functionCalls.push(call);
                            continue;
                        }
                    }
                    const contextualSymbol = getSymbolForContextualType(entry.node, checker);
                    if (contextualSymbol && contains(contextualSymbols, contextualSymbol)) {
                        const decl = entryToDeclaration(entry);
                        if (decl) {
                            groupedReferences2.declarations.push(decl);
                            continue;
                        }
                    }
                    if (contains(functionSymbols, getSymbolTargetAtLocation(entry.node)) || isNewExpressionTarget(entry.node)) {
                        const importOrExportReference = entryToImportOrExport(entry);
                        if (importOrExportReference) {
                            continue;
                        }
                        const decl = entryToDeclaration(entry);
                        if (decl) {
                            groupedReferences2.declarations.push(decl);
                            continue;
                        }
                        const call = entryToFunctionCall(entry);
                        if (call) {
                            groupedReferences2.functionCalls.push(call);
                            continue;
                        }
                    }
                    if (isConstructor && contains(classSymbols, getSymbolTargetAtLocation(entry.node))) {
                        const importOrExportReference = entryToImportOrExport(entry);
                        if (importOrExportReference) {
                            continue;
                        }
                        const decl = entryToDeclaration(entry);
                        if (decl) {
                            groupedReferences2.declarations.push(decl);
                            continue;
                        }
                        const accessExpression = entryToAccessExpression(entry);
                        if (accessExpression) {
                            classReferences.accessExpressions.push(accessExpression);
                            continue;
                        }
                        if (isClassDeclaration(functionDeclaration.parent)) {
                            const type = entryToType(entry);
                            if (type) {
                                classReferences.typeUsages.push(type);
                                continue;
                            }
                        }
                    }
                    groupedReferences2.valid = false;
                }
                return groupedReferences2;
            }
            function getSymbolTargetAtLocation(node) {
                const symbol = checker.getSymbolAtLocation(node);
                return symbol && getSymbolTarget(symbol, checker);
            }
        }
        function getSymbolForContextualType(node, checker) {
            const element = getContainingObjectLiteralElement(node);
            if (element) {
                const contextualType = checker.getContextualTypeForObjectLiteralElement(element);
                const symbol = contextualType == null ? void 0 : contextualType.getSymbol();
                if (symbol && !(getCheckFlags(symbol) & 6 /* Synthetic */)) {
                    return symbol;
                }
            }
        }
        function entryToImportOrExport(entry) {
            const node = entry.node;
            if (isImportSpecifier(node.parent) || isImportClause(node.parent) || isImportEqualsDeclaration(node.parent) || isNamespaceImport(node.parent)) {
                return node;
            }
            if (isExportSpecifier(node.parent) || isExportAssignment(node.parent)) {
                return node;
            }
            return void 0;
        }
        function entryToDeclaration(entry) {
            if (isDeclaration(entry.node.parent)) {
                return entry.node;
            }
            return void 0;
        }
        function entryToFunctionCall(entry) {
            if (entry.node.parent) {
                const functionReference = entry.node;
                const parent2 = functionReference.parent;
                switch (parent2.kind) {
                    case 210 /* CallExpression */:
                    case 211 /* NewExpression */:
                        const callOrNewExpression = tryCast(parent2, isCallOrNewExpression);
                        if (callOrNewExpression && callOrNewExpression.expression === functionReference) {
                            return callOrNewExpression;
                        }
                        break;
                    case 208 /* PropertyAccessExpression */:
                        const propertyAccessExpression = tryCast(parent2, isPropertyAccessExpression);
                        if (propertyAccessExpression && propertyAccessExpression.parent && propertyAccessExpression.name === functionReference) {
                            const callOrNewExpression2 = tryCast(propertyAccessExpression.parent, isCallOrNewExpression);
                            if (callOrNewExpression2 && callOrNewExpression2.expression === propertyAccessExpression) {
                                return callOrNewExpression2;
                            }
                        }
                        break;
                    case 209 /* ElementAccessExpression */:
                        const elementAccessExpression = tryCast(parent2, isElementAccessExpression);
                        if (elementAccessExpression && elementAccessExpression.parent && elementAccessExpression.argumentExpression === functionReference) {
                            const callOrNewExpression2 = tryCast(elementAccessExpression.parent, isCallOrNewExpression);
                            if (callOrNewExpression2 && callOrNewExpression2.expression === elementAccessExpression) {
                                return callOrNewExpression2;
                            }
                        }
                        break;
                }
            }
            return void 0;
        }
        function entryToAccessExpression(entry) {
            if (entry.node.parent) {
                const reference = entry.node;
                const parent2 = reference.parent;
                switch (parent2.kind) {
                    case 208 /* PropertyAccessExpression */:
                        const propertyAccessExpression = tryCast(parent2, isPropertyAccessExpression);
                        if (propertyAccessExpression && propertyAccessExpression.expression === reference) {
                            return propertyAccessExpression;
                        }
                        break;
                    case 209 /* ElementAccessExpression */:
                        const elementAccessExpression = tryCast(parent2, isElementAccessExpression);
                        if (elementAccessExpression && elementAccessExpression.expression === reference) {
                            return elementAccessExpression;
                        }
                        break;
                }
            }
            return void 0;
        }
        function entryToType(entry) {
            const reference = entry.node;
            if (getMeaningFromLocation(reference) === 2 /* Type */ || isExpressionWithTypeArgumentsInClassExtendsClause(reference.parent)) {
                return reference;
            }
            return void 0;
        }
        function getFunctionDeclarationAtPosition(file, startPosition, checker) {
            const node = getTouchingToken(file, startPosition);
            const functionDeclaration = getContainingFunctionDeclaration(node);
            if (isTopLevelJSDoc(node))
                return void 0;
            if (functionDeclaration && isValidFunctionDeclaration(functionDeclaration, checker) && rangeContainsRange(functionDeclaration, node) && !(functionDeclaration.body && rangeContainsRange(functionDeclaration.body, node)))
                return functionDeclaration;
            return void 0;
        }
        function isTopLevelJSDoc(node) {
            const containingJSDoc = findAncestor(node, isJSDocNode);
            if (containingJSDoc) {
                const containingNonJSDoc = findAncestor(containingJSDoc, (n) => !isJSDocNode(n));
                return !!containingNonJSDoc && isFunctionLikeDeclaration(containingNonJSDoc);
            }
            return false;
        }
        function isValidMethodSignature(node) {
            return isMethodSignature(node) && (isInterfaceDeclaration(node.parent) || isTypeLiteralNode(node.parent));
        }
        function isValidFunctionDeclaration(functionDeclaration, checker) {
            var _a2;
            if (!isValidParameterNodeArray(functionDeclaration.parameters, checker))
                return false;
            switch (functionDeclaration.kind) {
                case 259 /* FunctionDeclaration */:
                    return hasNameOrDefault(functionDeclaration) && isSingleImplementation(functionDeclaration, checker);
                case 171 /* MethodDeclaration */:
                    if (isObjectLiteralExpression(functionDeclaration.parent)) {
                        const contextualSymbol = getSymbolForContextualType(functionDeclaration.name, checker);
                        return ((_a2 = contextualSymbol == null ? void 0 : contextualSymbol.declarations) == null ? void 0 : _a2.length) === 1 && isSingleImplementation(functionDeclaration, checker);
                    }
                    return isSingleImplementation(functionDeclaration, checker);
                case 173 /* Constructor */:
                    if (isClassDeclaration(functionDeclaration.parent)) {
                        return hasNameOrDefault(functionDeclaration.parent) && isSingleImplementation(functionDeclaration, checker);
                    }
                    else {
                        return isValidVariableDeclaration(functionDeclaration.parent.parent) && isSingleImplementation(functionDeclaration, checker);
                    }
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                    return isValidVariableDeclaration(functionDeclaration.parent);
            }
            return false;
        }
        function isSingleImplementation(functionDeclaration, checker) {
            return !!functionDeclaration.body && !checker.isImplementationOfOverload(functionDeclaration);
        }
        function hasNameOrDefault(functionOrClassDeclaration) {
            if (!functionOrClassDeclaration.name) {
                const defaultKeyword = findModifier(functionOrClassDeclaration, 88 /* DefaultKeyword */);
                return !!defaultKeyword;
            }
            return true;
        }
        function isValidParameterNodeArray(parameters, checker) {
            return getRefactorableParametersLength(parameters) >= minimumParameterLength && every(parameters, 
            /*callback*/
            (paramDecl) => isValidParameterDeclaration(paramDecl, checker));
        }
        function isValidParameterDeclaration(parameterDeclaration, checker) {
            if (isRestParameter(parameterDeclaration)) {
                const type = checker.getTypeAtLocation(parameterDeclaration);
                if (!checker.isArrayType(type) && !checker.isTupleType(type))
                    return false;
            }
            return !parameterDeclaration.modifiers && isIdentifier(parameterDeclaration.name);
        }
        function isValidVariableDeclaration(node) {
            return isVariableDeclaration(node) && isVarConst(node) && isIdentifier(node.name) && !node.type;
        }
        function hasThisParameter(parameters) {
            return parameters.length > 0 && isThis(parameters[0].name);
        }
        function getRefactorableParametersLength(parameters) {
            if (hasThisParameter(parameters)) {
                return parameters.length - 1;
            }
            return parameters.length;
        }
        function getRefactorableParameters(parameters) {
            if (hasThisParameter(parameters)) {
                parameters = factory.createNodeArray(parameters.slice(1), parameters.hasTrailingComma);
            }
            return parameters;
        }
        function createPropertyOrShorthandAssignment(name, initializer) {
            if (isIdentifier(initializer) && getTextOfIdentifierOrLiteral(initializer) === name) {
                return factory.createShorthandPropertyAssignment(name);
            }
            return factory.createPropertyAssignment(name, initializer);
        }
        function createNewArgument(functionDeclaration, functionArguments) {
            const parameters = getRefactorableParameters(functionDeclaration.parameters);
            const hasRestParameter2 = isRestParameter(last(parameters));
            const nonRestArguments = hasRestParameter2 ? functionArguments.slice(0, parameters.length - 1) : functionArguments;
            const properties = map(nonRestArguments, (arg, i) => {
                const parameterName = getParameterName(parameters[i]);
                const property = createPropertyOrShorthandAssignment(parameterName, arg);
                suppressLeadingAndTrailingTrivia(property.name);
                if (isPropertyAssignment(property))
                    suppressLeadingAndTrailingTrivia(property.initializer);
                copyComments(arg, property);
                return property;
            });
            if (hasRestParameter2 && functionArguments.length >= parameters.length) {
                const restArguments = functionArguments.slice(parameters.length - 1);
                const restProperty = factory.createPropertyAssignment(getParameterName(last(parameters)), factory.createArrayLiteralExpression(restArguments));
                properties.push(restProperty);
            }
            const objectLiteral = factory.createObjectLiteralExpression(properties, 
            /*multiLine*/
            false);
            return objectLiteral;
        }
        function createNewParameters(functionDeclaration, program, host) {
            const checker = program.getTypeChecker();
            const refactorableParameters = getRefactorableParameters(functionDeclaration.parameters);
            const bindingElements = map(refactorableParameters, createBindingElementFromParameterDeclaration);
            const objectParameterName = factory.createObjectBindingPattern(bindingElements);
            const objectParameterType = createParameterTypeNode(refactorableParameters);
            let objectInitializer;
            if (every(refactorableParameters, isOptionalParameter)) {
                objectInitializer = factory.createObjectLiteralExpression();
            }
            const objectParameter = factory.createParameterDeclaration(
            /*modifiers*/
            void 0, 
            /*dotDotDotToken*/
            void 0, objectParameterName, 
            /*questionToken*/
            void 0, objectParameterType, objectInitializer);
            if (hasThisParameter(functionDeclaration.parameters)) {
                const thisParameter = functionDeclaration.parameters[0];
                const newThisParameter = factory.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotDotDotToken*/
                void 0, thisParameter.name, 
                /*questionToken*/
                void 0, thisParameter.type);
                suppressLeadingAndTrailingTrivia(newThisParameter.name);
                copyComments(thisParameter.name, newThisParameter.name);
                if (thisParameter.type) {
                    suppressLeadingAndTrailingTrivia(newThisParameter.type);
                    copyComments(thisParameter.type, newThisParameter.type);
                }
                return factory.createNodeArray([newThisParameter, objectParameter]);
            }
            return factory.createNodeArray([objectParameter]);
            function createBindingElementFromParameterDeclaration(parameterDeclaration) {
                const element = factory.createBindingElement(
                /*dotDotDotToken*/
                void 0, 
                /*propertyName*/
                void 0, getParameterName(parameterDeclaration), isRestParameter(parameterDeclaration) && isOptionalParameter(parameterDeclaration) ? factory.createArrayLiteralExpression() : parameterDeclaration.initializer);
                suppressLeadingAndTrailingTrivia(element);
                if (parameterDeclaration.initializer && element.initializer) {
                    copyComments(parameterDeclaration.initializer, element.initializer);
                }
                return element;
            }
            function createParameterTypeNode(parameters) {
                const members = map(parameters, createPropertySignatureFromParameterDeclaration);
                const typeNode = addEmitFlags(factory.createTypeLiteralNode(members), 1 /* SingleLine */);
                return typeNode;
            }
            function createPropertySignatureFromParameterDeclaration(parameterDeclaration) {
                let parameterType = parameterDeclaration.type;
                if (!parameterType && (parameterDeclaration.initializer || isRestParameter(parameterDeclaration))) {
                    parameterType = getTypeNode3(parameterDeclaration);
                }
                const propertySignature = factory.createPropertySignature(
                /*modifiers*/
                void 0, getParameterName(parameterDeclaration), isOptionalParameter(parameterDeclaration) ? factory.createToken(57 /* QuestionToken */) : parameterDeclaration.questionToken, parameterType);
                suppressLeadingAndTrailingTrivia(propertySignature);
                copyComments(parameterDeclaration.name, propertySignature.name);
                if (parameterDeclaration.type && propertySignature.type) {
                    copyComments(parameterDeclaration.type, propertySignature.type);
                }
                return propertySignature;
            }
            function getTypeNode3(node) {
                const type = checker.getTypeAtLocation(node);
                return getTypeNodeIfAccessible(type, node, program, host);
            }
            function isOptionalParameter(parameterDeclaration) {
                if (isRestParameter(parameterDeclaration)) {
                    const type = checker.getTypeAtLocation(parameterDeclaration);
                    return !checker.isTupleType(type);
                }
                return checker.isOptionalParameter(parameterDeclaration);
            }
        }
        function getParameterName(paramDeclaration) {
            return getTextOfIdentifierOrLiteral(paramDeclaration.name);
        }
        function getClassNames(constructorDeclaration) {
            switch (constructorDeclaration.parent.kind) {
                case 260 /* ClassDeclaration */:
                    const classDeclaration = constructorDeclaration.parent;
                    if (classDeclaration.name)
                        return [classDeclaration.name];
                    const defaultModifier = Debug.checkDefined(findModifier(classDeclaration, 88 /* DefaultKeyword */), "Nameless class declaration should be a default export");
                    return [defaultModifier];
                case 228 /* ClassExpression */:
                    const classExpression = constructorDeclaration.parent;
                    const variableDeclaration = constructorDeclaration.parent.parent;
                    const className = classExpression.name;
                    if (className)
                        return [className, variableDeclaration.name];
                    return [variableDeclaration.name];
            }
        }
        function getFunctionNames(functionDeclaration) {
            switch (functionDeclaration.kind) {
                case 259 /* FunctionDeclaration */:
                    if (functionDeclaration.name)
                        return [functionDeclaration.name];
                    const defaultModifier = Debug.checkDefined(findModifier(functionDeclaration, 88 /* DefaultKeyword */), "Nameless function declaration should be a default export");
                    return [defaultModifier];
                case 171 /* MethodDeclaration */:
                    return [functionDeclaration.name];
                case 173 /* Constructor */:
                    const ctrKeyword = Debug.checkDefined(findChildOfKind(functionDeclaration, 135 /* ConstructorKeyword */, functionDeclaration.getSourceFile()), "Constructor declaration should have constructor keyword");
                    if (functionDeclaration.parent.kind === 228 /* ClassExpression */) {
                        const variableDeclaration = functionDeclaration.parent.parent;
                        return [variableDeclaration.name, ctrKeyword];
                    }
                    return [ctrKeyword];
                case 216 /* ArrowFunction */:
                    return [functionDeclaration.parent.name];
                case 215 /* FunctionExpression */:
                    if (functionDeclaration.name)
                        return [functionDeclaration.name, functionDeclaration.parent.name];
                    return [functionDeclaration.parent.name];
                default:
                    return Debug.assertNever(functionDeclaration, `Unexpected function declaration kind ${functionDeclaration.kind}`);
            }
        }
        var refactorName8, minimumParameterLength, refactorDescription4, toDestructuredAction;
        var init_convertParamsToDestructuredObject = __esm({
            "src/services/refactors/convertParamsToDestructuredObject.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName8 = "Convert parameters to destructured object";
                minimumParameterLength = 1;
                refactorDescription4 = getLocaleSpecificMessage(Diagnostics.Convert_parameters_to_destructured_object);
                toDestructuredAction = {
                    name: refactorName8,
                    description: refactorDescription4,
                    kind: "refactor.rewrite.parameters.toDestructured"
                };
                registerRefactor(refactorName8, {
                    kinds: [toDestructuredAction.kind],
                    getEditsForAction: getRefactorEditsToConvertParametersToDestructuredObject,
                    getAvailableActions: getRefactorActionsToConvertParametersToDestructuredObject
                });
            }
        });
        // src/services/_namespaces/ts.refactor.convertParamsToDestructuredObject.ts
        var ts_refactor_convertParamsToDestructuredObject_exports = {};
        var init_ts_refactor_convertParamsToDestructuredObject = __esm({
            "src/services/_namespaces/ts.refactor.convertParamsToDestructuredObject.ts"() {
                "use strict";
                init_convertParamsToDestructuredObject();
            }
        });
        // src/services/refactors/convertStringOrTemplateLiteral.ts
        function getRefactorActionsToConvertToTemplateString(context) {
            const { file, startPosition } = context;
            const node = getNodeOrParentOfParentheses(file, startPosition);
            const maybeBinary = getParentBinaryExpression(node);
            const refactorInfo = { name: refactorName9, description: refactorDescription5, actions: [] };
            if (isBinaryExpression(maybeBinary) && treeToArray(maybeBinary).isValidConcatenation) {
                refactorInfo.actions.push(convertStringAction);
                return [refactorInfo];
            }
            else if (context.preferences.provideRefactorNotApplicableReason) {
                refactorInfo.actions.push({
                    ...convertStringAction,
                    notApplicableReason: getLocaleSpecificMessage(Diagnostics.Can_only_convert_string_concatenation)
                });
                return [refactorInfo];
            }
            return emptyArray;
        }
        function getNodeOrParentOfParentheses(file, startPosition) {
            const node = getTokenAtPosition(file, startPosition);
            const nestedBinary = getParentBinaryExpression(node);
            const isNonStringBinary = !treeToArray(nestedBinary).isValidConcatenation;
            if (isNonStringBinary && isParenthesizedExpression(nestedBinary.parent) && isBinaryExpression(nestedBinary.parent.parent)) {
                return nestedBinary.parent.parent;
            }
            return node;
        }
        function getRefactorEditsToConvertToTemplateString(context, actionName2) {
            const { file, startPosition } = context;
            const node = getNodeOrParentOfParentheses(file, startPosition);
            switch (actionName2) {
                case refactorDescription5:
                    return { edits: getEditsForToTemplateLiteral(context, node) };
                default:
                    return Debug.fail("invalid action");
            }
        }
        function getEditsForToTemplateLiteral(context, node) {
            const maybeBinary = getParentBinaryExpression(node);
            const file = context.file;
            const templateLiteral = nodesToTemplate(treeToArray(maybeBinary), file);
            const trailingCommentRanges = getTrailingCommentRanges(file.text, maybeBinary.end);
            if (trailingCommentRanges) {
                const lastComment = trailingCommentRanges[trailingCommentRanges.length - 1];
                const trailingRange = { pos: trailingCommentRanges[0].pos, end: lastComment.end };
                return ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                    t.deleteRange(file, trailingRange);
                    t.replaceNode(file, maybeBinary, templateLiteral);
                });
            }
            else {
                return ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(file, maybeBinary, templateLiteral));
            }
        }
        function isNotEqualsOperator(node) {
            return node.operatorToken.kind !== 63 /* EqualsToken */;
        }
        function getParentBinaryExpression(expr) {
            const container = findAncestor(expr.parent, (n) => {
                switch (n.kind) {
                    case 208 /* PropertyAccessExpression */:
                    case 209 /* ElementAccessExpression */:
                        return false;
                    case 225 /* TemplateExpression */:
                    case 223 /* BinaryExpression */:
                        return !(isBinaryExpression(n.parent) && isNotEqualsOperator(n.parent));
                    default:
                        return "quit";
                }
            });
            return container || expr;
        }
        function treeToArray(current) {
            const loop = (current2) => {
                if (!isBinaryExpression(current2)) {
                    return {
                        nodes: [current2],
                        operators: [],
                        validOperators: true,
                        hasString: isStringLiteral(current2) || isNoSubstitutionTemplateLiteral(current2)
                    };
                }
                const { nodes: nodes2, operators: operators2, hasString: leftHasString, validOperators: leftOperatorValid } = loop(current2.left);
                if (!(leftHasString || isStringLiteral(current2.right) || isTemplateExpression(current2.right))) {
                    return { nodes: [current2], operators: [], hasString: false, validOperators: true };
                }
                const currentOperatorValid = current2.operatorToken.kind === 39 /* PlusToken */;
                const validOperators2 = leftOperatorValid && currentOperatorValid;
                nodes2.push(current2.right);
                operators2.push(current2.operatorToken);
                return { nodes: nodes2, operators: operators2, hasString: true, validOperators: validOperators2 };
            };
            const { nodes, operators, validOperators, hasString } = loop(current);
            return { nodes, operators, isValidConcatenation: validOperators && hasString };
        }
        function escapeRawStringForTemplate(s) {
            return s.replace(/\\.|[$`]/g, (m) => m[0] === "\\" ? m : "\\" + m);
        }
        function getRawTextOfTemplate(node) {
            const rightShaving = isTemplateHead(node) || isTemplateMiddle(node) ? -2 : -1;
            return getTextOfNode(node).slice(1, rightShaving);
        }
        function concatConsecutiveString(index, nodes) {
            const indexes = [];
            let text = "", rawText = "";
            while (index < nodes.length) {
                const node = nodes[index];
                if (isStringLiteralLike(node)) {
                    text += node.text;
                    rawText += escapeRawStringForTemplate(getTextOfNode(node).slice(1, -1));
                    indexes.push(index);
                    index++;
                }
                else if (isTemplateExpression(node)) {
                    text += node.head.text;
                    rawText += getRawTextOfTemplate(node.head);
                    break;
                }
                else {
                    break;
                }
            }
            return [index, text, rawText, indexes];
        }
        function nodesToTemplate({ nodes, operators }, file) {
            const copyOperatorComments = copyTrailingOperatorComments(operators, file);
            const copyCommentFromStringLiterals = copyCommentFromMultiNode(nodes, file, copyOperatorComments);
            const [begin, headText, rawHeadText, headIndexes] = concatConsecutiveString(0, nodes);
            if (begin === nodes.length) {
                const noSubstitutionTemplateLiteral = factory.createNoSubstitutionTemplateLiteral(headText, rawHeadText);
                copyCommentFromStringLiterals(headIndexes, noSubstitutionTemplateLiteral);
                return noSubstitutionTemplateLiteral;
            }
            const templateSpans = [];
            const templateHead = factory.createTemplateHead(headText, rawHeadText);
            copyCommentFromStringLiterals(headIndexes, templateHead);
            for (let i = begin; i < nodes.length; i++) {
                const currentNode = getExpressionFromParenthesesOrExpression(nodes[i]);
                copyOperatorComments(i, currentNode);
                const [newIndex, subsequentText, rawSubsequentText, stringIndexes] = concatConsecutiveString(i + 1, nodes);
                i = newIndex - 1;
                const isLast = i === nodes.length - 1;
                if (isTemplateExpression(currentNode)) {
                    const spans = map(currentNode.templateSpans, (span, index) => {
                        copyExpressionComments(span);
                        const isLastSpan = index === currentNode.templateSpans.length - 1;
                        const text = span.literal.text + (isLastSpan ? subsequentText : "");
                        const rawText = getRawTextOfTemplate(span.literal) + (isLastSpan ? rawSubsequentText : "");
                        return factory.createTemplateSpan(span.expression, isLast && isLastSpan ? factory.createTemplateTail(text, rawText) : factory.createTemplateMiddle(text, rawText));
                    });
                    templateSpans.push(...spans);
                }
                else {
                    const templatePart = isLast ? factory.createTemplateTail(subsequentText, rawSubsequentText) : factory.createTemplateMiddle(subsequentText, rawSubsequentText);
                    copyCommentFromStringLiterals(stringIndexes, templatePart);
                    templateSpans.push(factory.createTemplateSpan(currentNode, templatePart));
                }
            }
            return factory.createTemplateExpression(templateHead, templateSpans);
        }
        function copyExpressionComments(node) {
            const file = node.getSourceFile();
            copyTrailingComments(node, node.expression, file, 3 /* MultiLineCommentTrivia */, 
            /* hasTrailingNewLine */
            false);
            copyTrailingAsLeadingComments(node.expression, node.expression, file, 3 /* MultiLineCommentTrivia */, 
            /* hasTrailingNewLine */
            false);
        }
        function getExpressionFromParenthesesOrExpression(node) {
            if (isParenthesizedExpression(node)) {
                copyExpressionComments(node);
                node = node.expression;
            }
            return node;
        }
        var refactorName9, refactorDescription5, convertStringAction, copyTrailingOperatorComments, copyCommentFromMultiNode;
        var init_convertStringOrTemplateLiteral = __esm({
            "src/services/refactors/convertStringOrTemplateLiteral.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName9 = "Convert to template string";
                refactorDescription5 = getLocaleSpecificMessage(Diagnostics.Convert_to_template_string);
                convertStringAction = {
                    name: refactorName9,
                    description: refactorDescription5,
                    kind: "refactor.rewrite.string"
                };
                registerRefactor(refactorName9, {
                    kinds: [convertStringAction.kind],
                    getEditsForAction: getRefactorEditsToConvertToTemplateString,
                    getAvailableActions: getRefactorActionsToConvertToTemplateString
                });
                copyTrailingOperatorComments = (operators, file) => (index, targetNode) => {
                    if (index < operators.length) {
                        copyTrailingComments(operators[index], targetNode, file, 3 /* MultiLineCommentTrivia */, 
                        /* hasTrailingNewLine */
                        false);
                    }
                };
                copyCommentFromMultiNode = (nodes, file, copyOperatorComments) => (indexes, targetNode) => {
                    while (indexes.length > 0) {
                        const index = indexes.shift();
                        copyTrailingComments(nodes[index], targetNode, file, 3 /* MultiLineCommentTrivia */, 
                        /* hasTrailingNewLine */
                        false);
                        copyOperatorComments(index, targetNode);
                    }
                };
            }
        });
        // src/services/_namespaces/ts.refactor.convertStringOrTemplateLiteral.ts
        var ts_refactor_convertStringOrTemplateLiteral_exports = {};
        var init_ts_refactor_convertStringOrTemplateLiteral = __esm({
            "src/services/_namespaces/ts.refactor.convertStringOrTemplateLiteral.ts"() {
                "use strict";
                init_convertStringOrTemplateLiteral();
            }
        });
        // src/services/refactors/convertToOptionalChainExpression.ts
        function getRefactorActionsToConvertToOptionalChain(context) {
            const info = getInfo20(context, context.triggerReason === "invoked");
            if (!info)
                return emptyArray;
            if (!isRefactorErrorInfo(info)) {
                return [{
                        name: refactorName10,
                        description: convertToOptionalChainExpressionMessage,
                        actions: [toOptionalChainAction]
                    }];
            }
            if (context.preferences.provideRefactorNotApplicableReason) {
                return [{
                        name: refactorName10,
                        description: convertToOptionalChainExpressionMessage,
                        actions: [{ ...toOptionalChainAction, notApplicableReason: info.error }]
                    }];
            }
            return emptyArray;
        }
        function getRefactorEditsToConvertToOptionalChain(context, actionName2) {
            const info = getInfo20(context);
            Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
            const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange37(context.file, context.program.getTypeChecker(), t, info, actionName2));
            return { edits, renameFilename: void 0, renameLocation: void 0 };
        }
        function isValidExpression(node) {
            return isBinaryExpression(node) || isConditionalExpression(node);
        }
        function isValidStatement(node) {
            return isExpressionStatement(node) || isReturnStatement(node) || isVariableStatement(node);
        }
        function isValidExpressionOrStatement(node) {
            return isValidExpression(node) || isValidStatement(node);
        }
        function getInfo20(context, considerEmptySpans = true) {
            const { file, program } = context;
            const span = getRefactorContextSpan(context);
            const forEmptySpan = span.length === 0;
            if (forEmptySpan && !considerEmptySpans)
                return void 0;
            const startToken = getTokenAtPosition(file, span.start);
            const endToken = findTokenOnLeftOfPosition(file, span.start + span.length);
            const adjustedSpan = createTextSpanFromBounds(startToken.pos, endToken && endToken.end >= startToken.pos ? endToken.getEnd() : startToken.getEnd());
            const parent2 = forEmptySpan ? getValidParentNodeOfEmptySpan(startToken) : getValidParentNodeContainingSpan(startToken, adjustedSpan);
            const expression = parent2 && isValidExpressionOrStatement(parent2) ? getExpression(parent2) : void 0;
            if (!expression)
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_convertible_access_expression) };
            const checker = program.getTypeChecker();
            return isConditionalExpression(expression) ? getConditionalInfo(expression, checker) : getBinaryInfo(expression);
        }
        function getConditionalInfo(expression, checker) {
            const condition = expression.condition;
            const finalExpression = getFinalExpressionInChain(expression.whenTrue);
            if (!finalExpression || checker.isNullableType(checker.getTypeAtLocation(finalExpression))) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_convertible_access_expression) };
            }
            if ((isPropertyAccessExpression(condition) || isIdentifier(condition)) && getMatchingStart(condition, finalExpression.expression)) {
                return { finalExpression, occurrences: [condition], expression };
            }
            else if (isBinaryExpression(condition)) {
                const occurrences = getOccurrencesInExpression(finalExpression.expression, condition);
                return occurrences ? { finalExpression, occurrences, expression } : { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_matching_access_expressions) };
            }
        }
        function getBinaryInfo(expression) {
            if (expression.operatorToken.kind !== 55 /* AmpersandAmpersandToken */) {
                return { error: getLocaleSpecificMessage(Diagnostics.Can_only_convert_logical_AND_access_chains) };
            }
            const finalExpression = getFinalExpressionInChain(expression.right);
            if (!finalExpression)
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_convertible_access_expression) };
            const occurrences = getOccurrencesInExpression(finalExpression.expression, expression.left);
            return occurrences ? { finalExpression, occurrences, expression } : { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_matching_access_expressions) };
        }
        function getOccurrencesInExpression(matchTo, expression) {
            const occurrences = [];
            while (isBinaryExpression(expression) && expression.operatorToken.kind === 55 /* AmpersandAmpersandToken */) {
                const match = getMatchingStart(skipParentheses(matchTo), skipParentheses(expression.right));
                if (!match) {
                    break;
                }
                occurrences.push(match);
                matchTo = match;
                expression = expression.left;
            }
            const finalMatch = getMatchingStart(matchTo, expression);
            if (finalMatch) {
                occurrences.push(finalMatch);
            }
            return occurrences.length > 0 ? occurrences : void 0;
        }
        function getMatchingStart(chain, subchain) {
            if (!isIdentifier(subchain) && !isPropertyAccessExpression(subchain) && !isElementAccessExpression(subchain)) {
                return void 0;
            }
            return chainStartsWith(chain, subchain) ? subchain : void 0;
        }
        function chainStartsWith(chain, subchain) {
            while (isCallExpression(chain) || isPropertyAccessExpression(chain) || isElementAccessExpression(chain)) {
                if (getTextOfChainNode(chain) === getTextOfChainNode(subchain))
                    break;
                chain = chain.expression;
            }
            while (isPropertyAccessExpression(chain) && isPropertyAccessExpression(subchain) || isElementAccessExpression(chain) && isElementAccessExpression(subchain)) {
                if (getTextOfChainNode(chain) !== getTextOfChainNode(subchain))
                    return false;
                chain = chain.expression;
                subchain = subchain.expression;
            }
            return isIdentifier(chain) && isIdentifier(subchain) && chain.getText() === subchain.getText();
        }
        function getTextOfChainNode(node) {
            if (isIdentifier(node) || isStringOrNumericLiteralLike(node)) {
                return node.getText();
            }
            if (isPropertyAccessExpression(node)) {
                return getTextOfChainNode(node.name);
            }
            if (isElementAccessExpression(node)) {
                return getTextOfChainNode(node.argumentExpression);
            }
            return void 0;
        }
        function getValidParentNodeContainingSpan(node, span) {
            while (node.parent) {
                if (isValidExpressionOrStatement(node) && span.length !== 0 && node.end >= span.start + span.length) {
                    return node;
                }
                node = node.parent;
            }
            return void 0;
        }
        function getValidParentNodeOfEmptySpan(node) {
            while (node.parent) {
                if (isValidExpressionOrStatement(node) && !isValidExpressionOrStatement(node.parent)) {
                    return node;
                }
                node = node.parent;
            }
            return void 0;
        }
        function getExpression(node) {
            if (isValidExpression(node)) {
                return node;
            }
            if (isVariableStatement(node)) {
                const variable = getSingleVariableOfVariableStatement(node);
                const initializer = variable == null ? void 0 : variable.initializer;
                return initializer && isValidExpression(initializer) ? initializer : void 0;
            }
            return node.expression && isValidExpression(node.expression) ? node.expression : void 0;
        }
        function getFinalExpressionInChain(node) {
            node = skipParentheses(node);
            if (isBinaryExpression(node)) {
                return getFinalExpressionInChain(node.left);
            }
            else if ((isPropertyAccessExpression(node) || isElementAccessExpression(node) || isCallExpression(node)) && !isOptionalChain(node)) {
                return node;
            }
            return void 0;
        }
        function convertOccurrences(checker, toConvert, occurrences) {
            if (isPropertyAccessExpression(toConvert) || isElementAccessExpression(toConvert) || isCallExpression(toConvert)) {
                const chain = convertOccurrences(checker, toConvert.expression, occurrences);
                const lastOccurrence = occurrences.length > 0 ? occurrences[occurrences.length - 1] : void 0;
                const isOccurrence = (lastOccurrence == null ? void 0 : lastOccurrence.getText()) === toConvert.expression.getText();
                if (isOccurrence)
                    occurrences.pop();
                if (isCallExpression(toConvert)) {
                    return isOccurrence ? factory.createCallChain(chain, factory.createToken(28 /* QuestionDotToken */), toConvert.typeArguments, toConvert.arguments) : factory.createCallChain(chain, toConvert.questionDotToken, toConvert.typeArguments, toConvert.arguments);
                }
                else if (isPropertyAccessExpression(toConvert)) {
                    return isOccurrence ? factory.createPropertyAccessChain(chain, factory.createToken(28 /* QuestionDotToken */), toConvert.name) : factory.createPropertyAccessChain(chain, toConvert.questionDotToken, toConvert.name);
                }
                else if (isElementAccessExpression(toConvert)) {
                    return isOccurrence ? factory.createElementAccessChain(chain, factory.createToken(28 /* QuestionDotToken */), toConvert.argumentExpression) : factory.createElementAccessChain(chain, toConvert.questionDotToken, toConvert.argumentExpression);
                }
            }
            return toConvert;
        }
        function doChange37(sourceFile, checker, changes, info, _actionName) {
            const { finalExpression, occurrences, expression } = info;
            const firstOccurrence = occurrences[occurrences.length - 1];
            const convertedChain = convertOccurrences(checker, finalExpression, occurrences);
            if (convertedChain && (isPropertyAccessExpression(convertedChain) || isElementAccessExpression(convertedChain) || isCallExpression(convertedChain))) {
                if (isBinaryExpression(expression)) {
                    changes.replaceNodeRange(sourceFile, firstOccurrence, finalExpression, convertedChain);
                }
                else if (isConditionalExpression(expression)) {
                    changes.replaceNode(sourceFile, expression, factory.createBinaryExpression(convertedChain, factory.createToken(60 /* QuestionQuestionToken */), expression.whenFalse));
                }
            }
        }
        var refactorName10, convertToOptionalChainExpressionMessage, toOptionalChainAction;
        var init_convertToOptionalChainExpression = __esm({
            "src/services/refactors/convertToOptionalChainExpression.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName10 = "Convert to optional chain expression";
                convertToOptionalChainExpressionMessage = getLocaleSpecificMessage(Diagnostics.Convert_to_optional_chain_expression);
                toOptionalChainAction = {
                    name: refactorName10,
                    description: convertToOptionalChainExpressionMessage,
                    kind: "refactor.rewrite.expression.optionalChain"
                };
                registerRefactor(refactorName10, {
                    kinds: [toOptionalChainAction.kind],
                    getEditsForAction: getRefactorEditsToConvertToOptionalChain,
                    getAvailableActions: getRefactorActionsToConvertToOptionalChain
                });
            }
        });
        // src/services/_namespaces/ts.refactor.convertToOptionalChainExpression.ts
        var ts_refactor_convertToOptionalChainExpression_exports = {};
        var init_ts_refactor_convertToOptionalChainExpression = __esm({
            "src/services/_namespaces/ts.refactor.convertToOptionalChainExpression.ts"() {
                "use strict";
                init_convertToOptionalChainExpression();
            }
        });
        // src/services/refactors/extractSymbol.ts
        function getRefactorActionsToExtractSymbol(context) {
            const requestedRefactor = context.kind;
            const rangeToExtract = getRangeToExtract2(context.file, getRefactorContextSpan(context), context.triggerReason === "invoked");
            const targetRange = rangeToExtract.targetRange;
            if (targetRange === void 0) {
                if (!rangeToExtract.errors || rangeToExtract.errors.length === 0 || !context.preferences.provideRefactorNotApplicableReason) {
                    return emptyArray;
                }
                const errors = [];
                if (refactorKindBeginsWith(extractFunctionAction.kind, requestedRefactor)) {
                    errors.push({
                        name: refactorName11,
                        description: extractFunctionAction.description,
                        actions: [{ ...extractFunctionAction, notApplicableReason: getStringError(rangeToExtract.errors) }]
                    });
                }
                if (refactorKindBeginsWith(extractConstantAction.kind, requestedRefactor)) {
                    errors.push({
                        name: refactorName11,
                        description: extractConstantAction.description,
                        actions: [{ ...extractConstantAction, notApplicableReason: getStringError(rangeToExtract.errors) }]
                    });
                }
                return errors;
            }
            const extractions = getPossibleExtractions(targetRange, context);
            if (extractions === void 0) {
                return emptyArray;
            }
            const functionActions = [];
            const usedFunctionNames = /* @__PURE__ */ new Map();
            let innermostErrorFunctionAction;
            const constantActions = [];
            const usedConstantNames = /* @__PURE__ */ new Map();
            let innermostErrorConstantAction;
            let i = 0;
            for (const { functionExtraction, constantExtraction } of extractions) {
                if (refactorKindBeginsWith(extractFunctionAction.kind, requestedRefactor)) {
                    const description2 = functionExtraction.description;
                    if (functionExtraction.errors.length === 0) {
                        if (!usedFunctionNames.has(description2)) {
                            usedFunctionNames.set(description2, true);
                            functionActions.push({
                                description: description2,
                                name: `function_scope_${i}`,
                                kind: extractFunctionAction.kind
                            });
                        }
                    }
                    else if (!innermostErrorFunctionAction) {
                        innermostErrorFunctionAction = {
                            description: description2,
                            name: `function_scope_${i}`,
                            notApplicableReason: getStringError(functionExtraction.errors),
                            kind: extractFunctionAction.kind
                        };
                    }
                }
                if (refactorKindBeginsWith(extractConstantAction.kind, requestedRefactor)) {
                    const description2 = constantExtraction.description;
                    if (constantExtraction.errors.length === 0) {
                        if (!usedConstantNames.has(description2)) {
                            usedConstantNames.set(description2, true);
                            constantActions.push({
                                description: description2,
                                name: `constant_scope_${i}`,
                                kind: extractConstantAction.kind
                            });
                        }
                    }
                    else if (!innermostErrorConstantAction) {
                        innermostErrorConstantAction = {
                            description: description2,
                            name: `constant_scope_${i}`,
                            notApplicableReason: getStringError(constantExtraction.errors),
                            kind: extractConstantAction.kind
                        };
                    }
                }
                i++;
            }
            const infos = [];
            if (functionActions.length) {
                infos.push({
                    name: refactorName11,
                    description: getLocaleSpecificMessage(Diagnostics.Extract_function),
                    actions: functionActions
                });
            }
            else if (context.preferences.provideRefactorNotApplicableReason && innermostErrorFunctionAction) {
                infos.push({
                    name: refactorName11,
                    description: getLocaleSpecificMessage(Diagnostics.Extract_function),
                    actions: [innermostErrorFunctionAction]
                });
            }
            if (constantActions.length) {
                infos.push({
                    name: refactorName11,
                    description: getLocaleSpecificMessage(Diagnostics.Extract_constant),
                    actions: constantActions
                });
            }
            else if (context.preferences.provideRefactorNotApplicableReason && innermostErrorConstantAction) {
                infos.push({
                    name: refactorName11,
                    description: getLocaleSpecificMessage(Diagnostics.Extract_constant),
                    actions: [innermostErrorConstantAction]
                });
            }
            return infos.length ? infos : emptyArray;
            function getStringError(errors) {
                let error = errors[0].messageText;
                if (typeof error !== "string") {
                    error = error.messageText;
                }
                return error;
            }
        }
        function getRefactorEditsToExtractSymbol(context, actionName2) {
            const rangeToExtract = getRangeToExtract2(context.file, getRefactorContextSpan(context));
            const targetRange = rangeToExtract.targetRange;
            const parsedFunctionIndexMatch = /^function_scope_(\d+)$/.exec(actionName2);
            if (parsedFunctionIndexMatch) {
                const index = +parsedFunctionIndexMatch[1];
                Debug.assert(isFinite(index), "Expected to parse a finite number from the function scope index");
                return getFunctionExtractionAtIndex(targetRange, context, index);
            }
            const parsedConstantIndexMatch = /^constant_scope_(\d+)$/.exec(actionName2);
            if (parsedConstantIndexMatch) {
                const index = +parsedConstantIndexMatch[1];
                Debug.assert(isFinite(index), "Expected to parse a finite number from the constant scope index");
                return getConstantExtractionAtIndex(targetRange, context, index);
            }
            Debug.fail("Unrecognized action name");
        }
        function getRangeToExtract2(sourceFile, span, invoked = true) {
            const { length: length2 } = span;
            if (length2 === 0 && !invoked) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractEmpty)] };
            }
            const cursorRequest = length2 === 0 && invoked;
            const startToken = findFirstNonJsxWhitespaceToken(sourceFile, span.start);
            const endToken = findTokenOnLeftOfPosition(sourceFile, textSpanEnd(span));
            const adjustedSpan = startToken && endToken && invoked ? getAdjustedSpanFromNodes(startToken, endToken, sourceFile) : span;
            const start = cursorRequest ? getExtractableParent(startToken) : getParentNodeInSpan(startToken, sourceFile, adjustedSpan);
            const end = cursorRequest ? start : getParentNodeInSpan(endToken, sourceFile, adjustedSpan);
            let rangeFacts = 0 /* None */;
            let thisNode;
            if (!start || !end) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
            }
            if (start.flags & 8388608 /* JSDoc */) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractJSDoc)] };
            }
            if (start.parent !== end.parent) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
            }
            if (start !== end) {
                if (!isBlockLike(start.parent)) {
                    return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
                }
                const statements = [];
                for (const statement of start.parent.statements) {
                    if (statement === start || statements.length) {
                        const errors2 = checkNode(statement);
                        if (errors2) {
                            return { errors: errors2 };
                        }
                        statements.push(statement);
                    }
                    if (statement === end) {
                        break;
                    }
                }
                if (!statements.length) {
                    return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
                }
                return { targetRange: { range: statements, facts: rangeFacts, thisNode } };
            }
            if (isReturnStatement(start) && !start.expression) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
            }
            const node = refineNode(start);
            const errors = checkRootNode(node) || checkNode(node);
            if (errors) {
                return { errors };
            }
            return { targetRange: { range: getStatementOrExpressionRange(node), facts: rangeFacts, thisNode } };
            function refineNode(node2) {
                if (isReturnStatement(node2)) {
                    if (node2.expression) {
                        return node2.expression;
                    }
                }
                else if (isVariableStatement(node2) || isVariableDeclarationList(node2)) {
                    const declarations = isVariableStatement(node2) ? node2.declarationList.declarations : node2.declarations;
                    let numInitializers = 0;
                    let lastInitializer;
                    for (const declaration of declarations) {
                        if (declaration.initializer) {
                            numInitializers++;
                            lastInitializer = declaration.initializer;
                        }
                    }
                    if (numInitializers === 1) {
                        return lastInitializer;
                    }
                }
                else if (isVariableDeclaration(node2)) {
                    if (node2.initializer) {
                        return node2.initializer;
                    }
                }
                return node2;
            }
            function checkRootNode(node2) {
                if (isIdentifier(isExpressionStatement(node2) ? node2.expression : node2)) {
                    return [createDiagnosticForNode(node2, Messages.cannotExtractIdentifier)];
                }
                return void 0;
            }
            function checkForStaticContext(nodeToCheck, containingClass) {
                let current = nodeToCheck;
                while (current !== containingClass) {
                    if (current.kind === 169 /* PropertyDeclaration */) {
                        if (isStatic(current)) {
                            rangeFacts |= 32 /* InStaticRegion */;
                        }
                        break;
                    }
                    else if (current.kind === 166 /* Parameter */) {
                        const ctorOrMethod = getContainingFunction(current);
                        if (ctorOrMethod.kind === 173 /* Constructor */) {
                            rangeFacts |= 32 /* InStaticRegion */;
                        }
                        break;
                    }
                    else if (current.kind === 171 /* MethodDeclaration */) {
                        if (isStatic(current)) {
                            rangeFacts |= 32 /* InStaticRegion */;
                        }
                    }
                    current = current.parent;
                }
            }
            function checkNode(nodeToCheck) {
                let PermittedJumps;
                ((PermittedJumps2) => {
                    PermittedJumps2[PermittedJumps2["None"] = 0] = "None";
                    PermittedJumps2[PermittedJumps2["Break"] = 1] = "Break";
                    PermittedJumps2[PermittedJumps2["Continue"] = 2] = "Continue";
                    PermittedJumps2[PermittedJumps2["Return"] = 4] = "Return";
                })(PermittedJumps || (PermittedJumps = {}));
                Debug.assert(nodeToCheck.pos <= nodeToCheck.end, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809 (1)");
                Debug.assert(!positionIsSynthesized(nodeToCheck.pos), "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809 (2)");
                if (!isStatement(nodeToCheck) && !(isExpressionNode(nodeToCheck) && isExtractableExpression(nodeToCheck)) && !isStringLiteralJsxAttribute(nodeToCheck)) {
                    return [createDiagnosticForNode(nodeToCheck, Messages.statementOrExpressionExpected)];
                }
                if (nodeToCheck.flags & 16777216 /* Ambient */) {
                    return [createDiagnosticForNode(nodeToCheck, Messages.cannotExtractAmbientBlock)];
                }
                const containingClass = getContainingClass(nodeToCheck);
                if (containingClass) {
                    checkForStaticContext(nodeToCheck, containingClass);
                }
                let errors2;
                let permittedJumps = 4 /* Return */;
                let seenLabels;
                visit(nodeToCheck);
                if (rangeFacts & 8 /* UsesThis */) {
                    const container = getThisContainer(nodeToCheck, 
                    /** includeArrowFunctions */
                    false, 
                    /*includeClassComputedPropertyName*/
                    false);
                    if (container.kind === 259 /* FunctionDeclaration */ || container.kind === 171 /* MethodDeclaration */ && container.parent.kind === 207 /* ObjectLiteralExpression */ || container.kind === 215 /* FunctionExpression */) {
                        rangeFacts |= 16 /* UsesThisInFunction */;
                    }
                }
                return errors2;
                function visit(node2) {
                    if (errors2) {
                        return true;
                    }
                    if (isDeclaration(node2)) {
                        const declaringNode = node2.kind === 257 /* VariableDeclaration */ ? node2.parent.parent : node2;
                        if (hasSyntacticModifier(declaringNode, 1 /* Export */)) {
                            (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractExportedEntity));
                            return true;
                        }
                    }
                    switch (node2.kind) {
                        case 269 /* ImportDeclaration */:
                            (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractImport));
                            return true;
                        case 274 /* ExportAssignment */:
                            (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractExportedEntity));
                            return true;
                        case 106 /* SuperKeyword */:
                            if (node2.parent.kind === 210 /* CallExpression */) {
                                const containingClass2 = getContainingClass(node2);
                                if (containingClass2 === void 0 || containingClass2.pos < span.start || containingClass2.end >= span.start + span.length) {
                                    (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractSuper));
                                    return true;
                                }
                            }
                            else {
                                rangeFacts |= 8 /* UsesThis */;
                                thisNode = node2;
                            }
                            break;
                        case 216 /* ArrowFunction */:
                            forEachChild(node2, function check(n) {
                                if (isThis(n)) {
                                    rangeFacts |= 8 /* UsesThis */;
                                    thisNode = node2;
                                }
                                else if (isClassLike(n) || isFunctionLike(n) && !isArrowFunction(n)) {
                                    return false;
                                }
                                else {
                                    forEachChild(n, check);
                                }
                            });
                        case 260 /* ClassDeclaration */:
                        case 259 /* FunctionDeclaration */:
                            if (isSourceFile(node2.parent) && node2.parent.externalModuleIndicator === void 0) {
                                (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.functionWillNotBeVisibleInTheNewScope));
                            }
                        case 228 /* ClassExpression */:
                        case 215 /* FunctionExpression */:
                        case 171 /* MethodDeclaration */:
                        case 173 /* Constructor */:
                        case 174 /* GetAccessor */:
                        case 175 /* SetAccessor */:
                            return false;
                    }
                    const savedPermittedJumps = permittedJumps;
                    switch (node2.kind) {
                        case 242 /* IfStatement */:
                            permittedJumps &= ~4 /* Return */;
                            break;
                        case 255 /* TryStatement */:
                            permittedJumps = 0 /* None */;
                            break;
                        case 238 /* Block */:
                            if (node2.parent && node2.parent.kind === 255 /* TryStatement */ && node2.parent.finallyBlock === node2) {
                                permittedJumps = 4 /* Return */;
                            }
                            break;
                        case 293 /* DefaultClause */:
                        case 292 /* CaseClause */:
                            permittedJumps |= 1 /* Break */;
                            break;
                        default:
                            if (isIterationStatement(node2, 
                            /*lookInLabeledStatements*/
                            false)) {
                                permittedJumps |= 1 /* Break */ | 2 /* Continue */;
                            }
                            break;
                    }
                    switch (node2.kind) {
                        case 194 /* ThisType */:
                        case 108 /* ThisKeyword */:
                            rangeFacts |= 8 /* UsesThis */;
                            thisNode = node2;
                            break;
                        case 253 /* LabeledStatement */: {
                            const label = node2.label;
                            (seenLabels || (seenLabels = [])).push(label.escapedText);
                            forEachChild(node2, visit);
                            seenLabels.pop();
                            break;
                        }
                        case 249 /* BreakStatement */:
                        case 248 /* ContinueStatement */: {
                            const label = node2.label;
                            if (label) {
                                if (!contains(seenLabels, label.escapedText)) {
                                    (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractRangeContainingLabeledBreakOrContinueStatementWithTargetOutsideOfTheRange));
                                }
                            }
                            else {
                                if (!(permittedJumps & (node2.kind === 249 /* BreakStatement */ ? 1 /* Break */ : 2 /* Continue */))) {
                                    (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractRangeContainingConditionalBreakOrContinueStatements));
                                }
                            }
                            break;
                        }
                        case 220 /* AwaitExpression */:
                            rangeFacts |= 4 /* IsAsyncFunction */;
                            break;
                        case 226 /* YieldExpression */:
                            rangeFacts |= 2 /* IsGenerator */;
                            break;
                        case 250 /* ReturnStatement */:
                            if (permittedJumps & 4 /* Return */) {
                                rangeFacts |= 1 /* HasReturn */;
                            }
                            else {
                                (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractRangeContainingConditionalReturnStatement));
                            }
                            break;
                        default:
                            forEachChild(node2, visit);
                            break;
                    }
                    permittedJumps = savedPermittedJumps;
                }
            }
        }
        function getAdjustedSpanFromNodes(startNode2, endNode2, sourceFile) {
            const start = startNode2.getStart(sourceFile);
            let end = endNode2.getEnd();
            if (sourceFile.text.charCodeAt(end) === 59 /* semicolon */) {
                end++;
            }
            return { start, length: end - start };
        }
        function getStatementOrExpressionRange(node) {
            if (isStatement(node)) {
                return [node];
            }
            if (isExpressionNode(node)) {
                return isExpressionStatement(node.parent) ? [node.parent] : node;
            }
            if (isStringLiteralJsxAttribute(node)) {
                return node;
            }
            return void 0;
        }
        function isScope(node) {
            return isArrowFunction(node) ? isFunctionBody(node.body) : isFunctionLikeDeclaration(node) || isSourceFile(node) || isModuleBlock(node) || isClassLike(node);
        }
        function collectEnclosingScopes(range) {
            let current = isReadonlyArray(range.range) ? first(range.range) : range.range;
            if (range.facts & 8 /* UsesThis */ && !(range.facts & 16 /* UsesThisInFunction */)) {
                const containingClass = getContainingClass(current);
                if (containingClass) {
                    const containingFunction = findAncestor(current, isFunctionLikeDeclaration);
                    return containingFunction ? [containingFunction, containingClass] : [containingClass];
                }
            }
            const scopes = [];
            while (true) {
                current = current.parent;
                if (current.kind === 166 /* Parameter */) {
                    current = findAncestor(current, (parent2) => isFunctionLikeDeclaration(parent2)).parent;
                }
                if (isScope(current)) {
                    scopes.push(current);
                    if (current.kind === 308 /* SourceFile */) {
                        return scopes;
                    }
                }
            }
        }
        function getFunctionExtractionAtIndex(targetRange, context, requestedChangesIndex) {
            const { scopes, readsAndWrites: { target, usagesPerScope, functionErrorsPerScope, exposedVariableDeclarations } } = getPossibleExtractionsWorker(targetRange, context);
            Debug.assert(!functionErrorsPerScope[requestedChangesIndex].length, "The extraction went missing? How?");
            context.cancellationToken.throwIfCancellationRequested();
            return extractFunctionInScope(target, scopes[requestedChangesIndex], usagesPerScope[requestedChangesIndex], exposedVariableDeclarations, targetRange, context);
        }
        function getConstantExtractionAtIndex(targetRange, context, requestedChangesIndex) {
            const { scopes, readsAndWrites: { target, usagesPerScope, constantErrorsPerScope, exposedVariableDeclarations } } = getPossibleExtractionsWorker(targetRange, context);
            Debug.assert(!constantErrorsPerScope[requestedChangesIndex].length, "The extraction went missing? How?");
            Debug.assert(exposedVariableDeclarations.length === 0, "Extract constant accepted a range containing a variable declaration?");
            context.cancellationToken.throwIfCancellationRequested();
            const expression = isExpression(target) ? target : target.statements[0].expression;
            return extractConstantInScope(expression, scopes[requestedChangesIndex], usagesPerScope[requestedChangesIndex], targetRange.facts, context);
        }
        function getPossibleExtractions(targetRange, context) {
            const { scopes, readsAndWrites: { functionErrorsPerScope, constantErrorsPerScope } } = getPossibleExtractionsWorker(targetRange, context);
            const extractions = scopes.map((scope, i) => {
                const functionDescriptionPart = getDescriptionForFunctionInScope(scope);
                const constantDescriptionPart = getDescriptionForConstantInScope(scope);
                const scopeDescription = isFunctionLikeDeclaration(scope) ? getDescriptionForFunctionLikeDeclaration(scope) : isClassLike(scope) ? getDescriptionForClassLikeDeclaration(scope) : getDescriptionForModuleLikeDeclaration(scope);
                let functionDescription;
                let constantDescription;
                if (scopeDescription === 1 /* Global */) {
                    functionDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1_scope), [functionDescriptionPart, "global"]);
                    constantDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1_scope), [constantDescriptionPart, "global"]);
                }
                else if (scopeDescription === 0 /* Module */) {
                    functionDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1_scope), [functionDescriptionPart, "module"]);
                    constantDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1_scope), [constantDescriptionPart, "module"]);
                }
                else {
                    functionDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1), [functionDescriptionPart, scopeDescription]);
                    constantDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1), [constantDescriptionPart, scopeDescription]);
                }
                if (i === 0 && !isClassLike(scope)) {
                    constantDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_enclosing_scope), [constantDescriptionPart]);
                }
                return {
                    functionExtraction: {
                        description: functionDescription,
                        errors: functionErrorsPerScope[i]
                    },
                    constantExtraction: {
                        description: constantDescription,
                        errors: constantErrorsPerScope[i]
                    }
                };
            });
            return extractions;
        }
        function getPossibleExtractionsWorker(targetRange, context) {
            const { file: sourceFile } = context;
            const scopes = collectEnclosingScopes(targetRange);
            const enclosingTextRange = getEnclosingTextRange(targetRange, sourceFile);
            const readsAndWrites = collectReadsAndWrites(targetRange, scopes, enclosingTextRange, sourceFile, context.program.getTypeChecker(), context.cancellationToken);
            return { scopes, readsAndWrites };
        }
        function getDescriptionForFunctionInScope(scope) {
            return isFunctionLikeDeclaration(scope) ? "inner function" : isClassLike(scope) ? "method" : "function";
        }
        function getDescriptionForConstantInScope(scope) {
            return isClassLike(scope) ? "readonly field" : "constant";
        }
        function getDescriptionForFunctionLikeDeclaration(scope) {
            switch (scope.kind) {
                case 173 /* Constructor */:
                    return "constructor";
                case 215 /* FunctionExpression */:
                case 259 /* FunctionDeclaration */:
                    return scope.name ? `function '${scope.name.text}'` : ANONYMOUS;
                case 216 /* ArrowFunction */:
                    return "arrow function";
                case 171 /* MethodDeclaration */:
                    return `method '${scope.name.getText()}'`;
                case 174 /* GetAccessor */:
                    return `'get ${scope.name.getText()}'`;
                case 175 /* SetAccessor */:
                    return `'set ${scope.name.getText()}'`;
                default:
                    throw Debug.assertNever(scope, `Unexpected scope kind ${scope.kind}`);
            }
        }
        function getDescriptionForClassLikeDeclaration(scope) {
            return scope.kind === 260 /* ClassDeclaration */ ? scope.name ? `class '${scope.name.text}'` : "anonymous class declaration" : scope.name ? `class expression '${scope.name.text}'` : "anonymous class expression";
        }
        function getDescriptionForModuleLikeDeclaration(scope) {
            return scope.kind === 265 /* ModuleBlock */ ? `namespace '${scope.parent.name.getText()}'` : scope.externalModuleIndicator ? 0 /* Module */ : 1 /* Global */;
        }
        function extractFunctionInScope(node, scope, { usages: usagesInScope, typeParameterUsages, substitutions }, exposedVariableDeclarations, range, context) {
            const checker = context.program.getTypeChecker();
            const scriptTarget = getEmitScriptTarget(context.program.getCompilerOptions());
            const importAdder = ts_codefix_exports.createImportAdder(context.file, context.program, context.preferences, context.host);
            const file = scope.getSourceFile();
            const functionNameText = getUniqueName(isClassLike(scope) ? "newMethod" : "newFunction", file);
            const isJS = isInJSFile(scope);
            const functionName = factory.createIdentifier(functionNameText);
            let returnType;
            const parameters = [];
            const callArguments = [];
            let writes;
            usagesInScope.forEach((usage, name) => {
                let typeNode;
                if (!isJS) {
                    let type = checker.getTypeOfSymbolAtLocation(usage.symbol, usage.node);
                    type = checker.getBaseTypeOfLiteralType(type);
                    typeNode = ts_codefix_exports.typeToAutoImportableTypeNode(checker, importAdder, type, scope, scriptTarget, 1 /* NoTruncation */);
                }
                const paramDecl = factory.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotDotDotToken*/
                void 0, 
                /*name*/
                name, 
                /*questionToken*/
                void 0, typeNode);
                parameters.push(paramDecl);
                if (usage.usage === 2 /* Write */) {
                    (writes || (writes = [])).push(usage);
                }
                callArguments.push(factory.createIdentifier(name));
            });
            const typeParametersAndDeclarations = arrayFrom(typeParameterUsages.values(), (type) => ({ type, declaration: getFirstDeclaration(type) }));
            const sortedTypeParametersAndDeclarations = typeParametersAndDeclarations.sort(compareTypesByDeclarationOrder);
            const typeParameters = sortedTypeParametersAndDeclarations.length === 0 ? void 0 : sortedTypeParametersAndDeclarations.map((t) => t.declaration);
            const callTypeArguments = typeParameters !== void 0 ? typeParameters.map((decl) => factory.createTypeReferenceNode(decl.name, 
            /*typeArguments*/
            void 0)) : void 0;
            if (isExpression(node) && !isJS) {
                const contextualType = checker.getContextualType(node);
                returnType = checker.typeToTypeNode(contextualType, scope, 1 /* NoTruncation */);
            }
            const { body, returnValueProperty } = transformFunctionBody(node, exposedVariableDeclarations, writes, substitutions, !!(range.facts & 1 /* HasReturn */));
            suppressLeadingAndTrailingTrivia(body);
            let newFunction;
            const callThis = !!(range.facts & 16 /* UsesThisInFunction */);
            if (isClassLike(scope)) {
                const modifiers = isJS ? [] : [factory.createModifier(121 /* PrivateKeyword */)];
                if (range.facts & 32 /* InStaticRegion */) {
                    modifiers.push(factory.createModifier(124 /* StaticKeyword */));
                }
                if (range.facts & 4 /* IsAsyncFunction */) {
                    modifiers.push(factory.createModifier(132 /* AsyncKeyword */));
                }
                newFunction = factory.createMethodDeclaration(modifiers.length ? modifiers : void 0, range.facts & 2 /* IsGenerator */ ? factory.createToken(41 /* AsteriskToken */) : void 0, functionName, 
                /*questionToken*/
                void 0, typeParameters, parameters, returnType, body);
            }
            else {
                if (callThis) {
                    parameters.unshift(factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, 
                    /*name*/
                    "this", 
                    /*questionToken*/
                    void 0, checker.typeToTypeNode(checker.getTypeAtLocation(range.thisNode), scope, 1 /* NoTruncation */), 
                    /*initializer*/
                    void 0));
                }
                newFunction = factory.createFunctionDeclaration(range.facts & 4 /* IsAsyncFunction */ ? [factory.createToken(132 /* AsyncKeyword */)] : void 0, range.facts & 2 /* IsGenerator */ ? factory.createToken(41 /* AsteriskToken */) : void 0, functionName, typeParameters, parameters, returnType, body);
            }
            const changeTracker = ts_textChanges_exports.ChangeTracker.fromContext(context);
            const minInsertionPos = (isReadonlyArray(range.range) ? last(range.range) : range.range).end;
            const nodeToInsertBefore = getNodeToInsertFunctionBefore(minInsertionPos, scope);
            if (nodeToInsertBefore) {
                changeTracker.insertNodeBefore(context.file, nodeToInsertBefore, newFunction, 
                /*blankLineBetween*/
                true);
            }
            else {
                changeTracker.insertNodeAtEndOfScope(context.file, scope, newFunction);
            }
            importAdder.writeFixes(changeTracker);
            const newNodes = [];
            const called = getCalledExpression(scope, range, functionNameText);
            if (callThis) {
                callArguments.unshift(factory.createIdentifier("this"));
            }
            let call = factory.createCallExpression(callThis ? factory.createPropertyAccessExpression(called, "call") : called, callTypeArguments, 
            // Note that no attempt is made to take advantage of type argument inference
            callArguments);
            if (range.facts & 2 /* IsGenerator */) {
                call = factory.createYieldExpression(factory.createToken(41 /* AsteriskToken */), call);
            }
            if (range.facts & 4 /* IsAsyncFunction */) {
                call = factory.createAwaitExpression(call);
            }
            if (isInJSXContent(node)) {
                call = factory.createJsxExpression(
                /*dotDotDotToken*/
                void 0, call);
            }
            if (exposedVariableDeclarations.length && !writes) {
                Debug.assert(!returnValueProperty, "Expected no returnValueProperty");
                Debug.assert(!(range.facts & 1 /* HasReturn */), "Expected RangeFacts.HasReturn flag to be unset");
                if (exposedVariableDeclarations.length === 1) {
                    const variableDeclaration = exposedVariableDeclarations[0];
                    newNodes.push(factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(getSynthesizedDeepClone(variableDeclaration.name), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        getSynthesizedDeepClone(variableDeclaration.type), 
                        /*initializer*/
                        call)], variableDeclaration.parent.flags)));
                }
                else {
                    const bindingElements = [];
                    const typeElements = [];
                    let commonNodeFlags = exposedVariableDeclarations[0].parent.flags;
                    let sawExplicitType = false;
                    for (const variableDeclaration of exposedVariableDeclarations) {
                        bindingElements.push(factory.createBindingElement(
                        /*dotDotDotToken*/
                        void 0, 
                        /*propertyName*/
                        void 0, 
                        /*name*/
                        getSynthesizedDeepClone(variableDeclaration.name)));
                        const variableType = checker.typeToTypeNode(checker.getBaseTypeOfLiteralType(checker.getTypeAtLocation(variableDeclaration)), scope, 1 /* NoTruncation */);
                        typeElements.push(factory.createPropertySignature(
                        /*modifiers*/
                        void 0, 
                        /*name*/
                        variableDeclaration.symbol.name, 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        variableType));
                        sawExplicitType = sawExplicitType || variableDeclaration.type !== void 0;
                        commonNodeFlags = commonNodeFlags & variableDeclaration.parent.flags;
                    }
                    const typeLiteral = sawExplicitType ? factory.createTypeLiteralNode(typeElements) : void 0;
                    if (typeLiteral) {
                        setEmitFlags(typeLiteral, 1 /* SingleLine */);
                    }
                    newNodes.push(factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(factory.createObjectBindingPattern(bindingElements), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        typeLiteral, 
                        /*initializer*/
                        call)], commonNodeFlags)));
                }
            }
            else if (exposedVariableDeclarations.length || writes) {
                if (exposedVariableDeclarations.length) {
                    for (const variableDeclaration of exposedVariableDeclarations) {
                        let flags = variableDeclaration.parent.flags;
                        if (flags & 2 /* Const */) {
                            flags = flags & ~2 /* Const */ | 1 /* Let */;
                        }
                        newNodes.push(factory.createVariableStatement(
                        /*modifiers*/
                        void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(variableDeclaration.symbol.name, 
                            /*exclamationToken*/
                            void 0, getTypeDeepCloneUnionUndefined(variableDeclaration.type))], flags)));
                    }
                }
                if (returnValueProperty) {
                    newNodes.push(factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(returnValueProperty, 
                        /*exclamationToken*/
                        void 0, getTypeDeepCloneUnionUndefined(returnType))], 1 /* Let */)));
                }
                const assignments = getPropertyAssignmentsForWritesAndVariableDeclarations(exposedVariableDeclarations, writes);
                if (returnValueProperty) {
                    assignments.unshift(factory.createShorthandPropertyAssignment(returnValueProperty));
                }
                if (assignments.length === 1) {
                    Debug.assert(!returnValueProperty, "Shouldn't have returnValueProperty here");
                    newNodes.push(factory.createExpressionStatement(factory.createAssignment(assignments[0].name, call)));
                    if (range.facts & 1 /* HasReturn */) {
                        newNodes.push(factory.createReturnStatement());
                    }
                }
                else {
                    newNodes.push(factory.createExpressionStatement(factory.createAssignment(factory.createObjectLiteralExpression(assignments), call)));
                    if (returnValueProperty) {
                        newNodes.push(factory.createReturnStatement(factory.createIdentifier(returnValueProperty)));
                    }
                }
            }
            else {
                if (range.facts & 1 /* HasReturn */) {
                    newNodes.push(factory.createReturnStatement(call));
                }
                else if (isReadonlyArray(range.range)) {
                    newNodes.push(factory.createExpressionStatement(call));
                }
                else {
                    newNodes.push(call);
                }
            }
            if (isReadonlyArray(range.range)) {
                changeTracker.replaceNodeRangeWithNodes(context.file, first(range.range), last(range.range), newNodes);
            }
            else {
                changeTracker.replaceNodeWithNodes(context.file, range.range, newNodes);
            }
            const edits = changeTracker.getChanges();
            const renameRange = isReadonlyArray(range.range) ? first(range.range) : range.range;
            const renameFilename = renameRange.getSourceFile().fileName;
            const renameLocation = getRenameLocation(edits, renameFilename, functionNameText, 
            /*isDeclaredBeforeUse*/
            false);
            return { renameFilename, renameLocation, edits };
            function getTypeDeepCloneUnionUndefined(typeNode) {
                if (typeNode === void 0) {
                    return void 0;
                }
                const clone2 = getSynthesizedDeepClone(typeNode);
                let withoutParens = clone2;
                while (isParenthesizedTypeNode(withoutParens)) {
                    withoutParens = withoutParens.type;
                }
                return isUnionTypeNode(withoutParens) && find(withoutParens.types, (t) => t.kind === 155 /* UndefinedKeyword */) ? clone2 : factory.createUnionTypeNode([clone2, factory.createKeywordTypeNode(155 /* UndefinedKeyword */)]);
            }
        }
        function extractConstantInScope(node, scope, { substitutions }, rangeFacts, context) {
            const checker = context.program.getTypeChecker();
            const file = scope.getSourceFile();
            const localNameText = isPropertyAccessExpression(node) && !isClassLike(scope) && !checker.resolveName(node.name.text, node, 111551 /* Value */, 
            /*excludeGlobals*/
            false) && !isPrivateIdentifier(node.name) && !identifierToKeywordKind(node.name) ? node.name.text : getUniqueName(isClassLike(scope) ? "newProperty" : "newLocal", file);
            const isJS = isInJSFile(scope);
            let variableType = isJS || !checker.isContextSensitive(node) ? void 0 : checker.typeToTypeNode(checker.getContextualType(node), scope, 1 /* NoTruncation */);
            let initializer = transformConstantInitializer(skipParentheses(node), substitutions);
            ({ variableType, initializer } = transformFunctionInitializerAndType(variableType, initializer));
            suppressLeadingAndTrailingTrivia(initializer);
            const changeTracker = ts_textChanges_exports.ChangeTracker.fromContext(context);
            if (isClassLike(scope)) {
                Debug.assert(!isJS, "Cannot extract to a JS class");
                const modifiers = [];
                modifiers.push(factory.createModifier(121 /* PrivateKeyword */));
                if (rangeFacts & 32 /* InStaticRegion */) {
                    modifiers.push(factory.createModifier(124 /* StaticKeyword */));
                }
                modifiers.push(factory.createModifier(146 /* ReadonlyKeyword */));
                const newVariable = factory.createPropertyDeclaration(modifiers, localNameText, 
                /*questionToken*/
                void 0, variableType, initializer);
                let localReference = factory.createPropertyAccessExpression(rangeFacts & 32 /* InStaticRegion */ ? factory.createIdentifier(scope.name.getText()) : factory.createThis(), factory.createIdentifier(localNameText));
                if (isInJSXContent(node)) {
                    localReference = factory.createJsxExpression(
                    /*dotDotDotToken*/
                    void 0, localReference);
                }
                const maxInsertionPos = node.pos;
                const nodeToInsertBefore = getNodeToInsertPropertyBefore(maxInsertionPos, scope);
                changeTracker.insertNodeBefore(context.file, nodeToInsertBefore, newVariable, 
                /*blankLineBetween*/
                true);
                changeTracker.replaceNode(context.file, node, localReference);
            }
            else {
                const newVariableDeclaration = factory.createVariableDeclaration(localNameText, 
                /*exclamationToken*/
                void 0, variableType, initializer);
                const oldVariableDeclaration = getContainingVariableDeclarationIfInList(node, scope);
                if (oldVariableDeclaration) {
                    changeTracker.insertNodeBefore(context.file, oldVariableDeclaration, newVariableDeclaration);
                    const localReference = factory.createIdentifier(localNameText);
                    changeTracker.replaceNode(context.file, node, localReference);
                }
                else if (node.parent.kind === 241 /* ExpressionStatement */ && scope === findAncestor(node, isScope)) {
                    const newVariableStatement = factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([newVariableDeclaration], 2 /* Const */));
                    changeTracker.replaceNode(context.file, node.parent, newVariableStatement);
                }
                else {
                    const newVariableStatement = factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([newVariableDeclaration], 2 /* Const */));
                    const nodeToInsertBefore = getNodeToInsertConstantBefore(node, scope);
                    if (nodeToInsertBefore.pos === 0) {
                        changeTracker.insertNodeAtTopOfFile(context.file, newVariableStatement, 
                        /*blankLineBetween*/
                        false);
                    }
                    else {
                        changeTracker.insertNodeBefore(context.file, nodeToInsertBefore, newVariableStatement, 
                        /*blankLineBetween*/
                        false);
                    }
                    if (node.parent.kind === 241 /* ExpressionStatement */) {
                        changeTracker.delete(context.file, node.parent);
                    }
                    else {
                        let localReference = factory.createIdentifier(localNameText);
                        if (isInJSXContent(node)) {
                            localReference = factory.createJsxExpression(
                            /*dotDotDotToken*/
                            void 0, localReference);
                        }
                        changeTracker.replaceNode(context.file, node, localReference);
                    }
                }
            }
            const edits = changeTracker.getChanges();
            const renameFilename = node.getSourceFile().fileName;
            const renameLocation = getRenameLocation(edits, renameFilename, localNameText, 
            /*isDeclaredBeforeUse*/
            true);
            return { renameFilename, renameLocation, edits };
            function transformFunctionInitializerAndType(variableType2, initializer2) {
                if (variableType2 === void 0)
                    return { variableType: variableType2, initializer: initializer2 };
                if (!isFunctionExpression(initializer2) && !isArrowFunction(initializer2) || !!initializer2.typeParameters)
                    return { variableType: variableType2, initializer: initializer2 };
                const functionType = checker.getTypeAtLocation(node);
                const functionSignature = singleOrUndefined(checker.getSignaturesOfType(functionType, 0 /* Call */));
                if (!functionSignature)
                    return { variableType: variableType2, initializer: initializer2 };
                if (!!functionSignature.getTypeParameters())
                    return { variableType: variableType2, initializer: initializer2 };
                const parameters = [];
                let hasAny = false;
                for (const p of initializer2.parameters) {
                    if (p.type) {
                        parameters.push(p);
                    }
                    else {
                        const paramType = checker.getTypeAtLocation(p);
                        if (paramType === checker.getAnyType())
                            hasAny = true;
                        parameters.push(factory.updateParameterDeclaration(p, p.modifiers, p.dotDotDotToken, p.name, p.questionToken, p.type || checker.typeToTypeNode(paramType, scope, 1 /* NoTruncation */), p.initializer));
                    }
                }
                if (hasAny)
                    return { variableType: variableType2, initializer: initializer2 };
                variableType2 = void 0;
                if (isArrowFunction(initializer2)) {
                    initializer2 = factory.updateArrowFunction(initializer2, canHaveModifiers(node) ? getModifiers(node) : void 0, initializer2.typeParameters, parameters, initializer2.type || checker.typeToTypeNode(functionSignature.getReturnType(), scope, 1 /* NoTruncation */), initializer2.equalsGreaterThanToken, initializer2.body);
                }
                else {
                    if (functionSignature && !!functionSignature.thisParameter) {
                        const firstParameter = firstOrUndefined(parameters);
                        if (!firstParameter || isIdentifier(firstParameter.name) && firstParameter.name.escapedText !== "this") {
                            const thisType = checker.getTypeOfSymbolAtLocation(functionSignature.thisParameter, node);
                            parameters.splice(0, 0, factory.createParameterDeclaration(
                            /* modifiers */
                            void 0, 
                            /* dotDotDotToken */
                            void 0, "this", 
                            /* questionToken */
                            void 0, checker.typeToTypeNode(thisType, scope, 1 /* NoTruncation */)));
                        }
                    }
                    initializer2 = factory.updateFunctionExpression(initializer2, canHaveModifiers(node) ? getModifiers(node) : void 0, initializer2.asteriskToken, initializer2.name, initializer2.typeParameters, parameters, initializer2.type || checker.typeToTypeNode(functionSignature.getReturnType(), scope, 1 /* NoTruncation */), initializer2.body);
                }
                return { variableType: variableType2, initializer: initializer2 };
            }
        }
        function getContainingVariableDeclarationIfInList(node, scope) {
            let prevNode;
            while (node !== void 0 && node !== scope) {
                if (isVariableDeclaration(node) && node.initializer === prevNode && isVariableDeclarationList(node.parent) && node.parent.declarations.length > 1) {
                    return node;
                }
                prevNode = node;
                node = node.parent;
            }
        }
        function getFirstDeclaration(type) {
            let firstDeclaration;
            const symbol = type.symbol;
            if (symbol && symbol.declarations) {
                for (const declaration of symbol.declarations) {
                    if (firstDeclaration === void 0 || declaration.pos < firstDeclaration.pos) {
                        firstDeclaration = declaration;
                    }
                }
            }
            return firstDeclaration;
        }
        function compareTypesByDeclarationOrder({ type: type1, declaration: declaration1 }, { type: type2, declaration: declaration2 }) {
            return compareProperties(declaration1, declaration2, "pos", compareValues) || compareStringsCaseSensitive(type1.symbol ? type1.symbol.getName() : "", type2.symbol ? type2.symbol.getName() : "") || compareValues(type1.id, type2.id);
        }
        function getCalledExpression(scope, range, functionNameText) {
            const functionReference = factory.createIdentifier(functionNameText);
            if (isClassLike(scope)) {
                const lhs = range.facts & 32 /* InStaticRegion */ ? factory.createIdentifier(scope.name.text) : factory.createThis();
                return factory.createPropertyAccessExpression(lhs, functionReference);
            }
            else {
                return functionReference;
            }
        }
        function transformFunctionBody(body, exposedVariableDeclarations, writes, substitutions, hasReturn2) {
            const hasWritesOrVariableDeclarations = writes !== void 0 || exposedVariableDeclarations.length > 0;
            if (isBlock(body) && !hasWritesOrVariableDeclarations && substitutions.size === 0) {
                return { body: factory.createBlock(body.statements, 
                    /*multLine*/
                    true), returnValueProperty: void 0 };
            }
            let returnValueProperty;
            let ignoreReturns = false;
            const statements = factory.createNodeArray(isBlock(body) ? body.statements.slice(0) : [isStatement(body) ? body : factory.createReturnStatement(skipParentheses(body))]);
            if (hasWritesOrVariableDeclarations || substitutions.size) {
                const rewrittenStatements = visitNodes2(statements, visitor, isStatement).slice();
                if (hasWritesOrVariableDeclarations && !hasReturn2 && isStatement(body)) {
                    const assignments = getPropertyAssignmentsForWritesAndVariableDeclarations(exposedVariableDeclarations, writes);
                    if (assignments.length === 1) {
                        rewrittenStatements.push(factory.createReturnStatement(assignments[0].name));
                    }
                    else {
                        rewrittenStatements.push(factory.createReturnStatement(factory.createObjectLiteralExpression(assignments)));
                    }
                }
                return { body: factory.createBlock(rewrittenStatements, 
                    /*multiLine*/
                    true), returnValueProperty };
            }
            else {
                return { body: factory.createBlock(statements, 
                    /*multiLine*/
                    true), returnValueProperty: void 0 };
            }
            function visitor(node) {
                if (!ignoreReturns && isReturnStatement(node) && hasWritesOrVariableDeclarations) {
                    const assignments = getPropertyAssignmentsForWritesAndVariableDeclarations(exposedVariableDeclarations, writes);
                    if (node.expression) {
                        if (!returnValueProperty) {
                            returnValueProperty = "__return";
                        }
                        assignments.unshift(factory.createPropertyAssignment(returnValueProperty, visitNode(node.expression, visitor, isExpression)));
                    }
                    if (assignments.length === 1) {
                        return factory.createReturnStatement(assignments[0].name);
                    }
                    else {
                        return factory.createReturnStatement(factory.createObjectLiteralExpression(assignments));
                    }
                }
                else {
                    const oldIgnoreReturns = ignoreReturns;
                    ignoreReturns = ignoreReturns || isFunctionLikeDeclaration(node) || isClassLike(node);
                    const substitution = substitutions.get(getNodeId(node).toString());
                    const result = substitution ? getSynthesizedDeepClone(substitution) : visitEachChild(node, visitor, nullTransformationContext);
                    ignoreReturns = oldIgnoreReturns;
                    return result;
                }
            }
        }
        function transformConstantInitializer(initializer, substitutions) {
            return substitutions.size ? visitor(initializer) : initializer;
            function visitor(node) {
                const substitution = substitutions.get(getNodeId(node).toString());
                return substitution ? getSynthesizedDeepClone(substitution) : visitEachChild(node, visitor, nullTransformationContext);
            }
        }
        function getStatementsOrClassElements(scope) {
            if (isFunctionLikeDeclaration(scope)) {
                const body = scope.body;
                if (isBlock(body)) {
                    return body.statements;
                }
            }
            else if (isModuleBlock(scope) || isSourceFile(scope)) {
                return scope.statements;
            }
            else if (isClassLike(scope)) {
                return scope.members;
            }
            else {
                assertType(scope);
            }
            return emptyArray;
        }
        function getNodeToInsertFunctionBefore(minPos, scope) {
            return find(getStatementsOrClassElements(scope), (child) => child.pos >= minPos && isFunctionLikeDeclaration(child) && !isConstructorDeclaration(child));
        }
        function getNodeToInsertPropertyBefore(maxPos, scope) {
            const members = scope.members;
            Debug.assert(members.length > 0, "Found no members");
            let prevMember;
            let allProperties = true;
            for (const member of members) {
                if (member.pos > maxPos) {
                    return prevMember || members[0];
                }
                if (allProperties && !isPropertyDeclaration(member)) {
                    if (prevMember !== void 0) {
                        return member;
                    }
                    allProperties = false;
                }
                prevMember = member;
            }
            if (prevMember === void 0)
                return Debug.fail();
            return prevMember;
        }
        function getNodeToInsertConstantBefore(node, scope) {
            Debug.assert(!isClassLike(scope));
            let prevScope;
            for (let curr = node; curr !== scope; curr = curr.parent) {
                if (isScope(curr)) {
                    prevScope = curr;
                }
            }
            for (let curr = (prevScope || node).parent;; curr = curr.parent) {
                if (isBlockLike(curr)) {
                    let prevStatement;
                    for (const statement of curr.statements) {
                        if (statement.pos > node.pos) {
                            break;
                        }
                        prevStatement = statement;
                    }
                    if (!prevStatement && isCaseClause(curr)) {
                        Debug.assert(isSwitchStatement(curr.parent.parent), "Grandparent isn't a switch statement");
                        return curr.parent.parent;
                    }
                    return Debug.checkDefined(prevStatement, "prevStatement failed to get set");
                }
                Debug.assert(curr !== scope, "Didn't encounter a block-like before encountering scope");
            }
        }
        function getPropertyAssignmentsForWritesAndVariableDeclarations(exposedVariableDeclarations, writes) {
            const variableAssignments = map(exposedVariableDeclarations, (v) => factory.createShorthandPropertyAssignment(v.symbol.name));
            const writeAssignments = map(writes, (w) => factory.createShorthandPropertyAssignment(w.symbol.name));
            return variableAssignments === void 0 ? writeAssignments : writeAssignments === void 0 ? variableAssignments : variableAssignments.concat(writeAssignments);
        }
        function isReadonlyArray(v) {
            return isArray(v);
        }
        function getEnclosingTextRange(targetRange, sourceFile) {
            return isReadonlyArray(targetRange.range) ? { pos: first(targetRange.range).getStart(sourceFile), end: last(targetRange.range).getEnd() } : targetRange.range;
        }
        function collectReadsAndWrites(targetRange, scopes, enclosingTextRange, sourceFile, checker, cancellationToken) {
            const allTypeParameterUsages = /* @__PURE__ */ new Map();
            const usagesPerScope = [];
            const substitutionsPerScope = [];
            const functionErrorsPerScope = [];
            const constantErrorsPerScope = [];
            const visibleDeclarationsInExtractedRange = [];
            const exposedVariableSymbolSet = /* @__PURE__ */ new Map();
            const exposedVariableDeclarations = [];
            let firstExposedNonVariableDeclaration;
            const expression = !isReadonlyArray(targetRange.range) ? targetRange.range : targetRange.range.length === 1 && isExpressionStatement(targetRange.range[0]) ? targetRange.range[0].expression : void 0;
            let expressionDiagnostic;
            if (expression === void 0) {
                const statements = targetRange.range;
                const start = first(statements).getStart();
                const end = last(statements).end;
                expressionDiagnostic = createFileDiagnostic(sourceFile, start, end - start, Messages.expressionExpected);
            }
            else if (checker.getTypeAtLocation(expression).flags & (16384 /* Void */ | 131072 /* Never */)) {
                expressionDiagnostic = createDiagnosticForNode(expression, Messages.uselessConstantType);
            }
            for (const scope of scopes) {
                usagesPerScope.push({ usages: /* @__PURE__ */ new Map(), typeParameterUsages: /* @__PURE__ */ new Map(), substitutions: /* @__PURE__ */ new Map() });
                substitutionsPerScope.push(/* @__PURE__ */ new Map());
                functionErrorsPerScope.push([]);
                const constantErrors = [];
                if (expressionDiagnostic) {
                    constantErrors.push(expressionDiagnostic);
                }
                if (isClassLike(scope) && isInJSFile(scope)) {
                    constantErrors.push(createDiagnosticForNode(scope, Messages.cannotExtractToJSClass));
                }
                if (isArrowFunction(scope) && !isBlock(scope.body)) {
                    constantErrors.push(createDiagnosticForNode(scope, Messages.cannotExtractToExpressionArrowFunction));
                }
                constantErrorsPerScope.push(constantErrors);
            }
            const seenUsages = /* @__PURE__ */ new Map();
            const target = isReadonlyArray(targetRange.range) ? factory.createBlock(targetRange.range) : targetRange.range;
            const unmodifiedNode = isReadonlyArray(targetRange.range) ? first(targetRange.range) : targetRange.range;
            const inGenericContext = isInGenericContext(unmodifiedNode);
            collectUsages(target);
            if (inGenericContext && !isReadonlyArray(targetRange.range) && !isJsxAttribute(targetRange.range)) {
                const contextualType = checker.getContextualType(targetRange.range);
                recordTypeParameterUsages(contextualType);
            }
            if (allTypeParameterUsages.size > 0) {
                const seenTypeParameterUsages = /* @__PURE__ */ new Map();
                let i = 0;
                for (let curr = unmodifiedNode; curr !== void 0 && i < scopes.length; curr = curr.parent) {
                    if (curr === scopes[i]) {
                        seenTypeParameterUsages.forEach((typeParameter, id) => {
                            usagesPerScope[i].typeParameterUsages.set(id, typeParameter);
                        });
                        i++;
                    }
                    if (isDeclarationWithTypeParameters(curr)) {
                        for (const typeParameterDecl of getEffectiveTypeParameterDeclarations(curr)) {
                            const typeParameter = checker.getTypeAtLocation(typeParameterDecl);
                            if (allTypeParameterUsages.has(typeParameter.id.toString())) {
                                seenTypeParameterUsages.set(typeParameter.id.toString(), typeParameter);
                            }
                        }
                    }
                }
                Debug.assert(i === scopes.length, "Should have iterated all scopes");
            }
            if (visibleDeclarationsInExtractedRange.length) {
                const containingLexicalScopeOfExtraction = isBlockScope(scopes[0], scopes[0].parent) ? scopes[0] : getEnclosingBlockScopeContainer(scopes[0]);
                forEachChild(containingLexicalScopeOfExtraction, checkForUsedDeclarations);
            }
            for (let i = 0; i < scopes.length; i++) {
                const scopeUsages = usagesPerScope[i];
                if (i > 0 && (scopeUsages.usages.size > 0 || scopeUsages.typeParameterUsages.size > 0)) {
                    const errorNode = isReadonlyArray(targetRange.range) ? targetRange.range[0] : targetRange.range;
                    constantErrorsPerScope[i].push(createDiagnosticForNode(errorNode, Messages.cannotAccessVariablesFromNestedScopes));
                }
                if (targetRange.facts & 16 /* UsesThisInFunction */ && isClassLike(scopes[i])) {
                    functionErrorsPerScope[i].push(createDiagnosticForNode(targetRange.thisNode, Messages.cannotExtractFunctionsContainingThisToMethod));
                }
                let hasWrite = false;
                let readonlyClassPropertyWrite;
                usagesPerScope[i].usages.forEach((value) => {
                    if (value.usage === 2 /* Write */) {
                        hasWrite = true;
                        if (value.symbol.flags & 106500 /* ClassMember */ && value.symbol.valueDeclaration && hasEffectiveModifier(value.symbol.valueDeclaration, 64 /* Readonly */)) {
                            readonlyClassPropertyWrite = value.symbol.valueDeclaration;
                        }
                    }
                });
                Debug.assert(isReadonlyArray(targetRange.range) || exposedVariableDeclarations.length === 0, "No variable declarations expected if something was extracted");
                if (hasWrite && !isReadonlyArray(targetRange.range)) {
                    const diag2 = createDiagnosticForNode(targetRange.range, Messages.cannotWriteInExpression);
                    functionErrorsPerScope[i].push(diag2);
                    constantErrorsPerScope[i].push(diag2);
                }
                else if (readonlyClassPropertyWrite && i > 0) {
                    const diag2 = createDiagnosticForNode(readonlyClassPropertyWrite, Messages.cannotExtractReadonlyPropertyInitializerOutsideConstructor);
                    functionErrorsPerScope[i].push(diag2);
                    constantErrorsPerScope[i].push(diag2);
                }
                else if (firstExposedNonVariableDeclaration) {
                    const diag2 = createDiagnosticForNode(firstExposedNonVariableDeclaration, Messages.cannotExtractExportedEntity);
                    functionErrorsPerScope[i].push(diag2);
                    constantErrorsPerScope[i].push(diag2);
                }
            }
            return { target, usagesPerScope, functionErrorsPerScope, constantErrorsPerScope, exposedVariableDeclarations };
            function isInGenericContext(node) {
                return !!findAncestor(node, (n) => isDeclarationWithTypeParameters(n) && getEffectiveTypeParameterDeclarations(n).length !== 0);
            }
            function recordTypeParameterUsages(type) {
                const symbolWalker = checker.getSymbolWalker(() => (cancellationToken.throwIfCancellationRequested(), true));
                const { visitedTypes } = symbolWalker.walkType(type);
                for (const visitedType of visitedTypes) {
                    if (visitedType.isTypeParameter()) {
                        allTypeParameterUsages.set(visitedType.id.toString(), visitedType);
                    }
                }
            }
            function collectUsages(node, valueUsage = 1 /* Read */) {
                if (inGenericContext) {
                    const type = checker.getTypeAtLocation(node);
                    recordTypeParameterUsages(type);
                }
                if (isDeclaration(node) && node.symbol) {
                    visibleDeclarationsInExtractedRange.push(node);
                }
                if (isAssignmentExpression(node)) {
                    collectUsages(node.left, 2 /* Write */);
                    collectUsages(node.right);
                }
                else if (isUnaryExpressionWithWrite(node)) {
                    collectUsages(node.operand, 2 /* Write */);
                }
                else if (isPropertyAccessExpression(node) || isElementAccessExpression(node)) {
                    forEachChild(node, collectUsages);
                }
                else if (isIdentifier(node)) {
                    if (!node.parent) {
                        return;
                    }
                    if (isQualifiedName(node.parent) && node !== node.parent.left) {
                        return;
                    }
                    if (isPropertyAccessExpression(node.parent) && node !== node.parent.expression) {
                        return;
                    }
                    recordUsage(node, valueUsage, 
                    /*isTypeNode*/
                    isPartOfTypeNode(node));
                }
                else {
                    forEachChild(node, collectUsages);
                }
            }
            function recordUsage(n, usage, isTypeNode2) {
                const symbolId = recordUsagebySymbol(n, usage, isTypeNode2);
                if (symbolId) {
                    for (let i = 0; i < scopes.length; i++) {
                        const substitution = substitutionsPerScope[i].get(symbolId);
                        if (substitution) {
                            usagesPerScope[i].substitutions.set(getNodeId(n).toString(), substitution);
                        }
                    }
                }
            }
            function recordUsagebySymbol(identifier, usage, isTypeName) {
                const symbol = getSymbolReferencedByIdentifier(identifier);
                if (!symbol) {
                    return void 0;
                }
                const symbolId = getSymbolId(symbol).toString();
                const lastUsage = seenUsages.get(symbolId);
                if (lastUsage && lastUsage >= usage) {
                    return symbolId;
                }
                seenUsages.set(symbolId, usage);
                if (lastUsage) {
                    for (const perScope of usagesPerScope) {
                        const prevEntry = perScope.usages.get(identifier.text);
                        if (prevEntry) {
                            perScope.usages.set(identifier.text, { usage, symbol, node: identifier });
                        }
                    }
                    return symbolId;
                }
                const decls = symbol.getDeclarations();
                const declInFile = decls && find(decls, (d) => d.getSourceFile() === sourceFile);
                if (!declInFile) {
                    return void 0;
                }
                if (rangeContainsStartEnd(enclosingTextRange, declInFile.getStart(), declInFile.end)) {
                    return void 0;
                }
                if (targetRange.facts & 2 /* IsGenerator */ && usage === 2 /* Write */) {
                    const diag2 = createDiagnosticForNode(identifier, Messages.cannotExtractRangeThatContainsWritesToReferencesLocatedOutsideOfTheTargetRangeInGenerators);
                    for (const errors of functionErrorsPerScope) {
                        errors.push(diag2);
                    }
                    for (const errors of constantErrorsPerScope) {
                        errors.push(diag2);
                    }
                }
                for (let i = 0; i < scopes.length; i++) {
                    const scope = scopes[i];
                    const resolvedSymbol = checker.resolveName(symbol.name, scope, symbol.flags, 
                    /*excludeGlobals*/
                    false);
                    if (resolvedSymbol === symbol) {
                        continue;
                    }
                    if (!substitutionsPerScope[i].has(symbolId)) {
                        const substitution = tryReplaceWithQualifiedNameOrPropertyAccess(symbol.exportSymbol || symbol, scope, isTypeName);
                        if (substitution) {
                            substitutionsPerScope[i].set(symbolId, substitution);
                        }
                        else if (isTypeName) {
                            if (!(symbol.flags & 262144 /* TypeParameter */)) {
                                const diag2 = createDiagnosticForNode(identifier, Messages.typeWillNotBeVisibleInTheNewScope);
                                functionErrorsPerScope[i].push(diag2);
                                constantErrorsPerScope[i].push(diag2);
                            }
                        }
                        else {
                            usagesPerScope[i].usages.set(identifier.text, { usage, symbol, node: identifier });
                        }
                    }
                }
                return symbolId;
            }
            function checkForUsedDeclarations(node) {
                if (node === targetRange.range || isReadonlyArray(targetRange.range) && targetRange.range.indexOf(node) >= 0) {
                    return;
                }
                const sym = isIdentifier(node) ? getSymbolReferencedByIdentifier(node) : checker.getSymbolAtLocation(node);
                if (sym) {
                    const decl = find(visibleDeclarationsInExtractedRange, (d) => d.symbol === sym);
                    if (decl) {
                        if (isVariableDeclaration(decl)) {
                            const idString = decl.symbol.id.toString();
                            if (!exposedVariableSymbolSet.has(idString)) {
                                exposedVariableDeclarations.push(decl);
                                exposedVariableSymbolSet.set(idString, true);
                            }
                        }
                        else {
                            firstExposedNonVariableDeclaration = firstExposedNonVariableDeclaration || decl;
                        }
                    }
                }
                forEachChild(node, checkForUsedDeclarations);
            }
            function getSymbolReferencedByIdentifier(identifier) {
                return identifier.parent && isShorthandPropertyAssignment(identifier.parent) && identifier.parent.name === identifier ? checker.getShorthandAssignmentValueSymbol(identifier.parent) : checker.getSymbolAtLocation(identifier);
            }
            function tryReplaceWithQualifiedNameOrPropertyAccess(symbol, scopeDecl, isTypeNode2) {
                if (!symbol) {
                    return void 0;
                }
                const decls = symbol.getDeclarations();
                if (decls && decls.some((d) => d.parent === scopeDecl)) {
                    return factory.createIdentifier(symbol.name);
                }
                const prefix = tryReplaceWithQualifiedNameOrPropertyAccess(symbol.parent, scopeDecl, isTypeNode2);
                if (prefix === void 0) {
                    return void 0;
                }
                return isTypeNode2 ? factory.createQualifiedName(prefix, factory.createIdentifier(symbol.name)) : factory.createPropertyAccessExpression(prefix, symbol.name);
            }
        }
        function getExtractableParent(node) {
            return findAncestor(node, (node2) => node2.parent && isExtractableExpression(node2) && !isBinaryExpression(node2.parent));
        }
        function isExtractableExpression(node) {
            const { parent: parent2 } = node;
            switch (parent2.kind) {
                case 302 /* EnumMember */:
                    return false;
            }
            switch (node.kind) {
                case 10 /* StringLiteral */:
                    return parent2.kind !== 269 /* ImportDeclaration */ && parent2.kind !== 273 /* ImportSpecifier */;
                case 227 /* SpreadElement */:
                case 203 /* ObjectBindingPattern */:
                case 205 /* BindingElement */:
                    return false;
                case 79 /* Identifier */:
                    return parent2.kind !== 205 /* BindingElement */ && parent2.kind !== 273 /* ImportSpecifier */ && parent2.kind !== 278 /* ExportSpecifier */;
            }
            return true;
        }
        function isBlockLike(node) {
            switch (node.kind) {
                case 238 /* Block */:
                case 308 /* SourceFile */:
                case 265 /* ModuleBlock */:
                case 292 /* CaseClause */:
                    return true;
                default:
                    return false;
            }
        }
        function isInJSXContent(node) {
            return isStringLiteralJsxAttribute(node) || (isJsxElement(node) || isJsxSelfClosingElement(node) || isJsxFragment(node)) && (isJsxElement(node.parent) || isJsxFragment(node.parent));
        }
        function isStringLiteralJsxAttribute(node) {
            return isStringLiteral(node) && node.parent && isJsxAttribute(node.parent);
        }
        var refactorName11, extractConstantAction, extractFunctionAction, Messages, RangeFacts;
        var init_extractSymbol = __esm({
            "src/services/refactors/extractSymbol.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName11 = "Extract Symbol";
                extractConstantAction = {
                    name: "Extract Constant",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_constant),
                    kind: "refactor.extract.constant"
                };
                extractFunctionAction = {
                    name: "Extract Function",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_function),
                    kind: "refactor.extract.function"
                };
                registerRefactor(refactorName11, {
                    kinds: [
                        extractConstantAction.kind,
                        extractFunctionAction.kind
                    ],
                    getEditsForAction: getRefactorEditsToExtractSymbol,
                    getAvailableActions: getRefactorActionsToExtractSymbol
                });
                ((Messages2) => {
                    function createMessage(message) {
                        return { message, code: 0, category: 3 /* Message */, key: message };
                    }
                    Messages2.cannotExtractRange = createMessage("Cannot extract range.");
                    Messages2.cannotExtractImport = createMessage("Cannot extract import statement.");
                    Messages2.cannotExtractSuper = createMessage("Cannot extract super call.");
                    Messages2.cannotExtractJSDoc = createMessage("Cannot extract JSDoc.");
                    Messages2.cannotExtractEmpty = createMessage("Cannot extract empty range.");
                    Messages2.expressionExpected = createMessage("expression expected.");
                    Messages2.uselessConstantType = createMessage("No reason to extract constant of type.");
                    Messages2.statementOrExpressionExpected = createMessage("Statement or expression expected.");
                    Messages2.cannotExtractRangeContainingConditionalBreakOrContinueStatements = createMessage("Cannot extract range containing conditional break or continue statements.");
                    Messages2.cannotExtractRangeContainingConditionalReturnStatement = createMessage("Cannot extract range containing conditional return statement.");
                    Messages2.cannotExtractRangeContainingLabeledBreakOrContinueStatementWithTargetOutsideOfTheRange = createMessage("Cannot extract range containing labeled break or continue with target outside of the range.");
                    Messages2.cannotExtractRangeThatContainsWritesToReferencesLocatedOutsideOfTheTargetRangeInGenerators = createMessage("Cannot extract range containing writes to references located outside of the target range in generators.");
                    Messages2.typeWillNotBeVisibleInTheNewScope = createMessage("Type will not visible in the new scope.");
                    Messages2.functionWillNotBeVisibleInTheNewScope = createMessage("Function will not visible in the new scope.");
                    Messages2.cannotExtractIdentifier = createMessage("Select more than a single identifier.");
                    Messages2.cannotExtractExportedEntity = createMessage("Cannot extract exported declaration");
                    Messages2.cannotWriteInExpression = createMessage("Cannot write back side-effects when extracting an expression");
                    Messages2.cannotExtractReadonlyPropertyInitializerOutsideConstructor = createMessage("Cannot move initialization of read-only class property outside of the constructor");
                    Messages2.cannotExtractAmbientBlock = createMessage("Cannot extract code from ambient contexts");
                    Messages2.cannotAccessVariablesFromNestedScopes = createMessage("Cannot access variables from nested scopes");
                    Messages2.cannotExtractToJSClass = createMessage("Cannot extract constant to a class scope in JS");
                    Messages2.cannotExtractToExpressionArrowFunction = createMessage("Cannot extract constant to an arrow function without a block");
                    Messages2.cannotExtractFunctionsContainingThisToMethod = createMessage("Cannot extract functions containing this to method");
                })(Messages || (Messages = {}));
                RangeFacts = /* @__PURE__ */ ((RangeFacts2) => {
                    RangeFacts2[RangeFacts2["None"] = 0] = "None";
                    RangeFacts2[RangeFacts2["HasReturn"] = 1] = "HasReturn";
                    RangeFacts2[RangeFacts2["IsGenerator"] = 2] = "IsGenerator";
                    RangeFacts2[RangeFacts2["IsAsyncFunction"] = 4] = "IsAsyncFunction";
                    RangeFacts2[RangeFacts2["UsesThis"] = 8] = "UsesThis";
                    RangeFacts2[RangeFacts2["UsesThisInFunction"] = 16] = "UsesThisInFunction";
                    RangeFacts2[RangeFacts2["InStaticRegion"] = 32] = "InStaticRegion";
                    return RangeFacts2;
                })(RangeFacts || {});
            }
        });
        // src/services/_namespaces/ts.refactor.extractSymbol.ts
        var ts_refactor_extractSymbol_exports = {};
        __export(ts_refactor_extractSymbol_exports, {
            Messages: () => Messages,
            RangeFacts: () => RangeFacts,
            getRangeToExtract: () => getRangeToExtract2,
            getRefactorActionsToExtractSymbol: () => getRefactorActionsToExtractSymbol,
            getRefactorEditsToExtractSymbol: () => getRefactorEditsToExtractSymbol
        });
        var init_ts_refactor_extractSymbol = __esm({
            "src/services/_namespaces/ts.refactor.extractSymbol.ts"() {
                "use strict";
                init_extractSymbol();
            }
        });
        // src/services/refactors/generateGetAccessorAndSetAccessor.ts
        var actionName, actionDescription, generateGetSetAction;
        var init_generateGetAccessorAndSetAccessor = __esm({
            "src/services/refactors/generateGetAccessorAndSetAccessor.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                actionName = "Generate 'get' and 'set' accessors";
                actionDescription = Diagnostics.Generate_get_and_set_accessors.message;
                generateGetSetAction = {
                    name: actionName,
                    description: actionDescription,
                    kind: "refactor.rewrite.property.generateAccessors"
                };
                registerRefactor(actionName, {
                    kinds: [generateGetSetAction.kind],
                    getEditsForAction: function getRefactorActionsToGenerateGetAndSetAccessors(context, actionName2) {
                        if (!context.endPosition)
                            return void 0;
                        const info = ts_codefix_exports.getAccessorConvertiblePropertyAtPosition(context.file, context.program, context.startPosition, context.endPosition);
                        Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
                        const edits = ts_codefix_exports.generateAccessorFromProperty(context.file, context.program, context.startPosition, context.endPosition, context, actionName2);
                        if (!edits)
                            return void 0;
                        const renameFilename = context.file.fileName;
                        const nameNeedRename = info.renameAccessor ? info.accessorName : info.fieldName;
                        const renameLocationOffset = isIdentifier(nameNeedRename) ? 0 : -1;
                        const renameLocation = renameLocationOffset + getRenameLocation(edits, renameFilename, nameNeedRename.text, 
                        /*preferLastLocation*/
                        isParameter(info.declaration));
                        return { renameFilename, renameLocation, edits };
                    },
                    getAvailableActions(context) {
                        if (!context.endPosition)
                            return emptyArray;
                        const info = ts_codefix_exports.getAccessorConvertiblePropertyAtPosition(context.file, context.program, context.startPosition, context.endPosition, context.triggerReason === "invoked");
                        if (!info)
                            return emptyArray;
                        if (!isRefactorErrorInfo(info)) {
                            return [{
                                    name: actionName,
                                    description: actionDescription,
                                    actions: [generateGetSetAction]
                                }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return [{
                                    name: actionName,
                                    description: actionDescription,
                                    actions: [{ ...generateGetSetAction, notApplicableReason: info.error }]
                                }];
                        }
                        return emptyArray;
                    }
                });
            }
        });
        // src/services/_namespaces/ts.refactor.generateGetAccessorAndSetAccessor.ts
        var ts_refactor_generateGetAccessorAndSetAccessor_exports = {};
        var init_ts_refactor_generateGetAccessorAndSetAccessor = __esm({
            "src/services/_namespaces/ts.refactor.generateGetAccessorAndSetAccessor.ts"() {
                "use strict";
                init_generateGetAccessorAndSetAccessor();
            }
        });
        // src/services/refactors/inferFunctionReturnType.ts
        function getRefactorEditsToInferReturnType(context) {
            const info = getInfo21(context);
            if (info && !isRefactorErrorInfo(info)) {
                const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange38(context.file, t, info.declaration, info.returnTypeNode));
                return { renameFilename: void 0, renameLocation: void 0, edits };
            }
            return void 0;
        }
        function getRefactorActionsToInferReturnType(context) {
            const info = getInfo21(context);
            if (!info)
                return emptyArray;
            if (!isRefactorErrorInfo(info)) {
                return [{
                        name: refactorName12,
                        description: refactorDescription6,
                        actions: [inferReturnTypeAction]
                    }];
            }
            if (context.preferences.provideRefactorNotApplicableReason) {
                return [{
                        name: refactorName12,
                        description: refactorDescription6,
                        actions: [{ ...inferReturnTypeAction, notApplicableReason: info.error }]
                    }];
            }
            return emptyArray;
        }
        function doChange38(sourceFile, changes, declaration, typeNode) {
            const closeParen = findChildOfKind(declaration, 21 /* CloseParenToken */, sourceFile);
            const needParens = isArrowFunction(declaration) && closeParen === void 0;
            const endNode2 = needParens ? first(declaration.parameters) : closeParen;
            if (endNode2) {
                if (needParens) {
                    changes.insertNodeBefore(sourceFile, endNode2, factory.createToken(20 /* OpenParenToken */));
                    changes.insertNodeAfter(sourceFile, endNode2, factory.createToken(21 /* CloseParenToken */));
                }
                changes.insertNodeAt(sourceFile, endNode2.end, typeNode, { prefix: ": " });
            }
        }
        function getInfo21(context) {
            if (isInJSFile(context.file) || !refactorKindBeginsWith(inferReturnTypeAction.kind, context.kind))
                return;
            const token = getTokenAtPosition(context.file, context.startPosition);
            const declaration = findAncestor(token, (n) => isBlock(n) || n.parent && isArrowFunction(n.parent) && (n.kind === 38 /* EqualsGreaterThanToken */ || n.parent.body === n) ? "quit" : isConvertibleDeclaration(n));
            if (!declaration || !declaration.body || declaration.type) {
                return { error: getLocaleSpecificMessage(Diagnostics.Return_type_must_be_inferred_from_a_function) };
            }
            const typeChecker = context.program.getTypeChecker();
            const returnType = tryGetReturnType(typeChecker, declaration);
            if (!returnType) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_determine_function_return_type) };
            }
            const returnTypeNode = typeChecker.typeToTypeNode(returnType, declaration, 1 /* NoTruncation */);
            if (returnTypeNode) {
                return { declaration, returnTypeNode };
            }
        }
        function isConvertibleDeclaration(node) {
            switch (node.kind) {
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                case 171 /* MethodDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function tryGetReturnType(typeChecker, node) {
            if (typeChecker.isImplementationOfOverload(node)) {
                const signatures = typeChecker.getTypeAtLocation(node).getCallSignatures();
                if (signatures.length > 1) {
                    return typeChecker.getUnionType(mapDefined(signatures, (s) => s.getReturnType()));
                }
            }
            const signature = typeChecker.getSignatureFromDeclaration(node);
            if (signature) {
                return typeChecker.getReturnTypeOfSignature(signature);
            }
        }
        var refactorName12, refactorDescription6, inferReturnTypeAction;
        var init_inferFunctionReturnType = __esm({
            "src/services/refactors/inferFunctionReturnType.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName12 = "Infer function return type";
                refactorDescription6 = Diagnostics.Infer_function_return_type.message;
                inferReturnTypeAction = {
                    name: refactorName12,
                    description: refactorDescription6,
                    kind: "refactor.rewrite.function.returnType"
                };
                registerRefactor(refactorName12, {
                    kinds: [inferReturnTypeAction.kind],
                    getEditsForAction: getRefactorEditsToInferReturnType,
                    getAvailableActions: getRefactorActionsToInferReturnType
                });
            }
        });
        // src/services/_namespaces/ts.refactor.inferFunctionReturnType.ts
        var ts_refactor_inferFunctionReturnType_exports = {};
        var init_ts_refactor_inferFunctionReturnType = __esm({
            "src/services/_namespaces/ts.refactor.inferFunctionReturnType.ts"() {
                "use strict";
                init_inferFunctionReturnType();
            }
        });
        // src/services/_namespaces/ts.refactor.ts
        var ts_refactor_exports = {};
        __export(ts_refactor_exports, {
            addOrRemoveBracesToArrowFunction: () => ts_refactor_addOrRemoveBracesToArrowFunction_exports,
            convertArrowFunctionOrFunctionExpression: () => ts_refactor_convertArrowFunctionOrFunctionExpression_exports,
            convertParamsToDestructuredObject: () => ts_refactor_convertParamsToDestructuredObject_exports,
            convertStringOrTemplateLiteral: () => ts_refactor_convertStringOrTemplateLiteral_exports,
            convertToOptionalChainExpression: () => ts_refactor_convertToOptionalChainExpression_exports,
            doChangeNamedToNamespaceOrDefault: () => doChangeNamedToNamespaceOrDefault,
            extractSymbol: () => ts_refactor_extractSymbol_exports,
            generateGetAccessorAndSetAccessor: () => ts_refactor_generateGetAccessorAndSetAccessor_exports,
            getApplicableRefactors: () => getApplicableRefactors,
            getEditsForRefactor: () => getEditsForRefactor,
            inferFunctionReturnType: () => ts_refactor_inferFunctionReturnType_exports,
            isRefactorErrorInfo: () => isRefactorErrorInfo,
            refactorKindBeginsWith: () => refactorKindBeginsWith,
            registerRefactor: () => registerRefactor
        });
        var init_ts_refactor = __esm({
            "src/services/_namespaces/ts.refactor.ts"() {
                "use strict";
                init_refactorProvider();
                init_convertExport();
                init_convertImport();
                init_extractType();
                init_helpers2();
                init_moveToNewFile();
                init_ts_refactor_addOrRemoveBracesToArrowFunction();
                init_ts_refactor_convertArrowFunctionOrFunctionExpression();
                init_ts_refactor_convertParamsToDestructuredObject();
                init_ts_refactor_convertStringOrTemplateLiteral();
                init_ts_refactor_convertToOptionalChainExpression();
                init_ts_refactor_extractSymbol();
                init_ts_refactor_generateGetAccessorAndSetAccessor();
                init_ts_refactor_inferFunctionReturnType();
            }
        });
        // src/services/rename.ts
        function getRenameInfo(program, sourceFile, position, preferences) {
            const node = getAdjustedRenameLocation(getTouchingPropertyName(sourceFile, position));
            if (nodeIsEligibleForRename(node)) {
                const renameInfo = getRenameInfoForNode(node, program.getTypeChecker(), sourceFile, program, preferences);
                if (renameInfo) {
                    return renameInfo;
                }
            }
            return getRenameInfoError(Diagnostics.You_cannot_rename_this_element);
        }
        function getRenameInfoForNode(node, typeChecker, sourceFile, program, preferences) {
            const symbol = typeChecker.getSymbolAtLocation(node);
            if (!symbol) {
                if (isStringLiteralLike(node)) {
                    const type = getContextualTypeFromParentOrAncestorTypeNode(node, typeChecker);
                    if (type && (type.flags & 128 /* StringLiteral */ || type.flags & 1048576 /* Union */ && every(type.types, (type2) => !!(type2.flags & 128 /* StringLiteral */)))) {
                        return getRenameInfoSuccess(node.text, node.text, "string" /* string */, "", node, sourceFile);
                    }
                }
                else if (isLabelName(node)) {
                    const name = getTextOfNode(node);
                    return getRenameInfoSuccess(name, name, "label" /* label */, "" /* none */, node, sourceFile);
                }
                return void 0;
            }
            const { declarations } = symbol;
            if (!declarations || declarations.length === 0)
                return;
            if (declarations.some((declaration) => isDefinedInLibraryFile(program, declaration))) {
                return getRenameInfoError(Diagnostics.You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library);
            }
            if (isIdentifier(node) && node.escapedText === "default" && symbol.parent && symbol.parent.flags & 1536 /* Module */) {
                return void 0;
            }
            if (isStringLiteralLike(node) && tryGetImportFromModuleSpecifier(node)) {
                return preferences.allowRenameOfImportPath ? getRenameInfoForModule(node, sourceFile, symbol) : void 0;
            }
            const wouldRenameNodeModules = wouldRenameInOtherNodeModules(sourceFile, symbol, typeChecker, preferences);
            if (wouldRenameNodeModules) {
                return getRenameInfoError(wouldRenameNodeModules);
            }
            const kind = ts_SymbolDisplay_exports.getSymbolKind(typeChecker, symbol, node);
            const specifierName = isImportOrExportSpecifierName(node) || isStringOrNumericLiteralLike(node) && node.parent.kind === 164 /* ComputedPropertyName */ ? stripQuotes(getTextOfIdentifierOrLiteral(node)) : void 0;
            const displayName = specifierName || typeChecker.symbolToString(symbol);
            const fullDisplayName = specifierName || typeChecker.getFullyQualifiedName(symbol);
            return getRenameInfoSuccess(displayName, fullDisplayName, kind, ts_SymbolDisplay_exports.getSymbolModifiers(typeChecker, symbol), node, sourceFile);
        }
        function isDefinedInLibraryFile(program, declaration) {
            const sourceFile = declaration.getSourceFile();
            return program.isSourceFileDefaultLibrary(sourceFile) && fileExtensionIs(sourceFile.fileName, ".d.ts" /* Dts */);
        }
        function wouldRenameInOtherNodeModules(originalFile, symbol, checker, preferences) {
            if (!preferences.providePrefixAndSuffixTextForRename && symbol.flags & 2097152 /* Alias */) {
                const importSpecifier = symbol.declarations && find(symbol.declarations, (decl) => isImportSpecifier(decl));
                if (importSpecifier && !importSpecifier.propertyName) {
                    symbol = checker.getAliasedSymbol(symbol);
                }
            }
            const { declarations } = symbol;
            if (!declarations) {
                return void 0;
            }
            const originalPackage = getPackagePathComponents(originalFile.path);
            if (originalPackage === void 0) {
                if (some(declarations, (declaration) => isInsideNodeModules(declaration.getSourceFile().path))) {
                    return Diagnostics.You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder;
                }
                else {
                    return void 0;
                }
            }
            for (const declaration of declarations) {
                const declPackage = getPackagePathComponents(declaration.getSourceFile().path);
                if (declPackage) {
                    const length2 = Math.min(originalPackage.length, declPackage.length);
                    for (let i = 0; i <= length2; i++) {
                        if (compareStringsCaseSensitive(originalPackage[i], declPackage[i]) !== 0 /* EqualTo */) {
                            return Diagnostics.You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder;
                        }
                    }
                }
            }
            return void 0;
        }
        function getPackagePathComponents(filePath) {
            const components = getPathComponents(filePath);
            const nodeModulesIdx = components.lastIndexOf("node_modules");
            if (nodeModulesIdx === -1) {
                return void 0;
            }
            return components.slice(0, nodeModulesIdx + 2);
        }
        function getRenameInfoForModule(node, sourceFile, moduleSymbol) {
            if (!isExternalModuleNameRelative(node.text)) {
                return getRenameInfoError(Diagnostics.You_cannot_rename_a_module_via_a_global_import);
            }
            const moduleSourceFile = moduleSymbol.declarations && find(moduleSymbol.declarations, isSourceFile);
            if (!moduleSourceFile)
                return void 0;
            const withoutIndex = endsWith(node.text, "/index") || endsWith(node.text, "/index.js") ? void 0 : tryRemoveSuffix(removeFileExtension(moduleSourceFile.fileName), "/index");
            const name = withoutIndex === void 0 ? moduleSourceFile.fileName : withoutIndex;
            const kind = withoutIndex === void 0 ? "module" /* moduleElement */ : "directory" /* directory */;
            const indexAfterLastSlash = node.text.lastIndexOf("/") + 1;
            const triggerSpan = createTextSpan(node.getStart(sourceFile) + 1 + indexAfterLastSlash, node.text.length - indexAfterLastSlash);
            return {
                canRename: true,
                fileToRename: name,
                kind,
                displayName: name,
                fullDisplayName: name,
                kindModifiers: "" /* none */,
                triggerSpan
            };
        }
        function getRenameInfoSuccess(displayName, fullDisplayName, kind, kindModifiers, node, sourceFile) {
            return {
                canRename: true,
                fileToRename: void 0,
                kind,
                displayName,
                fullDisplayName,
                kindModifiers,
                triggerSpan: createTriggerSpanForNode(node, sourceFile)
            };
        }
        function getRenameInfoError(diagnostic) {
            return { canRename: false, localizedErrorMessage: getLocaleSpecificMessage(diagnostic) };
        }
        function createTriggerSpanForNode(node, sourceFile) {
            let start = node.getStart(sourceFile);
            let width = node.getWidth(sourceFile);
            if (isStringLiteralLike(node)) {
                start += 1;
                width -= 2;
            }
            return createTextSpan(start, width);
        }
        function nodeIsEligibleForRename(node) {
            switch (node.kind) {
                case 79 /* Identifier */:
                case 80 /* PrivateIdentifier */:
                case 10 /* StringLiteral */:
                case 14 /* NoSubstitutionTemplateLiteral */:
                case 108 /* ThisKeyword */:
                    return true;
                case 8 /* NumericLiteral */:
                    return isLiteralNameOfPropertyDeclarationOrIndexAccess(node);
                default:
                    return false;
            }
        }
        var init_rename = __esm({
            "src/services/rename.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/_namespaces/ts.Rename.ts
        var ts_Rename_exports = {};
        __export(ts_Rename_exports, {
            getRenameInfo: () => getRenameInfo,
            nodeIsEligibleForRename: () => nodeIsEligibleForRename
        });
        var init_ts_Rename = __esm({
            "src/services/_namespaces/ts.Rename.ts"() {
                "use strict";
                init_rename();
            }
        });
        // src/services/signatureHelp.ts
        function getSignatureHelpItems(program, sourceFile, position, triggerReason, cancellationToken) {
            const typeChecker = program.getTypeChecker();
            const startingToken = findTokenOnLeftOfPosition(sourceFile, position);
            if (!startingToken) {
                return void 0;
            }
            const onlyUseSyntacticOwners = !!triggerReason && triggerReason.kind === "characterTyped";
            if (onlyUseSyntacticOwners && (isInString(sourceFile, position, startingToken) || isInComment(sourceFile, position))) {
                return void 0;
            }
            const isManuallyInvoked = !!triggerReason && triggerReason.kind === "invoked";
            const argumentInfo = getContainingArgumentInfo(startingToken, position, sourceFile, typeChecker, isManuallyInvoked);
            if (!argumentInfo)
                return void 0;
            cancellationToken.throwIfCancellationRequested();
            const candidateInfo = getCandidateOrTypeInfo(argumentInfo, typeChecker, sourceFile, startingToken, onlyUseSyntacticOwners);
            cancellationToken.throwIfCancellationRequested();
            if (!candidateInfo) {
                return isSourceFileJS(sourceFile) ? createJSSignatureHelpItems(argumentInfo, program, cancellationToken) : void 0;
            }
            return typeChecker.runWithCancellationToken(cancellationToken, (typeChecker2) => candidateInfo.kind === 0 /* Candidate */ ? createSignatureHelpItems(candidateInfo.candidates, candidateInfo.resolvedSignature, argumentInfo, sourceFile, typeChecker2) : createTypeHelpItems(candidateInfo.symbol, argumentInfo, sourceFile, typeChecker2));
        }
        function getCandidateOrTypeInfo({ invocation, argumentCount }, checker, sourceFile, startingToken, onlyUseSyntacticOwners) {
            switch (invocation.kind) {
                case 0 /* Call */: {
                    if (onlyUseSyntacticOwners && !isSyntacticOwner(startingToken, invocation.node, sourceFile)) {
                        return void 0;
                    }
                    const candidates = [];
                    const resolvedSignature = checker.getResolvedSignatureForSignatureHelp(invocation.node, candidates, argumentCount);
                    return candidates.length === 0 ? void 0 : { kind: 0 /* Candidate */, candidates, resolvedSignature };
                }
                case 1 /* TypeArgs */: {
                    const { called } = invocation;
                    if (onlyUseSyntacticOwners && !containsPrecedingToken(startingToken, sourceFile, isIdentifier(called) ? called.parent : called)) {
                        return void 0;
                    }
                    const candidates = getPossibleGenericSignatures(called, argumentCount, checker);
                    if (candidates.length !== 0)
                        return { kind: 0 /* Candidate */, candidates, resolvedSignature: first(candidates) };
                    const symbol = checker.getSymbolAtLocation(called);
                    return symbol && { kind: 1 /* Type */, symbol };
                }
                case 2 /* Contextual */:
                    return { kind: 0 /* Candidate */, candidates: [invocation.signature], resolvedSignature: invocation.signature };
                default:
                    return Debug.assertNever(invocation);
            }
        }
        function isSyntacticOwner(startingToken, node, sourceFile) {
            if (!isCallOrNewExpression(node))
                return false;
            const invocationChildren = node.getChildren(sourceFile);
            switch (startingToken.kind) {
                case 20 /* OpenParenToken */:
                    return contains(invocationChildren, startingToken);
                case 27 /* CommaToken */: {
                    const containingList = findContainingList(startingToken);
                    return !!containingList && contains(invocationChildren, containingList);
                }
                case 29 /* LessThanToken */:
                    return containsPrecedingToken(startingToken, sourceFile, node.expression);
                default:
                    return false;
            }
        }
        function createJSSignatureHelpItems(argumentInfo, program, cancellationToken) {
            if (argumentInfo.invocation.kind === 2 /* Contextual */)
                return void 0;
            const expression = getExpressionFromInvocation(argumentInfo.invocation);
            const name = isPropertyAccessExpression(expression) ? expression.name.text : void 0;
            const typeChecker = program.getTypeChecker();
            return name === void 0 ? void 0 : firstDefined(program.getSourceFiles(), (sourceFile) => firstDefined(sourceFile.getNamedDeclarations().get(name), (declaration) => {
                const type = declaration.symbol && typeChecker.getTypeOfSymbolAtLocation(declaration.symbol, declaration);
                const callSignatures = type && type.getCallSignatures();
                if (callSignatures && callSignatures.length) {
                    return typeChecker.runWithCancellationToken(cancellationToken, (typeChecker2) => createSignatureHelpItems(callSignatures, callSignatures[0], argumentInfo, sourceFile, typeChecker2, 
                    /*useFullPrefix*/
                    true));
                }
            }));
        }
        function containsPrecedingToken(startingToken, sourceFile, container) {
            const pos = startingToken.getFullStart();
            let currentParent = startingToken.parent;
            while (currentParent) {
                const precedingToken = findPrecedingToken(pos, sourceFile, currentParent, 
                /*excludeJsdoc*/
                true);
                if (precedingToken) {
                    return rangeContainsRange(container, precedingToken);
                }
                currentParent = currentParent.parent;
            }
            return Debug.fail("Could not find preceding token");
        }
        function getArgumentInfoForCompletions(node, position, sourceFile) {
            const info = getImmediatelyContainingArgumentInfo(node, position, sourceFile);
            return !info || info.isTypeParameterList || info.invocation.kind !== 0 /* Call */ ? void 0 : { invocation: info.invocation.node, argumentCount: info.argumentCount, argumentIndex: info.argumentIndex };
        }
        function getArgumentOrParameterListInfo(node, position, sourceFile) {
            const info = getArgumentOrParameterListAndIndex(node, sourceFile);
            if (!info)
                return void 0;
            const { list, argumentIndex } = info;
            const argumentCount = getArgumentCount(list, 
            /*ignoreTrailingComma*/
            isInString(sourceFile, position, node));
            if (argumentIndex !== 0) {
                Debug.assertLessThan(argumentIndex, argumentCount);
            }
            const argumentsSpan = getApplicableSpanForArguments(list, sourceFile);
            return { list, argumentIndex, argumentCount, argumentsSpan };
        }
        function getArgumentOrParameterListAndIndex(node, sourceFile) {
            if (node.kind === 29 /* LessThanToken */ || node.kind === 20 /* OpenParenToken */) {
                return { list: getChildListThatStartsWithOpenerToken(node.parent, node, sourceFile), argumentIndex: 0 };
            }
            else {
                const list = findContainingList(node);
                return list && { list, argumentIndex: getArgumentIndex(list, node) };
            }
        }
        function getImmediatelyContainingArgumentInfo(node, position, sourceFile) {
            const { parent: parent2 } = node;
            if (isCallOrNewExpression(parent2)) {
                const invocation = parent2;
                const info = getArgumentOrParameterListInfo(node, position, sourceFile);
                if (!info)
                    return void 0;
                const { list, argumentIndex, argumentCount, argumentsSpan } = info;
                const isTypeParameterList = !!parent2.typeArguments && parent2.typeArguments.pos === list.pos;
                return { isTypeParameterList, invocation: { kind: 0 /* Call */, node: invocation }, argumentsSpan, argumentIndex, argumentCount };
            }
            else if (isNoSubstitutionTemplateLiteral(node) && isTaggedTemplateExpression(parent2)) {
                if (isInsideTemplateLiteral(node, position, sourceFile)) {
                    return getArgumentListInfoForTemplate(parent2, 
                    /*argumentIndex*/
                    0, sourceFile);
                }
                return void 0;
            }
            else if (isTemplateHead(node) && parent2.parent.kind === 212 /* TaggedTemplateExpression */) {
                const templateExpression = parent2;
                const tagExpression = templateExpression.parent;
                Debug.assert(templateExpression.kind === 225 /* TemplateExpression */);
                const argumentIndex = isInsideTemplateLiteral(node, position, sourceFile) ? 0 : 1;
                return getArgumentListInfoForTemplate(tagExpression, argumentIndex, sourceFile);
            }
            else if (isTemplateSpan(parent2) && isTaggedTemplateExpression(parent2.parent.parent)) {
                const templateSpan = parent2;
                const tagExpression = parent2.parent.parent;
                if (isTemplateTail(node) && !isInsideTemplateLiteral(node, position, sourceFile)) {
                    return void 0;
                }
                const spanIndex = templateSpan.parent.templateSpans.indexOf(templateSpan);
                const argumentIndex = getArgumentIndexForTemplatePiece(spanIndex, node, position, sourceFile);
                return getArgumentListInfoForTemplate(tagExpression, argumentIndex, sourceFile);
            }
            else if (isJsxOpeningLikeElement(parent2)) {
                const attributeSpanStart = parent2.attributes.pos;
                const attributeSpanEnd = skipTrivia(sourceFile.text, parent2.attributes.end, 
                /*stopAfterLineBreak*/
                false);
                return {
                    isTypeParameterList: false,
                    invocation: { kind: 0 /* Call */, node: parent2 },
                    argumentsSpan: createTextSpan(attributeSpanStart, attributeSpanEnd - attributeSpanStart),
                    argumentIndex: 0,
                    argumentCount: 1
                };
            }
            else {
                const typeArgInfo = getPossibleTypeArgumentsInfo(node, sourceFile);
                if (typeArgInfo) {
                    const { called, nTypeArguments } = typeArgInfo;
                    const invocation = { kind: 1 /* TypeArgs */, called };
                    const argumentsSpan = createTextSpanFromBounds(called.getStart(sourceFile), node.end);
                    return { isTypeParameterList: true, invocation, argumentsSpan, argumentIndex: nTypeArguments, argumentCount: nTypeArguments + 1 };
                }
                return void 0;
            }
        }
        function getImmediatelyContainingArgumentOrContextualParameterInfo(node, position, sourceFile, checker) {
            return tryGetParameterInfo(node, position, sourceFile, checker) || getImmediatelyContainingArgumentInfo(node, position, sourceFile);
        }
        function getHighestBinary(b) {
            return isBinaryExpression(b.parent) ? getHighestBinary(b.parent) : b;
        }
        function countBinaryExpressionParameters(b) {
            return isBinaryExpression(b.left) ? countBinaryExpressionParameters(b.left) + 1 : 2;
        }
        function tryGetParameterInfo(startingToken, position, sourceFile, checker) {
            const info = getContextualSignatureLocationInfo(startingToken, sourceFile, position, checker);
            if (!info)
                return void 0;
            const { contextualType, argumentIndex, argumentCount, argumentsSpan } = info;
            const nonNullableContextualType = contextualType.getNonNullableType();
            const symbol = nonNullableContextualType.symbol;
            if (symbol === void 0)
                return void 0;
            const signature = lastOrUndefined(nonNullableContextualType.getCallSignatures());
            if (signature === void 0)
                return void 0;
            const invocation = { kind: 2 /* Contextual */, signature, node: startingToken, symbol: chooseBetterSymbol(symbol) };
            return { isTypeParameterList: false, invocation, argumentsSpan, argumentIndex, argumentCount };
        }
        function getContextualSignatureLocationInfo(startingToken, sourceFile, position, checker) {
            if (startingToken.kind !== 20 /* OpenParenToken */ && startingToken.kind !== 27 /* CommaToken */)
                return void 0;
            const { parent: parent2 } = startingToken;
            switch (parent2.kind) {
                case 214 /* ParenthesizedExpression */:
                case 171 /* MethodDeclaration */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                    const info = getArgumentOrParameterListInfo(startingToken, position, sourceFile);
                    if (!info)
                        return void 0;
                    const { argumentIndex, argumentCount, argumentsSpan } = info;
                    const contextualType = isMethodDeclaration(parent2) ? checker.getContextualTypeForObjectLiteralElement(parent2) : checker.getContextualType(parent2);
                    return contextualType && { contextualType, argumentIndex, argumentCount, argumentsSpan };
                case 223 /* BinaryExpression */: {
                    const highestBinary = getHighestBinary(parent2);
                    const contextualType2 = checker.getContextualType(highestBinary);
                    const argumentIndex2 = startingToken.kind === 20 /* OpenParenToken */ ? 0 : countBinaryExpressionParameters(parent2) - 1;
                    const argumentCount2 = countBinaryExpressionParameters(highestBinary);
                    return contextualType2 && { contextualType: contextualType2, argumentIndex: argumentIndex2, argumentCount: argumentCount2, argumentsSpan: createTextSpanFromNode(parent2) };
                }
                default:
                    return void 0;
            }
        }
        function chooseBetterSymbol(s) {
            return s.name === "__type" /* Type */ ? firstDefined(s.declarations, (d) => {
                var _a2;
                return isFunctionTypeNode(d) ? (_a2 = tryCast(d.parent, canHaveSymbol)) == null ? void 0 : _a2.symbol : void 0;
            }) || s : s;
        }
        function getArgumentIndex(argumentsList, node) {
            let argumentIndex = 0;
            for (const child of argumentsList.getChildren()) {
                if (child === node) {
                    break;
                }
                if (child.kind !== 27 /* CommaToken */) {
                    argumentIndex++;
                }
            }
            return argumentIndex;
        }
        function getArgumentCount(argumentsList, ignoreTrailingComma) {
            const listChildren = argumentsList.getChildren();
            let argumentCount = countWhere(listChildren, (arg) => arg.kind !== 27 /* CommaToken */);
            if (!ignoreTrailingComma && listChildren.length > 0 && last(listChildren).kind === 27 /* CommaToken */) {
                argumentCount++;
            }
            return argumentCount;
        }
        function getArgumentIndexForTemplatePiece(spanIndex, node, position, sourceFile) {
            Debug.assert(position >= node.getStart(), "Assumed 'position' could not occur before node.");
            if (isTemplateLiteralToken(node)) {
                if (isInsideTemplateLiteral(node, position, sourceFile)) {
                    return 0;
                }
                return spanIndex + 2;
            }
            return spanIndex + 1;
        }
        function getArgumentListInfoForTemplate(tagExpression, argumentIndex, sourceFile) {
            const argumentCount = isNoSubstitutionTemplateLiteral(tagExpression.template) ? 1 : tagExpression.template.templateSpans.length + 1;
            if (argumentIndex !== 0) {
                Debug.assertLessThan(argumentIndex, argumentCount);
            }
            return {
                isTypeParameterList: false,
                invocation: { kind: 0 /* Call */, node: tagExpression },
                argumentsSpan: getApplicableSpanForTaggedTemplate(tagExpression, sourceFile),
                argumentIndex,
                argumentCount
            };
        }
        function getApplicableSpanForArguments(argumentsList, sourceFile) {
            const applicableSpanStart = argumentsList.getFullStart();
            const applicableSpanEnd = skipTrivia(sourceFile.text, argumentsList.getEnd(), 
            /*stopAfterLineBreak*/
            false);
            return createTextSpan(applicableSpanStart, applicableSpanEnd - applicableSpanStart);
        }
        function getApplicableSpanForTaggedTemplate(taggedTemplate, sourceFile) {
            const template = taggedTemplate.template;
            const applicableSpanStart = template.getStart();
            let applicableSpanEnd = template.getEnd();
            if (template.kind === 225 /* TemplateExpression */) {
                const lastSpan = last(template.templateSpans);
                if (lastSpan.literal.getFullWidth() === 0) {
                    applicableSpanEnd = skipTrivia(sourceFile.text, applicableSpanEnd, 
                    /*stopAfterLineBreak*/
                    false);
                }
            }
            return createTextSpan(applicableSpanStart, applicableSpanEnd - applicableSpanStart);
        }
        function getContainingArgumentInfo(node, position, sourceFile, checker, isManuallyInvoked) {
            for (let n = node; !isSourceFile(n) && (isManuallyInvoked || !isBlock(n)); n = n.parent) {
                Debug.assert(rangeContainsRange(n.parent, n), "Not a subspan", () => `Child: ${Debug.formatSyntaxKind(n.kind)}, parent: ${Debug.formatSyntaxKind(n.parent.kind)}`);
                const argumentInfo = getImmediatelyContainingArgumentOrContextualParameterInfo(n, position, sourceFile, checker);
                if (argumentInfo) {
                    return argumentInfo;
                }
            }
            return void 0;
        }
        function getChildListThatStartsWithOpenerToken(parent2, openerToken, sourceFile) {
            const children = parent2.getChildren(sourceFile);
            const indexOfOpenerToken = children.indexOf(openerToken);
            Debug.assert(indexOfOpenerToken >= 0 && children.length > indexOfOpenerToken + 1);
            return children[indexOfOpenerToken + 1];
        }
        function getExpressionFromInvocation(invocation) {
            return invocation.kind === 0 /* Call */ ? getInvokedExpression(invocation.node) : invocation.called;
        }
        function getEnclosingDeclarationFromInvocation(invocation) {
            return invocation.kind === 0 /* Call */ ? invocation.node : invocation.kind === 1 /* TypeArgs */ ? invocation.called : invocation.node;
        }
        function createSignatureHelpItems(candidates, resolvedSignature, { isTypeParameterList, argumentCount, argumentsSpan: applicableSpan, invocation, argumentIndex }, sourceFile, typeChecker, useFullPrefix) {
            var _a2;
            const enclosingDeclaration = getEnclosingDeclarationFromInvocation(invocation);
            const callTargetSymbol = invocation.kind === 2 /* Contextual */ ? invocation.symbol : typeChecker.getSymbolAtLocation(getExpressionFromInvocation(invocation)) || useFullPrefix && ((_a2 = resolvedSignature.declaration) == null ? void 0 : _a2.symbol);
            const callTargetDisplayParts = callTargetSymbol ? symbolToDisplayParts(typeChecker, callTargetSymbol, useFullPrefix ? sourceFile : void 0, 
            /*meaning*/
            void 0) : emptyArray;
            const items = map(candidates, (candidateSignature) => getSignatureHelpItem(candidateSignature, callTargetDisplayParts, isTypeParameterList, typeChecker, enclosingDeclaration, sourceFile));
            if (argumentIndex !== 0) {
                Debug.assertLessThan(argumentIndex, argumentCount);
            }
            let selectedItemIndex = 0;
            let itemsSeen = 0;
            for (let i = 0; i < items.length; i++) {
                const item = items[i];
                if (candidates[i] === resolvedSignature) {
                    selectedItemIndex = itemsSeen;
                    if (item.length > 1) {
                        let count = 0;
                        for (const i2 of item) {
                            if (i2.isVariadic || i2.parameters.length >= argumentCount) {
                                selectedItemIndex = itemsSeen + count;
                                break;
                            }
                            count++;
                        }
                    }
                }
                itemsSeen += item.length;
            }
            Debug.assert(selectedItemIndex !== -1);
            const help = { items: flatMapToMutable(items, identity), applicableSpan, selectedItemIndex, argumentIndex, argumentCount };
            const selected = help.items[selectedItemIndex];
            if (selected.isVariadic) {
                const firstRest = findIndex(selected.parameters, (p) => !!p.isRest);
                if (-1 < firstRest && firstRest < selected.parameters.length - 1) {
                    help.argumentIndex = selected.parameters.length;
                }
                else {
                    help.argumentIndex = Math.min(help.argumentIndex, selected.parameters.length - 1);
                }
            }
            return help;
        }
        function createTypeHelpItems(symbol, { argumentCount, argumentsSpan: applicableSpan, invocation, argumentIndex }, sourceFile, checker) {
            const typeParameters = checker.getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
            if (!typeParameters)
                return void 0;
            const items = [getTypeHelpItem(symbol, typeParameters, checker, getEnclosingDeclarationFromInvocation(invocation), sourceFile)];
            return { items, applicableSpan, selectedItemIndex: 0, argumentIndex, argumentCount };
        }
        function getTypeHelpItem(symbol, typeParameters, checker, enclosingDeclaration, sourceFile) {
            const typeSymbolDisplay = symbolToDisplayParts(checker, symbol);
            const printer = createPrinterWithRemoveComments();
            const parameters = typeParameters.map((t) => createSignatureHelpParameterForTypeParameter(t, checker, enclosingDeclaration, sourceFile, printer));
            const documentation = symbol.getDocumentationComment(checker);
            const tags = symbol.getJsDocTags(checker);
            const prefixDisplayParts = [...typeSymbolDisplay, punctuationPart(29 /* LessThanToken */)];
            return { isVariadic: false, prefixDisplayParts, suffixDisplayParts: [punctuationPart(31 /* GreaterThanToken */)], separatorDisplayParts, parameters, documentation, tags };
        }
        function getSignatureHelpItem(candidateSignature, callTargetDisplayParts, isTypeParameterList, checker, enclosingDeclaration, sourceFile) {
            const infos = (isTypeParameterList ? itemInfoForTypeParameters : itemInfoForParameters)(candidateSignature, checker, enclosingDeclaration, sourceFile);
            return map(infos, ({ isVariadic, parameters, prefix, suffix }) => {
                const prefixDisplayParts = [...callTargetDisplayParts, ...prefix];
                const suffixDisplayParts = [...suffix, ...returnTypeToDisplayParts(candidateSignature, enclosingDeclaration, checker)];
                const documentation = candidateSignature.getDocumentationComment(checker);
                const tags = candidateSignature.getJsDocTags();
                return { isVariadic, prefixDisplayParts, suffixDisplayParts, separatorDisplayParts, parameters, documentation, tags };
            });
        }
        function returnTypeToDisplayParts(candidateSignature, enclosingDeclaration, checker) {
            return mapToDisplayParts((writer) => {
                writer.writePunctuation(":");
                writer.writeSpace(" ");
                const predicate = checker.getTypePredicateOfSignature(candidateSignature);
                if (predicate) {
                    checker.writeTypePredicate(predicate, enclosingDeclaration, 
                    /*flags*/
                    void 0, writer);
                }
                else {
                    checker.writeType(checker.getReturnTypeOfSignature(candidateSignature), enclosingDeclaration, 
                    /*flags*/
                    void 0, writer);
                }
            });
        }
        function itemInfoForTypeParameters(candidateSignature, checker, enclosingDeclaration, sourceFile) {
            const typeParameters = (candidateSignature.target || candidateSignature).typeParameters;
            const printer = createPrinterWithRemoveComments();
            const parameters = (typeParameters || emptyArray).map((t) => createSignatureHelpParameterForTypeParameter(t, checker, enclosingDeclaration, sourceFile, printer));
            const thisParameter = candidateSignature.thisParameter ? [checker.symbolToParameterDeclaration(candidateSignature.thisParameter, enclosingDeclaration, signatureHelpNodeBuilderFlags)] : [];
            return checker.getExpandedParameters(candidateSignature).map((paramList) => {
                const params = factory.createNodeArray([...thisParameter, ...map(paramList, (param) => checker.symbolToParameterDeclaration(param, enclosingDeclaration, signatureHelpNodeBuilderFlags))]);
                const parameterParts = mapToDisplayParts((writer) => {
                    printer.writeList(2576 /* CallExpressionArguments */, params, sourceFile, writer);
                });
                return { isVariadic: false, parameters, prefix: [punctuationPart(29 /* LessThanToken */)], suffix: [punctuationPart(31 /* GreaterThanToken */), ...parameterParts] };
            });
        }
        function itemInfoForParameters(candidateSignature, checker, enclosingDeclaration, sourceFile) {
            const printer = createPrinterWithRemoveComments();
            const typeParameterParts = mapToDisplayParts((writer) => {
                if (candidateSignature.typeParameters && candidateSignature.typeParameters.length) {
                    const args = factory.createNodeArray(candidateSignature.typeParameters.map((p) => checker.typeParameterToDeclaration(p, enclosingDeclaration, signatureHelpNodeBuilderFlags)));
                    printer.writeList(53776 /* TypeParameters */, args, sourceFile, writer);
                }
            });
            const lists = checker.getExpandedParameters(candidateSignature);
            const isVariadic = !checker.hasEffectiveRestParameter(candidateSignature) ? (_) => false : lists.length === 1 ? (_) => true : (pList) => {
                var _a2;
                return !!(pList.length && ((_a2 = tryCast(pList[pList.length - 1], isTransientSymbol)) == null ? void 0 : _a2.links.checkFlags) & 32768 /* RestParameter */);
            };
            return lists.map((parameterList) => ({
                isVariadic: isVariadic(parameterList),
                parameters: parameterList.map((p) => createSignatureHelpParameterForParameter(p, checker, enclosingDeclaration, sourceFile, printer)),
                prefix: [...typeParameterParts, punctuationPart(20 /* OpenParenToken */)],
                suffix: [punctuationPart(21 /* CloseParenToken */)]
            }));
        }
        function createSignatureHelpParameterForParameter(parameter, checker, enclosingDeclaration, sourceFile, printer) {
            const displayParts = mapToDisplayParts((writer) => {
                const param = checker.symbolToParameterDeclaration(parameter, enclosingDeclaration, signatureHelpNodeBuilderFlags);
                printer.writeNode(4 /* Unspecified */, param, sourceFile, writer);
            });
            const isOptional = checker.isOptionalParameter(parameter.valueDeclaration);
            const isRest = isTransientSymbol(parameter) && !!(parameter.links.checkFlags & 32768 /* RestParameter */);
            return { name: parameter.name, documentation: parameter.getDocumentationComment(checker), displayParts, isOptional, isRest };
        }
        function createSignatureHelpParameterForTypeParameter(typeParameter, checker, enclosingDeclaration, sourceFile, printer) {
            const displayParts = mapToDisplayParts((writer) => {
                const param = checker.typeParameterToDeclaration(typeParameter, enclosingDeclaration, signatureHelpNodeBuilderFlags);
                printer.writeNode(4 /* Unspecified */, param, sourceFile, writer);
            });
            return { name: typeParameter.symbol.name, documentation: typeParameter.symbol.getDocumentationComment(checker), displayParts, isOptional: false, isRest: false };
        }
        var signatureHelpNodeBuilderFlags, separatorDisplayParts;
        var init_signatureHelp = __esm({
            "src/services/signatureHelp.ts"() {
                "use strict";
                init_ts4();
                signatureHelpNodeBuilderFlags = 8192 /* OmitParameterModifiers */ | 70221824 /* IgnoreErrors */ | 16384 /* UseAliasDefinedOutsideCurrentScope */;
                separatorDisplayParts = [punctuationPart(27 /* CommaToken */), spacePart()];
            }
        });
        // src/services/_namespaces/ts.SignatureHelp.ts
        var ts_SignatureHelp_exports = {};
        __export(ts_SignatureHelp_exports, {
            getArgumentInfoForCompletions: () => getArgumentInfoForCompletions,
            getSignatureHelpItems: () => getSignatureHelpItems
        });
        var init_ts_SignatureHelp = __esm({
            "src/services/_namespaces/ts.SignatureHelp.ts"() {
                "use strict";
                init_signatureHelp();
            }
        });
        // src/services/smartSelection.ts
        function getSmartSelectionRange(pos, sourceFile) {
            var _a2, _b;
            let selectionRange = {
                textSpan: createTextSpanFromBounds(sourceFile.getFullStart(), sourceFile.getEnd())
            };
            let parentNode = sourceFile;
            outer: while (true) {
                const children = getSelectionChildren(parentNode);
                if (!children.length)
                    break;
                for (let i = 0; i < children.length; i++) {
                    const prevNode = children[i - 1];
                    const node = children[i];
                    const nextNode = children[i + 1];
                    if (getTokenPosOfNode(node, sourceFile, 
                    /*includeJsDoc*/
                    true) > pos) {
                        break outer;
                    }
                    const comment = singleOrUndefined(getTrailingCommentRanges(sourceFile.text, node.end));
                    if (comment && comment.kind === 2 /* SingleLineCommentTrivia */) {
                        pushSelectionCommentRange(comment.pos, comment.end);
                    }
                    if (positionShouldSnapToNode(sourceFile, pos, node)) {
                        if (isFunctionBody(node) && isFunctionLikeDeclaration(parentNode) && !positionsAreOnSameLine(node.getStart(sourceFile), node.getEnd(), sourceFile)) {
                            pushSelectionRange(node.getStart(sourceFile), node.getEnd());
                        }
                        if (isBlock(node) || isTemplateSpan(node) || isTemplateHead(node) || isTemplateTail(node) || prevNode && isTemplateHead(prevNode) || isVariableDeclarationList(node) && isVariableStatement(parentNode) || isSyntaxList(node) && isVariableDeclarationList(parentNode) || isVariableDeclaration(node) && isSyntaxList(parentNode) && children.length === 1 || isJSDocTypeExpression(node) || isJSDocSignature(node) || isJSDocTypeLiteral(node)) {
                            parentNode = node;
                            break;
                        }
                        if (isTemplateSpan(parentNode) && nextNode && isTemplateMiddleOrTemplateTail(nextNode)) {
                            const start2 = node.getFullStart() - "${".length;
                            const end2 = nextNode.getStart() + "}".length;
                            pushSelectionRange(start2, end2);
                        }
                        const isBetweenMultiLineBookends = isSyntaxList(node) && isListOpener(prevNode) && isListCloser(nextNode) && !positionsAreOnSameLine(prevNode.getStart(), nextNode.getStart(), sourceFile);
                        let start = isBetweenMultiLineBookends ? prevNode.getEnd() : node.getStart();
                        const end = isBetweenMultiLineBookends ? nextNode.getStart() : getEndPos(sourceFile, node);
                        if (hasJSDocNodes(node) && ((_a2 = node.jsDoc) == null ? void 0 : _a2.length)) {
                            pushSelectionRange(first(node.jsDoc).getStart(), end);
                        }
                        if (isSyntaxList(node)) {
                            const firstChild = node.getChildren()[0];
                            if (firstChild && hasJSDocNodes(firstChild) && ((_b = firstChild.jsDoc) == null ? void 0 : _b.length) && firstChild.getStart() !== node.pos) {
                                start = Math.min(start, first(firstChild.jsDoc).getStart());
                            }
                        }
                        pushSelectionRange(start, end);
                        if (isStringLiteral(node) || isTemplateLiteral(node)) {
                            pushSelectionRange(start + 1, end - 1);
                        }
                        parentNode = node;
                        break;
                    }
                    if (i === children.length - 1) {
                        break outer;
                    }
                }
            }
            return selectionRange;
            function pushSelectionRange(start, end) {
                if (start !== end) {
                    const textSpan = createTextSpanFromBounds(start, end);
                    if (!selectionRange || // Skip ranges that are identical to the parent
                        !textSpansEqual(textSpan, selectionRange.textSpan) && // Skip ranges that don’t contain the original position
                            textSpanIntersectsWithPosition(textSpan, pos)) {
                        selectionRange = { textSpan, ...selectionRange && { parent: selectionRange } };
                    }
                }
            }
            function pushSelectionCommentRange(start, end) {
                pushSelectionRange(start, end);
                let pos2 = start;
                while (sourceFile.text.charCodeAt(pos2) === 47 /* slash */) {
                    pos2++;
                }
                pushSelectionRange(pos2, end);
            }
        }
        function positionShouldSnapToNode(sourceFile, pos, node) {
            Debug.assert(node.pos <= pos);
            if (pos < node.end) {
                return true;
            }
            const nodeEnd = node.getEnd();
            if (nodeEnd === pos) {
                return getTouchingPropertyName(sourceFile, pos).pos < node.end;
            }
            return false;
        }
        function getSelectionChildren(node) {
            var _a2;
            if (isSourceFile(node)) {
                return groupChildren(node.getChildAt(0).getChildren(), isImport2);
            }
            if (isMappedTypeNode(node)) {
                const [openBraceToken, ...children] = node.getChildren();
                const closeBraceToken = Debug.checkDefined(children.pop());
                Debug.assertEqual(openBraceToken.kind, 18 /* OpenBraceToken */);
                Debug.assertEqual(closeBraceToken.kind, 19 /* CloseBraceToken */);
                const groupedWithPlusMinusTokens = groupChildren(children, (child) => child === node.readonlyToken || child.kind === 146 /* ReadonlyKeyword */ || child === node.questionToken || child.kind === 57 /* QuestionToken */);
                const groupedWithBrackets = groupChildren(groupedWithPlusMinusTokens, ({ kind }) => kind === 22 /* OpenBracketToken */ || kind === 165 /* TypeParameter */ || kind === 23 /* CloseBracketToken */);
                return [
                    openBraceToken,
                    // Pivot on `:`
                    createSyntaxList2(splitChildren(groupedWithBrackets, ({ kind }) => kind === 58 /* ColonToken */)),
                    closeBraceToken
                ];
            }
            if (isPropertySignature(node)) {
                const children = groupChildren(node.getChildren(), (child) => child === node.name || contains(node.modifiers, child));
                const firstJSDocChild = ((_a2 = children[0]) == null ? void 0 : _a2.kind) === 323 /* JSDoc */ ? children[0] : void 0;
                const withJSDocSeparated = firstJSDocChild ? children.slice(1) : children;
                const splittedChildren = splitChildren(withJSDocSeparated, ({ kind }) => kind === 58 /* ColonToken */);
                return firstJSDocChild ? [firstJSDocChild, createSyntaxList2(splittedChildren)] : splittedChildren;
            }
            if (isParameter(node)) {
                const groupedDotDotDotAndName = groupChildren(node.getChildren(), (child) => child === node.dotDotDotToken || child === node.name);
                const groupedWithQuestionToken = groupChildren(groupedDotDotDotAndName, (child) => child === groupedDotDotDotAndName[0] || child === node.questionToken);
                return splitChildren(groupedWithQuestionToken, ({ kind }) => kind === 63 /* EqualsToken */);
            }
            if (isBindingElement(node)) {
                return splitChildren(node.getChildren(), ({ kind }) => kind === 63 /* EqualsToken */);
            }
            return node.getChildren();
        }
        function groupChildren(children, groupOn) {
            const result = [];
            let group2;
            for (const child of children) {
                if (groupOn(child)) {
                    group2 = group2 || [];
                    group2.push(child);
                }
                else {
                    if (group2) {
                        result.push(createSyntaxList2(group2));
                        group2 = void 0;
                    }
                    result.push(child);
                }
            }
            if (group2) {
                result.push(createSyntaxList2(group2));
            }
            return result;
        }
        function splitChildren(children, pivotOn, separateTrailingSemicolon = true) {
            if (children.length < 2) {
                return children;
            }
            const splitTokenIndex = findIndex(children, pivotOn);
            if (splitTokenIndex === -1) {
                return children;
            }
            const leftChildren = children.slice(0, splitTokenIndex);
            const splitToken = children[splitTokenIndex];
            const lastToken = last(children);
            const separateLastToken = separateTrailingSemicolon && lastToken.kind === 26 /* SemicolonToken */;
            const rightChildren = children.slice(splitTokenIndex + 1, separateLastToken ? children.length - 1 : void 0);
            const result = compact([
                leftChildren.length ? createSyntaxList2(leftChildren) : void 0,
                splitToken,
                rightChildren.length ? createSyntaxList2(rightChildren) : void 0
            ]);
            return separateLastToken ? result.concat(lastToken) : result;
        }
        function createSyntaxList2(children) {
            Debug.assertGreaterThanOrEqual(children.length, 1);
            return setTextRangePosEnd(parseNodeFactory.createSyntaxList(children), children[0].pos, last(children).end);
        }
        function isListOpener(token) {
            const kind = token && token.kind;
            return kind === 18 /* OpenBraceToken */ || kind === 22 /* OpenBracketToken */ || kind === 20 /* OpenParenToken */ || kind === 283 /* JsxOpeningElement */;
        }
        function isListCloser(token) {
            const kind = token && token.kind;
            return kind === 19 /* CloseBraceToken */ || kind === 23 /* CloseBracketToken */ || kind === 21 /* CloseParenToken */ || kind === 284 /* JsxClosingElement */;
        }
        function getEndPos(sourceFile, node) {
            switch (node.kind) {
                case 344 /* JSDocParameterTag */:
                case 341 /* JSDocCallbackTag */:
                case 351 /* JSDocPropertyTag */:
                case 349 /* JSDocTypedefTag */:
                case 346 /* JSDocThisTag */:
                    return sourceFile.getLineEndOfPosition(node.getStart());
                default:
                    return node.getEnd();
            }
        }
        var isImport2;
        var init_smartSelection = __esm({
            "src/services/smartSelection.ts"() {
                "use strict";
                init_ts4();
                isImport2 = or(isImportDeclaration, isImportEqualsDeclaration);
            }
        });
        // src/services/_namespaces/ts.SmartSelectionRange.ts
        var ts_SmartSelectionRange_exports = {};
        __export(ts_SmartSelectionRange_exports, {
            getSmartSelectionRange: () => getSmartSelectionRange
        });
        var init_ts_SmartSelectionRange = __esm({
            "src/services/_namespaces/ts.SmartSelectionRange.ts"() {
                "use strict";
                init_smartSelection();
            }
        });
        // src/services/symbolDisplay.ts
        function getSymbolKind(typeChecker, symbol, location) {
            const result = getSymbolKindOfConstructorPropertyMethodAccessorFunctionOrVar(typeChecker, symbol, location);
            if (result !== "" /* unknown */) {
                return result;
            }
            const flags = getCombinedLocalAndExportSymbolFlags(symbol);
            if (flags & 32 /* Class */) {
                return getDeclarationOfKind(symbol, 228 /* ClassExpression */) ? "local class" /* localClassElement */ : "class" /* classElement */;
            }
            if (flags & 384 /* Enum */)
                return "enum" /* enumElement */;
            if (flags & 524288 /* TypeAlias */)
                return "type" /* typeElement */;
            if (flags & 64 /* Interface */)
                return "interface" /* interfaceElement */;
            if (flags & 262144 /* TypeParameter */)
                return "type parameter" /* typeParameterElement */;
            if (flags & 8 /* EnumMember */)
                return "enum member" /* enumMemberElement */;
            if (flags & 2097152 /* Alias */)
                return "alias" /* alias */;
            if (flags & 1536 /* Module */)
                return "module" /* moduleElement */;
            return result;
        }
        function getSymbolKindOfConstructorPropertyMethodAccessorFunctionOrVar(typeChecker, symbol, location) {
            const roots = typeChecker.getRootSymbols(symbol);
            if (roots.length === 1 && first(roots).flags & 8192 /* Method */ && typeChecker.getTypeOfSymbolAtLocation(symbol, location).getNonNullableType().getCallSignatures().length !== 0) {
                return "method" /* memberFunctionElement */;
            }
            if (typeChecker.isUndefinedSymbol(symbol)) {
                return "var" /* variableElement */;
            }
            if (typeChecker.isArgumentsSymbol(symbol)) {
                return "local var" /* localVariableElement */;
            }
            if (location.kind === 108 /* ThisKeyword */ && isExpression(location) || isThisInTypeQuery(location)) {
                return "parameter" /* parameterElement */;
            }
            const flags = getCombinedLocalAndExportSymbolFlags(symbol);
            if (flags & 3 /* Variable */) {
                if (isFirstDeclarationOfSymbolParameter(symbol)) {
                    return "parameter" /* parameterElement */;
                }
                else if (symbol.valueDeclaration && isVarConst(symbol.valueDeclaration)) {
                    return "const" /* constElement */;
                }
                else if (forEach(symbol.declarations, isLet)) {
                    return "let" /* letElement */;
                }
                return isLocalVariableOrFunction(symbol) ? "local var" /* localVariableElement */ : "var" /* variableElement */;
            }
            if (flags & 16 /* Function */)
                return isLocalVariableOrFunction(symbol) ? "local function" /* localFunctionElement */ : "function" /* functionElement */;
            if (flags & 32768 /* GetAccessor */)
                return "getter" /* memberGetAccessorElement */;
            if (flags & 65536 /* SetAccessor */)
                return "setter" /* memberSetAccessorElement */;
            if (flags & 8192 /* Method */)
                return "method" /* memberFunctionElement */;
            if (flags & 16384 /* Constructor */)
                return "constructor" /* constructorImplementationElement */;
            if (flags & 131072 /* Signature */)
                return "index" /* indexSignatureElement */;
            if (flags & 4 /* Property */) {
                if (flags & 33554432 /* Transient */ && symbol.links.checkFlags & 6 /* Synthetic */) {
                    const unionPropertyKind = forEach(typeChecker.getRootSymbols(symbol), (rootSymbol) => {
                        const rootSymbolFlags = rootSymbol.getFlags();
                        if (rootSymbolFlags & (98308 /* PropertyOrAccessor */ | 3 /* Variable */)) {
                            return "property" /* memberVariableElement */;
                        }
                    });
                    if (!unionPropertyKind) {
                        const typeOfUnionProperty = typeChecker.getTypeOfSymbolAtLocation(symbol, location);
                        if (typeOfUnionProperty.getCallSignatures().length) {
                            return "method" /* memberFunctionElement */;
                        }
                        return "property" /* memberVariableElement */;
                    }
                    return unionPropertyKind;
                }
                return "property" /* memberVariableElement */;
            }
            return "" /* unknown */;
        }
        function getNormalizedSymbolModifiers(symbol) {
            if (symbol.declarations && symbol.declarations.length) {
                const [declaration, ...declarations] = symbol.declarations;
                const excludeFlags = length(declarations) && isDeprecatedDeclaration(declaration) && some(declarations, (d) => !isDeprecatedDeclaration(d)) ? 8192 /* Deprecated */ : 0 /* None */;
                const modifiers = getNodeModifiers(declaration, excludeFlags);
                if (modifiers) {
                    return modifiers.split(",");
                }
            }
            return [];
        }
        function getSymbolModifiers(typeChecker, symbol) {
            if (!symbol) {
                return "" /* none */;
            }
            const modifiers = new Set(getNormalizedSymbolModifiers(symbol));
            if (symbol.flags & 2097152 /* Alias */) {
                const resolvedSymbol = typeChecker.getAliasedSymbol(symbol);
                if (resolvedSymbol !== symbol) {
                    forEach(getNormalizedSymbolModifiers(resolvedSymbol), (modifier) => {
                        modifiers.add(modifier);
                    });
                }
            }
            if (symbol.flags & 16777216 /* Optional */) {
                modifiers.add("optional" /* optionalModifier */);
            }
            return modifiers.size > 0 ? arrayFrom(modifiers.values()).join(",") : "" /* none */;
        }
        function getSymbolDisplayPartsDocumentationAndSymbolKind(typeChecker, symbol, sourceFile, enclosingDeclaration, location, semanticMeaning = getMeaningFromLocation(location), alias) {
            var _a2;
            const displayParts = [];
            let documentation = [];
            let tags = [];
            const symbolFlags = getCombinedLocalAndExportSymbolFlags(symbol);
            let symbolKind = semanticMeaning & 1 /* Value */ ? getSymbolKindOfConstructorPropertyMethodAccessorFunctionOrVar(typeChecker, symbol, location) : "" /* unknown */;
            let hasAddedSymbolInfo = false;
            const isThisExpression = location.kind === 108 /* ThisKeyword */ && isInExpressionContext(location) || isThisInTypeQuery(location);
            let type;
            let documentationFromAlias;
            let tagsFromAlias;
            let hasMultipleSignatures = false;
            if (location.kind === 108 /* ThisKeyword */ && !isThisExpression) {
                return { displayParts: [keywordPart(108 /* ThisKeyword */)], documentation: [], symbolKind: "primitive type" /* primitiveType */, tags: void 0 };
            }
            if (symbolKind !== "" /* unknown */ || symbolFlags & 32 /* Class */ || symbolFlags & 2097152 /* Alias */) {
                if (symbolKind === "getter" /* memberGetAccessorElement */ || symbolKind === "setter" /* memberSetAccessorElement */) {
                    const declaration = find(symbol.declarations, (declaration2) => declaration2.name === location);
                    if (declaration) {
                        switch (declaration.kind) {
                            case 174 /* GetAccessor */:
                                symbolKind = "getter" /* memberGetAccessorElement */;
                                break;
                            case 175 /* SetAccessor */:
                                symbolKind = "setter" /* memberSetAccessorElement */;
                                break;
                            case 169 /* PropertyDeclaration */:
                                symbolKind = "accessor" /* memberAccessorVariableElement */;
                                break;
                            default:
                                Debug.assertNever(declaration);
                        }
                    }
                    else {
                        symbolKind = "property" /* memberVariableElement */;
                    }
                }
                let signature;
                type = isThisExpression ? typeChecker.getTypeAtLocation(location) : typeChecker.getTypeOfSymbolAtLocation(symbol, location);
                if (location.parent && location.parent.kind === 208 /* PropertyAccessExpression */) {
                    const right = location.parent.name;
                    if (right === location || right && right.getFullWidth() === 0) {
                        location = location.parent;
                    }
                }
                let callExpressionLike;
                if (isCallOrNewExpression(location)) {
                    callExpressionLike = location;
                }
                else if (isCallExpressionTarget(location) || isNewExpressionTarget(location)) {
                    callExpressionLike = location.parent;
                }
                else if (location.parent && (isJsxOpeningLikeElement(location.parent) || isTaggedTemplateExpression(location.parent)) && isFunctionLike(symbol.valueDeclaration)) {
                    callExpressionLike = location.parent;
                }
                if (callExpressionLike) {
                    signature = typeChecker.getResolvedSignature(callExpressionLike);
                    const useConstructSignatures = callExpressionLike.kind === 211 /* NewExpression */ || isCallExpression(callExpressionLike) && callExpressionLike.expression.kind === 106 /* SuperKeyword */;
                    const allSignatures = useConstructSignatures ? type.getConstructSignatures() : type.getCallSignatures();
                    if (signature && !contains(allSignatures, signature.target) && !contains(allSignatures, signature)) {
                        signature = allSignatures.length ? allSignatures[0] : void 0;
                    }
                    if (signature) {
                        if (useConstructSignatures && symbolFlags & 32 /* Class */) {
                            symbolKind = "constructor" /* constructorImplementationElement */;
                            addPrefixForAnyFunctionOrVar(type.symbol, symbolKind);
                        }
                        else if (symbolFlags & 2097152 /* Alias */) {
                            symbolKind = "alias" /* alias */;
                            pushSymbolKind(symbolKind);
                            displayParts.push(spacePart());
                            if (useConstructSignatures) {
                                if (signature.flags & 4 /* Abstract */) {
                                    displayParts.push(keywordPart(126 /* AbstractKeyword */));
                                    displayParts.push(spacePart());
                                }
                                displayParts.push(keywordPart(103 /* NewKeyword */));
                                displayParts.push(spacePart());
                            }
                            addFullSymbolName(symbol);
                        }
                        else {
                            addPrefixForAnyFunctionOrVar(symbol, symbolKind);
                        }
                        switch (symbolKind) {
                            case "JSX attribute" /* jsxAttribute */:
                            case "property" /* memberVariableElement */:
                            case "var" /* variableElement */:
                            case "const" /* constElement */:
                            case "let" /* letElement */:
                            case "parameter" /* parameterElement */:
                            case "local var" /* localVariableElement */:
                                displayParts.push(punctuationPart(58 /* ColonToken */));
                                displayParts.push(spacePart());
                                if (!(getObjectFlags(type) & 16 /* Anonymous */) && type.symbol) {
                                    addRange(displayParts, symbolToDisplayParts(typeChecker, type.symbol, enclosingDeclaration, 
                                    /*meaning*/
                                    void 0, 4 /* AllowAnyNodeKind */ | 1 /* WriteTypeParametersOrArguments */));
                                    displayParts.push(lineBreakPart());
                                }
                                if (useConstructSignatures) {
                                    if (signature.flags & 4 /* Abstract */) {
                                        displayParts.push(keywordPart(126 /* AbstractKeyword */));
                                        displayParts.push(spacePart());
                                    }
                                    displayParts.push(keywordPart(103 /* NewKeyword */));
                                    displayParts.push(spacePart());
                                }
                                addSignatureDisplayParts(signature, allSignatures, 262144 /* WriteArrowStyleSignature */);
                                break;
                            default:
                                addSignatureDisplayParts(signature, allSignatures);
                        }
                        hasAddedSymbolInfo = true;
                        hasMultipleSignatures = allSignatures.length > 1;
                    }
                }
                else if (isNameOfFunctionDeclaration(location) && !(symbolFlags & 98304 /* Accessor */) || // name of function declaration
                    location.kind === 135 /* ConstructorKeyword */ && location.parent.kind === 173 /* Constructor */) {
                    const functionDeclaration = location.parent;
                    const locationIsSymbolDeclaration = symbol.declarations && find(symbol.declarations, (declaration) => declaration === (location.kind === 135 /* ConstructorKeyword */ ? functionDeclaration.parent : functionDeclaration));
                    if (locationIsSymbolDeclaration) {
                        const allSignatures = functionDeclaration.kind === 173 /* Constructor */ ? type.getNonNullableType().getConstructSignatures() : type.getNonNullableType().getCallSignatures();
                        if (!typeChecker.isImplementationOfOverload(functionDeclaration)) {
                            signature = typeChecker.getSignatureFromDeclaration(functionDeclaration);
                        }
                        else {
                            signature = allSignatures[0];
                        }
                        if (functionDeclaration.kind === 173 /* Constructor */) {
                            symbolKind = "constructor" /* constructorImplementationElement */;
                            addPrefixForAnyFunctionOrVar(type.symbol, symbolKind);
                        }
                        else {
                            addPrefixForAnyFunctionOrVar(functionDeclaration.kind === 176 /* CallSignature */ && !(type.symbol.flags & 2048 /* TypeLiteral */ || type.symbol.flags & 4096 /* ObjectLiteral */) ? type.symbol : symbol, symbolKind);
                        }
                        if (signature) {
                            addSignatureDisplayParts(signature, allSignatures);
                        }
                        hasAddedSymbolInfo = true;
                        hasMultipleSignatures = allSignatures.length > 1;
                    }
                }
            }
            if (symbolFlags & 32 /* Class */ && !hasAddedSymbolInfo && !isThisExpression) {
                addAliasPrefixIfNecessary();
                if (getDeclarationOfKind(symbol, 228 /* ClassExpression */)) {
                    pushSymbolKind("local class" /* localClassElement */);
                }
                else {
                    displayParts.push(keywordPart(84 /* ClassKeyword */));
                }
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                writeTypeParametersOfSymbol(symbol, sourceFile);
            }
            if (symbolFlags & 64 /* Interface */ && semanticMeaning & 2 /* Type */) {
                prefixNextMeaning();
                displayParts.push(keywordPart(118 /* InterfaceKeyword */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                writeTypeParametersOfSymbol(symbol, sourceFile);
            }
            if (symbolFlags & 524288 /* TypeAlias */ && semanticMeaning & 2 /* Type */) {
                prefixNextMeaning();
                displayParts.push(keywordPart(154 /* TypeKeyword */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                writeTypeParametersOfSymbol(symbol, sourceFile);
                displayParts.push(spacePart());
                displayParts.push(operatorPart(63 /* EqualsToken */));
                displayParts.push(spacePart());
                addRange(displayParts, typeToDisplayParts(typeChecker, isConstTypeReference(location.parent) ? typeChecker.getTypeAtLocation(location.parent) : typeChecker.getDeclaredTypeOfSymbol(symbol), enclosingDeclaration, 8388608 /* InTypeAlias */));
            }
            if (symbolFlags & 384 /* Enum */) {
                prefixNextMeaning();
                if (some(symbol.declarations, (d) => isEnumDeclaration(d) && isEnumConst(d))) {
                    displayParts.push(keywordPart(85 /* ConstKeyword */));
                    displayParts.push(spacePart());
                }
                displayParts.push(keywordPart(92 /* EnumKeyword */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
            }
            if (symbolFlags & 1536 /* Module */ && !isThisExpression) {
                prefixNextMeaning();
                const declaration = getDeclarationOfKind(symbol, 264 /* ModuleDeclaration */);
                const isNamespace = declaration && declaration.name && declaration.name.kind === 79 /* Identifier */;
                displayParts.push(keywordPart(isNamespace ? 143 /* NamespaceKeyword */ : 142 /* ModuleKeyword */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
            }
            if (symbolFlags & 262144 /* TypeParameter */ && semanticMeaning & 2 /* Type */) {
                prefixNextMeaning();
                displayParts.push(punctuationPart(20 /* OpenParenToken */));
                displayParts.push(textPart("type parameter"));
                displayParts.push(punctuationPart(21 /* CloseParenToken */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                if (symbol.parent) {
                    addInPrefix();
                    addFullSymbolName(symbol.parent, enclosingDeclaration);
                    writeTypeParametersOfSymbol(symbol.parent, enclosingDeclaration);
                }
                else {
                    const decl = getDeclarationOfKind(symbol, 165 /* TypeParameter */);
                    if (decl === void 0)
                        return Debug.fail();
                    const declaration = decl.parent;
                    if (declaration) {
                        if (isFunctionLike(declaration)) {
                            addInPrefix();
                            const signature = typeChecker.getSignatureFromDeclaration(declaration);
                            if (declaration.kind === 177 /* ConstructSignature */) {
                                displayParts.push(keywordPart(103 /* NewKeyword */));
                                displayParts.push(spacePart());
                            }
                            else if (declaration.kind !== 176 /* CallSignature */ && declaration.name) {
                                addFullSymbolName(declaration.symbol);
                            }
                            addRange(displayParts, signatureToDisplayParts(typeChecker, signature, sourceFile, 32 /* WriteTypeArgumentsOfSignature */));
                        }
                        else if (isTypeAliasDeclaration(declaration)) {
                            addInPrefix();
                            displayParts.push(keywordPart(154 /* TypeKeyword */));
                            displayParts.push(spacePart());
                            addFullSymbolName(declaration.symbol);
                            writeTypeParametersOfSymbol(declaration.symbol, sourceFile);
                        }
                    }
                }
            }
            if (symbolFlags & 8 /* EnumMember */) {
                symbolKind = "enum member" /* enumMemberElement */;
                addPrefixForAnyFunctionOrVar(symbol, "enum member");
                const declaration = (_a2 = symbol.declarations) == null ? void 0 : _a2[0];
                if ((declaration == null ? void 0 : declaration.kind) === 302 /* EnumMember */) {
                    const constantValue = typeChecker.getConstantValue(declaration);
                    if (constantValue !== void 0) {
                        displayParts.push(spacePart());
                        displayParts.push(operatorPart(63 /* EqualsToken */));
                        displayParts.push(spacePart());
                        displayParts.push(displayPart(getTextOfConstantValue(constantValue), typeof constantValue === "number" ? 7 /* numericLiteral */ : 8 /* stringLiteral */));
                    }
                }
            }
            if (symbol.flags & 2097152 /* Alias */) {
                prefixNextMeaning();
                if (!hasAddedSymbolInfo) {
                    const resolvedSymbol = typeChecker.getAliasedSymbol(symbol);
                    if (resolvedSymbol !== symbol && resolvedSymbol.declarations && resolvedSymbol.declarations.length > 0) {
                        const resolvedNode = resolvedSymbol.declarations[0];
                        const declarationName = getNameOfDeclaration(resolvedNode);
                        if (declarationName) {
                            const isExternalModuleDeclaration = isModuleWithStringLiteralName(resolvedNode) && hasSyntacticModifier(resolvedNode, 2 /* Ambient */);
                            const shouldUseAliasName = symbol.name !== "default" && !isExternalModuleDeclaration;
                            const resolvedInfo = getSymbolDisplayPartsDocumentationAndSymbolKind(typeChecker, resolvedSymbol, getSourceFileOfNode(resolvedNode), resolvedNode, declarationName, semanticMeaning, shouldUseAliasName ? symbol : resolvedSymbol);
                            displayParts.push(...resolvedInfo.displayParts);
                            displayParts.push(lineBreakPart());
                            documentationFromAlias = resolvedInfo.documentation;
                            tagsFromAlias = resolvedInfo.tags;
                        }
                        else {
                            documentationFromAlias = resolvedSymbol.getContextualDocumentationComment(resolvedNode, typeChecker);
                            tagsFromAlias = resolvedSymbol.getJsDocTags(typeChecker);
                        }
                    }
                }
                if (symbol.declarations) {
                    switch (symbol.declarations[0].kind) {
                        case 267 /* NamespaceExportDeclaration */:
                            displayParts.push(keywordPart(93 /* ExportKeyword */));
                            displayParts.push(spacePart());
                            displayParts.push(keywordPart(143 /* NamespaceKeyword */));
                            break;
                        case 274 /* ExportAssignment */:
                            displayParts.push(keywordPart(93 /* ExportKeyword */));
                            displayParts.push(spacePart());
                            displayParts.push(keywordPart(symbol.declarations[0].isExportEquals ? 63 /* EqualsToken */ : 88 /* DefaultKeyword */));
                            break;
                        case 278 /* ExportSpecifier */:
                            displayParts.push(keywordPart(93 /* ExportKeyword */));
                            break;
                        default:
                            displayParts.push(keywordPart(100 /* ImportKeyword */));
                    }
                }
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                forEach(symbol.declarations, (declaration) => {
                    if (declaration.kind === 268 /* ImportEqualsDeclaration */) {
                        const importEqualsDeclaration = declaration;
                        if (isExternalModuleImportEqualsDeclaration(importEqualsDeclaration)) {
                            displayParts.push(spacePart());
                            displayParts.push(operatorPart(63 /* EqualsToken */));
                            displayParts.push(spacePart());
                            displayParts.push(keywordPart(147 /* RequireKeyword */));
                            displayParts.push(punctuationPart(20 /* OpenParenToken */));
                            displayParts.push(displayPart(getTextOfNode(getExternalModuleImportEqualsDeclarationExpression(importEqualsDeclaration)), 8 /* stringLiteral */));
                            displayParts.push(punctuationPart(21 /* CloseParenToken */));
                        }
                        else {
                            const internalAliasSymbol = typeChecker.getSymbolAtLocation(importEqualsDeclaration.moduleReference);
                            if (internalAliasSymbol) {
                                displayParts.push(spacePart());
                                displayParts.push(operatorPart(63 /* EqualsToken */));
                                displayParts.push(spacePart());
                                addFullSymbolName(internalAliasSymbol, enclosingDeclaration);
                            }
                        }
                        return true;
                    }
                });
            }
            if (!hasAddedSymbolInfo) {
                if (symbolKind !== "" /* unknown */) {
                    if (type) {
                        if (isThisExpression) {
                            prefixNextMeaning();
                            displayParts.push(keywordPart(108 /* ThisKeyword */));
                        }
                        else {
                            addPrefixForAnyFunctionOrVar(symbol, symbolKind);
                        }
                        if (symbolKind === "property" /* memberVariableElement */ || symbolKind === "accessor" /* memberAccessorVariableElement */ || symbolKind === "getter" /* memberGetAccessorElement */ || symbolKind === "setter" /* memberSetAccessorElement */ || symbolKind === "JSX attribute" /* jsxAttribute */ || symbolFlags & 3 /* Variable */ || symbolKind === "local var" /* localVariableElement */ || symbolKind === "index" /* indexSignatureElement */ || isThisExpression) {
                            displayParts.push(punctuationPart(58 /* ColonToken */));
                            displayParts.push(spacePart());
                            if (type.symbol && type.symbol.flags & 262144 /* TypeParameter */ && symbolKind !== "index" /* indexSignatureElement */) {
                                const typeParameterParts = mapToDisplayParts((writer) => {
                                    const param = typeChecker.typeParameterToDeclaration(type, enclosingDeclaration, symbolDisplayNodeBuilderFlags);
                                    getPrinter().writeNode(4 /* Unspecified */, param, getSourceFileOfNode(getParseTreeNode(enclosingDeclaration)), writer);
                                });
                                addRange(displayParts, typeParameterParts);
                            }
                            else {
                                addRange(displayParts, typeToDisplayParts(typeChecker, type, enclosingDeclaration));
                            }
                            if (isTransientSymbol(symbol) && symbol.links.target && isTransientSymbol(symbol.links.target) && symbol.links.target.links.tupleLabelDeclaration) {
                                const labelDecl = symbol.links.target.links.tupleLabelDeclaration;
                                Debug.assertNode(labelDecl.name, isIdentifier);
                                displayParts.push(spacePart());
                                displayParts.push(punctuationPart(20 /* OpenParenToken */));
                                displayParts.push(textPart(idText(labelDecl.name)));
                                displayParts.push(punctuationPart(21 /* CloseParenToken */));
                            }
                        }
                        else if (symbolFlags & 16 /* Function */ || symbolFlags & 8192 /* Method */ || symbolFlags & 16384 /* Constructor */ || symbolFlags & 131072 /* Signature */ || symbolFlags & 98304 /* Accessor */ || symbolKind === "method" /* memberFunctionElement */) {
                            const allSignatures = type.getNonNullableType().getCallSignatures();
                            if (allSignatures.length) {
                                addSignatureDisplayParts(allSignatures[0], allSignatures);
                                hasMultipleSignatures = allSignatures.length > 1;
                            }
                        }
                    }
                }
                else {
                    symbolKind = getSymbolKind(typeChecker, symbol, location);
                }
            }
            if (documentation.length === 0 && !hasMultipleSignatures) {
                documentation = symbol.getContextualDocumentationComment(enclosingDeclaration, typeChecker);
            }
            if (documentation.length === 0 && symbolFlags & 4 /* Property */) {
                if (symbol.parent && symbol.declarations && forEach(symbol.parent.declarations, (declaration) => declaration.kind === 308 /* SourceFile */)) {
                    for (const declaration of symbol.declarations) {
                        if (!declaration.parent || declaration.parent.kind !== 223 /* BinaryExpression */) {
                            continue;
                        }
                        const rhsSymbol = typeChecker.getSymbolAtLocation(declaration.parent.right);
                        if (!rhsSymbol) {
                            continue;
                        }
                        documentation = rhsSymbol.getDocumentationComment(typeChecker);
                        tags = rhsSymbol.getJsDocTags(typeChecker);
                        if (documentation.length > 0) {
                            break;
                        }
                    }
                }
            }
            if (documentation.length === 0 && isIdentifier(location) && symbol.valueDeclaration && isBindingElement(symbol.valueDeclaration)) {
                const declaration = symbol.valueDeclaration;
                const parent2 = declaration.parent;
                if (isIdentifier(declaration.name) && isObjectBindingPattern(parent2)) {
                    const name = getTextOfIdentifierOrLiteral(declaration.name);
                    const objectType = typeChecker.getTypeAtLocation(parent2);
                    documentation = firstDefined(objectType.isUnion() ? objectType.types : [objectType], (t) => {
                        const prop = t.getProperty(name);
                        return prop ? prop.getDocumentationComment(typeChecker) : void 0;
                    }) || emptyArray;
                }
            }
            if (tags.length === 0 && !hasMultipleSignatures) {
                tags = symbol.getContextualJsDocTags(enclosingDeclaration, typeChecker);
            }
            if (documentation.length === 0 && documentationFromAlias) {
                documentation = documentationFromAlias;
            }
            if (tags.length === 0 && tagsFromAlias) {
                tags = tagsFromAlias;
            }
            return { displayParts, documentation, symbolKind, tags: tags.length === 0 ? void 0 : tags };
            function getPrinter() {
                return createPrinterWithRemoveComments();
            }
            function prefixNextMeaning() {
                if (displayParts.length) {
                    displayParts.push(lineBreakPart());
                }
                addAliasPrefixIfNecessary();
            }
            function addAliasPrefixIfNecessary() {
                if (alias) {
                    pushSymbolKind("alias" /* alias */);
                    displayParts.push(spacePart());
                }
            }
            function addInPrefix() {
                displayParts.push(spacePart());
                displayParts.push(keywordPart(101 /* InKeyword */));
                displayParts.push(spacePart());
            }
            function addFullSymbolName(symbolToDisplay, enclosingDeclaration2) {
                let indexInfos;
                if (alias && symbolToDisplay === symbol) {
                    symbolToDisplay = alias;
                }
                if (symbolKind === "index" /* indexSignatureElement */) {
                    indexInfos = typeChecker.getIndexInfosOfIndexSymbol(symbolToDisplay);
                }
                let fullSymbolDisplayParts = [];
                if (symbolToDisplay.flags & 131072 /* Signature */ && indexInfos) {
                    if (symbolToDisplay.parent) {
                        fullSymbolDisplayParts = symbolToDisplayParts(typeChecker, symbolToDisplay.parent);
                    }
                    fullSymbolDisplayParts.push(punctuationPart(22 /* OpenBracketToken */));
                    indexInfos.forEach((info, i) => {
                        fullSymbolDisplayParts.push(...typeToDisplayParts(typeChecker, info.keyType));
                        if (i !== indexInfos.length - 1) {
                            fullSymbolDisplayParts.push(spacePart());
                            fullSymbolDisplayParts.push(punctuationPart(51 /* BarToken */));
                            fullSymbolDisplayParts.push(spacePart());
                        }
                    });
                    fullSymbolDisplayParts.push(punctuationPart(23 /* CloseBracketToken */));
                }
                else {
                    fullSymbolDisplayParts = symbolToDisplayParts(typeChecker, symbolToDisplay, enclosingDeclaration2 || sourceFile, 
                    /*meaning*/
                    void 0, 1 /* WriteTypeParametersOrArguments */ | 2 /* UseOnlyExternalAliasing */ | 4 /* AllowAnyNodeKind */);
                }
                addRange(displayParts, fullSymbolDisplayParts);
                if (symbol.flags & 16777216 /* Optional */) {
                    displayParts.push(punctuationPart(57 /* QuestionToken */));
                }
            }
            function addPrefixForAnyFunctionOrVar(symbol2, symbolKind2) {
                prefixNextMeaning();
                if (symbolKind2) {
                    pushSymbolKind(symbolKind2);
                    if (symbol2 && !some(symbol2.declarations, (d) => isArrowFunction(d) || (isFunctionExpression(d) || isClassExpression(d)) && !d.name)) {
                        displayParts.push(spacePart());
                        addFullSymbolName(symbol2);
                    }
                }
            }
            function pushSymbolKind(symbolKind2) {
                switch (symbolKind2) {
                    case "var" /* variableElement */:
                    case "function" /* functionElement */:
                    case "let" /* letElement */:
                    case "const" /* constElement */:
                    case "constructor" /* constructorImplementationElement */:
                        displayParts.push(textOrKeywordPart(symbolKind2));
                        return;
                    default:
                        displayParts.push(punctuationPart(20 /* OpenParenToken */));
                        displayParts.push(textOrKeywordPart(symbolKind2));
                        displayParts.push(punctuationPart(21 /* CloseParenToken */));
                        return;
                }
            }
            function addSignatureDisplayParts(signature, allSignatures, flags = 0 /* None */) {
                addRange(displayParts, signatureToDisplayParts(typeChecker, signature, enclosingDeclaration, flags | 32 /* WriteTypeArgumentsOfSignature */));
                if (allSignatures.length > 1) {
                    displayParts.push(spacePart());
                    displayParts.push(punctuationPart(20 /* OpenParenToken */));
                    displayParts.push(operatorPart(39 /* PlusToken */));
                    displayParts.push(displayPart((allSignatures.length - 1).toString(), 7 /* numericLiteral */));
                    displayParts.push(spacePart());
                    displayParts.push(textPart(allSignatures.length === 2 ? "overload" : "overloads"));
                    displayParts.push(punctuationPart(21 /* CloseParenToken */));
                }
                documentation = signature.getDocumentationComment(typeChecker);
                tags = signature.getJsDocTags();
                if (allSignatures.length > 1 && documentation.length === 0 && tags.length === 0) {
                    documentation = allSignatures[0].getDocumentationComment(typeChecker);
                    tags = allSignatures[0].getJsDocTags().filter((tag) => tag.name !== "deprecated");
                }
            }
            function writeTypeParametersOfSymbol(symbol2, enclosingDeclaration2) {
                const typeParameterParts = mapToDisplayParts((writer) => {
                    const params = typeChecker.symbolToTypeParameterDeclarations(symbol2, enclosingDeclaration2, symbolDisplayNodeBuilderFlags);
                    getPrinter().writeList(53776 /* TypeParameters */, params, getSourceFileOfNode(getParseTreeNode(enclosingDeclaration2)), writer);
                });
                addRange(displayParts, typeParameterParts);
            }
        }
        function isLocalVariableOrFunction(symbol) {
            if (symbol.parent) {
                return false;
            }
            return forEach(symbol.declarations, (declaration) => {
                if (declaration.kind === 215 /* FunctionExpression */) {
                    return true;
                }
                if (declaration.kind !== 257 /* VariableDeclaration */ && declaration.kind !== 259 /* FunctionDeclaration */) {
                    return false;
                }
                for (let parent2 = declaration.parent; !isFunctionBlock(parent2); parent2 = parent2.parent) {
                    if (parent2.kind === 308 /* SourceFile */ || parent2.kind === 265 /* ModuleBlock */) {
                        return false;
                    }
                }
                return true;
            });
        }
        var symbolDisplayNodeBuilderFlags;
        var init_symbolDisplay = __esm({
            "src/services/symbolDisplay.ts"() {
                "use strict";
                init_ts4();
                symbolDisplayNodeBuilderFlags = 8192 /* OmitParameterModifiers */ | 70221824 /* IgnoreErrors */ | 16384 /* UseAliasDefinedOutsideCurrentScope */;
            }
        });
        // src/services/_namespaces/ts.SymbolDisplay.ts
        var ts_SymbolDisplay_exports = {};
        __export(ts_SymbolDisplay_exports, {
            getSymbolDisplayPartsDocumentationAndSymbolKind: () => getSymbolDisplayPartsDocumentationAndSymbolKind,
            getSymbolKind: () => getSymbolKind,
            getSymbolModifiers: () => getSymbolModifiers
        });
        var init_ts_SymbolDisplay = __esm({
            "src/services/_namespaces/ts.SymbolDisplay.ts"() {
                "use strict";
                init_symbolDisplay();
            }
        });
        // src/services/textChanges.ts
        function getPos2(n) {
            const result = n.__pos;
            Debug.assert(typeof result === "number");
            return result;
        }
        function setPos(n, pos) {
            Debug.assert(typeof pos === "number");
            n.__pos = pos;
        }
        function getEnd(n) {
            const result = n.__end;
            Debug.assert(typeof result === "number");
            return result;
        }
        function setEnd(n, end) {
            Debug.assert(typeof end === "number");
            n.__end = end;
        }
        function skipWhitespacesAndLineBreaks(text, start) {
            return skipTrivia(text, start, 
            /*stopAfterLineBreak*/
            false, 
            /*stopAtComments*/
            true);
        }
        function hasCommentsBeforeLineBreak(text, start) {
            let i = start;
            while (i < text.length) {
                const ch = text.charCodeAt(i);
                if (isWhiteSpaceSingleLine(ch)) {
                    i++;
                    continue;
                }
                return ch === 47 /* slash */;
            }
            return false;
        }
        function getAdjustedRange(sourceFile, startNode2, endNode2, options) {
            return { pos: getAdjustedStartPosition(sourceFile, startNode2, options), end: getAdjustedEndPosition(sourceFile, endNode2, options) };
        }
        function getAdjustedStartPosition(sourceFile, node, options, hasTrailingComment = false) {
            var _a2, _b;
            const { leadingTriviaOption } = options;
            if (leadingTriviaOption === 0 /* Exclude */) {
                return node.getStart(sourceFile);
            }
            if (leadingTriviaOption === 3 /* StartLine */) {
                const startPos = node.getStart(sourceFile);
                const pos = getLineStartPositionForPosition(startPos, sourceFile);
                return rangeContainsPosition(node, pos) ? pos : startPos;
            }
            if (leadingTriviaOption === 2 /* JSDoc */) {
                const JSDocComments = getJSDocCommentRanges(node, sourceFile.text);
                if (JSDocComments == null ? void 0 : JSDocComments.length) {
                    return getLineStartPositionForPosition(JSDocComments[0].pos, sourceFile);
                }
            }
            const fullStart = node.getFullStart();
            const start = node.getStart(sourceFile);
            if (fullStart === start) {
                return start;
            }
            const fullStartLine = getLineStartPositionForPosition(fullStart, sourceFile);
            const startLine = getLineStartPositionForPosition(start, sourceFile);
            if (startLine === fullStartLine) {
                return leadingTriviaOption === 1 /* IncludeAll */ ? fullStart : start;
            }
            if (hasTrailingComment) {
                const comment = ((_a2 = getLeadingCommentRanges(sourceFile.text, fullStart)) == null ? void 0 : _a2[0]) || ((_b = getTrailingCommentRanges(sourceFile.text, fullStart)) == null ? void 0 : _b[0]);
                if (comment) {
                    return skipTrivia(sourceFile.text, comment.end, 
                    /*stopAfterLineBreak*/
                    true, 
                    /*stopAtComments*/
                    true);
                }
            }
            const nextLineStart = fullStart > 0 ? 1 : 0;
            let adjustedStartPosition = getStartPositionOfLine(getLineOfLocalPosition(sourceFile, fullStartLine) + nextLineStart, sourceFile);
            adjustedStartPosition = skipWhitespacesAndLineBreaks(sourceFile.text, adjustedStartPosition);
            return getStartPositionOfLine(getLineOfLocalPosition(sourceFile, adjustedStartPosition), sourceFile);
        }
        function getEndPositionOfMultilineTrailingComment(sourceFile, node, options) {
            const { end } = node;
            const { trailingTriviaOption } = options;
            if (trailingTriviaOption === 2 /* Include */) {
                const comments = getTrailingCommentRanges(sourceFile.text, end);
                if (comments) {
                    const nodeEndLine = getLineOfLocalPosition(sourceFile, node.end);
                    for (const comment of comments) {
                        if (comment.kind === 2 /* SingleLineCommentTrivia */ || getLineOfLocalPosition(sourceFile, comment.pos) > nodeEndLine) {
                            break;
                        }
                        const commentEndLine = getLineOfLocalPosition(sourceFile, comment.end);
                        if (commentEndLine > nodeEndLine) {
                            return skipTrivia(sourceFile.text, comment.end, 
                            /*stopAfterLineBreak*/
                            true, 
                            /*stopAtComments*/
                            true);
                        }
                    }
                }
            }
            return void 0;
        }
        function getAdjustedEndPosition(sourceFile, node, options) {
            var _a2;
            const { end } = node;
            const { trailingTriviaOption } = options;
            if (trailingTriviaOption === 0 /* Exclude */) {
                return end;
            }
            if (trailingTriviaOption === 1 /* ExcludeWhitespace */) {
                const comments = concatenate(getTrailingCommentRanges(sourceFile.text, end), getLeadingCommentRanges(sourceFile.text, end));
                const realEnd = (_a2 = comments == null ? void 0 : comments[comments.length - 1]) == null ? void 0 : _a2.end;
                if (realEnd) {
                    return realEnd;
                }
                return end;
            }
            const multilineEndPosition = getEndPositionOfMultilineTrailingComment(sourceFile, node, options);
            if (multilineEndPosition) {
                return multilineEndPosition;
            }
            const newEnd = skipTrivia(sourceFile.text, end, 
            /*stopAfterLineBreak*/
            true);
            return newEnd !== end && (trailingTriviaOption === 2 /* Include */ || isLineBreak(sourceFile.text.charCodeAt(newEnd - 1))) ? newEnd : end;
        }
        function isSeparator(node, candidate) {
            return !!candidate && !!node.parent && (candidate.kind === 27 /* CommaToken */ || candidate.kind === 26 /* SemicolonToken */ && node.parent.kind === 207 /* ObjectLiteralExpression */);
        }
        function isThisTypeAnnotatable(containingFunction) {
            return isFunctionExpression(containingFunction) || isFunctionDeclaration(containingFunction);
        }
        function updateJSDocHost(parent2) {
            if (parent2.kind !== 216 /* ArrowFunction */) {
                return parent2;
            }
            const jsDocNode = parent2.parent.kind === 169 /* PropertyDeclaration */ ? parent2.parent : parent2.parent.parent;
            jsDocNode.jsDoc = parent2.jsDoc;
            return jsDocNode;
        }
        function tryMergeJsdocTags(oldTag, newTag) {
            if (oldTag.kind !== newTag.kind) {
                return void 0;
            }
            switch (oldTag.kind) {
                case 344 /* JSDocParameterTag */: {
                    const oldParam = oldTag;
                    const newParam = newTag;
                    return isIdentifier(oldParam.name) && isIdentifier(newParam.name) && oldParam.name.escapedText === newParam.name.escapedText ? factory.createJSDocParameterTag(
                    /*tagName*/
                    void 0, newParam.name, 
                    /*isBracketed*/
                    false, newParam.typeExpression, newParam.isNameFirst, oldParam.comment) : void 0;
                }
                case 345 /* JSDocReturnTag */:
                    return factory.createJSDocReturnTag(
                    /*tagName*/
                    void 0, newTag.typeExpression, oldTag.comment);
                case 347 /* JSDocTypeTag */:
                    return factory.createJSDocTypeTag(
                    /*tagName*/
                    void 0, newTag.typeExpression, oldTag.comment);
            }
        }
        function startPositionToDeleteNodeInList(sourceFile, node) {
            return skipTrivia(sourceFile.text, getAdjustedStartPosition(sourceFile, node, { leadingTriviaOption: 1 /* IncludeAll */ }), 
            /*stopAfterLineBreak*/
            false, 
            /*stopAtComments*/
            true);
        }
        function endPositionToDeleteNodeInList(sourceFile, node, prevNode, nextNode) {
            const end = startPositionToDeleteNodeInList(sourceFile, nextNode);
            if (prevNode === void 0 || positionsAreOnSameLine(getAdjustedEndPosition(sourceFile, node, {}), end, sourceFile)) {
                return end;
            }
            const token = findPrecedingToken(nextNode.getStart(sourceFile), sourceFile);
            if (isSeparator(node, token)) {
                const prevToken = findPrecedingToken(node.getStart(sourceFile), sourceFile);
                if (isSeparator(prevNode, prevToken)) {
                    const pos = skipTrivia(sourceFile.text, token.getEnd(), 
                    /*stopAfterLineBreak*/
                    true, 
                    /*stopAtComments*/
                    true);
                    if (positionsAreOnSameLine(prevToken.getStart(sourceFile), token.getStart(sourceFile), sourceFile)) {
                        return isLineBreak(sourceFile.text.charCodeAt(pos - 1)) ? pos - 1 : pos;
                    }
                    if (isLineBreak(sourceFile.text.charCodeAt(pos))) {
                        return pos;
                    }
                }
            }
            return end;
        }
        function getClassOrObjectBraceEnds(cls, sourceFile) {
            const open = findChildOfKind(cls, 18 /* OpenBraceToken */, sourceFile);
            const close = findChildOfKind(cls, 19 /* CloseBraceToken */, sourceFile);
            return [open == null ? void 0 : open.end, close == null ? void 0 : close.end];
        }
        function getMembersOrProperties(node) {
            return isObjectLiteralExpression(node) ? node.properties : node.members;
        }
        function getNewFileText(statements, scriptKind, newLineCharacter, formatContext) {
            return changesToText.newFileChangesWorker(
            /*oldFile*/
            void 0, scriptKind, statements, newLineCharacter, formatContext);
        }
        function applyChanges(text, changes) {
            for (let i = changes.length - 1; i >= 0; i--) {
                const { span, newText } = changes[i];
                text = `${text.substring(0, span.start)}${newText}${text.substring(textSpanEnd(span))}`;
            }
            return text;
        }
        function isTrivia2(s) {
            return skipTrivia(s, 0) === s.length;
        }
        function assignPositionsToNode(node) {
            const visited = visitEachChild(node, assignPositionsToNode, textChangesTransformationContext, assignPositionsToNodeArray, assignPositionsToNode);
            const newNode = nodeIsSynthesized(visited) ? visited : Object.create(visited);
            setTextRangePosEnd(newNode, getPos2(node), getEnd(node));
            return newNode;
        }
        function assignPositionsToNodeArray(nodes, visitor, test, start, count) {
            const visited = visitNodes2(nodes, visitor, test, start, count);
            if (!visited) {
                return visited;
            }
            Debug.assert(nodes);
            const nodeArray = visited === nodes ? factory.createNodeArray(visited.slice(0)) : visited;
            setTextRangePosEnd(nodeArray, getPos2(nodes), getEnd(nodes));
            return nodeArray;
        }
        function createWriter(newLine) {
            let lastNonTriviaPosition = 0;
            const writer = createTextWriter(newLine);
            const onBeforeEmitNode = (node) => {
                if (node) {
                    setPos(node, lastNonTriviaPosition);
                }
            };
            const onAfterEmitNode = (node) => {
                if (node) {
                    setEnd(node, lastNonTriviaPosition);
                }
            };
            const onBeforeEmitNodeArray = (nodes) => {
                if (nodes) {
                    setPos(nodes, lastNonTriviaPosition);
                }
            };
            const onAfterEmitNodeArray = (nodes) => {
                if (nodes) {
                    setEnd(nodes, lastNonTriviaPosition);
                }
            };
            const onBeforeEmitToken = (node) => {
                if (node) {
                    setPos(node, lastNonTriviaPosition);
                }
            };
            const onAfterEmitToken = (node) => {
                if (node) {
                    setEnd(node, lastNonTriviaPosition);
                }
            };
            function setLastNonTriviaPosition(s, force) {
                if (force || !isTrivia2(s)) {
                    lastNonTriviaPosition = writer.getTextPos();
                    let i = 0;
                    while (isWhiteSpaceLike(s.charCodeAt(s.length - i - 1))) {
                        i++;
                    }
                    lastNonTriviaPosition -= i;
                }
            }
            function write(s) {
                writer.write(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeComment(s) {
                writer.writeComment(s);
            }
            function writeKeyword(s) {
                writer.writeKeyword(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeOperator(s) {
                writer.writeOperator(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writePunctuation(s) {
                writer.writePunctuation(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeTrailingSemicolon(s) {
                writer.writeTrailingSemicolon(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeParameter(s) {
                writer.writeParameter(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeProperty(s) {
                writer.writeProperty(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeSpace(s) {
                writer.writeSpace(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeStringLiteral(s) {
                writer.writeStringLiteral(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeSymbol(s, sym) {
                writer.writeSymbol(s, sym);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeLine(force) {
                writer.writeLine(force);
            }
            function increaseIndent() {
                writer.increaseIndent();
            }
            function decreaseIndent() {
                writer.decreaseIndent();
            }
            function getText() {
                return writer.getText();
            }
            function rawWrite(s) {
                writer.rawWrite(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeLiteral(s) {
                writer.writeLiteral(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                true);
            }
            function getTextPos() {
                return writer.getTextPos();
            }
            function getLine() {
                return writer.getLine();
            }
            function getColumn() {
                return writer.getColumn();
            }
            function getIndent() {
                return writer.getIndent();
            }
            function isAtStartOfLine() {
                return writer.isAtStartOfLine();
            }
            function clear2() {
                writer.clear();
                lastNonTriviaPosition = 0;
            }
            return {
                onBeforeEmitNode,
                onAfterEmitNode,
                onBeforeEmitNodeArray,
                onAfterEmitNodeArray,
                onBeforeEmitToken,
                onAfterEmitToken,
                write,
                writeComment,
                writeKeyword,
                writeOperator,
                writePunctuation,
                writeTrailingSemicolon,
                writeParameter,
                writeProperty,
                writeSpace,
                writeStringLiteral,
                writeSymbol,
                writeLine,
                increaseIndent,
                decreaseIndent,
                getText,
                rawWrite,
                writeLiteral,
                getTextPos,
                getLine,
                getColumn,
                getIndent,
                isAtStartOfLine,
                hasTrailingComment: () => writer.hasTrailingComment(),
                hasTrailingWhitespace: () => writer.hasTrailingWhitespace(),
                clear: clear2
            };
        }
        function getInsertionPositionAtSourceFileTop(sourceFile) {
            let lastPrologue;
            for (const node of sourceFile.statements) {
                if (isPrologueDirective(node)) {
                    lastPrologue = node;
                }
                else {
                    break;
                }
            }
            let position = 0;
            const text = sourceFile.text;
            if (lastPrologue) {
                position = lastPrologue.end;
                advancePastLineBreak();
                return position;
            }
            const shebang = getShebang(text);
            if (shebang !== void 0) {
                position = shebang.length;
                advancePastLineBreak();
            }
            const ranges = getLeadingCommentRanges(text, position);
            if (!ranges)
                return position;
            let lastComment;
            let firstNodeLine;
            for (const range of ranges) {
                if (range.kind === 3 /* MultiLineCommentTrivia */) {
                    if (isPinnedComment(text, range.pos)) {
                        lastComment = { range, pinnedOrTripleSlash: true };
                        continue;
                    }
                }
                else if (isRecognizedTripleSlashComment(text, range.pos, range.end)) {
                    lastComment = { range, pinnedOrTripleSlash: true };
                    continue;
                }
                if (lastComment) {
                    if (lastComment.pinnedOrTripleSlash)
                        break;
                    const commentLine = sourceFile.getLineAndCharacterOfPosition(range.pos).line;
                    const lastCommentEndLine = sourceFile.getLineAndCharacterOfPosition(lastComment.range.end).line;
                    if (commentLine >= lastCommentEndLine + 2)
                        break;
                }
                if (sourceFile.statements.length) {
                    if (firstNodeLine === void 0)
                        firstNodeLine = sourceFile.getLineAndCharacterOfPosition(sourceFile.statements[0].getStart()).line;
                    const commentEndLine = sourceFile.getLineAndCharacterOfPosition(range.end).line;
                    if (firstNodeLine < commentEndLine + 2)
                        break;
                }
                lastComment = { range, pinnedOrTripleSlash: false };
            }
            if (lastComment) {
                position = lastComment.range.end;
                advancePastLineBreak();
            }
            return position;
            function advancePastLineBreak() {
                if (position < text.length) {
                    const charCode = text.charCodeAt(position);
                    if (isLineBreak(charCode)) {
                        position++;
                        if (position < text.length && charCode === 13 /* carriageReturn */ && text.charCodeAt(position) === 10 /* lineFeed */) {
                            position++;
                        }
                    }
                }
            }
        }
        function isValidLocationToAddComment(sourceFile, position) {
            return !isInComment(sourceFile, position) && !isInString(sourceFile, position) && !isInTemplateString(sourceFile, position) && !isInJSXText(sourceFile, position);
        }
        function needSemicolonBetween(a, b) {
            return (isPropertySignature(a) || isPropertyDeclaration(a)) && isClassOrTypeElement(b) && b.name.kind === 164 /* ComputedPropertyName */ || isStatementButNotDeclaration(a) && isStatementButNotDeclaration(b);
        }
        function deleteNode(changes, sourceFile, node, options = { leadingTriviaOption: 1 /* IncludeAll */ }) {
            const startPosition = getAdjustedStartPosition(sourceFile, node, options);
            const endPosition = getAdjustedEndPosition(sourceFile, node, options);
            changes.deleteRange(sourceFile, { pos: startPosition, end: endPosition });
        }
        function deleteNodeInList(changes, deletedNodesInLists, sourceFile, node) {
            const containingList = Debug.checkDefined(ts_formatting_exports.SmartIndenter.getContainingList(node, sourceFile));
            const index = indexOfNode(containingList, node);
            Debug.assert(index !== -1);
            if (containingList.length === 1) {
                deleteNode(changes, sourceFile, node);
                return;
            }
            Debug.assert(!deletedNodesInLists.has(node), "Deleting a node twice");
            deletedNodesInLists.add(node);
            changes.deleteRange(sourceFile, {
                pos: startPositionToDeleteNodeInList(sourceFile, node),
                end: index === containingList.length - 1 ? getAdjustedEndPosition(sourceFile, node, {}) : endPositionToDeleteNodeInList(sourceFile, node, containingList[index - 1], containingList[index + 1])
            });
        }
        var LeadingTriviaOption, TrailingTriviaOption, useNonAdjustedPositions, ChangeTracker, changesToText, textChangesTransformationContext, deleteDeclaration;
        var init_textChanges = __esm({
            "src/services/textChanges.ts"() {
                "use strict";
                init_ts4();
                LeadingTriviaOption = /* @__PURE__ */ ((LeadingTriviaOption2) => {
                    LeadingTriviaOption2[LeadingTriviaOption2["Exclude"] = 0] = "Exclude";
                    LeadingTriviaOption2[LeadingTriviaOption2["IncludeAll"] = 1] = "IncludeAll";
                    LeadingTriviaOption2[LeadingTriviaOption2["JSDoc"] = 2] = "JSDoc";
                    LeadingTriviaOption2[LeadingTriviaOption2["StartLine"] = 3] = "StartLine";
                    return LeadingTriviaOption2;
                })(LeadingTriviaOption || {});
                TrailingTriviaOption = /* @__PURE__ */ ((TrailingTriviaOption2) => {
                    TrailingTriviaOption2[TrailingTriviaOption2["Exclude"] = 0] = "Exclude";
                    TrailingTriviaOption2[TrailingTriviaOption2["ExcludeWhitespace"] = 1] = "ExcludeWhitespace";
                    TrailingTriviaOption2[TrailingTriviaOption2["Include"] = 2] = "Include";
                    return TrailingTriviaOption2;
                })(TrailingTriviaOption || {});
                useNonAdjustedPositions = {
                    leadingTriviaOption: 0 /* Exclude */,
                    trailingTriviaOption: 0 /* Exclude */
                };
                ChangeTracker = class {
                    /** Public for tests only. Other callers should use `ChangeTracker.with`. */
                    constructor(newLineCharacter, formatContext) {
                        this.newLineCharacter = newLineCharacter;
                        this.formatContext = formatContext;
                        this.changes = [];
                        this.newFiles = [];
                        this.classesWithNodesInsertedAtStart = /* @__PURE__ */ new Map();
                        // Set<ClassDeclaration> implemented as Map<node id, ClassDeclaration>
                        this.deletedNodes = [];
                    }
                    static fromContext(context) {
                        return new ChangeTracker(getNewLineOrDefaultFromHost(context.host, context.formatContext.options), context.formatContext);
                    }
                    static with(context, cb) {
                        const tracker = ChangeTracker.fromContext(context);
                        cb(tracker);
                        return tracker.getChanges();
                    }
                    pushRaw(sourceFile, change) {
                        Debug.assertEqual(sourceFile.fileName, change.fileName);
                        for (const c of change.textChanges) {
                            this.changes.push({
                                kind: 3 /* Text */,
                                sourceFile,
                                text: c.newText,
                                range: createTextRangeFromSpan(c.span)
                            });
                        }
                    }
                    deleteRange(sourceFile, range) {
                        this.changes.push({ kind: 0 /* Remove */, sourceFile, range });
                    }
                    delete(sourceFile, node) {
                        this.deletedNodes.push({ sourceFile, node });
                    }
                    /** Stop! Consider using `delete` instead, which has logic for deleting nodes from delimited lists. */
                    deleteNode(sourceFile, node, options = { leadingTriviaOption: 1 /* IncludeAll */ }) {
                        this.deleteRange(sourceFile, getAdjustedRange(sourceFile, node, node, options));
                    }
                    deleteNodes(sourceFile, nodes, options = { leadingTriviaOption: 1 /* IncludeAll */ }, hasTrailingComment) {
                        for (const node of nodes) {
                            const pos = getAdjustedStartPosition(sourceFile, node, options, hasTrailingComment);
                            const end = getAdjustedEndPosition(sourceFile, node, options);
                            this.deleteRange(sourceFile, { pos, end });
                            hasTrailingComment = !!getEndPositionOfMultilineTrailingComment(sourceFile, node, options);
                        }
                    }
                    deleteModifier(sourceFile, modifier) {
                        this.deleteRange(sourceFile, { pos: modifier.getStart(sourceFile), end: skipTrivia(sourceFile.text, modifier.end, 
                            /*stopAfterLineBreak*/
                            true) });
                    }
                    deleteNodeRange(sourceFile, startNode2, endNode2, options = { leadingTriviaOption: 1 /* IncludeAll */ }) {
                        const startPosition = getAdjustedStartPosition(sourceFile, startNode2, options);
                        const endPosition = getAdjustedEndPosition(sourceFile, endNode2, options);
                        this.deleteRange(sourceFile, { pos: startPosition, end: endPosition });
                    }
                    deleteNodeRangeExcludingEnd(sourceFile, startNode2, afterEndNode, options = { leadingTriviaOption: 1 /* IncludeAll */ }) {
                        const startPosition = getAdjustedStartPosition(sourceFile, startNode2, options);
                        const endPosition = afterEndNode === void 0 ? sourceFile.text.length : getAdjustedStartPosition(sourceFile, afterEndNode, options);
                        this.deleteRange(sourceFile, { pos: startPosition, end: endPosition });
                    }
                    replaceRange(sourceFile, range, newNode, options = {}) {
                        this.changes.push({ kind: 1 /* ReplaceWithSingleNode */, sourceFile, range, options, node: newNode });
                    }
                    replaceNode(sourceFile, oldNode, newNode, options = useNonAdjustedPositions) {
                        this.replaceRange(sourceFile, getAdjustedRange(sourceFile, oldNode, oldNode, options), newNode, options);
                    }
                    replaceNodeRange(sourceFile, startNode2, endNode2, newNode, options = useNonAdjustedPositions) {
                        this.replaceRange(sourceFile, getAdjustedRange(sourceFile, startNode2, endNode2, options), newNode, options);
                    }
                    replaceRangeWithNodes(sourceFile, range, newNodes, options = {}) {
                        this.changes.push({ kind: 2 /* ReplaceWithMultipleNodes */, sourceFile, range, options, nodes: newNodes });
                    }
                    replaceNodeWithNodes(sourceFile, oldNode, newNodes, options = useNonAdjustedPositions) {
                        this.replaceRangeWithNodes(sourceFile, getAdjustedRange(sourceFile, oldNode, oldNode, options), newNodes, options);
                    }
                    replaceNodeWithText(sourceFile, oldNode, text) {
                        this.replaceRangeWithText(sourceFile, getAdjustedRange(sourceFile, oldNode, oldNode, useNonAdjustedPositions), text);
                    }
                    replaceNodeRangeWithNodes(sourceFile, startNode2, endNode2, newNodes, options = useNonAdjustedPositions) {
                        this.replaceRangeWithNodes(sourceFile, getAdjustedRange(sourceFile, startNode2, endNode2, options), newNodes, options);
                    }
                    nodeHasTrailingComment(sourceFile, oldNode, configurableEnd = useNonAdjustedPositions) {
                        return !!getEndPositionOfMultilineTrailingComment(sourceFile, oldNode, configurableEnd);
                    }
                    nextCommaToken(sourceFile, node) {
                        const next = findNextToken(node, node.parent, sourceFile);
                        return next && next.kind === 27 /* CommaToken */ ? next : void 0;
                    }
                    replacePropertyAssignment(sourceFile, oldNode, newNode) {
                        const suffix = this.nextCommaToken(sourceFile, oldNode) ? "" : "," + this.newLineCharacter;
                        this.replaceNode(sourceFile, oldNode, newNode, { suffix });
                    }
                    insertNodeAt(sourceFile, pos, newNode, options = {}) {
                        this.replaceRange(sourceFile, createRange(pos), newNode, options);
                    }
                    insertNodesAt(sourceFile, pos, newNodes, options = {}) {
                        this.replaceRangeWithNodes(sourceFile, createRange(pos), newNodes, options);
                    }
                    insertNodeAtTopOfFile(sourceFile, newNode, blankLineBetween) {
                        this.insertAtTopOfFile(sourceFile, newNode, blankLineBetween);
                    }
                    insertNodesAtTopOfFile(sourceFile, newNodes, blankLineBetween) {
                        this.insertAtTopOfFile(sourceFile, newNodes, blankLineBetween);
                    }
                    insertAtTopOfFile(sourceFile, insert, blankLineBetween) {
                        const pos = getInsertionPositionAtSourceFileTop(sourceFile);
                        const options = {
                            prefix: pos === 0 ? void 0 : this.newLineCharacter,
                            suffix: (isLineBreak(sourceFile.text.charCodeAt(pos)) ? "" : this.newLineCharacter) + (blankLineBetween ? this.newLineCharacter : "")
                        };
                        if (isArray(insert)) {
                            this.insertNodesAt(sourceFile, pos, insert, options);
                        }
                        else {
                            this.insertNodeAt(sourceFile, pos, insert, options);
                        }
                    }
                    insertFirstParameter(sourceFile, parameters, newParam) {
                        const p0 = firstOrUndefined(parameters);
                        if (p0) {
                            this.insertNodeBefore(sourceFile, p0, newParam);
                        }
                        else {
                            this.insertNodeAt(sourceFile, parameters.pos, newParam);
                        }
                    }
                    insertNodeBefore(sourceFile, before, newNode, blankLineBetween = false, options = {}) {
                        this.insertNodeAt(sourceFile, getAdjustedStartPosition(sourceFile, before, options), newNode, this.getOptionsForInsertNodeBefore(before, newNode, blankLineBetween));
                    }
                    insertModifierAt(sourceFile, pos, modifier, options = {}) {
                        this.insertNodeAt(sourceFile, pos, factory.createToken(modifier), options);
                    }
                    insertModifierBefore(sourceFile, modifier, before) {
                        return this.insertModifierAt(sourceFile, before.getStart(sourceFile), modifier, { suffix: " " });
                    }
                    insertCommentBeforeLine(sourceFile, lineNumber, position, commentText) {
                        const lineStartPosition = getStartPositionOfLine(lineNumber, sourceFile);
                        const startPosition = getFirstNonSpaceCharacterPosition(sourceFile.text, lineStartPosition);
                        const insertAtLineStart = isValidLocationToAddComment(sourceFile, startPosition);
                        const token = getTouchingToken(sourceFile, insertAtLineStart ? startPosition : position);
                        const indent2 = sourceFile.text.slice(lineStartPosition, startPosition);
                        const text = `${insertAtLineStart ? "" : this.newLineCharacter}//${commentText}${this.newLineCharacter}${indent2}`;
                        this.insertText(sourceFile, token.getStart(sourceFile), text);
                    }
                    insertJsdocCommentBefore(sourceFile, node, tag) {
                        const fnStart = node.getStart(sourceFile);
                        if (node.jsDoc) {
                            for (const jsdoc of node.jsDoc) {
                                this.deleteRange(sourceFile, {
                                    pos: getLineStartPositionForPosition(jsdoc.getStart(sourceFile), sourceFile),
                                    end: getAdjustedEndPosition(sourceFile, jsdoc, 
                                    /*options*/
                                    {})
                                });
                            }
                        }
                        const startPosition = getPrecedingNonSpaceCharacterPosition(sourceFile.text, fnStart - 1);
                        const indent2 = sourceFile.text.slice(startPosition, fnStart);
                        this.insertNodeAt(sourceFile, fnStart, tag, { suffix: this.newLineCharacter + indent2 });
                    }
                    createJSDocText(sourceFile, node) {
                        const comments = flatMap(node.jsDoc, (jsDoc2) => isString(jsDoc2.comment) ? factory.createJSDocText(jsDoc2.comment) : jsDoc2.comment);
                        const jsDoc = singleOrUndefined(node.jsDoc);
                        return jsDoc && positionsAreOnSameLine(jsDoc.pos, jsDoc.end, sourceFile) && length(comments) === 0 ? void 0 : factory.createNodeArray(intersperse(comments, factory.createJSDocText("\n")));
                    }
                    replaceJSDocComment(sourceFile, node, tags) {
                        this.insertJsdocCommentBefore(sourceFile, updateJSDocHost(node), factory.createJSDocComment(this.createJSDocText(sourceFile, node), factory.createNodeArray(tags)));
                    }
                    addJSDocTags(sourceFile, parent2, newTags) {
                        const oldTags = flatMapToMutable(parent2.jsDoc, (j) => j.tags);
                        const unmergedNewTags = newTags.filter((newTag) => !oldTags.some((tag, i) => {
                            const merged = tryMergeJsdocTags(tag, newTag);
                            if (merged)
                                oldTags[i] = merged;
                            return !!merged;
                        }));
                        this.replaceJSDocComment(sourceFile, parent2, [...oldTags, ...unmergedNewTags]);
                    }
                    filterJSDocTags(sourceFile, parent2, predicate) {
                        this.replaceJSDocComment(sourceFile, parent2, filter(flatMapToMutable(parent2.jsDoc, (j) => j.tags), predicate));
                    }
                    replaceRangeWithText(sourceFile, range, text) {
                        this.changes.push({ kind: 3 /* Text */, sourceFile, range, text });
                    }
                    insertText(sourceFile, pos, text) {
                        this.replaceRangeWithText(sourceFile, createRange(pos), text);
                    }
                    /** Prefer this over replacing a node with another that has a type annotation, as it avoids reformatting the other parts of the node. */
                    tryInsertTypeAnnotation(sourceFile, node, type) {
                        var _a2;
                        let endNode2;
                        if (isFunctionLike(node)) {
                            endNode2 = findChildOfKind(node, 21 /* CloseParenToken */, sourceFile);
                            if (!endNode2) {
                                if (!isArrowFunction(node))
                                    return false;
                                endNode2 = first(node.parameters);
                            }
                        }
                        else {
                            endNode2 = (_a2 = node.kind === 257 /* VariableDeclaration */ ? node.exclamationToken : node.questionToken) != null ? _a2 : node.name;
                        }
                        this.insertNodeAt(sourceFile, endNode2.end, type, { prefix: ": " });
                        return true;
                    }
                    tryInsertThisTypeAnnotation(sourceFile, node, type) {
                        const start = findChildOfKind(node, 20 /* OpenParenToken */, sourceFile).getStart(sourceFile) + 1;
                        const suffix = node.parameters.length ? ", " : "";
                        this.insertNodeAt(sourceFile, start, type, { prefix: "this: ", suffix });
                    }
                    insertTypeParameters(sourceFile, node, typeParameters) {
                        const start = (findChildOfKind(node, 20 /* OpenParenToken */, sourceFile) || first(node.parameters)).getStart(sourceFile);
                        this.insertNodesAt(sourceFile, start, typeParameters, { prefix: "<", suffix: ">", joiner: ", " });
                    }
                    getOptionsForInsertNodeBefore(before, inserted, blankLineBetween) {
                        if (isStatement(before) || isClassElement(before)) {
                            return { suffix: blankLineBetween ? this.newLineCharacter + this.newLineCharacter : this.newLineCharacter };
                        }
                        else if (isVariableDeclaration(before)) {
                            return { suffix: ", " };
                        }
                        else if (isParameter(before)) {
                            return isParameter(inserted) ? { suffix: ", " } : {};
                        }
                        else if (isStringLiteral(before) && isImportDeclaration(before.parent) || isNamedImports(before)) {
                            return { suffix: ", " };
                        }
                        else if (isImportSpecifier(before)) {
                            return { suffix: "," + (blankLineBetween ? this.newLineCharacter : " ") };
                        }
                        return Debug.failBadSyntaxKind(before);
                    }
                    insertNodeAtConstructorStart(sourceFile, ctr, newStatement) {
                        const firstStatement = firstOrUndefined(ctr.body.statements);
                        if (!firstStatement || !ctr.body.multiLine) {
                            this.replaceConstructorBody(sourceFile, ctr, [newStatement, ...ctr.body.statements]);
                        }
                        else {
                            this.insertNodeBefore(sourceFile, firstStatement, newStatement);
                        }
                    }
                    insertNodeAtConstructorStartAfterSuperCall(sourceFile, ctr, newStatement) {
                        const superCallStatement = find(ctr.body.statements, (stmt) => isExpressionStatement(stmt) && isSuperCall(stmt.expression));
                        if (!superCallStatement || !ctr.body.multiLine) {
                            this.replaceConstructorBody(sourceFile, ctr, [...ctr.body.statements, newStatement]);
                        }
                        else {
                            this.insertNodeAfter(sourceFile, superCallStatement, newStatement);
                        }
                    }
                    insertNodeAtConstructorEnd(sourceFile, ctr, newStatement) {
                        const lastStatement = lastOrUndefined(ctr.body.statements);
                        if (!lastStatement || !ctr.body.multiLine) {
                            this.replaceConstructorBody(sourceFile, ctr, [...ctr.body.statements, newStatement]);
                        }
                        else {
                            this.insertNodeAfter(sourceFile, lastStatement, newStatement);
                        }
                    }
                    replaceConstructorBody(sourceFile, ctr, statements) {
                        this.replaceNode(sourceFile, ctr.body, factory.createBlock(statements, 
                        /*multiLine*/
                        true));
                    }
                    insertNodeAtEndOfScope(sourceFile, scope, newNode) {
                        const pos = getAdjustedStartPosition(sourceFile, scope.getLastToken(), {});
                        this.insertNodeAt(sourceFile, pos, newNode, {
                            prefix: isLineBreak(sourceFile.text.charCodeAt(scope.getLastToken().pos)) ? this.newLineCharacter : this.newLineCharacter + this.newLineCharacter,
                            suffix: this.newLineCharacter
                        });
                    }
                    insertMemberAtStart(sourceFile, node, newElement) {
                        this.insertNodeAtStartWorker(sourceFile, node, newElement);
                    }
                    insertNodeAtObjectStart(sourceFile, obj, newElement) {
                        this.insertNodeAtStartWorker(sourceFile, obj, newElement);
                    }
                    insertNodeAtStartWorker(sourceFile, node, newElement) {
                        var _a2;
                        const indentation = (_a2 = this.guessIndentationFromExistingMembers(sourceFile, node)) != null ? _a2 : this.computeIndentationForNewMember(sourceFile, node);
                        this.insertNodeAt(sourceFile, getMembersOrProperties(node).pos, newElement, this.getInsertNodeAtStartInsertOptions(sourceFile, node, indentation));
                    }
                    /**
                     * Tries to guess the indentation from the existing members of a class/interface/object. All members must be on
                     * new lines and must share the same indentation.
                     */
                    guessIndentationFromExistingMembers(sourceFile, node) {
                        let indentation;
                        let lastRange = node;
                        for (const member of getMembersOrProperties(node)) {
                            if (rangeStartPositionsAreOnSameLine(lastRange, member, sourceFile)) {
                                return void 0;
                            }
                            const memberStart = member.getStart(sourceFile);
                            const memberIndentation = ts_formatting_exports.SmartIndenter.findFirstNonWhitespaceColumn(getLineStartPositionForPosition(memberStart, sourceFile), memberStart, sourceFile, this.formatContext.options);
                            if (indentation === void 0) {
                                indentation = memberIndentation;
                            }
                            else if (memberIndentation !== indentation) {
                                return void 0;
                            }
                            lastRange = member;
                        }
                        return indentation;
                    }
                    computeIndentationForNewMember(sourceFile, node) {
                        var _a2;
                        const nodeStart = node.getStart(sourceFile);
                        return ts_formatting_exports.SmartIndenter.findFirstNonWhitespaceColumn(getLineStartPositionForPosition(nodeStart, sourceFile), nodeStart, sourceFile, this.formatContext.options) + ((_a2 = this.formatContext.options.indentSize) != null ? _a2 : 4);
                    }
                    getInsertNodeAtStartInsertOptions(sourceFile, node, indentation) {
                        const members = getMembersOrProperties(node);
                        const isEmpty = members.length === 0;
                        const isFirstInsertion = addToSeen(this.classesWithNodesInsertedAtStart, getNodeId(node), { node, sourceFile });
                        const insertTrailingComma = isObjectLiteralExpression(node) && (!isJsonSourceFile(sourceFile) || !isEmpty);
                        const insertLeadingComma = isObjectLiteralExpression(node) && isJsonSourceFile(sourceFile) && isEmpty && !isFirstInsertion;
                        return {
                            indentation,
                            prefix: (insertLeadingComma ? "," : "") + this.newLineCharacter,
                            suffix: insertTrailingComma ? "," : isInterfaceDeclaration(node) && isEmpty ? ";" : ""
                        };
                    }
                    insertNodeAfterComma(sourceFile, after, newNode) {
                        const endPosition = this.insertNodeAfterWorker(sourceFile, this.nextCommaToken(sourceFile, after) || after, newNode);
                        this.insertNodeAt(sourceFile, endPosition, newNode, this.getInsertNodeAfterOptions(sourceFile, after));
                    }
                    insertNodeAfter(sourceFile, after, newNode) {
                        const endPosition = this.insertNodeAfterWorker(sourceFile, after, newNode);
                        this.insertNodeAt(sourceFile, endPosition, newNode, this.getInsertNodeAfterOptions(sourceFile, after));
                    }
                    insertNodeAtEndOfList(sourceFile, list, newNode) {
                        this.insertNodeAt(sourceFile, list.end, newNode, { prefix: ", " });
                    }
                    insertNodesAfter(sourceFile, after, newNodes) {
                        const endPosition = this.insertNodeAfterWorker(sourceFile, after, first(newNodes));
                        this.insertNodesAt(sourceFile, endPosition, newNodes, this.getInsertNodeAfterOptions(sourceFile, after));
                    }
                    insertNodeAfterWorker(sourceFile, after, newNode) {
                        if (needSemicolonBetween(after, newNode)) {
                            if (sourceFile.text.charCodeAt(after.end - 1) !== 59 /* semicolon */) {
                                this.replaceRange(sourceFile, createRange(after.end), factory.createToken(26 /* SemicolonToken */));
                            }
                        }
                        const endPosition = getAdjustedEndPosition(sourceFile, after, {});
                        return endPosition;
                    }
                    getInsertNodeAfterOptions(sourceFile, after) {
                        const options = this.getInsertNodeAfterOptionsWorker(after);
                        return {
                            ...options,
                            prefix: after.end === sourceFile.end && isStatement(after) ? options.prefix ? `
${options.prefix}` : "\n" : options.prefix
                        };
                    }
                    getInsertNodeAfterOptionsWorker(node) {
                        switch (node.kind) {
                            case 260 /* ClassDeclaration */:
                            case 264 /* ModuleDeclaration */:
                                return { prefix: this.newLineCharacter, suffix: this.newLineCharacter };
                            case 257 /* VariableDeclaration */:
                            case 10 /* StringLiteral */:
                            case 79 /* Identifier */:
                                return { prefix: ", " };
                            case 299 /* PropertyAssignment */:
                                return { suffix: "," + this.newLineCharacter };
                            case 93 /* ExportKeyword */:
                                return { prefix: " " };
                            case 166 /* Parameter */:
                                return {};
                            default:
                                Debug.assert(isStatement(node) || isClassOrTypeElement(node));
                                return { suffix: this.newLineCharacter };
                        }
                    }
                    insertName(sourceFile, node, name) {
                        Debug.assert(!node.name);
                        if (node.kind === 216 /* ArrowFunction */) {
                            const arrow = findChildOfKind(node, 38 /* EqualsGreaterThanToken */, sourceFile);
                            const lparen = findChildOfKind(node, 20 /* OpenParenToken */, sourceFile);
                            if (lparen) {
                                this.insertNodesAt(sourceFile, lparen.getStart(sourceFile), [factory.createToken(98 /* FunctionKeyword */), factory.createIdentifier(name)], { joiner: " " });
                                deleteNode(this, sourceFile, arrow);
                            }
                            else {
                                this.insertText(sourceFile, first(node.parameters).getStart(sourceFile), `function ${name}(`);
                                this.replaceRange(sourceFile, arrow, factory.createToken(21 /* CloseParenToken */));
                            }
                            if (node.body.kind !== 238 /* Block */) {
                                this.insertNodesAt(sourceFile, node.body.getStart(sourceFile), [factory.createToken(18 /* OpenBraceToken */), factory.createToken(105 /* ReturnKeyword */)], { joiner: " ", suffix: " " });
                                this.insertNodesAt(sourceFile, node.body.end, [factory.createToken(26 /* SemicolonToken */), factory.createToken(19 /* CloseBraceToken */)], { joiner: " " });
                            }
                        }
                        else {
                            const pos = findChildOfKind(node, node.kind === 215 /* FunctionExpression */ ? 98 /* FunctionKeyword */ : 84 /* ClassKeyword */, sourceFile).end;
                            this.insertNodeAt(sourceFile, pos, factory.createIdentifier(name), { prefix: " " });
                        }
                    }
                    insertExportModifier(sourceFile, node) {
                        this.insertText(sourceFile, node.getStart(sourceFile), "export ");
                    }
                    insertImportSpecifierAtIndex(sourceFile, importSpecifier, namedImports, index) {
                        const prevSpecifier = namedImports.elements[index - 1];
                        if (prevSpecifier) {
                            this.insertNodeInListAfter(sourceFile, prevSpecifier, importSpecifier);
                        }
                        else {
                            this.insertNodeBefore(sourceFile, namedImports.elements[0], importSpecifier, !positionsAreOnSameLine(namedImports.elements[0].getStart(), namedImports.parent.parent.getStart(), sourceFile));
                        }
                    }
                    /**
                     * This function should be used to insert nodes in lists when nodes don't carry separators as the part of the node range,
                     * i.e. arguments in arguments lists, parameters in parameter lists etc.
                     * Note that separators are part of the node in statements and class elements.
                     */
                    insertNodeInListAfter(sourceFile, after, newNode, containingList = ts_formatting_exports.SmartIndenter.getContainingList(after, sourceFile)) {
                        if (!containingList) {
                            Debug.fail("node is not a list element");
                            return;
                        }
                        const index = indexOfNode(containingList, after);
                        if (index < 0) {
                            return;
                        }
                        const end = after.getEnd();
                        if (index !== containingList.length - 1) {
                            const nextToken = getTokenAtPosition(sourceFile, after.end);
                            if (nextToken && isSeparator(after, nextToken)) {
                                const nextNode = containingList[index + 1];
                                const startPos = skipWhitespacesAndLineBreaks(sourceFile.text, nextNode.getFullStart());
                                const suffix = `${tokenToString(nextToken.kind)}${sourceFile.text.substring(nextToken.end, startPos)}`;
                                this.insertNodesAt(sourceFile, startPos, [newNode], { suffix });
                            }
                        }
                        else {
                            const afterStart = after.getStart(sourceFile);
                            const afterStartLinePosition = getLineStartPositionForPosition(afterStart, sourceFile);
                            let separator;
                            let multilineList = false;
                            if (containingList.length === 1) {
                                separator = 27 /* CommaToken */;
                            }
                            else {
                                const tokenBeforeInsertPosition = findPrecedingToken(after.pos, sourceFile);
                                separator = isSeparator(after, tokenBeforeInsertPosition) ? tokenBeforeInsertPosition.kind : 27 /* CommaToken */;
                                const afterMinusOneStartLinePosition = getLineStartPositionForPosition(containingList[index - 1].getStart(sourceFile), sourceFile);
                                multilineList = afterMinusOneStartLinePosition !== afterStartLinePosition;
                            }
                            if (hasCommentsBeforeLineBreak(sourceFile.text, after.end)) {
                                multilineList = true;
                            }
                            if (multilineList) {
                                this.replaceRange(sourceFile, createRange(end), factory.createToken(separator));
                                const indentation = ts_formatting_exports.SmartIndenter.findFirstNonWhitespaceColumn(afterStartLinePosition, afterStart, sourceFile, this.formatContext.options);
                                let insertPos = skipTrivia(sourceFile.text, end, 
                                /*stopAfterLineBreak*/
                                true, 
                                /*stopAtComments*/
                                false);
                                while (insertPos !== end && isLineBreak(sourceFile.text.charCodeAt(insertPos - 1))) {
                                    insertPos--;
                                }
                                this.replaceRange(sourceFile, createRange(insertPos), newNode, { indentation, prefix: this.newLineCharacter });
                            }
                            else {
                                this.replaceRange(sourceFile, createRange(end), newNode, { prefix: `${tokenToString(separator)} ` });
                            }
                        }
                    }
                    parenthesizeExpression(sourceFile, expression) {
                        this.replaceRange(sourceFile, rangeOfNode(expression), factory.createParenthesizedExpression(expression));
                    }
                    finishClassesWithNodesInsertedAtStart() {
                        this.classesWithNodesInsertedAtStart.forEach(({ node, sourceFile }) => {
                            const [openBraceEnd, closeBraceEnd] = getClassOrObjectBraceEnds(node, sourceFile);
                            if (openBraceEnd !== void 0 && closeBraceEnd !== void 0) {
                                const isEmpty = getMembersOrProperties(node).length === 0;
                                const isSingleLine = positionsAreOnSameLine(openBraceEnd, closeBraceEnd, sourceFile);
                                if (isEmpty && isSingleLine && openBraceEnd !== closeBraceEnd - 1) {
                                    this.deleteRange(sourceFile, createRange(openBraceEnd, closeBraceEnd - 1));
                                }
                                if (isSingleLine) {
                                    this.insertText(sourceFile, closeBraceEnd - 1, this.newLineCharacter);
                                }
                            }
                        });
                    }
                    finishDeleteDeclarations() {
                        const deletedNodesInLists = /* @__PURE__ */ new Set();
                        for (const { sourceFile, node } of this.deletedNodes) {
                            if (!this.deletedNodes.some((d) => d.sourceFile === sourceFile && rangeContainsRangeExclusive(d.node, node))) {
                                if (isArray(node)) {
                                    this.deleteRange(sourceFile, rangeOfTypeParameters(sourceFile, node));
                                }
                                else {
                                    deleteDeclaration.deleteDeclaration(this, deletedNodesInLists, sourceFile, node);
                                }
                            }
                        }
                        deletedNodesInLists.forEach((node) => {
                            const sourceFile = node.getSourceFile();
                            const list = ts_formatting_exports.SmartIndenter.getContainingList(node, sourceFile);
                            if (node !== last(list))
                                return;
                            const lastNonDeletedIndex = findLastIndex(list, (n) => !deletedNodesInLists.has(n), list.length - 2);
                            if (lastNonDeletedIndex !== -1) {
                                this.deleteRange(sourceFile, { pos: list[lastNonDeletedIndex].end, end: startPositionToDeleteNodeInList(sourceFile, list[lastNonDeletedIndex + 1]) });
                            }
                        });
                    }
                    /**
                     * Note: after calling this, the TextChanges object must be discarded!
                     * @param validate only for tests
                     *    The reason we must validate as part of this method is that `getNonFormattedText` changes the node's positions,
                     *    so we can only call this once and can't get the non-formatted text separately.
                     */
                    getChanges(validate) {
                        this.finishDeleteDeclarations();
                        this.finishClassesWithNodesInsertedAtStart();
                        const changes = changesToText.getTextChangesFromChanges(this.changes, this.newLineCharacter, this.formatContext, validate);
                        for (const { oldFile, fileName, statements } of this.newFiles) {
                            changes.push(changesToText.newFileChanges(oldFile, fileName, statements, this.newLineCharacter, this.formatContext));
                        }
                        return changes;
                    }
                    createNewFile(oldFile, fileName, statements) {
                        this.newFiles.push({ oldFile, fileName, statements });
                    }
                };
                ((changesToText2) => {
                    function getTextChangesFromChanges(changes, newLineCharacter, formatContext, validate) {
                        return mapDefined(group(changes, (c) => c.sourceFile.path), (changesInFile) => {
                            const sourceFile = changesInFile[0].sourceFile;
                            const normalized = stableSort(changesInFile, (a, b) => a.range.pos - b.range.pos || a.range.end - b.range.end);
                            for (let i = 0; i < normalized.length - 1; i++) {
                                Debug.assert(normalized[i].range.end <= normalized[i + 1].range.pos, "Changes overlap", () => `${JSON.stringify(normalized[i].range)} and ${JSON.stringify(normalized[i + 1].range)}`);
                            }
                            const textChanges2 = mapDefined(normalized, (c) => {
                                const span = createTextSpanFromRange(c.range);
                                const newText = computeNewText(c, sourceFile, newLineCharacter, formatContext, validate);
                                if (span.length === newText.length && stringContainsAt(sourceFile.text, newText, span.start)) {
                                    return void 0;
                                }
                                return createTextChange(span, newText);
                            });
                            return textChanges2.length > 0 ? { fileName: sourceFile.fileName, textChanges: textChanges2 } : void 0;
                        });
                    }
                    changesToText2.getTextChangesFromChanges = getTextChangesFromChanges;
                    function newFileChanges(oldFile, fileName, statements, newLineCharacter, formatContext) {
                        const text = newFileChangesWorker(oldFile, getScriptKindFromFileName(fileName), statements, newLineCharacter, formatContext);
                        return { fileName, textChanges: [createTextChange(createTextSpan(0, 0), text)], isNewFile: true };
                    }
                    changesToText2.newFileChanges = newFileChanges;
                    function newFileChangesWorker(oldFile, scriptKind, statements, newLineCharacter, formatContext) {
                        const nonFormattedText = statements.map((s) => s === 4 /* NewLineTrivia */ ? "" : getNonformattedText(s, oldFile, newLineCharacter).text).join(newLineCharacter);
                        const sourceFile = createSourceFile("any file name", nonFormattedText, 99 /* ESNext */, 
                        /*setParentNodes*/
                        true, scriptKind);
                        const changes = ts_formatting_exports.formatDocument(sourceFile, formatContext);
                        return applyChanges(nonFormattedText, changes) + newLineCharacter;
                    }
                    changesToText2.newFileChangesWorker = newFileChangesWorker;
                    function computeNewText(change, sourceFile, newLineCharacter, formatContext, validate) {
                        var _a2;
                        if (change.kind === 0 /* Remove */) {
                            return "";
                        }
                        if (change.kind === 3 /* Text */) {
                            return change.text;
                        }
                        const { options = {}, range: { pos } } = change;
                        const format = (n) => getFormattedTextOfNode(n, sourceFile, pos, options, newLineCharacter, formatContext, validate);
                        const text = change.kind === 2 /* ReplaceWithMultipleNodes */ ? change.nodes.map((n) => removeSuffix(format(n), newLineCharacter)).join(((_a2 = change.options) == null ? void 0 : _a2.joiner) || newLineCharacter) : format(change.node);
                        const noIndent = options.indentation !== void 0 || getLineStartPositionForPosition(pos, sourceFile) === pos ? text : text.replace(/^\s+/, "");
                        return (options.prefix || "") + noIndent + (!options.suffix || endsWith(noIndent, options.suffix) ? "" : options.suffix);
                    }
                    function getFormattedTextOfNode(nodeIn, sourceFile, pos, { indentation, prefix, delta }, newLineCharacter, formatContext, validate) {
                        const { node, text } = getNonformattedText(nodeIn, sourceFile, newLineCharacter);
                        if (validate)
                            validate(node, text);
                        const formatOptions = getFormatCodeSettingsForWriting(formatContext, sourceFile);
                        const initialIndentation = indentation !== void 0 ? indentation : ts_formatting_exports.SmartIndenter.getIndentation(pos, sourceFile, formatOptions, prefix === newLineCharacter || getLineStartPositionForPosition(pos, sourceFile) === pos);
                        if (delta === void 0) {
                            delta = ts_formatting_exports.SmartIndenter.shouldIndentChildNode(formatOptions, nodeIn) ? formatOptions.indentSize || 0 : 0;
                        }
                        const file = {
                            text,
                            getLineAndCharacterOfPosition(pos2) {
                                return getLineAndCharacterOfPosition(this, pos2);
                            }
                        };
                        const changes = ts_formatting_exports.formatNodeGivenIndentation(node, file, sourceFile.languageVariant, initialIndentation, delta, { ...formatContext, options: formatOptions });
                        return applyChanges(text, changes);
                    }
                    function getNonformattedText(node, sourceFile, newLineCharacter) {
                        const writer = createWriter(newLineCharacter);
                        const newLine = getNewLineKind(newLineCharacter);
                        createPrinter({
                            newLine,
                            neverAsciiEscape: true,
                            preserveSourceNewlines: true,
                            terminateUnterminatedLiterals: true
                        }, writer).writeNode(4 /* Unspecified */, node, sourceFile, writer);
                        return { text: writer.getText(), node: assignPositionsToNode(node) };
                    }
                    changesToText2.getNonformattedText = getNonformattedText;
                })(changesToText || (changesToText = {}));
                textChangesTransformationContext = {
                    ...nullTransformationContext,
                    factory: createNodeFactory(nullTransformationContext.factory.flags | 1 /* NoParenthesizerRules */, nullTransformationContext.factory.baseFactory)
                };
                ((_deleteDeclaration) => {
                    function deleteDeclaration2(changes, deletedNodesInLists, sourceFile, node) {
                        switch (node.kind) {
                            case 166 /* Parameter */: {
                                const oldFunction = node.parent;
                                if (isArrowFunction(oldFunction) && oldFunction.parameters.length === 1 && !findChildOfKind(oldFunction, 20 /* OpenParenToken */, sourceFile)) {
                                    changes.replaceNodeWithText(sourceFile, node, "()");
                                }
                                else {
                                    deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                }
                                break;
                            }
                            case 269 /* ImportDeclaration */:
                            case 268 /* ImportEqualsDeclaration */:
                                const isFirstImport = sourceFile.imports.length && node === first(sourceFile.imports).parent || node === find(sourceFile.statements, isAnyImportSyntax);
                                deleteNode(changes, sourceFile, node, {
                                    leadingTriviaOption: isFirstImport ? 0 /* Exclude */ : hasJSDocNodes(node) ? 2 /* JSDoc */ : 3 /* StartLine */
                                });
                                break;
                            case 205 /* BindingElement */:
                                const pattern = node.parent;
                                const preserveComma = pattern.kind === 204 /* ArrayBindingPattern */ && node !== last(pattern.elements);
                                if (preserveComma) {
                                    deleteNode(changes, sourceFile, node);
                                }
                                else {
                                    deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                }
                                break;
                            case 257 /* VariableDeclaration */:
                                deleteVariableDeclaration(changes, deletedNodesInLists, sourceFile, node);
                                break;
                            case 165 /* TypeParameter */:
                                deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                break;
                            case 273 /* ImportSpecifier */:
                                const namedImports = node.parent;
                                if (namedImports.elements.length === 1) {
                                    deleteImportBinding(changes, sourceFile, namedImports);
                                }
                                else {
                                    deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                }
                                break;
                            case 271 /* NamespaceImport */:
                                deleteImportBinding(changes, sourceFile, node);
                                break;
                            case 26 /* SemicolonToken */:
                                deleteNode(changes, sourceFile, node, { trailingTriviaOption: 0 /* Exclude */ });
                                break;
                            case 98 /* FunctionKeyword */:
                                deleteNode(changes, sourceFile, node, { leadingTriviaOption: 0 /* Exclude */ });
                                break;
                            case 260 /* ClassDeclaration */:
                            case 259 /* FunctionDeclaration */:
                                deleteNode(changes, sourceFile, node, { leadingTriviaOption: hasJSDocNodes(node) ? 2 /* JSDoc */ : 3 /* StartLine */ });
                                break;
                            default:
                                if (!node.parent) {
                                    deleteNode(changes, sourceFile, node);
                                }
                                else if (isImportClause(node.parent) && node.parent.name === node) {
                                    deleteDefaultImport(changes, sourceFile, node.parent);
                                }
                                else if (isCallExpression(node.parent) && contains(node.parent.arguments, node)) {
                                    deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                }
                                else {
                                    deleteNode(changes, sourceFile, node);
                                }
                        }
                    }
                    _deleteDeclaration.deleteDeclaration = deleteDeclaration2;
                    function deleteDefaultImport(changes, sourceFile, importClause) {
                        if (!importClause.namedBindings) {
                            deleteNode(changes, sourceFile, importClause.parent);
                        }
                        else {
                            const start = importClause.name.getStart(sourceFile);
                            const nextToken = getTokenAtPosition(sourceFile, importClause.name.end);
                            if (nextToken && nextToken.kind === 27 /* CommaToken */) {
                                const end = skipTrivia(sourceFile.text, nextToken.end, 
                                /*stopAfterLineBreaks*/
                                false, 
                                /*stopAtComments*/
                                true);
                                changes.deleteRange(sourceFile, { pos: start, end });
                            }
                            else {
                                deleteNode(changes, sourceFile, importClause.name);
                            }
                        }
                    }
                    function deleteImportBinding(changes, sourceFile, node) {
                        if (node.parent.name) {
                            const previousToken = Debug.checkDefined(getTokenAtPosition(sourceFile, node.pos - 1));
                            changes.deleteRange(sourceFile, { pos: previousToken.getStart(sourceFile), end: node.end });
                        }
                        else {
                            const importDecl = getAncestor(node, 269 /* ImportDeclaration */);
                            deleteNode(changes, sourceFile, importDecl);
                        }
                    }
                    function deleteVariableDeclaration(changes, deletedNodesInLists, sourceFile, node) {
                        const { parent: parent2 } = node;
                        if (parent2.kind === 295 /* CatchClause */) {
                            changes.deleteNodeRange(sourceFile, findChildOfKind(parent2, 20 /* OpenParenToken */, sourceFile), findChildOfKind(parent2, 21 /* CloseParenToken */, sourceFile));
                            return;
                        }
                        if (parent2.declarations.length !== 1) {
                            deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                            return;
                        }
                        const gp = parent2.parent;
                        switch (gp.kind) {
                            case 247 /* ForOfStatement */:
                            case 246 /* ForInStatement */:
                                changes.replaceNode(sourceFile, node, factory.createObjectLiteralExpression());
                                break;
                            case 245 /* ForStatement */:
                                deleteNode(changes, sourceFile, parent2);
                                break;
                            case 240 /* VariableStatement */:
                                deleteNode(changes, sourceFile, gp, { leadingTriviaOption: hasJSDocNodes(gp) ? 2 /* JSDoc */ : 3 /* StartLine */ });
                                break;
                            default:
                                Debug.assertNever(gp);
                        }
                    }
                })(deleteDeclaration || (deleteDeclaration = {}));
            }
        });
        // src/services/_namespaces/ts.textChanges.ts
        var ts_textChanges_exports = {};
        __export(ts_textChanges_exports, {
            ChangeTracker: () => ChangeTracker,
            LeadingTriviaOption: () => LeadingTriviaOption,
            TrailingTriviaOption: () => TrailingTriviaOption,
            applyChanges: () => applyChanges,
            assignPositionsToNode: () => assignPositionsToNode,
            createWriter: () => createWriter,
            deleteNode: () => deleteNode,
            getNewFileText: () => getNewFileText,
            isThisTypeAnnotatable: () => isThisTypeAnnotatable,
            isValidLocationToAddComment: () => isValidLocationToAddComment
        });
        var init_ts_textChanges = __esm({
            "src/services/_namespaces/ts.textChanges.ts"() {
                "use strict";
                init_textChanges();
            }
        });
        // src/services/formatting/formattingContext.ts
        var FormattingRequestKind, FormattingContext;
        var init_formattingContext = __esm({
            "src/services/formatting/formattingContext.ts"() {
                "use strict";
                init_ts4();
                FormattingRequestKind = /* @__PURE__ */ ((FormattingRequestKind2) => {
                    FormattingRequestKind2[FormattingRequestKind2["FormatDocument"] = 0] = "FormatDocument";
                    FormattingRequestKind2[FormattingRequestKind2["FormatSelection"] = 1] = "FormatSelection";
                    FormattingRequestKind2[FormattingRequestKind2["FormatOnEnter"] = 2] = "FormatOnEnter";
                    FormattingRequestKind2[FormattingRequestKind2["FormatOnSemicolon"] = 3] = "FormatOnSemicolon";
                    FormattingRequestKind2[FormattingRequestKind2["FormatOnOpeningCurlyBrace"] = 4] = "FormatOnOpeningCurlyBrace";
                    FormattingRequestKind2[FormattingRequestKind2["FormatOnClosingCurlyBrace"] = 5] = "FormatOnClosingCurlyBrace";
                    return FormattingRequestKind2;
                })(FormattingRequestKind || {});
                FormattingContext = class {
                    constructor(sourceFile, formattingRequestKind, options) {
                        this.sourceFile = sourceFile;
                        this.formattingRequestKind = formattingRequestKind;
                        this.options = options;
                    }
                    updateContext(currentRange, currentTokenParent, nextRange, nextTokenParent, commonParent) {
                        this.currentTokenSpan = Debug.checkDefined(currentRange);
                        this.currentTokenParent = Debug.checkDefined(currentTokenParent);
                        this.nextTokenSpan = Debug.checkDefined(nextRange);
                        this.nextTokenParent = Debug.checkDefined(nextTokenParent);
                        this.contextNode = Debug.checkDefined(commonParent);
                        this.contextNodeAllOnSameLine = void 0;
                        this.nextNodeAllOnSameLine = void 0;
                        this.tokensAreOnSameLine = void 0;
                        this.contextNodeBlockIsOnOneLine = void 0;
                        this.nextNodeBlockIsOnOneLine = void 0;
                    }
                    ContextNodeAllOnSameLine() {
                        if (this.contextNodeAllOnSameLine === void 0) {
                            this.contextNodeAllOnSameLine = this.NodeIsOnOneLine(this.contextNode);
                        }
                        return this.contextNodeAllOnSameLine;
                    }
                    NextNodeAllOnSameLine() {
                        if (this.nextNodeAllOnSameLine === void 0) {
                            this.nextNodeAllOnSameLine = this.NodeIsOnOneLine(this.nextTokenParent);
                        }
                        return this.nextNodeAllOnSameLine;
                    }
                    TokensAreOnSameLine() {
                        if (this.tokensAreOnSameLine === void 0) {
                            const startLine = this.sourceFile.getLineAndCharacterOfPosition(this.currentTokenSpan.pos).line;
                            const endLine = this.sourceFile.getLineAndCharacterOfPosition(this.nextTokenSpan.pos).line;
                            this.tokensAreOnSameLine = startLine === endLine;
                        }
                        return this.tokensAreOnSameLine;
                    }
                    ContextNodeBlockIsOnOneLine() {
                        if (this.contextNodeBlockIsOnOneLine === void 0) {
                            this.contextNodeBlockIsOnOneLine = this.BlockIsOnOneLine(this.contextNode);
                        }
                        return this.contextNodeBlockIsOnOneLine;
                    }
                    NextNodeBlockIsOnOneLine() {
                        if (this.nextNodeBlockIsOnOneLine === void 0) {
                            this.nextNodeBlockIsOnOneLine = this.BlockIsOnOneLine(this.nextTokenParent);
                        }
                        return this.nextNodeBlockIsOnOneLine;
                    }
                    NodeIsOnOneLine(node) {
                        const startLine = this.sourceFile.getLineAndCharacterOfPosition(node.getStart(this.sourceFile)).line;
                        const endLine = this.sourceFile.getLineAndCharacterOfPosition(node.getEnd()).line;
                        return startLine === endLine;
                    }
                    BlockIsOnOneLine(node) {
                        const openBrace = findChildOfKind(node, 18 /* OpenBraceToken */, this.sourceFile);
                        const closeBrace = findChildOfKind(node, 19 /* CloseBraceToken */, this.sourceFile);
                        if (openBrace && closeBrace) {
                            const startLine = this.sourceFile.getLineAndCharacterOfPosition(openBrace.getEnd()).line;
                            const endLine = this.sourceFile.getLineAndCharacterOfPosition(closeBrace.getStart(this.sourceFile)).line;
                            return startLine === endLine;
                        }
                        return false;
                    }
                };
            }
        });
        // src/services/formatting/formattingScanner.ts
        function getFormattingScanner(text, languageVariant, startPos, endPos, cb) {
            const scanner2 = languageVariant === 1 /* JSX */ ? jsxScanner : standardScanner;
            scanner2.setText(text);
            scanner2.setTextPos(startPos);
            let wasNewLine = true;
            let leadingTrivia;
            let trailingTrivia;
            let savedPos;
            let lastScanAction;
            let lastTokenInfo;
            const res = cb({
                advance,
                readTokenInfo,
                readEOFTokenRange,
                isOnToken,
                isOnEOF,
                getCurrentLeadingTrivia: () => leadingTrivia,
                lastTrailingTriviaWasNewLine: () => wasNewLine,
                skipToEndOf,
                skipToStartOf,
                getStartPos: () => {
                    var _a2;
                    return (_a2 = lastTokenInfo == null ? void 0 : lastTokenInfo.token.pos) != null ? _a2 : scanner2.getTokenPos();
                }
            });
            lastTokenInfo = void 0;
            scanner2.setText(void 0);
            return res;
            function advance() {
                lastTokenInfo = void 0;
                const isStarted = scanner2.getStartPos() !== startPos;
                if (isStarted) {
                    wasNewLine = !!trailingTrivia && last(trailingTrivia).kind === 4 /* NewLineTrivia */;
                }
                else {
                    scanner2.scan();
                }
                leadingTrivia = void 0;
                trailingTrivia = void 0;
                let pos = scanner2.getStartPos();
                while (pos < endPos) {
                    const t = scanner2.getToken();
                    if (!isTrivia(t)) {
                        break;
                    }
                    scanner2.scan();
                    const item = {
                        pos,
                        end: scanner2.getStartPos(),
                        kind: t
                    };
                    pos = scanner2.getStartPos();
                    leadingTrivia = append(leadingTrivia, item);
                }
                savedPos = scanner2.getStartPos();
            }
            function shouldRescanGreaterThanToken(node) {
                switch (node.kind) {
                    case 33 /* GreaterThanEqualsToken */:
                    case 71 /* GreaterThanGreaterThanEqualsToken */:
                    case 72 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                    case 49 /* GreaterThanGreaterThanGreaterThanToken */:
                    case 48 /* GreaterThanGreaterThanToken */:
                        return true;
                }
                return false;
            }
            function shouldRescanJsxIdentifier(node) {
                if (node.parent) {
                    switch (node.parent.kind) {
                        case 288 /* JsxAttribute */:
                        case 283 /* JsxOpeningElement */:
                        case 284 /* JsxClosingElement */:
                        case 282 /* JsxSelfClosingElement */:
                            return isKeyword(node.kind) || node.kind === 79 /* Identifier */;
                    }
                }
                return false;
            }
            function shouldRescanJsxText(node) {
                return isJsxText(node) || isJsxElement(node) && (lastTokenInfo == null ? void 0 : lastTokenInfo.token.kind) === 11 /* JsxText */;
            }
            function shouldRescanSlashToken(container) {
                return container.kind === 13 /* RegularExpressionLiteral */;
            }
            function shouldRescanTemplateToken(container) {
                return container.kind === 16 /* TemplateMiddle */ || container.kind === 17 /* TemplateTail */;
            }
            function shouldRescanJsxAttributeValue(node) {
                return node.parent && isJsxAttribute(node.parent) && node.parent.initializer === node;
            }
            function startsWithSlashToken(t) {
                return t === 43 /* SlashToken */ || t === 68 /* SlashEqualsToken */;
            }
            function readTokenInfo(n) {
                Debug.assert(isOnToken());
                const expectedScanAction = shouldRescanGreaterThanToken(n) ? 1 /* RescanGreaterThanToken */ : shouldRescanSlashToken(n) ? 2 /* RescanSlashToken */ : shouldRescanTemplateToken(n) ? 3 /* RescanTemplateToken */ : shouldRescanJsxIdentifier(n) ? 4 /* RescanJsxIdentifier */ : shouldRescanJsxText(n) ? 5 /* RescanJsxText */ : shouldRescanJsxAttributeValue(n) ? 6 /* RescanJsxAttributeValue */ : 0 /* Scan */;
                if (lastTokenInfo && expectedScanAction === lastScanAction) {
                    return fixTokenKind(lastTokenInfo, n);
                }
                if (scanner2.getStartPos() !== savedPos) {
                    Debug.assert(lastTokenInfo !== void 0);
                    scanner2.setTextPos(savedPos);
                    scanner2.scan();
                }
                let currentToken = getNextToken(n, expectedScanAction);
                const token = createTextRangeWithKind(scanner2.getStartPos(), scanner2.getTextPos(), currentToken);
                if (trailingTrivia) {
                    trailingTrivia = void 0;
                }
                while (scanner2.getStartPos() < endPos) {
                    currentToken = scanner2.scan();
                    if (!isTrivia(currentToken)) {
                        break;
                    }
                    const trivia = createTextRangeWithKind(scanner2.getStartPos(), scanner2.getTextPos(), currentToken);
                    if (!trailingTrivia) {
                        trailingTrivia = [];
                    }
                    trailingTrivia.push(trivia);
                    if (currentToken === 4 /* NewLineTrivia */) {
                        scanner2.scan();
                        break;
                    }
                }
                lastTokenInfo = { leadingTrivia, trailingTrivia, token };
                return fixTokenKind(lastTokenInfo, n);
            }
            function getNextToken(n, expectedScanAction) {
                const token = scanner2.getToken();
                lastScanAction = 0 /* Scan */;
                switch (expectedScanAction) {
                    case 1 /* RescanGreaterThanToken */:
                        if (token === 31 /* GreaterThanToken */) {
                            lastScanAction = 1 /* RescanGreaterThanToken */;
                            const newToken = scanner2.reScanGreaterToken();
                            Debug.assert(n.kind === newToken);
                            return newToken;
                        }
                        break;
                    case 2 /* RescanSlashToken */:
                        if (startsWithSlashToken(token)) {
                            lastScanAction = 2 /* RescanSlashToken */;
                            const newToken = scanner2.reScanSlashToken();
                            Debug.assert(n.kind === newToken);
                            return newToken;
                        }
                        break;
                    case 3 /* RescanTemplateToken */:
                        if (token === 19 /* CloseBraceToken */) {
                            lastScanAction = 3 /* RescanTemplateToken */;
                            return scanner2.reScanTemplateToken(
                            /* isTaggedTemplate */
                            false);
                        }
                        break;
                    case 4 /* RescanJsxIdentifier */:
                        lastScanAction = 4 /* RescanJsxIdentifier */;
                        return scanner2.scanJsxIdentifier();
                    case 5 /* RescanJsxText */:
                        lastScanAction = 5 /* RescanJsxText */;
                        return scanner2.reScanJsxToken(
                        /* allowMultilineJsxText */
                        false);
                    case 6 /* RescanJsxAttributeValue */:
                        lastScanAction = 6 /* RescanJsxAttributeValue */;
                        return scanner2.reScanJsxAttributeValue();
                    case 0 /* Scan */:
                        break;
                    default:
                        Debug.assertNever(expectedScanAction);
                }
                return token;
            }
            function readEOFTokenRange() {
                Debug.assert(isOnEOF());
                return createTextRangeWithKind(scanner2.getStartPos(), scanner2.getTextPos(), 1 /* EndOfFileToken */);
            }
            function isOnToken() {
                const current = lastTokenInfo ? lastTokenInfo.token.kind : scanner2.getToken();
                return current !== 1 /* EndOfFileToken */ && !isTrivia(current);
            }
            function isOnEOF() {
                const current = lastTokenInfo ? lastTokenInfo.token.kind : scanner2.getToken();
                return current === 1 /* EndOfFileToken */;
            }
            function fixTokenKind(tokenInfo, container) {
                if (isToken(container) && tokenInfo.token.kind !== container.kind) {
                    tokenInfo.token.kind = container.kind;
                }
                return tokenInfo;
            }
            function skipToEndOf(node) {
                scanner2.setTextPos(node.end);
                savedPos = scanner2.getStartPos();
                lastScanAction = void 0;
                lastTokenInfo = void 0;
                wasNewLine = false;
                leadingTrivia = void 0;
                trailingTrivia = void 0;
            }
            function skipToStartOf(node) {
                scanner2.setTextPos(node.pos);
                savedPos = scanner2.getStartPos();
                lastScanAction = void 0;
                lastTokenInfo = void 0;
                wasNewLine = false;
                leadingTrivia = void 0;
                trailingTrivia = void 0;
            }
        }
        var standardScanner, jsxScanner;
        var init_formattingScanner = __esm({
            "src/services/formatting/formattingScanner.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
                standardScanner = createScanner(99 /* Latest */, 
                /*skipTrivia*/
                false, 0 /* Standard */);
                jsxScanner = createScanner(99 /* Latest */, 
                /*skipTrivia*/
                false, 1 /* JSX */);
            }
        });
        // src/services/formatting/rule.ts
        var anyContext, RuleAction, RuleFlags;
        var init_rule = __esm({
            "src/services/formatting/rule.ts"() {
                "use strict";
                init_ts4();
                anyContext = emptyArray;
                RuleAction = /* @__PURE__ */ ((RuleAction2) => {
                    RuleAction2[RuleAction2["None"] = 0] = "None";
                    RuleAction2[RuleAction2["StopProcessingSpaceActions"] = 1] = "StopProcessingSpaceActions";
                    RuleAction2[RuleAction2["StopProcessingTokenActions"] = 2] = "StopProcessingTokenActions";
                    RuleAction2[RuleAction2["InsertSpace"] = 4] = "InsertSpace";
                    RuleAction2[RuleAction2["InsertNewLine"] = 8] = "InsertNewLine";
                    RuleAction2[RuleAction2["DeleteSpace"] = 16] = "DeleteSpace";
                    RuleAction2[RuleAction2["DeleteToken"] = 32] = "DeleteToken";
                    RuleAction2[RuleAction2["InsertTrailingSemicolon"] = 64] = "InsertTrailingSemicolon";
                    RuleAction2[RuleAction2["StopAction"] = 3] = "StopAction";
                    RuleAction2[RuleAction2["ModifySpaceAction"] = 28] = "ModifySpaceAction";
                    RuleAction2[RuleAction2["ModifyTokenAction"] = 96] = "ModifyTokenAction";
                    return RuleAction2;
                })(RuleAction || {});
                RuleFlags = /* @__PURE__ */ ((RuleFlags2) => {
                    RuleFlags2[RuleFlags2["None"] = 0] = "None";
                    RuleFlags2[RuleFlags2["CanDeleteNewLines"] = 1] = "CanDeleteNewLines";
                    return RuleFlags2;
                })(RuleFlags || {});
            }
        });
        // src/services/formatting/rules.ts
        function getAllRules() {
            const allTokens = [];
            for (let token = 0 /* FirstToken */; token <= 162 /* LastToken */; token++) {
                if (token !== 1 /* EndOfFileToken */) {
                    allTokens.push(token);
                }
            }
            function anyTokenExcept(...tokens) {
                return { tokens: allTokens.filter((t) => !tokens.some((t2) => t2 === t)), isSpecific: false };
            }
            const anyToken = { tokens: allTokens, isSpecific: false };
            const anyTokenIncludingMultilineComments = tokenRangeFrom([...allTokens, 3 /* MultiLineCommentTrivia */]);
            const anyTokenIncludingEOF = tokenRangeFrom([...allTokens, 1 /* EndOfFileToken */]);
            const keywords = tokenRangeFromRange(81 /* FirstKeyword */, 162 /* LastKeyword */);
            const binaryOperators = tokenRangeFromRange(29 /* FirstBinaryOperator */, 78 /* LastBinaryOperator */);
            const binaryKeywordOperators = [
                101 /* InKeyword */,
                102 /* InstanceOfKeyword */,
                162 /* OfKeyword */,
                128 /* AsKeyword */,
                140 /* IsKeyword */,
                150 /* SatisfiesKeyword */
            ];
            const unaryPrefixOperators = [45 /* PlusPlusToken */, 46 /* MinusMinusToken */, 54 /* TildeToken */, 53 /* ExclamationToken */];
            const unaryPrefixExpressions = [
                8 /* NumericLiteral */,
                9 /* BigIntLiteral */,
                79 /* Identifier */,
                20 /* OpenParenToken */,
                22 /* OpenBracketToken */,
                18 /* OpenBraceToken */,
                108 /* ThisKeyword */,
                103 /* NewKeyword */
            ];
            const unaryPreincrementExpressions = [79 /* Identifier */, 20 /* OpenParenToken */, 108 /* ThisKeyword */, 103 /* NewKeyword */];
            const unaryPostincrementExpressions = [79 /* Identifier */, 21 /* CloseParenToken */, 23 /* CloseBracketToken */, 103 /* NewKeyword */];
            const unaryPredecrementExpressions = [79 /* Identifier */, 20 /* OpenParenToken */, 108 /* ThisKeyword */, 103 /* NewKeyword */];
            const unaryPostdecrementExpressions = [79 /* Identifier */, 21 /* CloseParenToken */, 23 /* CloseBracketToken */, 103 /* NewKeyword */];
            const comments = [2 /* SingleLineCommentTrivia */, 3 /* MultiLineCommentTrivia */];
            const typeNames = [79 /* Identifier */, ...typeKeywords];
            const functionOpenBraceLeftTokenRange = anyTokenIncludingMultilineComments;
            const typeScriptOpenBraceLeftTokenRange = tokenRangeFrom([79 /* Identifier */, 3 /* MultiLineCommentTrivia */, 84 /* ClassKeyword */, 93 /* ExportKeyword */, 100 /* ImportKeyword */]);
            const controlOpenBraceLeftTokenRange = tokenRangeFrom([21 /* CloseParenToken */, 3 /* MultiLineCommentTrivia */, 90 /* DoKeyword */, 111 /* TryKeyword */, 96 /* FinallyKeyword */, 91 /* ElseKeyword */]);
            const highPriorityCommonRules = [
                // Leave comments alone
                rule("IgnoreBeforeComment", anyToken, comments, anyContext, 1 /* StopProcessingSpaceActions */),
                rule("IgnoreAfterLineComment", 2 /* SingleLineCommentTrivia */, anyToken, anyContext, 1 /* StopProcessingSpaceActions */),
                rule("NotSpaceBeforeColon", anyToken, 58 /* ColonToken */, [isNonJsxSameLineTokenContext, isNotBinaryOpContext, isNotTypeAnnotationContext], 16 /* DeleteSpace */),
                rule("SpaceAfterColon", 58 /* ColonToken */, anyToken, [isNonJsxSameLineTokenContext, isNotBinaryOpContext], 4 /* InsertSpace */),
                rule("NoSpaceBeforeQuestionMark", anyToken, 57 /* QuestionToken */, [isNonJsxSameLineTokenContext, isNotBinaryOpContext, isNotTypeAnnotationContext], 16 /* DeleteSpace */),
                // insert space after '?' only when it is used in conditional operator
                rule("SpaceAfterQuestionMarkInConditionalOperator", 57 /* QuestionToken */, anyToken, [isNonJsxSameLineTokenContext, isConditionalOperatorContext], 4 /* InsertSpace */),
                // in other cases there should be no space between '?' and next token
                rule("NoSpaceAfterQuestionMark", 57 /* QuestionToken */, anyToken, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeDot", anyToken, [24 /* DotToken */, 28 /* QuestionDotToken */], [isNonJsxSameLineTokenContext, isNotPropertyAccessOnIntegerLiteral], 16 /* DeleteSpace */),
                rule("NoSpaceAfterDot", [24 /* DotToken */, 28 /* QuestionDotToken */], anyToken, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBetweenImportParenInImportType", 100 /* ImportKeyword */, 20 /* OpenParenToken */, [isNonJsxSameLineTokenContext, isImportTypeContext], 16 /* DeleteSpace */),
                // Special handling of unary operators.
                // Prefix operators generally shouldn't have a space between
                // them and their target unary expression.
                rule("NoSpaceAfterUnaryPrefixOperator", unaryPrefixOperators, unaryPrefixExpressions, [isNonJsxSameLineTokenContext, isNotBinaryOpContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterUnaryPreincrementOperator", 45 /* PlusPlusToken */, unaryPreincrementExpressions, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterUnaryPredecrementOperator", 46 /* MinusMinusToken */, unaryPredecrementExpressions, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeUnaryPostincrementOperator", unaryPostincrementExpressions, 45 /* PlusPlusToken */, [isNonJsxSameLineTokenContext, isNotStatementConditionContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeUnaryPostdecrementOperator", unaryPostdecrementExpressions, 46 /* MinusMinusToken */, [isNonJsxSameLineTokenContext, isNotStatementConditionContext], 16 /* DeleteSpace */),
                // More unary operator special-casing.
                // DevDiv 181814: Be careful when removing leading whitespace
                // around unary operators.  Examples:
                //      1 - -2  --X--> 1--2
                //      a + ++b --X--> a+++b
                rule("SpaceAfterPostincrementWhenFollowedByAdd", 45 /* PlusPlusToken */, 39 /* PlusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterAddWhenFollowedByUnaryPlus", 39 /* PlusToken */, 39 /* PlusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterAddWhenFollowedByPreincrement", 39 /* PlusToken */, 45 /* PlusPlusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterPostdecrementWhenFollowedBySubtract", 46 /* MinusMinusToken */, 40 /* MinusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterSubtractWhenFollowedByUnaryMinus", 40 /* MinusToken */, 40 /* MinusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterSubtractWhenFollowedByPredecrement", 40 /* MinusToken */, 46 /* MinusMinusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterCloseBrace", 19 /* CloseBraceToken */, [27 /* CommaToken */, 26 /* SemicolonToken */], [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // For functions and control block place } on a new line [multi-line rule]
                rule("NewLineBeforeCloseBraceInBlockContext", anyTokenIncludingMultilineComments, 19 /* CloseBraceToken */, [isMultilineBlockContext], 8 /* InsertNewLine */),
                // Space/new line after }.
                rule("SpaceAfterCloseBrace", 19 /* CloseBraceToken */, anyTokenExcept(21 /* CloseParenToken */), [isNonJsxSameLineTokenContext, isAfterCodeBlockContext], 4 /* InsertSpace */),
                // Special case for (}, else) and (}, while) since else & while tokens are not part of the tree which makes SpaceAfterCloseBrace rule not applied
                // Also should not apply to })
                rule("SpaceBetweenCloseBraceAndElse", 19 /* CloseBraceToken */, 91 /* ElseKeyword */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBetweenCloseBraceAndWhile", 19 /* CloseBraceToken */, 115 /* WhileKeyword */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenEmptyBraceBrackets", 18 /* OpenBraceToken */, 19 /* CloseBraceToken */, [isNonJsxSameLineTokenContext, isObjectContext], 16 /* DeleteSpace */),
                // Add a space after control dec context if the next character is an open bracket ex: 'if (false)[a, b] = [1, 2];' -> 'if (false) [a, b] = [1, 2];'
                rule("SpaceAfterConditionalClosingParen", 21 /* CloseParenToken */, 22 /* OpenBracketToken */, [isControlDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenFunctionKeywordAndStar", 98 /* FunctionKeyword */, 41 /* AsteriskToken */, [isFunctionDeclarationOrFunctionExpressionContext], 16 /* DeleteSpace */),
                rule("SpaceAfterStarInGeneratorDeclaration", 41 /* AsteriskToken */, 79 /* Identifier */, [isFunctionDeclarationOrFunctionExpressionContext], 4 /* InsertSpace */),
                rule("SpaceAfterFunctionInFuncDecl", 98 /* FunctionKeyword */, anyToken, [isFunctionDeclContext], 4 /* InsertSpace */),
                // Insert new line after { and before } in multi-line contexts.
                rule("NewLineAfterOpenBraceInBlockContext", 18 /* OpenBraceToken */, anyToken, [isMultilineBlockContext], 8 /* InsertNewLine */),
                // For get/set members, we check for (identifier,identifier) since get/set don't have tokens and they are represented as just an identifier token.
                // Though, we do extra check on the context to make sure we are dealing with get/set node. Example:
                //      get x() {}
                //      set x(val) {}
                rule("SpaceAfterGetSetInMember", [137 /* GetKeyword */, 151 /* SetKeyword */], 79 /* Identifier */, [isFunctionDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenYieldKeywordAndStar", 125 /* YieldKeyword */, 41 /* AsteriskToken */, [isNonJsxSameLineTokenContext, isYieldOrYieldStarWithOperand], 16 /* DeleteSpace */),
                rule("SpaceBetweenYieldOrYieldStarAndOperand", [125 /* YieldKeyword */, 41 /* AsteriskToken */], anyToken, [isNonJsxSameLineTokenContext, isYieldOrYieldStarWithOperand], 4 /* InsertSpace */),
                rule("NoSpaceBetweenReturnAndSemicolon", 105 /* ReturnKeyword */, 26 /* SemicolonToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("SpaceAfterCertainKeywords", [113 /* VarKeyword */, 109 /* ThrowKeyword */, 103 /* NewKeyword */, 89 /* DeleteKeyword */, 105 /* ReturnKeyword */, 112 /* TypeOfKeyword */, 133 /* AwaitKeyword */], anyToken, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceAfterLetConstInVariableDeclaration", [119 /* LetKeyword */, 85 /* ConstKeyword */], anyToken, [isNonJsxSameLineTokenContext, isStartOfVariableDeclarationList], 4 /* InsertSpace */),
                rule("NoSpaceBeforeOpenParenInFuncCall", anyToken, 20 /* OpenParenToken */, [isNonJsxSameLineTokenContext, isFunctionCallOrNewContext, isPreviousTokenNotComma], 16 /* DeleteSpace */),
                // Special case for binary operators (that are keywords). For these we have to add a space and shouldn't follow any user options.
                rule("SpaceBeforeBinaryKeywordOperator", anyToken, binaryKeywordOperators, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterBinaryKeywordOperator", binaryKeywordOperators, anyToken, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterVoidOperator", 114 /* VoidKeyword */, anyToken, [isNonJsxSameLineTokenContext, isVoidOpContext], 4 /* InsertSpace */),
                // Async-await
                rule("SpaceBetweenAsyncAndOpenParen", 132 /* AsyncKeyword */, 20 /* OpenParenToken */, [isArrowFunctionContext, isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBetweenAsyncAndFunctionKeyword", 132 /* AsyncKeyword */, [98 /* FunctionKeyword */, 79 /* Identifier */], [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Template string
                rule("NoSpaceBetweenTagAndTemplateString", [79 /* Identifier */, 21 /* CloseParenToken */], [14 /* NoSubstitutionTemplateLiteral */, 15 /* TemplateHead */], [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // JSX opening elements
                rule("SpaceBeforeJsxAttribute", anyToken, 79 /* Identifier */, [isNextTokenParentJsxAttribute, isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBeforeSlashInJsxOpeningElement", anyToken, 43 /* SlashToken */, [isJsxSelfClosingElementContext, isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceBeforeGreaterThanTokenInJsxOpeningElement", 43 /* SlashToken */, 31 /* GreaterThanToken */, [isJsxSelfClosingElementContext, isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeEqualInJsxAttribute", anyToken, 63 /* EqualsToken */, [isJsxAttributeContext, isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterEqualInJsxAttribute", 63 /* EqualsToken */, anyToken, [isJsxAttributeContext, isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // TypeScript-specific rules
                // Use of module as a function call. e.g.: import m2 = module("m2");
                rule("NoSpaceAfterModuleImport", [142 /* ModuleKeyword */, 147 /* RequireKeyword */], 20 /* OpenParenToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Add a space around certain TypeScript keywords
                rule("SpaceAfterCertainTypeScriptKeywords", [
                    126 /* AbstractKeyword */,
                    127 /* AccessorKeyword */,
                    84 /* ClassKeyword */,
                    136 /* DeclareKeyword */,
                    88 /* DefaultKeyword */,
                    92 /* EnumKeyword */,
                    93 /* ExportKeyword */,
                    94 /* ExtendsKeyword */,
                    137 /* GetKeyword */,
                    117 /* ImplementsKeyword */,
                    100 /* ImportKeyword */,
                    118 /* InterfaceKeyword */,
                    142 /* ModuleKeyword */,
                    143 /* NamespaceKeyword */,
                    121 /* PrivateKeyword */,
                    123 /* PublicKeyword */,
                    122 /* ProtectedKeyword */,
                    146 /* ReadonlyKeyword */,
                    151 /* SetKeyword */,
                    124 /* StaticKeyword */,
                    154 /* TypeKeyword */,
                    158 /* FromKeyword */,
                    141 /* KeyOfKeyword */,
                    138 /* InferKeyword */
                ], anyToken, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCertainTypeScriptKeywords", anyToken, [94 /* ExtendsKeyword */, 117 /* ImplementsKeyword */, 158 /* FromKeyword */], [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Treat string literals in module names as identifiers, and add a space between the literal and the opening Brace braces, e.g.: module "m2" {
                rule("SpaceAfterModuleName", 10 /* StringLiteral */, 18 /* OpenBraceToken */, [isModuleDeclContext], 4 /* InsertSpace */),
                // Lambda expressions
                rule("SpaceBeforeArrow", anyToken, 38 /* EqualsGreaterThanToken */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceAfterArrow", 38 /* EqualsGreaterThanToken */, anyToken, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Optional parameters and let args
                rule("NoSpaceAfterEllipsis", 25 /* DotDotDotToken */, 79 /* Identifier */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOptionalParameters", 57 /* QuestionToken */, [21 /* CloseParenToken */, 27 /* CommaToken */], [isNonJsxSameLineTokenContext, isNotBinaryOpContext], 16 /* DeleteSpace */),
                // Remove spaces in empty interface literals. e.g.: x: {}
                rule("NoSpaceBetweenEmptyInterfaceBraceBrackets", 18 /* OpenBraceToken */, 19 /* CloseBraceToken */, [isNonJsxSameLineTokenContext, isObjectTypeContext], 16 /* DeleteSpace */),
                // generics and type assertions
                rule("NoSpaceBeforeOpenAngularBracket", typeNames, 29 /* LessThanToken */, [isNonJsxSameLineTokenContext, isTypeArgumentOrParameterOrAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceBetweenCloseParenAndAngularBracket", 21 /* CloseParenToken */, 29 /* LessThanToken */, [isNonJsxSameLineTokenContext, isTypeArgumentOrParameterOrAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOpenAngularBracket", 29 /* LessThanToken */, anyToken, [isNonJsxSameLineTokenContext, isTypeArgumentOrParameterOrAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseAngularBracket", anyToken, 31 /* GreaterThanToken */, [isNonJsxSameLineTokenContext, isTypeArgumentOrParameterOrAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterCloseAngularBracket", 31 /* GreaterThanToken */, [20 /* OpenParenToken */, 22 /* OpenBracketToken */, 31 /* GreaterThanToken */, 27 /* CommaToken */], [
                    isNonJsxSameLineTokenContext,
                    isTypeArgumentOrParameterOrAssertionContext,
                    isNotFunctionDeclContext,
                    isNonTypeAssertionContext
                ], 16 /* DeleteSpace */),
                // decorators
                rule("SpaceBeforeAt", [21 /* CloseParenToken */, 79 /* Identifier */], 59 /* AtToken */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterAt", 59 /* AtToken */, anyToken, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert space after @ in decorator
                rule("SpaceAfterDecorator", anyToken, [
                    126 /* AbstractKeyword */,
                    79 /* Identifier */,
                    93 /* ExportKeyword */,
                    88 /* DefaultKeyword */,
                    84 /* ClassKeyword */,
                    124 /* StaticKeyword */,
                    123 /* PublicKeyword */,
                    121 /* PrivateKeyword */,
                    122 /* ProtectedKeyword */,
                    137 /* GetKeyword */,
                    151 /* SetKeyword */,
                    22 /* OpenBracketToken */,
                    41 /* AsteriskToken */
                ], [isEndOfDecoratorContextOnSameLine], 4 /* InsertSpace */),
                rule("NoSpaceBeforeNonNullAssertionOperator", anyToken, 53 /* ExclamationToken */, [isNonJsxSameLineTokenContext, isNonNullAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterNewKeywordOnConstructorSignature", 103 /* NewKeyword */, 20 /* OpenParenToken */, [isNonJsxSameLineTokenContext, isConstructorSignatureContext], 16 /* DeleteSpace */),
                rule("SpaceLessThanAndNonJSXTypeAnnotation", 29 /* LessThanToken */, 29 /* LessThanToken */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */)
            ];
            const userConfigurableRules = [
                // Treat constructor as an identifier in a function declaration, and remove spaces between constructor and following left parentheses
                rule("SpaceAfterConstructor", 135 /* ConstructorKeyword */, 20 /* OpenParenToken */, [isOptionEnabled("insertSpaceAfterConstructor"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterConstructor", 135 /* ConstructorKeyword */, 20 /* OpenParenToken */, [isOptionDisabledOrUndefined("insertSpaceAfterConstructor"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("SpaceAfterComma", 27 /* CommaToken */, anyToken, [isOptionEnabled("insertSpaceAfterCommaDelimiter"), isNonJsxSameLineTokenContext, isNonJsxElementOrFragmentContext, isNextTokenNotCloseBracket, isNextTokenNotCloseParen], 4 /* InsertSpace */),
                rule("NoSpaceAfterComma", 27 /* CommaToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterCommaDelimiter"), isNonJsxSameLineTokenContext, isNonJsxElementOrFragmentContext], 16 /* DeleteSpace */),
                // Insert space after function keyword for anonymous functions
                rule("SpaceAfterAnonymousFunctionKeyword", [98 /* FunctionKeyword */, 41 /* AsteriskToken */], 20 /* OpenParenToken */, [isOptionEnabled("insertSpaceAfterFunctionKeywordForAnonymousFunctions"), isFunctionDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterAnonymousFunctionKeyword", [98 /* FunctionKeyword */, 41 /* AsteriskToken */], 20 /* OpenParenToken */, [isOptionDisabledOrUndefined("insertSpaceAfterFunctionKeywordForAnonymousFunctions"), isFunctionDeclContext], 16 /* DeleteSpace */),
                // Insert space after keywords in control flow statements
                rule("SpaceAfterKeywordInControl", keywords, 20 /* OpenParenToken */, [isOptionEnabled("insertSpaceAfterKeywordsInControlFlowStatements"), isControlDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterKeywordInControl", keywords, 20 /* OpenParenToken */, [isOptionDisabledOrUndefined("insertSpaceAfterKeywordsInControlFlowStatements"), isControlDeclContext], 16 /* DeleteSpace */),
                // Insert space after opening and before closing nonempty parenthesis
                rule("SpaceAfterOpenParen", 20 /* OpenParenToken */, anyToken, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCloseParen", anyToken, 21 /* CloseParenToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBetweenOpenParens", 20 /* OpenParenToken */, 20 /* OpenParenToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenParens", 20 /* OpenParenToken */, 21 /* CloseParenToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOpenParen", 20 /* OpenParenToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseParen", anyToken, 21 /* CloseParenToken */, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert space after opening and before closing nonempty brackets
                rule("SpaceAfterOpenBracket", 22 /* OpenBracketToken */, anyToken, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCloseBracket", anyToken, 23 /* CloseBracketToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenBrackets", 22 /* OpenBracketToken */, 23 /* CloseBracketToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOpenBracket", 22 /* OpenBracketToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseBracket", anyToken, 23 /* CloseBracketToken */, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert a space after { and before } in single-line contexts, but remove space from empty object literals {}.
                rule("SpaceAfterOpenBrace", 18 /* OpenBraceToken */, anyToken, [isOptionEnabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"), isBraceWrappedContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCloseBrace", anyToken, 19 /* CloseBraceToken */, [isOptionEnabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"), isBraceWrappedContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenEmptyBraceBrackets", 18 /* OpenBraceToken */, 19 /* CloseBraceToken */, [isNonJsxSameLineTokenContext, isObjectContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOpenBrace", 18 /* OpenBraceToken */, anyToken, [isOptionDisabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseBrace", anyToken, 19 /* CloseBraceToken */, [isOptionDisabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert a space after opening and before closing empty brace brackets
                rule("SpaceBetweenEmptyBraceBrackets", 18 /* OpenBraceToken */, 19 /* CloseBraceToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingEmptyBraces")], 4 /* InsertSpace */),
                rule("NoSpaceBetweenEmptyBraceBrackets", 18 /* OpenBraceToken */, 19 /* CloseBraceToken */, [isOptionDisabled("insertSpaceAfterOpeningAndBeforeClosingEmptyBraces"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert space after opening and before closing template string braces
                rule("SpaceAfterTemplateHeadAndMiddle", [15 /* TemplateHead */, 16 /* TemplateMiddle */], anyToken, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"), isNonJsxTextContext], 4 /* InsertSpace */, 1 /* CanDeleteNewLines */),
                rule("SpaceBeforeTemplateMiddleAndTail", anyToken, [16 /* TemplateMiddle */, 17 /* TemplateTail */], [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterTemplateHeadAndMiddle", [15 /* TemplateHead */, 16 /* TemplateMiddle */], anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"), isNonJsxTextContext], 16 /* DeleteSpace */, 1 /* CanDeleteNewLines */),
                rule("NoSpaceBeforeTemplateMiddleAndTail", anyToken, [16 /* TemplateMiddle */, 17 /* TemplateTail */], [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // No space after { and before } in JSX expression
                rule("SpaceAfterOpenBraceInJsxExpression", 18 /* OpenBraceToken */, anyToken, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"), isNonJsxSameLineTokenContext, isJsxExpressionContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCloseBraceInJsxExpression", anyToken, 19 /* CloseBraceToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"), isNonJsxSameLineTokenContext, isJsxExpressionContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterOpenBraceInJsxExpression", 18 /* OpenBraceToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"), isNonJsxSameLineTokenContext, isJsxExpressionContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseBraceInJsxExpression", anyToken, 19 /* CloseBraceToken */, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"), isNonJsxSameLineTokenContext, isJsxExpressionContext], 16 /* DeleteSpace */),
                // Insert space after semicolon in for statement
                rule("SpaceAfterSemicolonInFor", 26 /* SemicolonToken */, anyToken, [isOptionEnabled("insertSpaceAfterSemicolonInForStatements"), isNonJsxSameLineTokenContext, isForContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterSemicolonInFor", 26 /* SemicolonToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterSemicolonInForStatements"), isNonJsxSameLineTokenContext, isForContext], 16 /* DeleteSpace */),
                // Insert space before and after binary operators
                rule("SpaceBeforeBinaryOperator", anyToken, binaryOperators, [isOptionEnabled("insertSpaceBeforeAndAfterBinaryOperators"), isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterBinaryOperator", binaryOperators, anyToken, [isOptionEnabled("insertSpaceBeforeAndAfterBinaryOperators"), isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("NoSpaceBeforeBinaryOperator", anyToken, binaryOperators, [isOptionDisabledOrUndefined("insertSpaceBeforeAndAfterBinaryOperators"), isNonJsxSameLineTokenContext, isBinaryOpContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterBinaryOperator", binaryOperators, anyToken, [isOptionDisabledOrUndefined("insertSpaceBeforeAndAfterBinaryOperators"), isNonJsxSameLineTokenContext, isBinaryOpContext], 16 /* DeleteSpace */),
                rule("SpaceBeforeOpenParenInFuncDecl", anyToken, 20 /* OpenParenToken */, [isOptionEnabled("insertSpaceBeforeFunctionParenthesis"), isNonJsxSameLineTokenContext, isFunctionDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceBeforeOpenParenInFuncDecl", anyToken, 20 /* OpenParenToken */, [isOptionDisabledOrUndefined("insertSpaceBeforeFunctionParenthesis"), isNonJsxSameLineTokenContext, isFunctionDeclContext], 16 /* DeleteSpace */),
                // Open Brace braces after control block
                rule("NewLineBeforeOpenBraceInControl", controlOpenBraceLeftTokenRange, 18 /* OpenBraceToken */, [isOptionEnabled("placeOpenBraceOnNewLineForControlBlocks"), isControlDeclContext, isBeforeMultilineBlockContext], 8 /* InsertNewLine */, 1 /* CanDeleteNewLines */),
                // Open Brace braces after function
                // TypeScript: Function can have return types, which can be made of tons of different token kinds
                rule("NewLineBeforeOpenBraceInFunction", functionOpenBraceLeftTokenRange, 18 /* OpenBraceToken */, [isOptionEnabled("placeOpenBraceOnNewLineForFunctions"), isFunctionDeclContext, isBeforeMultilineBlockContext], 8 /* InsertNewLine */, 1 /* CanDeleteNewLines */),
                // Open Brace braces after TypeScript module/class/interface
                rule("NewLineBeforeOpenBraceInTypeScriptDeclWithBlock", typeScriptOpenBraceLeftTokenRange, 18 /* OpenBraceToken */, [isOptionEnabled("placeOpenBraceOnNewLineForFunctions"), isTypeScriptDeclWithBlockContext, isBeforeMultilineBlockContext], 8 /* InsertNewLine */, 1 /* CanDeleteNewLines */),
                rule("SpaceAfterTypeAssertion", 31 /* GreaterThanToken */, anyToken, [isOptionEnabled("insertSpaceAfterTypeAssertion"), isNonJsxSameLineTokenContext, isTypeAssertionContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterTypeAssertion", 31 /* GreaterThanToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterTypeAssertion"), isNonJsxSameLineTokenContext, isTypeAssertionContext], 16 /* DeleteSpace */),
                rule("SpaceBeforeTypeAnnotation", anyToken, [57 /* QuestionToken */, 58 /* ColonToken */], [isOptionEnabled("insertSpaceBeforeTypeAnnotation"), isNonJsxSameLineTokenContext, isTypeAnnotationContext], 4 /* InsertSpace */),
                rule("NoSpaceBeforeTypeAnnotation", anyToken, [57 /* QuestionToken */, 58 /* ColonToken */], [isOptionDisabledOrUndefined("insertSpaceBeforeTypeAnnotation"), isNonJsxSameLineTokenContext, isTypeAnnotationContext], 16 /* DeleteSpace */),
                rule("NoOptionalSemicolon", 26 /* SemicolonToken */, anyTokenIncludingEOF, [optionEquals("semicolons", "remove" /* Remove */), isSemicolonDeletionContext], 32 /* DeleteToken */),
                rule("OptionalSemicolon", anyToken, anyTokenIncludingEOF, [optionEquals("semicolons", "insert" /* Insert */), isSemicolonInsertionContext], 64 /* InsertTrailingSemicolon */)
            ];
            const lowPriorityCommonRules = [
                // Space after keyword but not before ; or : or ?
                rule("NoSpaceBeforeSemicolon", anyToken, 26 /* SemicolonToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("SpaceBeforeOpenBraceInControl", controlOpenBraceLeftTokenRange, 18 /* OpenBraceToken */, [isOptionDisabledOrUndefinedOrTokensOnSameLine("placeOpenBraceOnNewLineForControlBlocks"), isControlDeclContext, isNotFormatOnEnter, isSameLineTokenOrBeforeBlockContext], 4 /* InsertSpace */, 1 /* CanDeleteNewLines */),
                rule("SpaceBeforeOpenBraceInFunction", functionOpenBraceLeftTokenRange, 18 /* OpenBraceToken */, [isOptionDisabledOrUndefinedOrTokensOnSameLine("placeOpenBraceOnNewLineForFunctions"), isFunctionDeclContext, isBeforeBlockContext, isNotFormatOnEnter, isSameLineTokenOrBeforeBlockContext], 4 /* InsertSpace */, 1 /* CanDeleteNewLines */),
                rule("SpaceBeforeOpenBraceInTypeScriptDeclWithBlock", typeScriptOpenBraceLeftTokenRange, 18 /* OpenBraceToken */, [isOptionDisabledOrUndefinedOrTokensOnSameLine("placeOpenBraceOnNewLineForFunctions"), isTypeScriptDeclWithBlockContext, isNotFormatOnEnter, isSameLineTokenOrBeforeBlockContext], 4 /* InsertSpace */, 1 /* CanDeleteNewLines */),
                rule("NoSpaceBeforeComma", anyToken, 27 /* CommaToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // No space before and after indexer `x[]`
                rule("NoSpaceBeforeOpenBracket", anyTokenExcept(132 /* AsyncKeyword */, 82 /* CaseKeyword */), 22 /* OpenBracketToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterCloseBracket", 23 /* CloseBracketToken */, anyToken, [isNonJsxSameLineTokenContext, isNotBeforeBlockInFunctionDeclarationContext], 16 /* DeleteSpace */),
                rule("SpaceAfterSemicolon", 26 /* SemicolonToken */, anyToken, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Remove extra space between for and await
                rule("SpaceBetweenForAndAwaitKeyword", 97 /* ForKeyword */, 133 /* AwaitKeyword */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Add a space between statements. All keywords except (do,else,case) has open/close parens after them.
                // So, we have a rule to add a space for [),Any], [do,Any], [else,Any], and [case,Any]
                rule("SpaceBetweenStatements", [21 /* CloseParenToken */, 90 /* DoKeyword */, 91 /* ElseKeyword */, 82 /* CaseKeyword */], anyToken, [isNonJsxSameLineTokenContext, isNonJsxElementOrFragmentContext, isNotForContext], 4 /* InsertSpace */),
                // This low-pri rule takes care of "try {", "catch {" and "finally {" in case the rule SpaceBeforeOpenBraceInControl didn't execute on FormatOnEnter.
                rule("SpaceAfterTryCatchFinally", [111 /* TryKeyword */, 83 /* CatchKeyword */, 96 /* FinallyKeyword */], 18 /* OpenBraceToken */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */)
            ];
            return [
                ...highPriorityCommonRules,
                ...userConfigurableRules,
                ...lowPriorityCommonRules
            ];
        }
        function rule(debugName, left, right, context, action, flags = 0 /* None */) {
            return { leftTokenRange: toTokenRange(left), rightTokenRange: toTokenRange(right), rule: { debugName, context, action, flags } };
        }
        function tokenRangeFrom(tokens) {
            return { tokens, isSpecific: true };
        }
        function toTokenRange(arg) {
            return typeof arg === "number" ? tokenRangeFrom([arg]) : isArray(arg) ? tokenRangeFrom(arg) : arg;
        }
        function tokenRangeFromRange(from, to, except = []) {
            const tokens = [];
            for (let token = from; token <= to; token++) {
                if (!contains(except, token)) {
                    tokens.push(token);
                }
            }
            return tokenRangeFrom(tokens);
        }
        function optionEquals(optionName, optionValue) {
            return (context) => context.options && context.options[optionName] === optionValue;
        }
        function isOptionEnabled(optionName) {
            return (context) => context.options && hasProperty(context.options, optionName) && !!context.options[optionName];
        }
        function isOptionDisabled(optionName) {
            return (context) => context.options && hasProperty(context.options, optionName) && !context.options[optionName];
        }
        function isOptionDisabledOrUndefined(optionName) {
            return (context) => !context.options || !hasProperty(context.options, optionName) || !context.options[optionName];
        }
        function isOptionDisabledOrUndefinedOrTokensOnSameLine(optionName) {
            return (context) => !context.options || !hasProperty(context.options, optionName) || !context.options[optionName] || context.TokensAreOnSameLine();
        }
        function isOptionEnabledOrUndefined(optionName) {
            return (context) => !context.options || !hasProperty(context.options, optionName) || !!context.options[optionName];
        }
        function isForContext(context) {
            return context.contextNode.kind === 245 /* ForStatement */;
        }
        function isNotForContext(context) {
            return !isForContext(context);
        }
        function isBinaryOpContext(context) {
            switch (context.contextNode.kind) {
                case 223 /* BinaryExpression */:
                    return context.contextNode.operatorToken.kind !== 27 /* CommaToken */;
                case 224 /* ConditionalExpression */:
                case 191 /* ConditionalType */:
                case 231 /* AsExpression */:
                case 278 /* ExportSpecifier */:
                case 273 /* ImportSpecifier */:
                case 179 /* TypePredicate */:
                case 189 /* UnionType */:
                case 190 /* IntersectionType */:
                case 235 /* SatisfiesExpression */:
                    return true;
                case 205 /* BindingElement */:
                case 262 /* TypeAliasDeclaration */:
                case 268 /* ImportEqualsDeclaration */:
                case 274 /* ExportAssignment */:
                case 257 /* VariableDeclaration */:
                case 166 /* Parameter */:
                case 302 /* EnumMember */:
                case 169 /* PropertyDeclaration */:
                case 168 /* PropertySignature */:
                    return context.currentTokenSpan.kind === 63 /* EqualsToken */ || context.nextTokenSpan.kind === 63 /* EqualsToken */;
                case 246 /* ForInStatement */:
                case 165 /* TypeParameter */:
                    return context.currentTokenSpan.kind === 101 /* InKeyword */ || context.nextTokenSpan.kind === 101 /* InKeyword */ || context.currentTokenSpan.kind === 63 /* EqualsToken */ || context.nextTokenSpan.kind === 63 /* EqualsToken */;
                case 247 /* ForOfStatement */:
                    return context.currentTokenSpan.kind === 162 /* OfKeyword */ || context.nextTokenSpan.kind === 162 /* OfKeyword */;
            }
            return false;
        }
        function isNotBinaryOpContext(context) {
            return !isBinaryOpContext(context);
        }
        function isNotTypeAnnotationContext(context) {
            return !isTypeAnnotationContext(context);
        }
        function isTypeAnnotationContext(context) {
            const contextKind = context.contextNode.kind;
            return contextKind === 169 /* PropertyDeclaration */ || contextKind === 168 /* PropertySignature */ || contextKind === 166 /* Parameter */ || contextKind === 257 /* VariableDeclaration */ || isFunctionLikeKind(contextKind);
        }
        function isConditionalOperatorContext(context) {
            return context.contextNode.kind === 224 /* ConditionalExpression */ || context.contextNode.kind === 191 /* ConditionalType */;
        }
        function isSameLineTokenOrBeforeBlockContext(context) {
            return context.TokensAreOnSameLine() || isBeforeBlockContext(context);
        }
        function isBraceWrappedContext(context) {
            return context.contextNode.kind === 203 /* ObjectBindingPattern */ || context.contextNode.kind === 197 /* MappedType */ || isSingleLineBlockContext(context);
        }
        function isBeforeMultilineBlockContext(context) {
            return isBeforeBlockContext(context) && !(context.NextNodeAllOnSameLine() || context.NextNodeBlockIsOnOneLine());
        }
        function isMultilineBlockContext(context) {
            return isBlockContext(context) && !(context.ContextNodeAllOnSameLine() || context.ContextNodeBlockIsOnOneLine());
        }
        function isSingleLineBlockContext(context) {
            return isBlockContext(context) && (context.ContextNodeAllOnSameLine() || context.ContextNodeBlockIsOnOneLine());
        }
        function isBlockContext(context) {
            return nodeIsBlockContext(context.contextNode);
        }
        function isBeforeBlockContext(context) {
            return nodeIsBlockContext(context.nextTokenParent);
        }
        function nodeIsBlockContext(node) {
            if (nodeIsTypeScriptDeclWithBlockContext(node)) {
                return true;
            }
            switch (node.kind) {
                case 238 /* Block */:
                case 266 /* CaseBlock */:
                case 207 /* ObjectLiteralExpression */:
                case 265 /* ModuleBlock */:
                    return true;
            }
            return false;
        }
        function isFunctionDeclContext(context) {
            switch (context.contextNode.kind) {
                case 259 /* FunctionDeclaration */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                case 176 /* CallSignature */:
                case 215 /* FunctionExpression */:
                case 173 /* Constructor */:
                case 216 /* ArrowFunction */:
                case 261 /* InterfaceDeclaration */:
                    return true;
            }
            return false;
        }
        function isNotFunctionDeclContext(context) {
            return !isFunctionDeclContext(context);
        }
        function isFunctionDeclarationOrFunctionExpressionContext(context) {
            return context.contextNode.kind === 259 /* FunctionDeclaration */ || context.contextNode.kind === 215 /* FunctionExpression */;
        }
        function isTypeScriptDeclWithBlockContext(context) {
            return nodeIsTypeScriptDeclWithBlockContext(context.contextNode);
        }
        function nodeIsTypeScriptDeclWithBlockContext(node) {
            switch (node.kind) {
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 261 /* InterfaceDeclaration */:
                case 263 /* EnumDeclaration */:
                case 184 /* TypeLiteral */:
                case 264 /* ModuleDeclaration */:
                case 275 /* ExportDeclaration */:
                case 276 /* NamedExports */:
                case 269 /* ImportDeclaration */:
                case 272 /* NamedImports */:
                    return true;
            }
            return false;
        }
        function isAfterCodeBlockContext(context) {
            switch (context.currentTokenParent.kind) {
                case 260 /* ClassDeclaration */:
                case 264 /* ModuleDeclaration */:
                case 263 /* EnumDeclaration */:
                case 295 /* CatchClause */:
                case 265 /* ModuleBlock */:
                case 252 /* SwitchStatement */:
                    return true;
                case 238 /* Block */: {
                    const blockParent = context.currentTokenParent.parent;
                    if (!blockParent || blockParent.kind !== 216 /* ArrowFunction */ && blockParent.kind !== 215 /* FunctionExpression */) {
                        return true;
                    }
                }
            }
            return false;
        }
        function isControlDeclContext(context) {
            switch (context.contextNode.kind) {
                case 242 /* IfStatement */:
                case 252 /* SwitchStatement */:
                case 245 /* ForStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                case 244 /* WhileStatement */:
                case 255 /* TryStatement */:
                case 243 /* DoStatement */:
                case 251 /* WithStatement */:
                case 295 /* CatchClause */:
                    return true;
                default:
                    return false;
            }
        }
        function isObjectContext(context) {
            return context.contextNode.kind === 207 /* ObjectLiteralExpression */;
        }
        function isFunctionCallContext(context) {
            return context.contextNode.kind === 210 /* CallExpression */;
        }
        function isNewContext(context) {
            return context.contextNode.kind === 211 /* NewExpression */;
        }
        function isFunctionCallOrNewContext(context) {
            return isFunctionCallContext(context) || isNewContext(context);
        }
        function isPreviousTokenNotComma(context) {
            return context.currentTokenSpan.kind !== 27 /* CommaToken */;
        }
        function isNextTokenNotCloseBracket(context) {
            return context.nextTokenSpan.kind !== 23 /* CloseBracketToken */;
        }
        function isNextTokenNotCloseParen(context) {
            return context.nextTokenSpan.kind !== 21 /* CloseParenToken */;
        }
        function isArrowFunctionContext(context) {
            return context.contextNode.kind === 216 /* ArrowFunction */;
        }
        function isImportTypeContext(context) {
            return context.contextNode.kind === 202 /* ImportType */;
        }
        function isNonJsxSameLineTokenContext(context) {
            return context.TokensAreOnSameLine() && context.contextNode.kind !== 11 /* JsxText */;
        }
        function isNonJsxTextContext(context) {
            return context.contextNode.kind !== 11 /* JsxText */;
        }
        function isNonJsxElementOrFragmentContext(context) {
            return context.contextNode.kind !== 281 /* JsxElement */ && context.contextNode.kind !== 285 /* JsxFragment */;
        }
        function isJsxExpressionContext(context) {
            return context.contextNode.kind === 291 /* JsxExpression */ || context.contextNode.kind === 290 /* JsxSpreadAttribute */;
        }
        function isNextTokenParentJsxAttribute(context) {
            return context.nextTokenParent.kind === 288 /* JsxAttribute */;
        }
        function isJsxAttributeContext(context) {
            return context.contextNode.kind === 288 /* JsxAttribute */;
        }
        function isJsxSelfClosingElementContext(context) {
            return context.contextNode.kind === 282 /* JsxSelfClosingElement */;
        }
        function isNotBeforeBlockInFunctionDeclarationContext(context) {
            return !isFunctionDeclContext(context) && !isBeforeBlockContext(context);
        }
        function isEndOfDecoratorContextOnSameLine(context) {
            return context.TokensAreOnSameLine() && hasDecorators(context.contextNode) && nodeIsInDecoratorContext(context.currentTokenParent) && !nodeIsInDecoratorContext(context.nextTokenParent);
        }
        function nodeIsInDecoratorContext(node) {
            while (node && isExpression(node)) {
                node = node.parent;
            }
            return node && node.kind === 167 /* Decorator */;
        }
        function isStartOfVariableDeclarationList(context) {
            return context.currentTokenParent.kind === 258 /* VariableDeclarationList */ && context.currentTokenParent.getStart(context.sourceFile) === context.currentTokenSpan.pos;
        }
        function isNotFormatOnEnter(context) {
            return context.formattingRequestKind !== 2 /* FormatOnEnter */;
        }
        function isModuleDeclContext(context) {
            return context.contextNode.kind === 264 /* ModuleDeclaration */;
        }
        function isObjectTypeContext(context) {
            return context.contextNode.kind === 184 /* TypeLiteral */;
        }
        function isConstructorSignatureContext(context) {
            return context.contextNode.kind === 177 /* ConstructSignature */;
        }
        function isTypeArgumentOrParameterOrAssertion(token, parent2) {
            if (token.kind !== 29 /* LessThanToken */ && token.kind !== 31 /* GreaterThanToken */) {
                return false;
            }
            switch (parent2.kind) {
                case 180 /* TypeReference */:
                case 213 /* TypeAssertionExpression */:
                case 262 /* TypeAliasDeclaration */:
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 261 /* InterfaceDeclaration */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 216 /* ArrowFunction */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 176 /* CallSignature */:
                case 177 /* ConstructSignature */:
                case 210 /* CallExpression */:
                case 211 /* NewExpression */:
                case 230 /* ExpressionWithTypeArguments */:
                    return true;
                default:
                    return false;
            }
        }
        function isTypeArgumentOrParameterOrAssertionContext(context) {
            return isTypeArgumentOrParameterOrAssertion(context.currentTokenSpan, context.currentTokenParent) || isTypeArgumentOrParameterOrAssertion(context.nextTokenSpan, context.nextTokenParent);
        }
        function isTypeAssertionContext(context) {
            return context.contextNode.kind === 213 /* TypeAssertionExpression */;
        }
        function isNonTypeAssertionContext(context) {
            return !isTypeAssertionContext(context);
        }
        function isVoidOpContext(context) {
            return context.currentTokenSpan.kind === 114 /* VoidKeyword */ && context.currentTokenParent.kind === 219 /* VoidExpression */;
        }
        function isYieldOrYieldStarWithOperand(context) {
            return context.contextNode.kind === 226 /* YieldExpression */ && context.contextNode.expression !== void 0;
        }
        function isNonNullAssertionContext(context) {
            return context.contextNode.kind === 232 /* NonNullExpression */;
        }
        function isNotStatementConditionContext(context) {
            return !isStatementConditionContext(context);
        }
        function isStatementConditionContext(context) {
            switch (context.contextNode.kind) {
                case 242 /* IfStatement */:
                case 245 /* ForStatement */:
                case 246 /* ForInStatement */:
                case 247 /* ForOfStatement */:
                case 243 /* DoStatement */:
                case 244 /* WhileStatement */:
                    return true;
                default:
                    return false;
            }
        }
        function isSemicolonDeletionContext(context) {
            let nextTokenKind = context.nextTokenSpan.kind;
            let nextTokenStart = context.nextTokenSpan.pos;
            if (isTrivia(nextTokenKind)) {
                const nextRealToken = context.nextTokenParent === context.currentTokenParent ? findNextToken(context.currentTokenParent, findAncestor(context.currentTokenParent, (a) => !a.parent), context.sourceFile) : context.nextTokenParent.getFirstToken(context.sourceFile);
                if (!nextRealToken) {
                    return true;
                }
                nextTokenKind = nextRealToken.kind;
                nextTokenStart = nextRealToken.getStart(context.sourceFile);
            }
            const startLine = context.sourceFile.getLineAndCharacterOfPosition(context.currentTokenSpan.pos).line;
            const endLine = context.sourceFile.getLineAndCharacterOfPosition(nextTokenStart).line;
            if (startLine === endLine) {
                return nextTokenKind === 19 /* CloseBraceToken */ || nextTokenKind === 1 /* EndOfFileToken */;
            }
            if (nextTokenKind === 237 /* SemicolonClassElement */ || nextTokenKind === 26 /* SemicolonToken */) {
                return false;
            }
            if (context.contextNode.kind === 261 /* InterfaceDeclaration */ || context.contextNode.kind === 262 /* TypeAliasDeclaration */) {
                return !isPropertySignature(context.currentTokenParent) || !!context.currentTokenParent.type || nextTokenKind !== 20 /* OpenParenToken */;
            }
            if (isPropertyDeclaration(context.currentTokenParent)) {
                return !context.currentTokenParent.initializer;
            }
            return context.currentTokenParent.kind !== 245 /* ForStatement */ && context.currentTokenParent.kind !== 239 /* EmptyStatement */ && context.currentTokenParent.kind !== 237 /* SemicolonClassElement */ && nextTokenKind !== 22 /* OpenBracketToken */ && nextTokenKind !== 20 /* OpenParenToken */ && nextTokenKind !== 39 /* PlusToken */ && nextTokenKind !== 40 /* MinusToken */ && nextTokenKind !== 43 /* SlashToken */ && nextTokenKind !== 13 /* RegularExpressionLiteral */ && nextTokenKind !== 27 /* CommaToken */ && nextTokenKind !== 225 /* TemplateExpression */ && nextTokenKind !== 15 /* TemplateHead */ && nextTokenKind !== 14 /* NoSubstitutionTemplateLiteral */ && nextTokenKind !== 24 /* DotToken */;
        }
        function isSemicolonInsertionContext(context) {
            return positionIsASICandidate(context.currentTokenSpan.end, context.currentTokenParent, context.sourceFile);
        }
        function isNotPropertyAccessOnIntegerLiteral(context) {
            return !isPropertyAccessExpression(context.contextNode) || !isNumericLiteral(context.contextNode.expression) || context.contextNode.expression.getText().indexOf(".") !== -1;
        }
        var init_rules = __esm({
            "src/services/formatting/rules.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
            }
        });
        // src/services/formatting/rulesMap.ts
        function getFormatContext(options, host) {
            return { options, getRules: getRulesMap(), host };
        }
        function getRulesMap() {
            if (rulesMapCache === void 0) {
                rulesMapCache = createRulesMap(getAllRules());
            }
            return rulesMapCache;
        }
        function getRuleActionExclusion(ruleAction) {
            let mask2 = 0 /* None */;
            if (ruleAction & 1 /* StopProcessingSpaceActions */) {
                mask2 |= 28 /* ModifySpaceAction */;
            }
            if (ruleAction & 2 /* StopProcessingTokenActions */) {
                mask2 |= 96 /* ModifyTokenAction */;
            }
            if (ruleAction & 28 /* ModifySpaceAction */) {
                mask2 |= 28 /* ModifySpaceAction */;
            }
            if (ruleAction & 96 /* ModifyTokenAction */) {
                mask2 |= 96 /* ModifyTokenAction */;
            }
            return mask2;
        }
        function createRulesMap(rules) {
            const map2 = buildMap(rules);
            return (context) => {
                const bucket = map2[getRuleBucketIndex(context.currentTokenSpan.kind, context.nextTokenSpan.kind)];
                if (bucket) {
                    const rules2 = [];
                    let ruleActionMask = 0;
                    for (const rule2 of bucket) {
                        const acceptRuleActions = ~getRuleActionExclusion(ruleActionMask);
                        if (rule2.action & acceptRuleActions && every(rule2.context, (c) => c(context))) {
                            rules2.push(rule2);
                            ruleActionMask |= rule2.action;
                        }
                    }
                    if (rules2.length) {
                        return rules2;
                    }
                }
            };
        }
        function buildMap(rules) {
            const map2 = new Array(mapRowLength * mapRowLength);
            const rulesBucketConstructionStateList = new Array(map2.length);
            for (const rule2 of rules) {
                const specificRule = rule2.leftTokenRange.isSpecific && rule2.rightTokenRange.isSpecific;
                for (const left of rule2.leftTokenRange.tokens) {
                    for (const right of rule2.rightTokenRange.tokens) {
                        const index = getRuleBucketIndex(left, right);
                        let rulesBucket = map2[index];
                        if (rulesBucket === void 0) {
                            rulesBucket = map2[index] = [];
                        }
                        addRule(rulesBucket, rule2.rule, specificRule, rulesBucketConstructionStateList, index);
                    }
                }
            }
            return map2;
        }
        function getRuleBucketIndex(row, column) {
            Debug.assert(row <= 162 /* LastKeyword */ && column <= 162 /* LastKeyword */, "Must compute formatting context from tokens");
            return row * mapRowLength + column;
        }
        function addRule(rules, rule2, specificTokens, constructionState, rulesBucketIndex) {
            const position = rule2.action & 3 /* StopAction */ ? specificTokens ? 0 /* StopRulesSpecific */ : RulesPosition.StopRulesAny : rule2.context !== anyContext ? specificTokens ? RulesPosition.ContextRulesSpecific : RulesPosition.ContextRulesAny : specificTokens ? RulesPosition.NoContextRulesSpecific : RulesPosition.NoContextRulesAny;
            const state = constructionState[rulesBucketIndex] || 0;
            rules.splice(getInsertionIndex(state, position), 0, rule2);
            constructionState[rulesBucketIndex] = increaseInsertionIndex(state, position);
        }
        function getInsertionIndex(indexBitmap, maskPosition) {
            let index = 0;
            for (let pos = 0; pos <= maskPosition; pos += maskBitSize) {
                index += indexBitmap & mask;
                indexBitmap >>= maskBitSize;
            }
            return index;
        }
        function increaseInsertionIndex(indexBitmap, maskPosition) {
            const value = (indexBitmap >> maskPosition & mask) + 1;
            Debug.assert((value & mask) === value, "Adding more rules into the sub-bucket than allowed. Maximum allowed is 32 rules.");
            return indexBitmap & ~(mask << maskPosition) | value << maskPosition;
        }
        var rulesMapCache, maskBitSize, mask, mapRowLength, RulesPosition;
        var init_rulesMap = __esm({
            "src/services/formatting/rulesMap.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
                maskBitSize = 5;
                mask = 31;
                mapRowLength = 162 /* LastToken */ + 1;
                RulesPosition = ((RulesPosition2) => {
                    RulesPosition2[RulesPosition2["StopRulesSpecific"] = 0] = "StopRulesSpecific";
                    RulesPosition2[RulesPosition2["StopRulesAny"] = maskBitSize * 1] = "StopRulesAny";
                    RulesPosition2[RulesPosition2["ContextRulesSpecific"] = maskBitSize * 2] = "ContextRulesSpecific";
                    RulesPosition2[RulesPosition2["ContextRulesAny"] = maskBitSize * 3] = "ContextRulesAny";
                    RulesPosition2[RulesPosition2["NoContextRulesSpecific"] = maskBitSize * 4] = "NoContextRulesSpecific";
                    RulesPosition2[RulesPosition2["NoContextRulesAny"] = maskBitSize * 5] = "NoContextRulesAny";
                    return RulesPosition2;
                })(RulesPosition || {});
            }
        });
        // src/services/formatting/formatting.ts
        function createTextRangeWithKind(pos, end, kind) {
            const textRangeWithKind = { pos, end, kind };
            if (Debug.isDebugging) {
                Object.defineProperty(textRangeWithKind, "__debugKind", {
                    get: () => Debug.formatSyntaxKind(kind)
                });
            }
            return textRangeWithKind;
        }
        function formatOnEnter(position, sourceFile, formatContext) {
            const line = sourceFile.getLineAndCharacterOfPosition(position).line;
            if (line === 0) {
                return [];
            }
            let endOfFormatSpan = getEndLinePosition(line, sourceFile);
            while (isWhiteSpaceSingleLine(sourceFile.text.charCodeAt(endOfFormatSpan))) {
                endOfFormatSpan--;
            }
            if (isLineBreak(sourceFile.text.charCodeAt(endOfFormatSpan))) {
                endOfFormatSpan--;
            }
            const span = {
                // get start position for the previous line
                pos: getStartPositionOfLine(line - 1, sourceFile),
                // end value is exclusive so add 1 to the result
                end: endOfFormatSpan + 1
            };
            return formatSpan(span, sourceFile, formatContext, 2 /* FormatOnEnter */);
        }
        function formatOnSemicolon(position, sourceFile, formatContext) {
            const semicolon = findImmediatelyPrecedingTokenOfKind(position, 26 /* SemicolonToken */, sourceFile);
            return formatNodeLines(findOutermostNodeWithinListLevel(semicolon), sourceFile, formatContext, 3 /* FormatOnSemicolon */);
        }
        function formatOnOpeningCurly(position, sourceFile, formatContext) {
            const openingCurly = findImmediatelyPrecedingTokenOfKind(position, 18 /* OpenBraceToken */, sourceFile);
            if (!openingCurly) {
                return [];
            }
            const curlyBraceRange = openingCurly.parent;
            const outermostNode = findOutermostNodeWithinListLevel(curlyBraceRange);
            const textRange = {
                pos: getLineStartPositionForPosition(outermostNode.getStart(sourceFile), sourceFile),
                // TODO: GH#18217
                end: position
            };
            return formatSpan(textRange, sourceFile, formatContext, 4 /* FormatOnOpeningCurlyBrace */);
        }
        function formatOnClosingCurly(position, sourceFile, formatContext) {
            const precedingToken = findImmediatelyPrecedingTokenOfKind(position, 19 /* CloseBraceToken */, sourceFile);
            return formatNodeLines(findOutermostNodeWithinListLevel(precedingToken), sourceFile, formatContext, 5 /* FormatOnClosingCurlyBrace */);
        }
        function formatDocument(sourceFile, formatContext) {
            const span = {
                pos: 0,
                end: sourceFile.text.length
            };
            return formatSpan(span, sourceFile, formatContext, 0 /* FormatDocument */);
        }
        function formatSelection(start, end, sourceFile, formatContext) {
            const span = {
                pos: getLineStartPositionForPosition(start, sourceFile),
                end
            };
            return formatSpan(span, sourceFile, formatContext, 1 /* FormatSelection */);
        }
        function findImmediatelyPrecedingTokenOfKind(end, expectedTokenKind, sourceFile) {
            const precedingToken = findPrecedingToken(end, sourceFile);
            return precedingToken && precedingToken.kind === expectedTokenKind && end === precedingToken.getEnd() ? precedingToken : void 0;
        }
        function findOutermostNodeWithinListLevel(node) {
            let current = node;
            while (current && current.parent && current.parent.end === node.end && !isListElement(current.parent, current)) {
                current = current.parent;
            }
            return current;
        }
        function isListElement(parent2, node) {
            switch (parent2.kind) {
                case 260 /* ClassDeclaration */:
                case 261 /* InterfaceDeclaration */:
                    return rangeContainsRange(parent2.members, node);
                case 264 /* ModuleDeclaration */:
                    const body = parent2.body;
                    return !!body && body.kind === 265 /* ModuleBlock */ && rangeContainsRange(body.statements, node);
                case 308 /* SourceFile */:
                case 238 /* Block */:
                case 265 /* ModuleBlock */:
                    return rangeContainsRange(parent2.statements, node);
                case 295 /* CatchClause */:
                    return rangeContainsRange(parent2.block.statements, node);
            }
            return false;
        }
        function findEnclosingNode(range, sourceFile) {
            return find2(sourceFile);
            function find2(n) {
                const candidate = forEachChild(n, (c) => startEndContainsRange(c.getStart(sourceFile), c.end, range) && c);
                if (candidate) {
                    const result = find2(candidate);
                    if (result) {
                        return result;
                    }
                }
                return n;
            }
        }
        function prepareRangeContainsErrorFunction(errors, originalRange) {
            if (!errors.length) {
                return rangeHasNoErrors;
            }
            const sorted = errors.filter((d) => rangeOverlapsWithStartEnd(originalRange, d.start, d.start + d.length)).sort((e1, e2) => e1.start - e2.start);
            if (!sorted.length) {
                return rangeHasNoErrors;
            }
            let index = 0;
            return (r) => {
                while (true) {
                    if (index >= sorted.length) {
                        return false;
                    }
                    const error = sorted[index];
                    if (r.end <= error.start) {
                        return false;
                    }
                    if (startEndOverlapsWithStartEnd(r.pos, r.end, error.start, error.start + error.length)) {
                        return true;
                    }
                    index++;
                }
            };
            function rangeHasNoErrors() {
                return false;
            }
        }
        function getScanStartPosition(enclosingNode, originalRange, sourceFile) {
            const start = enclosingNode.getStart(sourceFile);
            if (start === originalRange.pos && enclosingNode.end === originalRange.end) {
                return start;
            }
            const precedingToken = findPrecedingToken(originalRange.pos, sourceFile);
            if (!precedingToken) {
                return enclosingNode.pos;
            }
            if (precedingToken.end >= originalRange.pos) {
                return enclosingNode.pos;
            }
            return precedingToken.end;
        }
        function getOwnOrInheritedDelta(n, options, sourceFile) {
            let previousLine = -1 /* Unknown */;
            let child;
            while (n) {
                const line = sourceFile.getLineAndCharacterOfPosition(n.getStart(sourceFile)).line;
                if (previousLine !== -1 /* Unknown */ && line !== previousLine) {
                    break;
                }
                if (SmartIndenter.shouldIndentChildNode(options, n, child, sourceFile)) {
                    return options.indentSize;
                }
                previousLine = line;
                child = n;
                n = n.parent;
            }
            return 0;
        }
        function formatNodeGivenIndentation(node, sourceFileLike, languageVariant, initialIndentation, delta, formatContext) {
            const range = { pos: node.pos, end: node.end };
            return getFormattingScanner(sourceFileLike.text, languageVariant, range.pos, range.end, (scanner2) => formatSpanWorker(range, node, initialIndentation, delta, scanner2, formatContext, 1 /* FormatSelection */, (_) => false, 
            // assume that node does not have any errors
            sourceFileLike));
        }
        function formatNodeLines(node, sourceFile, formatContext, requestKind) {
            if (!node) {
                return [];
            }
            const span = {
                pos: getLineStartPositionForPosition(node.getStart(sourceFile), sourceFile),
                end: node.end
            };
            return formatSpan(span, sourceFile, formatContext, requestKind);
        }
        function formatSpan(originalRange, sourceFile, formatContext, requestKind) {
            const enclosingNode = findEnclosingNode(originalRange, sourceFile);
            return getFormattingScanner(sourceFile.text, sourceFile.languageVariant, getScanStartPosition(enclosingNode, originalRange, sourceFile), originalRange.end, (scanner2) => formatSpanWorker(originalRange, enclosingNode, SmartIndenter.getIndentationForNode(enclosingNode, originalRange, sourceFile, formatContext.options), getOwnOrInheritedDelta(enclosingNode, formatContext.options, sourceFile), scanner2, formatContext, requestKind, prepareRangeContainsErrorFunction(sourceFile.parseDiagnostics, originalRange), sourceFile));
        }
        function formatSpanWorker(originalRange, enclosingNode, initialIndentation, delta, formattingScanner, { options, getRules, host }, requestKind, rangeContainsError, sourceFile) {
            var _a2;
            const formattingContext = new FormattingContext(sourceFile, requestKind, options);
            let previousRangeTriviaEnd;
            let previousRange;
            let previousParent;
            let previousRangeStartLine;
            let lastIndentedLine;
            let indentationOnLastIndentedLine = -1 /* Unknown */;
            const edits = [];
            formattingScanner.advance();
            if (formattingScanner.isOnToken()) {
                const startLine = sourceFile.getLineAndCharacterOfPosition(enclosingNode.getStart(sourceFile)).line;
                let undecoratedStartLine = startLine;
                if (hasDecorators(enclosingNode)) {
                    undecoratedStartLine = sourceFile.getLineAndCharacterOfPosition(getNonDecoratorTokenPosOfNode(enclosingNode, sourceFile)).line;
                }
                processNode(enclosingNode, enclosingNode, startLine, undecoratedStartLine, initialIndentation, delta);
            }
            if (!formattingScanner.isOnToken()) {
                const indentation = SmartIndenter.nodeWillIndentChild(options, enclosingNode, 
                /*child*/
                void 0, sourceFile, 
                /*indentByDefault*/
                false) ? initialIndentation + options.indentSize : initialIndentation;
                const leadingTrivia = formattingScanner.getCurrentLeadingTrivia();
                if (leadingTrivia) {
                    indentTriviaItems(leadingTrivia, indentation, 
                    /*indentNextTokenOrTrivia*/
                    false, (item) => processRange(item, sourceFile.getLineAndCharacterOfPosition(item.pos), enclosingNode, enclosingNode, 
                    /*dynamicIndentation*/
                    void 0));
                    if (options.trimTrailingWhitespace !== false) {
                        trimTrailingWhitespacesForRemainingRange(leadingTrivia);
                    }
                }
            }
            if (previousRange && formattingScanner.getStartPos() >= originalRange.end) {
                const tokenInfo = formattingScanner.isOnEOF() ? formattingScanner.readEOFTokenRange() : formattingScanner.isOnToken() ? formattingScanner.readTokenInfo(enclosingNode).token : void 0;
                if (tokenInfo && tokenInfo.pos === previousRangeTriviaEnd) {
                    const parent2 = ((_a2 = findPrecedingToken(tokenInfo.end, sourceFile, enclosingNode)) == null ? void 0 : _a2.parent) || previousParent;
                    processPair(tokenInfo, sourceFile.getLineAndCharacterOfPosition(tokenInfo.pos).line, parent2, previousRange, previousRangeStartLine, previousParent, parent2, 
                    /*dynamicIndentation*/
                    void 0);
                }
            }
            return edits;
            function tryComputeIndentationForListItem(startPos, endPos, parentStartLine, range, inheritedIndentation) {
                if (rangeOverlapsWithStartEnd(range, startPos, endPos) || rangeContainsStartEnd(range, startPos, endPos)) {
                    if (inheritedIndentation !== -1 /* Unknown */) {
                        return inheritedIndentation;
                    }
                }
                else {
                    const startLine = sourceFile.getLineAndCharacterOfPosition(startPos).line;
                    const startLinePosition = getLineStartPositionForPosition(startPos, sourceFile);
                    const column = SmartIndenter.findFirstNonWhitespaceColumn(startLinePosition, startPos, sourceFile, options);
                    if (startLine !== parentStartLine || startPos === column) {
                        const baseIndentSize = SmartIndenter.getBaseIndentation(options);
                        return baseIndentSize > column ? baseIndentSize : column;
                    }
                }
                return -1 /* Unknown */;
            }
            function computeIndentation(node, startLine, inheritedIndentation, parent2, parentDynamicIndentation, effectiveParentStartLine) {
                const delta2 = SmartIndenter.shouldIndentChildNode(options, node) ? options.indentSize : 0;
                if (effectiveParentStartLine === startLine) {
                    return {
                        indentation: startLine === lastIndentedLine ? indentationOnLastIndentedLine : parentDynamicIndentation.getIndentation(),
                        delta: Math.min(options.indentSize, parentDynamicIndentation.getDelta(node) + delta2)
                    };
                }
                else if (inheritedIndentation === -1 /* Unknown */) {
                    if (node.kind === 20 /* OpenParenToken */ && startLine === lastIndentedLine) {
                        return { indentation: indentationOnLastIndentedLine, delta: parentDynamicIndentation.getDelta(node) };
                    }
                    else if (SmartIndenter.childStartsOnTheSameLineWithElseInIfStatement(parent2, node, startLine, sourceFile) || SmartIndenter.childIsUnindentedBranchOfConditionalExpression(parent2, node, startLine, sourceFile) || SmartIndenter.argumentStartsOnSameLineAsPreviousArgument(parent2, node, startLine, sourceFile)) {
                        return { indentation: parentDynamicIndentation.getIndentation(), delta: delta2 };
                    }
                    else {
                        return { indentation: parentDynamicIndentation.getIndentation() + parentDynamicIndentation.getDelta(node), delta: delta2 };
                    }
                }
                else {
                    return { indentation: inheritedIndentation, delta: delta2 };
                }
            }
            function getFirstNonDecoratorTokenOfNode(node) {
                if (canHaveModifiers(node)) {
                    const modifier = find(node.modifiers, isModifier, findIndex(node.modifiers, isDecorator));
                    if (modifier)
                        return modifier.kind;
                }
                switch (node.kind) {
                    case 260 /* ClassDeclaration */:
                        return 84 /* ClassKeyword */;
                    case 261 /* InterfaceDeclaration */:
                        return 118 /* InterfaceKeyword */;
                    case 259 /* FunctionDeclaration */:
                        return 98 /* FunctionKeyword */;
                    case 263 /* EnumDeclaration */:
                        return 263 /* EnumDeclaration */;
                    case 174 /* GetAccessor */:
                        return 137 /* GetKeyword */;
                    case 175 /* SetAccessor */:
                        return 151 /* SetKeyword */;
                    case 171 /* MethodDeclaration */:
                        if (node.asteriskToken) {
                            return 41 /* AsteriskToken */;
                        }
                    case 169 /* PropertyDeclaration */:
                    case 166 /* Parameter */:
                        const name = getNameOfDeclaration(node);
                        if (name) {
                            return name.kind;
                        }
                }
            }
            function getDynamicIndentation(node, nodeStartLine, indentation, delta2) {
                return {
                    getIndentationForComment: (kind, tokenIndentation, container) => {
                        switch (kind) {
                            case 19 /* CloseBraceToken */:
                            case 23 /* CloseBracketToken */:
                            case 21 /* CloseParenToken */:
                                return indentation + getDelta(container);
                        }
                        return tokenIndentation !== -1 /* Unknown */ ? tokenIndentation : indentation;
                    },
                    // if list end token is LessThanToken '>' then its delta should be explicitly suppressed
                    // so that LessThanToken as a binary operator can still be indented.
                    // foo.then
                    //     <
                    //         number,
                    //         string,
                    //     >();
                    // vs
                    // var a = xValue
                    //     > yValue;
                    getIndentationForToken: (line, kind, container, suppressDelta) => !suppressDelta && shouldAddDelta(line, kind, container) ? indentation + getDelta(container) : indentation,
                    getIndentation: () => indentation,
                    getDelta,
                    recomputeIndentation: (lineAdded, parent2) => {
                        if (SmartIndenter.shouldIndentChildNode(options, parent2, node, sourceFile)) {
                            indentation += lineAdded ? options.indentSize : -options.indentSize;
                            delta2 = SmartIndenter.shouldIndentChildNode(options, node) ? options.indentSize : 0;
                        }
                    }
                };
                function shouldAddDelta(line, kind, container) {
                    switch (kind) {
                        case 18 /* OpenBraceToken */:
                        case 19 /* CloseBraceToken */:
                        case 21 /* CloseParenToken */:
                        case 91 /* ElseKeyword */:
                        case 115 /* WhileKeyword */:
                        case 59 /* AtToken */:
                            return false;
                        case 43 /* SlashToken */:
                        case 31 /* GreaterThanToken */:
                            switch (container.kind) {
                                case 283 /* JsxOpeningElement */:
                                case 284 /* JsxClosingElement */:
                                case 282 /* JsxSelfClosingElement */:
                                    return false;
                            }
                            break;
                        case 22 /* OpenBracketToken */:
                        case 23 /* CloseBracketToken */:
                            if (container.kind !== 197 /* MappedType */) {
                                return false;
                            }
                            break;
                    }
                    return nodeStartLine !== line && !(hasDecorators(node) && kind === getFirstNonDecoratorTokenOfNode(node));
                }
                function getDelta(child) {
                    return SmartIndenter.nodeWillIndentChild(options, node, child, sourceFile, 
                    /*indentByDefault*/
                    true) ? delta2 : 0;
                }
            }
            function processNode(node, contextNode, nodeStartLine, undecoratedNodeStartLine, indentation, delta2) {
                if (!rangeOverlapsWithStartEnd(originalRange, node.getStart(sourceFile), node.getEnd())) {
                    return;
                }
                const nodeDynamicIndentation = getDynamicIndentation(node, nodeStartLine, indentation, delta2);
                let childContextNode = contextNode;
                forEachChild(node, (child) => {
                    processChildNode(child, 
                    /*inheritedIndentation*/
                    -1 /* Unknown */, node, nodeDynamicIndentation, nodeStartLine, undecoratedNodeStartLine, 
                    /*isListItem*/
                    false);
                }, (nodes) => {
                    processChildNodes(nodes, node, nodeStartLine, nodeDynamicIndentation);
                });
                while (formattingScanner.isOnToken() && formattingScanner.getStartPos() < originalRange.end) {
                    const tokenInfo = formattingScanner.readTokenInfo(node);
                    if (tokenInfo.token.end > Math.min(node.end, originalRange.end)) {
                        break;
                    }
                    consumeTokenAndAdvanceScanner(tokenInfo, node, nodeDynamicIndentation, node);
                }
                function processChildNode(child, inheritedIndentation, parent2, parentDynamicIndentation, parentStartLine, undecoratedParentStartLine, isListItem, isFirstListItem) {
                    Debug.assert(!nodeIsSynthesized(child));
                    if (nodeIsMissing(child) || isGrammarError(parent2, child)) {
                        return inheritedIndentation;
                    }
                    const childStartPos = child.getStart(sourceFile);
                    const childStartLine = sourceFile.getLineAndCharacterOfPosition(childStartPos).line;
                    let undecoratedChildStartLine = childStartLine;
                    if (hasDecorators(child)) {
                        undecoratedChildStartLine = sourceFile.getLineAndCharacterOfPosition(getNonDecoratorTokenPosOfNode(child, sourceFile)).line;
                    }
                    let childIndentationAmount = -1 /* Unknown */;
                    if (isListItem && rangeContainsRange(originalRange, parent2)) {
                        childIndentationAmount = tryComputeIndentationForListItem(childStartPos, child.end, parentStartLine, originalRange, inheritedIndentation);
                        if (childIndentationAmount !== -1 /* Unknown */) {
                            inheritedIndentation = childIndentationAmount;
                        }
                    }
                    if (!rangeOverlapsWithStartEnd(originalRange, child.pos, child.end)) {
                        if (child.end < originalRange.pos) {
                            formattingScanner.skipToEndOf(child);
                        }
                        return inheritedIndentation;
                    }
                    if (child.getFullWidth() === 0) {
                        return inheritedIndentation;
                    }
                    while (formattingScanner.isOnToken() && formattingScanner.getStartPos() < originalRange.end) {
                        const tokenInfo = formattingScanner.readTokenInfo(node);
                        if (tokenInfo.token.end > originalRange.end) {
                            return inheritedIndentation;
                        }
                        if (tokenInfo.token.end > childStartPos) {
                            if (tokenInfo.token.pos > childStartPos) {
                                formattingScanner.skipToStartOf(child);
                            }
                            break;
                        }
                        consumeTokenAndAdvanceScanner(tokenInfo, node, parentDynamicIndentation, node);
                    }
                    if (!formattingScanner.isOnToken() || formattingScanner.getStartPos() >= originalRange.end) {
                        return inheritedIndentation;
                    }
                    if (isToken(child)) {
                        const tokenInfo = formattingScanner.readTokenInfo(child);
                        if (child.kind !== 11 /* JsxText */) {
                            Debug.assert(tokenInfo.token.end === child.end, "Token end is child end");
                            consumeTokenAndAdvanceScanner(tokenInfo, node, parentDynamicIndentation, child);
                            return inheritedIndentation;
                        }
                    }
                    const effectiveParentStartLine = child.kind === 167 /* Decorator */ ? childStartLine : undecoratedParentStartLine;
                    const childIndentation = computeIndentation(child, childStartLine, childIndentationAmount, node, parentDynamicIndentation, effectiveParentStartLine);
                    processNode(child, childContextNode, childStartLine, undecoratedChildStartLine, childIndentation.indentation, childIndentation.delta);
                    childContextNode = node;
                    if (isFirstListItem && parent2.kind === 206 /* ArrayLiteralExpression */ && inheritedIndentation === -1 /* Unknown */) {
                        inheritedIndentation = childIndentation.indentation;
                    }
                    return inheritedIndentation;
                }
                function processChildNodes(nodes, parent2, parentStartLine, parentDynamicIndentation) {
                    Debug.assert(isNodeArray(nodes));
                    Debug.assert(!nodeIsSynthesized(nodes));
                    const listStartToken = getOpenTokenForList(parent2, nodes);
                    let listDynamicIndentation = parentDynamicIndentation;
                    let startLine = parentStartLine;
                    if (!rangeOverlapsWithStartEnd(originalRange, nodes.pos, nodes.end)) {
                        if (nodes.end < originalRange.pos) {
                            formattingScanner.skipToEndOf(nodes);
                        }
                        return;
                    }
                    if (listStartToken !== 0 /* Unknown */) {
                        while (formattingScanner.isOnToken() && formattingScanner.getStartPos() < originalRange.end) {
                            const tokenInfo = formattingScanner.readTokenInfo(parent2);
                            if (tokenInfo.token.end > nodes.pos) {
                                break;
                            }
                            else if (tokenInfo.token.kind === listStartToken) {
                                startLine = sourceFile.getLineAndCharacterOfPosition(tokenInfo.token.pos).line;
                                consumeTokenAndAdvanceScanner(tokenInfo, parent2, parentDynamicIndentation, parent2);
                                let indentationOnListStartToken;
                                if (indentationOnLastIndentedLine !== -1 /* Unknown */) {
                                    indentationOnListStartToken = indentationOnLastIndentedLine;
                                }
                                else {
                                    const startLinePosition = getLineStartPositionForPosition(tokenInfo.token.pos, sourceFile);
                                    indentationOnListStartToken = SmartIndenter.findFirstNonWhitespaceColumn(startLinePosition, tokenInfo.token.pos, sourceFile, options);
                                }
                                listDynamicIndentation = getDynamicIndentation(parent2, parentStartLine, indentationOnListStartToken, options.indentSize);
                            }
                            else {
                                consumeTokenAndAdvanceScanner(tokenInfo, parent2, parentDynamicIndentation, parent2);
                            }
                        }
                    }
                    let inheritedIndentation = -1 /* Unknown */;
                    for (let i = 0; i < nodes.length; i++) {
                        const child = nodes[i];
                        inheritedIndentation = processChildNode(child, inheritedIndentation, node, listDynamicIndentation, startLine, startLine, 
                        /*isListItem*/
                        true, 
                        /*isFirstListItem*/
                        i === 0);
                    }
                    const listEndToken = getCloseTokenForOpenToken(listStartToken);
                    if (listEndToken !== 0 /* Unknown */ && formattingScanner.isOnToken() && formattingScanner.getStartPos() < originalRange.end) {
                        let tokenInfo = formattingScanner.readTokenInfo(parent2);
                        if (tokenInfo.token.kind === 27 /* CommaToken */) {
                            consumeTokenAndAdvanceScanner(tokenInfo, parent2, listDynamicIndentation, parent2);
                            tokenInfo = formattingScanner.isOnToken() ? formattingScanner.readTokenInfo(parent2) : void 0;
                        }
                        if (tokenInfo && tokenInfo.token.kind === listEndToken && rangeContainsRange(parent2, tokenInfo.token)) {
                            consumeTokenAndAdvanceScanner(tokenInfo, parent2, listDynamicIndentation, parent2, 
                            /*isListEndToken*/
                            true);
                        }
                    }
                }
                function consumeTokenAndAdvanceScanner(currentTokenInfo, parent2, dynamicIndentation, container, isListEndToken) {
                    Debug.assert(rangeContainsRange(parent2, currentTokenInfo.token));
                    const lastTriviaWasNewLine = formattingScanner.lastTrailingTriviaWasNewLine();
                    let indentToken = false;
                    if (currentTokenInfo.leadingTrivia) {
                        processTrivia(currentTokenInfo.leadingTrivia, parent2, childContextNode, dynamicIndentation);
                    }
                    let lineAction = 0 /* None */;
                    const isTokenInRange = rangeContainsRange(originalRange, currentTokenInfo.token);
                    const tokenStart = sourceFile.getLineAndCharacterOfPosition(currentTokenInfo.token.pos);
                    if (isTokenInRange) {
                        const rangeHasError = rangeContainsError(currentTokenInfo.token);
                        const savePreviousRange = previousRange;
                        lineAction = processRange(currentTokenInfo.token, tokenStart, parent2, childContextNode, dynamicIndentation);
                        if (!rangeHasError) {
                            if (lineAction === 0 /* None */) {
                                const prevEndLine = savePreviousRange && sourceFile.getLineAndCharacterOfPosition(savePreviousRange.end).line;
                                indentToken = lastTriviaWasNewLine && tokenStart.line !== prevEndLine;
                            }
                            else {
                                indentToken = lineAction === 1 /* LineAdded */;
                            }
                        }
                    }
                    if (currentTokenInfo.trailingTrivia) {
                        previousRangeTriviaEnd = last(currentTokenInfo.trailingTrivia).end;
                        processTrivia(currentTokenInfo.trailingTrivia, parent2, childContextNode, dynamicIndentation);
                    }
                    if (indentToken) {
                        const tokenIndentation = isTokenInRange && !rangeContainsError(currentTokenInfo.token) ? dynamicIndentation.getIndentationForToken(tokenStart.line, currentTokenInfo.token.kind, container, !!isListEndToken) : -1 /* Unknown */;
                        let indentNextTokenOrTrivia = true;
                        if (currentTokenInfo.leadingTrivia) {
                            const commentIndentation = dynamicIndentation.getIndentationForComment(currentTokenInfo.token.kind, tokenIndentation, container);
                            indentNextTokenOrTrivia = indentTriviaItems(currentTokenInfo.leadingTrivia, commentIndentation, indentNextTokenOrTrivia, (item) => insertIndentation(item.pos, commentIndentation, 
                            /*lineAdded*/
                            false));
                        }
                        if (tokenIndentation !== -1 /* Unknown */ && indentNextTokenOrTrivia) {
                            insertIndentation(currentTokenInfo.token.pos, tokenIndentation, lineAction === 1 /* LineAdded */);
                            lastIndentedLine = tokenStart.line;
                            indentationOnLastIndentedLine = tokenIndentation;
                        }
                    }
                    formattingScanner.advance();
                    childContextNode = parent2;
                }
            }
            function indentTriviaItems(trivia, commentIndentation, indentNextTokenOrTrivia, indentSingleLine) {
                for (const triviaItem of trivia) {
                    const triviaInRange = rangeContainsRange(originalRange, triviaItem);
                    switch (triviaItem.kind) {
                        case 3 /* MultiLineCommentTrivia */:
                            if (triviaInRange) {
                                indentMultilineComment(triviaItem, commentIndentation, 
                                /*firstLineIsIndented*/
                                !indentNextTokenOrTrivia);
                            }
                            indentNextTokenOrTrivia = false;
                            break;
                        case 2 /* SingleLineCommentTrivia */:
                            if (indentNextTokenOrTrivia && triviaInRange) {
                                indentSingleLine(triviaItem);
                            }
                            indentNextTokenOrTrivia = false;
                            break;
                        case 4 /* NewLineTrivia */:
                            indentNextTokenOrTrivia = true;
                            break;
                    }
                }
                return indentNextTokenOrTrivia;
            }
            function processTrivia(trivia, parent2, contextNode, dynamicIndentation) {
                for (const triviaItem of trivia) {
                    if (isComment(triviaItem.kind) && rangeContainsRange(originalRange, triviaItem)) {
                        const triviaItemStart = sourceFile.getLineAndCharacterOfPosition(triviaItem.pos);
                        processRange(triviaItem, triviaItemStart, parent2, contextNode, dynamicIndentation);
                    }
                }
            }
            function processRange(range, rangeStart, parent2, contextNode, dynamicIndentation) {
                const rangeHasError = rangeContainsError(range);
                let lineAction = 0 /* None */;
                if (!rangeHasError) {
                    if (!previousRange) {
                        const originalStart = sourceFile.getLineAndCharacterOfPosition(originalRange.pos);
                        trimTrailingWhitespacesForLines(originalStart.line, rangeStart.line);
                    }
                    else {
                        lineAction = processPair(range, rangeStart.line, parent2, previousRange, previousRangeStartLine, previousParent, contextNode, dynamicIndentation);
                    }
                }
                previousRange = range;
                previousRangeTriviaEnd = range.end;
                previousParent = parent2;
                previousRangeStartLine = rangeStart.line;
                return lineAction;
            }
            function processPair(currentItem, currentStartLine, currentParent, previousItem, previousStartLine, previousParent2, contextNode, dynamicIndentation) {
                formattingContext.updateContext(previousItem, previousParent2, currentItem, currentParent, contextNode);
                const rules = getRules(formattingContext);
                let trimTrailingWhitespaces = formattingContext.options.trimTrailingWhitespace !== false;
                let lineAction = 0 /* None */;
                if (rules) {
                    forEachRight(rules, (rule2) => {
                        lineAction = applyRuleEdits(rule2, previousItem, previousStartLine, currentItem, currentStartLine);
                        if (dynamicIndentation) {
                            switch (lineAction) {
                                case 2 /* LineRemoved */:
                                    if (currentParent.getStart(sourceFile) === currentItem.pos) {
                                        dynamicIndentation.recomputeIndentation(
                                        /*lineAddedByFormatting*/
                                        false, contextNode);
                                    }
                                    break;
                                case 1 /* LineAdded */:
                                    if (currentParent.getStart(sourceFile) === currentItem.pos) {
                                        dynamicIndentation.recomputeIndentation(
                                        /*lineAddedByFormatting*/
                                        true, contextNode);
                                    }
                                    break;
                                default:
                                    Debug.assert(lineAction === 0 /* None */);
                            }
                        }
                        trimTrailingWhitespaces = trimTrailingWhitespaces && !(rule2.action & 16 /* DeleteSpace */) && rule2.flags !== 1 /* CanDeleteNewLines */;
                    });
                }
                else {
                    trimTrailingWhitespaces = trimTrailingWhitespaces && currentItem.kind !== 1 /* EndOfFileToken */;
                }
                if (currentStartLine !== previousStartLine && trimTrailingWhitespaces) {
                    trimTrailingWhitespacesForLines(previousStartLine, currentStartLine, previousItem);
                }
                return lineAction;
            }
            function insertIndentation(pos, indentation, lineAdded) {
                const indentationString = getIndentationString(indentation, options);
                if (lineAdded) {
                    recordReplace(pos, 0, indentationString);
                }
                else {
                    const tokenStart = sourceFile.getLineAndCharacterOfPosition(pos);
                    const startLinePosition = getStartPositionOfLine(tokenStart.line, sourceFile);
                    if (indentation !== characterToColumn(startLinePosition, tokenStart.character) || indentationIsDifferent(indentationString, startLinePosition)) {
                        recordReplace(startLinePosition, tokenStart.character, indentationString);
                    }
                }
            }
            function characterToColumn(startLinePosition, characterInLine) {
                let column = 0;
                for (let i = 0; i < characterInLine; i++) {
                    if (sourceFile.text.charCodeAt(startLinePosition + i) === 9 /* tab */) {
                        column += options.tabSize - column % options.tabSize;
                    }
                    else {
                        column++;
                    }
                }
                return column;
            }
            function indentationIsDifferent(indentationString, startLinePosition) {
                return indentationString !== sourceFile.text.substr(startLinePosition, indentationString.length);
            }
            function indentMultilineComment(commentRange, indentation, firstLineIsIndented, indentFinalLine = true) {
                let startLine = sourceFile.getLineAndCharacterOfPosition(commentRange.pos).line;
                const endLine = sourceFile.getLineAndCharacterOfPosition(commentRange.end).line;
                if (startLine === endLine) {
                    if (!firstLineIsIndented) {
                        insertIndentation(commentRange.pos, indentation, 
                        /*lineAdded*/
                        false);
                    }
                    return;
                }
                const parts = [];
                let startPos = commentRange.pos;
                for (let line = startLine; line < endLine; line++) {
                    const endOfLine = getEndLinePosition(line, sourceFile);
                    parts.push({ pos: startPos, end: endOfLine });
                    startPos = getStartPositionOfLine(line + 1, sourceFile);
                }
                if (indentFinalLine) {
                    parts.push({ pos: startPos, end: commentRange.end });
                }
                if (parts.length === 0)
                    return;
                const startLinePos = getStartPositionOfLine(startLine, sourceFile);
                const nonWhitespaceColumnInFirstPart = SmartIndenter.findFirstNonWhitespaceCharacterAndColumn(startLinePos, parts[0].pos, sourceFile, options);
                let startIndex = 0;
                if (firstLineIsIndented) {
                    startIndex = 1;
                    startLine++;
                }
                const delta2 = indentation - nonWhitespaceColumnInFirstPart.column;
                for (let i = startIndex; i < parts.length; i++, startLine++) {
                    const startLinePos2 = getStartPositionOfLine(startLine, sourceFile);
                    const nonWhitespaceCharacterAndColumn = i === 0 ? nonWhitespaceColumnInFirstPart : SmartIndenter.findFirstNonWhitespaceCharacterAndColumn(parts[i].pos, parts[i].end, sourceFile, options);
                    const newIndentation = nonWhitespaceCharacterAndColumn.column + delta2;
                    if (newIndentation > 0) {
                        const indentationString = getIndentationString(newIndentation, options);
                        recordReplace(startLinePos2, nonWhitespaceCharacterAndColumn.character, indentationString);
                    }
                    else {
                        recordDelete(startLinePos2, nonWhitespaceCharacterAndColumn.character);
                    }
                }
            }
            function trimTrailingWhitespacesForLines(line1, line2, range) {
                for (let line = line1; line < line2; line++) {
                    const lineStartPosition = getStartPositionOfLine(line, sourceFile);
                    const lineEndPosition = getEndLinePosition(line, sourceFile);
                    if (range && (isComment(range.kind) || isStringOrRegularExpressionOrTemplateLiteral(range.kind)) && range.pos <= lineEndPosition && range.end > lineEndPosition) {
                        continue;
                    }
                    const whitespaceStart = getTrailingWhitespaceStartPosition(lineStartPosition, lineEndPosition);
                    if (whitespaceStart !== -1) {
                        Debug.assert(whitespaceStart === lineStartPosition || !isWhiteSpaceSingleLine(sourceFile.text.charCodeAt(whitespaceStart - 1)));
                        recordDelete(whitespaceStart, lineEndPosition + 1 - whitespaceStart);
                    }
                }
            }
            function getTrailingWhitespaceStartPosition(start, end) {
                let pos = end;
                while (pos >= start && isWhiteSpaceSingleLine(sourceFile.text.charCodeAt(pos))) {
                    pos--;
                }
                if (pos !== end) {
                    return pos + 1;
                }
                return -1;
            }
            function trimTrailingWhitespacesForRemainingRange(trivias) {
                let startPos = previousRange ? previousRange.end : originalRange.pos;
                for (const trivia of trivias) {
                    if (isComment(trivia.kind)) {
                        if (startPos < trivia.pos) {
                            trimTrailingWitespacesForPositions(startPos, trivia.pos - 1, previousRange);
                        }
                        startPos = trivia.end + 1;
                    }
                }
                if (startPos < originalRange.end) {
                    trimTrailingWitespacesForPositions(startPos, originalRange.end, previousRange);
                }
            }
            function trimTrailingWitespacesForPositions(startPos, endPos, previousRange2) {
                const startLine = sourceFile.getLineAndCharacterOfPosition(startPos).line;
                const endLine = sourceFile.getLineAndCharacterOfPosition(endPos).line;
                trimTrailingWhitespacesForLines(startLine, endLine + 1, previousRange2);
            }
            function recordDelete(start, len) {
                if (len) {
                    edits.push(createTextChangeFromStartLength(start, len, ""));
                }
            }
            function recordReplace(start, len, newText) {
                if (len || newText) {
                    edits.push(createTextChangeFromStartLength(start, len, newText));
                }
            }
            function recordInsert(start, text) {
                if (text) {
                    edits.push(createTextChangeFromStartLength(start, 0, text));
                }
            }
            function applyRuleEdits(rule2, previousRange2, previousStartLine, currentRange, currentStartLine) {
                const onLaterLine = currentStartLine !== previousStartLine;
                switch (rule2.action) {
                    case 1 /* StopProcessingSpaceActions */:
                        return 0 /* None */;
                    case 16 /* DeleteSpace */:
                        if (previousRange2.end !== currentRange.pos) {
                            recordDelete(previousRange2.end, currentRange.pos - previousRange2.end);
                            return onLaterLine ? 2 /* LineRemoved */ : 0 /* None */;
                        }
                        break;
                    case 32 /* DeleteToken */:
                        recordDelete(previousRange2.pos, previousRange2.end - previousRange2.pos);
                        break;
                    case 8 /* InsertNewLine */:
                        if (rule2.flags !== 1 /* CanDeleteNewLines */ && previousStartLine !== currentStartLine) {
                            return 0 /* None */;
                        }
                        const lineDelta = currentStartLine - previousStartLine;
                        if (lineDelta !== 1) {
                            recordReplace(previousRange2.end, currentRange.pos - previousRange2.end, getNewLineOrDefaultFromHost(host, options));
                            return onLaterLine ? 0 /* None */ : 1 /* LineAdded */;
                        }
                        break;
                    case 4 /* InsertSpace */:
                        if (rule2.flags !== 1 /* CanDeleteNewLines */ && previousStartLine !== currentStartLine) {
                            return 0 /* None */;
                        }
                        const posDelta = currentRange.pos - previousRange2.end;
                        if (posDelta !== 1 || sourceFile.text.charCodeAt(previousRange2.end) !== 32 /* space */) {
                            recordReplace(previousRange2.end, currentRange.pos - previousRange2.end, " ");
                            return onLaterLine ? 2 /* LineRemoved */ : 0 /* None */;
                        }
                        break;
                    case 64 /* InsertTrailingSemicolon */:
                        recordInsert(previousRange2.end, ";");
                }
                return 0 /* None */;
            }
        }
        function getRangeOfEnclosingComment(sourceFile, position, precedingToken, tokenAtPosition = getTokenAtPosition(sourceFile, position)) {
            const jsdoc = findAncestor(tokenAtPosition, isJSDoc);
            if (jsdoc)
                tokenAtPosition = jsdoc.parent;
            const tokenStart = tokenAtPosition.getStart(sourceFile);
            if (tokenStart <= position && position < tokenAtPosition.getEnd()) {
                return void 0;
            }
            precedingToken = precedingToken === null ? void 0 : precedingToken === void 0 ? findPrecedingToken(position, sourceFile) : precedingToken;
            const trailingRangesOfPreviousToken = precedingToken && getTrailingCommentRanges(sourceFile.text, precedingToken.end);
            const leadingCommentRangesOfNextToken = getLeadingCommentRangesOfNode(tokenAtPosition, sourceFile);
            const commentRanges = concatenate(trailingRangesOfPreviousToken, leadingCommentRangesOfNextToken);
            return commentRanges && find(commentRanges, (range) => rangeContainsPositionExclusive(range, position) || // The end marker of a single-line comment does not include the newline character.
                // With caret at `^`, in the following case, we are inside a comment (^ denotes the cursor position):
                //
                //    // asdf   ^\n
                //
                // But for closed multi-line comments, we don't want to be inside the comment in the following case:
                //
                //    /* asdf */^
                //
                // However, unterminated multi-line comments *do* contain their end.
                //
                // Internally, we represent the end of the comment at the newline and closing '/', respectively.
                //
                position === range.end && (range.kind === 2 /* SingleLineCommentTrivia */ || position === sourceFile.getFullWidth()));
        }
        function getOpenTokenForList(node, list) {
            switch (node.kind) {
                case 173 /* Constructor */:
                case 259 /* FunctionDeclaration */:
                case 215 /* FunctionExpression */:
                case 171 /* MethodDeclaration */:
                case 170 /* MethodSignature */:
                case 216 /* ArrowFunction */:
                case 176 /* CallSignature */:
                case 177 /* ConstructSignature */:
                case 181 /* FunctionType */:
                case 182 /* ConstructorType */:
                case 174 /* GetAccessor */:
                case 175 /* SetAccessor */:
                    if (node.typeParameters === list) {
                        return 29 /* LessThanToken */;
                    }
                    else if (node.parameters === list) {
                        return 20 /* OpenParenToken */;
                    }
                    break;
                case 210 /* CallExpression */:
                case 211 /* NewExpression */:
                    if (node.typeArguments === list) {
                        return 29 /* LessThanToken */;
                    }
                    else if (node.arguments === list) {
                        return 20 /* OpenParenToken */;
                    }
                    break;
                case 260 /* ClassDeclaration */:
                case 228 /* ClassExpression */:
                case 261 /* InterfaceDeclaration */:
                case 262 /* TypeAliasDeclaration */:
                    if (node.typeParameters === list) {
                        return 29 /* LessThanToken */;
                    }
                    break;
                case 180 /* TypeReference */:
                case 212 /* TaggedTemplateExpression */:
                case 183 /* TypeQuery */:
                case 230 /* ExpressionWithTypeArguments */:
                case 202 /* ImportType */:
                    if (node.typeArguments === list) {
                        return 29 /* LessThanToken */;
                    }
                    break;
                case 184 /* TypeLiteral */:
                    return 18 /* OpenBraceToken */;
            }
            return 0 /* Unknown */;
        }
        function getCloseTokenForOpenToken(kind) {
            switch (kind) {
                case 20 /* OpenParenToken */:
                    return 21 /* CloseParenToken */;
                case 29 /* LessThanToken */:
                    return 31 /* GreaterThanToken */;
                case 18 /* OpenBraceToken */:
                    return 19 /* CloseBraceToken */;
            }
            return 0 /* Unknown */;
        }
        function getIndentationString(indentation, options) {
            const resetInternedStrings = !internedSizes || (internedSizes.tabSize !== options.tabSize || internedSizes.indentSize !== options.indentSize);
            if (resetInternedStrings) {
                internedSizes = { tabSize: options.tabSize, indentSize: options.indentSize };
                internedTabsIndentation = internedSpacesIndentation = void 0;
            }
            if (!options.convertTabsToSpaces) {
                const tabs = Math.floor(indentation / options.tabSize);
                const spaces = indentation - tabs * options.tabSize;
                let tabString;
                if (!internedTabsIndentation) {
                    internedTabsIndentation = [];
                }
                if (internedTabsIndentation[tabs] === void 0) {
                    internedTabsIndentation[tabs] = tabString = repeatString("	", tabs);
                }
                else {
                    tabString = internedTabsIndentation[tabs];
                }
                return spaces ? tabString + repeatString(" ", spaces) : tabString;
            }
            else {
                let spacesString;
                const quotient = Math.floor(indentation / options.indentSize);
                const remainder = indentation % options.indentSize;
                if (!internedSpacesIndentation) {
                    internedSpacesIndentation = [];
                }
                if (internedSpacesIndentation[quotient] === void 0) {
                    spacesString = repeatString(" ", options.indentSize * quotient);
                    internedSpacesIndentation[quotient] = spacesString;
                }
                else {
                    spacesString = internedSpacesIndentation[quotient];
                }
                return remainder ? spacesString + repeatString(" ", remainder) : spacesString;
            }
        }
        var internedSizes, internedTabsIndentation, internedSpacesIndentation;
        var init_formatting = __esm({
            "src/services/formatting/formatting.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
            }
        });
        // src/services/formatting/smartIndenter.ts
        var SmartIndenter;
        var init_smartIndenter = __esm({
            "src/services/formatting/smartIndenter.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
                ((SmartIndenter2) => {
                    let Value;
                    ((Value2) => {
                        Value2[Value2["Unknown"] = -1] = "Unknown";
                    })(Value || (Value = {}));
                    function getIndentation(position, sourceFile, options, assumeNewLineBeforeCloseBrace = false) {
                        if (position > sourceFile.text.length) {
                            return getBaseIndentation(options);
                        }
                        if (options.indentStyle === 0 /* None */) {
                            return 0;
                        }
                        const precedingToken = findPrecedingToken(position, sourceFile, 
                        /*startNode*/
                        void 0, 
                        /*excludeJsdoc*/
                        true);
                        const enclosingCommentRange = getRangeOfEnclosingComment(sourceFile, position, precedingToken || null);
                        if (enclosingCommentRange && enclosingCommentRange.kind === 3 /* MultiLineCommentTrivia */) {
                            return getCommentIndent(sourceFile, position, options, enclosingCommentRange);
                        }
                        if (!precedingToken) {
                            return getBaseIndentation(options);
                        }
                        const precedingTokenIsLiteral = isStringOrRegularExpressionOrTemplateLiteral(precedingToken.kind);
                        if (precedingTokenIsLiteral && precedingToken.getStart(sourceFile) <= position && position < precedingToken.end) {
                            return 0;
                        }
                        const lineAtPosition = sourceFile.getLineAndCharacterOfPosition(position).line;
                        const currentToken = getTokenAtPosition(sourceFile, position);
                        const isObjectLiteral = currentToken.kind === 18 /* OpenBraceToken */ && currentToken.parent.kind === 207 /* ObjectLiteralExpression */;
                        if (options.indentStyle === 1 /* Block */ || isObjectLiteral) {
                            return getBlockIndent(sourceFile, position, options);
                        }
                        if (precedingToken.kind === 27 /* CommaToken */ && precedingToken.parent.kind !== 223 /* BinaryExpression */) {
                            const actualIndentation = getActualIndentationForListItemBeforeComma(precedingToken, sourceFile, options);
                            if (actualIndentation !== -1 /* Unknown */) {
                                return actualIndentation;
                            }
                        }
                        const containerList = getListByPosition(position, precedingToken.parent, sourceFile);
                        if (containerList && !rangeContainsRange(containerList, precedingToken)) {
                            const useTheSameBaseIndentation = [215 /* FunctionExpression */, 216 /* ArrowFunction */].indexOf(currentToken.parent.kind) !== -1;
                            const indentSize = useTheSameBaseIndentation ? 0 : options.indentSize;
                            return getActualIndentationForListStartLine(containerList, sourceFile, options) + indentSize;
                        }
                        return getSmartIndent(sourceFile, position, precedingToken, lineAtPosition, assumeNewLineBeforeCloseBrace, options);
                    }
                    SmartIndenter2.getIndentation = getIndentation;
                    function getCommentIndent(sourceFile, position, options, enclosingCommentRange) {
                        const previousLine = getLineAndCharacterOfPosition(sourceFile, position).line - 1;
                        const commentStartLine = getLineAndCharacterOfPosition(sourceFile, enclosingCommentRange.pos).line;
                        Debug.assert(commentStartLine >= 0);
                        if (previousLine <= commentStartLine) {
                            return findFirstNonWhitespaceColumn(getStartPositionOfLine(commentStartLine, sourceFile), position, sourceFile, options);
                        }
                        const startPositionOfLine = getStartPositionOfLine(previousLine, sourceFile);
                        const { column, character } = findFirstNonWhitespaceCharacterAndColumn(startPositionOfLine, position, sourceFile, options);
                        if (column === 0) {
                            return column;
                        }
                        const firstNonWhitespaceCharacterCode = sourceFile.text.charCodeAt(startPositionOfLine + character);
                        return firstNonWhitespaceCharacterCode === 42 /* asterisk */ ? column - 1 : column;
                    }
                    function getBlockIndent(sourceFile, position, options) {
                        let current = position;
                        while (current > 0) {
                            const char = sourceFile.text.charCodeAt(current);
                            if (!isWhiteSpaceLike(char)) {
                                break;
                            }
                            current--;
                        }
                        const lineStart = getLineStartPositionForPosition(current, sourceFile);
                        return findFirstNonWhitespaceColumn(lineStart, current, sourceFile, options);
                    }
                    function getSmartIndent(sourceFile, position, precedingToken, lineAtPosition, assumeNewLineBeforeCloseBrace, options) {
                        let previous;
                        let current = precedingToken;
                        while (current) {
                            if (positionBelongsToNode(current, position, sourceFile) && shouldIndentChildNode(options, current, previous, sourceFile, 
                            /*isNextChild*/
                            true)) {
                                const currentStart = getStartLineAndCharacterForNode(current, sourceFile);
                                const nextTokenKind = nextTokenIsCurlyBraceOnSameLineAsCursor(precedingToken, current, lineAtPosition, sourceFile);
                                const indentationDelta = nextTokenKind !== 0 /* Unknown */ ? assumeNewLineBeforeCloseBrace && nextTokenKind === 2 /* CloseBrace */ ? options.indentSize : 0 : lineAtPosition !== currentStart.line ? options.indentSize : 0;
                                return getIndentationForNodeWorker(current, currentStart, 
                                /*ignoreActualIndentationRange*/
                                void 0, indentationDelta, sourceFile, 
                                /*isNextChild*/
                                true, options);
                            }
                            const actualIndentation = getActualIndentationForListItem(current, sourceFile, options, 
                            /*listIndentsChild*/
                            true);
                            if (actualIndentation !== -1 /* Unknown */) {
                                return actualIndentation;
                            }
                            previous = current;
                            current = current.parent;
                        }
                        return getBaseIndentation(options);
                    }
                    function getIndentationForNode(n, ignoreActualIndentationRange, sourceFile, options) {
                        const start = sourceFile.getLineAndCharacterOfPosition(n.getStart(sourceFile));
                        return getIndentationForNodeWorker(n, start, ignoreActualIndentationRange, 
                        /*indentationDelta*/
                        0, sourceFile, 
                        /*isNextChild*/
                        false, options);
                    }
                    SmartIndenter2.getIndentationForNode = getIndentationForNode;
                    function getBaseIndentation(options) {
                        return options.baseIndentSize || 0;
                    }
                    SmartIndenter2.getBaseIndentation = getBaseIndentation;
                    function getIndentationForNodeWorker(current, currentStart, ignoreActualIndentationRange, indentationDelta, sourceFile, isNextChild, options) {
                        var _a2;
                        let parent2 = current.parent;
                        while (parent2) {
                            let useActualIndentation = true;
                            if (ignoreActualIndentationRange) {
                                const start = current.getStart(sourceFile);
                                useActualIndentation = start < ignoreActualIndentationRange.pos || start > ignoreActualIndentationRange.end;
                            }
                            const containingListOrParentStart = getContainingListOrParentStart(parent2, current, sourceFile);
                            const parentAndChildShareLine = containingListOrParentStart.line === currentStart.line || childStartsOnTheSameLineWithElseInIfStatement(parent2, current, currentStart.line, sourceFile);
                            if (useActualIndentation) {
                                const firstListChild = (_a2 = getContainingList(current, sourceFile)) == null ? void 0 : _a2[0];
                                const listIndentsChild = !!firstListChild && getStartLineAndCharacterForNode(firstListChild, sourceFile).line > containingListOrParentStart.line;
                                let actualIndentation = getActualIndentationForListItem(current, sourceFile, options, listIndentsChild);
                                if (actualIndentation !== -1 /* Unknown */) {
                                    return actualIndentation + indentationDelta;
                                }
                                actualIndentation = getActualIndentationForNode(current, parent2, currentStart, parentAndChildShareLine, sourceFile, options);
                                if (actualIndentation !== -1 /* Unknown */) {
                                    return actualIndentation + indentationDelta;
                                }
                            }
                            if (shouldIndentChildNode(options, parent2, current, sourceFile, isNextChild) && !parentAndChildShareLine) {
                                indentationDelta += options.indentSize;
                            }
                            const useTrueStart = isArgumentAndStartLineOverlapsExpressionBeingCalled(parent2, current, currentStart.line, sourceFile);
                            current = parent2;
                            parent2 = current.parent;
                            currentStart = useTrueStart ? sourceFile.getLineAndCharacterOfPosition(current.getStart(sourceFile)) : containingListOrParentStart;
                        }
                        return indentationDelta + getBaseIndentation(options);
                    }
                    function getContainingListOrParentStart(parent2, child, sourceFile) {
                        const containingList = getContainingList(child, sourceFile);
                        const startPos = containingList ? containingList.pos : parent2.getStart(sourceFile);
                        return sourceFile.getLineAndCharacterOfPosition(startPos);
                    }
                    function getActualIndentationForListItemBeforeComma(commaToken, sourceFile, options) {
                        const commaItemInfo = findListItemInfo(commaToken);
                        if (commaItemInfo && commaItemInfo.listItemIndex > 0) {
                            return deriveActualIndentationFromList(commaItemInfo.list.getChildren(), commaItemInfo.listItemIndex - 1, sourceFile, options);
                        }
                        else {
                            return -1 /* Unknown */;
                        }
                    }
                    function getActualIndentationForNode(current, parent2, currentLineAndChar, parentAndChildShareLine, sourceFile, options) {
                        const useActualIndentation = (isDeclaration(current) || isStatementButNotDeclaration(current)) && (parent2.kind === 308 /* SourceFile */ || !parentAndChildShareLine);
                        if (!useActualIndentation) {
                            return -1 /* Unknown */;
                        }
                        return findColumnForFirstNonWhitespaceCharacterInLine(currentLineAndChar, sourceFile, options);
                    }
                    let NextTokenKind;
                    ((NextTokenKind2) => {
                        NextTokenKind2[NextTokenKind2["Unknown"] = 0] = "Unknown";
                        NextTokenKind2[NextTokenKind2["OpenBrace"] = 1] = "OpenBrace";
                        NextTokenKind2[NextTokenKind2["CloseBrace"] = 2] = "CloseBrace";
                    })(NextTokenKind || (NextTokenKind = {}));
                    function nextTokenIsCurlyBraceOnSameLineAsCursor(precedingToken, current, lineAtPosition, sourceFile) {
                        const nextToken = findNextToken(precedingToken, current, sourceFile);
                        if (!nextToken) {
                            return 0 /* Unknown */;
                        }
                        if (nextToken.kind === 18 /* OpenBraceToken */) {
                            return 1 /* OpenBrace */;
                        }
                        else if (nextToken.kind === 19 /* CloseBraceToken */) {
                            const nextTokenStartLine = getStartLineAndCharacterForNode(nextToken, sourceFile).line;
                            return lineAtPosition === nextTokenStartLine ? 2 /* CloseBrace */ : 0 /* Unknown */;
                        }
                        return 0 /* Unknown */;
                    }
                    function getStartLineAndCharacterForNode(n, sourceFile) {
                        return sourceFile.getLineAndCharacterOfPosition(n.getStart(sourceFile));
                    }
                    function isArgumentAndStartLineOverlapsExpressionBeingCalled(parent2, child, childStartLine, sourceFile) {
                        if (!(isCallExpression(parent2) && contains(parent2.arguments, child))) {
                            return false;
                        }
                        const expressionOfCallExpressionEnd = parent2.expression.getEnd();
                        const expressionOfCallExpressionEndLine = getLineAndCharacterOfPosition(sourceFile, expressionOfCallExpressionEnd).line;
                        return expressionOfCallExpressionEndLine === childStartLine;
                    }
                    SmartIndenter2.isArgumentAndStartLineOverlapsExpressionBeingCalled = isArgumentAndStartLineOverlapsExpressionBeingCalled;
                    function childStartsOnTheSameLineWithElseInIfStatement(parent2, child, childStartLine, sourceFile) {
                        if (parent2.kind === 242 /* IfStatement */ && parent2.elseStatement === child) {
                            const elseKeyword = findChildOfKind(parent2, 91 /* ElseKeyword */, sourceFile);
                            Debug.assert(elseKeyword !== void 0);
                            const elseKeywordStartLine = getStartLineAndCharacterForNode(elseKeyword, sourceFile).line;
                            return elseKeywordStartLine === childStartLine;
                        }
                        return false;
                    }
                    SmartIndenter2.childStartsOnTheSameLineWithElseInIfStatement = childStartsOnTheSameLineWithElseInIfStatement;
                    function childIsUnindentedBranchOfConditionalExpression(parent2, child, childStartLine, sourceFile) {
                        if (isConditionalExpression(parent2) && (child === parent2.whenTrue || child === parent2.whenFalse)) {
                            const conditionEndLine = getLineAndCharacterOfPosition(sourceFile, parent2.condition.end).line;
                            if (child === parent2.whenTrue) {
                                return childStartLine === conditionEndLine;
                            }
                            else {
                                const trueStartLine = getStartLineAndCharacterForNode(parent2.whenTrue, sourceFile).line;
                                const trueEndLine = getLineAndCharacterOfPosition(sourceFile, parent2.whenTrue.end).line;
                                return conditionEndLine === trueStartLine && trueEndLine === childStartLine;
                            }
                        }
                        return false;
                    }
                    SmartIndenter2.childIsUnindentedBranchOfConditionalExpression = childIsUnindentedBranchOfConditionalExpression;
                    function argumentStartsOnSameLineAsPreviousArgument(parent2, child, childStartLine, sourceFile) {
                        if (isCallOrNewExpression(parent2)) {
                            if (!parent2.arguments)
                                return false;
                            const currentNode = find(parent2.arguments, (arg) => arg.pos === child.pos);
                            if (!currentNode)
                                return false;
                            const currentIndex = parent2.arguments.indexOf(currentNode);
                            if (currentIndex === 0)
                                return false;
                            const previousNode = parent2.arguments[currentIndex - 1];
                            const lineOfPreviousNode = getLineAndCharacterOfPosition(sourceFile, previousNode.getEnd()).line;
                            if (childStartLine === lineOfPreviousNode) {
                                return true;
                            }
                        }
                        return false;
                    }
                    SmartIndenter2.argumentStartsOnSameLineAsPreviousArgument = argumentStartsOnSameLineAsPreviousArgument;
                    function getContainingList(node, sourceFile) {
                        return node.parent && getListByRange(node.getStart(sourceFile), node.getEnd(), node.parent, sourceFile);
                    }
                    SmartIndenter2.getContainingList = getContainingList;
                    function getListByPosition(pos, node, sourceFile) {
                        return node && getListByRange(pos, pos, node, sourceFile);
                    }
                    function getListByRange(start, end, node, sourceFile) {
                        switch (node.kind) {
                            case 180 /* TypeReference */:
                                return getList(node.typeArguments);
                            case 207 /* ObjectLiteralExpression */:
                                return getList(node.properties);
                            case 206 /* ArrayLiteralExpression */:
                                return getList(node.elements);
                            case 184 /* TypeLiteral */:
                                return getList(node.members);
                            case 259 /* FunctionDeclaration */:
                            case 215 /* FunctionExpression */:
                            case 216 /* ArrowFunction */:
                            case 171 /* MethodDeclaration */:
                            case 170 /* MethodSignature */:
                            case 176 /* CallSignature */:
                            case 173 /* Constructor */:
                            case 182 /* ConstructorType */:
                            case 177 /* ConstructSignature */:
                                return getList(node.typeParameters) || getList(node.parameters);
                            case 174 /* GetAccessor */:
                                return getList(node.parameters);
                            case 260 /* ClassDeclaration */:
                            case 228 /* ClassExpression */:
                            case 261 /* InterfaceDeclaration */:
                            case 262 /* TypeAliasDeclaration */:
                            case 348 /* JSDocTemplateTag */:
                                return getList(node.typeParameters);
                            case 211 /* NewExpression */:
                            case 210 /* CallExpression */:
                                return getList(node.typeArguments) || getList(node.arguments);
                            case 258 /* VariableDeclarationList */:
                                return getList(node.declarations);
                            case 272 /* NamedImports */:
                            case 276 /* NamedExports */:
                                return getList(node.elements);
                            case 203 /* ObjectBindingPattern */:
                            case 204 /* ArrayBindingPattern */:
                                return getList(node.elements);
                        }
                        function getList(list) {
                            return list && rangeContainsStartEnd(getVisualListRange(node, list, sourceFile), start, end) ? list : void 0;
                        }
                    }
                    function getVisualListRange(node, list, sourceFile) {
                        const children = node.getChildren(sourceFile);
                        for (let i = 1; i < children.length - 1; i++) {
                            if (children[i].pos === list.pos && children[i].end === list.end) {
                                return { pos: children[i - 1].end, end: children[i + 1].getStart(sourceFile) };
                            }
                        }
                        return list;
                    }
                    function getActualIndentationForListStartLine(list, sourceFile, options) {
                        if (!list) {
                            return -1 /* Unknown */;
                        }
                        return findColumnForFirstNonWhitespaceCharacterInLine(sourceFile.getLineAndCharacterOfPosition(list.pos), sourceFile, options);
                    }
                    function getActualIndentationForListItem(node, sourceFile, options, listIndentsChild) {
                        if (node.parent && node.parent.kind === 258 /* VariableDeclarationList */) {
                            return -1 /* Unknown */;
                        }
                        const containingList = getContainingList(node, sourceFile);
                        if (containingList) {
                            const index = containingList.indexOf(node);
                            if (index !== -1) {
                                const result = deriveActualIndentationFromList(containingList, index, sourceFile, options);
                                if (result !== -1 /* Unknown */) {
                                    return result;
                                }
                            }
                            return getActualIndentationForListStartLine(containingList, sourceFile, options) + (listIndentsChild ? options.indentSize : 0);
                        }
                        return -1 /* Unknown */;
                    }
                    function deriveActualIndentationFromList(list, index, sourceFile, options) {
                        Debug.assert(index >= 0 && index < list.length);
                        const node = list[index];
                        let lineAndCharacter = getStartLineAndCharacterForNode(node, sourceFile);
                        for (let i = index - 1; i >= 0; i--) {
                            if (list[i].kind === 27 /* CommaToken */) {
                                continue;
                            }
                            const prevEndLine = sourceFile.getLineAndCharacterOfPosition(list[i].end).line;
                            if (prevEndLine !== lineAndCharacter.line) {
                                return findColumnForFirstNonWhitespaceCharacterInLine(lineAndCharacter, sourceFile, options);
                            }
                            lineAndCharacter = getStartLineAndCharacterForNode(list[i], sourceFile);
                        }
                        return -1 /* Unknown */;
                    }
                    function findColumnForFirstNonWhitespaceCharacterInLine(lineAndCharacter, sourceFile, options) {
                        const lineStart = sourceFile.getPositionOfLineAndCharacter(lineAndCharacter.line, 0);
                        return findFirstNonWhitespaceColumn(lineStart, lineStart + lineAndCharacter.character, sourceFile, options);
                    }
                    function findFirstNonWhitespaceCharacterAndColumn(startPos, endPos, sourceFile, options) {
                        let character = 0;
                        let column = 0;
                        for (let pos = startPos; pos < endPos; pos++) {
                            const ch = sourceFile.text.charCodeAt(pos);
                            if (!isWhiteSpaceSingleLine(ch)) {
                                break;
                            }
                            if (ch === 9 /* tab */) {
                                column += options.tabSize + column % options.tabSize;
                            }
                            else {
                                column++;
                            }
                            character++;
                        }
                        return { column, character };
                    }
                    SmartIndenter2.findFirstNonWhitespaceCharacterAndColumn = findFirstNonWhitespaceCharacterAndColumn;
                    function findFirstNonWhitespaceColumn(startPos, endPos, sourceFile, options) {
                        return findFirstNonWhitespaceCharacterAndColumn(startPos, endPos, sourceFile, options).column;
                    }
                    SmartIndenter2.findFirstNonWhitespaceColumn = findFirstNonWhitespaceColumn;
                    function nodeWillIndentChild(settings, parent2, child, sourceFile, indentByDefault) {
                        const childKind = child ? child.kind : 0 /* Unknown */;
                        switch (parent2.kind) {
                            case 241 /* ExpressionStatement */:
                            case 260 /* ClassDeclaration */:
                            case 228 /* ClassExpression */:
                            case 261 /* InterfaceDeclaration */:
                            case 263 /* EnumDeclaration */:
                            case 262 /* TypeAliasDeclaration */:
                            case 206 /* ArrayLiteralExpression */:
                            case 238 /* Block */:
                            case 265 /* ModuleBlock */:
                            case 207 /* ObjectLiteralExpression */:
                            case 184 /* TypeLiteral */:
                            case 197 /* MappedType */:
                            case 186 /* TupleType */:
                            case 266 /* CaseBlock */:
                            case 293 /* DefaultClause */:
                            case 292 /* CaseClause */:
                            case 214 /* ParenthesizedExpression */:
                            case 208 /* PropertyAccessExpression */:
                            case 210 /* CallExpression */:
                            case 211 /* NewExpression */:
                            case 240 /* VariableStatement */:
                            case 274 /* ExportAssignment */:
                            case 250 /* ReturnStatement */:
                            case 224 /* ConditionalExpression */:
                            case 204 /* ArrayBindingPattern */:
                            case 203 /* ObjectBindingPattern */:
                            case 283 /* JsxOpeningElement */:
                            case 286 /* JsxOpeningFragment */:
                            case 282 /* JsxSelfClosingElement */:
                            case 291 /* JsxExpression */:
                            case 170 /* MethodSignature */:
                            case 176 /* CallSignature */:
                            case 177 /* ConstructSignature */:
                            case 166 /* Parameter */:
                            case 181 /* FunctionType */:
                            case 182 /* ConstructorType */:
                            case 193 /* ParenthesizedType */:
                            case 212 /* TaggedTemplateExpression */:
                            case 220 /* AwaitExpression */:
                            case 276 /* NamedExports */:
                            case 272 /* NamedImports */:
                            case 278 /* ExportSpecifier */:
                            case 273 /* ImportSpecifier */:
                            case 169 /* PropertyDeclaration */:
                                return true;
                            case 257 /* VariableDeclaration */:
                            case 299 /* PropertyAssignment */:
                            case 223 /* BinaryExpression */:
                                if (!settings.indentMultiLineObjectLiteralBeginningOnBlankLine && sourceFile && childKind === 207 /* ObjectLiteralExpression */) {
                                    return rangeIsOnOneLine(sourceFile, child);
                                }
                                if (parent2.kind === 223 /* BinaryExpression */ && sourceFile && child && childKind === 281 /* JsxElement */) {
                                    const parentStartLine = sourceFile.getLineAndCharacterOfPosition(skipTrivia(sourceFile.text, parent2.pos)).line;
                                    const childStartLine = sourceFile.getLineAndCharacterOfPosition(skipTrivia(sourceFile.text, child.pos)).line;
                                    return parentStartLine !== childStartLine;
                                }
                                if (parent2.kind !== 223 /* BinaryExpression */) {
                                    return true;
                                }
                                break;
                            case 243 /* DoStatement */:
                            case 244 /* WhileStatement */:
                            case 246 /* ForInStatement */:
                            case 247 /* ForOfStatement */:
                            case 245 /* ForStatement */:
                            case 242 /* IfStatement */:
                            case 259 /* FunctionDeclaration */:
                            case 215 /* FunctionExpression */:
                            case 171 /* MethodDeclaration */:
                            case 173 /* Constructor */:
                            case 174 /* GetAccessor */:
                            case 175 /* SetAccessor */:
                                return childKind !== 238 /* Block */;
                            case 216 /* ArrowFunction */:
                                if (sourceFile && childKind === 214 /* ParenthesizedExpression */) {
                                    return rangeIsOnOneLine(sourceFile, child);
                                }
                                return childKind !== 238 /* Block */;
                            case 275 /* ExportDeclaration */:
                                return childKind !== 276 /* NamedExports */;
                            case 269 /* ImportDeclaration */:
                                return childKind !== 270 /* ImportClause */ || !!child.namedBindings && child.namedBindings.kind !== 272 /* NamedImports */;
                            case 281 /* JsxElement */:
                                return childKind !== 284 /* JsxClosingElement */;
                            case 285 /* JsxFragment */:
                                return childKind !== 287 /* JsxClosingFragment */;
                            case 190 /* IntersectionType */:
                            case 189 /* UnionType */:
                                if (childKind === 184 /* TypeLiteral */ || childKind === 186 /* TupleType */) {
                                    return false;
                                }
                                break;
                        }
                        return indentByDefault;
                    }
                    SmartIndenter2.nodeWillIndentChild = nodeWillIndentChild;
                    function isControlFlowEndingStatement(kind, parent2) {
                        switch (kind) {
                            case 250 /* ReturnStatement */:
                            case 254 /* ThrowStatement */:
                            case 248 /* ContinueStatement */:
                            case 249 /* BreakStatement */:
                                return parent2.kind !== 238 /* Block */;
                            default:
                                return false;
                        }
                    }
                    function shouldIndentChildNode(settings, parent2, child, sourceFile, isNextChild = false) {
                        return nodeWillIndentChild(settings, parent2, child, sourceFile, 
                        /*indentByDefault*/
                        false) && !(isNextChild && child && isControlFlowEndingStatement(child.kind, parent2));
                    }
                    SmartIndenter2.shouldIndentChildNode = shouldIndentChildNode;
                    function rangeIsOnOneLine(sourceFile, range) {
                        const rangeStart = skipTrivia(sourceFile.text, range.pos);
                        const startLine = sourceFile.getLineAndCharacterOfPosition(rangeStart).line;
                        const endLine = sourceFile.getLineAndCharacterOfPosition(range.end).line;
                        return startLine === endLine;
                    }
                })(SmartIndenter || (SmartIndenter = {}));
            }
        });
        // src/services/_namespaces/ts.formatting.ts
        var ts_formatting_exports = {};
        __export(ts_formatting_exports, {
            FormattingContext: () => FormattingContext,
            FormattingRequestKind: () => FormattingRequestKind,
            RuleAction: () => RuleAction,
            RuleFlags: () => RuleFlags,
            SmartIndenter: () => SmartIndenter,
            anyContext: () => anyContext,
            createTextRangeWithKind: () => createTextRangeWithKind,
            formatDocument: () => formatDocument,
            formatNodeGivenIndentation: () => formatNodeGivenIndentation,
            formatOnClosingCurly: () => formatOnClosingCurly,
            formatOnEnter: () => formatOnEnter,
            formatOnOpeningCurly: () => formatOnOpeningCurly,
            formatOnSemicolon: () => formatOnSemicolon,
            formatSelection: () => formatSelection,
            getAllRules: () => getAllRules,
            getFormatContext: () => getFormatContext,
            getFormattingScanner: () => getFormattingScanner,
            getIndentationString: () => getIndentationString,
            getRangeOfEnclosingComment: () => getRangeOfEnclosingComment
        });
        var init_ts_formatting = __esm({
            "src/services/_namespaces/ts.formatting.ts"() {
                "use strict";
                init_formattingContext();
                init_formattingScanner();
                init_rule();
                init_rules();
                init_rulesMap();
                init_formatting();
                init_smartIndenter();
            }
        });
        // src/services/_namespaces/ts.ts
        var init_ts4 = __esm({
            "src/services/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_ts3();
                init_types3();
                init_utilities4();
                init_exportInfoMap();
                init_classifier();
                init_documentHighlights();
                init_documentRegistry();
                init_getEditsForFileRename();
                init_patternMatcher();
                init_preProcess();
                init_sourcemaps();
                init_suggestionDiagnostics();
                init_transpile();
                init_services();
                init_transform();
                init_shims();
                init_ts_BreakpointResolver();
                init_ts_CallHierarchy();
                init_ts_classifier();
                init_ts_codefix();
                init_ts_Completions();
                init_ts_FindAllReferences();
                init_ts_GoToDefinition();
                init_ts_InlayHints();
                init_ts_JsDoc();
                init_ts_NavigateTo();
                init_ts_NavigationBar();
                init_ts_OrganizeImports();
                init_ts_OutliningElementsCollector();
                init_ts_refactor();
                init_ts_Rename();
                init_ts_SignatureHelp();
                init_ts_SmartSelectionRange();
                init_ts_SymbolDisplay();
                init_ts_textChanges();
                init_ts_formatting();
            }
        });
        // src/deprecatedCompat/deprecate.ts
        function getTypeScriptVersion() {
            return typeScriptVersion2 != null ? typeScriptVersion2 : typeScriptVersion2 = new Version(version);
        }
        function formatDeprecationMessage(name, error, errorAfter, since, message) {
            let deprecationMessage = error ? "DeprecationError: " : "DeprecationWarning: ";
            deprecationMessage += `'${name}' `;
            deprecationMessage += since ? `has been deprecated since v${since}` : "is deprecated";
            deprecationMessage += error ? " and can no longer be used." : errorAfter ? ` and will no longer be usable after v${errorAfter}.` : ".";
            deprecationMessage += message ? ` ${formatStringFromArgs(message, [name], 0)}` : "";
            return deprecationMessage;
        }
        function createErrorDeprecation(name, errorAfter, since, message) {
            const deprecationMessage = formatDeprecationMessage(name, 
            /*error*/
            true, errorAfter, since, message);
            return () => {
                throw new TypeError(deprecationMessage);
            };
        }
        function createWarningDeprecation(name, errorAfter, since, message) {
            let hasWrittenDeprecation = false;
            return () => {
                if (enableDeprecationWarnings && !hasWrittenDeprecation) {
                    Debug.log.warn(formatDeprecationMessage(name, 
                    /*error*/
                    false, errorAfter, since, message));
                    hasWrittenDeprecation = true;
                }
            };
        }
        function createDeprecation(name, options = {}) {
            var _a2, _b;
            const version2 = typeof options.typeScriptVersion === "string" ? new Version(options.typeScriptVersion) : (_a2 = options.typeScriptVersion) != null ? _a2 : getTypeScriptVersion();
            const errorAfter = typeof options.errorAfter === "string" ? new Version(options.errorAfter) : options.errorAfter;
            const warnAfter = typeof options.warnAfter === "string" ? new Version(options.warnAfter) : options.warnAfter;
            const since = typeof options.since === "string" ? new Version(options.since) : (_b = options.since) != null ? _b : warnAfter;
            const error = options.error || errorAfter && version2.compareTo(errorAfter) >= 0;
            const warn = !warnAfter || version2.compareTo(warnAfter) >= 0;
            return error ? createErrorDeprecation(name, errorAfter, since, options.message) : warn ? createWarningDeprecation(name, errorAfter, since, options.message) : noop;
        }
        function wrapFunction(deprecation, func) {
            return function () {
                deprecation();
                return func.apply(this, arguments);
            };
        }
        function deprecate(func, options) {
            var _a2;
            const deprecation = createDeprecation((_a2 = options == null ? void 0 : options.name) != null ? _a2 : Debug.getFunctionName(func), options);
            return wrapFunction(deprecation, func);
        }
        var enableDeprecationWarnings, typeScriptVersion2;
        var init_deprecate = __esm({
            "src/deprecatedCompat/deprecate.ts"() {
                "use strict";
                init_ts5();
                enableDeprecationWarnings = true;
            }
        });
        // src/deprecatedCompat/deprecations.ts
        function createOverload(name, overloads, binder2, deprecations) {
            Object.defineProperty(call, "name", { ...Object.getOwnPropertyDescriptor(call, "name"), value: name });
            if (deprecations) {
                for (const key of Object.keys(deprecations)) {
                    const index = +key;
                    if (!isNaN(index) && hasProperty(overloads, `${index}`)) {
                        overloads[index] = deprecate(overloads[index], { ...deprecations[index], name });
                    }
                }
            }
            const bind = createBinder2(overloads, binder2);
            return call;
            function call(...args) {
                const index = bind(args);
                const fn = index !== void 0 ? overloads[index] : void 0;
                if (typeof fn === "function") {
                    return fn(...args);
                }
                throw new TypeError("Invalid arguments");
            }
        }
        function createBinder2(overloads, binder2) {
            return (args) => {
                for (let i = 0; hasProperty(overloads, `${i}`) && hasProperty(binder2, `${i}`); i++) {
                    const fn = binder2[i];
                    if (fn(args)) {
                        return i;
                    }
                }
            };
        }
        function buildOverload(name) {
            return {
                overload: (overloads) => ({
                    bind: (binder2) => ({
                        finish: () => createOverload(name, overloads, binder2),
                        deprecate: (deprecations) => ({
                            finish: () => createOverload(name, overloads, binder2, deprecations)
                        })
                    })
                })
            };
        }
        var init_deprecations = __esm({
            "src/deprecatedCompat/deprecations.ts"() {
                "use strict";
                init_ts5();
                init_deprecate();
            }
        });
        // src/deprecatedCompat/5.0/identifierProperties.ts
        var init_identifierProperties = __esm({
            "src/deprecatedCompat/5.0/identifierProperties.ts"() {
                "use strict";
                init_ts5();
                init_deprecate();
                addObjectAllocatorPatcher((objectAllocator2) => {
                    const Identifier73 = objectAllocator2.getIdentifierConstructor();
                    if (!hasProperty(Identifier73.prototype, "originalKeywordKind")) {
                        Object.defineProperty(Identifier73.prototype, "originalKeywordKind", {
                            get: deprecate(function () {
                                return identifierToKeywordKind(this);
                            }, {
                                name: "originalKeywordKind",
                                since: "5.0",
                                warnAfter: "5.1",
                                errorAfter: "5.2",
                                message: "Use 'identifierToKeywordKind(identifier)' instead."
                            })
                        });
                    }
                    if (!hasProperty(Identifier73.prototype, "isInJSDocNamespace")) {
                        Object.defineProperty(Identifier73.prototype, "isInJSDocNamespace", {
                            get: deprecate(function () {
                                return this.flags & 2048 /* IdentifierIsInJSDocNamespace */ ? true : void 0;
                            }, {
                                name: "isInJSDocNamespace",
                                since: "5.0",
                                warnAfter: "5.1",
                                errorAfter: "5.2",
                                message: "Use '.parent' or the surrounding context to determine this instead."
                            })
                        });
                    }
                });
            }
        });
        // src/deprecatedCompat/_namespaces/ts.ts
        var init_ts5 = __esm({
            "src/deprecatedCompat/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_deprecations();
                init_identifierProperties();
            }
        });
        // src/typescript/_namespaces/ts.ts
        var ts_exports3 = {};
        __export(ts_exports3, {
            ANONYMOUS: () => ANONYMOUS,
            AccessFlags: () => AccessFlags,
            AssertionLevel: () => AssertionLevel,
            AssignmentDeclarationKind: () => AssignmentDeclarationKind,
            AssignmentKind: () => AssignmentKind,
            Associativity: () => Associativity,
            BreakpointResolver: () => ts_BreakpointResolver_exports,
            BuilderFileEmit: () => BuilderFileEmit,
            BuilderProgramKind: () => BuilderProgramKind,
            BuilderState: () => BuilderState,
            BundleFileSectionKind: () => BundleFileSectionKind,
            CallHierarchy: () => ts_CallHierarchy_exports,
            CharacterCodes: () => CharacterCodes,
            CheckFlags: () => CheckFlags,
            CheckMode: () => CheckMode,
            ClassificationType: () => ClassificationType,
            ClassificationTypeNames: () => ClassificationTypeNames,
            CommentDirectiveType: () => CommentDirectiveType,
            Comparison: () => Comparison,
            CompletionInfoFlags: () => CompletionInfoFlags,
            CompletionTriggerKind: () => CompletionTriggerKind,
            Completions: () => ts_Completions_exports,
            ConfigFileProgramReloadLevel: () => ConfigFileProgramReloadLevel,
            ContextFlags: () => ContextFlags,
            CoreServicesShimHostAdapter: () => CoreServicesShimHostAdapter,
            Debug: () => Debug,
            DiagnosticCategory: () => DiagnosticCategory,
            Diagnostics: () => Diagnostics,
            DocumentHighlights: () => DocumentHighlights,
            ElementFlags: () => ElementFlags,
            EmitFlags: () => EmitFlags,
            EmitHint: () => EmitHint,
            EmitOnly: () => EmitOnly,
            EndOfLineState: () => EndOfLineState,
            EnumKind: () => EnumKind,
            ExitStatus: () => ExitStatus,
            ExportKind: () => ExportKind,
            Extension: () => Extension,
            ExternalEmitHelpers: () => ExternalEmitHelpers,
            FileIncludeKind: () => FileIncludeKind,
            FilePreprocessingDiagnosticsKind: () => FilePreprocessingDiagnosticsKind,
            FileSystemEntryKind: () => FileSystemEntryKind,
            FileWatcherEventKind: () => FileWatcherEventKind,
            FindAllReferences: () => ts_FindAllReferences_exports,
            FlattenLevel: () => FlattenLevel,
            FlowFlags: () => FlowFlags,
            ForegroundColorEscapeSequences: () => ForegroundColorEscapeSequences,
            FunctionFlags: () => FunctionFlags,
            GeneratedIdentifierFlags: () => GeneratedIdentifierFlags,
            GetLiteralTextFlags: () => GetLiteralTextFlags,
            GoToDefinition: () => ts_GoToDefinition_exports,
            HighlightSpanKind: () => HighlightSpanKind,
            ImportKind: () => ImportKind,
            ImportsNotUsedAsValues: () => ImportsNotUsedAsValues,
            IndentStyle: () => IndentStyle,
            IndexKind: () => IndexKind,
            InferenceFlags: () => InferenceFlags,
            InferencePriority: () => InferencePriority,
            InlayHintKind: () => InlayHintKind,
            InlayHints: () => ts_InlayHints_exports,
            InternalEmitFlags: () => InternalEmitFlags,
            InternalSymbolName: () => InternalSymbolName,
            InvalidatedProjectKind: () => InvalidatedProjectKind,
            JsDoc: () => ts_JsDoc_exports,
            JsTyping: () => ts_JsTyping_exports,
            JsxEmit: () => JsxEmit,
            JsxFlags: () => JsxFlags,
            JsxReferenceKind: () => JsxReferenceKind,
            LanguageServiceMode: () => LanguageServiceMode,
            LanguageServiceShimHostAdapter: () => LanguageServiceShimHostAdapter,
            LanguageVariant: () => LanguageVariant,
            LexicalEnvironmentFlags: () => LexicalEnvironmentFlags,
            ListFormat: () => ListFormat,
            LogLevel: () => LogLevel,
            MemberOverrideStatus: () => MemberOverrideStatus,
            ModifierFlags: () => ModifierFlags,
            ModuleDetectionKind: () => ModuleDetectionKind,
            ModuleInstanceState: () => ModuleInstanceState,
            ModuleKind: () => ModuleKind,
            ModuleResolutionKind: () => ModuleResolutionKind,
            ModuleSpecifierEnding: () => ModuleSpecifierEnding,
            NavigateTo: () => ts_NavigateTo_exports,
            NavigationBar: () => ts_NavigationBar_exports,
            NewLineKind: () => NewLineKind,
            NodeBuilderFlags: () => NodeBuilderFlags,
            NodeCheckFlags: () => NodeCheckFlags,
            NodeFactoryFlags: () => NodeFactoryFlags,
            NodeFlags: () => NodeFlags,
            NodeResolutionFeatures: () => NodeResolutionFeatures,
            ObjectFlags: () => ObjectFlags,
            OperationCanceledException: () => OperationCanceledException,
            OperatorPrecedence: () => OperatorPrecedence,
            OrganizeImports: () => ts_OrganizeImports_exports,
            OrganizeImportsMode: () => OrganizeImportsMode,
            OuterExpressionKinds: () => OuterExpressionKinds,
            OutliningElementsCollector: () => ts_OutliningElementsCollector_exports,
            OutliningSpanKind: () => OutliningSpanKind,
            OutputFileType: () => OutputFileType,
            PackageJsonAutoImportPreference: () => PackageJsonAutoImportPreference,
            PackageJsonDependencyGroup: () => PackageJsonDependencyGroup,
            PatternMatchKind: () => PatternMatchKind,
            PollingInterval: () => PollingInterval,
            PollingWatchKind: () => PollingWatchKind,
            PragmaKindFlags: () => PragmaKindFlags,
            PrivateIdentifierKind: () => PrivateIdentifierKind,
            ProcessLevel: () => ProcessLevel,
            QuotePreference: () => QuotePreference,
            RelationComparisonResult: () => RelationComparisonResult,
            Rename: () => ts_Rename_exports,
            ScriptElementKind: () => ScriptElementKind,
            ScriptElementKindModifier: () => ScriptElementKindModifier,
            ScriptKind: () => ScriptKind,
            ScriptSnapshot: () => ScriptSnapshot,
            ScriptTarget: () => ScriptTarget,
            SemanticClassificationFormat: () => SemanticClassificationFormat,
            SemanticMeaning: () => SemanticMeaning,
            SemicolonPreference: () => SemicolonPreference,
            SignatureCheckMode: () => SignatureCheckMode,
            SignatureFlags: () => SignatureFlags,
            SignatureHelp: () => ts_SignatureHelp_exports,
            SignatureKind: () => SignatureKind,
            SmartSelectionRange: () => ts_SmartSelectionRange_exports,
            SnippetKind: () => SnippetKind,
            SortKind: () => SortKind,
            StructureIsReused: () => StructureIsReused,
            SymbolAccessibility: () => SymbolAccessibility,
            SymbolDisplay: () => ts_SymbolDisplay_exports,
            SymbolDisplayPartKind: () => SymbolDisplayPartKind,
            SymbolFlags: () => SymbolFlags,
            SymbolFormatFlags: () => SymbolFormatFlags,
            SyntaxKind: () => SyntaxKind,
            SyntheticSymbolKind: () => SyntheticSymbolKind,
            Ternary: () => Ternary,
            ThrottledCancellationToken: () => ThrottledCancellationToken,
            TokenClass: () => TokenClass,
            TokenFlags: () => TokenFlags,
            TransformFlags: () => TransformFlags,
            TypeFacts: () => TypeFacts,
            TypeFlags: () => TypeFlags,
            TypeFormatFlags: () => TypeFormatFlags,
            TypeMapKind: () => TypeMapKind,
            TypePredicateKind: () => TypePredicateKind,
            TypeReferenceSerializationKind: () => TypeReferenceSerializationKind,
            TypeScriptServicesFactory: () => TypeScriptServicesFactory,
            UnionReduction: () => UnionReduction,
            UpToDateStatusType: () => UpToDateStatusType,
            VarianceFlags: () => VarianceFlags,
            Version: () => Version,
            VersionRange: () => VersionRange,
            WatchDirectoryFlags: () => WatchDirectoryFlags,
            WatchDirectoryKind: () => WatchDirectoryKind,
            WatchFileKind: () => WatchFileKind,
            WatchLogLevel: () => WatchLogLevel,
            WatchType: () => WatchType,
            accessPrivateIdentifier: () => accessPrivateIdentifier,
            addEmitFlags: () => addEmitFlags,
            addEmitHelper: () => addEmitHelper,
            addEmitHelpers: () => addEmitHelpers,
            addInternalEmitFlags: () => addInternalEmitFlags,
            addNodeFactoryPatcher: () => addNodeFactoryPatcher,
            addObjectAllocatorPatcher: () => addObjectAllocatorPatcher,
            addRange: () => addRange,
            addRelatedInfo: () => addRelatedInfo,
            addSyntheticLeadingComment: () => addSyntheticLeadingComment,
            addSyntheticTrailingComment: () => addSyntheticTrailingComment,
            addToSeen: () => addToSeen,
            advancedAsyncSuperHelper: () => advancedAsyncSuperHelper,
            affectsDeclarationPathOptionDeclarations: () => affectsDeclarationPathOptionDeclarations,
            affectsEmitOptionDeclarations: () => affectsEmitOptionDeclarations,
            allKeysStartWithDot: () => allKeysStartWithDot,
            altDirectorySeparator: () => altDirectorySeparator,
            and: () => and,
            append: () => append,
            appendIfUnique: () => appendIfUnique,
            arrayFrom: () => arrayFrom,
            arrayIsEqualTo: () => arrayIsEqualTo,
            arrayIsHomogeneous: () => arrayIsHomogeneous,
            arrayIsSorted: () => arrayIsSorted,
            arrayOf: () => arrayOf,
            arrayReverseIterator: () => arrayReverseIterator,
            arrayToMap: () => arrayToMap,
            arrayToMultiMap: () => arrayToMultiMap,
            arrayToNumericMap: () => arrayToNumericMap,
            arraysEqual: () => arraysEqual,
            assertType: () => assertType,
            assign: () => assign,
            assignHelper: () => assignHelper,
            asyncDelegator: () => asyncDelegator,
            asyncGeneratorHelper: () => asyncGeneratorHelper,
            asyncSuperHelper: () => asyncSuperHelper,
            asyncValues: () => asyncValues,
            attachFileToDiagnostics: () => attachFileToDiagnostics,
            awaitHelper: () => awaitHelper,
            awaiterHelper: () => awaiterHelper,
            base64decode: () => base64decode,
            base64encode: () => base64encode,
            binarySearch: () => binarySearch,
            binarySearchKey: () => binarySearchKey,
            bindSourceFile: () => bindSourceFile,
            breakIntoCharacterSpans: () => breakIntoCharacterSpans,
            breakIntoWordSpans: () => breakIntoWordSpans,
            buildLinkParts: () => buildLinkParts,
            buildOpts: () => buildOpts,
            buildOverload: () => buildOverload,
            bundlerModuleNameResolver: () => bundlerModuleNameResolver,
            canBeConvertedToAsync: () => canBeConvertedToAsync,
            canHaveDecorators: () => canHaveDecorators,
            canHaveExportModifier: () => canHaveExportModifier,
            canHaveFlowNode: () => canHaveFlowNode,
            canHaveIllegalDecorators: () => canHaveIllegalDecorators,
            canHaveIllegalModifiers: () => canHaveIllegalModifiers,
            canHaveIllegalType: () => canHaveIllegalType,
            canHaveIllegalTypeParameters: () => canHaveIllegalTypeParameters,
            canHaveJSDoc: () => canHaveJSDoc,
            canHaveLocals: () => canHaveLocals,
            canHaveModifiers: () => canHaveModifiers,
            canHaveSymbol: () => canHaveSymbol,
            canJsonReportNoInputFiles: () => canJsonReportNoInputFiles,
            canProduceDiagnostics: () => canProduceDiagnostics,
            canUsePropertyAccess: () => canUsePropertyAccess,
            canWatchDirectoryOrFile: () => canWatchDirectoryOrFile,
            cartesianProduct: () => cartesianProduct,
            cast: () => cast,
            chainBundle: () => chainBundle,
            chainDiagnosticMessages: () => chainDiagnosticMessages,
            changeAnyExtension: () => changeAnyExtension,
            changeCompilerHostLikeToUseCache: () => changeCompilerHostLikeToUseCache,
            changeExtension: () => changeExtension,
            changesAffectModuleResolution: () => changesAffectModuleResolution,
            changesAffectingProgramStructure: () => changesAffectingProgramStructure,
            childIsDecorated: () => childIsDecorated,
            classElementOrClassElementParameterIsDecorated: () => classElementOrClassElementParameterIsDecorated,
            classOrConstructorParameterIsDecorated: () => classOrConstructorParameterIsDecorated,
            classPrivateFieldGetHelper: () => classPrivateFieldGetHelper,
            classPrivateFieldInHelper: () => classPrivateFieldInHelper,
            classPrivateFieldSetHelper: () => classPrivateFieldSetHelper,
            classicNameResolver: () => classicNameResolver,
            classifier: () => ts_classifier_exports,
            cleanExtendedConfigCache: () => cleanExtendedConfigCache,
            clear: () => clear,
            clearMap: () => clearMap,
            clearSharedExtendedConfigFileWatcher: () => clearSharedExtendedConfigFileWatcher,
            climbPastPropertyAccess: () => climbPastPropertyAccess,
            climbPastPropertyOrElementAccess: () => climbPastPropertyOrElementAccess,
            clone: () => clone,
            cloneCompilerOptions: () => cloneCompilerOptions,
            closeFileWatcher: () => closeFileWatcher,
            closeFileWatcherOf: () => closeFileWatcherOf,
            codefix: () => ts_codefix_exports,
            collapseTextChangeRangesAcrossMultipleVersions: () => collapseTextChangeRangesAcrossMultipleVersions,
            collectExternalModuleInfo: () => collectExternalModuleInfo,
            combine: () => combine,
            combinePaths: () => combinePaths,
            commentPragmas: () => commentPragmas,
            commonOptionsWithBuild: () => commonOptionsWithBuild,
            commonPackageFolders: () => commonPackageFolders,
            compact: () => compact,
            compareBooleans: () => compareBooleans,
            compareDataObjects: () => compareDataObjects,
            compareDiagnostics: () => compareDiagnostics,
            compareDiagnosticsSkipRelatedInformation: () => compareDiagnosticsSkipRelatedInformation,
            compareEmitHelpers: () => compareEmitHelpers,
            compareNumberOfDirectorySeparators: () => compareNumberOfDirectorySeparators,
            comparePaths: () => comparePaths,
            comparePathsCaseInsensitive: () => comparePathsCaseInsensitive,
            comparePathsCaseSensitive: () => comparePathsCaseSensitive,
            comparePatternKeys: () => comparePatternKeys,
            compareProperties: () => compareProperties,
            compareStringsCaseInsensitive: () => compareStringsCaseInsensitive,
            compareStringsCaseInsensitiveEslintCompatible: () => compareStringsCaseInsensitiveEslintCompatible,
            compareStringsCaseSensitive: () => compareStringsCaseSensitive,
            compareStringsCaseSensitiveUI: () => compareStringsCaseSensitiveUI,
            compareTextSpans: () => compareTextSpans,
            compareValues: () => compareValues,
            compileOnSaveCommandLineOption: () => compileOnSaveCommandLineOption,
            compilerOptionsAffectDeclarationPath: () => compilerOptionsAffectDeclarationPath,
            compilerOptionsAffectEmit: () => compilerOptionsAffectEmit,
            compilerOptionsAffectSemanticDiagnostics: () => compilerOptionsAffectSemanticDiagnostics,
            compilerOptionsDidYouMeanDiagnostics: () => compilerOptionsDidYouMeanDiagnostics,
            compilerOptionsIndicateEsModules: () => compilerOptionsIndicateEsModules,
            compose: () => compose,
            computeCommonSourceDirectoryOfFilenames: () => computeCommonSourceDirectoryOfFilenames,
            computeLineAndCharacterOfPosition: () => computeLineAndCharacterOfPosition,
            computeLineOfPosition: () => computeLineOfPosition,
            computeLineStarts: () => computeLineStarts,
            computePositionOfLineAndCharacter: () => computePositionOfLineAndCharacter,
            computeSignature: () => computeSignature,
            computeSignatureWithDiagnostics: () => computeSignatureWithDiagnostics,
            computeSuggestionDiagnostics: () => computeSuggestionDiagnostics,
            concatenate: () => concatenate,
            concatenateDiagnosticMessageChains: () => concatenateDiagnosticMessageChains,
            consumesNodeCoreModules: () => consumesNodeCoreModules,
            contains: () => contains,
            containsIgnoredPath: () => containsIgnoredPath,
            containsObjectRestOrSpread: () => containsObjectRestOrSpread,
            containsParseError: () => containsParseError,
            containsPath: () => containsPath,
            convertCompilerOptionsForTelemetry: () => convertCompilerOptionsForTelemetry,
            convertCompilerOptionsFromJson: () => convertCompilerOptionsFromJson,
            convertJsonOption: () => convertJsonOption,
            convertToBase64: () => convertToBase64,
            convertToObject: () => convertToObject,
            convertToObjectWorker: () => convertToObjectWorker,
            convertToOptionsWithAbsolutePaths: () => convertToOptionsWithAbsolutePaths,
            convertToRelativePath: () => convertToRelativePath,
            convertToTSConfig: () => convertToTSConfig,
            convertTypeAcquisitionFromJson: () => convertTypeAcquisitionFromJson,
            copyComments: () => copyComments,
            copyEntries: () => copyEntries,
            copyLeadingComments: () => copyLeadingComments,
            copyProperties: () => copyProperties,
            copyTrailingAsLeadingComments: () => copyTrailingAsLeadingComments,
            copyTrailingComments: () => copyTrailingComments,
            couldStartTrivia: () => couldStartTrivia,
            countWhere: () => countWhere,
            createAbstractBuilder: () => createAbstractBuilder,
            createAccessorPropertyBackingField: () => createAccessorPropertyBackingField,
            createAccessorPropertyGetRedirector: () => createAccessorPropertyGetRedirector,
            createAccessorPropertySetRedirector: () => createAccessorPropertySetRedirector,
            createBaseNodeFactory: () => createBaseNodeFactory,
            createBinaryExpressionTrampoline: () => createBinaryExpressionTrampoline,
            createBindingHelper: () => createBindingHelper,
            createBuildInfo: () => createBuildInfo,
            createBuilderProgram: () => createBuilderProgram,
            createBuilderProgramUsingProgramBuildInfo: () => createBuilderProgramUsingProgramBuildInfo,
            createBuilderStatusReporter: () => createBuilderStatusReporter,
            createCacheWithRedirects: () => createCacheWithRedirects,
            createCacheableExportInfoMap: () => createCacheableExportInfoMap,
            createCachedDirectoryStructureHost: () => createCachedDirectoryStructureHost,
            createClassifier: () => createClassifier,
            createCommentDirectivesMap: () => createCommentDirectivesMap,
            createCompilerDiagnostic: () => createCompilerDiagnostic,
            createCompilerDiagnosticForInvalidCustomType: () => createCompilerDiagnosticForInvalidCustomType,
            createCompilerDiagnosticFromMessageChain: () => createCompilerDiagnosticFromMessageChain,
            createCompilerHost: () => createCompilerHost,
            createCompilerHostFromProgramHost: () => createCompilerHostFromProgramHost,
            createCompilerHostWorker: () => createCompilerHostWorker,
            createDetachedDiagnostic: () => createDetachedDiagnostic,
            createDiagnosticCollection: () => createDiagnosticCollection,
            createDiagnosticForFileFromMessageChain: () => createDiagnosticForFileFromMessageChain,
            createDiagnosticForNode: () => createDiagnosticForNode,
            createDiagnosticForNodeArray: () => createDiagnosticForNodeArray,
            createDiagnosticForNodeArrayFromMessageChain: () => createDiagnosticForNodeArrayFromMessageChain,
            createDiagnosticForNodeFromMessageChain: () => createDiagnosticForNodeFromMessageChain,
            createDiagnosticForNodeInSourceFile: () => createDiagnosticForNodeInSourceFile,
            createDiagnosticForRange: () => createDiagnosticForRange,
            createDiagnosticMessageChainFromDiagnostic: () => createDiagnosticMessageChainFromDiagnostic,
            createDiagnosticReporter: () => createDiagnosticReporter,
            createDocumentPositionMapper: () => createDocumentPositionMapper,
            createDocumentRegistry: () => createDocumentRegistry,
            createDocumentRegistryInternal: () => createDocumentRegistryInternal,
            createEmitAndSemanticDiagnosticsBuilderProgram: () => createEmitAndSemanticDiagnosticsBuilderProgram,
            createEmitHelperFactory: () => createEmitHelperFactory,
            createEmptyExports: () => createEmptyExports,
            createExpressionForJsxElement: () => createExpressionForJsxElement,
            createExpressionForJsxFragment: () => createExpressionForJsxFragment,
            createExpressionForObjectLiteralElementLike: () => createExpressionForObjectLiteralElementLike,
            createExpressionForPropertyName: () => createExpressionForPropertyName,
            createExpressionFromEntityName: () => createExpressionFromEntityName,
            createExternalHelpersImportDeclarationIfNeeded: () => createExternalHelpersImportDeclarationIfNeeded,
            createFileDiagnostic: () => createFileDiagnostic,
            createFileDiagnosticFromMessageChain: () => createFileDiagnosticFromMessageChain,
            createForOfBindingStatement: () => createForOfBindingStatement,
            createGetCanonicalFileName: () => createGetCanonicalFileName,
            createGetSourceFile: () => createGetSourceFile,
            createGetSymbolAccessibilityDiagnosticForNode: () => createGetSymbolAccessibilityDiagnosticForNode,
            createGetSymbolAccessibilityDiagnosticForNodeName: () => createGetSymbolAccessibilityDiagnosticForNodeName,
            createGetSymbolWalker: () => createGetSymbolWalker,
            createIncrementalCompilerHost: () => createIncrementalCompilerHost,
            createIncrementalProgram: () => createIncrementalProgram,
            createInputFiles: () => createInputFiles,
            createInputFilesWithFilePaths: () => createInputFilesWithFilePaths,
            createInputFilesWithFileTexts: () => createInputFilesWithFileTexts,
            createJsxFactoryExpression: () => createJsxFactoryExpression,
            createLanguageService: () => createLanguageService,
            createLanguageServiceSourceFile: () => createLanguageServiceSourceFile,
            createMemberAccessForPropertyName: () => createMemberAccessForPropertyName,
            createModeAwareCache: () => createModeAwareCache,
            createModeAwareCacheKey: () => createModeAwareCacheKey,
            createModuleResolutionCache: () => createModuleResolutionCache,
            createModuleResolutionLoader: () => createModuleResolutionLoader,
            createModuleSpecifierResolutionHost: () => createModuleSpecifierResolutionHost,
            createMultiMap: () => createMultiMap,
            createNodeConverters: () => createNodeConverters,
            createNodeFactory: () => createNodeFactory,
            createOptionNameMap: () => createOptionNameMap,
            createOverload: () => createOverload,
            createPackageJsonImportFilter: () => createPackageJsonImportFilter,
            createPackageJsonInfo: () => createPackageJsonInfo,
            createParenthesizerRules: () => createParenthesizerRules,
            createPatternMatcher: () => createPatternMatcher,
            createPrependNodes: () => createPrependNodes,
            createPrinter: () => createPrinter,
            createPrinterWithDefaults: () => createPrinterWithDefaults,
            createPrinterWithRemoveComments: () => createPrinterWithRemoveComments,
            createPrinterWithRemoveCommentsNeverAsciiEscape: () => createPrinterWithRemoveCommentsNeverAsciiEscape,
            createPrinterWithRemoveCommentsOmitTrailingSemicolon: () => createPrinterWithRemoveCommentsOmitTrailingSemicolon,
            createProgram: () => createProgram,
            createProgramHost: () => createProgramHost,
            createPropertyNameNodeForIdentifierOrLiteral: () => createPropertyNameNodeForIdentifierOrLiteral,
            createQueue: () => createQueue,
            createRange: () => createRange,
            createRedirectedBuilderProgram: () => createRedirectedBuilderProgram,
            createResolutionCache: () => createResolutionCache,
            createRuntimeTypeSerializer: () => createRuntimeTypeSerializer,
            createScanner: () => createScanner,
            createSemanticDiagnosticsBuilderProgram: () => createSemanticDiagnosticsBuilderProgram,
            createSet: () => createSet,
            createSolutionBuilder: () => createSolutionBuilder,
            createSolutionBuilderHost: () => createSolutionBuilderHost,
            createSolutionBuilderWithWatch: () => createSolutionBuilderWithWatch,
            createSolutionBuilderWithWatchHost: () => createSolutionBuilderWithWatchHost,
            createSortedArray: () => createSortedArray,
            createSourceFile: () => createSourceFile,
            createSourceMapGenerator: () => createSourceMapGenerator,
            createSourceMapSource: () => createSourceMapSource,
            createSuperAccessVariableStatement: () => createSuperAccessVariableStatement,
            createSymbolTable: () => createSymbolTable,
            createSymlinkCache: () => createSymlinkCache,
            createSystemWatchFunctions: () => createSystemWatchFunctions,
            createTextChange: () => createTextChange,
            createTextChangeFromStartLength: () => createTextChangeFromStartLength,
            createTextChangeRange: () => createTextChangeRange,
            createTextRangeFromNode: () => createTextRangeFromNode,
            createTextRangeFromSpan: () => createTextRangeFromSpan,
            createTextSpan: () => createTextSpan,
            createTextSpanFromBounds: () => createTextSpanFromBounds,
            createTextSpanFromNode: () => createTextSpanFromNode,
            createTextSpanFromRange: () => createTextSpanFromRange,
            createTextSpanFromStringLiteralLikeContent: () => createTextSpanFromStringLiteralLikeContent,
            createTextWriter: () => createTextWriter,
            createTokenRange: () => createTokenRange,
            createTypeChecker: () => createTypeChecker,
            createTypeReferenceDirectiveResolutionCache: () => createTypeReferenceDirectiveResolutionCache,
            createTypeReferenceResolutionLoader: () => createTypeReferenceResolutionLoader,
            createUnderscoreEscapedMultiMap: () => createUnderscoreEscapedMultiMap,
            createUnparsedSourceFile: () => createUnparsedSourceFile,
            createWatchCompilerHost: () => createWatchCompilerHost2,
            createWatchCompilerHostOfConfigFile: () => createWatchCompilerHostOfConfigFile,
            createWatchCompilerHostOfFilesAndCompilerOptions: () => createWatchCompilerHostOfFilesAndCompilerOptions,
            createWatchFactory: () => createWatchFactory,
            createWatchHost: () => createWatchHost,
            createWatchProgram: () => createWatchProgram,
            createWatchStatusReporter: () => createWatchStatusReporter,
            createWriteFileMeasuringIO: () => createWriteFileMeasuringIO,
            declarationNameToString: () => declarationNameToString,
            decodeMappings: () => decodeMappings,
            decodedTextSpanIntersectsWith: () => decodedTextSpanIntersectsWith,
            decorateHelper: () => decorateHelper,
            deduplicate: () => deduplicate,
            defaultIncludeSpec: () => defaultIncludeSpec,
            defaultInitCompilerOptions: () => defaultInitCompilerOptions,
            defaultMaximumTruncationLength: () => defaultMaximumTruncationLength,
            detectSortCaseSensitivity: () => detectSortCaseSensitivity,
            diagnosticCategoryName: () => diagnosticCategoryName,
            diagnosticToString: () => diagnosticToString,
            directoryProbablyExists: () => directoryProbablyExists,
            directorySeparator: () => directorySeparator,
            displayPart: () => displayPart,
            displayPartsToString: () => displayPartsToString,
            disposeEmitNodes: () => disposeEmitNodes,
            documentSpansEqual: () => documentSpansEqual,
            dumpTracingLegend: () => dumpTracingLegend,
            elementAt: () => elementAt,
            elideNodes: () => elideNodes,
            emitComments: () => emitComments,
            emitDetachedComments: () => emitDetachedComments,
            emitFiles: () => emitFiles,
            emitFilesAndReportErrors: () => emitFilesAndReportErrors,
            emitFilesAndReportErrorsAndGetExitStatus: () => emitFilesAndReportErrorsAndGetExitStatus,
            emitModuleKindIsNonNodeESM: () => emitModuleKindIsNonNodeESM,
            emitNewLineBeforeLeadingCommentOfPosition: () => emitNewLineBeforeLeadingCommentOfPosition,
            emitNewLineBeforeLeadingComments: () => emitNewLineBeforeLeadingComments,
            emitNewLineBeforeLeadingCommentsOfPosition: () => emitNewLineBeforeLeadingCommentsOfPosition,
            emitSkippedWithNoDiagnostics: () => emitSkippedWithNoDiagnostics,
            emitUsingBuildInfo: () => emitUsingBuildInfo,
            emptyArray: () => emptyArray,
            emptyFileSystemEntries: () => emptyFileSystemEntries,
            emptyMap: () => emptyMap,
            emptyOptions: () => emptyOptions,
            emptySet: () => emptySet,
            endsWith: () => endsWith,
            ensurePathIsNonModuleName: () => ensurePathIsNonModuleName,
            ensureScriptKind: () => ensureScriptKind,
            ensureTrailingDirectorySeparator: () => ensureTrailingDirectorySeparator,
            entityNameToString: () => entityNameToString,
            enumerateInsertsAndDeletes: () => enumerateInsertsAndDeletes,
            equalOwnProperties: () => equalOwnProperties,
            equateStringsCaseInsensitive: () => equateStringsCaseInsensitive,
            equateStringsCaseSensitive: () => equateStringsCaseSensitive,
            equateValues: () => equateValues,
            esDecorateHelper: () => esDecorateHelper,
            escapeJsxAttributeString: () => escapeJsxAttributeString,
            escapeLeadingUnderscores: () => escapeLeadingUnderscores,
            escapeNonAsciiString: () => escapeNonAsciiString,
            escapeSnippetText: () => escapeSnippetText,
            escapeString: () => escapeString,
            every: () => every,
            expandPreOrPostfixIncrementOrDecrementExpression: () => expandPreOrPostfixIncrementOrDecrementExpression,
            explainFiles: () => explainFiles,
            explainIfFileIsRedirectAndImpliedFormat: () => explainIfFileIsRedirectAndImpliedFormat,
            exportAssignmentIsAlias: () => exportAssignmentIsAlias,
            exportStarHelper: () => exportStarHelper,
            expressionResultIsUnused: () => expressionResultIsUnused,
            extend: () => extend,
            extendsHelper: () => extendsHelper,
            extensionFromPath: () => extensionFromPath,
            extensionIsTS: () => extensionIsTS,
            externalHelpersModuleNameText: () => externalHelpersModuleNameText,
            factory: () => factory,
            fileExtensionIs: () => fileExtensionIs,
            fileExtensionIsOneOf: () => fileExtensionIsOneOf,
            fileIncludeReasonToDiagnostics: () => fileIncludeReasonToDiagnostics,
            filter: () => filter,
            filterMutate: () => filterMutate,
            filterSemanticDiagnostics: () => filterSemanticDiagnostics,
            find: () => find,
            findAncestor: () => findAncestor,
            findBestPatternMatch: () => findBestPatternMatch,
            findChildOfKind: () => findChildOfKind,
            findComputedPropertyNameCacheAssignment: () => findComputedPropertyNameCacheAssignment,
            findConfigFile: () => findConfigFile,
            findContainingList: () => findContainingList,
            findDiagnosticForNode: () => findDiagnosticForNode,
            findFirstNonJsxWhitespaceToken: () => findFirstNonJsxWhitespaceToken,
            findIndex: () => findIndex,
            findLast: () => findLast,
            findLastIndex: () => findLastIndex,
            findListItemInfo: () => findListItemInfo,
            findMap: () => findMap,
            findModifier: () => findModifier,
            findNextToken: () => findNextToken,
            findPackageJson: () => findPackageJson,
            findPackageJsons: () => findPackageJsons,
            findPrecedingMatchingToken: () => findPrecedingMatchingToken,
            findPrecedingToken: () => findPrecedingToken,
            findSuperStatementIndex: () => findSuperStatementIndex,
            findTokenOnLeftOfPosition: () => findTokenOnLeftOfPosition,
            findUseStrictPrologue: () => findUseStrictPrologue,
            first: () => first,
            firstDefined: () => firstDefined,
            firstDefinedIterator: () => firstDefinedIterator,
            firstIterator: () => firstIterator,
            firstOrOnly: () => firstOrOnly,
            firstOrUndefined: () => firstOrUndefined,
            firstOrUndefinedIterator: () => firstOrUndefinedIterator,
            fixupCompilerOptions: () => fixupCompilerOptions,
            flatMap: () => flatMap,
            flatMapIterator: () => flatMapIterator,
            flatMapToMutable: () => flatMapToMutable,
            flatten: () => flatten,
            flattenCommaList: () => flattenCommaList,
            flattenDestructuringAssignment: () => flattenDestructuringAssignment,
            flattenDestructuringBinding: () => flattenDestructuringBinding,
            flattenDiagnosticMessageText: () => flattenDiagnosticMessageText,
            forEach: () => forEach,
            forEachAncestor: () => forEachAncestor,
            forEachAncestorDirectory: () => forEachAncestorDirectory,
            forEachChild: () => forEachChild,
            forEachChildRecursively: () => forEachChildRecursively,
            forEachEmittedFile: () => forEachEmittedFile,
            forEachEnclosingBlockScopeContainer: () => forEachEnclosingBlockScopeContainer,
            forEachEntry: () => forEachEntry,
            forEachExternalModuleToImportFrom: () => forEachExternalModuleToImportFrom,
            forEachImportClauseDeclaration: () => forEachImportClauseDeclaration,
            forEachKey: () => forEachKey,
            forEachLeadingCommentRange: () => forEachLeadingCommentRange,
            forEachNameInAccessChainWalkingLeft: () => forEachNameInAccessChainWalkingLeft,
            forEachResolvedProjectReference: () => forEachResolvedProjectReference,
            forEachReturnStatement: () => forEachReturnStatement,
            forEachRight: () => forEachRight,
            forEachTrailingCommentRange: () => forEachTrailingCommentRange,
            forEachUnique: () => forEachUnique,
            forEachYieldExpression: () => forEachYieldExpression,
            forSomeAncestorDirectory: () => forSomeAncestorDirectory,
            formatColorAndReset: () => formatColorAndReset,
            formatDiagnostic: () => formatDiagnostic,
            formatDiagnostics: () => formatDiagnostics,
            formatDiagnosticsWithColorAndContext: () => formatDiagnosticsWithColorAndContext,
            formatGeneratedName: () => formatGeneratedName,
            formatGeneratedNamePart: () => formatGeneratedNamePart,
            formatLocation: () => formatLocation,
            formatMessage: () => formatMessage,
            formatStringFromArgs: () => formatStringFromArgs,
            formatting: () => ts_formatting_exports,
            fullTripleSlashAMDReferencePathRegEx: () => fullTripleSlashAMDReferencePathRegEx,
            fullTripleSlashReferencePathRegEx: () => fullTripleSlashReferencePathRegEx,
            generateDjb2Hash: () => generateDjb2Hash,
            generateTSConfig: () => generateTSConfig,
            generatorHelper: () => generatorHelper,
            getAdjustedReferenceLocation: () => getAdjustedReferenceLocation,
            getAdjustedRenameLocation: () => getAdjustedRenameLocation,
            getAliasDeclarationFromName: () => getAliasDeclarationFromName,
            getAllAccessorDeclarations: () => getAllAccessorDeclarations,
            getAllDecoratorsOfClass: () => getAllDecoratorsOfClass,
            getAllDecoratorsOfClassElement: () => getAllDecoratorsOfClassElement,
            getAllJSDocTags: () => getAllJSDocTags,
            getAllJSDocTagsOfKind: () => getAllJSDocTagsOfKind,
            getAllKeys: () => getAllKeys,
            getAllProjectOutputs: () => getAllProjectOutputs,
            getAllSuperTypeNodes: () => getAllSuperTypeNodes,
            getAllUnscopedEmitHelpers: () => getAllUnscopedEmitHelpers,
            getAllowJSCompilerOption: () => getAllowJSCompilerOption,
            getAllowSyntheticDefaultImports: () => getAllowSyntheticDefaultImports,
            getAncestor: () => getAncestor,
            getAnyExtensionFromPath: () => getAnyExtensionFromPath,
            getAreDeclarationMapsEnabled: () => getAreDeclarationMapsEnabled,
            getAssignedExpandoInitializer: () => getAssignedExpandoInitializer,
            getAssignedName: () => getAssignedName,
            getAssignmentDeclarationKind: () => getAssignmentDeclarationKind,
            getAssignmentDeclarationPropertyAccessKind: () => getAssignmentDeclarationPropertyAccessKind,
            getAssignmentTargetKind: () => getAssignmentTargetKind,
            getAutomaticTypeDirectiveNames: () => getAutomaticTypeDirectiveNames,
            getBaseFileName: () => getBaseFileName,
            getBinaryOperatorPrecedence: () => getBinaryOperatorPrecedence,
            getBuildInfo: () => getBuildInfo,
            getBuildInfoFileVersionMap: () => getBuildInfoFileVersionMap,
            getBuildInfoText: () => getBuildInfoText,
            getBuildOrderFromAnyBuildOrder: () => getBuildOrderFromAnyBuildOrder,
            getBuilderCreationParameters: () => getBuilderCreationParameters,
            getBuilderFileEmit: () => getBuilderFileEmit,
            getCheckFlags: () => getCheckFlags,
            getClassExtendsHeritageElement: () => getClassExtendsHeritageElement,
            getClassLikeDeclarationOfSymbol: () => getClassLikeDeclarationOfSymbol,
            getCombinedLocalAndExportSymbolFlags: () => getCombinedLocalAndExportSymbolFlags,
            getCombinedModifierFlags: () => getCombinedModifierFlags,
            getCombinedNodeFlags: () => getCombinedNodeFlags,
            getCombinedNodeFlagsAlwaysIncludeJSDoc: () => getCombinedNodeFlagsAlwaysIncludeJSDoc,
            getCommentRange: () => getCommentRange,
            getCommonSourceDirectory: () => getCommonSourceDirectory,
            getCommonSourceDirectoryOfConfig: () => getCommonSourceDirectoryOfConfig,
            getCompilerOptionValue: () => getCompilerOptionValue,
            getCompilerOptionsDiffValue: () => getCompilerOptionsDiffValue,
            getConditions: () => getConditions,
            getConfigFileParsingDiagnostics: () => getConfigFileParsingDiagnostics,
            getConstantValue: () => getConstantValue,
            getContainerNode: () => getContainerNode,
            getContainingClass: () => getContainingClass,
            getContainingClassStaticBlock: () => getContainingClassStaticBlock,
            getContainingFunction: () => getContainingFunction,
            getContainingFunctionDeclaration: () => getContainingFunctionDeclaration,
            getContainingFunctionOrClassStaticBlock: () => getContainingFunctionOrClassStaticBlock,
            getContainingNodeArray: () => getContainingNodeArray,
            getContainingObjectLiteralElement: () => getContainingObjectLiteralElement,
            getContextualTypeFromParent: () => getContextualTypeFromParent,
            getContextualTypeFromParentOrAncestorTypeNode: () => getContextualTypeFromParentOrAncestorTypeNode,
            getCurrentTime: () => getCurrentTime,
            getDeclarationDiagnostics: () => getDeclarationDiagnostics,
            getDeclarationEmitExtensionForPath: () => getDeclarationEmitExtensionForPath,
            getDeclarationEmitOutputFilePath: () => getDeclarationEmitOutputFilePath,
            getDeclarationEmitOutputFilePathWorker: () => getDeclarationEmitOutputFilePathWorker,
            getDeclarationFromName: () => getDeclarationFromName,
            getDeclarationModifierFlagsFromSymbol: () => getDeclarationModifierFlagsFromSymbol,
            getDeclarationOfKind: () => getDeclarationOfKind,
            getDeclarationsOfKind: () => getDeclarationsOfKind,
            getDeclaredExpandoInitializer: () => getDeclaredExpandoInitializer,
            getDecorators: () => getDecorators,
            getDefaultCompilerOptions: () => getDefaultCompilerOptions2,
            getDefaultExportInfoWorker: () => getDefaultExportInfoWorker,
            getDefaultFormatCodeSettings: () => getDefaultFormatCodeSettings,
            getDefaultLibFileName: () => getDefaultLibFileName,
            getDefaultLibFilePath: () => getDefaultLibFilePath,
            getDefaultLikeExportInfo: () => getDefaultLikeExportInfo,
            getDiagnosticText: () => getDiagnosticText,
            getDiagnosticsWithinSpan: () => getDiagnosticsWithinSpan,
            getDirectoryPath: () => getDirectoryPath,
            getDocumentPositionMapper: () => getDocumentPositionMapper,
            getESModuleInterop: () => getESModuleInterop,
            getEditsForFileRename: () => getEditsForFileRename,
            getEffectiveBaseTypeNode: () => getEffectiveBaseTypeNode,
            getEffectiveConstraintOfTypeParameter: () => getEffectiveConstraintOfTypeParameter,
            getEffectiveContainerForJSDocTemplateTag: () => getEffectiveContainerForJSDocTemplateTag,
            getEffectiveImplementsTypeNodes: () => getEffectiveImplementsTypeNodes,
            getEffectiveInitializer: () => getEffectiveInitializer,
            getEffectiveJSDocHost: () => getEffectiveJSDocHost,
            getEffectiveModifierFlags: () => getEffectiveModifierFlags,
            getEffectiveModifierFlagsAlwaysIncludeJSDoc: () => getEffectiveModifierFlagsAlwaysIncludeJSDoc,
            getEffectiveModifierFlagsNoCache: () => getEffectiveModifierFlagsNoCache,
            getEffectiveReturnTypeNode: () => getEffectiveReturnTypeNode,
            getEffectiveSetAccessorTypeAnnotationNode: () => getEffectiveSetAccessorTypeAnnotationNode,
            getEffectiveTypeAnnotationNode: () => getEffectiveTypeAnnotationNode,
            getEffectiveTypeParameterDeclarations: () => getEffectiveTypeParameterDeclarations,
            getEffectiveTypeRoots: () => getEffectiveTypeRoots,
            getElementOrPropertyAccessArgumentExpressionOrName: () => getElementOrPropertyAccessArgumentExpressionOrName,
            getElementOrPropertyAccessName: () => getElementOrPropertyAccessName,
            getElementsOfBindingOrAssignmentPattern: () => getElementsOfBindingOrAssignmentPattern,
            getEmitDeclarations: () => getEmitDeclarations,
            getEmitFlags: () => getEmitFlags,
            getEmitHelpers: () => getEmitHelpers,
            getEmitModuleDetectionKind: () => getEmitModuleDetectionKind,
            getEmitModuleKind: () => getEmitModuleKind,
            getEmitModuleResolutionKind: () => getEmitModuleResolutionKind,
            getEmitScriptTarget: () => getEmitScriptTarget,
            getEnclosingBlockScopeContainer: () => getEnclosingBlockScopeContainer,
            getEncodedSemanticClassifications: () => getEncodedSemanticClassifications,
            getEncodedSyntacticClassifications: () => getEncodedSyntacticClassifications,
            getEndLinePosition: () => getEndLinePosition,
            getEntityNameFromTypeNode: () => getEntityNameFromTypeNode,
            getEntrypointsFromPackageJsonInfo: () => getEntrypointsFromPackageJsonInfo,
            getErrorCountForSummary: () => getErrorCountForSummary,
            getErrorSpanForNode: () => getErrorSpanForNode,
            getErrorSummaryText: () => getErrorSummaryText,
            getEscapedTextOfIdentifierOrLiteral: () => getEscapedTextOfIdentifierOrLiteral,
            getExpandoInitializer: () => getExpandoInitializer,
            getExportAssignmentExpression: () => getExportAssignmentExpression,
            getExportInfoMap: () => getExportInfoMap,
            getExportNeedsImportStarHelper: () => getExportNeedsImportStarHelper,
            getExpressionAssociativity: () => getExpressionAssociativity,
            getExpressionPrecedence: () => getExpressionPrecedence,
            getExternalHelpersModuleName: () => getExternalHelpersModuleName,
            getExternalModuleImportEqualsDeclarationExpression: () => getExternalModuleImportEqualsDeclarationExpression,
            getExternalModuleName: () => getExternalModuleName,
            getExternalModuleNameFromDeclaration: () => getExternalModuleNameFromDeclaration,
            getExternalModuleNameFromPath: () => getExternalModuleNameFromPath,
            getExternalModuleNameLiteral: () => getExternalModuleNameLiteral,
            getExternalModuleRequireArgument: () => getExternalModuleRequireArgument,
            getFallbackOptions: () => getFallbackOptions,
            getFileEmitOutput: () => getFileEmitOutput,
            getFileMatcherPatterns: () => getFileMatcherPatterns,
            getFileNamesFromConfigSpecs: () => getFileNamesFromConfigSpecs,
            getFileWatcherEventKind: () => getFileWatcherEventKind,
            getFilesInErrorForSummary: () => getFilesInErrorForSummary,
            getFirstConstructorWithBody: () => getFirstConstructorWithBody,
            getFirstIdentifier: () => getFirstIdentifier,
            getFirstNonSpaceCharacterPosition: () => getFirstNonSpaceCharacterPosition,
            getFirstProjectOutput: () => getFirstProjectOutput,
            getFixableErrorSpanExpression: () => getFixableErrorSpanExpression,
            getFormatCodeSettingsForWriting: () => getFormatCodeSettingsForWriting,
            getFullWidth: () => getFullWidth,
            getFunctionFlags: () => getFunctionFlags,
            getHeritageClause: () => getHeritageClause,
            getHostSignatureFromJSDoc: () => getHostSignatureFromJSDoc,
            getIdentifierAutoGenerate: () => getIdentifierAutoGenerate,
            getIdentifierGeneratedImportReference: () => getIdentifierGeneratedImportReference,
            getIdentifierTypeArguments: () => getIdentifierTypeArguments,
            getImmediatelyInvokedFunctionExpression: () => getImmediatelyInvokedFunctionExpression,
            getImpliedNodeFormatForFile: () => getImpliedNodeFormatForFile,
            getImpliedNodeFormatForFileWorker: () => getImpliedNodeFormatForFileWorker,
            getImportNeedsImportDefaultHelper: () => getImportNeedsImportDefaultHelper,
            getImportNeedsImportStarHelper: () => getImportNeedsImportStarHelper,
            getIndentSize: () => getIndentSize,
            getIndentString: () => getIndentString,
            getInitializedVariables: () => getInitializedVariables,
            getInitializerOfBinaryExpression: () => getInitializerOfBinaryExpression,
            getInitializerOfBindingOrAssignmentElement: () => getInitializerOfBindingOrAssignmentElement,
            getInterfaceBaseTypeNodes: () => getInterfaceBaseTypeNodes,
            getInternalEmitFlags: () => getInternalEmitFlags,
            getInvokedExpression: () => getInvokedExpression,
            getIsolatedModules: () => getIsolatedModules,
            getJSDocAugmentsTag: () => getJSDocAugmentsTag,
            getJSDocClassTag: () => getJSDocClassTag,
            getJSDocCommentRanges: () => getJSDocCommentRanges,
            getJSDocCommentsAndTags: () => getJSDocCommentsAndTags,
            getJSDocDeprecatedTag: () => getJSDocDeprecatedTag,
            getJSDocDeprecatedTagNoCache: () => getJSDocDeprecatedTagNoCache,
            getJSDocEnumTag: () => getJSDocEnumTag,
            getJSDocHost: () => getJSDocHost,
            getJSDocImplementsTags: () => getJSDocImplementsTags,
            getJSDocOverrideTagNoCache: () => getJSDocOverrideTagNoCache,
            getJSDocParameterTags: () => getJSDocParameterTags,
            getJSDocParameterTagsNoCache: () => getJSDocParameterTagsNoCache,
            getJSDocPrivateTag: () => getJSDocPrivateTag,
            getJSDocPrivateTagNoCache: () => getJSDocPrivateTagNoCache,
            getJSDocProtectedTag: () => getJSDocProtectedTag,
            getJSDocProtectedTagNoCache: () => getJSDocProtectedTagNoCache,
            getJSDocPublicTag: () => getJSDocPublicTag,
            getJSDocPublicTagNoCache: () => getJSDocPublicTagNoCache,
            getJSDocReadonlyTag: () => getJSDocReadonlyTag,
            getJSDocReadonlyTagNoCache: () => getJSDocReadonlyTagNoCache,
            getJSDocReturnTag: () => getJSDocReturnTag,
            getJSDocReturnType: () => getJSDocReturnType,
            getJSDocRoot: () => getJSDocRoot,
            getJSDocSatisfiesExpressionType: () => getJSDocSatisfiesExpressionType,
            getJSDocSatisfiesTag: () => getJSDocSatisfiesTag,
            getJSDocTags: () => getJSDocTags,
            getJSDocTagsNoCache: () => getJSDocTagsNoCache,
            getJSDocTemplateTag: () => getJSDocTemplateTag,
            getJSDocThisTag: () => getJSDocThisTag,
            getJSDocType: () => getJSDocType,
            getJSDocTypeAliasName: () => getJSDocTypeAliasName,
            getJSDocTypeAssertionType: () => getJSDocTypeAssertionType,
            getJSDocTypeParameterDeclarations: () => getJSDocTypeParameterDeclarations,
            getJSDocTypeParameterTags: () => getJSDocTypeParameterTags,
            getJSDocTypeParameterTagsNoCache: () => getJSDocTypeParameterTagsNoCache,
            getJSDocTypeTag: () => getJSDocTypeTag,
            getJSXImplicitImportBase: () => getJSXImplicitImportBase,
            getJSXRuntimeImport: () => getJSXRuntimeImport,
            getJSXTransformEnabled: () => getJSXTransformEnabled,
            getKeyForCompilerOptions: () => getKeyForCompilerOptions,
            getLanguageVariant: () => getLanguageVariant,
            getLastChild: () => getLastChild,
            getLeadingCommentRanges: () => getLeadingCommentRanges,
            getLeadingCommentRangesOfNode: () => getLeadingCommentRangesOfNode,
            getLeftmostAccessExpression: () => getLeftmostAccessExpression,
            getLeftmostExpression: () => getLeftmostExpression,
            getLineAndCharacterOfPosition: () => getLineAndCharacterOfPosition,
            getLineInfo: () => getLineInfo,
            getLineOfLocalPosition: () => getLineOfLocalPosition,
            getLineOfLocalPositionFromLineMap: () => getLineOfLocalPositionFromLineMap,
            getLineStartPositionForPosition: () => getLineStartPositionForPosition,
            getLineStarts: () => getLineStarts,
            getLinesBetweenPositionAndNextNonWhitespaceCharacter: () => getLinesBetweenPositionAndNextNonWhitespaceCharacter,
            getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter: () => getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter,
            getLinesBetweenPositions: () => getLinesBetweenPositions,
            getLinesBetweenRangeEndAndRangeStart: () => getLinesBetweenRangeEndAndRangeStart,
            getLinesBetweenRangeEndPositions: () => getLinesBetweenRangeEndPositions,
            getLiteralText: () => getLiteralText,
            getLocalNameForExternalImport: () => getLocalNameForExternalImport,
            getLocalSymbolForExportDefault: () => getLocalSymbolForExportDefault,
            getLocaleSpecificMessage: () => getLocaleSpecificMessage,
            getLocaleTimeString: () => getLocaleTimeString,
            getMappedContextSpan: () => getMappedContextSpan,
            getMappedDocumentSpan: () => getMappedDocumentSpan,
            getMappedLocation: () => getMappedLocation,
            getMatchedFileSpec: () => getMatchedFileSpec,
            getMatchedIncludeSpec: () => getMatchedIncludeSpec,
            getMeaningFromDeclaration: () => getMeaningFromDeclaration,
            getMeaningFromLocation: () => getMeaningFromLocation,
            getMembersOfDeclaration: () => getMembersOfDeclaration,
            getModeForFileReference: () => getModeForFileReference,
            getModeForResolutionAtIndex: () => getModeForResolutionAtIndex,
            getModeForUsageLocation: () => getModeForUsageLocation,
            getModifiedTime: () => getModifiedTime,
            getModifiers: () => getModifiers,
            getModuleInstanceState: () => getModuleInstanceState,
            getModuleNameStringLiteralAt: () => getModuleNameStringLiteralAt,
            getModuleSpecifierEndingPreference: () => getModuleSpecifierEndingPreference,
            getModuleSpecifierResolverHost: () => getModuleSpecifierResolverHost,
            getNameForExportedSymbol: () => getNameForExportedSymbol,
            getNameFromIndexInfo: () => getNameFromIndexInfo,
            getNameFromPropertyName: () => getNameFromPropertyName,
            getNameOfAccessExpression: () => getNameOfAccessExpression,
            getNameOfCompilerOptionValue: () => getNameOfCompilerOptionValue,
            getNameOfDeclaration: () => getNameOfDeclaration,
            getNameOfExpando: () => getNameOfExpando,
            getNameOfJSDocTypedef: () => getNameOfJSDocTypedef,
            getNameOrArgument: () => getNameOrArgument,
            getNameTable: () => getNameTable,
            getNamesForExportedSymbol: () => getNamesForExportedSymbol,
            getNamespaceDeclarationNode: () => getNamespaceDeclarationNode,
            getNewLineCharacter: () => getNewLineCharacter,
            getNewLineKind: () => getNewLineKind,
            getNewLineOrDefaultFromHost: () => getNewLineOrDefaultFromHost,
            getNewTargetContainer: () => getNewTargetContainer,
            getNextJSDocCommentLocation: () => getNextJSDocCommentLocation,
            getNodeForGeneratedName: () => getNodeForGeneratedName,
            getNodeId: () => getNodeId,
            getNodeKind: () => getNodeKind,
            getNodeModifiers: () => getNodeModifiers,
            getNodeModulePathParts: () => getNodeModulePathParts,
            getNonAssignedNameOfDeclaration: () => getNonAssignedNameOfDeclaration,
            getNonAssignmentOperatorForCompoundAssignment: () => getNonAssignmentOperatorForCompoundAssignment,
            getNonAugmentationDeclaration: () => getNonAugmentationDeclaration,
            getNonDecoratorTokenPosOfNode: () => getNonDecoratorTokenPosOfNode,
            getNormalizedAbsolutePath: () => getNormalizedAbsolutePath,
            getNormalizedAbsolutePathWithoutRoot: () => getNormalizedAbsolutePathWithoutRoot,
            getNormalizedPathComponents: () => getNormalizedPathComponents,
            getObjectFlags: () => getObjectFlags,
            getOperator: () => getOperator,
            getOperatorAssociativity: () => getOperatorAssociativity,
            getOperatorPrecedence: () => getOperatorPrecedence,
            getOptionFromName: () => getOptionFromName,
            getOptionsNameMap: () => getOptionsNameMap,
            getOrCreateEmitNode: () => getOrCreateEmitNode,
            getOrCreateExternalHelpersModuleNameIfNeeded: () => getOrCreateExternalHelpersModuleNameIfNeeded,
            getOrUpdate: () => getOrUpdate,
            getOriginalNode: () => getOriginalNode,
            getOriginalNodeId: () => getOriginalNodeId,
            getOriginalSourceFile: () => getOriginalSourceFile,
            getOutputDeclarationFileName: () => getOutputDeclarationFileName,
            getOutputExtension: () => getOutputExtension,
            getOutputFileNames: () => getOutputFileNames,
            getOutputPathsFor: () => getOutputPathsFor,
            getOutputPathsForBundle: () => getOutputPathsForBundle,
            getOwnEmitOutputFilePath: () => getOwnEmitOutputFilePath,
            getOwnKeys: () => getOwnKeys,
            getOwnValues: () => getOwnValues,
            getPackageJsonInfo: () => getPackageJsonInfo,
            getPackageJsonTypesVersionsPaths: () => getPackageJsonTypesVersionsPaths,
            getPackageJsonsVisibleToFile: () => getPackageJsonsVisibleToFile,
            getPackageNameFromTypesPackageName: () => getPackageNameFromTypesPackageName,
            getPackageScopeForPath: () => getPackageScopeForPath,
            getParameterSymbolFromJSDoc: () => getParameterSymbolFromJSDoc,
            getParameterTypeNode: () => getParameterTypeNode,
            getParentNodeInSpan: () => getParentNodeInSpan,
            getParseTreeNode: () => getParseTreeNode,
            getParsedCommandLineOfConfigFile: () => getParsedCommandLineOfConfigFile,
            getPathComponents: () => getPathComponents,
            getPathComponentsRelativeTo: () => getPathComponentsRelativeTo,
            getPathFromPathComponents: () => getPathFromPathComponents,
            getPathUpdater: () => getPathUpdater,
            getPathsBasePath: () => getPathsBasePath,
            getPatternFromSpec: () => getPatternFromSpec,
            getPendingEmitKind: () => getPendingEmitKind,
            getPositionOfLineAndCharacter: () => getPositionOfLineAndCharacter,
            getPossibleGenericSignatures: () => getPossibleGenericSignatures,
            getPossibleOriginalInputExtensionForExtension: () => getPossibleOriginalInputExtensionForExtension,
            getPossibleTypeArgumentsInfo: () => getPossibleTypeArgumentsInfo,
            getPreEmitDiagnostics: () => getPreEmitDiagnostics,
            getPrecedingNonSpaceCharacterPosition: () => getPrecedingNonSpaceCharacterPosition,
            getPrivateIdentifier: () => getPrivateIdentifier,
            getProperties: () => getProperties,
            getProperty: () => getProperty,
            getPropertyArrayElementValue: () => getPropertyArrayElementValue,
            getPropertyAssignment: () => getPropertyAssignment,
            getPropertyAssignmentAliasLikeExpression: () => getPropertyAssignmentAliasLikeExpression,
            getPropertyNameForPropertyNameNode: () => getPropertyNameForPropertyNameNode,
            getPropertyNameForUniqueESSymbol: () => getPropertyNameForUniqueESSymbol,
            getPropertyNameOfBindingOrAssignmentElement: () => getPropertyNameOfBindingOrAssignmentElement,
            getPropertySymbolFromBindingElement: () => getPropertySymbolFromBindingElement,
            getPropertySymbolsFromContextualType: () => getPropertySymbolsFromContextualType,
            getQuoteFromPreference: () => getQuoteFromPreference,
            getQuotePreference: () => getQuotePreference,
            getRangesWhere: () => getRangesWhere,
            getRefactorContextSpan: () => getRefactorContextSpan,
            getReferencedFileLocation: () => getReferencedFileLocation,
            getRegexFromPattern: () => getRegexFromPattern,
            getRegularExpressionForWildcard: () => getRegularExpressionForWildcard,
            getRegularExpressionsForWildcards: () => getRegularExpressionsForWildcards,
            getRelativePathFromDirectory: () => getRelativePathFromDirectory,
            getRelativePathFromFile: () => getRelativePathFromFile,
            getRelativePathToDirectoryOrUrl: () => getRelativePathToDirectoryOrUrl,
            getRenameLocation: () => getRenameLocation,
            getReplacementSpanForContextToken: () => getReplacementSpanForContextToken,
            getResolutionDiagnostic: () => getResolutionDiagnostic,
            getResolutionModeOverrideForClause: () => getResolutionModeOverrideForClause,
            getResolveJsonModule: () => getResolveJsonModule,
            getResolvePackageJsonExports: () => getResolvePackageJsonExports,
            getResolvePackageJsonImports: () => getResolvePackageJsonImports,
            getResolvedExternalModuleName: () => getResolvedExternalModuleName,
            getResolvedModule: () => getResolvedModule,
            getResolvedTypeReferenceDirective: () => getResolvedTypeReferenceDirective,
            getRestIndicatorOfBindingOrAssignmentElement: () => getRestIndicatorOfBindingOrAssignmentElement,
            getRestParameterElementType: () => getRestParameterElementType,
            getRightMostAssignedExpression: () => getRightMostAssignedExpression,
            getRootDeclaration: () => getRootDeclaration,
            getRootLength: () => getRootLength,
            getScriptKind: () => getScriptKind,
            getScriptKindFromFileName: () => getScriptKindFromFileName,
            getScriptTargetFeatures: () => getScriptTargetFeatures,
            getSelectedEffectiveModifierFlags: () => getSelectedEffectiveModifierFlags,
            getSelectedSyntacticModifierFlags: () => getSelectedSyntacticModifierFlags,
            getSemanticClassifications: () => getSemanticClassifications,
            getSemanticJsxChildren: () => getSemanticJsxChildren,
            getSetAccessorTypeAnnotationNode: () => getSetAccessorTypeAnnotationNode,
            getSetAccessorValueParameter: () => getSetAccessorValueParameter,
            getSetExternalModuleIndicator: () => getSetExternalModuleIndicator,
            getShebang: () => getShebang,
            getSingleInitializerOfVariableStatementOrPropertyDeclaration: () => getSingleInitializerOfVariableStatementOrPropertyDeclaration,
            getSingleVariableOfVariableStatement: () => getSingleVariableOfVariableStatement,
            getSnapshotText: () => getSnapshotText,
            getSnippetElement: () => getSnippetElement,
            getSourceFileOfModule: () => getSourceFileOfModule,
            getSourceFileOfNode: () => getSourceFileOfNode,
            getSourceFilePathInNewDir: () => getSourceFilePathInNewDir,
            getSourceFilePathInNewDirWorker: () => getSourceFilePathInNewDirWorker,
            getSourceFileVersionAsHashFromText: () => getSourceFileVersionAsHashFromText,
            getSourceFilesToEmit: () => getSourceFilesToEmit,
            getSourceMapRange: () => getSourceMapRange,
            getSourceMapper: () => getSourceMapper,
            getSourceTextOfNodeFromSourceFile: () => getSourceTextOfNodeFromSourceFile,
            getSpanOfTokenAtPosition: () => getSpanOfTokenAtPosition,
            getSpellingSuggestion: () => getSpellingSuggestion,
            getStartPositionOfLine: () => getStartPositionOfLine,
            getStartPositionOfRange: () => getStartPositionOfRange,
            getStartsOnNewLine: () => getStartsOnNewLine,
            getStaticPropertiesAndClassStaticBlock: () => getStaticPropertiesAndClassStaticBlock,
            getStrictOptionValue: () => getStrictOptionValue,
            getStringComparer: () => getStringComparer,
            getSuperCallFromStatement: () => getSuperCallFromStatement,
            getSuperContainer: () => getSuperContainer,
            getSupportedCodeFixes: () => getSupportedCodeFixes,
            getSupportedExtensions: () => getSupportedExtensions,
            getSupportedExtensionsWithJsonIfResolveJsonModule: () => getSupportedExtensionsWithJsonIfResolveJsonModule,
            getSwitchedType: () => getSwitchedType,
            getSymbolId: () => getSymbolId,
            getSymbolNameForPrivateIdentifier: () => getSymbolNameForPrivateIdentifier,
            getSymbolTarget: () => getSymbolTarget,
            getSyntacticClassifications: () => getSyntacticClassifications,
            getSyntacticModifierFlags: () => getSyntacticModifierFlags,
            getSyntacticModifierFlagsNoCache: () => getSyntacticModifierFlagsNoCache,
            getSynthesizedDeepClone: () => getSynthesizedDeepClone,
            getSynthesizedDeepCloneWithReplacements: () => getSynthesizedDeepCloneWithReplacements,
            getSynthesizedDeepClones: () => getSynthesizedDeepClones,
            getSynthesizedDeepClonesWithReplacements: () => getSynthesizedDeepClonesWithReplacements,
            getSyntheticLeadingComments: () => getSyntheticLeadingComments,
            getSyntheticTrailingComments: () => getSyntheticTrailingComments,
            getTargetLabel: () => getTargetLabel,
            getTargetOfBindingOrAssignmentElement: () => getTargetOfBindingOrAssignmentElement,
            getTemporaryModuleResolutionState: () => getTemporaryModuleResolutionState,
            getTextOfConstantValue: () => getTextOfConstantValue,
            getTextOfIdentifierOrLiteral: () => getTextOfIdentifierOrLiteral,
            getTextOfJSDocComment: () => getTextOfJSDocComment,
            getTextOfNode: () => getTextOfNode,
            getTextOfNodeFromSourceText: () => getTextOfNodeFromSourceText,
            getTextOfPropertyName: () => getTextOfPropertyName,
            getThisContainer: () => getThisContainer,
            getThisParameter: () => getThisParameter,
            getTokenAtPosition: () => getTokenAtPosition,
            getTokenPosOfNode: () => getTokenPosOfNode,
            getTokenSourceMapRange: () => getTokenSourceMapRange,
            getTouchingPropertyName: () => getTouchingPropertyName,
            getTouchingToken: () => getTouchingToken,
            getTrailingCommentRanges: () => getTrailingCommentRanges,
            getTrailingSemicolonDeferringWriter: () => getTrailingSemicolonDeferringWriter,
            getTransformFlagsSubtreeExclusions: () => getTransformFlagsSubtreeExclusions,
            getTransformers: () => getTransformers,
            getTsBuildInfoEmitOutputFilePath: () => getTsBuildInfoEmitOutputFilePath,
            getTsConfigObjectLiteralExpression: () => getTsConfigObjectLiteralExpression,
            getTsConfigPropArray: () => getTsConfigPropArray,
            getTsConfigPropArrayElementValue: () => getTsConfigPropArrayElementValue,
            getTypeAnnotationNode: () => getTypeAnnotationNode,
            getTypeArgumentOrTypeParameterList: () => getTypeArgumentOrTypeParameterList,
            getTypeKeywordOfTypeOnlyImport: () => getTypeKeywordOfTypeOnlyImport,
            getTypeNode: () => getTypeNode,
            getTypeNodeIfAccessible: () => getTypeNodeIfAccessible,
            getTypeParameterFromJsDoc: () => getTypeParameterFromJsDoc,
            getTypeParameterOwner: () => getTypeParameterOwner,
            getTypesPackageName: () => getTypesPackageName,
            getUILocale: () => getUILocale,
            getUniqueName: () => getUniqueName,
            getUniqueSymbolId: () => getUniqueSymbolId,
            getUseDefineForClassFields: () => getUseDefineForClassFields,
            getWatchErrorSummaryDiagnosticMessage: () => getWatchErrorSummaryDiagnosticMessage,
            getWatchFactory: () => getWatchFactory,
            group: () => group,
            groupBy: () => groupBy,
            guessIndentation: () => guessIndentation,
            handleNoEmitOptions: () => handleNoEmitOptions,
            hasAbstractModifier: () => hasAbstractModifier,
            hasAccessorModifier: () => hasAccessorModifier,
            hasAmbientModifier: () => hasAmbientModifier,
            hasChangesInResolutions: () => hasChangesInResolutions,
            hasChildOfKind: () => hasChildOfKind,
            hasContextSensitiveParameters: () => hasContextSensitiveParameters,
            hasDecorators: () => hasDecorators,
            hasDocComment: () => hasDocComment,
            hasDynamicName: () => hasDynamicName,
            hasEffectiveModifier: () => hasEffectiveModifier,
            hasEffectiveModifiers: () => hasEffectiveModifiers,
            hasEffectiveReadonlyModifier: () => hasEffectiveReadonlyModifier,
            hasExtension: () => hasExtension,
            hasIndexSignature: () => hasIndexSignature,
            hasInitializer: () => hasInitializer,
            hasInvalidEscape: () => hasInvalidEscape,
            hasJSDocNodes: () => hasJSDocNodes,
            hasJSDocParameterTags: () => hasJSDocParameterTags,
            hasJSFileExtension: () => hasJSFileExtension,
            hasJsonModuleEmitEnabled: () => hasJsonModuleEmitEnabled,
            hasOnlyExpressionInitializer: () => hasOnlyExpressionInitializer,
            hasOverrideModifier: () => hasOverrideModifier,
            hasPossibleExternalModuleReference: () => hasPossibleExternalModuleReference,
            hasProperty: () => hasProperty,
            hasPropertyAccessExpressionWithName: () => hasPropertyAccessExpressionWithName,
            hasQuestionToken: () => hasQuestionToken,
            hasRecordedExternalHelpers: () => hasRecordedExternalHelpers,
            hasRestParameter: () => hasRestParameter,
            hasScopeMarker: () => hasScopeMarker,
            hasStaticModifier: () => hasStaticModifier,
            hasSyntacticModifier: () => hasSyntacticModifier,
            hasSyntacticModifiers: () => hasSyntacticModifiers,
            hasTSFileExtension: () => hasTSFileExtension,
            hasTabstop: () => hasTabstop,
            hasTrailingDirectorySeparator: () => hasTrailingDirectorySeparator,
            hasType: () => hasType,
            hasTypeArguments: () => hasTypeArguments,
            hasZeroOrOneAsteriskCharacter: () => hasZeroOrOneAsteriskCharacter,
            helperString: () => helperString,
            hostGetCanonicalFileName: () => hostGetCanonicalFileName,
            hostUsesCaseSensitiveFileNames: () => hostUsesCaseSensitiveFileNames,
            idText: () => idText,
            identifierIsThisKeyword: () => identifierIsThisKeyword,
            identifierToKeywordKind: () => identifierToKeywordKind,
            identity: () => identity,
            identitySourceMapConsumer: () => identitySourceMapConsumer,
            ignoreSourceNewlines: () => ignoreSourceNewlines,
            ignoredPaths: () => ignoredPaths,
            importDefaultHelper: () => importDefaultHelper,
            importFromModuleSpecifier: () => importFromModuleSpecifier,
            importNameElisionDisabled: () => importNameElisionDisabled,
            importStarHelper: () => importStarHelper,
            indexOfAnyCharCode: () => indexOfAnyCharCode,
            indexOfNode: () => indexOfNode,
            indicesOf: () => indicesOf,
            inferredTypesContainingFile: () => inferredTypesContainingFile,
            insertImports: () => insertImports,
            insertLeadingStatement: () => insertLeadingStatement,
            insertSorted: () => insertSorted,
            insertStatementAfterCustomPrologue: () => insertStatementAfterCustomPrologue,
            insertStatementAfterStandardPrologue: () => insertStatementAfterStandardPrologue,
            insertStatementsAfterCustomPrologue: () => insertStatementsAfterCustomPrologue,
            insertStatementsAfterStandardPrologue: () => insertStatementsAfterStandardPrologue,
            intersperse: () => intersperse,
            introducesArgumentsExoticObject: () => introducesArgumentsExoticObject,
            inverseJsxOptionMap: () => inverseJsxOptionMap,
            isAbstractConstructorSymbol: () => isAbstractConstructorSymbol,
            isAbstractModifier: () => isAbstractModifier,
            isAccessExpression: () => isAccessExpression,
            isAccessibilityModifier: () => isAccessibilityModifier,
            isAccessor: () => isAccessor,
            isAccessorModifier: () => isAccessorModifier,
            isAliasSymbolDeclaration: () => isAliasSymbolDeclaration,
            isAliasableExpression: () => isAliasableExpression,
            isAmbientModule: () => isAmbientModule,
            isAmbientPropertyDeclaration: () => isAmbientPropertyDeclaration,
            isAnonymousFunctionDefinition: () => isAnonymousFunctionDefinition,
            isAnyDirectorySeparator: () => isAnyDirectorySeparator,
            isAnyImportOrBareOrAccessedRequire: () => isAnyImportOrBareOrAccessedRequire,
            isAnyImportOrReExport: () => isAnyImportOrReExport,
            isAnyImportSyntax: () => isAnyImportSyntax,
            isAnySupportedFileExtension: () => isAnySupportedFileExtension,
            isApplicableVersionedTypesKey: () => isApplicableVersionedTypesKey,
            isArgumentExpressionOfElementAccess: () => isArgumentExpressionOfElementAccess,
            isArray: () => isArray,
            isArrayBindingElement: () => isArrayBindingElement,
            isArrayBindingOrAssignmentElement: () => isArrayBindingOrAssignmentElement,
            isArrayBindingOrAssignmentPattern: () => isArrayBindingOrAssignmentPattern,
            isArrayBindingPattern: () => isArrayBindingPattern,
            isArrayLiteralExpression: () => isArrayLiteralExpression,
            isArrayLiteralOrObjectLiteralDestructuringPattern: () => isArrayLiteralOrObjectLiteralDestructuringPattern,
            isArrayTypeNode: () => isArrayTypeNode,
            isArrowFunction: () => isArrowFunction,
            isAsExpression: () => isAsExpression,
            isAssertClause: () => isAssertClause,
            isAssertEntry: () => isAssertEntry,
            isAssertionExpression: () => isAssertionExpression,
            isAssertionKey: () => isAssertionKey,
            isAssertsKeyword: () => isAssertsKeyword,
            isAssignmentDeclaration: () => isAssignmentDeclaration,
            isAssignmentExpression: () => isAssignmentExpression,
            isAssignmentOperator: () => isAssignmentOperator,
            isAssignmentPattern: () => isAssignmentPattern,
            isAssignmentTarget: () => isAssignmentTarget,
            isAsteriskToken: () => isAsteriskToken,
            isAsyncFunction: () => isAsyncFunction,
            isAsyncModifier: () => isAsyncModifier,
            isAutoAccessorPropertyDeclaration: () => isAutoAccessorPropertyDeclaration,
            isAwaitExpression: () => isAwaitExpression,
            isAwaitKeyword: () => isAwaitKeyword,
            isBigIntLiteral: () => isBigIntLiteral,
            isBinaryExpression: () => isBinaryExpression,
            isBinaryOperatorToken: () => isBinaryOperatorToken,
            isBindableObjectDefinePropertyCall: () => isBindableObjectDefinePropertyCall,
            isBindableStaticAccessExpression: () => isBindableStaticAccessExpression,
            isBindableStaticElementAccessExpression: () => isBindableStaticElementAccessExpression,
            isBindableStaticNameExpression: () => isBindableStaticNameExpression,
            isBindingElement: () => isBindingElement,
            isBindingElementOfBareOrAccessedRequire: () => isBindingElementOfBareOrAccessedRequire,
            isBindingName: () => isBindingName,
            isBindingOrAssignmentElement: () => isBindingOrAssignmentElement,
            isBindingOrAssignmentPattern: () => isBindingOrAssignmentPattern,
            isBindingPattern: () => isBindingPattern,
            isBlock: () => isBlock,
            isBlockOrCatchScoped: () => isBlockOrCatchScoped,
            isBlockScope: () => isBlockScope,
            isBlockScopedContainerTopLevel: () => isBlockScopedContainerTopLevel,
            isBooleanLiteral: () => isBooleanLiteral,
            isBreakOrContinueStatement: () => isBreakOrContinueStatement,
            isBreakStatement: () => isBreakStatement,
            isBuildInfoFile: () => isBuildInfoFile,
            isBuilderProgram: () => isBuilderProgram2,
            isBundle: () => isBundle,
            isBundleFileTextLike: () => isBundleFileTextLike,
            isCallChain: () => isCallChain,
            isCallExpression: () => isCallExpression,
            isCallExpressionTarget: () => isCallExpressionTarget,
            isCallLikeExpression: () => isCallLikeExpression,
            isCallOrNewExpression: () => isCallOrNewExpression,
            isCallOrNewExpressionTarget: () => isCallOrNewExpressionTarget,
            isCallSignatureDeclaration: () => isCallSignatureDeclaration,
            isCallToHelper: () => isCallToHelper,
            isCaseBlock: () => isCaseBlock,
            isCaseClause: () => isCaseClause,
            isCaseKeyword: () => isCaseKeyword,
            isCaseOrDefaultClause: () => isCaseOrDefaultClause,
            isCatchClause: () => isCatchClause,
            isCatchClauseVariableDeclaration: () => isCatchClauseVariableDeclaration,
            isCatchClauseVariableDeclarationOrBindingElement: () => isCatchClauseVariableDeclarationOrBindingElement,
            isCheckJsEnabledForFile: () => isCheckJsEnabledForFile,
            isChildOfNodeWithKind: () => isChildOfNodeWithKind,
            isCircularBuildOrder: () => isCircularBuildOrder,
            isClassDeclaration: () => isClassDeclaration,
            isClassElement: () => isClassElement,
            isClassExpression: () => isClassExpression,
            isClassLike: () => isClassLike,
            isClassMemberModifier: () => isClassMemberModifier,
            isClassOrTypeElement: () => isClassOrTypeElement,
            isClassStaticBlockDeclaration: () => isClassStaticBlockDeclaration,
            isCollapsedRange: () => isCollapsedRange,
            isColonToken: () => isColonToken,
            isCommaExpression: () => isCommaExpression,
            isCommaListExpression: () => isCommaListExpression,
            isCommaSequence: () => isCommaSequence,
            isCommaToken: () => isCommaToken,
            isComment: () => isComment,
            isCommonJsExportPropertyAssignment: () => isCommonJsExportPropertyAssignment,
            isCommonJsExportedExpression: () => isCommonJsExportedExpression,
            isCompoundAssignment: () => isCompoundAssignment,
            isComputedNonLiteralName: () => isComputedNonLiteralName,
            isComputedPropertyName: () => isComputedPropertyName,
            isConciseBody: () => isConciseBody,
            isConditionalExpression: () => isConditionalExpression,
            isConditionalTypeNode: () => isConditionalTypeNode,
            isConstTypeReference: () => isConstTypeReference,
            isConstructSignatureDeclaration: () => isConstructSignatureDeclaration,
            isConstructorDeclaration: () => isConstructorDeclaration,
            isConstructorTypeNode: () => isConstructorTypeNode,
            isContextualKeyword: () => isContextualKeyword,
            isContinueStatement: () => isContinueStatement,
            isCustomPrologue: () => isCustomPrologue,
            isDebuggerStatement: () => isDebuggerStatement,
            isDeclaration: () => isDeclaration,
            isDeclarationBindingElement: () => isDeclarationBindingElement,
            isDeclarationFileName: () => isDeclarationFileName,
            isDeclarationName: () => isDeclarationName,
            isDeclarationNameOfEnumOrNamespace: () => isDeclarationNameOfEnumOrNamespace,
            isDeclarationReadonly: () => isDeclarationReadonly,
            isDeclarationStatement: () => isDeclarationStatement,
            isDeclarationWithTypeParameterChildren: () => isDeclarationWithTypeParameterChildren,
            isDeclarationWithTypeParameters: () => isDeclarationWithTypeParameters,
            isDecorator: () => isDecorator,
            isDecoratorTarget: () => isDecoratorTarget,
            isDefaultClause: () => isDefaultClause,
            isDefaultImport: () => isDefaultImport,
            isDefaultModifier: () => isDefaultModifier,
            isDefaultedExpandoInitializer: () => isDefaultedExpandoInitializer,
            isDeleteExpression: () => isDeleteExpression,
            isDeleteTarget: () => isDeleteTarget,
            isDeprecatedDeclaration: () => isDeprecatedDeclaration,
            isDestructuringAssignment: () => isDestructuringAssignment,
            isDiagnosticWithLocation: () => isDiagnosticWithLocation,
            isDiskPathRoot: () => isDiskPathRoot,
            isDoStatement: () => isDoStatement,
            isDotDotDotToken: () => isDotDotDotToken,
            isDottedName: () => isDottedName,
            isDynamicName: () => isDynamicName,
            isESSymbolIdentifier: () => isESSymbolIdentifier,
            isEffectiveExternalModule: () => isEffectiveExternalModule,
            isEffectiveModuleDeclaration: () => isEffectiveModuleDeclaration,
            isEffectiveStrictModeSourceFile: () => isEffectiveStrictModeSourceFile,
            isElementAccessChain: () => isElementAccessChain,
            isElementAccessExpression: () => isElementAccessExpression,
            isEmittedFileOfProgram: () => isEmittedFileOfProgram,
            isEmptyArrayLiteral: () => isEmptyArrayLiteral,
            isEmptyBindingElement: () => isEmptyBindingElement,
            isEmptyBindingPattern: () => isEmptyBindingPattern,
            isEmptyObjectLiteral: () => isEmptyObjectLiteral,
            isEmptyStatement: () => isEmptyStatement,
            isEmptyStringLiteral: () => isEmptyStringLiteral,
            isEndOfDeclarationMarker: () => isEndOfDeclarationMarker,
            isEntityName: () => isEntityName,
            isEntityNameExpression: () => isEntityNameExpression,
            isEnumConst: () => isEnumConst,
            isEnumDeclaration: () => isEnumDeclaration,
            isEnumMember: () => isEnumMember,
            isEqualityOperatorKind: () => isEqualityOperatorKind,
            isEqualsGreaterThanToken: () => isEqualsGreaterThanToken,
            isExclamationToken: () => isExclamationToken,
            isExcludedFile: () => isExcludedFile,
            isExclusivelyTypeOnlyImportOrExport: () => isExclusivelyTypeOnlyImportOrExport,
            isExportAssignment: () => isExportAssignment,
            isExportDeclaration: () => isExportDeclaration,
            isExportModifier: () => isExportModifier,
            isExportName: () => isExportName,
            isExportNamespaceAsDefaultDeclaration: () => isExportNamespaceAsDefaultDeclaration,
            isExportOrDefaultModifier: () => isExportOrDefaultModifier,
            isExportSpecifier: () => isExportSpecifier,
            isExportsIdentifier: () => isExportsIdentifier,
            isExportsOrModuleExportsOrAlias: () => isExportsOrModuleExportsOrAlias,
            isExpression: () => isExpression,
            isExpressionNode: () => isExpressionNode,
            isExpressionOfExternalModuleImportEqualsDeclaration: () => isExpressionOfExternalModuleImportEqualsDeclaration,
            isExpressionOfOptionalChainRoot: () => isExpressionOfOptionalChainRoot,
            isExpressionStatement: () => isExpressionStatement,
            isExpressionWithTypeArguments: () => isExpressionWithTypeArguments,
            isExpressionWithTypeArgumentsInClassExtendsClause: () => isExpressionWithTypeArgumentsInClassExtendsClause,
            isExternalModule: () => isExternalModule,
            isExternalModuleAugmentation: () => isExternalModuleAugmentation,
            isExternalModuleImportEqualsDeclaration: () => isExternalModuleImportEqualsDeclaration,
            isExternalModuleIndicator: () => isExternalModuleIndicator,
            isExternalModuleNameRelative: () => isExternalModuleNameRelative,
            isExternalModuleReference: () => isExternalModuleReference,
            isExternalModuleSymbol: () => isExternalModuleSymbol,
            isExternalOrCommonJsModule: () => isExternalOrCommonJsModule,
            isFileLevelUniqueName: () => isFileLevelUniqueName,
            isFileProbablyExternalModule: () => isFileProbablyExternalModule,
            isFirstDeclarationOfSymbolParameter: () => isFirstDeclarationOfSymbolParameter,
            isFixablePromiseHandler: () => isFixablePromiseHandler,
            isForInOrOfStatement: () => isForInOrOfStatement,
            isForInStatement: () => isForInStatement,
            isForInitializer: () => isForInitializer,
            isForOfStatement: () => isForOfStatement,
            isForStatement: () => isForStatement,
            isFunctionBlock: () => isFunctionBlock,
            isFunctionBody: () => isFunctionBody,
            isFunctionDeclaration: () => isFunctionDeclaration,
            isFunctionExpression: () => isFunctionExpression,
            isFunctionExpressionOrArrowFunction: () => isFunctionExpressionOrArrowFunction,
            isFunctionLike: () => isFunctionLike,
            isFunctionLikeDeclaration: () => isFunctionLikeDeclaration,
            isFunctionLikeKind: () => isFunctionLikeKind,
            isFunctionLikeOrClassStaticBlockDeclaration: () => isFunctionLikeOrClassStaticBlockDeclaration,
            isFunctionOrConstructorTypeNode: () => isFunctionOrConstructorTypeNode,
            isFunctionOrModuleBlock: () => isFunctionOrModuleBlock,
            isFunctionSymbol: () => isFunctionSymbol,
            isFunctionTypeNode: () => isFunctionTypeNode,
            isFutureReservedKeyword: () => isFutureReservedKeyword,
            isGeneratedIdentifier: () => isGeneratedIdentifier,
            isGeneratedPrivateIdentifier: () => isGeneratedPrivateIdentifier,
            isGetAccessor: () => isGetAccessor,
            isGetAccessorDeclaration: () => isGetAccessorDeclaration,
            isGetOrSetAccessorDeclaration: () => isGetOrSetAccessorDeclaration,
            isGlobalDeclaration: () => isGlobalDeclaration,
            isGlobalScopeAugmentation: () => isGlobalScopeAugmentation,
            isGrammarError: () => isGrammarError,
            isHeritageClause: () => isHeritageClause,
            isHoistedFunction: () => isHoistedFunction,
            isHoistedVariableStatement: () => isHoistedVariableStatement,
            isIdentifier: () => isIdentifier,
            isIdentifierANonContextualKeyword: () => isIdentifierANonContextualKeyword,
            isIdentifierName: () => isIdentifierName,
            isIdentifierOrThisTypeNode: () => isIdentifierOrThisTypeNode,
            isIdentifierPart: () => isIdentifierPart,
            isIdentifierStart: () => isIdentifierStart,
            isIdentifierText: () => isIdentifierText,
            isIdentifierTypePredicate: () => isIdentifierTypePredicate,
            isIdentifierTypeReference: () => isIdentifierTypeReference,
            isIfStatement: () => isIfStatement,
            isIgnoredFileFromWildCardWatching: () => isIgnoredFileFromWildCardWatching,
            isImplicitGlob: () => isImplicitGlob,
            isImportCall: () => isImportCall,
            isImportClause: () => isImportClause,
            isImportDeclaration: () => isImportDeclaration,
            isImportEqualsDeclaration: () => isImportEqualsDeclaration,
            isImportKeyword: () => isImportKeyword,
            isImportMeta: () => isImportMeta,
            isImportOrExportSpecifier: () => isImportOrExportSpecifier,
            isImportOrExportSpecifierName: () => isImportOrExportSpecifierName,
            isImportSpecifier: () => isImportSpecifier,
            isImportTypeAssertionContainer: () => isImportTypeAssertionContainer,
            isImportTypeNode: () => isImportTypeNode,
            isImportableFile: () => isImportableFile,
            isInComment: () => isInComment,
            isInExpressionContext: () => isInExpressionContext,
            isInJSDoc: () => isInJSDoc,
            isInJSFile: () => isInJSFile,
            isInJSXText: () => isInJSXText,
            isInJsonFile: () => isInJsonFile,
            isInNonReferenceComment: () => isInNonReferenceComment,
            isInReferenceComment: () => isInReferenceComment,
            isInRightSideOfInternalImportEqualsDeclaration: () => isInRightSideOfInternalImportEqualsDeclaration,
            isInString: () => isInString,
            isInTemplateString: () => isInTemplateString,
            isInTopLevelContext: () => isInTopLevelContext,
            isIncrementalCompilation: () => isIncrementalCompilation,
            isIndexSignatureDeclaration: () => isIndexSignatureDeclaration,
            isIndexedAccessTypeNode: () => isIndexedAccessTypeNode,
            isInferTypeNode: () => isInferTypeNode,
            isInfinityOrNaNString: () => isInfinityOrNaNString,
            isInitializedProperty: () => isInitializedProperty,
            isInitializedVariable: () => isInitializedVariable,
            isInsideJsxElement: () => isInsideJsxElement,
            isInsideJsxElementOrAttribute: () => isInsideJsxElementOrAttribute,
            isInsideNodeModules: () => isInsideNodeModules,
            isInsideTemplateLiteral: () => isInsideTemplateLiteral,
            isInstantiatedModule: () => isInstantiatedModule,
            isInterfaceDeclaration: () => isInterfaceDeclaration,
            isInternalDeclaration: () => isInternalDeclaration,
            isInternalModuleImportEqualsDeclaration: () => isInternalModuleImportEqualsDeclaration,
            isInternalName: () => isInternalName,
            isIntersectionTypeNode: () => isIntersectionTypeNode,
            isIntrinsicJsxName: () => isIntrinsicJsxName,
            isIterationStatement: () => isIterationStatement,
            isJSDoc: () => isJSDoc,
            isJSDocAllType: () => isJSDocAllType,
            isJSDocAugmentsTag: () => isJSDocAugmentsTag,
            isJSDocAuthorTag: () => isJSDocAuthorTag,
            isJSDocCallbackTag: () => isJSDocCallbackTag,
            isJSDocClassTag: () => isJSDocClassTag,
            isJSDocCommentContainingNode: () => isJSDocCommentContainingNode,
            isJSDocConstructSignature: () => isJSDocConstructSignature,
            isJSDocDeprecatedTag: () => isJSDocDeprecatedTag,
            isJSDocEnumTag: () => isJSDocEnumTag,
            isJSDocFunctionType: () => isJSDocFunctionType,
            isJSDocImplementsTag: () => isJSDocImplementsTag,
            isJSDocIndexSignature: () => isJSDocIndexSignature,
            isJSDocLikeText: () => isJSDocLikeText,
            isJSDocLink: () => isJSDocLink,
            isJSDocLinkCode: () => isJSDocLinkCode,
            isJSDocLinkLike: () => isJSDocLinkLike,
            isJSDocLinkPlain: () => isJSDocLinkPlain,
            isJSDocMemberName: () => isJSDocMemberName,
            isJSDocNameReference: () => isJSDocNameReference,
            isJSDocNamepathType: () => isJSDocNamepathType,
            isJSDocNamespaceBody: () => isJSDocNamespaceBody,
            isJSDocNode: () => isJSDocNode,
            isJSDocNonNullableType: () => isJSDocNonNullableType,
            isJSDocNullableType: () => isJSDocNullableType,
            isJSDocOptionalParameter: () => isJSDocOptionalParameter,
            isJSDocOptionalType: () => isJSDocOptionalType,
            isJSDocOverloadTag: () => isJSDocOverloadTag,
            isJSDocOverrideTag: () => isJSDocOverrideTag,
            isJSDocParameterTag: () => isJSDocParameterTag,
            isJSDocPrivateTag: () => isJSDocPrivateTag,
            isJSDocPropertyLikeTag: () => isJSDocPropertyLikeTag,
            isJSDocPropertyTag: () => isJSDocPropertyTag,
            isJSDocProtectedTag: () => isJSDocProtectedTag,
            isJSDocPublicTag: () => isJSDocPublicTag,
            isJSDocReadonlyTag: () => isJSDocReadonlyTag,
            isJSDocReturnTag: () => isJSDocReturnTag,
            isJSDocSatisfiesExpression: () => isJSDocSatisfiesExpression,
            isJSDocSatisfiesTag: () => isJSDocSatisfiesTag,
            isJSDocSeeTag: () => isJSDocSeeTag,
            isJSDocSignature: () => isJSDocSignature,
            isJSDocTag: () => isJSDocTag,
            isJSDocTemplateTag: () => isJSDocTemplateTag,
            isJSDocThisTag: () => isJSDocThisTag,
            isJSDocThrowsTag: () => isJSDocThrowsTag,
            isJSDocTypeAlias: () => isJSDocTypeAlias,
            isJSDocTypeAssertion: () => isJSDocTypeAssertion,
            isJSDocTypeExpression: () => isJSDocTypeExpression,
            isJSDocTypeLiteral: () => isJSDocTypeLiteral,
            isJSDocTypeTag: () => isJSDocTypeTag,
            isJSDocTypedefTag: () => isJSDocTypedefTag,
            isJSDocUnknownTag: () => isJSDocUnknownTag,
            isJSDocUnknownType: () => isJSDocUnknownType,
            isJSDocVariadicType: () => isJSDocVariadicType,
            isJSXTagName: () => isJSXTagName,
            isJsonEqual: () => isJsonEqual,
            isJsonSourceFile: () => isJsonSourceFile,
            isJsxAttribute: () => isJsxAttribute,
            isJsxAttributeLike: () => isJsxAttributeLike,
            isJsxAttributes: () => isJsxAttributes,
            isJsxChild: () => isJsxChild,
            isJsxClosingElement: () => isJsxClosingElement,
            isJsxClosingFragment: () => isJsxClosingFragment,
            isJsxElement: () => isJsxElement,
            isJsxExpression: () => isJsxExpression,
            isJsxFragment: () => isJsxFragment,
            isJsxOpeningElement: () => isJsxOpeningElement,
            isJsxOpeningFragment: () => isJsxOpeningFragment,
            isJsxOpeningLikeElement: () => isJsxOpeningLikeElement,
            isJsxOpeningLikeElementTagName: () => isJsxOpeningLikeElementTagName,
            isJsxSelfClosingElement: () => isJsxSelfClosingElement,
            isJsxSpreadAttribute: () => isJsxSpreadAttribute,
            isJsxTagNameExpression: () => isJsxTagNameExpression,
            isJsxText: () => isJsxText,
            isJumpStatementTarget: () => isJumpStatementTarget,
            isKeyword: () => isKeyword,
            isKnownSymbol: () => isKnownSymbol,
            isLabelName: () => isLabelName,
            isLabelOfLabeledStatement: () => isLabelOfLabeledStatement,
            isLabeledStatement: () => isLabeledStatement,
            isLateVisibilityPaintedStatement: () => isLateVisibilityPaintedStatement,
            isLeftHandSideExpression: () => isLeftHandSideExpression,
            isLeftHandSideOfAssignment: () => isLeftHandSideOfAssignment,
            isLet: () => isLet,
            isLineBreak: () => isLineBreak,
            isLiteralComputedPropertyDeclarationName: () => isLiteralComputedPropertyDeclarationName,
            isLiteralExpression: () => isLiteralExpression,
            isLiteralExpressionOfObject: () => isLiteralExpressionOfObject,
            isLiteralImportTypeNode: () => isLiteralImportTypeNode,
            isLiteralKind: () => isLiteralKind,
            isLiteralLikeAccess: () => isLiteralLikeAccess,
            isLiteralLikeElementAccess: () => isLiteralLikeElementAccess,
            isLiteralNameOfPropertyDeclarationOrIndexAccess: () => isLiteralNameOfPropertyDeclarationOrIndexAccess,
            isLiteralTypeLikeExpression: () => isLiteralTypeLikeExpression,
            isLiteralTypeLiteral: () => isLiteralTypeLiteral,
            isLiteralTypeNode: () => isLiteralTypeNode,
            isLocalName: () => isLocalName,
            isLogicalOperator: () => isLogicalOperator,
            isLogicalOrCoalescingAssignmentExpression: () => isLogicalOrCoalescingAssignmentExpression,
            isLogicalOrCoalescingAssignmentOperator: () => isLogicalOrCoalescingAssignmentOperator,
            isLogicalOrCoalescingBinaryExpression: () => isLogicalOrCoalescingBinaryExpression,
            isLogicalOrCoalescingBinaryOperator: () => isLogicalOrCoalescingBinaryOperator,
            isMappedTypeNode: () => isMappedTypeNode,
            isMemberName: () => isMemberName,
            isMergeDeclarationMarker: () => isMergeDeclarationMarker,
            isMetaProperty: () => isMetaProperty,
            isMethodDeclaration: () => isMethodDeclaration,
            isMethodOrAccessor: () => isMethodOrAccessor,
            isMethodSignature: () => isMethodSignature,
            isMinusToken: () => isMinusToken,
            isMissingDeclaration: () => isMissingDeclaration,
            isModifier: () => isModifier,
            isModifierKind: () => isModifierKind,
            isModifierLike: () => isModifierLike,
            isModuleAugmentationExternal: () => isModuleAugmentationExternal,
            isModuleBlock: () => isModuleBlock,
            isModuleBody: () => isModuleBody,
            isModuleDeclaration: () => isModuleDeclaration,
            isModuleExportsAccessExpression: () => isModuleExportsAccessExpression,
            isModuleIdentifier: () => isModuleIdentifier,
            isModuleName: () => isModuleName,
            isModuleOrEnumDeclaration: () => isModuleOrEnumDeclaration,
            isModuleReference: () => isModuleReference,
            isModuleSpecifierLike: () => isModuleSpecifierLike,
            isModuleWithStringLiteralName: () => isModuleWithStringLiteralName,
            isNameOfFunctionDeclaration: () => isNameOfFunctionDeclaration,
            isNameOfModuleDeclaration: () => isNameOfModuleDeclaration,
            isNamedClassElement: () => isNamedClassElement,
            isNamedDeclaration: () => isNamedDeclaration,
            isNamedEvaluation: () => isNamedEvaluation,
            isNamedEvaluationSource: () => isNamedEvaluationSource,
            isNamedExportBindings: () => isNamedExportBindings,
            isNamedExports: () => isNamedExports,
            isNamedImportBindings: () => isNamedImportBindings,
            isNamedImports: () => isNamedImports,
            isNamedImportsOrExports: () => isNamedImportsOrExports,
            isNamedTupleMember: () => isNamedTupleMember,
            isNamespaceBody: () => isNamespaceBody,
            isNamespaceExport: () => isNamespaceExport,
            isNamespaceExportDeclaration: () => isNamespaceExportDeclaration,
            isNamespaceImport: () => isNamespaceImport,
            isNamespaceReexportDeclaration: () => isNamespaceReexportDeclaration,
            isNewExpression: () => isNewExpression,
            isNewExpressionTarget: () => isNewExpressionTarget,
            isNightly: () => isNightly,
            isNoSubstitutionTemplateLiteral: () => isNoSubstitutionTemplateLiteral,
            isNode: () => isNode,
            isNodeArray: () => isNodeArray,
            isNodeArrayMultiLine: () => isNodeArrayMultiLine,
            isNodeDescendantOf: () => isNodeDescendantOf,
            isNodeKind: () => isNodeKind,
            isNodeLikeSystem: () => isNodeLikeSystem,
            isNodeModulesDirectory: () => isNodeModulesDirectory,
            isNodeWithPossibleHoistedDeclaration: () => isNodeWithPossibleHoistedDeclaration,
            isNonContextualKeyword: () => isNonContextualKeyword,
            isNonExportDefaultModifier: () => isNonExportDefaultModifier,
            isNonGlobalAmbientModule: () => isNonGlobalAmbientModule,
            isNonGlobalDeclaration: () => isNonGlobalDeclaration,
            isNonNullAccess: () => isNonNullAccess,
            isNonNullChain: () => isNonNullChain,
            isNonNullExpression: () => isNonNullExpression,
            isNonStaticMethodOrAccessorWithPrivateName: () => isNonStaticMethodOrAccessorWithPrivateName,
            isNotEmittedOrPartiallyEmittedNode: () => isNotEmittedOrPartiallyEmittedNode,
            isNotEmittedStatement: () => isNotEmittedStatement,
            isNullishCoalesce: () => isNullishCoalesce,
            isNumber: () => isNumber,
            isNumericLiteral: () => isNumericLiteral,
            isNumericLiteralName: () => isNumericLiteralName,
            isObjectBindingElementWithoutPropertyName: () => isObjectBindingElementWithoutPropertyName,
            isObjectBindingOrAssignmentElement: () => isObjectBindingOrAssignmentElement,
            isObjectBindingOrAssignmentPattern: () => isObjectBindingOrAssignmentPattern,
            isObjectBindingPattern: () => isObjectBindingPattern,
            isObjectLiteralElement: () => isObjectLiteralElement,
            isObjectLiteralElementLike: () => isObjectLiteralElementLike,
            isObjectLiteralExpression: () => isObjectLiteralExpression,
            isObjectLiteralMethod: () => isObjectLiteralMethod,
            isObjectLiteralOrClassExpressionMethodOrAccessor: () => isObjectLiteralOrClassExpressionMethodOrAccessor,
            isObjectTypeDeclaration: () => isObjectTypeDeclaration,
            isOctalDigit: () => isOctalDigit,
            isOmittedExpression: () => isOmittedExpression,
            isOptionalChain: () => isOptionalChain,
            isOptionalChainRoot: () => isOptionalChainRoot,
            isOptionalDeclaration: () => isOptionalDeclaration,
            isOptionalJSDocPropertyLikeTag: () => isOptionalJSDocPropertyLikeTag,
            isOptionalTypeNode: () => isOptionalTypeNode,
            isOuterExpression: () => isOuterExpression,
            isOutermostOptionalChain: () => isOutermostOptionalChain,
            isOverrideModifier: () => isOverrideModifier,
            isPackedArrayLiteral: () => isPackedArrayLiteral,
            isParameter: () => isParameter,
            isParameterDeclaration: () => isParameterDeclaration,
            isParameterOrCatchClauseVariable: () => isParameterOrCatchClauseVariable,
            isParameterPropertyDeclaration: () => isParameterPropertyDeclaration,
            isParameterPropertyModifier: () => isParameterPropertyModifier,
            isParenthesizedExpression: () => isParenthesizedExpression,
            isParenthesizedTypeNode: () => isParenthesizedTypeNode,
            isParseTreeNode: () => isParseTreeNode,
            isPartOfTypeNode: () => isPartOfTypeNode,
            isPartOfTypeQuery: () => isPartOfTypeQuery,
            isPartiallyEmittedExpression: () => isPartiallyEmittedExpression,
            isPatternMatch: () => isPatternMatch,
            isPinnedComment: () => isPinnedComment,
            isPlainJsFile: () => isPlainJsFile,
            isPlusToken: () => isPlusToken,
            isPossiblyTypeArgumentPosition: () => isPossiblyTypeArgumentPosition,
            isPostfixUnaryExpression: () => isPostfixUnaryExpression,
            isPrefixUnaryExpression: () => isPrefixUnaryExpression,
            isPrivateIdentifier: () => isPrivateIdentifier,
            isPrivateIdentifierClassElementDeclaration: () => isPrivateIdentifierClassElementDeclaration,
            isPrivateIdentifierPropertyAccessExpression: () => isPrivateIdentifierPropertyAccessExpression,
            isPrivateIdentifierSymbol: () => isPrivateIdentifierSymbol,
            isProgramBundleEmitBuildInfo: () => isProgramBundleEmitBuildInfo,
            isProgramUptoDate: () => isProgramUptoDate,
            isPrologueDirective: () => isPrologueDirective,
            isPropertyAccessChain: () => isPropertyAccessChain,
            isPropertyAccessEntityNameExpression: () => isPropertyAccessEntityNameExpression,
            isPropertyAccessExpression: () => isPropertyAccessExpression,
            isPropertyAccessOrQualifiedName: () => isPropertyAccessOrQualifiedName,
            isPropertyAccessOrQualifiedNameOrImportTypeNode: () => isPropertyAccessOrQualifiedNameOrImportTypeNode,
            isPropertyAssignment: () => isPropertyAssignment,
            isPropertyDeclaration: () => isPropertyDeclaration,
            isPropertyName: () => isPropertyName,
            isPropertyNameLiteral: () => isPropertyNameLiteral,
            isPropertySignature: () => isPropertySignature,
            isProtoSetter: () => isProtoSetter,
            isPrototypeAccess: () => isPrototypeAccess,
            isPrototypePropertyAssignment: () => isPrototypePropertyAssignment,
            isPunctuation: () => isPunctuation,
            isPushOrUnshiftIdentifier: () => isPushOrUnshiftIdentifier,
            isQualifiedName: () => isQualifiedName,
            isQuestionDotToken: () => isQuestionDotToken,
            isQuestionOrExclamationToken: () => isQuestionOrExclamationToken,
            isQuestionOrPlusOrMinusToken: () => isQuestionOrPlusOrMinusToken,
            isQuestionToken: () => isQuestionToken,
            isRawSourceMap: () => isRawSourceMap,
            isReadonlyKeyword: () => isReadonlyKeyword,
            isReadonlyKeywordOrPlusOrMinusToken: () => isReadonlyKeywordOrPlusOrMinusToken,
            isRecognizedTripleSlashComment: () => isRecognizedTripleSlashComment,
            isReferenceFileLocation: () => isReferenceFileLocation,
            isReferencedFile: () => isReferencedFile,
            isRegularExpressionLiteral: () => isRegularExpressionLiteral,
            isRequireCall: () => isRequireCall,
            isRequireVariableStatement: () => isRequireVariableStatement,
            isRestParameter: () => isRestParameter,
            isRestTypeNode: () => isRestTypeNode,
            isReturnStatement: () => isReturnStatement,
            isReturnStatementWithFixablePromiseHandler: () => isReturnStatementWithFixablePromiseHandler,
            isRightSideOfAccessExpression: () => isRightSideOfAccessExpression,
            isRightSideOfPropertyAccess: () => isRightSideOfPropertyAccess,
            isRightSideOfQualifiedName: () => isRightSideOfQualifiedName,
            isRightSideOfQualifiedNameOrPropertyAccess: () => isRightSideOfQualifiedNameOrPropertyAccess,
            isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName: () => isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName,
            isRootedDiskPath: () => isRootedDiskPath,
            isSameEntityName: () => isSameEntityName,
            isSatisfiesExpression: () => isSatisfiesExpression,
            isScopeMarker: () => isScopeMarker,
            isSemicolonClassElement: () => isSemicolonClassElement,
            isSetAccessor: () => isSetAccessor,
            isSetAccessorDeclaration: () => isSetAccessorDeclaration,
            isShebangTrivia: () => isShebangTrivia,
            isShorthandAmbientModuleSymbol: () => isShorthandAmbientModuleSymbol,
            isShorthandPropertyAssignment: () => isShorthandPropertyAssignment,
            isSignedNumericLiteral: () => isSignedNumericLiteral,
            isSimpleCopiableExpression: () => isSimpleCopiableExpression,
            isSimpleInlineableExpression: () => isSimpleInlineableExpression,
            isSingleOrDoubleQuote: () => isSingleOrDoubleQuote,
            isSourceFile: () => isSourceFile,
            isSourceFileFromLibrary: () => isSourceFileFromLibrary,
            isSourceFileJS: () => isSourceFileJS,
            isSourceFileNotJS: () => isSourceFileNotJS,
            isSourceFileNotJson: () => isSourceFileNotJson,
            isSourceMapping: () => isSourceMapping,
            isSpecialPropertyDeclaration: () => isSpecialPropertyDeclaration,
            isSpreadAssignment: () => isSpreadAssignment,
            isSpreadElement: () => isSpreadElement,
            isStatement: () => isStatement,
            isStatementButNotDeclaration: () => isStatementButNotDeclaration,
            isStatementOrBlock: () => isStatementOrBlock,
            isStatementWithLocals: () => isStatementWithLocals,
            isStatic: () => isStatic,
            isStaticModifier: () => isStaticModifier,
            isString: () => isString,
            isStringAKeyword: () => isStringAKeyword,
            isStringANonContextualKeyword: () => isStringANonContextualKeyword,
            isStringAndEmptyAnonymousObjectIntersection: () => isStringAndEmptyAnonymousObjectIntersection,
            isStringDoubleQuoted: () => isStringDoubleQuoted,
            isStringLiteral: () => isStringLiteral,
            isStringLiteralLike: () => isStringLiteralLike,
            isStringLiteralOrJsxExpression: () => isStringLiteralOrJsxExpression,
            isStringLiteralOrTemplate: () => isStringLiteralOrTemplate,
            isStringOrNumericLiteralLike: () => isStringOrNumericLiteralLike,
            isStringOrRegularExpressionOrTemplateLiteral: () => isStringOrRegularExpressionOrTemplateLiteral,
            isStringTextContainingNode: () => isStringTextContainingNode,
            isSuperCall: () => isSuperCall,
            isSuperKeyword: () => isSuperKeyword,
            isSuperOrSuperProperty: () => isSuperOrSuperProperty,
            isSuperProperty: () => isSuperProperty,
            isSupportedSourceFileName: () => isSupportedSourceFileName,
            isSwitchStatement: () => isSwitchStatement,
            isSyntaxList: () => isSyntaxList,
            isSyntheticExpression: () => isSyntheticExpression,
            isSyntheticReference: () => isSyntheticReference,
            isTagName: () => isTagName,
            isTaggedTemplateExpression: () => isTaggedTemplateExpression,
            isTaggedTemplateTag: () => isTaggedTemplateTag,
            isTemplateExpression: () => isTemplateExpression,
            isTemplateHead: () => isTemplateHead,
            isTemplateLiteral: () => isTemplateLiteral,
            isTemplateLiteralKind: () => isTemplateLiteralKind,
            isTemplateLiteralToken: () => isTemplateLiteralToken,
            isTemplateLiteralTypeNode: () => isTemplateLiteralTypeNode,
            isTemplateLiteralTypeSpan: () => isTemplateLiteralTypeSpan,
            isTemplateMiddle: () => isTemplateMiddle,
            isTemplateMiddleOrTemplateTail: () => isTemplateMiddleOrTemplateTail,
            isTemplateSpan: () => isTemplateSpan,
            isTemplateTail: () => isTemplateTail,
            isTextWhiteSpaceLike: () => isTextWhiteSpaceLike,
            isThis: () => isThis,
            isThisContainerOrFunctionBlock: () => isThisContainerOrFunctionBlock,
            isThisIdentifier: () => isThisIdentifier,
            isThisInTypeQuery: () => isThisInTypeQuery,
            isThisInitializedDeclaration: () => isThisInitializedDeclaration,
            isThisInitializedObjectBindingExpression: () => isThisInitializedObjectBindingExpression,
            isThisProperty: () => isThisProperty,
            isThisTypeNode: () => isThisTypeNode,
            isThisTypeParameter: () => isThisTypeParameter,
            isThisTypePredicate: () => isThisTypePredicate,
            isThrowStatement: () => isThrowStatement,
            isToken: () => isToken,
            isTokenKind: () => isTokenKind,
            isTraceEnabled: () => isTraceEnabled,
            isTransientSymbol: () => isTransientSymbol,
            isTrivia: () => isTrivia,
            isTryStatement: () => isTryStatement,
            isTupleTypeNode: () => isTupleTypeNode,
            isTypeAlias: () => isTypeAlias,
            isTypeAliasDeclaration: () => isTypeAliasDeclaration,
            isTypeAssertionExpression: () => isTypeAssertionExpression,
            isTypeDeclaration: () => isTypeDeclaration,
            isTypeElement: () => isTypeElement,
            isTypeKeyword: () => isTypeKeyword,
            isTypeKeywordToken: () => isTypeKeywordToken,
            isTypeKeywordTokenOrIdentifier: () => isTypeKeywordTokenOrIdentifier,
            isTypeLiteralNode: () => isTypeLiteralNode,
            isTypeNode: () => isTypeNode,
            isTypeNodeKind: () => isTypeNodeKind,
            isTypeOfExpression: () => isTypeOfExpression,
            isTypeOnlyExportDeclaration: () => isTypeOnlyExportDeclaration,
            isTypeOnlyImportDeclaration: () => isTypeOnlyImportDeclaration,
            isTypeOnlyImportOrExportDeclaration: () => isTypeOnlyImportOrExportDeclaration,
            isTypeOperatorNode: () => isTypeOperatorNode,
            isTypeParameterDeclaration: () => isTypeParameterDeclaration,
            isTypePredicateNode: () => isTypePredicateNode,
            isTypeQueryNode: () => isTypeQueryNode,
            isTypeReferenceNode: () => isTypeReferenceNode,
            isTypeReferenceType: () => isTypeReferenceType,
            isUMDExportSymbol: () => isUMDExportSymbol,
            isUnaryExpression: () => isUnaryExpression,
            isUnaryExpressionWithWrite: () => isUnaryExpressionWithWrite,
            isUnicodeIdentifierStart: () => isUnicodeIdentifierStart,
            isUnionTypeNode: () => isUnionTypeNode,
            isUnparsedNode: () => isUnparsedNode,
            isUnparsedPrepend: () => isUnparsedPrepend,
            isUnparsedSource: () => isUnparsedSource,
            isUnparsedTextLike: () => isUnparsedTextLike,
            isUrl: () => isUrl,
            isValidBigIntString: () => isValidBigIntString,
            isValidESSymbolDeclaration: () => isValidESSymbolDeclaration,
            isValidTypeOnlyAliasUseSite: () => isValidTypeOnlyAliasUseSite,
            isValueSignatureDeclaration: () => isValueSignatureDeclaration,
            isVarConst: () => isVarConst,
            isVariableDeclaration: () => isVariableDeclaration,
            isVariableDeclarationInVariableStatement: () => isVariableDeclarationInVariableStatement,
            isVariableDeclarationInitializedToBareOrAccessedRequire: () => isVariableDeclarationInitializedToBareOrAccessedRequire,
            isVariableDeclarationInitializedToRequire: () => isVariableDeclarationInitializedToRequire,
            isVariableDeclarationList: () => isVariableDeclarationList,
            isVariableLike: () => isVariableLike,
            isVariableLikeOrAccessor: () => isVariableLikeOrAccessor,
            isVariableStatement: () => isVariableStatement,
            isVoidExpression: () => isVoidExpression,
            isWatchSet: () => isWatchSet,
            isWhileStatement: () => isWhileStatement,
            isWhiteSpaceLike: () => isWhiteSpaceLike,
            isWhiteSpaceSingleLine: () => isWhiteSpaceSingleLine,
            isWithStatement: () => isWithStatement,
            isWriteAccess: () => isWriteAccess,
            isWriteOnlyAccess: () => isWriteOnlyAccess,
            isYieldExpression: () => isYieldExpression,
            jsxModeNeedsExplicitImport: () => jsxModeNeedsExplicitImport,
            keywordPart: () => keywordPart,
            last: () => last,
            lastOrUndefined: () => lastOrUndefined,
            length: () => length,
            libMap: () => libMap,
            libs: () => libs,
            lineBreakPart: () => lineBreakPart,
            linkNamePart: () => linkNamePart,
            linkPart: () => linkPart,
            linkTextPart: () => linkTextPart,
            listFiles: () => listFiles,
            loadModuleFromGlobalCache: () => loadModuleFromGlobalCache,
            loadWithModeAwareCache: () => loadWithModeAwareCache,
            makeIdentifierFromModuleName: () => makeIdentifierFromModuleName,
            makeImport: () => makeImport,
            makeImportIfNecessary: () => makeImportIfNecessary,
            makeStringLiteral: () => makeStringLiteral,
            mangleScopedPackageName: () => mangleScopedPackageName,
            map: () => map,
            mapAllOrFail: () => mapAllOrFail,
            mapDefined: () => mapDefined,
            mapDefinedEntries: () => mapDefinedEntries,
            mapDefinedIterator: () => mapDefinedIterator,
            mapEntries: () => mapEntries,
            mapIterator: () => mapIterator,
            mapOneOrMany: () => mapOneOrMany,
            mapToDisplayParts: () => mapToDisplayParts,
            matchFiles: () => matchFiles,
            matchPatternOrExact: () => matchPatternOrExact,
            matchedText: () => matchedText,
            matchesExclude: () => matchesExclude,
            maybeBind: () => maybeBind,
            maybeSetLocalizedDiagnosticMessages: () => maybeSetLocalizedDiagnosticMessages,
            memoize: () => memoize,
            memoizeCached: () => memoizeCached,
            memoizeOne: () => memoizeOne,
            memoizeWeak: () => memoizeWeak,
            metadataHelper: () => metadataHelper,
            min: () => min,
            minAndMax: () => minAndMax,
            missingFileModifiedTime: () => missingFileModifiedTime,
            modifierToFlag: () => modifierToFlag,
            modifiersToFlags: () => modifiersToFlags,
            moduleOptionDeclaration: () => moduleOptionDeclaration,
            moduleResolutionIsEqualTo: () => moduleResolutionIsEqualTo,
            moduleResolutionNameAndModeGetter: () => moduleResolutionNameAndModeGetter,
            moduleResolutionOptionDeclarations: () => moduleResolutionOptionDeclarations,
            moduleResolutionSupportsPackageJsonExportsAndImports: () => moduleResolutionSupportsPackageJsonExportsAndImports,
            moduleResolutionUsesNodeModules: () => moduleResolutionUsesNodeModules,
            moduleSpecifiers: () => ts_moduleSpecifiers_exports,
            moveEmitHelpers: () => moveEmitHelpers,
            moveRangeEnd: () => moveRangeEnd,
            moveRangePastDecorators: () => moveRangePastDecorators,
            moveRangePastModifiers: () => moveRangePastModifiers,
            moveRangePos: () => moveRangePos,
            moveSyntheticComments: () => moveSyntheticComments,
            mutateMap: () => mutateMap,
            mutateMapSkippingNewValues: () => mutateMapSkippingNewValues,
            needsParentheses: () => needsParentheses,
            needsScopeMarker: () => needsScopeMarker,
            newCaseClauseTracker: () => newCaseClauseTracker,
            newPrivateEnvironment: () => newPrivateEnvironment,
            noEmitNotification: () => noEmitNotification,
            noEmitSubstitution: () => noEmitSubstitution,
            noTransformers: () => noTransformers,
            noTruncationMaximumTruncationLength: () => noTruncationMaximumTruncationLength,
            nodeCanBeDecorated: () => nodeCanBeDecorated,
            nodeHasName: () => nodeHasName,
            nodeIsDecorated: () => nodeIsDecorated,
            nodeIsMissing: () => nodeIsMissing,
            nodeIsPresent: () => nodeIsPresent,
            nodeIsSynthesized: () => nodeIsSynthesized,
            nodeModuleNameResolver: () => nodeModuleNameResolver,
            nodeModulesPathPart: () => nodeModulesPathPart,
            nodeNextJsonConfigResolver: () => nodeNextJsonConfigResolver,
            nodeOrChildIsDecorated: () => nodeOrChildIsDecorated,
            nodeOverlapsWithStartEnd: () => nodeOverlapsWithStartEnd,
            nodePosToString: () => nodePosToString,
            nodeSeenTracker: () => nodeSeenTracker,
            nodeStartsNewLexicalEnvironment: () => nodeStartsNewLexicalEnvironment,
            nodeToDisplayParts: () => nodeToDisplayParts,
            noop: () => noop,
            noopFileWatcher: () => noopFileWatcher,
            noopPush: () => noopPush,
            normalizePath: () => normalizePath,
            normalizeSlashes: () => normalizeSlashes,
            not: () => not,
            notImplemented: () => notImplemented,
            notImplementedResolver: () => notImplementedResolver,
            nullNodeConverters: () => nullNodeConverters,
            nullParenthesizerRules: () => nullParenthesizerRules,
            nullTransformationContext: () => nullTransformationContext,
            objectAllocator: () => objectAllocator,
            operatorPart: () => operatorPart,
            optionDeclarations: () => optionDeclarations,
            optionMapToObject: () => optionMapToObject,
            optionsAffectingProgramStructure: () => optionsAffectingProgramStructure,
            optionsForBuild: () => optionsForBuild,
            optionsForWatch: () => optionsForWatch,
            optionsHaveChanges: () => optionsHaveChanges,
            optionsHaveModuleResolutionChanges: () => optionsHaveModuleResolutionChanges,
            or: () => or,
            orderedRemoveItem: () => orderedRemoveItem,
            orderedRemoveItemAt: () => orderedRemoveItemAt,
            outFile: () => outFile,
            packageIdToPackageName: () => packageIdToPackageName,
            packageIdToString: () => packageIdToString,
            padLeft: () => padLeft,
            padRight: () => padRight,
            paramHelper: () => paramHelper,
            parameterIsThisKeyword: () => parameterIsThisKeyword,
            parameterNamePart: () => parameterNamePart,
            parseBaseNodeFactory: () => parseBaseNodeFactory,
            parseBigInt: () => parseBigInt,
            parseBuildCommand: () => parseBuildCommand,
            parseCommandLine: () => parseCommandLine,
            parseCommandLineWorker: () => parseCommandLineWorker,
            parseConfigFileTextToJson: () => parseConfigFileTextToJson,
            parseConfigFileWithSystem: () => parseConfigFileWithSystem,
            parseConfigHostFromCompilerHostLike: () => parseConfigHostFromCompilerHostLike,
            parseCustomTypeOption: () => parseCustomTypeOption,
            parseIsolatedEntityName: () => parseIsolatedEntityName,
            parseIsolatedJSDocComment: () => parseIsolatedJSDocComment,
            parseJSDocTypeExpressionForTests: () => parseJSDocTypeExpressionForTests,
            parseJsonConfigFileContent: () => parseJsonConfigFileContent,
            parseJsonSourceFileConfigFileContent: () => parseJsonSourceFileConfigFileContent,
            parseJsonText: () => parseJsonText,
            parseListTypeOption: () => parseListTypeOption,
            parseNodeFactory: () => parseNodeFactory,
            parseNodeModuleFromPath: () => parseNodeModuleFromPath,
            parsePackageName: () => parsePackageName,
            parsePseudoBigInt: () => parsePseudoBigInt,
            parseValidBigInt: () => parseValidBigInt,
            patchWriteFileEnsuringDirectory: () => patchWriteFileEnsuringDirectory,
            pathContainsNodeModules: () => pathContainsNodeModules,
            pathIsAbsolute: () => pathIsAbsolute,
            pathIsBareSpecifier: () => pathIsBareSpecifier,
            pathIsRelative: () => pathIsRelative,
            patternText: () => patternText,
            perfLogger: () => perfLogger,
            performIncrementalCompilation: () => performIncrementalCompilation,
            performance: () => ts_performance_exports,
            plainJSErrors: () => plainJSErrors,
            positionBelongsToNode: () => positionBelongsToNode,
            positionIsASICandidate: () => positionIsASICandidate,
            positionIsSynthesized: () => positionIsSynthesized,
            positionsAreOnSameLine: () => positionsAreOnSameLine,
            preProcessFile: () => preProcessFile,
            probablyUsesSemicolons: () => probablyUsesSemicolons,
            processCommentPragmas: () => processCommentPragmas,
            processPragmasIntoFields: () => processPragmasIntoFields,
            processTaggedTemplateExpression: () => processTaggedTemplateExpression,
            programContainsEsModules: () => programContainsEsModules,
            programContainsModules: () => programContainsModules,
            projectReferenceIsEqualTo: () => projectReferenceIsEqualTo,
            propKeyHelper: () => propKeyHelper,
            propertyNamePart: () => propertyNamePart,
            pseudoBigIntToString: () => pseudoBigIntToString,
            punctuationPart: () => punctuationPart,
            pushIfUnique: () => pushIfUnique,
            quote: () => quote,
            quotePreferenceFromString: () => quotePreferenceFromString,
            rangeContainsPosition: () => rangeContainsPosition,
            rangeContainsPositionExclusive: () => rangeContainsPositionExclusive,
            rangeContainsRange: () => rangeContainsRange,
            rangeContainsRangeExclusive: () => rangeContainsRangeExclusive,
            rangeContainsStartEnd: () => rangeContainsStartEnd,
            rangeEndIsOnSameLineAsRangeStart: () => rangeEndIsOnSameLineAsRangeStart,
            rangeEndPositionsAreOnSameLine: () => rangeEndPositionsAreOnSameLine,
            rangeEquals: () => rangeEquals,
            rangeIsOnSingleLine: () => rangeIsOnSingleLine,
            rangeOfNode: () => rangeOfNode,
            rangeOfTypeParameters: () => rangeOfTypeParameters,
            rangeOverlapsWithStartEnd: () => rangeOverlapsWithStartEnd,
            rangeStartIsOnSameLineAsRangeEnd: () => rangeStartIsOnSameLineAsRangeEnd,
            rangeStartPositionsAreOnSameLine: () => rangeStartPositionsAreOnSameLine,
            readBuilderProgram: () => readBuilderProgram,
            readConfigFile: () => readConfigFile,
            readHelper: () => readHelper,
            readJson: () => readJson,
            readJsonConfigFile: () => readJsonConfigFile,
            readJsonOrUndefined: () => readJsonOrUndefined,
            realizeDiagnostics: () => realizeDiagnostics,
            reduceEachLeadingCommentRange: () => reduceEachLeadingCommentRange,
            reduceEachTrailingCommentRange: () => reduceEachTrailingCommentRange,
            reduceLeft: () => reduceLeft,
            reduceLeftIterator: () => reduceLeftIterator,
            reducePathComponents: () => reducePathComponents,
            refactor: () => ts_refactor_exports,
            regExpEscape: () => regExpEscape,
            relativeComplement: () => relativeComplement,
            removeAllComments: () => removeAllComments,
            removeEmitHelper: () => removeEmitHelper,
            removeExtension: () => removeExtension,
            removeFileExtension: () => removeFileExtension,
            removeIgnoredPath: () => removeIgnoredPath,
            removeMinAndVersionNumbers: () => removeMinAndVersionNumbers,
            removeOptionality: () => removeOptionality,
            removePrefix: () => removePrefix,
            removeSuffix: () => removeSuffix,
            removeTrailingDirectorySeparator: () => removeTrailingDirectorySeparator,
            repeatString: () => repeatString,
            replaceElement: () => replaceElement,
            resolutionExtensionIsTSOrJson: () => resolutionExtensionIsTSOrJson,
            resolveConfigFileProjectName: () => resolveConfigFileProjectName,
            resolveJSModule: () => resolveJSModule,
            resolveModuleName: () => resolveModuleName,
            resolveModuleNameFromCache: () => resolveModuleNameFromCache,
            resolvePackageNameToPackageJson: () => resolvePackageNameToPackageJson,
            resolvePath: () => resolvePath,
            resolveProjectReferencePath: () => resolveProjectReferencePath,
            resolveTripleslashReference: () => resolveTripleslashReference,
            resolveTypeReferenceDirective: () => resolveTypeReferenceDirective,
            resolvingEmptyArray: () => resolvingEmptyArray,
            restHelper: () => restHelper,
            returnFalse: () => returnFalse,
            returnNoopFileWatcher: () => returnNoopFileWatcher,
            returnTrue: () => returnTrue,
            returnUndefined: () => returnUndefined,
            returnsPromise: () => returnsPromise,
            runInitializersHelper: () => runInitializersHelper,
            sameFlatMap: () => sameFlatMap,
            sameMap: () => sameMap,
            sameMapping: () => sameMapping,
            scanShebangTrivia: () => scanShebangTrivia,
            scanTokenAtPosition: () => scanTokenAtPosition,
            scanner: () => scanner,
            screenStartingMessageCodes: () => screenStartingMessageCodes,
            semanticDiagnosticsOptionDeclarations: () => semanticDiagnosticsOptionDeclarations,
            serializeCompilerOptions: () => serializeCompilerOptions,
            server: () => ts_server_exports,
            servicesVersion: () => servicesVersion,
            setCommentRange: () => setCommentRange,
            setConfigFileInOptions: () => setConfigFileInOptions,
            setConstantValue: () => setConstantValue,
            setEachParent: () => setEachParent,
            setEmitFlags: () => setEmitFlags,
            setFunctionNameHelper: () => setFunctionNameHelper,
            setGetSourceFileAsHashVersioned: () => setGetSourceFileAsHashVersioned,
            setIdentifierAutoGenerate: () => setIdentifierAutoGenerate,
            setIdentifierGeneratedImportReference: () => setIdentifierGeneratedImportReference,
            setIdentifierTypeArguments: () => setIdentifierTypeArguments,
            setInternalEmitFlags: () => setInternalEmitFlags,
            setLocalizedDiagnosticMessages: () => setLocalizedDiagnosticMessages,
            setModuleDefaultHelper: () => setModuleDefaultHelper,
            setNodeFlags: () => setNodeFlags,
            setObjectAllocator: () => setObjectAllocator,
            setOriginalNode: () => setOriginalNode,
            setParent: () => setParent,
            setParentRecursive: () => setParentRecursive,
            setPrivateIdentifier: () => setPrivateIdentifier,
            setResolvedModule: () => setResolvedModule,
            setResolvedTypeReferenceDirective: () => setResolvedTypeReferenceDirective,
            setSnippetElement: () => setSnippetElement,
            setSourceMapRange: () => setSourceMapRange,
            setStackTraceLimit: () => setStackTraceLimit,
            setStartsOnNewLine: () => setStartsOnNewLine,
            setSyntheticLeadingComments: () => setSyntheticLeadingComments,
            setSyntheticTrailingComments: () => setSyntheticTrailingComments,
            setSys: () => setSys,
            setSysLog: () => setSysLog,
            setTextRange: () => setTextRange,
            setTextRangeEnd: () => setTextRangeEnd,
            setTextRangePos: () => setTextRangePos,
            setTextRangePosEnd: () => setTextRangePosEnd,
            setTextRangePosWidth: () => setTextRangePosWidth,
            setTokenSourceMapRange: () => setTokenSourceMapRange,
            setTypeNode: () => setTypeNode,
            setUILocale: () => setUILocale,
            setValueDeclaration: () => setValueDeclaration,
            shouldAllowImportingTsExtension: () => shouldAllowImportingTsExtension,
            shouldPreserveConstEnums: () => shouldPreserveConstEnums,
            shouldResolveJsRequire: () => shouldResolveJsRequire,
            shouldUseUriStyleNodeCoreModules: () => shouldUseUriStyleNodeCoreModules,
            showModuleSpecifier: () => showModuleSpecifier,
            signatureHasLiteralTypes: () => signatureHasLiteralTypes,
            signatureHasRestParameter: () => signatureHasRestParameter,
            signatureToDisplayParts: () => signatureToDisplayParts,
            single: () => single,
            singleElementArray: () => singleElementArray,
            singleIterator: () => singleIterator,
            singleOrMany: () => singleOrMany,
            singleOrUndefined: () => singleOrUndefined,
            skipAlias: () => skipAlias,
            skipAssertions: () => skipAssertions,
            skipConstraint: () => skipConstraint,
            skipOuterExpressions: () => skipOuterExpressions,
            skipParentheses: () => skipParentheses,
            skipPartiallyEmittedExpressions: () => skipPartiallyEmittedExpressions,
            skipTrivia: () => skipTrivia,
            skipTypeChecking: () => skipTypeChecking,
            skipTypeParentheses: () => skipTypeParentheses,
            skipWhile: () => skipWhile,
            sliceAfter: () => sliceAfter,
            some: () => some,
            sort: () => sort,
            sortAndDeduplicate: () => sortAndDeduplicate,
            sortAndDeduplicateDiagnostics: () => sortAndDeduplicateDiagnostics,
            sourceFileAffectingCompilerOptions: () => sourceFileAffectingCompilerOptions,
            sourceFileMayBeEmitted: () => sourceFileMayBeEmitted,
            sourceMapCommentRegExp: () => sourceMapCommentRegExp,
            sourceMapCommentRegExpDontCareLineStart: () => sourceMapCommentRegExpDontCareLineStart,
            spacePart: () => spacePart,
            spanMap: () => spanMap,
            spreadArrayHelper: () => spreadArrayHelper,
            stableSort: () => stableSort,
            startEndContainsRange: () => startEndContainsRange,
            startEndOverlapsWithStartEnd: () => startEndOverlapsWithStartEnd,
            startOnNewLine: () => startOnNewLine,
            startTracing: () => startTracing,
            startsWith: () => startsWith,
            startsWithDirectory: () => startsWithDirectory,
            startsWithUnderscore: () => startsWithUnderscore,
            startsWithUseStrict: () => startsWithUseStrict,
            stringContains: () => stringContains,
            stringContainsAt: () => stringContainsAt,
            stringToToken: () => stringToToken,
            stripQuotes: () => stripQuotes,
            supportedDeclarationExtensions: () => supportedDeclarationExtensions,
            supportedJSExtensions: () => supportedJSExtensions,
            supportedJSExtensionsFlat: () => supportedJSExtensionsFlat,
            supportedLocaleDirectories: () => supportedLocaleDirectories,
            supportedTSExtensions: () => supportedTSExtensions,
            supportedTSExtensionsFlat: () => supportedTSExtensionsFlat,
            supportedTSImplementationExtensions: () => supportedTSImplementationExtensions,
            suppressLeadingAndTrailingTrivia: () => suppressLeadingAndTrailingTrivia,
            suppressLeadingTrivia: () => suppressLeadingTrivia,
            suppressTrailingTrivia: () => suppressTrailingTrivia,
            symbolEscapedNameNoDefault: () => symbolEscapedNameNoDefault,
            symbolName: () => symbolName,
            symbolNameNoDefault: () => symbolNameNoDefault,
            symbolPart: () => symbolPart,
            symbolToDisplayParts: () => symbolToDisplayParts,
            syntaxMayBeASICandidate: () => syntaxMayBeASICandidate,
            syntaxRequiresTrailingSemicolonOrASI: () => syntaxRequiresTrailingSemicolonOrASI,
            sys: () => sys,
            sysLog: () => sysLog,
            tagNamesAreEquivalent: () => tagNamesAreEquivalent,
            takeWhile: () => takeWhile,
            targetOptionDeclaration: () => targetOptionDeclaration,
            templateObjectHelper: () => templateObjectHelper,
            testFormatSettings: () => testFormatSettings,
            textChangeRangeIsUnchanged: () => textChangeRangeIsUnchanged,
            textChangeRangeNewSpan: () => textChangeRangeNewSpan,
            textChanges: () => ts_textChanges_exports,
            textOrKeywordPart: () => textOrKeywordPart,
            textPart: () => textPart,
            textRangeContainsPositionInclusive: () => textRangeContainsPositionInclusive,
            textSpanContainsPosition: () => textSpanContainsPosition,
            textSpanContainsTextSpan: () => textSpanContainsTextSpan,
            textSpanEnd: () => textSpanEnd,
            textSpanIntersection: () => textSpanIntersection,
            textSpanIntersectsWith: () => textSpanIntersectsWith,
            textSpanIntersectsWithPosition: () => textSpanIntersectsWithPosition,
            textSpanIntersectsWithTextSpan: () => textSpanIntersectsWithTextSpan,
            textSpanIsEmpty: () => textSpanIsEmpty,
            textSpanOverlap: () => textSpanOverlap,
            textSpanOverlapsWith: () => textSpanOverlapsWith,
            textSpansEqual: () => textSpansEqual,
            textToKeywordObj: () => textToKeywordObj,
            timestamp: () => timestamp,
            toArray: () => toArray,
            toBuilderFileEmit: () => toBuilderFileEmit,
            toBuilderStateFileInfoForMultiEmit: () => toBuilderStateFileInfoForMultiEmit,
            toEditorSettings: () => toEditorSettings,
            toFileNameLowerCase: () => toFileNameLowerCase,
            toLowerCase: () => toLowerCase,
            toPath: () => toPath,
            toProgramEmitPending: () => toProgramEmitPending,
            tokenIsIdentifierOrKeyword: () => tokenIsIdentifierOrKeyword,
            tokenIsIdentifierOrKeywordOrGreaterThan: () => tokenIsIdentifierOrKeywordOrGreaterThan,
            tokenToString: () => tokenToString,
            trace: () => trace,
            tracing: () => tracing,
            tracingEnabled: () => tracingEnabled,
            transform: () => transform,
            transformClassFields: () => transformClassFields,
            transformDeclarations: () => transformDeclarations,
            transformECMAScriptModule: () => transformECMAScriptModule,
            transformES2015: () => transformES2015,
            transformES2016: () => transformES2016,
            transformES2017: () => transformES2017,
            transformES2018: () => transformES2018,
            transformES2019: () => transformES2019,
            transformES2020: () => transformES2020,
            transformES2021: () => transformES2021,
            transformES5: () => transformES5,
            transformESDecorators: () => transformESDecorators,
            transformESNext: () => transformESNext,
            transformGenerators: () => transformGenerators,
            transformJsx: () => transformJsx,
            transformLegacyDecorators: () => transformLegacyDecorators,
            transformModule: () => transformModule,
            transformNodeModule: () => transformNodeModule,
            transformNodes: () => transformNodes,
            transformSystemModule: () => transformSystemModule,
            transformTypeScript: () => transformTypeScript,
            transpile: () => transpile,
            transpileModule: () => transpileModule,
            transpileOptionValueCompilerOptions: () => transpileOptionValueCompilerOptions,
            trimString: () => trimString,
            trimStringEnd: () => trimStringEnd,
            trimStringStart: () => trimStringStart,
            tryAddToSet: () => tryAddToSet,
            tryAndIgnoreErrors: () => tryAndIgnoreErrors,
            tryCast: () => tryCast,
            tryDirectoryExists: () => tryDirectoryExists,
            tryExtractTSExtension: () => tryExtractTSExtension,
            tryFileExists: () => tryFileExists,
            tryGetClassExtendingExpressionWithTypeArguments: () => tryGetClassExtendingExpressionWithTypeArguments,
            tryGetClassImplementingOrExtendingExpressionWithTypeArguments: () => tryGetClassImplementingOrExtendingExpressionWithTypeArguments,
            tryGetDirectories: () => tryGetDirectories,
            tryGetExtensionFromPath: () => tryGetExtensionFromPath2,
            tryGetImportFromModuleSpecifier: () => tryGetImportFromModuleSpecifier,
            tryGetJSDocSatisfiesTypeNode: () => tryGetJSDocSatisfiesTypeNode,
            tryGetModuleNameFromFile: () => tryGetModuleNameFromFile,
            tryGetModuleSpecifierFromDeclaration: () => tryGetModuleSpecifierFromDeclaration,
            tryGetNativePerformanceHooks: () => tryGetNativePerformanceHooks,
            tryGetPropertyAccessOrIdentifierToString: () => tryGetPropertyAccessOrIdentifierToString,
            tryGetPropertyNameOfBindingOrAssignmentElement: () => tryGetPropertyNameOfBindingOrAssignmentElement,
            tryGetSourceMappingURL: () => tryGetSourceMappingURL,
            tryGetTextOfPropertyName: () => tryGetTextOfPropertyName,
            tryIOAndConsumeErrors: () => tryIOAndConsumeErrors,
            tryParsePattern: () => tryParsePattern,
            tryParsePatterns: () => tryParsePatterns,
            tryParseRawSourceMap: () => tryParseRawSourceMap,
            tryReadDirectory: () => tryReadDirectory,
            tryReadFile: () => tryReadFile,
            tryRemoveDirectoryPrefix: () => tryRemoveDirectoryPrefix,
            tryRemoveExtension: () => tryRemoveExtension,
            tryRemovePrefix: () => tryRemovePrefix,
            tryRemoveSuffix: () => tryRemoveSuffix,
            typeAcquisitionDeclarations: () => typeAcquisitionDeclarations,
            typeAliasNamePart: () => typeAliasNamePart,
            typeDirectiveIsEqualTo: () => typeDirectiveIsEqualTo,
            typeKeywords: () => typeKeywords,
            typeParameterNamePart: () => typeParameterNamePart,
            typeReferenceResolutionNameAndModeGetter: () => typeReferenceResolutionNameAndModeGetter,
            typeToDisplayParts: () => typeToDisplayParts,
            unchangedPollThresholds: () => unchangedPollThresholds,
            unchangedTextChangeRange: () => unchangedTextChangeRange,
            unescapeLeadingUnderscores: () => unescapeLeadingUnderscores,
            unmangleScopedPackageName: () => unmangleScopedPackageName,
            unorderedRemoveItem: () => unorderedRemoveItem,
            unorderedRemoveItemAt: () => unorderedRemoveItemAt,
            unreachableCodeIsError: () => unreachableCodeIsError,
            unusedLabelIsError: () => unusedLabelIsError,
            unwrapInnermostStatementOfLabel: () => unwrapInnermostStatementOfLabel,
            updateErrorForNoInputFiles: () => updateErrorForNoInputFiles,
            updateLanguageServiceSourceFile: () => updateLanguageServiceSourceFile,
            updateMissingFilePathsWatch: () => updateMissingFilePathsWatch,
            updatePackageJsonWatch: () => updatePackageJsonWatch,
            updateResolutionField: () => updateResolutionField,
            updateSharedExtendedConfigFileWatcher: () => updateSharedExtendedConfigFileWatcher,
            updateSourceFile: () => updateSourceFile,
            updateWatchingWildcardDirectories: () => updateWatchingWildcardDirectories,
            usesExtensionsOnImports: () => usesExtensionsOnImports,
            usingSingleLineStringWriter: () => usingSingleLineStringWriter,
            utf16EncodeAsString: () => utf16EncodeAsString,
            validateLocaleAndSetLanguage: () => validateLocaleAndSetLanguage,
            valuesHelper: () => valuesHelper,
            version: () => version,
            versionMajorMinor: () => versionMajorMinor,
            visitArray: () => visitArray,
            visitCommaListElements: () => visitCommaListElements,
            visitEachChild: () => visitEachChild,
            visitFunctionBody: () => visitFunctionBody,
            visitIterationBody: () => visitIterationBody,
            visitLexicalEnvironment: () => visitLexicalEnvironment,
            visitNode: () => visitNode,
            visitNodes: () => visitNodes2,
            visitParameterList: () => visitParameterList,
            walkUpBindingElementsAndPatterns: () => walkUpBindingElementsAndPatterns,
            walkUpLexicalEnvironments: () => walkUpLexicalEnvironments,
            walkUpOuterExpressions: () => walkUpOuterExpressions,
            walkUpParenthesizedExpressions: () => walkUpParenthesizedExpressions,
            walkUpParenthesizedTypes: () => walkUpParenthesizedTypes,
            walkUpParenthesizedTypesAndGetParentAndChild: () => walkUpParenthesizedTypesAndGetParentAndChild,
            whitespaceOrMapCommentRegExp: () => whitespaceOrMapCommentRegExp,
            writeCommentRange: () => writeCommentRange,
            writeFile: () => writeFile,
            writeFileEnsuringDirectories: () => writeFileEnsuringDirectories,
            zipToModeAwareCache: () => zipToModeAwareCache,
            zipWith: () => zipWith
        });
        var init_ts6 = __esm({
            "src/typescript/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_ts3();
                init_ts4();
                init_ts5();
            }
        });
        // src/typescript/typescript.ts
        var require_typescript = __commonJS({
            "src/typescript/typescript.ts"(exports, module2) {
                init_ts6();
                init_ts6();
                if (typeof console !== "undefined") {
                    Debug.loggingHost = {
                        log(level, s) {
                            switch (level) {
                                case 1 /* Error */:
                                    return console.error(s);
                                case 2 /* Warning */:
                                    return console.warn(s);
                                case 3 /* Info */:
                                    return console.log(s);
                                case 4 /* Verbose */:
                                    return console.log(s);
                            }
                        }
                    };
                }
                module2.exports = ts_exports3;
            }
        });
        return require_typescript();
    })();
    if (typeof module !== "undefined" && module.exports) {
        module.exports = ts;
    }
    
},
/* source-map-support/source-map-support.js */ function _(require, module, exports, __esModule, __esExport) {
    var SourceMapConsumer = require(23) /* source-map */.SourceMapConsumer;
    var path = require('path');
    var fs;
    try {
        fs = require('fs');
        if (!fs.existsSync || !fs.readFileSync) {
            // fs doesn't have all methods we need
            fs = null;
        }
    }
    catch (err) {
        /* nop */
    }
    var bufferFrom = require(34) /* buffer-from */;
    /**
     * Requires a module which is protected against bundler minification.
     *
     * @param {NodeModule} mod
     * @param {string} request
     */
    function dynamicRequire(mod, request) {
        return mod.require(request);
    }
    // Only install once if called multiple times
    var errorFormatterInstalled = false;
    var uncaughtShimInstalled = false;
    // If true, the caches are reset before a stack trace formatting operation
    var emptyCacheBetweenOperations = false;
    // Supports {browser, node, auto}
    var environment = "auto";
    // Maps a file path to a string containing the file contents
    var fileContentsCache = {};
    // Maps a file path to a source map for that file
    var sourceMapCache = {};
    // Regex for detecting source maps
    var reSourceMap = /^data:application\/json[^,]+base64,/;
    // Priority list of retrieve handlers
    var retrieveFileHandlers = [];
    var retrieveMapHandlers = [];
    function isInBrowser() {
        if (environment === "browser")
            return true;
        if (environment === "node")
            return false;
        return ((typeof window !== 'undefined') && (typeof XMLHttpRequest === 'function') && !(window.require && window.module && window.process && window.process.type === "renderer"));
    }
    function hasGlobalProcessEventEmitter() {
        return ((typeof process === 'object') && (process !== null) && (typeof process.on === 'function'));
    }
    function globalProcessVersion() {
        if ((typeof process === 'object') && (process !== null)) {
            return process.version;
        }
        else {
            return '';
        }
    }
    function globalProcessStderr() {
        if ((typeof process === 'object') && (process !== null)) {
            return process.stderr;
        }
    }
    function globalProcessExit(code) {
        if ((typeof process === 'object') && (process !== null) && (typeof process.exit === 'function')) {
            return process.exit(code);
        }
    }
    function handlerExec(list) {
        return function (arg) {
            for (var i = 0; i < list.length; i++) {
                var ret = list[i](arg);
                if (ret) {
                    return ret;
                }
            }
            return null;
        };
    }
    var retrieveFile = handlerExec(retrieveFileHandlers);
    retrieveFileHandlers.push(function (path) {
        // Trim the path to make sure there is no extra whitespace.
        path = path.trim();
        if (/^file:/.test(path)) {
            // existsSync/readFileSync can't handle file protocol, but once stripped, it works
            path = path.replace(/file:\/\/\/(\w:)?/, function (protocol, drive) {
                return drive ?
                    '' : // file:///C:/dir/file -> C:/dir/file
                    '/'; // file:///root-dir/file -> /root-dir/file
            });
        }
        if (path in fileContentsCache) {
            return fileContentsCache[path];
        }
        var contents = '';
        try {
            if (!fs) {
                // Use SJAX if we are in the browser
                var xhr = new XMLHttpRequest();
                xhr.open('GET', path, /** async */ false);
                xhr.send(null);
                if (xhr.readyState === 4 && xhr.status === 200) {
                    contents = xhr.responseText;
                }
            }
            else if (fs.existsSync(path)) {
                // Otherwise, use the filesystem
                contents = fs.readFileSync(path, 'utf8');
            }
        }
        catch (er) {
            /* ignore any errors */
        }
        return fileContentsCache[path] = contents;
    });
    // Support URLs relative to a directory, but be careful about a protocol prefix
    // in case we are in the browser (i.e. directories may start with "http://" or "file:///")
    function supportRelativeURL(file, url) {
        if (!file)
            return url;
        var dir = path.dirname(file);
        var match = /^\w+:\/\/[^\/]*/.exec(dir);
        var protocol = match ? match[0] : '';
        var startPath = dir.slice(protocol.length);
        if (protocol && /^\/\w\:/.test(startPath)) {
            // handle file:///C:/ paths
            protocol += '/';
            return protocol + path.resolve(dir.slice(protocol.length), url).replace(/\\/g, '/');
        }
        return protocol + path.resolve(dir.slice(protocol.length), url);
    }
    function retrieveSourceMapURL(source) {
        var fileData;
        if (isInBrowser()) {
            try {
                var xhr = new XMLHttpRequest();
                xhr.open('GET', source, false);
                xhr.send(null);
                fileData = xhr.readyState === 4 ? xhr.responseText : null;
                // Support providing a sourceMappingURL via the SourceMap header
                var sourceMapHeader = xhr.getResponseHeader("SourceMap") ||
                    xhr.getResponseHeader("X-SourceMap");
                if (sourceMapHeader) {
                    return sourceMapHeader;
                }
            }
            catch (e) {
            }
        }
        // Get the URL of the source map
        fileData = retrieveFile(source);
        var re = /(?:\/\/[@#][\s]*sourceMappingURL=([^\s'"]+)[\s]*$)|(?:\/\*[@#][\s]*sourceMappingURL=([^\s*'"]+)[\s]*(?:\*\/)[\s]*$)/mg;
        // Keep executing the search to find the *last* sourceMappingURL to avoid
        // picking up sourceMappingURLs from comments, strings, etc.
        var lastMatch, match;
        while (match = re.exec(fileData))
            lastMatch = match;
        if (!lastMatch)
            return null;
        return lastMatch[1];
    }
    ;
    // Can be overridden by the retrieveSourceMap option to install. Takes a
    // generated source filename; returns a {map, optional url} object, or null if
    // there is no source map.  The map field may be either a string or the parsed
    // JSON object (ie, it must be a valid argument to the SourceMapConsumer
    // constructor).
    var retrieveSourceMap = handlerExec(retrieveMapHandlers);
    retrieveMapHandlers.push(function (source) {
        var sourceMappingURL = retrieveSourceMapURL(source);
        if (!sourceMappingURL)
            return null;
        // Read the contents of the source map
        var sourceMapData;
        if (reSourceMap.test(sourceMappingURL)) {
            // Support source map URL as a data url
            var rawData = sourceMappingURL.slice(sourceMappingURL.indexOf(',') + 1);
            sourceMapData = bufferFrom(rawData, "base64").toString();
            sourceMappingURL = source;
        }
        else {
            // Support source map URLs relative to the source URL
            sourceMappingURL = supportRelativeURL(source, sourceMappingURL);
            sourceMapData = retrieveFile(sourceMappingURL);
        }
        if (!sourceMapData) {
            return null;
        }
        return {
            url: sourceMappingURL,
            map: sourceMapData
        };
    });
    function mapSourcePosition(position) {
        var sourceMap = sourceMapCache[position.source];
        if (!sourceMap) {
            // Call the (overrideable) retrieveSourceMap function to get the source map.
            var urlAndMap = retrieveSourceMap(position.source);
            if (urlAndMap) {
                sourceMap = sourceMapCache[position.source] = {
                    url: urlAndMap.url,
                    map: new SourceMapConsumer(urlAndMap.map)
                };
                // Load all sources stored inline with the source map into the file cache
                // to pretend like they are already loaded. They may not exist on disk.
                if (sourceMap.map.sourcesContent) {
                    sourceMap.map.sources.forEach(function (source, i) {
                        var contents = sourceMap.map.sourcesContent[i];
                        if (contents) {
                            var url = supportRelativeURL(sourceMap.url, source);
                            fileContentsCache[url] = contents;
                        }
                    });
                }
            }
            else {
                sourceMap = sourceMapCache[position.source] = {
                    url: null,
                    map: null
                };
            }
        }
        // Resolve the source URL relative to the URL of the source map
        if (sourceMap && sourceMap.map && typeof sourceMap.map.originalPositionFor === 'function') {
            var originalPosition = sourceMap.map.originalPositionFor(position);
            // Only return the original position if a matching line was found. If no
            // matching line is found then we return position instead, which will cause
            // the stack trace to print the path and line for the compiled file. It is
            // better to give a precise location in the compiled file than a vague
            // location in the original file.
            if (originalPosition.source !== null) {
                originalPosition.source = supportRelativeURL(sourceMap.url, originalPosition.source);
                return originalPosition;
            }
        }
        return position;
    }
    // Parses code generated by FormatEvalOrigin(), a function inside V8:
    // https://code.google.com/p/v8/source/browse/trunk/src/messages.js
    function mapEvalOrigin(origin) {
        // Most eval() calls are in this format
        var match = /^eval at ([^(]+) \((.+):(\d+):(\d+)\)$/.exec(origin);
        if (match) {
            var position = mapSourcePosition({
                source: match[2],
                line: +match[3],
                column: match[4] - 1
            });
            return 'eval at ' + match[1] + ' (' + position.source + ':' +
                position.line + ':' + (position.column + 1) + ')';
        }
        // Parse nested eval() calls using recursion
        match = /^eval at ([^(]+) \((.+)\)$/.exec(origin);
        if (match) {
            return 'eval at ' + match[1] + ' (' + mapEvalOrigin(match[2]) + ')';
        }
        // Make sure we still return useful information if we didn't find anything
        return origin;
    }
    // This is copied almost verbatim from the V8 source code at
    // https://code.google.com/p/v8/source/browse/trunk/src/messages.js. The
    // implementation of wrapCallSite() used to just forward to the actual source
    // code of CallSite.prototype.toString but unfortunately a new release of V8
    // did something to the prototype chain and broke the shim. The only fix I
    // could find was copy/paste.
    function CallSiteToString() {
        var fileName;
        var fileLocation = "";
        if (this.isNative()) {
            fileLocation = "native";
        }
        else {
            fileName = this.getScriptNameOrSourceURL();
            if (!fileName && this.isEval()) {
                fileLocation = this.getEvalOrigin();
                fileLocation += ", "; // Expecting source position to follow.
            }
            if (fileName) {
                fileLocation += fileName;
            }
            else {
                // Source code does not originate from a file and is not native, but we
                // can still get the source position inside the source string, e.g. in
                // an eval string.
                fileLocation += "<anonymous>";
            }
            var lineNumber = this.getLineNumber();
            if (lineNumber != null) {
                fileLocation += ":" + lineNumber;
                var columnNumber = this.getColumnNumber();
                if (columnNumber) {
                    fileLocation += ":" + columnNumber;
                }
            }
        }
        var line = "";
        var functionName = this.getFunctionName();
        var addSuffix = true;
        var isConstructor = this.isConstructor();
        var isMethodCall = !(this.isToplevel() || isConstructor);
        if (isMethodCall) {
            var typeName = this.getTypeName();
            // Fixes shim to be backward compatable with Node v0 to v4
            if (typeName === "[object Object]") {
                typeName = "null";
            }
            var methodName = this.getMethodName();
            if (functionName) {
                if (typeName && functionName.indexOf(typeName) != 0) {
                    line += typeName + ".";
                }
                line += functionName;
                if (methodName && functionName.indexOf("." + methodName) != functionName.length - methodName.length - 1) {
                    line += " [as " + methodName + "]";
                }
            }
            else {
                line += typeName + "." + (methodName || "<anonymous>");
            }
        }
        else if (isConstructor) {
            line += "new " + (functionName || "<anonymous>");
        }
        else if (functionName) {
            line += functionName;
        }
        else {
            line += fileLocation;
            addSuffix = false;
        }
        if (addSuffix) {
            line += " (" + fileLocation + ")";
        }
        return line;
    }
    function cloneCallSite(frame) {
        var object = {};
        Object.getOwnPropertyNames(Object.getPrototypeOf(frame)).forEach(function (name) {
            object[name] = /^(?:is|get)/.test(name) ? function () { return frame[name].call(frame); } : frame[name];
        });
        object.toString = CallSiteToString;
        return object;
    }
    function wrapCallSite(frame, state) {
        // provides interface backward compatibility
        if (state === undefined) {
            state = { nextPosition: null, curPosition: null };
        }
        if (frame.isNative()) {
            state.curPosition = null;
            return frame;
        }
        // Most call sites will return the source file from getFileName(), but code
        // passed to eval() ending in "//# sourceURL=..." will return the source file
        // from getScriptNameOrSourceURL() instead
        var source = frame.getFileName() || frame.getScriptNameOrSourceURL();
        if (source) {
            var line = frame.getLineNumber();
            var column = frame.getColumnNumber() - 1;
            // Fix position in Node where some (internal) code is prepended.
            // See https://github.com/evanw/node-source-map-support/issues/36
            // Header removed in node at ^10.16 || >=11.11.0
            // v11 is not an LTS candidate, we can just test the one version with it.
            // Test node versions for: 10.16-19, 10.20+, 12-19, 20-99, 100+, or 11.11
            var noHeader = /^v(10\.1[6-9]|10\.[2-9][0-9]|10\.[0-9]{3,}|1[2-9]\d*|[2-9]\d|\d{3,}|11\.11)/;
            var headerLength = noHeader.test(globalProcessVersion()) ? 0 : 62;
            if (line === 1 && column > headerLength && !isInBrowser() && !frame.isEval()) {
                column -= headerLength;
            }
            var position = mapSourcePosition({
                source: source,
                line: line,
                column: column
            });
            state.curPosition = position;
            frame = cloneCallSite(frame);
            var originalFunctionName = frame.getFunctionName;
            frame.getFunctionName = function () {
                if (state.nextPosition == null) {
                    return originalFunctionName();
                }
                return state.nextPosition.name || originalFunctionName();
            };
            frame.getFileName = function () { return position.source; };
            frame.getLineNumber = function () { return position.line; };
            frame.getColumnNumber = function () { return position.column + 1; };
            frame.getScriptNameOrSourceURL = function () { return position.source; };
            return frame;
        }
        // Code called using eval() needs special handling
        var origin = frame.isEval() && frame.getEvalOrigin();
        if (origin) {
            origin = mapEvalOrigin(origin);
            frame = cloneCallSite(frame);
            frame.getEvalOrigin = function () { return origin; };
            return frame;
        }
        // If we get here then we were unable to change the source position
        return frame;
    }
    // This function is part of the V8 stack trace API, for more info see:
    // https://v8.dev/docs/stack-trace-api
    function prepareStackTrace(error, stack) {
        if (emptyCacheBetweenOperations) {
            fileContentsCache = {};
            sourceMapCache = {};
        }
        var name = error.name || 'Error';
        var message = error.message || '';
        var errorString = name + ": " + message;
        var state = { nextPosition: null, curPosition: null };
        var processedStack = [];
        for (var i = stack.length - 1; i >= 0; i--) {
            processedStack.push('\n    at ' + wrapCallSite(stack[i], state));
            state.nextPosition = state.curPosition;
        }
        state.curPosition = state.nextPosition = null;
        return errorString + processedStack.reverse().join('');
    }
    // Generate position and snippet of original source with pointer
    function getErrorSource(error) {
        var match = /\n    at [^(]+ \((.*):(\d+):(\d+)\)/.exec(error.stack);
        if (match) {
            var source = match[1];
            var line = +match[2];
            var column = +match[3];
            // Support the inline sourceContents inside the source map
            var contents = fileContentsCache[source];
            // Support files on disk
            if (!contents && fs && fs.existsSync(source)) {
                try {
                    contents = fs.readFileSync(source, 'utf8');
                }
                catch (er) {
                    contents = '';
                }
            }
            // Format the line from the original source code like node does
            if (contents) {
                var code = contents.split(/(?:\r\n|\r|\n)/)[line - 1];
                if (code) {
                    return source + ':' + line + '\n' + code + '\n' +
                        new Array(column).join(' ') + '^';
                }
            }
        }
        return null;
    }
    function printErrorAndExit(error) {
        var source = getErrorSource(error);
        // Ensure error is printed synchronously and not truncated
        var stderr = globalProcessStderr();
        if (stderr && stderr._handle && stderr._handle.setBlocking) {
            stderr._handle.setBlocking(true);
        }
        if (source) {
            console.error();
            console.error(source);
        }
        console.error(error.stack);
        globalProcessExit(1);
    }
    function shimEmitUncaughtException() {
        var origEmit = process.emit;
        process.emit = function (type) {
            if (type === 'uncaughtException') {
                var hasStack = (arguments[1] && arguments[1].stack);
                var hasListeners = (this.listeners(type).length > 0);
                if (hasStack && !hasListeners) {
                    return printErrorAndExit(arguments[1]);
                }
            }
            return origEmit.apply(this, arguments);
        };
    }
    var originalRetrieveFileHandlers = retrieveFileHandlers.slice(0);
    var originalRetrieveMapHandlers = retrieveMapHandlers.slice(0);
    exports.wrapCallSite = wrapCallSite;
    exports.getErrorSource = getErrorSource;
    exports.mapSourcePosition = mapSourcePosition;
    exports.retrieveSourceMap = retrieveSourceMap;
    exports.install = function (options) {
        options = options || {};
        if (options.environment) {
            environment = options.environment;
            if (["node", "browser", "auto"].indexOf(environment) === -1) {
                throw new Error("environment " + environment + " was unknown. Available options are {auto, browser, node}");
            }
        }
        // Allow sources to be found by methods other than reading the files
        // directly from disk.
        if (options.retrieveFile) {
            if (options.overrideRetrieveFile) {
                retrieveFileHandlers.length = 0;
            }
            retrieveFileHandlers.unshift(options.retrieveFile);
        }
        // Allow source maps to be found by methods other than reading the files
        // directly from disk.
        if (options.retrieveSourceMap) {
            if (options.overrideRetrieveSourceMap) {
                retrieveMapHandlers.length = 0;
            }
            retrieveMapHandlers.unshift(options.retrieveSourceMap);
        }
        // Support runtime transpilers that include inline source maps
        if (options.hookRequire && !isInBrowser()) {
            // Use dynamicRequire to avoid including in browser bundles
            var Module = dynamicRequire(module, 'module');
            var $compile = Module.prototype._compile;
            if (!$compile.__sourceMapSupport) {
                Module.prototype._compile = function (content, filename) {
                    fileContentsCache[filename] = content;
                    sourceMapCache[filename] = undefined;
                    return $compile.call(this, content, filename);
                };
                Module.prototype._compile.__sourceMapSupport = true;
            }
        }
        // Configure options
        if (!emptyCacheBetweenOperations) {
            emptyCacheBetweenOperations = 'emptyCacheBetweenOperations' in options ?
                options.emptyCacheBetweenOperations : false;
        }
        // Install the error reformatter
        if (!errorFormatterInstalled) {
            errorFormatterInstalled = true;
            Error.prepareStackTrace = prepareStackTrace;
        }
        if (!uncaughtShimInstalled) {
            var installHandler = 'handleUncaughtExceptions' in options ?
                options.handleUncaughtExceptions : true;
            // Do not override 'uncaughtException' with our own handler in Node.js
            // Worker threads. Workers pass the error to the main thread as an event,
            // rather than printing something to stderr and exiting.
            try {
                // We need to use `dynamicRequire` because `require` on it's own will be optimized by WebPack/Browserify.
                var worker_threads = dynamicRequire(module, 'worker_threads');
                if (worker_threads.isMainThread === false) {
                    installHandler = false;
                }
            }
            catch (e) { }
            // Provide the option to not install the uncaught exception handler. This is
            // to support other uncaught exception handlers (in test frameworks, for
            // example). If this handler is not installed and there are no other uncaught
            // exception handlers, uncaught exceptions will be caught by node's built-in
            // exception handler and the process will still be terminated. However, the
            // generated JavaScript code will be shown above the stack trace instead of
            // the original source code.
            if (installHandler && hasGlobalProcessEventEmitter()) {
                uncaughtShimInstalled = true;
                shimEmitUncaughtException();
            }
        }
    };
    exports.resetRetrieveHandlers = function () {
        retrieveFileHandlers.length = 0;
        retrieveMapHandlers.length = 0;
        retrieveFileHandlers = originalRetrieveFileHandlers.slice(0);
        retrieveMapHandlers = originalRetrieveMapHandlers.slice(0);
        retrieveSourceMap = handlerExec(retrieveMapHandlers);
        retrieveFile = handlerExec(retrieveFileHandlers);
    };
},
/* source-map/source-map.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
     * Copyright 2009-2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE.txt or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    exports.SourceMapGenerator = require(24) /* ./lib/source-map-generator */.SourceMapGenerator;
    exports.SourceMapConsumer = require(30) /* ./lib/source-map-consumer */.SourceMapConsumer;
    exports.SourceNode = require(33) /* ./lib/source-node */.SourceNode;
},
/* source-map/lib/source-map-generator.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var base64VLQ = require(25) /* ./base64-vlq */;
    var util = require(27) /* ./util */;
    var ArraySet = require(28) /* ./array-set */.ArraySet;
    var MappingList = require(29) /* ./mapping-list */.MappingList;
    /**
     * An instance of the SourceMapGenerator represents a source map which is
     * being built incrementally. You may pass an object with the following
     * properties:
     *
     *   - file: The filename of the generated source.
     *   - sourceRoot: A root for all relative URLs in this source map.
     */
    function SourceMapGenerator(aArgs) {
        if (!aArgs) {
            aArgs = {};
        }
        this._file = util.getArg(aArgs, 'file', null);
        this._sourceRoot = util.getArg(aArgs, 'sourceRoot', null);
        this._skipValidation = util.getArg(aArgs, 'skipValidation', false);
        this._sources = new ArraySet();
        this._names = new ArraySet();
        this._mappings = new MappingList();
        this._sourcesContents = null;
    }
    SourceMapGenerator.prototype._version = 3;
    /**
     * Creates a new SourceMapGenerator based on a SourceMapConsumer
     *
     * @param aSourceMapConsumer The SourceMap.
     */
    SourceMapGenerator.fromSourceMap =
        function SourceMapGenerator_fromSourceMap(aSourceMapConsumer) {
            var sourceRoot = aSourceMapConsumer.sourceRoot;
            var generator = new SourceMapGenerator({
                file: aSourceMapConsumer.file,
                sourceRoot: sourceRoot
            });
            aSourceMapConsumer.eachMapping(function (mapping) {
                var newMapping = {
                    generated: {
                        line: mapping.generatedLine,
                        column: mapping.generatedColumn
                    }
                };
                if (mapping.source != null) {
                    newMapping.source = mapping.source;
                    if (sourceRoot != null) {
                        newMapping.source = util.relative(sourceRoot, newMapping.source);
                    }
                    newMapping.original = {
                        line: mapping.originalLine,
                        column: mapping.originalColumn
                    };
                    if (mapping.name != null) {
                        newMapping.name = mapping.name;
                    }
                }
                generator.addMapping(newMapping);
            });
            aSourceMapConsumer.sources.forEach(function (sourceFile) {
                var sourceRelative = sourceFile;
                if (sourceRoot !== null) {
                    sourceRelative = util.relative(sourceRoot, sourceFile);
                }
                if (!generator._sources.has(sourceRelative)) {
                    generator._sources.add(sourceRelative);
                }
                var content = aSourceMapConsumer.sourceContentFor(sourceFile);
                if (content != null) {
                    generator.setSourceContent(sourceFile, content);
                }
            });
            return generator;
        };
    /**
     * Add a single mapping from original source line and column to the generated
     * source's line and column for this source map being created. The mapping
     * object should have the following properties:
     *
     *   - generated: An object with the generated line and column positions.
     *   - original: An object with the original line and column positions.
     *   - source: The original source file (relative to the sourceRoot).
     *   - name: An optional original token name for this mapping.
     */
    SourceMapGenerator.prototype.addMapping =
        function SourceMapGenerator_addMapping(aArgs) {
            var generated = util.getArg(aArgs, 'generated');
            var original = util.getArg(aArgs, 'original', null);
            var source = util.getArg(aArgs, 'source', null);
            var name = util.getArg(aArgs, 'name', null);
            if (!this._skipValidation) {
                this._validateMapping(generated, original, source, name);
            }
            if (source != null) {
                source = String(source);
                if (!this._sources.has(source)) {
                    this._sources.add(source);
                }
            }
            if (name != null) {
                name = String(name);
                if (!this._names.has(name)) {
                    this._names.add(name);
                }
            }
            this._mappings.add({
                generatedLine: generated.line,
                generatedColumn: generated.column,
                originalLine: original != null && original.line,
                originalColumn: original != null && original.column,
                source: source,
                name: name
            });
        };
    /**
     * Set the source content for a source file.
     */
    SourceMapGenerator.prototype.setSourceContent =
        function SourceMapGenerator_setSourceContent(aSourceFile, aSourceContent) {
            var source = aSourceFile;
            if (this._sourceRoot != null) {
                source = util.relative(this._sourceRoot, source);
            }
            if (aSourceContent != null) {
                // Add the source content to the _sourcesContents map.
                // Create a new _sourcesContents map if the property is null.
                if (!this._sourcesContents) {
                    this._sourcesContents = Object.create(null);
                }
                this._sourcesContents[util.toSetString(source)] = aSourceContent;
            }
            else if (this._sourcesContents) {
                // Remove the source file from the _sourcesContents map.
                // If the _sourcesContents map is empty, set the property to null.
                delete this._sourcesContents[util.toSetString(source)];
                if (Object.keys(this._sourcesContents).length === 0) {
                    this._sourcesContents = null;
                }
            }
        };
    /**
     * Applies the mappings of a sub-source-map for a specific source file to the
     * source map being generated. Each mapping to the supplied source file is
     * rewritten using the supplied source map. Note: The resolution for the
     * resulting mappings is the minimium of this map and the supplied map.
     *
     * @param aSourceMapConsumer The source map to be applied.
     * @param aSourceFile Optional. The filename of the source file.
     *        If omitted, SourceMapConsumer's file property will be used.
     * @param aSourceMapPath Optional. The dirname of the path to the source map
     *        to be applied. If relative, it is relative to the SourceMapConsumer.
     *        This parameter is needed when the two source maps aren't in the same
     *        directory, and the source map to be applied contains relative source
     *        paths. If so, those relative source paths need to be rewritten
     *        relative to the SourceMapGenerator.
     */
    SourceMapGenerator.prototype.applySourceMap =
        function SourceMapGenerator_applySourceMap(aSourceMapConsumer, aSourceFile, aSourceMapPath) {
            var sourceFile = aSourceFile;
            // If aSourceFile is omitted, we will use the file property of the SourceMap
            if (aSourceFile == null) {
                if (aSourceMapConsumer.file == null) {
                    throw new Error('SourceMapGenerator.prototype.applySourceMap requires either an explicit source file, ' +
                        'or the source map\'s "file" property. Both were omitted.');
                }
                sourceFile = aSourceMapConsumer.file;
            }
            var sourceRoot = this._sourceRoot;
            // Make "sourceFile" relative if an absolute Url is passed.
            if (sourceRoot != null) {
                sourceFile = util.relative(sourceRoot, sourceFile);
            }
            // Applying the SourceMap can add and remove items from the sources and
            // the names array.
            var newSources = new ArraySet();
            var newNames = new ArraySet();
            // Find mappings for the "sourceFile"
            this._mappings.unsortedForEach(function (mapping) {
                if (mapping.source === sourceFile && mapping.originalLine != null) {
                    // Check if it can be mapped by the source map, then update the mapping.
                    var original = aSourceMapConsumer.originalPositionFor({
                        line: mapping.originalLine,
                        column: mapping.originalColumn
                    });
                    if (original.source != null) {
                        // Copy mapping
                        mapping.source = original.source;
                        if (aSourceMapPath != null) {
                            mapping.source = util.join(aSourceMapPath, mapping.source);
                        }
                        if (sourceRoot != null) {
                            mapping.source = util.relative(sourceRoot, mapping.source);
                        }
                        mapping.originalLine = original.line;
                        mapping.originalColumn = original.column;
                        if (original.name != null) {
                            mapping.name = original.name;
                        }
                    }
                }
                var source = mapping.source;
                if (source != null && !newSources.has(source)) {
                    newSources.add(source);
                }
                var name = mapping.name;
                if (name != null && !newNames.has(name)) {
                    newNames.add(name);
                }
            }, this);
            this._sources = newSources;
            this._names = newNames;
            // Copy sourcesContents of applied map.
            aSourceMapConsumer.sources.forEach(function (sourceFile) {
                var content = aSourceMapConsumer.sourceContentFor(sourceFile);
                if (content != null) {
                    if (aSourceMapPath != null) {
                        sourceFile = util.join(aSourceMapPath, sourceFile);
                    }
                    if (sourceRoot != null) {
                        sourceFile = util.relative(sourceRoot, sourceFile);
                    }
                    this.setSourceContent(sourceFile, content);
                }
            }, this);
        };
    /**
     * A mapping can have one of the three levels of data:
     *
     *   1. Just the generated position.
     *   2. The Generated position, original position, and original source.
     *   3. Generated and original position, original source, as well as a name
     *      token.
     *
     * To maintain consistency, we validate that any new mapping being added falls
     * in to one of these categories.
     */
    SourceMapGenerator.prototype._validateMapping =
        function SourceMapGenerator_validateMapping(aGenerated, aOriginal, aSource, aName) {
            // When aOriginal is truthy but has empty values for .line and .column,
            // it is most likely a programmer error. In this case we throw a very
            // specific error message to try to guide them the right way.
            // For example: https://github.com/Polymer/polymer-bundler/pull/519
            if (aOriginal && typeof aOriginal.line !== 'number' && typeof aOriginal.column !== 'number') {
                throw new Error('original.line and original.column are not numbers -- you probably meant to omit ' +
                    'the original mapping entirely and only map the generated position. If so, pass ' +
                    'null for the original mapping instead of an object with empty or null values.');
            }
            if (aGenerated && 'line' in aGenerated && 'column' in aGenerated
                && aGenerated.line > 0 && aGenerated.column >= 0
                && !aOriginal && !aSource && !aName) {
                // Case 1.
                return;
            }
            else if (aGenerated && 'line' in aGenerated && 'column' in aGenerated
                && aOriginal && 'line' in aOriginal && 'column' in aOriginal
                && aGenerated.line > 0 && aGenerated.column >= 0
                && aOriginal.line > 0 && aOriginal.column >= 0
                && aSource) {
                // Cases 2 and 3.
                return;
            }
            else {
                throw new Error('Invalid mapping: ' + JSON.stringify({
                    generated: aGenerated,
                    source: aSource,
                    original: aOriginal,
                    name: aName
                }));
            }
        };
    /**
     * Serialize the accumulated mappings in to the stream of base 64 VLQs
     * specified by the source map format.
     */
    SourceMapGenerator.prototype._serializeMappings =
        function SourceMapGenerator_serializeMappings() {
            var previousGeneratedColumn = 0;
            var previousGeneratedLine = 1;
            var previousOriginalColumn = 0;
            var previousOriginalLine = 0;
            var previousName = 0;
            var previousSource = 0;
            var result = '';
            var next;
            var mapping;
            var nameIdx;
            var sourceIdx;
            var mappings = this._mappings.toArray();
            for (var i = 0, len = mappings.length; i < len; i++) {
                mapping = mappings[i];
                next = '';
                if (mapping.generatedLine !== previousGeneratedLine) {
                    previousGeneratedColumn = 0;
                    while (mapping.generatedLine !== previousGeneratedLine) {
                        next += ';';
                        previousGeneratedLine++;
                    }
                }
                else {
                    if (i > 0) {
                        if (!util.compareByGeneratedPositionsInflated(mapping, mappings[i - 1])) {
                            continue;
                        }
                        next += ',';
                    }
                }
                next += base64VLQ.encode(mapping.generatedColumn
                    - previousGeneratedColumn);
                previousGeneratedColumn = mapping.generatedColumn;
                if (mapping.source != null) {
                    sourceIdx = this._sources.indexOf(mapping.source);
                    next += base64VLQ.encode(sourceIdx - previousSource);
                    previousSource = sourceIdx;
                    // lines are stored 0-based in SourceMap spec version 3
                    next += base64VLQ.encode(mapping.originalLine - 1
                        - previousOriginalLine);
                    previousOriginalLine = mapping.originalLine - 1;
                    next += base64VLQ.encode(mapping.originalColumn
                        - previousOriginalColumn);
                    previousOriginalColumn = mapping.originalColumn;
                    if (mapping.name != null) {
                        nameIdx = this._names.indexOf(mapping.name);
                        next += base64VLQ.encode(nameIdx - previousName);
                        previousName = nameIdx;
                    }
                }
                result += next;
            }
            return result;
        };
    SourceMapGenerator.prototype._generateSourcesContent =
        function SourceMapGenerator_generateSourcesContent(aSources, aSourceRoot) {
            return aSources.map(function (source) {
                if (!this._sourcesContents) {
                    return null;
                }
                if (aSourceRoot != null) {
                    source = util.relative(aSourceRoot, source);
                }
                var key = util.toSetString(source);
                return Object.prototype.hasOwnProperty.call(this._sourcesContents, key)
                    ? this._sourcesContents[key]
                    : null;
            }, this);
        };
    /**
     * Externalize the source map.
     */
    SourceMapGenerator.prototype.toJSON =
        function SourceMapGenerator_toJSON() {
            var map = {
                version: this._version,
                sources: this._sources.toArray(),
                names: this._names.toArray(),
                mappings: this._serializeMappings()
            };
            if (this._file != null) {
                map.file = this._file;
            }
            if (this._sourceRoot != null) {
                map.sourceRoot = this._sourceRoot;
            }
            if (this._sourcesContents) {
                map.sourcesContent = this._generateSourcesContent(map.sources, map.sourceRoot);
            }
            return map;
        };
    /**
     * Render the source map being generated to a string.
     */
    SourceMapGenerator.prototype.toString =
        function SourceMapGenerator_toString() {
            return JSON.stringify(this.toJSON());
        };
    exports.SourceMapGenerator = SourceMapGenerator;
},
/* source-map/lib/base64-vlq.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     *
     * Based on the Base 64 VLQ implementation in Closure Compiler:
     * https://code.google.com/p/closure-compiler/source/browse/trunk/src/com/google/debugging/sourcemap/Base64VLQ.java
     *
     * Copyright 2011 The Closure Compiler Authors. All rights reserved.
     * Redistribution and use in source and binary forms, with or without
     * modification, are permitted provided that the following conditions are
     * met:
     *
     *  * Redistributions of source code must retain the above copyright
     *    notice, this list of conditions and the following disclaimer.
     *  * Redistributions in binary form must reproduce the above
     *    copyright notice, this list of conditions and the following
     *    disclaimer in the documentation and/or other materials provided
     *    with the distribution.
     *  * Neither the name of Google Inc. nor the names of its
     *    contributors may be used to endorse or promote products derived
     *    from this software without specific prior written permission.
     *
     * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
     * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
     * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
     * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
     * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
     * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
     * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
     * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
     * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
     * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
     * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
     */
    var base64 = require(26) /* ./base64 */;
    // A single base 64 digit can contain 6 bits of data. For the base 64 variable
    // length quantities we use in the source map spec, the first bit is the sign,
    // the next four bits are the actual value, and the 6th bit is the
    // continuation bit. The continuation bit tells us whether there are more
    // digits in this value following this digit.
    //
    //   Continuation
    //   |    Sign
    //   |    |
    //   V    V
    //   101011
    var VLQ_BASE_SHIFT = 5;
    // binary: 100000
    var VLQ_BASE = 1 << VLQ_BASE_SHIFT;
    // binary: 011111
    var VLQ_BASE_MASK = VLQ_BASE - 1;
    // binary: 100000
    var VLQ_CONTINUATION_BIT = VLQ_BASE;
    /**
     * Converts from a two-complement value to a value where the sign bit is
     * placed in the least significant bit.  For example, as decimals:
     *   1 becomes 2 (10 binary), -1 becomes 3 (11 binary)
     *   2 becomes 4 (100 binary), -2 becomes 5 (101 binary)
     */
    function toVLQSigned(aValue) {
        return aValue < 0
            ? ((-aValue) << 1) + 1
            : (aValue << 1) + 0;
    }
    /**
     * Converts to a two-complement value from a value where the sign bit is
     * placed in the least significant bit.  For example, as decimals:
     *   2 (10 binary) becomes 1, 3 (11 binary) becomes -1
     *   4 (100 binary) becomes 2, 5 (101 binary) becomes -2
     */
    function fromVLQSigned(aValue) {
        var isNegative = (aValue & 1) === 1;
        var shifted = aValue >> 1;
        return isNegative
            ? -shifted
            : shifted;
    }
    /**
     * Returns the base 64 VLQ encoded value.
     */
    exports.encode = function base64VLQ_encode(aValue) {
        var encoded = "";
        var digit;
        var vlq = toVLQSigned(aValue);
        do {
            digit = vlq & VLQ_BASE_MASK;
            vlq >>>= VLQ_BASE_SHIFT;
            if (vlq > 0) {
                // There are still more digits in this value, so we must make sure the
                // continuation bit is marked.
                digit |= VLQ_CONTINUATION_BIT;
            }
            encoded += base64.encode(digit);
        } while (vlq > 0);
        return encoded;
    };
    /**
     * Decodes the next base 64 VLQ value from the given string and returns the
     * value and the rest of the string via the out parameter.
     */
    exports.decode = function base64VLQ_decode(aStr, aIndex, aOutParam) {
        var strLen = aStr.length;
        var result = 0;
        var shift = 0;
        var continuation, digit;
        do {
            if (aIndex >= strLen) {
                throw new Error("Expected more digits in base 64 VLQ value.");
            }
            digit = base64.decode(aStr.charCodeAt(aIndex++));
            if (digit === -1) {
                throw new Error("Invalid base64 digit: " + aStr.charAt(aIndex - 1));
            }
            continuation = !!(digit & VLQ_CONTINUATION_BIT);
            digit &= VLQ_BASE_MASK;
            result = result + (digit << shift);
            shift += VLQ_BASE_SHIFT;
        } while (continuation);
        aOutParam.value = fromVLQSigned(result);
        aOutParam.rest = aIndex;
    };
},
/* source-map/lib/base64.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var intToCharMap = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'.split('');
    /**
     * Encode an integer in the range of 0 to 63 to a single base 64 digit.
     */
    exports.encode = function (number) {
        if (0 <= number && number < intToCharMap.length) {
            return intToCharMap[number];
        }
        throw new TypeError("Must be between 0 and 63: " + number);
    };
    /**
     * Decode a single base 64 character code digit to an integer. Returns -1 on
     * failure.
     */
    exports.decode = function (charCode) {
        var bigA = 65; // 'A'
        var bigZ = 90; // 'Z'
        var littleA = 97; // 'a'
        var littleZ = 122; // 'z'
        var zero = 48; // '0'
        var nine = 57; // '9'
        var plus = 43; // '+'
        var slash = 47; // '/'
        var littleOffset = 26;
        var numberOffset = 52;
        // 0 - 25: ABCDEFGHIJKLMNOPQRSTUVWXYZ
        if (bigA <= charCode && charCode <= bigZ) {
            return (charCode - bigA);
        }
        // 26 - 51: abcdefghijklmnopqrstuvwxyz
        if (littleA <= charCode && charCode <= littleZ) {
            return (charCode - littleA + littleOffset);
        }
        // 52 - 61: 0123456789
        if (zero <= charCode && charCode <= nine) {
            return (charCode - zero + numberOffset);
        }
        // 62: +
        if (charCode == plus) {
            return 62;
        }
        // 63: /
        if (charCode == slash) {
            return 63;
        }
        // Invalid base64 digit.
        return -1;
    };
},
/* source-map/lib/util.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    /**
     * This is a helper function for getting values from parameter/options
     * objects.
     *
     * @param args The object we are extracting values from
     * @param name The name of the property we are getting.
     * @param defaultValue An optional value to return if the property is missing
     * from the object. If this is not specified and the property is missing, an
     * error will be thrown.
     */
    function getArg(aArgs, aName, aDefaultValue) {
        if (aName in aArgs) {
            return aArgs[aName];
        }
        else if (arguments.length === 3) {
            return aDefaultValue;
        }
        else {
            throw new Error('"' + aName + '" is a required argument.');
        }
    }
    exports.getArg = getArg;
    var urlRegexp = /^(?:([\w+\-.]+):)?\/\/(?:(\w+:\w+)@)?([\w.-]*)(?::(\d+))?(.*)$/;
    var dataUrlRegexp = /^data:.+\,.+$/;
    function urlParse(aUrl) {
        var match = aUrl.match(urlRegexp);
        if (!match) {
            return null;
        }
        return {
            scheme: match[1],
            auth: match[2],
            host: match[3],
            port: match[4],
            path: match[5]
        };
    }
    exports.urlParse = urlParse;
    function urlGenerate(aParsedUrl) {
        var url = '';
        if (aParsedUrl.scheme) {
            url += aParsedUrl.scheme + ':';
        }
        url += '//';
        if (aParsedUrl.auth) {
            url += aParsedUrl.auth + '@';
        }
        if (aParsedUrl.host) {
            url += aParsedUrl.host;
        }
        if (aParsedUrl.port) {
            url += ":" + aParsedUrl.port;
        }
        if (aParsedUrl.path) {
            url += aParsedUrl.path;
        }
        return url;
    }
    exports.urlGenerate = urlGenerate;
    /**
     * Normalizes a path, or the path portion of a URL:
     *
     * - Replaces consecutive slashes with one slash.
     * - Removes unnecessary '.' parts.
     * - Removes unnecessary '<dir>/..' parts.
     *
     * Based on code in the Node.js 'path' core module.
     *
     * @param aPath The path or url to normalize.
     */
    function normalize(aPath) {
        var path = aPath;
        var url = urlParse(aPath);
        if (url) {
            if (!url.path) {
                return aPath;
            }
            path = url.path;
        }
        var isAbsolute = exports.isAbsolute(path);
        var parts = path.split(/\/+/);
        for (var part, up = 0, i = parts.length - 1; i >= 0; i--) {
            part = parts[i];
            if (part === '.') {
                parts.splice(i, 1);
            }
            else if (part === '..') {
                up++;
            }
            else if (up > 0) {
                if (part === '') {
                    // The first part is blank if the path is absolute. Trying to go
                    // above the root is a no-op. Therefore we can remove all '..' parts
                    // directly after the root.
                    parts.splice(i + 1, up);
                    up = 0;
                }
                else {
                    parts.splice(i, 2);
                    up--;
                }
            }
        }
        path = parts.join('/');
        if (path === '') {
            path = isAbsolute ? '/' : '.';
        }
        if (url) {
            url.path = path;
            return urlGenerate(url);
        }
        return path;
    }
    exports.normalize = normalize;
    /**
     * Joins two paths/URLs.
     *
     * @param aRoot The root path or URL.
     * @param aPath The path or URL to be joined with the root.
     *
     * - If aPath is a URL or a data URI, aPath is returned, unless aPath is a
     *   scheme-relative URL: Then the scheme of aRoot, if any, is prepended
     *   first.
     * - Otherwise aPath is a path. If aRoot is a URL, then its path portion
     *   is updated with the result and aRoot is returned. Otherwise the result
     *   is returned.
     *   - If aPath is absolute, the result is aPath.
     *   - Otherwise the two paths are joined with a slash.
     * - Joining for example 'http://' and 'www.example.com' is also supported.
     */
    function join(aRoot, aPath) {
        if (aRoot === "") {
            aRoot = ".";
        }
        if (aPath === "") {
            aPath = ".";
        }
        var aPathUrl = urlParse(aPath);
        var aRootUrl = urlParse(aRoot);
        if (aRootUrl) {
            aRoot = aRootUrl.path || '/';
        }
        // `join(foo, '//www.example.org')`
        if (aPathUrl && !aPathUrl.scheme) {
            if (aRootUrl) {
                aPathUrl.scheme = aRootUrl.scheme;
            }
            return urlGenerate(aPathUrl);
        }
        if (aPathUrl || aPath.match(dataUrlRegexp)) {
            return aPath;
        }
        // `join('http://', 'www.example.com')`
        if (aRootUrl && !aRootUrl.host && !aRootUrl.path) {
            aRootUrl.host = aPath;
            return urlGenerate(aRootUrl);
        }
        var joined = aPath.charAt(0) === '/'
            ? aPath
            : normalize(aRoot.replace(/\/+$/, '') + '/' + aPath);
        if (aRootUrl) {
            aRootUrl.path = joined;
            return urlGenerate(aRootUrl);
        }
        return joined;
    }
    exports.join = join;
    exports.isAbsolute = function (aPath) {
        return aPath.charAt(0) === '/' || urlRegexp.test(aPath);
    };
    /**
     * Make a path relative to a URL or another path.
     *
     * @param aRoot The root path or URL.
     * @param aPath The path or URL to be made relative to aRoot.
     */
    function relative(aRoot, aPath) {
        if (aRoot === "") {
            aRoot = ".";
        }
        aRoot = aRoot.replace(/\/$/, '');
        // It is possible for the path to be above the root. In this case, simply
        // checking whether the root is a prefix of the path won't work. Instead, we
        // need to remove components from the root one by one, until either we find
        // a prefix that fits, or we run out of components to remove.
        var level = 0;
        while (aPath.indexOf(aRoot + '/') !== 0) {
            var index = aRoot.lastIndexOf("/");
            if (index < 0) {
                return aPath;
            }
            // If the only part of the root that is left is the scheme (i.e. http://,
            // file:///, etc.), one or more slashes (/), or simply nothing at all, we
            // have exhausted all components, so the path is not relative to the root.
            aRoot = aRoot.slice(0, index);
            if (aRoot.match(/^([^\/]+:\/)?\/*$/)) {
                return aPath;
            }
            ++level;
        }
        // Make sure we add a "../" for each component we removed from the root.
        return Array(level + 1).join("../") + aPath.substr(aRoot.length + 1);
    }
    exports.relative = relative;
    var supportsNullProto = (function () {
        var obj = Object.create(null);
        return !('__proto__' in obj);
    }());
    function identity(s) {
        return s;
    }
    /**
     * Because behavior goes wacky when you set `__proto__` on objects, we
     * have to prefix all the strings in our set with an arbitrary character.
     *
     * See https://github.com/mozilla/source-map/pull/31 and
     * https://github.com/mozilla/source-map/issues/30
     *
     * @param String aStr
     */
    function toSetString(aStr) {
        if (isProtoString(aStr)) {
            return '$' + aStr;
        }
        return aStr;
    }
    exports.toSetString = supportsNullProto ? identity : toSetString;
    function fromSetString(aStr) {
        if (isProtoString(aStr)) {
            return aStr.slice(1);
        }
        return aStr;
    }
    exports.fromSetString = supportsNullProto ? identity : fromSetString;
    function isProtoString(s) {
        if (!s) {
            return false;
        }
        var length = s.length;
        if (length < 9 /* "__proto__".length */) {
            return false;
        }
        if (s.charCodeAt(length - 1) !== 95 /* '_' */ ||
            s.charCodeAt(length - 2) !== 95 /* '_' */ ||
            s.charCodeAt(length - 3) !== 111 /* 'o' */ ||
            s.charCodeAt(length - 4) !== 116 /* 't' */ ||
            s.charCodeAt(length - 5) !== 111 /* 'o' */ ||
            s.charCodeAt(length - 6) !== 114 /* 'r' */ ||
            s.charCodeAt(length - 7) !== 112 /* 'p' */ ||
            s.charCodeAt(length - 8) !== 95 /* '_' */ ||
            s.charCodeAt(length - 9) !== 95 /* '_' */) {
            return false;
        }
        for (var i = length - 10; i >= 0; i--) {
            if (s.charCodeAt(i) !== 36 /* '$' */) {
                return false;
            }
        }
        return true;
    }
    /**
     * Comparator between two mappings where the original positions are compared.
     *
     * Optionally pass in `true` as `onlyCompareGenerated` to consider two
     * mappings with the same original source/line/column, but different generated
     * line and column the same. Useful when searching for a mapping with a
     * stubbed out mapping.
     */
    function compareByOriginalPositions(mappingA, mappingB, onlyCompareOriginal) {
        var cmp = strcmp(mappingA.source, mappingB.source);
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalLine - mappingB.originalLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalColumn - mappingB.originalColumn;
        if (cmp !== 0 || onlyCompareOriginal) {
            return cmp;
        }
        cmp = mappingA.generatedColumn - mappingB.generatedColumn;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.generatedLine - mappingB.generatedLine;
        if (cmp !== 0) {
            return cmp;
        }
        return strcmp(mappingA.name, mappingB.name);
    }
    exports.compareByOriginalPositions = compareByOriginalPositions;
    /**
     * Comparator between two mappings with deflated source and name indices where
     * the generated positions are compared.
     *
     * Optionally pass in `true` as `onlyCompareGenerated` to consider two
     * mappings with the same generated line and column, but different
     * source/name/original line and column the same. Useful when searching for a
     * mapping with a stubbed out mapping.
     */
    function compareByGeneratedPositionsDeflated(mappingA, mappingB, onlyCompareGenerated) {
        var cmp = mappingA.generatedLine - mappingB.generatedLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.generatedColumn - mappingB.generatedColumn;
        if (cmp !== 0 || onlyCompareGenerated) {
            return cmp;
        }
        cmp = strcmp(mappingA.source, mappingB.source);
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalLine - mappingB.originalLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalColumn - mappingB.originalColumn;
        if (cmp !== 0) {
            return cmp;
        }
        return strcmp(mappingA.name, mappingB.name);
    }
    exports.compareByGeneratedPositionsDeflated = compareByGeneratedPositionsDeflated;
    function strcmp(aStr1, aStr2) {
        if (aStr1 === aStr2) {
            return 0;
        }
        if (aStr1 === null) {
            return 1; // aStr2 !== null
        }
        if (aStr2 === null) {
            return -1; // aStr1 !== null
        }
        if (aStr1 > aStr2) {
            return 1;
        }
        return -1;
    }
    /**
     * Comparator between two mappings with inflated source and name strings where
     * the generated positions are compared.
     */
    function compareByGeneratedPositionsInflated(mappingA, mappingB) {
        var cmp = mappingA.generatedLine - mappingB.generatedLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.generatedColumn - mappingB.generatedColumn;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = strcmp(mappingA.source, mappingB.source);
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalLine - mappingB.originalLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalColumn - mappingB.originalColumn;
        if (cmp !== 0) {
            return cmp;
        }
        return strcmp(mappingA.name, mappingB.name);
    }
    exports.compareByGeneratedPositionsInflated = compareByGeneratedPositionsInflated;
    /**
     * Strip any JSON XSSI avoidance prefix from the string (as documented
     * in the source maps specification), and then parse the string as
     * JSON.
     */
    function parseSourceMapInput(str) {
        return JSON.parse(str.replace(/^\)]}'[^\n]*\n/, ''));
    }
    exports.parseSourceMapInput = parseSourceMapInput;
    /**
     * Compute the URL of a source given the the source root, the source's
     * URL, and the source map's URL.
     */
    function computeSourceURL(sourceRoot, sourceURL, sourceMapURL) {
        sourceURL = sourceURL || '';
        if (sourceRoot) {
            // This follows what Chrome does.
            if (sourceRoot[sourceRoot.length - 1] !== '/' && sourceURL[0] !== '/') {
                sourceRoot += '/';
            }
            // The spec says:
            //   Line 4: An optional source root, useful for relocating source
            //   files on a server or removing repeated values in the
            //   “sources” entry.  This value is prepended to the individual
            //   entries in the “source” field.
            sourceURL = sourceRoot + sourceURL;
        }
        // Historically, SourceMapConsumer did not take the sourceMapURL as
        // a parameter.  This mode is still somewhat supported, which is why
        // this code block is conditional.  However, it's preferable to pass
        // the source map URL to SourceMapConsumer, so that this function
        // can implement the source URL resolution algorithm as outlined in
        // the spec.  This block is basically the equivalent of:
        //    new URL(sourceURL, sourceMapURL).toString()
        // ... except it avoids using URL, which wasn't available in the
        // older releases of node still supported by this library.
        //
        // The spec says:
        //   If the sources are not absolute URLs after prepending of the
        //   “sourceRoot”, the sources are resolved relative to the
        //   SourceMap (like resolving script src in a html document).
        if (sourceMapURL) {
            var parsed = urlParse(sourceMapURL);
            if (!parsed) {
                throw new Error("sourceMapURL could not be parsed");
            }
            if (parsed.path) {
                // Strip the last path component, but keep the "/".
                var index = parsed.path.lastIndexOf('/');
                if (index >= 0) {
                    parsed.path = parsed.path.substring(0, index + 1);
                }
            }
            sourceURL = join(urlGenerate(parsed), sourceURL);
        }
        return normalize(sourceURL);
    }
    exports.computeSourceURL = computeSourceURL;
},
/* source-map/lib/array-set.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var util = require(27) /* ./util */;
    var has = Object.prototype.hasOwnProperty;
    var hasNativeMap = typeof Map !== "undefined";
    /**
     * A data structure which is a combination of an array and a set. Adding a new
     * member is O(1), testing for membership is O(1), and finding the index of an
     * element is O(1). Removing elements from the set is not supported. Only
     * strings are supported for membership.
     */
    function ArraySet() {
        this._array = [];
        this._set = hasNativeMap ? new Map() : Object.create(null);
    }
    /**
     * Static method for creating ArraySet instances from an existing array.
     */
    ArraySet.fromArray = function ArraySet_fromArray(aArray, aAllowDuplicates) {
        var set = new ArraySet();
        for (var i = 0, len = aArray.length; i < len; i++) {
            set.add(aArray[i], aAllowDuplicates);
        }
        return set;
    };
    /**
     * Return how many unique items are in this ArraySet. If duplicates have been
     * added, than those do not count towards the size.
     *
     * @returns Number
     */
    ArraySet.prototype.size = function ArraySet_size() {
        return hasNativeMap ? this._set.size : Object.getOwnPropertyNames(this._set).length;
    };
    /**
     * Add the given string to this set.
     *
     * @param String aStr
     */
    ArraySet.prototype.add = function ArraySet_add(aStr, aAllowDuplicates) {
        var sStr = hasNativeMap ? aStr : util.toSetString(aStr);
        var isDuplicate = hasNativeMap ? this.has(aStr) : has.call(this._set, sStr);
        var idx = this._array.length;
        if (!isDuplicate || aAllowDuplicates) {
            this._array.push(aStr);
        }
        if (!isDuplicate) {
            if (hasNativeMap) {
                this._set.set(aStr, idx);
            }
            else {
                this._set[sStr] = idx;
            }
        }
    };
    /**
     * Is the given string a member of this set?
     *
     * @param String aStr
     */
    ArraySet.prototype.has = function ArraySet_has(aStr) {
        if (hasNativeMap) {
            return this._set.has(aStr);
        }
        else {
            var sStr = util.toSetString(aStr);
            return has.call(this._set, sStr);
        }
    };
    /**
     * What is the index of the given string in the array?
     *
     * @param String aStr
     */
    ArraySet.prototype.indexOf = function ArraySet_indexOf(aStr) {
        if (hasNativeMap) {
            var idx = this._set.get(aStr);
            if (idx >= 0) {
                return idx;
            }
        }
        else {
            var sStr = util.toSetString(aStr);
            if (has.call(this._set, sStr)) {
                return this._set[sStr];
            }
        }
        throw new Error('"' + aStr + '" is not in the set.');
    };
    /**
     * What is the element at the given index?
     *
     * @param Number aIdx
     */
    ArraySet.prototype.at = function ArraySet_at(aIdx) {
        if (aIdx >= 0 && aIdx < this._array.length) {
            return this._array[aIdx];
        }
        throw new Error('No element indexed by ' + aIdx);
    };
    /**
     * Returns the array representation of this set (which has the proper indices
     * indicated by indexOf). Note that this is a copy of the internal array used
     * for storing the members so that no one can mess with internal state.
     */
    ArraySet.prototype.toArray = function ArraySet_toArray() {
        return this._array.slice();
    };
    exports.ArraySet = ArraySet;
},
/* source-map/lib/mapping-list.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2014 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var util = require(27) /* ./util */;
    /**
     * Determine whether mappingB is after mappingA with respect to generated
     * position.
     */
    function generatedPositionAfter(mappingA, mappingB) {
        // Optimized for most common case
        var lineA = mappingA.generatedLine;
        var lineB = mappingB.generatedLine;
        var columnA = mappingA.generatedColumn;
        var columnB = mappingB.generatedColumn;
        return lineB > lineA || lineB == lineA && columnB >= columnA ||
            util.compareByGeneratedPositionsInflated(mappingA, mappingB) <= 0;
    }
    /**
     * A data structure to provide a sorted view of accumulated mappings in a
     * performance conscious manner. It trades a neglibable overhead in general
     * case for a large speedup in case of mappings being added in order.
     */
    function MappingList() {
        this._array = [];
        this._sorted = true;
        // Serves as infimum
        this._last = { generatedLine: -1, generatedColumn: 0 };
    }
    /**
     * Iterate through internal items. This method takes the same arguments that
     * `Array.prototype.forEach` takes.
     *
     * NOTE: The order of the mappings is NOT guaranteed.
     */
    MappingList.prototype.unsortedForEach =
        function MappingList_forEach(aCallback, aThisArg) {
            this._array.forEach(aCallback, aThisArg);
        };
    /**
     * Add the given source mapping.
     *
     * @param Object aMapping
     */
    MappingList.prototype.add = function MappingList_add(aMapping) {
        if (generatedPositionAfter(this._last, aMapping)) {
            this._last = aMapping;
            this._array.push(aMapping);
        }
        else {
            this._sorted = false;
            this._array.push(aMapping);
        }
    };
    /**
     * Returns the flat, sorted array of mappings. The mappings are sorted by
     * generated position.
     *
     * WARNING: This method returns internal data without copying, for
     * performance. The return value must NOT be mutated, and should be treated as
     * an immutable borrow. If you want to take ownership, you must make your own
     * copy.
     */
    MappingList.prototype.toArray = function MappingList_toArray() {
        if (!this._sorted) {
            this._array.sort(util.compareByGeneratedPositionsInflated);
            this._sorted = true;
        }
        return this._array;
    };
    exports.MappingList = MappingList;
},
/* source-map/lib/source-map-consumer.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var util = require(27) /* ./util */;
    var binarySearch = require(31) /* ./binary-search */;
    var ArraySet = require(28) /* ./array-set */.ArraySet;
    var base64VLQ = require(25) /* ./base64-vlq */;
    var quickSort = require(32) /* ./quick-sort */.quickSort;
    function SourceMapConsumer(aSourceMap, aSourceMapURL) {
        var sourceMap = aSourceMap;
        if (typeof aSourceMap === 'string') {
            sourceMap = util.parseSourceMapInput(aSourceMap);
        }
        return sourceMap.sections != null
            ? new IndexedSourceMapConsumer(sourceMap, aSourceMapURL)
            : new BasicSourceMapConsumer(sourceMap, aSourceMapURL);
    }
    SourceMapConsumer.fromSourceMap = function (aSourceMap, aSourceMapURL) {
        return BasicSourceMapConsumer.fromSourceMap(aSourceMap, aSourceMapURL);
    };
    /**
     * The version of the source mapping spec that we are consuming.
     */
    SourceMapConsumer.prototype._version = 3;
    // `__generatedMappings` and `__originalMappings` are arrays that hold the
    // parsed mapping coordinates from the source map's "mappings" attribute. They
    // are lazily instantiated, accessed via the `_generatedMappings` and
    // `_originalMappings` getters respectively, and we only parse the mappings
    // and create these arrays once queried for a source location. We jump through
    // these hoops because there can be many thousands of mappings, and parsing
    // them is expensive, so we only want to do it if we must.
    //
    // Each object in the arrays is of the form:
    //
    //     {
    //       generatedLine: The line number in the generated code,
    //       generatedColumn: The column number in the generated code,
    //       source: The path to the original source file that generated this
    //               chunk of code,
    //       originalLine: The line number in the original source that
    //                     corresponds to this chunk of generated code,
    //       originalColumn: The column number in the original source that
    //                       corresponds to this chunk of generated code,
    //       name: The name of the original symbol which generated this chunk of
    //             code.
    //     }
    //
    // All properties except for `generatedLine` and `generatedColumn` can be
    // `null`.
    //
    // `_generatedMappings` is ordered by the generated positions.
    //
    // `_originalMappings` is ordered by the original positions.
    SourceMapConsumer.prototype.__generatedMappings = null;
    Object.defineProperty(SourceMapConsumer.prototype, '_generatedMappings', {
        configurable: true,
        enumerable: true,
        get: function () {
            if (!this.__generatedMappings) {
                this._parseMappings(this._mappings, this.sourceRoot);
            }
            return this.__generatedMappings;
        }
    });
    SourceMapConsumer.prototype.__originalMappings = null;
    Object.defineProperty(SourceMapConsumer.prototype, '_originalMappings', {
        configurable: true,
        enumerable: true,
        get: function () {
            if (!this.__originalMappings) {
                this._parseMappings(this._mappings, this.sourceRoot);
            }
            return this.__originalMappings;
        }
    });
    SourceMapConsumer.prototype._charIsMappingSeparator =
        function SourceMapConsumer_charIsMappingSeparator(aStr, index) {
            var c = aStr.charAt(index);
            return c === ";" || c === ",";
        };
    /**
     * Parse the mappings in a string in to a data structure which we can easily
     * query (the ordered arrays in the `this.__generatedMappings` and
     * `this.__originalMappings` properties).
     */
    SourceMapConsumer.prototype._parseMappings =
        function SourceMapConsumer_parseMappings(aStr, aSourceRoot) {
            throw new Error("Subclasses must implement _parseMappings");
        };
    SourceMapConsumer.GENERATED_ORDER = 1;
    SourceMapConsumer.ORIGINAL_ORDER = 2;
    SourceMapConsumer.GREATEST_LOWER_BOUND = 1;
    SourceMapConsumer.LEAST_UPPER_BOUND = 2;
    /**
     * Iterate over each mapping between an original source/line/column and a
     * generated line/column in this source map.
     *
     * @param Function aCallback
     *        The function that is called with each mapping.
     * @param Object aContext
     *        Optional. If specified, this object will be the value of `this` every
     *        time that `aCallback` is called.
     * @param aOrder
     *        Either `SourceMapConsumer.GENERATED_ORDER` or
     *        `SourceMapConsumer.ORIGINAL_ORDER`. Specifies whether you want to
     *        iterate over the mappings sorted by the generated file's line/column
     *        order or the original's source/line/column order, respectively. Defaults to
     *        `SourceMapConsumer.GENERATED_ORDER`.
     */
    SourceMapConsumer.prototype.eachMapping =
        function SourceMapConsumer_eachMapping(aCallback, aContext, aOrder) {
            var context = aContext || null;
            var order = aOrder || SourceMapConsumer.GENERATED_ORDER;
            var mappings;
            switch (order) {
                case SourceMapConsumer.GENERATED_ORDER:
                    mappings = this._generatedMappings;
                    break;
                case SourceMapConsumer.ORIGINAL_ORDER:
                    mappings = this._originalMappings;
                    break;
                default:
                    throw new Error("Unknown order of iteration.");
            }
            var sourceRoot = this.sourceRoot;
            mappings.map(function (mapping) {
                var source = mapping.source === null ? null : this._sources.at(mapping.source);
                source = util.computeSourceURL(sourceRoot, source, this._sourceMapURL);
                return {
                    source: source,
                    generatedLine: mapping.generatedLine,
                    generatedColumn: mapping.generatedColumn,
                    originalLine: mapping.originalLine,
                    originalColumn: mapping.originalColumn,
                    name: mapping.name === null ? null : this._names.at(mapping.name)
                };
            }, this).forEach(aCallback, context);
        };
    /**
     * Returns all generated line and column information for the original source,
     * line, and column provided. If no column is provided, returns all mappings
     * corresponding to a either the line we are searching for or the next
     * closest line that has any mappings. Otherwise, returns all mappings
     * corresponding to the given line and either the column we are searching for
     * or the next closest column that has any offsets.
     *
     * The only argument is an object with the following properties:
     *
     *   - source: The filename of the original source.
     *   - line: The line number in the original source.  The line number is 1-based.
     *   - column: Optional. the column number in the original source.
     *    The column number is 0-based.
     *
     * and an array of objects is returned, each with the following properties:
     *
     *   - line: The line number in the generated source, or null.  The
     *    line number is 1-based.
     *   - column: The column number in the generated source, or null.
     *    The column number is 0-based.
     */
    SourceMapConsumer.prototype.allGeneratedPositionsFor =
        function SourceMapConsumer_allGeneratedPositionsFor(aArgs) {
            var line = util.getArg(aArgs, 'line');
            // When there is no exact match, BasicSourceMapConsumer.prototype._findMapping
            // returns the index of the closest mapping less than the needle. By
            // setting needle.originalColumn to 0, we thus find the last mapping for
            // the given line, provided such a mapping exists.
            var needle = {
                source: util.getArg(aArgs, 'source'),
                originalLine: line,
                originalColumn: util.getArg(aArgs, 'column', 0)
            };
            needle.source = this._findSourceIndex(needle.source);
            if (needle.source < 0) {
                return [];
            }
            var mappings = [];
            var index = this._findMapping(needle, this._originalMappings, "originalLine", "originalColumn", util.compareByOriginalPositions, binarySearch.LEAST_UPPER_BOUND);
            if (index >= 0) {
                var mapping = this._originalMappings[index];
                if (aArgs.column === undefined) {
                    var originalLine = mapping.originalLine;
                    // Iterate until either we run out of mappings, or we run into
                    // a mapping for a different line than the one we found. Since
                    // mappings are sorted, this is guaranteed to find all mappings for
                    // the line we found.
                    while (mapping && mapping.originalLine === originalLine) {
                        mappings.push({
                            line: util.getArg(mapping, 'generatedLine', null),
                            column: util.getArg(mapping, 'generatedColumn', null),
                            lastColumn: util.getArg(mapping, 'lastGeneratedColumn', null)
                        });
                        mapping = this._originalMappings[++index];
                    }
                }
                else {
                    var originalColumn = mapping.originalColumn;
                    // Iterate until either we run out of mappings, or we run into
                    // a mapping for a different line than the one we were searching for.
                    // Since mappings are sorted, this is guaranteed to find all mappings for
                    // the line we are searching for.
                    while (mapping &&
                        mapping.originalLine === line &&
                        mapping.originalColumn == originalColumn) {
                        mappings.push({
                            line: util.getArg(mapping, 'generatedLine', null),
                            column: util.getArg(mapping, 'generatedColumn', null),
                            lastColumn: util.getArg(mapping, 'lastGeneratedColumn', null)
                        });
                        mapping = this._originalMappings[++index];
                    }
                }
            }
            return mappings;
        };
    exports.SourceMapConsumer = SourceMapConsumer;
    /**
     * A BasicSourceMapConsumer instance represents a parsed source map which we can
     * query for information about the original file positions by giving it a file
     * position in the generated source.
     *
     * The first parameter is the raw source map (either as a JSON string, or
     * already parsed to an object). According to the spec, source maps have the
     * following attributes:
     *
     *   - version: Which version of the source map spec this map is following.
     *   - sources: An array of URLs to the original source files.
     *   - names: An array of identifiers which can be referrenced by individual mappings.
     *   - sourceRoot: Optional. The URL root from which all sources are relative.
     *   - sourcesContent: Optional. An array of contents of the original source files.
     *   - mappings: A string of base64 VLQs which contain the actual mappings.
     *   - file: Optional. The generated file this source map is associated with.
     *
     * Here is an example source map, taken from the source map spec[0]:
     *
     *     {
     *       version : 3,
     *       file: "out.js",
     *       sourceRoot : "",
     *       sources: ["foo.js", "bar.js"],
     *       names: ["src", "maps", "are", "fun"],
     *       mappings: "AA,AB;;ABCDE;"
     *     }
     *
     * The second parameter, if given, is a string whose value is the URL
     * at which the source map was found.  This URL is used to compute the
     * sources array.
     *
     * [0]: https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit?pli=1#
     */
    function BasicSourceMapConsumer(aSourceMap, aSourceMapURL) {
        var sourceMap = aSourceMap;
        if (typeof aSourceMap === 'string') {
            sourceMap = util.parseSourceMapInput(aSourceMap);
        }
        var version = util.getArg(sourceMap, 'version');
        var sources = util.getArg(sourceMap, 'sources');
        // Sass 3.3 leaves out the 'names' array, so we deviate from the spec (which
        // requires the array) to play nice here.
        var names = util.getArg(sourceMap, 'names', []);
        var sourceRoot = util.getArg(sourceMap, 'sourceRoot', null);
        var sourcesContent = util.getArg(sourceMap, 'sourcesContent', null);
        var mappings = util.getArg(sourceMap, 'mappings');
        var file = util.getArg(sourceMap, 'file', null);
        // Once again, Sass deviates from the spec and supplies the version as a
        // string rather than a number, so we use loose equality checking here.
        if (version != this._version) {
            throw new Error('Unsupported version: ' + version);
        }
        if (sourceRoot) {
            sourceRoot = util.normalize(sourceRoot);
        }
        sources = sources
            .map(String)
            // Some source maps produce relative source paths like "./foo.js" instead of
            // "foo.js".  Normalize these first so that future comparisons will succeed.
            // See bugzil.la/1090768.
            .map(util.normalize)
            // Always ensure that absolute sources are internally stored relative to
            // the source root, if the source root is absolute. Not doing this would
            // be particularly problematic when the source root is a prefix of the
            // source (valid, but why??). See github issue #199 and bugzil.la/1188982.
            .map(function (source) {
            return sourceRoot && util.isAbsolute(sourceRoot) && util.isAbsolute(source)
                ? util.relative(sourceRoot, source)
                : source;
        });
        // Pass `true` below to allow duplicate names and sources. While source maps
        // are intended to be compressed and deduplicated, the TypeScript compiler
        // sometimes generates source maps with duplicates in them. See Github issue
        // #72 and bugzil.la/889492.
        this._names = ArraySet.fromArray(names.map(String), true);
        this._sources = ArraySet.fromArray(sources, true);
        this._absoluteSources = this._sources.toArray().map(function (s) {
            return util.computeSourceURL(sourceRoot, s, aSourceMapURL);
        });
        this.sourceRoot = sourceRoot;
        this.sourcesContent = sourcesContent;
        this._mappings = mappings;
        this._sourceMapURL = aSourceMapURL;
        this.file = file;
    }
    BasicSourceMapConsumer.prototype = Object.create(SourceMapConsumer.prototype);
    BasicSourceMapConsumer.prototype.consumer = SourceMapConsumer;
    /**
     * Utility function to find the index of a source.  Returns -1 if not
     * found.
     */
    BasicSourceMapConsumer.prototype._findSourceIndex = function (aSource) {
        var relativeSource = aSource;
        if (this.sourceRoot != null) {
            relativeSource = util.relative(this.sourceRoot, relativeSource);
        }
        if (this._sources.has(relativeSource)) {
            return this._sources.indexOf(relativeSource);
        }
        // Maybe aSource is an absolute URL as returned by |sources|.  In
        // this case we can't simply undo the transform.
        var i;
        for (i = 0; i < this._absoluteSources.length; ++i) {
            if (this._absoluteSources[i] == aSource) {
                return i;
            }
        }
        return -1;
    };
    /**
     * Create a BasicSourceMapConsumer from a SourceMapGenerator.
     *
     * @param SourceMapGenerator aSourceMap
     *        The source map that will be consumed.
     * @param String aSourceMapURL
     *        The URL at which the source map can be found (optional)
     * @returns BasicSourceMapConsumer
     */
    BasicSourceMapConsumer.fromSourceMap =
        function SourceMapConsumer_fromSourceMap(aSourceMap, aSourceMapURL) {
            var smc = Object.create(BasicSourceMapConsumer.prototype);
            var names = smc._names = ArraySet.fromArray(aSourceMap._names.toArray(), true);
            var sources = smc._sources = ArraySet.fromArray(aSourceMap._sources.toArray(), true);
            smc.sourceRoot = aSourceMap._sourceRoot;
            smc.sourcesContent = aSourceMap._generateSourcesContent(smc._sources.toArray(), smc.sourceRoot);
            smc.file = aSourceMap._file;
            smc._sourceMapURL = aSourceMapURL;
            smc._absoluteSources = smc._sources.toArray().map(function (s) {
                return util.computeSourceURL(smc.sourceRoot, s, aSourceMapURL);
            });
            // Because we are modifying the entries (by converting string sources and
            // names to indices into the sources and names ArraySets), we have to make
            // a copy of the entry or else bad things happen. Shared mutable state
            // strikes again! See github issue #191.
            var generatedMappings = aSourceMap._mappings.toArray().slice();
            var destGeneratedMappings = smc.__generatedMappings = [];
            var destOriginalMappings = smc.__originalMappings = [];
            for (var i = 0, length = generatedMappings.length; i < length; i++) {
                var srcMapping = generatedMappings[i];
                var destMapping = new Mapping;
                destMapping.generatedLine = srcMapping.generatedLine;
                destMapping.generatedColumn = srcMapping.generatedColumn;
                if (srcMapping.source) {
                    destMapping.source = sources.indexOf(srcMapping.source);
                    destMapping.originalLine = srcMapping.originalLine;
                    destMapping.originalColumn = srcMapping.originalColumn;
                    if (srcMapping.name) {
                        destMapping.name = names.indexOf(srcMapping.name);
                    }
                    destOriginalMappings.push(destMapping);
                }
                destGeneratedMappings.push(destMapping);
            }
            quickSort(smc.__originalMappings, util.compareByOriginalPositions);
            return smc;
        };
    /**
     * The version of the source mapping spec that we are consuming.
     */
    BasicSourceMapConsumer.prototype._version = 3;
    /**
     * The list of original sources.
     */
    Object.defineProperty(BasicSourceMapConsumer.prototype, 'sources', {
        get: function () {
            return this._absoluteSources.slice();
        }
    });
    /**
     * Provide the JIT with a nice shape / hidden class.
     */
    function Mapping() {
        this.generatedLine = 0;
        this.generatedColumn = 0;
        this.source = null;
        this.originalLine = null;
        this.originalColumn = null;
        this.name = null;
    }
    /**
     * Parse the mappings in a string in to a data structure which we can easily
     * query (the ordered arrays in the `this.__generatedMappings` and
     * `this.__originalMappings` properties).
     */
    BasicSourceMapConsumer.prototype._parseMappings =
        function SourceMapConsumer_parseMappings(aStr, aSourceRoot) {
            var generatedLine = 1;
            var previousGeneratedColumn = 0;
            var previousOriginalLine = 0;
            var previousOriginalColumn = 0;
            var previousSource = 0;
            var previousName = 0;
            var length = aStr.length;
            var index = 0;
            var cachedSegments = {};
            var temp = {};
            var originalMappings = [];
            var generatedMappings = [];
            var mapping, str, segment, end, value;
            while (index < length) {
                if (aStr.charAt(index) === ';') {
                    generatedLine++;
                    index++;
                    previousGeneratedColumn = 0;
                }
                else if (aStr.charAt(index) === ',') {
                    index++;
                }
                else {
                    mapping = new Mapping();
                    mapping.generatedLine = generatedLine;
                    // Because each offset is encoded relative to the previous one,
                    // many segments often have the same encoding. We can exploit this
                    // fact by caching the parsed variable length fields of each segment,
                    // allowing us to avoid a second parse if we encounter the same
                    // segment again.
                    for (end = index; end < length; end++) {
                        if (this._charIsMappingSeparator(aStr, end)) {
                            break;
                        }
                    }
                    str = aStr.slice(index, end);
                    segment = cachedSegments[str];
                    if (segment) {
                        index += str.length;
                    }
                    else {
                        segment = [];
                        while (index < end) {
                            base64VLQ.decode(aStr, index, temp);
                            value = temp.value;
                            index = temp.rest;
                            segment.push(value);
                        }
                        if (segment.length === 2) {
                            throw new Error('Found a source, but no line and column');
                        }
                        if (segment.length === 3) {
                            throw new Error('Found a source and line, but no column');
                        }
                        cachedSegments[str] = segment;
                    }
                    // Generated column.
                    mapping.generatedColumn = previousGeneratedColumn + segment[0];
                    previousGeneratedColumn = mapping.generatedColumn;
                    if (segment.length > 1) {
                        // Original source.
                        mapping.source = previousSource + segment[1];
                        previousSource += segment[1];
                        // Original line.
                        mapping.originalLine = previousOriginalLine + segment[2];
                        previousOriginalLine = mapping.originalLine;
                        // Lines are stored 0-based
                        mapping.originalLine += 1;
                        // Original column.
                        mapping.originalColumn = previousOriginalColumn + segment[3];
                        previousOriginalColumn = mapping.originalColumn;
                        if (segment.length > 4) {
                            // Original name.
                            mapping.name = previousName + segment[4];
                            previousName += segment[4];
                        }
                    }
                    generatedMappings.push(mapping);
                    if (typeof mapping.originalLine === 'number') {
                        originalMappings.push(mapping);
                    }
                }
            }
            quickSort(generatedMappings, util.compareByGeneratedPositionsDeflated);
            this.__generatedMappings = generatedMappings;
            quickSort(originalMappings, util.compareByOriginalPositions);
            this.__originalMappings = originalMappings;
        };
    /**
     * Find the mapping that best matches the hypothetical "needle" mapping that
     * we are searching for in the given "haystack" of mappings.
     */
    BasicSourceMapConsumer.prototype._findMapping =
        function SourceMapConsumer_findMapping(aNeedle, aMappings, aLineName, aColumnName, aComparator, aBias) {
            // To return the position we are searching for, we must first find the
            // mapping for the given position and then return the opposite position it
            // points to. Because the mappings are sorted, we can use binary search to
            // find the best mapping.
            if (aNeedle[aLineName] <= 0) {
                throw new TypeError('Line must be greater than or equal to 1, got '
                    + aNeedle[aLineName]);
            }
            if (aNeedle[aColumnName] < 0) {
                throw new TypeError('Column must be greater than or equal to 0, got '
                    + aNeedle[aColumnName]);
            }
            return binarySearch.search(aNeedle, aMappings, aComparator, aBias);
        };
    /**
     * Compute the last column for each generated mapping. The last column is
     * inclusive.
     */
    BasicSourceMapConsumer.prototype.computeColumnSpans =
        function SourceMapConsumer_computeColumnSpans() {
            for (var index = 0; index < this._generatedMappings.length; ++index) {
                var mapping = this._generatedMappings[index];
                // Mappings do not contain a field for the last generated columnt. We
                // can come up with an optimistic estimate, however, by assuming that
                // mappings are contiguous (i.e. given two consecutive mappings, the
                // first mapping ends where the second one starts).
                if (index + 1 < this._generatedMappings.length) {
                    var nextMapping = this._generatedMappings[index + 1];
                    if (mapping.generatedLine === nextMapping.generatedLine) {
                        mapping.lastGeneratedColumn = nextMapping.generatedColumn - 1;
                        continue;
                    }
                }
                // The last mapping for each line spans the entire line.
                mapping.lastGeneratedColumn = Infinity;
            }
        };
    /**
     * Returns the original source, line, and column information for the generated
     * source's line and column positions provided. The only argument is an object
     * with the following properties:
     *
     *   - line: The line number in the generated source.  The line number
     *     is 1-based.
     *   - column: The column number in the generated source.  The column
     *     number is 0-based.
     *   - bias: Either 'SourceMapConsumer.GREATEST_LOWER_BOUND' or
     *     'SourceMapConsumer.LEAST_UPPER_BOUND'. Specifies whether to return the
     *     closest element that is smaller than or greater than the one we are
     *     searching for, respectively, if the exact element cannot be found.
     *     Defaults to 'SourceMapConsumer.GREATEST_LOWER_BOUND'.
     *
     * and an object is returned with the following properties:
     *
     *   - source: The original source file, or null.
     *   - line: The line number in the original source, or null.  The
     *     line number is 1-based.
     *   - column: The column number in the original source, or null.  The
     *     column number is 0-based.
     *   - name: The original identifier, or null.
     */
    BasicSourceMapConsumer.prototype.originalPositionFor =
        function SourceMapConsumer_originalPositionFor(aArgs) {
            var needle = {
                generatedLine: util.getArg(aArgs, 'line'),
                generatedColumn: util.getArg(aArgs, 'column')
            };
            var index = this._findMapping(needle, this._generatedMappings, "generatedLine", "generatedColumn", util.compareByGeneratedPositionsDeflated, util.getArg(aArgs, 'bias', SourceMapConsumer.GREATEST_LOWER_BOUND));
            if (index >= 0) {
                var mapping = this._generatedMappings[index];
                if (mapping.generatedLine === needle.generatedLine) {
                    var source = util.getArg(mapping, 'source', null);
                    if (source !== null) {
                        source = this._sources.at(source);
                        source = util.computeSourceURL(this.sourceRoot, source, this._sourceMapURL);
                    }
                    var name = util.getArg(mapping, 'name', null);
                    if (name !== null) {
                        name = this._names.at(name);
                    }
                    return {
                        source: source,
                        line: util.getArg(mapping, 'originalLine', null),
                        column: util.getArg(mapping, 'originalColumn', null),
                        name: name
                    };
                }
            }
            return {
                source: null,
                line: null,
                column: null,
                name: null
            };
        };
    /**
     * Return true if we have the source content for every source in the source
     * map, false otherwise.
     */
    BasicSourceMapConsumer.prototype.hasContentsOfAllSources =
        function BasicSourceMapConsumer_hasContentsOfAllSources() {
            if (!this.sourcesContent) {
                return false;
            }
            return this.sourcesContent.length >= this._sources.size() &&
                !this.sourcesContent.some(function (sc) { return sc == null; });
        };
    /**
     * Returns the original source content. The only argument is the url of the
     * original source file. Returns null if no original source content is
     * available.
     */
    BasicSourceMapConsumer.prototype.sourceContentFor =
        function SourceMapConsumer_sourceContentFor(aSource, nullOnMissing) {
            if (!this.sourcesContent) {
                return null;
            }
            var index = this._findSourceIndex(aSource);
            if (index >= 0) {
                return this.sourcesContent[index];
            }
            var relativeSource = aSource;
            if (this.sourceRoot != null) {
                relativeSource = util.relative(this.sourceRoot, relativeSource);
            }
            var url;
            if (this.sourceRoot != null
                && (url = util.urlParse(this.sourceRoot))) {
                // XXX: file:// URIs and absolute paths lead to unexpected behavior for
                // many users. We can help them out when they expect file:// URIs to
                // behave like it would if they were running a local HTTP server. See
                // https://bugzilla.mozilla.org/show_bug.cgi?id=885597.
                var fileUriAbsPath = relativeSource.replace(/^file:\/\//, "");
                if (url.scheme == "file"
                    && this._sources.has(fileUriAbsPath)) {
                    return this.sourcesContent[this._sources.indexOf(fileUriAbsPath)];
                }
                if ((!url.path || url.path == "/")
                    && this._sources.has("/" + relativeSource)) {
                    return this.sourcesContent[this._sources.indexOf("/" + relativeSource)];
                }
            }
            // This function is used recursively from
            // IndexedSourceMapConsumer.prototype.sourceContentFor. In that case, we
            // don't want to throw if we can't find the source - we just want to
            // return null, so we provide a flag to exit gracefully.
            if (nullOnMissing) {
                return null;
            }
            else {
                throw new Error('"' + relativeSource + '" is not in the SourceMap.');
            }
        };
    /**
     * Returns the generated line and column information for the original source,
     * line, and column positions provided. The only argument is an object with
     * the following properties:
     *
     *   - source: The filename of the original source.
     *   - line: The line number in the original source.  The line number
     *     is 1-based.
     *   - column: The column number in the original source.  The column
     *     number is 0-based.
     *   - bias: Either 'SourceMapConsumer.GREATEST_LOWER_BOUND' or
     *     'SourceMapConsumer.LEAST_UPPER_BOUND'. Specifies whether to return the
     *     closest element that is smaller than or greater than the one we are
     *     searching for, respectively, if the exact element cannot be found.
     *     Defaults to 'SourceMapConsumer.GREATEST_LOWER_BOUND'.
     *
     * and an object is returned with the following properties:
     *
     *   - line: The line number in the generated source, or null.  The
     *     line number is 1-based.
     *   - column: The column number in the generated source, or null.
     *     The column number is 0-based.
     */
    BasicSourceMapConsumer.prototype.generatedPositionFor =
        function SourceMapConsumer_generatedPositionFor(aArgs) {
            var source = util.getArg(aArgs, 'source');
            source = this._findSourceIndex(source);
            if (source < 0) {
                return {
                    line: null,
                    column: null,
                    lastColumn: null
                };
            }
            var needle = {
                source: source,
                originalLine: util.getArg(aArgs, 'line'),
                originalColumn: util.getArg(aArgs, 'column')
            };
            var index = this._findMapping(needle, this._originalMappings, "originalLine", "originalColumn", util.compareByOriginalPositions, util.getArg(aArgs, 'bias', SourceMapConsumer.GREATEST_LOWER_BOUND));
            if (index >= 0) {
                var mapping = this._originalMappings[index];
                if (mapping.source === needle.source) {
                    return {
                        line: util.getArg(mapping, 'generatedLine', null),
                        column: util.getArg(mapping, 'generatedColumn', null),
                        lastColumn: util.getArg(mapping, 'lastGeneratedColumn', null)
                    };
                }
            }
            return {
                line: null,
                column: null,
                lastColumn: null
            };
        };
    exports.BasicSourceMapConsumer = BasicSourceMapConsumer;
    /**
     * An IndexedSourceMapConsumer instance represents a parsed source map which
     * we can query for information. It differs from BasicSourceMapConsumer in
     * that it takes "indexed" source maps (i.e. ones with a "sections" field) as
     * input.
     *
     * The first parameter is a raw source map (either as a JSON string, or already
     * parsed to an object). According to the spec for indexed source maps, they
     * have the following attributes:
     *
     *   - version: Which version of the source map spec this map is following.
     *   - file: Optional. The generated file this source map is associated with.
     *   - sections: A list of section definitions.
     *
     * Each value under the "sections" field has two fields:
     *   - offset: The offset into the original specified at which this section
     *       begins to apply, defined as an object with a "line" and "column"
     *       field.
     *   - map: A source map definition. This source map could also be indexed,
     *       but doesn't have to be.
     *
     * Instead of the "map" field, it's also possible to have a "url" field
     * specifying a URL to retrieve a source map from, but that's currently
     * unsupported.
     *
     * Here's an example source map, taken from the source map spec[0], but
     * modified to omit a section which uses the "url" field.
     *
     *  {
     *    version : 3,
     *    file: "app.js",
     *    sections: [{
     *      offset: {line:100, column:10},
     *      map: {
     *        version : 3,
     *        file: "section.js",
     *        sources: ["foo.js", "bar.js"],
     *        names: ["src", "maps", "are", "fun"],
     *        mappings: "AAAA,E;;ABCDE;"
     *      }
     *    }],
     *  }
     *
     * The second parameter, if given, is a string whose value is the URL
     * at which the source map was found.  This URL is used to compute the
     * sources array.
     *
     * [0]: https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit#heading=h.535es3xeprgt
     */
    function IndexedSourceMapConsumer(aSourceMap, aSourceMapURL) {
        var sourceMap = aSourceMap;
        if (typeof aSourceMap === 'string') {
            sourceMap = util.parseSourceMapInput(aSourceMap);
        }
        var version = util.getArg(sourceMap, 'version');
        var sections = util.getArg(sourceMap, 'sections');
        if (version != this._version) {
            throw new Error('Unsupported version: ' + version);
        }
        this._sources = new ArraySet();
        this._names = new ArraySet();
        var lastOffset = {
            line: -1,
            column: 0
        };
        this._sections = sections.map(function (s) {
            if (s.url) {
                // The url field will require support for asynchronicity.
                // See https://github.com/mozilla/source-map/issues/16
                throw new Error('Support for url field in sections not implemented.');
            }
            var offset = util.getArg(s, 'offset');
            var offsetLine = util.getArg(offset, 'line');
            var offsetColumn = util.getArg(offset, 'column');
            if (offsetLine < lastOffset.line ||
                (offsetLine === lastOffset.line && offsetColumn < lastOffset.column)) {
                throw new Error('Section offsets must be ordered and non-overlapping.');
            }
            lastOffset = offset;
            return {
                generatedOffset: {
                    // The offset fields are 0-based, but we use 1-based indices when
                    // encoding/decoding from VLQ.
                    generatedLine: offsetLine + 1,
                    generatedColumn: offsetColumn + 1
                },
                consumer: new SourceMapConsumer(util.getArg(s, 'map'), aSourceMapURL)
            };
        });
    }
    IndexedSourceMapConsumer.prototype = Object.create(SourceMapConsumer.prototype);
    IndexedSourceMapConsumer.prototype.constructor = SourceMapConsumer;
    /**
     * The version of the source mapping spec that we are consuming.
     */
    IndexedSourceMapConsumer.prototype._version = 3;
    /**
     * The list of original sources.
     */
    Object.defineProperty(IndexedSourceMapConsumer.prototype, 'sources', {
        get: function () {
            var sources = [];
            for (var i = 0; i < this._sections.length; i++) {
                for (var j = 0; j < this._sections[i].consumer.sources.length; j++) {
                    sources.push(this._sections[i].consumer.sources[j]);
                }
            }
            return sources;
        }
    });
    /**
     * Returns the original source, line, and column information for the generated
     * source's line and column positions provided. The only argument is an object
     * with the following properties:
     *
     *   - line: The line number in the generated source.  The line number
     *     is 1-based.
     *   - column: The column number in the generated source.  The column
     *     number is 0-based.
     *
     * and an object is returned with the following properties:
     *
     *   - source: The original source file, or null.
     *   - line: The line number in the original source, or null.  The
     *     line number is 1-based.
     *   - column: The column number in the original source, or null.  The
     *     column number is 0-based.
     *   - name: The original identifier, or null.
     */
    IndexedSourceMapConsumer.prototype.originalPositionFor =
        function IndexedSourceMapConsumer_originalPositionFor(aArgs) {
            var needle = {
                generatedLine: util.getArg(aArgs, 'line'),
                generatedColumn: util.getArg(aArgs, 'column')
            };
            // Find the section containing the generated position we're trying to map
            // to an original position.
            var sectionIndex = binarySearch.search(needle, this._sections, function (needle, section) {
                var cmp = needle.generatedLine - section.generatedOffset.generatedLine;
                if (cmp) {
                    return cmp;
                }
                return (needle.generatedColumn -
                    section.generatedOffset.generatedColumn);
            });
            var section = this._sections[sectionIndex];
            if (!section) {
                return {
                    source: null,
                    line: null,
                    column: null,
                    name: null
                };
            }
            return section.consumer.originalPositionFor({
                line: needle.generatedLine -
                    (section.generatedOffset.generatedLine - 1),
                column: needle.generatedColumn -
                    (section.generatedOffset.generatedLine === needle.generatedLine
                        ? section.generatedOffset.generatedColumn - 1
                        : 0),
                bias: aArgs.bias
            });
        };
    /**
     * Return true if we have the source content for every source in the source
     * map, false otherwise.
     */
    IndexedSourceMapConsumer.prototype.hasContentsOfAllSources =
        function IndexedSourceMapConsumer_hasContentsOfAllSources() {
            return this._sections.every(function (s) {
                return s.consumer.hasContentsOfAllSources();
            });
        };
    /**
     * Returns the original source content. The only argument is the url of the
     * original source file. Returns null if no original source content is
     * available.
     */
    IndexedSourceMapConsumer.prototype.sourceContentFor =
        function IndexedSourceMapConsumer_sourceContentFor(aSource, nullOnMissing) {
            for (var i = 0; i < this._sections.length; i++) {
                var section = this._sections[i];
                var content = section.consumer.sourceContentFor(aSource, true);
                if (content) {
                    return content;
                }
            }
            if (nullOnMissing) {
                return null;
            }
            else {
                throw new Error('"' + aSource + '" is not in the SourceMap.');
            }
        };
    /**
     * Returns the generated line and column information for the original source,
     * line, and column positions provided. The only argument is an object with
     * the following properties:
     *
     *   - source: The filename of the original source.
     *   - line: The line number in the original source.  The line number
     *     is 1-based.
     *   - column: The column number in the original source.  The column
     *     number is 0-based.
     *
     * and an object is returned with the following properties:
     *
     *   - line: The line number in the generated source, or null.  The
     *     line number is 1-based.
     *   - column: The column number in the generated source, or null.
     *     The column number is 0-based.
     */
    IndexedSourceMapConsumer.prototype.generatedPositionFor =
        function IndexedSourceMapConsumer_generatedPositionFor(aArgs) {
            for (var i = 0; i < this._sections.length; i++) {
                var section = this._sections[i];
                // Only consider this section if the requested source is in the list of
                // sources of the consumer.
                if (section.consumer._findSourceIndex(util.getArg(aArgs, 'source')) === -1) {
                    continue;
                }
                var generatedPosition = section.consumer.generatedPositionFor(aArgs);
                if (generatedPosition) {
                    var ret = {
                        line: generatedPosition.line +
                            (section.generatedOffset.generatedLine - 1),
                        column: generatedPosition.column +
                            (section.generatedOffset.generatedLine === generatedPosition.line
                                ? section.generatedOffset.generatedColumn - 1
                                : 0)
                    };
                    return ret;
                }
            }
            return {
                line: null,
                column: null
            };
        };
    /**
     * Parse the mappings in a string in to a data structure which we can easily
     * query (the ordered arrays in the `this.__generatedMappings` and
     * `this.__originalMappings` properties).
     */
    IndexedSourceMapConsumer.prototype._parseMappings =
        function IndexedSourceMapConsumer_parseMappings(aStr, aSourceRoot) {
            this.__generatedMappings = [];
            this.__originalMappings = [];
            for (var i = 0; i < this._sections.length; i++) {
                var section = this._sections[i];
                var sectionMappings = section.consumer._generatedMappings;
                for (var j = 0; j < sectionMappings.length; j++) {
                    var mapping = sectionMappings[j];
                    var source = section.consumer._sources.at(mapping.source);
                    source = util.computeSourceURL(section.consumer.sourceRoot, source, this._sourceMapURL);
                    this._sources.add(source);
                    source = this._sources.indexOf(source);
                    var name = null;
                    if (mapping.name) {
                        name = section.consumer._names.at(mapping.name);
                        this._names.add(name);
                        name = this._names.indexOf(name);
                    }
                    // The mappings coming from the consumer for the section have
                    // generated positions relative to the start of the section, so we
                    // need to offset them to be relative to the start of the concatenated
                    // generated file.
                    var adjustedMapping = {
                        source: source,
                        generatedLine: mapping.generatedLine +
                            (section.generatedOffset.generatedLine - 1),
                        generatedColumn: mapping.generatedColumn +
                            (section.generatedOffset.generatedLine === mapping.generatedLine
                                ? section.generatedOffset.generatedColumn - 1
                                : 0),
                        originalLine: mapping.originalLine,
                        originalColumn: mapping.originalColumn,
                        name: name
                    };
                    this.__generatedMappings.push(adjustedMapping);
                    if (typeof adjustedMapping.originalLine === 'number') {
                        this.__originalMappings.push(adjustedMapping);
                    }
                }
            }
            quickSort(this.__generatedMappings, util.compareByGeneratedPositionsDeflated);
            quickSort(this.__originalMappings, util.compareByOriginalPositions);
        };
    exports.IndexedSourceMapConsumer = IndexedSourceMapConsumer;
},
/* source-map/lib/binary-search.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    exports.GREATEST_LOWER_BOUND = 1;
    exports.LEAST_UPPER_BOUND = 2;
    /**
     * Recursive implementation of binary search.
     *
     * @param aLow Indices here and lower do not contain the needle.
     * @param aHigh Indices here and higher do not contain the needle.
     * @param aNeedle The element being searched for.
     * @param aHaystack The non-empty array being searched.
     * @param aCompare Function which takes two elements and returns -1, 0, or 1.
     * @param aBias Either 'binarySearch.GREATEST_LOWER_BOUND' or
     *     'binarySearch.LEAST_UPPER_BOUND'. Specifies whether to return the
     *     closest element that is smaller than or greater than the one we are
     *     searching for, respectively, if the exact element cannot be found.
     */
    function recursiveSearch(aLow, aHigh, aNeedle, aHaystack, aCompare, aBias) {
        // This function terminates when one of the following is true:
        //
        //   1. We find the exact element we are looking for.
        //
        //   2. We did not find the exact element, but we can return the index of
        //      the next-closest element.
        //
        //   3. We did not find the exact element, and there is no next-closest
        //      element than the one we are searching for, so we return -1.
        var mid = Math.floor((aHigh - aLow) / 2) + aLow;
        var cmp = aCompare(aNeedle, aHaystack[mid], true);
        if (cmp === 0) {
            // Found the element we are looking for.
            return mid;
        }
        else if (cmp > 0) {
            // Our needle is greater than aHaystack[mid].
            if (aHigh - mid > 1) {
                // The element is in the upper half.
                return recursiveSearch(mid, aHigh, aNeedle, aHaystack, aCompare, aBias);
            }
            // The exact needle element was not found in this haystack. Determine if
            // we are in termination case (3) or (2) and return the appropriate thing.
            if (aBias == exports.LEAST_UPPER_BOUND) {
                return aHigh < aHaystack.length ? aHigh : -1;
            }
            else {
                return mid;
            }
        }
        else {
            // Our needle is less than aHaystack[mid].
            if (mid - aLow > 1) {
                // The element is in the lower half.
                return recursiveSearch(aLow, mid, aNeedle, aHaystack, aCompare, aBias);
            }
            // we are in termination case (3) or (2) and return the appropriate thing.
            if (aBias == exports.LEAST_UPPER_BOUND) {
                return mid;
            }
            else {
                return aLow < 0 ? -1 : aLow;
            }
        }
    }
    /**
     * This is an implementation of binary search which will always try and return
     * the index of the closest element if there is no exact hit. This is because
     * mappings between original and generated line/col pairs are single points,
     * and there is an implicit region between each of them, so a miss just means
     * that you aren't on the very start of a region.
     *
     * @param aNeedle The element you are looking for.
     * @param aHaystack The array that is being searched.
     * @param aCompare A function which takes the needle and an element in the
     *     array and returns -1, 0, or 1 depending on whether the needle is less
     *     than, equal to, or greater than the element, respectively.
     * @param aBias Either 'binarySearch.GREATEST_LOWER_BOUND' or
     *     'binarySearch.LEAST_UPPER_BOUND'. Specifies whether to return the
     *     closest element that is smaller than or greater than the one we are
     *     searching for, respectively, if the exact element cannot be found.
     *     Defaults to 'binarySearch.GREATEST_LOWER_BOUND'.
     */
    exports.search = function search(aNeedle, aHaystack, aCompare, aBias) {
        if (aHaystack.length === 0) {
            return -1;
        }
        var index = recursiveSearch(-1, aHaystack.length, aNeedle, aHaystack, aCompare, aBias || exports.GREATEST_LOWER_BOUND);
        if (index < 0) {
            return -1;
        }
        // We have found either the exact element, or the next-closest element than
        // the one we are searching for. However, there may be more than one such
        // element. Make sure we always return the smallest of these.
        while (index - 1 >= 0) {
            if (aCompare(aHaystack[index], aHaystack[index - 1], true) !== 0) {
                break;
            }
            --index;
        }
        return index;
    };
},
/* source-map/lib/quick-sort.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    // It turns out that some (most?) JavaScript engines don't self-host
    // `Array.prototype.sort`. This makes sense because C++ will likely remain
    // faster than JS when doing raw CPU-intensive sorting. However, when using a
    // custom comparator function, calling back and forth between the VM's C++ and
    // JIT'd JS is rather slow *and* loses JIT type information, resulting in
    // worse generated code for the comparator function than would be optimal. In
    // fact, when sorting with a comparator, these costs outweigh the benefits of
    // sorting in C++. By using our own JS-implemented Quick Sort (below), we get
    // a ~3500ms mean speed-up in `bench/bench.html`.
    /**
     * Swap the elements indexed by `x` and `y` in the array `ary`.
     *
     * @param {Array} ary
     *        The array.
     * @param {Number} x
     *        The index of the first item.
     * @param {Number} y
     *        The index of the second item.
     */
    function swap(ary, x, y) {
        var temp = ary[x];
        ary[x] = ary[y];
        ary[y] = temp;
    }
    /**
     * Returns a random integer within the range `low .. high` inclusive.
     *
     * @param {Number} low
     *        The lower bound on the range.
     * @param {Number} high
     *        The upper bound on the range.
     */
    function randomIntInRange(low, high) {
        return Math.round(low + (Math.random() * (high - low)));
    }
    /**
     * The Quick Sort algorithm.
     *
     * @param {Array} ary
     *        An array to sort.
     * @param {function} comparator
     *        Function to use to compare two items.
     * @param {Number} p
     *        Start index of the array
     * @param {Number} r
     *        End index of the array
     */
    function doQuickSort(ary, comparator, p, r) {
        // If our lower bound is less than our upper bound, we (1) partition the
        // array into two pieces and (2) recurse on each half. If it is not, this is
        // the empty array and our base case.
        if (p < r) {
            // (1) Partitioning.
            //
            // The partitioning chooses a pivot between `p` and `r` and moves all
            // elements that are less than or equal to the pivot to the before it, and
            // all the elements that are greater than it after it. The effect is that
            // once partition is done, the pivot is in the exact place it will be when
            // the array is put in sorted order, and it will not need to be moved
            // again. This runs in O(n) time.
            // Always choose a random pivot so that an input array which is reverse
            // sorted does not cause O(n^2) running time.
            var pivotIndex = randomIntInRange(p, r);
            var i = p - 1;
            swap(ary, pivotIndex, r);
            var pivot = ary[r];
            // Immediately after `j` is incremented in this loop, the following hold
            // true:
            //
            //   * Every element in `ary[p .. i]` is less than or equal to the pivot.
            //
            //   * Every element in `ary[i+1 .. j-1]` is greater than the pivot.
            for (var j = p; j < r; j++) {
                if (comparator(ary[j], pivot) <= 0) {
                    i += 1;
                    swap(ary, i, j);
                }
            }
            swap(ary, i + 1, j);
            var q = i + 1;
            // (2) Recurse on each half.
            doQuickSort(ary, comparator, p, q - 1);
            doQuickSort(ary, comparator, q + 1, r);
        }
    }
    /**
     * Sort the given array in-place with the given comparator function.
     *
     * @param {Array} ary
     *        An array to sort.
     * @param {function} comparator
     *        Function to use to compare two items.
     */
    exports.quickSort = function (ary, comparator) {
        doQuickSort(ary, comparator, 0, ary.length - 1);
    };
},
/* source-map/lib/source-node.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var SourceMapGenerator = require(24) /* ./source-map-generator */.SourceMapGenerator;
    var util = require(27) /* ./util */;
    // Matches a Windows-style `\r\n` newline or a `\n` newline used by all other
    // operating systems these days (capturing the result).
    var REGEX_NEWLINE = /(\r?\n)/;
    // Newline character code for charCodeAt() comparisons
    var NEWLINE_CODE = 10;
    // Private symbol for identifying `SourceNode`s when multiple versions of
    // the source-map library are loaded. This MUST NOT CHANGE across
    // versions!
    var isSourceNode = "$$$isSourceNode$$$";
    /**
     * SourceNodes provide a way to abstract over interpolating/concatenating
     * snippets of generated JavaScript source code while maintaining the line and
     * column information associated with the original source code.
     *
     * @param aLine The original line number.
     * @param aColumn The original column number.
     * @param aSource The original source's filename.
     * @param aChunks Optional. An array of strings which are snippets of
     *        generated JS, or other SourceNodes.
     * @param aName The original identifier.
     */
    function SourceNode(aLine, aColumn, aSource, aChunks, aName) {
        this.children = [];
        this.sourceContents = {};
        this.line = aLine == null ? null : aLine;
        this.column = aColumn == null ? null : aColumn;
        this.source = aSource == null ? null : aSource;
        this.name = aName == null ? null : aName;
        this[isSourceNode] = true;
        if (aChunks != null)
            this.add(aChunks);
    }
    /**
     * Creates a SourceNode from generated code and a SourceMapConsumer.
     *
     * @param aGeneratedCode The generated code
     * @param aSourceMapConsumer The SourceMap for the generated code
     * @param aRelativePath Optional. The path that relative sources in the
     *        SourceMapConsumer should be relative to.
     */
    SourceNode.fromStringWithSourceMap =
        function SourceNode_fromStringWithSourceMap(aGeneratedCode, aSourceMapConsumer, aRelativePath) {
            // The SourceNode we want to fill with the generated code
            // and the SourceMap
            var node = new SourceNode();
            // All even indices of this array are one line of the generated code,
            // while all odd indices are the newlines between two adjacent lines
            // (since `REGEX_NEWLINE` captures its match).
            // Processed fragments are accessed by calling `shiftNextLine`.
            var remainingLines = aGeneratedCode.split(REGEX_NEWLINE);
            var remainingLinesIndex = 0;
            var shiftNextLine = function () {
                var lineContents = getNextLine();
                // The last line of a file might not have a newline.
                var newLine = getNextLine() || "";
                return lineContents + newLine;
                function getNextLine() {
                    return remainingLinesIndex < remainingLines.length ?
                        remainingLines[remainingLinesIndex++] : undefined;
                }
            };
            // We need to remember the position of "remainingLines"
            var lastGeneratedLine = 1, lastGeneratedColumn = 0;
            // The generate SourceNodes we need a code range.
            // To extract it current and last mapping is used.
            // Here we store the last mapping.
            var lastMapping = null;
            aSourceMapConsumer.eachMapping(function (mapping) {
                if (lastMapping !== null) {
                    // We add the code from "lastMapping" to "mapping":
                    // First check if there is a new line in between.
                    if (lastGeneratedLine < mapping.generatedLine) {
                        // Associate first line with "lastMapping"
                        addMappingWithCode(lastMapping, shiftNextLine());
                        lastGeneratedLine++;
                        lastGeneratedColumn = 0;
                        // The remaining code is added without mapping
                    }
                    else {
                        // There is no new line in between.
                        // Associate the code between "lastGeneratedColumn" and
                        // "mapping.generatedColumn" with "lastMapping"
                        var nextLine = remainingLines[remainingLinesIndex] || '';
                        var code = nextLine.substr(0, mapping.generatedColumn -
                            lastGeneratedColumn);
                        remainingLines[remainingLinesIndex] = nextLine.substr(mapping.generatedColumn -
                            lastGeneratedColumn);
                        lastGeneratedColumn = mapping.generatedColumn;
                        addMappingWithCode(lastMapping, code);
                        // No more remaining code, continue
                        lastMapping = mapping;
                        return;
                    }
                }
                // We add the generated code until the first mapping
                // to the SourceNode without any mapping.
                // Each line is added as separate string.
                while (lastGeneratedLine < mapping.generatedLine) {
                    node.add(shiftNextLine());
                    lastGeneratedLine++;
                }
                if (lastGeneratedColumn < mapping.generatedColumn) {
                    var nextLine = remainingLines[remainingLinesIndex] || '';
                    node.add(nextLine.substr(0, mapping.generatedColumn));
                    remainingLines[remainingLinesIndex] = nextLine.substr(mapping.generatedColumn);
                    lastGeneratedColumn = mapping.generatedColumn;
                }
                lastMapping = mapping;
            }, this);
            // We have processed all mappings.
            if (remainingLinesIndex < remainingLines.length) {
                if (lastMapping) {
                    // Associate the remaining code in the current line with "lastMapping"
                    addMappingWithCode(lastMapping, shiftNextLine());
                }
                // and add the remaining lines without any mapping
                node.add(remainingLines.splice(remainingLinesIndex).join(""));
            }
            // Copy sourcesContent into SourceNode
            aSourceMapConsumer.sources.forEach(function (sourceFile) {
                var content = aSourceMapConsumer.sourceContentFor(sourceFile);
                if (content != null) {
                    if (aRelativePath != null) {
                        sourceFile = util.join(aRelativePath, sourceFile);
                    }
                    node.setSourceContent(sourceFile, content);
                }
            });
            return node;
            function addMappingWithCode(mapping, code) {
                if (mapping === null || mapping.source === undefined) {
                    node.add(code);
                }
                else {
                    var source = aRelativePath
                        ? util.join(aRelativePath, mapping.source)
                        : mapping.source;
                    node.add(new SourceNode(mapping.originalLine, mapping.originalColumn, source, code, mapping.name));
                }
            }
        };
    /**
     * Add a chunk of generated JS to this source node.
     *
     * @param aChunk A string snippet of generated JS code, another instance of
     *        SourceNode, or an array where each member is one of those things.
     */
    SourceNode.prototype.add = function SourceNode_add(aChunk) {
        if (Array.isArray(aChunk)) {
            aChunk.forEach(function (chunk) {
                this.add(chunk);
            }, this);
        }
        else if (aChunk[isSourceNode] || typeof aChunk === "string") {
            if (aChunk) {
                this.children.push(aChunk);
            }
        }
        else {
            throw new TypeError("Expected a SourceNode, string, or an array of SourceNodes and strings. Got " + aChunk);
        }
        return this;
    };
    /**
     * Add a chunk of generated JS to the beginning of this source node.
     *
     * @param aChunk A string snippet of generated JS code, another instance of
     *        SourceNode, or an array where each member is one of those things.
     */
    SourceNode.prototype.prepend = function SourceNode_prepend(aChunk) {
        if (Array.isArray(aChunk)) {
            for (var i = aChunk.length - 1; i >= 0; i--) {
                this.prepend(aChunk[i]);
            }
        }
        else if (aChunk[isSourceNode] || typeof aChunk === "string") {
            this.children.unshift(aChunk);
        }
        else {
            throw new TypeError("Expected a SourceNode, string, or an array of SourceNodes and strings. Got " + aChunk);
        }
        return this;
    };
    /**
     * Walk over the tree of JS snippets in this node and its children. The
     * walking function is called once for each snippet of JS and is passed that
     * snippet and the its original associated source's line/column location.
     *
     * @param aFn The traversal function.
     */
    SourceNode.prototype.walk = function SourceNode_walk(aFn) {
        var chunk;
        for (var i = 0, len = this.children.length; i < len; i++) {
            chunk = this.children[i];
            if (chunk[isSourceNode]) {
                chunk.walk(aFn);
            }
            else {
                if (chunk !== '') {
                    aFn(chunk, { source: this.source,
                        line: this.line,
                        column: this.column,
                        name: this.name });
                }
            }
        }
    };
    /**
     * Like `String.prototype.join` except for SourceNodes. Inserts `aStr` between
     * each of `this.children`.
     *
     * @param aSep The separator.
     */
    SourceNode.prototype.join = function SourceNode_join(aSep) {
        var newChildren;
        var i;
        var len = this.children.length;
        if (len > 0) {
            newChildren = [];
            for (i = 0; i < len - 1; i++) {
                newChildren.push(this.children[i]);
                newChildren.push(aSep);
            }
            newChildren.push(this.children[i]);
            this.children = newChildren;
        }
        return this;
    };
    /**
     * Call String.prototype.replace on the very right-most source snippet. Useful
     * for trimming whitespace from the end of a source node, etc.
     *
     * @param aPattern The pattern to replace.
     * @param aReplacement The thing to replace the pattern with.
     */
    SourceNode.prototype.replaceRight = function SourceNode_replaceRight(aPattern, aReplacement) {
        var lastChild = this.children[this.children.length - 1];
        if (lastChild[isSourceNode]) {
            lastChild.replaceRight(aPattern, aReplacement);
        }
        else if (typeof lastChild === 'string') {
            this.children[this.children.length - 1] = lastChild.replace(aPattern, aReplacement);
        }
        else {
            this.children.push(''.replace(aPattern, aReplacement));
        }
        return this;
    };
    /**
     * Set the source content for a source file. This will be added to the SourceMapGenerator
     * in the sourcesContent field.
     *
     * @param aSourceFile The filename of the source file
     * @param aSourceContent The content of the source file
     */
    SourceNode.prototype.setSourceContent =
        function SourceNode_setSourceContent(aSourceFile, aSourceContent) {
            this.sourceContents[util.toSetString(aSourceFile)] = aSourceContent;
        };
    /**
     * Walk over the tree of SourceNodes. The walking function is called for each
     * source file content and is passed the filename and source content.
     *
     * @param aFn The traversal function.
     */
    SourceNode.prototype.walkSourceContents =
        function SourceNode_walkSourceContents(aFn) {
            for (var i = 0, len = this.children.length; i < len; i++) {
                if (this.children[i][isSourceNode]) {
                    this.children[i].walkSourceContents(aFn);
                }
            }
            var sources = Object.keys(this.sourceContents);
            for (var i = 0, len = sources.length; i < len; i++) {
                aFn(util.fromSetString(sources[i]), this.sourceContents[sources[i]]);
            }
        };
    /**
     * Return the string representation of this source node. Walks over the tree
     * and concatenates all the various snippets together to one string.
     */
    SourceNode.prototype.toString = function SourceNode_toString() {
        var str = "";
        this.walk(function (chunk) {
            str += chunk;
        });
        return str;
    };
    /**
     * Returns the string representation of this source node along with a source
     * map.
     */
    SourceNode.prototype.toStringWithSourceMap = function SourceNode_toStringWithSourceMap(aArgs) {
        var generated = {
            code: "",
            line: 1,
            column: 0
        };
        var map = new SourceMapGenerator(aArgs);
        var sourceMappingActive = false;
        var lastOriginalSource = null;
        var lastOriginalLine = null;
        var lastOriginalColumn = null;
        var lastOriginalName = null;
        this.walk(function (chunk, original) {
            generated.code += chunk;
            if (original.source !== null
                && original.line !== null
                && original.column !== null) {
                if (lastOriginalSource !== original.source
                    || lastOriginalLine !== original.line
                    || lastOriginalColumn !== original.column
                    || lastOriginalName !== original.name) {
                    map.addMapping({
                        source: original.source,
                        original: {
                            line: original.line,
                            column: original.column
                        },
                        generated: {
                            line: generated.line,
                            column: generated.column
                        },
                        name: original.name
                    });
                }
                lastOriginalSource = original.source;
                lastOriginalLine = original.line;
                lastOriginalColumn = original.column;
                lastOriginalName = original.name;
                sourceMappingActive = true;
            }
            else if (sourceMappingActive) {
                map.addMapping({
                    generated: {
                        line: generated.line,
                        column: generated.column
                    }
                });
                lastOriginalSource = null;
                sourceMappingActive = false;
            }
            for (var idx = 0, length = chunk.length; idx < length; idx++) {
                if (chunk.charCodeAt(idx) === NEWLINE_CODE) {
                    generated.line++;
                    generated.column = 0;
                    // Mappings end at eol
                    if (idx + 1 === length) {
                        lastOriginalSource = null;
                        sourceMappingActive = false;
                    }
                    else if (sourceMappingActive) {
                        map.addMapping({
                            source: original.source,
                            original: {
                                line: original.line,
                                column: original.column
                            },
                            generated: {
                                line: generated.line,
                                column: generated.column
                            },
                            name: original.name
                        });
                    }
                }
                else {
                    generated.column++;
                }
            }
        });
        this.walkSourceContents(function (sourceFile, sourceContent) {
            map.setSourceContent(sourceFile, sourceContent);
        });
        return { code: generated.code, map: map };
    };
    exports.SourceNode = SourceNode;
},
/* buffer-from/index.js */ function _(require, module, exports, __esModule, __esExport) {/* eslint-disable node/no-deprecated-api */
    var toString = Object.prototype.toString;
    var isModern = (typeof Buffer !== 'undefined' &&
        typeof Buffer.alloc === 'function' &&
        typeof Buffer.allocUnsafe === 'function' &&
        typeof Buffer.from === 'function');
    function isArrayBuffer(input) {
        return toString.call(input).slice(8, -1) === 'ArrayBuffer';
    }
    function fromArrayBuffer(obj, byteOffset, length) {
        byteOffset >>>= 0;
        var maxLength = obj.byteLength - byteOffset;
        if (maxLength < 0) {
            throw new RangeError("'offset' is out of bounds");
        }
        if (length === undefined) {
            length = maxLength;
        }
        else {
            length >>>= 0;
            if (length > maxLength) {
                throw new RangeError("'length' is out of bounds");
            }
        }
        return isModern
            ? Buffer.from(obj.slice(byteOffset, byteOffset + length))
            : new Buffer(new Uint8Array(obj.slice(byteOffset, byteOffset + length)));
    }
    function fromString(string, encoding) {
        if (typeof encoding !== 'string' || encoding === '') {
            encoding = 'utf8';
        }
        if (!Buffer.isEncoding(encoding)) {
            throw new TypeError('"encoding" must be a valid string encoding');
        }
        return isModern
            ? Buffer.from(string, encoding)
            : new Buffer(string, encoding);
    }
    function bufferFrom(value, encodingOrOffset, length) {
        if (typeof value === 'number') {
            throw new TypeError('"value" argument must not be a number');
        }
        if (isArrayBuffer(value)) {
            return fromArrayBuffer(value, encodingOrOffset, length);
        }
        if (typeof value === 'string') {
            return fromString(value, encodingOrOffset);
        }
        return isModern
            ? Buffer.from(value)
            : new Buffer(value);
    }
    module.exports = bufferFrom;
},
/* build.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.build = exports.init = exports.isPlainObject = exports.isObject = exports.isString = void 0;
    const cp = __importStar(require("child_process"));
    const path_1 = require("path");
    const sys_1 = require(20) /* ./sys */;
    const compiler_1 = require(36) /* ./compiler */;
    const linker_1 = require(44) /* ./linker */;
    const styles_1 = require(55) /* ./styles */;
    const preludes = __importStar(require(214) /* ./prelude */);
    const tsconfig_json = __importStar(require(215) /* ./tsconfig.ext.json */);
    const chalk_1 = __importDefault(require(37) /* chalk */);
    const { cyan, magenta, red } = chalk_1.default;
    const eslint_1 = require(216) /* eslint */;
    require(768) /* @typescript-eslint/eslint-plugin */;
    require(1294) /* @typescript-eslint/parser */;
    const readline = __importStar(require("readline"));
    const toString = Object.prototype.toString;
    function isString(obj) {
        return toString.call(obj) === "[object String]";
    }
    exports.isString = isString;
    function isObject(obj) {
        const tp = typeof obj;
        return tp === "function" || tp === "object" && !!obj;
    }
    exports.isObject = isObject;
    function isPlainObject(obj) {
        return isObject(obj) && (typeof obj.constructor == "undefined" || obj.constructor === Object);
    }
    exports.isPlainObject = isPlainObject;
    function print(str) {
        console.log(str);
    }
    function npm_install(base_dir) {
        const npm = process.platform != "win32" ? "npm" : "npm.cmd";
        const { status } = cp.spawnSync(npm, ["install"], { stdio: "inherit", cwd: base_dir });
        if (status != null && status != 0) {
            print(`${cyan("npm install")} failed with exit code ${red(`${status}`)}.`);
            process.exit(status);
        }
    }
    function is_up_to_date(base_dir, file, metadata) {
        const contents = (0, sys_1.read)((0, path_1.join)(base_dir, file));
        if (contents == null)
            return false;
        const old_hash = metadata.signatures[file];
        if (old_hash == null)
            return false;
        const new_hash = (0, sys_1.hash)(contents);
        return old_hash == new_hash;
    }
    function needs_install(base_dir, metadata) {
        if (!(0, sys_1.directory_exists)((0, path_1.join)(base_dir, "node_modules")))
            return "New development environment.";
        else if (!is_up_to_date(base_dir, "package.json", metadata))
            return "package.json has changed.";
        else if (!is_up_to_date(base_dir, "package-lock.json", metadata))
            return "package-lock.json has changed.";
        else
            return null;
    }
    async function lint(config_file, paths) {
        const eslint = new eslint_1.ESLint({
            extensions: [".ts", ".js"],
            overrideConfigFile: config_file,
        });
        const results = await eslint.lintFiles(paths);
        const errors = results.some(result => result.errorCount != 0);
        const warnings = results.some(result => result.warningCount != 0);
        if (errors || warnings) {
            const formatter = await eslint.loadFormatter("stylish");
            const output = await formatter.format(results);
            for (const line of output.trim().split("\n"))
                print(line);
        }
        return !errors;
    }
    async function init(base_dir, _bokehjs_dir, base_setup) {
        print(`Working directory: ${cyan(base_dir)}`);
        const setup = {
            interactive: base_setup.interactive ?? false,
            bokehjs_version: base_setup.bokehjs_version ?? base_setup.bokeh_version.split("-")[0],
            bokeh_version: base_setup.bokeh_version,
        };
        const paths = {
            bokeh_ext: (0, path_1.join)(base_dir, "bokeh.ext.json"),
            package: (0, path_1.join)(base_dir, "package.json"),
            package_lock: (0, path_1.join)(base_dir, "package-lock.json"),
            tsconfig: (0, path_1.join)(base_dir, "tsconfig.json"),
            index: (0, path_1.join)(base_dir, "index.ts"),
        };
        const is_extension = (0, sys_1.file_exists)(paths.bokeh_ext);
        if (is_extension) {
            print("Already a bokeh extension. Quitting.");
            return false;
        }
        function write_json(path, json) {
            (0, sys_1.write)(path, JSON.stringify(json, undefined, 2));
            print(`Wrote ${cyan(path)}`);
        }
        const bokeh_ext_json = {};
        write_json(paths.bokeh_ext, bokeh_ext_json);
        const package_json = {
            name: (0, path_1.basename)(base_dir),
            version: "0.0.1",
            description: "",
            license: "BSD-3-Clause",
            keywords: [],
            repository: {},
            dependencies: {
                "@bokeh/bokehjs": `^${setup.bokehjs_version}`,
            },
            devDependencies: {},
        };
        if (setup.interactive) {
            const rl = readline.createInterface({ input: process.stdin, output: process.stdout });
            async function ask(question, default_value) {
                return new Promise((resolve, _reject) => {
                    rl.question(`${question} `, (answer) => {
                        resolve(answer.length != 0 ? answer : default_value);
                    });
                });
            }
            async function ask_yn(question) {
                const ret = await ask(`${question} [y/n]`, "y");
                switch (ret) {
                    case "y":
                        return true;
                    case "n":
                        return false;
                    default: {
                        print(`${red("Invalid input")}. Assuming no.`);
                        return false;
                    }
                }
            }
            if (await ask_yn(`Create ${cyan("package.json")}? This will allow you to specify external dependencies.`)) {
                const { name } = package_json;
                package_json.name = await ask(`  What's the extension's name? [${name}]`, name);
                const { version } = package_json;
                package_json.version = await ask(`  What's the extension's version? [${version}]`, version);
                const { description } = package_json;
                package_json.description = await ask(`  What's the extension's description? [${description}]`, description);
                write_json(paths.package, package_json);
            }
            if (await ask_yn(`Create ${cyan("tsconfig.json")}? This will allow for customized configuration and improved IDE experience.`)) {
                write_json(paths.tsconfig, tsconfig_json);
            }
            rl.close();
        }
        else {
            write_json(paths.package, package_json);
            write_json(paths.tsconfig, tsconfig_json);
        }
        (0, sys_1.write)(paths.index, "export {}");
        print(`Created empty ${cyan("index.ts")}. This is the entry point of your extension.`);
        const rel = (0, path_1.relative)(process.cwd(), base_dir);
        print(`You can build your extension with ${magenta(`bokeh build ${rel}`)}`);
        print("All done.");
        return true;
    }
    exports.init = init;
    async function build(base_dir, bokehjs_dir, base_setup) {
        print(`Working directory: ${cyan(base_dir)}`);
        const setup = {
            rebuild: base_setup.rebuild ?? false,
            bokeh_version: base_setup.bokeh_version,
        };
        const bokeh_ext_json_path = (0, path_1.join)(base_dir, "bokeh.ext.json");
        const bokeh_ext = (0, sys_1.read_json)(bokeh_ext_json_path);
        if (!isPlainObject(bokeh_ext)) {
            print("Not a bokeh extension. Quitting.");
            return false;
        }
        const metadata_path = (0, path_1.join)(base_dir, ".bokeh");
        const metadata = (() => {
            let obj = (0, sys_1.read_json)(metadata_path);
            if (obj == null)
                obj = {};
            if (obj.signatures == null)
                obj.signatures = {};
            return obj;
        })();
        if (metadata.bokeh_version != setup.bokeh_version) {
            print("Using different version of bokeh, rebuilding from scratch.");
            setup.rebuild = true;
        }
        const package_json_path = (0, path_1.join)(base_dir, "package.json");
        const package_lock_json_path = (0, path_1.join)(base_dir, "package-lock.json");
        const is_package = (0, sys_1.file_exists)(package_json_path);
        if (!is_package) {
            print(`${cyan(package_json_path)} doesn't exist. Not a npm package.`);
        }
        else {
            if (setup.rebuild) {
                print(`Running ${cyan("npm install")}.`);
                npm_install(base_dir);
            }
            else {
                const result = needs_install(base_dir, metadata);
                if (result != null) {
                    print(`${result} Running ${cyan("npm install")}.`);
                    npm_install(base_dir);
                }
            }
        }
        const package_json = (is_package ? (0, sys_1.read_json)(package_json_path) : {});
        const is_static_dir = (0, path_1.basename)(bokehjs_dir) == "static";
        const tslib_dir = (() => {
            if (package_json.devDependencies?.typescript != null) {
                return (0, path_1.join)(base_dir, "node_modules", "typescript", "lib");
            }
            else {
                // bokeh/server/static or bokehjs/build
                if (is_static_dir)
                    return (0, path_1.join)(bokehjs_dir, "lib");
                else
                    return (0, path_1.join)((0, path_1.dirname)(bokehjs_dir), "node_modules", "typescript", "lib");
            }
        })();
        print(`TypeScript lib: ${cyan(tslib_dir)}`);
        const tsconfig_path = (0, path_1.join)(base_dir, "tsconfig.json");
        const tsconfig = (() => {
            const preconfigure = {
                baseUrl: base_dir,
                paths: {
                    "@bokehjs/*": [
                        (0, path_1.join)(bokehjs_dir, "js/lib/*"),
                    ],
                },
            };
            if ((0, sys_1.file_exists)(tsconfig_path)) {
                print(`Using ${cyan(tsconfig_path)}`);
                return (0, compiler_1.read_tsconfig)(tsconfig_path, is_package ? undefined : preconfigure);
            }
            else
                return (0, compiler_1.parse_tsconfig)(tsconfig_json, base_dir, preconfigure);
        })();
        if ((0, compiler_1.is_failed)(tsconfig)) {
            print((0, compiler_1.report_diagnostics)(tsconfig.diagnostics).text);
            return false;
        }
        let success = true;
        const { files, options } = tsconfig;
        const dist_dir = (0, path_1.join)(base_dir, "dist");
        const lib_dir = options.outDir ?? (0, path_1.join)(dist_dir, "lib");
        const dts_dir = options.declarationDir ?? lib_dir;
        const dts_internal_dir = (0, path_1.join)(dist_dir, "dts");
        const styles_dir = (0, path_1.join)(base_dir, "styles");
        const css_dir = (0, path_1.join)(dist_dir, "css");
        print("Compiling styles");
        if (!await (0, styles_1.compile_styles)(styles_dir, css_dir))
            success = false;
        (0, styles_1.wrap_css_modules)(css_dir, lib_dir, dts_dir, dts_internal_dir);
        const transformers = (0, compiler_1.default_transformers)(options);
        const host = (0, compiler_1.compiler_host)(new Map(), options, tslib_dir);
        print(`Compiling TypeScript (${magenta(`${files.length} files`)})`);
        const tsoutput = (0, compiler_1.compile_files)(files, options, transformers, host);
        if ((0, compiler_1.is_failed)(tsoutput)) {
            print((0, compiler_1.report_diagnostics)(tsoutput.diagnostics).text);
            if (options.noEmitOnError ?? false)
                return false;
        }
        const lint_config = (0, path_1.join)(base_dir, "eslint.js");
        if ((0, sys_1.file_exists)(lint_config)) {
            print("Linting sources");
            lint(lint_config, files);
        }
        const artifact = (0, path_1.basename)(base_dir);
        const bases = [lib_dir];
        if (is_package)
            bases.push((0, path_1.join)(base_dir, "node_modules"));
        const linker = new linker_1.Linker({
            entries: [(0, path_1.join)(lib_dir, "index.js")],
            bases,
            cache: (0, path_1.join)(dist_dir, `${artifact}.json`),
            excluded: (dep) => dep == "tslib" || dep.startsWith("@bokehjs/"),
            plugin: true,
            target: "ES2017",
        });
        print("Linking modules");
        if (!setup.rebuild)
            linker.load_cache();
        const { bundles, status } = await linker.link();
        if (!status)
            success = false;
        linker.store_cache();
        const outputs = [(0, path_1.join)(dist_dir, `${artifact}.js`)];
        const min_js = (js) => (0, sys_1.rename)(js, { ext: ".min.js" });
        const license = (() => {
            if (isPlainObject(bokeh_ext.license)) {
                if (isString(bokeh_ext.license.file)) {
                    const license_path = (0, path_1.join)(base_dir, bokeh_ext.license.file);
                    const text = (0, sys_1.read)(license_path);
                    if (text != null)
                        return text;
                    else
                        print(`Failed to license text from ${magenta(license_path)}`);
                }
                if (isString(bokeh_ext.license.text)) {
                    return bokeh_ext.license.text;
                }
            }
            return null;
        })();
        const license_text = license != null ? `${preludes.comment(license)}\n` : "";
        const prelude_base = `${license_text}${preludes.plugin_prelude()}`;
        const prelude = { main: prelude_base, plugin: prelude_base };
        const postlude_base = preludes.plugin_postlude();
        const postlude = { main: postlude_base, plugin: postlude_base };
        // HACK {{{
        for (const bundle of bundles) {
            bundle.bases.push({});
        }
        // }}}
        function bundle(minified, outputs) {
            bundles
                .map((bundle) => bundle.assemble({ prelude, postlude, minified }))
                .map((artifact, i) => artifact.write(outputs[i]));
        }
        bundle(false, outputs);
        bundle(true, outputs.map(min_js));
        (0, sys_1.write)(metadata_path, JSON.stringify({
            bokeh_version: setup.bokeh_version,
            signatures: {
                "package.json": (0, sys_1.hash_file)(package_json_path),
                "package-lock.json": (0, sys_1.hash_file)(package_lock_json_path),
                "tsconfig.json": (0, sys_1.hash_file)(tsconfig_path),
            },
        }));
        print(`Output written to ${cyan(dist_dir)}`);
        print("All done.");
        return !(0, compiler_1.is_failed)(tsoutput) && success;
    }
    exports.build = build;
    
},
/* compiler.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.compile_typescript = exports.read_tsconfig = exports.parse_tsconfig = exports.compile_files = exports.default_transformers = exports.compiler_host = exports.report_diagnostics = exports.is_failed = void 0;
    const chalk_1 = __importDefault(require(37) /* chalk */);
    const typescript_1 = __importDefault(require(21) /* typescript */);
    const path_1 = require("path");
    const transforms = __importStar(require(42) /* ./transforms */);
    const error_1 = require(43) /* ./error */;
    function is_failed(obj) {
        return typeof obj == "object" && obj != null && "diagnostics" in obj && obj.diagnostics != null;
    }
    exports.is_failed = is_failed;
    function normalize(path) {
        return path.replace(/\\/g, "/");
    }
    const diagnostics_host = {
        getCanonicalFileName: (path) => path,
        getCurrentDirectory: typescript_1.default.sys.getCurrentDirectory,
        getNewLine: () => typescript_1.default.sys.newLine,
    };
    function report_diagnostics(diagnostics) {
        const errors = typescript_1.default.sortAndDeduplicateDiagnostics(diagnostics);
        const text = typescript_1.default.formatDiagnosticsWithColorAndContext(errors, diagnostics_host);
        return { count: errors.length, text };
    }
    exports.report_diagnostics = report_diagnostics;
    function compiler_host(inputs, options, tslib_dir) {
        const default_host = typescript_1.default.createIncrementalCompilerHost(options);
        const host = {
            ...default_host,
            fileExists(name) {
                return inputs.get(name) != null || default_host.fileExists(name);
            },
            readFile(name) {
                return inputs.get(name) != null ? inputs.get(name) : default_host.readFile(name);
            },
            getSourceFile(name, target, _onError) {
                const source = inputs.get(name);
                if (source != null) {
                    const sf = typescript_1.default.createSourceFile(name, source, target);
                    const version = default_host.createHash(source);
                    return { ...sf, version }; // version is internal to the compiler
                }
                else
                    return default_host.getSourceFile(name, target, _onError);
            },
        };
        if (tslib_dir != null) {
            host.getDefaultLibLocation = () => tslib_dir;
        }
        return host;
    }
    exports.compiler_host = compiler_host;
    function default_transformers(options) {
        const transformers = {
            before: [],
            after: [],
            afterDeclarations: [],
        };
        const insert_class_name = transforms.insert_class_name();
        transformers.before.push(insert_class_name);
        const base = options.baseUrl;
        if (base != null) {
            const relativize_modules = transforms.relativize_modules((file, module_path) => {
                if (!module_path.startsWith(".") && !module_path.startsWith("/")) {
                    const module_file = (0, path_1.join)(base, module_path);
                    if (typescript_1.default.sys.fileExists(module_file) ||
                        typescript_1.default.sys.fileExists(`${module_file}.ts`) ||
                        typescript_1.default.sys.fileExists((0, path_1.join)(module_file, "index.ts")) ||
                        options.outDir != null && typescript_1.default.sys.fileExists((0, path_1.join)(options.outDir, `${module_path}.js`))) {
                        const rel_path = normalize((0, path_1.relative)((0, path_1.dirname)(file), module_file));
                        return rel_path.startsWith(".") ? rel_path : `./${rel_path}`;
                    }
                }
                return null;
            });
            transformers.after.push(relativize_modules);
            transformers.afterDeclarations.push(relativize_modules);
        }
        return transformers;
    }
    exports.default_transformers = default_transformers;
    function compile_files(inputs, options, transformers, host) {
        const program = typescript_1.default.createIncrementalProgram({ rootNames: inputs, options, host });
        const emitted = program.emit(undefined, undefined, undefined, false, transformers);
        const diagnostics = [
            ...program.getConfigFileParsingDiagnostics(),
            ...program.getSyntacticDiagnostics(),
            ...program.getOptionsDiagnostics(),
            ...program.getGlobalDiagnostics(),
            ...program.getSemanticDiagnostics(),
            ...emitted.diagnostics,
        ];
        return diagnostics.length != 0 ? { diagnostics } : {};
    }
    exports.compile_files = compile_files;
    function parse_tsconfig(tsconfig_json, base_dir, preconfigure) {
        const host = {
            useCaseSensitiveFileNames: typescript_1.default.sys.useCaseSensitiveFileNames,
            readDirectory: typescript_1.default.sys.readDirectory,
            fileExists: typescript_1.default.sys.fileExists,
            readFile: typescript_1.default.sys.readFile,
        };
        const tsconfig = typescript_1.default.parseJsonConfigFileContent(tsconfig_json, host, base_dir, preconfigure);
        if (tsconfig.errors.length != 0) {
            return { diagnostics: tsconfig.errors };
        }
        return { files: tsconfig.fileNames, options: tsconfig.options };
    }
    exports.parse_tsconfig = parse_tsconfig;
    function read_tsconfig(tsconfig_path, preconfigure) {
        const tsconfig_file = typescript_1.default.readConfigFile(tsconfig_path, typescript_1.default.sys.readFile);
        if (tsconfig_file.error != null) {
            return { diagnostics: [tsconfig_file.error] };
        }
        return parse_tsconfig(tsconfig_file.config, (0, path_1.dirname)(tsconfig_path), preconfigure);
    }
    exports.read_tsconfig = read_tsconfig;
    function compile_project(tsconfig_path, config) {
        const tsconfig = read_tsconfig(tsconfig_path);
        if (is_failed(tsconfig))
            return { diagnostics: tsconfig.diagnostics };
        const { files, options } = tsconfig;
        const transformers = default_transformers(tsconfig.options);
        const inputs = config.inputs?.(files) ?? new Map();
        const host = compiler_host(inputs, options, config.tslib_dir);
        const input_files = [...inputs.keys(), ...files];
        return compile_files(input_files, options, transformers, host);
    }
    function compile_typescript(tsconfig_path, config = {}) {
        const result = compile_project(tsconfig_path, config);
        if (is_failed(result)) {
            const { count, text } = report_diagnostics(result.diagnostics);
            throw new error_1.BuildError("typescript", `There were ${chalk_1.default.red(`${count}`)} TypeScript errors:\n${text}`);
        }
    }
    exports.compile_typescript = compile_typescript;
    
},
/* chalk/source/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const ansiStyles = require(12) /* ansi-styles */;
    const { stdout: stdoutColor, stderr: stderrColor } = require(38) /* supports-color */;
    const { stringReplaceAll, stringEncaseCRLFWithFirstIndex } = require(40) /* ./util */;
    const { isArray } = Array;
    // `supportsColor.level` → `ansiStyles.color[name]` mapping
    const levelMapping = [
        'ansi',
        'ansi',
        'ansi256',
        'ansi16m'
    ];
    const styles = Object.create(null);
    const applyOptions = (object, options = {}) => {
        if (options.level && !(Number.isInteger(options.level) && options.level >= 0 && options.level <= 3)) {
            throw new Error('The `level` option should be an integer from 0 to 3');
        }
        // Detect level if not set manually
        const colorLevel = stdoutColor ? stdoutColor.level : 0;
        object.level = options.level === undefined ? colorLevel : options.level;
    };
    class ChalkClass {
        constructor(options) {
            // eslint-disable-next-line no-constructor-return
            return chalkFactory(options);
        }
    }
    const chalkFactory = options => {
        const chalk = {};
        applyOptions(chalk, options);
        chalk.template = (...arguments_) => chalkTag(chalk.template, ...arguments_);
        Object.setPrototypeOf(chalk, Chalk.prototype);
        Object.setPrototypeOf(chalk.template, chalk);
        chalk.template.constructor = () => {
            throw new Error('`chalk.constructor()` is deprecated. Use `new chalk.Instance()` instead.');
        };
        chalk.template.Instance = ChalkClass;
        return chalk.template;
    };
    function Chalk(options) {
        return chalkFactory(options);
    }
    for (const [styleName, style] of Object.entries(ansiStyles)) {
        styles[styleName] = {
            get() {
                const builder = createBuilder(this, createStyler(style.open, style.close, this._styler), this._isEmpty);
                Object.defineProperty(this, styleName, { value: builder });
                return builder;
            }
        };
    }
    styles.visible = {
        get() {
            const builder = createBuilder(this, this._styler, true);
            Object.defineProperty(this, 'visible', { value: builder });
            return builder;
        }
    };
    const usedModels = ['rgb', 'hex', 'keyword', 'hsl', 'hsv', 'hwb', 'ansi', 'ansi256'];
    for (const model of usedModels) {
        styles[model] = {
            get() {
                const { level } = this;
                return function (...arguments_) {
                    const styler = createStyler(ansiStyles.color[levelMapping[level]][model](...arguments_), ansiStyles.color.close, this._styler);
                    return createBuilder(this, styler, this._isEmpty);
                };
            }
        };
    }
    for (const model of usedModels) {
        const bgModel = 'bg' + model[0].toUpperCase() + model.slice(1);
        styles[bgModel] = {
            get() {
                const { level } = this;
                return function (...arguments_) {
                    const styler = createStyler(ansiStyles.bgColor[levelMapping[level]][model](...arguments_), ansiStyles.bgColor.close, this._styler);
                    return createBuilder(this, styler, this._isEmpty);
                };
            }
        };
    }
    const proto = Object.defineProperties(() => { }, {
        ...styles,
        level: {
            enumerable: true,
            get() {
                return this._generator.level;
            },
            set(level) {
                this._generator.level = level;
            }
        }
    });
    const createStyler = (open, close, parent) => {
        let openAll;
        let closeAll;
        if (parent === undefined) {
            openAll = open;
            closeAll = close;
        }
        else {
            openAll = parent.openAll + open;
            closeAll = close + parent.closeAll;
        }
        return {
            open,
            close,
            openAll,
            closeAll,
            parent
        };
    };
    const createBuilder = (self, _styler, _isEmpty) => {
        const builder = (...arguments_) => {
            if (isArray(arguments_[0]) && isArray(arguments_[0].raw)) {
                // Called as a template literal, for example: chalk.red`2 + 3 = {bold ${2+3}}`
                return applyStyle(builder, chalkTag(builder, ...arguments_));
            }
            // Single argument is hot path, implicit coercion is faster than anything
            // eslint-disable-next-line no-implicit-coercion
            return applyStyle(builder, (arguments_.length === 1) ? ('' + arguments_[0]) : arguments_.join(' '));
        };
        // We alter the prototype because we must return a function, but there is
        // no way to create a function with a different prototype
        Object.setPrototypeOf(builder, proto);
        builder._generator = self;
        builder._styler = _styler;
        builder._isEmpty = _isEmpty;
        return builder;
    };
    const applyStyle = (self, string) => {
        if (self.level <= 0 || !string) {
            return self._isEmpty ? '' : string;
        }
        let styler = self._styler;
        if (styler === undefined) {
            return string;
        }
        const { openAll, closeAll } = styler;
        if (string.indexOf('\u001B') !== -1) {
            while (styler !== undefined) {
                // Replace any instances already present with a re-opening code
                // otherwise only the part of the string until said closing code
                // will be colored, and the rest will simply be 'plain'.
                string = stringReplaceAll(string, styler.close, styler.open);
                styler = styler.parent;
            }
        }
        // We can move both next actions out of loop, because remaining actions in loop won't have
        // any/visible effect on parts we add here. Close the styling before a linebreak and reopen
        // after next line to fix a bleed issue on macOS: https://github.com/chalk/chalk/pull/92
        const lfIndex = string.indexOf('\n');
        if (lfIndex !== -1) {
            string = stringEncaseCRLFWithFirstIndex(string, closeAll, openAll, lfIndex);
        }
        return openAll + string + closeAll;
    };
    let template;
    const chalkTag = (chalk, ...strings) => {
        const [firstString] = strings;
        if (!isArray(firstString) || !isArray(firstString.raw)) {
            // If chalk() was called by itself or with a string,
            // return the string itself as a string.
            return strings.join(' ');
        }
        const arguments_ = strings.slice(1);
        const parts = [firstString.raw[0]];
        for (let i = 1; i < firstString.length; i++) {
            parts.push(String(arguments_[i - 1]).replace(/[{}\\]/g, '\\$&'), String(firstString.raw[i]));
        }
        if (template === undefined) {
            template = require(41) /* ./templates */;
        }
        return template(chalk, parts.join(''));
    };
    Object.defineProperties(Chalk.prototype, styles);
    const chalk = Chalk(); // eslint-disable-line new-cap
    chalk.supportsColor = stdoutColor;
    chalk.stderr = Chalk({ level: stderrColor ? stderrColor.level : 0 }); // eslint-disable-line new-cap
    chalk.stderr.supportsColor = stderrColor;
    module.exports = chalk;
},
/* supports-color/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const os = require('os');
    const tty = require('tty');
    const hasFlag = require(39) /* has-flag */;
    const { env } = process;
    let forceColor;
    if (hasFlag('no-color') ||
        hasFlag('no-colors') ||
        hasFlag('color=false') ||
        hasFlag('color=never')) {
        forceColor = 0;
    }
    else if (hasFlag('color') ||
        hasFlag('colors') ||
        hasFlag('color=true') ||
        hasFlag('color=always')) {
        forceColor = 1;
    }
    if ('FORCE_COLOR' in env) {
        if (env.FORCE_COLOR === 'true') {
            forceColor = 1;
        }
        else if (env.FORCE_COLOR === 'false') {
            forceColor = 0;
        }
        else {
            forceColor = env.FORCE_COLOR.length === 0 ? 1 : Math.min(parseInt(env.FORCE_COLOR, 10), 3);
        }
    }
    function translateLevel(level) {
        if (level === 0) {
            return false;
        }
        return {
            level,
            hasBasic: true,
            has256: level >= 2,
            has16m: level >= 3
        };
    }
    function supportsColor(haveStream, streamIsTTY) {
        if (forceColor === 0) {
            return 0;
        }
        if (hasFlag('color=16m') ||
            hasFlag('color=full') ||
            hasFlag('color=truecolor')) {
            return 3;
        }
        if (hasFlag('color=256')) {
            return 2;
        }
        if (haveStream && !streamIsTTY && forceColor === undefined) {
            return 0;
        }
        const min = forceColor || 0;
        if (env.TERM === 'dumb') {
            return min;
        }
        if (process.platform === 'win32') {
            // Windows 10 build 10586 is the first Windows release that supports 256 colors.
            // Windows 10 build 14931 is the first release that supports 16m/TrueColor.
            const osRelease = os.release().split('.');
            if (Number(osRelease[0]) >= 10 &&
                Number(osRelease[2]) >= 10586) {
                return Number(osRelease[2]) >= 14931 ? 3 : 2;
            }
            return 1;
        }
        if ('CI' in env) {
            if (['TRAVIS', 'CIRCLECI', 'APPVEYOR', 'GITLAB_CI', 'GITHUB_ACTIONS', 'BUILDKITE'].some(sign => sign in env) || env.CI_NAME === 'codeship') {
                return 1;
            }
            return min;
        }
        if ('TEAMCITY_VERSION' in env) {
            return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ? 1 : 0;
        }
        if (env.COLORTERM === 'truecolor') {
            return 3;
        }
        if ('TERM_PROGRAM' in env) {
            const version = parseInt((env.TERM_PROGRAM_VERSION || '').split('.')[0], 10);
            switch (env.TERM_PROGRAM) {
                case 'iTerm.app':
                    return version >= 3 ? 3 : 2;
                case 'Apple_Terminal':
                    return 2;
                // No default
            }
        }
        if (/-256(color)?$/i.test(env.TERM)) {
            return 2;
        }
        if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env.TERM)) {
            return 1;
        }
        if ('COLORTERM' in env) {
            return 1;
        }
        return min;
    }
    function getSupportLevel(stream) {
        const level = supportsColor(stream, stream && stream.isTTY);
        return translateLevel(level);
    }
    module.exports = {
        supportsColor: getSupportLevel,
        stdout: translateLevel(supportsColor(true, tty.isatty(1))),
        stderr: translateLevel(supportsColor(true, tty.isatty(2)))
    };
},
/* has-flag/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = (flag, argv = process.argv) => {
        const prefix = flag.startsWith('-') ? '' : (flag.length === 1 ? '-' : '--');
        const position = argv.indexOf(prefix + flag);
        const terminatorPosition = argv.indexOf('--');
        return position !== -1 && (terminatorPosition === -1 || position < terminatorPosition);
    };
},
/* chalk/source/util.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const stringReplaceAll = (string, substring, replacer) => {
        let index = string.indexOf(substring);
        if (index === -1) {
            return string;
        }
        const substringLength = substring.length;
        let endIndex = 0;
        let returnValue = '';
        do {
            returnValue += string.substr(endIndex, index - endIndex) + substring + replacer;
            endIndex = index + substringLength;
            index = string.indexOf(substring, endIndex);
        } while (index !== -1);
        returnValue += string.substr(endIndex);
        return returnValue;
    };
    const stringEncaseCRLFWithFirstIndex = (string, prefix, postfix, index) => {
        let endIndex = 0;
        let returnValue = '';
        do {
            const gotCR = string[index - 1] === '\r';
            returnValue += string.substr(endIndex, (gotCR ? index - 1 : index) - endIndex) + prefix + (gotCR ? '\r\n' : '\n') + postfix;
            endIndex = index + 1;
            index = string.indexOf('\n', endIndex);
        } while (index !== -1);
        returnValue += string.substr(endIndex);
        return returnValue;
    };
    module.exports = {
        stringReplaceAll,
        stringEncaseCRLFWithFirstIndex
    };
},
/* chalk/source/templates.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const TEMPLATE_REGEX = /(?:\\(u(?:[a-f\d]{4}|\{[a-f\d]{1,6}\})|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi;
    const STYLE_REGEX = /(?:^|\.)(\w+)(?:\(([^)]*)\))?/g;
    const STRING_REGEX = /^(['"])((?:\\.|(?!\1)[^\\])*)\1$/;
    const ESCAPE_REGEX = /\\(u(?:[a-f\d]{4}|{[a-f\d]{1,6}})|x[a-f\d]{2}|.)|([^\\])/gi;
    const ESCAPES = new Map([
        ['n', '\n'],
        ['r', '\r'],
        ['t', '\t'],
        ['b', '\b'],
        ['f', '\f'],
        ['v', '\v'],
        ['0', '\0'],
        ['\\', '\\'],
        ['e', '\u001B'],
        ['a', '\u0007']
    ]);
    function unescape(c) {
        const u = c[0] === 'u';
        const bracket = c[1] === '{';
        if ((u && !bracket && c.length === 5) || (c[0] === 'x' && c.length === 3)) {
            return String.fromCharCode(parseInt(c.slice(1), 16));
        }
        if (u && bracket) {
            return String.fromCodePoint(parseInt(c.slice(2, -1), 16));
        }
        return ESCAPES.get(c) || c;
    }
    function parseArguments(name, arguments_) {
        const results = [];
        const chunks = arguments_.trim().split(/\s*,\s*/g);
        let matches;
        for (const chunk of chunks) {
            const number = Number(chunk);
            if (!Number.isNaN(number)) {
                results.push(number);
            }
            else if ((matches = chunk.match(STRING_REGEX))) {
                results.push(matches[2].replace(ESCAPE_REGEX, (m, escape, character) => escape ? unescape(escape) : character));
            }
            else {
                throw new Error(`Invalid Chalk template style argument: ${chunk} (in style '${name}')`);
            }
        }
        return results;
    }
    function parseStyle(style) {
        STYLE_REGEX.lastIndex = 0;
        const results = [];
        let matches;
        while ((matches = STYLE_REGEX.exec(style)) !== null) {
            const name = matches[1];
            if (matches[2]) {
                const args = parseArguments(name, matches[2]);
                results.push([name].concat(args));
            }
            else {
                results.push([name]);
            }
        }
        return results;
    }
    function buildStyle(chalk, styles) {
        const enabled = {};
        for (const layer of styles) {
            for (const style of layer.styles) {
                enabled[style[0]] = layer.inverse ? null : style.slice(1);
            }
        }
        let current = chalk;
        for (const [styleName, styles] of Object.entries(enabled)) {
            if (!Array.isArray(styles)) {
                continue;
            }
            if (!(styleName in current)) {
                throw new Error(`Unknown Chalk style: ${styleName}`);
            }
            current = styles.length > 0 ? current[styleName](...styles) : current[styleName];
        }
        return current;
    }
    module.exports = (chalk, temporary) => {
        const styles = [];
        const chunks = [];
        let chunk = [];
        // eslint-disable-next-line max-params
        temporary.replace(TEMPLATE_REGEX, (m, escapeCharacter, inverse, style, close, character) => {
            if (escapeCharacter) {
                chunk.push(unescape(escapeCharacter));
            }
            else if (style) {
                const string = chunk.join('');
                chunk = [];
                chunks.push(styles.length === 0 ? string : buildStyle(chalk, styles)(string));
                styles.push({ inverse, styles: parseStyle(style) });
            }
            else if (close) {
                if (styles.length === 0) {
                    throw new Error('Found extraneous } in Chalk template literal');
                }
                chunks.push(buildStyle(chalk, styles)(chunk.join('')));
                chunk = [];
                styles.pop();
            }
            else {
                chunk.push(character);
            }
        });
        chunks.push(chunk.join(''));
        if (styles.length > 0) {
            const errMessage = `Chalk template literal is missing ${styles.length} closing bracket${styles.length === 1 ? '' : 's'} (\`}\`)`;
            throw new Error(errMessage);
        }
        return chunks.join('');
    };
},
/* transforms.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.print_es = exports.parse_es = exports.wrap_in_function = exports.fix_regl = exports.fix_esexports = exports.remove_void0 = exports.fix_esmodule = exports.rename_exports = exports.rewrite_deps = exports.collect_deps = exports.collect_imports = exports.collect_exports = exports.remove_use_strict = exports.insert_class_name = exports.relativize_modules = exports.apply = void 0;
    const typescript_1 = __importDefault(require(21) /* typescript */);
    function apply(node, ...transforms) {
        const result = typescript_1.default.transform(node, transforms);
        return result.transformed[0];
    }
    exports.apply = apply;
    function is_require(node) {
        return typescript_1.default.isCallExpression(node) &&
            typescript_1.default.isIdentifier(node.expression) &&
            node.expression.text === "require" &&
            node.arguments.length === 1;
    }
    function isImportCall(node) {
        return typescript_1.default.isCallExpression(node) && node.expression.kind == typescript_1.default.SyntaxKind.ImportKeyword;
    }
    function relativize_modules(relativize) {
        function relativize_specifier(context, source, expr) {
            const { factory } = context;
            if (expr != null && typescript_1.default.isStringLiteralLike(expr) && expr.text.length > 0) {
                const relative = relativize(source.fileName, expr.text);
                if (relative != null)
                    return factory.createStringLiteral(relative);
            }
            return null;
        }
        return (context) => {
            return {
                transformSourceFile(root) {
                    const { factory } = context;
                    function visit(node) {
                        if (typescript_1.default.isImportDeclaration(node)) {
                            const moduleSpecifier = relativize_specifier(context, root, node.moduleSpecifier);
                            if (moduleSpecifier != null) {
                                const { modifiers, importClause, assertClause } = node;
                                return factory.updateImportDeclaration(node, modifiers, importClause, moduleSpecifier, assertClause);
                            }
                        }
                        else if (typescript_1.default.isExportDeclaration(node)) {
                            const moduleSpecifier = relativize_specifier(context, root, node.moduleSpecifier);
                            if (moduleSpecifier != null) {
                                const { modifiers, isTypeOnly, exportClause, assertClause } = node;
                                return factory.updateExportDeclaration(node, modifiers, isTypeOnly, exportClause, moduleSpecifier, assertClause);
                            }
                        }
                        else if (is_require(node)) {
                            const moduleSpecifier = relativize_specifier(context, root, node.arguments[0]);
                            if (moduleSpecifier != null) {
                                const { expression, typeArguments } = node;
                                return factory.updateCallExpression(node, expression, typeArguments, [moduleSpecifier]);
                            }
                        }
                        else if (isImportCall(node)) {
                            const moduleSpecifier = relativize_specifier(context, root, node.arguments[0]);
                            if (moduleSpecifier != null) {
                                const { expression, typeArguments } = node;
                                return factory.updateCallExpression(node, expression, typeArguments, [moduleSpecifier]);
                            }
                        }
                        return typescript_1.default.visitEachChild(node, visit, context);
                    }
                    return typescript_1.default.visitEachChild(root, visit, context);
                },
                transformBundle(_root) {
                    throw new Error("unsupported");
                },
            };
        };
    }
    exports.relativize_modules = relativize_modules;
    function is_static(node) {
        return typescript_1.default.canHaveModifiers(node) && typescript_1.default.getModifiers(node)?.find((modifier) => modifier.kind == typescript_1.default.SyntaxKind.StaticKeyword) != null;
    }
    function insert_class_name() {
        function has__name__(node) {
            return node.members.find((member) => typescript_1.default.isPropertyDeclaration(member) && member.name.getText() == "__name__" && is_static(member)) != null;
        }
        return (context) => (root) => {
            const { factory } = context;
            function visit(node) {
                node = typescript_1.default.visitEachChild(node, visit, context);
                if (typescript_1.default.isClassDeclaration(node) && node.name != null && !has__name__(node)) {
                    const property = factory.createPropertyDeclaration(factory.createModifiersFromModifierFlags(typescript_1.default.ModifierFlags.Static), "__name__", undefined, undefined, factory.createStringLiteral(node.name.text));
                    node = factory.updateClassDeclaration(node, node.modifiers, node.name, node.typeParameters, node.heritageClauses, [property, ...node.members]);
                }
                return node;
            }
            return typescript_1.default.visitEachChild(root, visit, context);
        };
    }
    exports.insert_class_name = insert_class_name;
    function remove_use_strict() {
        return (context) => (root) => {
            const { factory } = context;
            const statements = root.statements.filter((node) => {
                if (typescript_1.default.isExpressionStatement(node)) {
                    const expr = node.expression;
                    if (typescript_1.default.isStringLiteral(expr) && expr.text == "use strict")
                        return false;
                }
                return true;
            });
            return factory.updateSourceFile(root, statements);
        };
    }
    exports.remove_use_strict = remove_use_strict;
    function collect_exports(exported) {
        return (_context) => (root) => {
            for (const statement of root.statements) {
                if (typescript_1.default.isExportDeclaration(statement)) {
                    if (statement.isTypeOnly)
                        continue;
                    const { exportClause, moduleSpecifier } = statement;
                    if (moduleSpecifier == null || !typescript_1.default.isStringLiteral(moduleSpecifier))
                        continue;
                    const module = moduleSpecifier.text;
                    if (exportClause == null) {
                        // export * from "module"
                        exported.push({ type: "namespace", module });
                    }
                    else if (typescript_1.default.isNamespaceExport(exportClause)) {
                        // export * as name from "module"
                        const name = exportClause.name.text;
                        exported.push({ type: "namespace", name, module });
                    }
                    else if (typescript_1.default.isNamedExports(exportClause)) {
                        // export {name0, name1 as nameA} from "module"
                        const bindings = [];
                        for (const elem of exportClause.elements) {
                            bindings.push([elem.propertyName?.text, elem.name.text]);
                        }
                        exported.push({ type: "bindings", bindings, module });
                    }
                }
                else if (typescript_1.default.isExportAssignment(statement) && !(statement.isExportEquals ?? false)) {
                    // export default name
                    exported.push({ type: "named", name: "default" });
                }
                else if (typescript_1.default.isClassDeclaration(statement) || typescript_1.default.isFunctionDeclaration(statement)) {
                    const flags = typescript_1.default.getCombinedModifierFlags(statement);
                    if ((flags & typescript_1.default.ModifierFlags.Export) != 0) {
                        // export class X {}
                        // export function f() {}
                        if (statement.name != null) {
                            const name = statement.name.text;
                            exported.push({ type: "named", name });
                        }
                    }
                    else if ((flags & typescript_1.default.ModifierFlags.ExportDefault) != 0) {
                        // export default class X {}
                        // export function f() {}
                        exported.push({ type: "named", name: "default" });
                    }
                }
            }
            return root;
        };
    }
    exports.collect_exports = collect_exports;
    function collect_imports(imports) {
        return (context) => (root) => {
            function visit(node) {
                if (typescript_1.default.isImportDeclaration(node) || typescript_1.default.isExportDeclaration(node)) {
                    const name = node.moduleSpecifier;
                    if (name != null && typescript_1.default.isStringLiteral(name) && name.text.length != 0)
                        imports.add(name.text);
                }
                else if (isImportCall(node)) {
                    const [name] = node.arguments;
                    if (typescript_1.default.isStringLiteral(name) && name.text.length != 0)
                        imports.add(name.text);
                }
                return typescript_1.default.visitEachChild(node, visit, context);
            }
            return typescript_1.default.visitEachChild(root, visit, context);
        };
    }
    exports.collect_imports = collect_imports;
    function collect_deps(source) {
        function traverse(node) {
            if (is_require(node)) {
                const [arg] = node.arguments;
                if (typescript_1.default.isStringLiteral(arg) && arg.text.length > 0)
                    deps.add(arg.text);
            }
            typescript_1.default.forEachChild(node, traverse);
        }
        const deps = new Set();
        traverse(source);
        return [...deps];
    }
    exports.collect_deps = collect_deps;
    function rewrite_deps(resolve) {
        return (context) => (root) => {
            const { factory } = context;
            function visit(node) {
                if (is_require(node)) {
                    const [arg] = node.arguments;
                    if (typescript_1.default.isStringLiteral(arg) && arg.text.length > 0) {
                        const dep = arg.text;
                        const val = resolve(dep);
                        if (val != null) {
                            const literal = typeof val == "string" ? factory.createStringLiteral(val) : factory.createNumericLiteral(val);
                            node = factory.updateCallExpression(node, node.expression, node.typeArguments, [literal]);
                            typescript_1.default.addSyntheticTrailingComment(node, typescript_1.default.SyntaxKind.MultiLineCommentTrivia, ` ${dep} `, false);
                        }
                        return node;
                    }
                }
                return typescript_1.default.visitEachChild(node, visit, context);
            }
            return typescript_1.default.visitEachChild(root, visit, context);
        };
    }
    exports.rewrite_deps = rewrite_deps;
    // XXX: this is pretty naive, but affects very litte code
    function rename_exports() {
        return (context) => (root) => {
            const { factory } = context;
            function is_exports(node) {
                return typescript_1.default.isIdentifier(node) && node.text == "exports";
            }
            const has_exports = root.statements.some((stmt) => {
                return typescript_1.default.isVariableStatement(stmt) && stmt.declarationList.declarations.some((decl) => is_exports(decl.name));
            });
            if (has_exports) {
                function visit(node) {
                    if (is_exports(node)) {
                        const updated = factory.createIdentifier("exports$1");
                        const original = node;
                        typescript_1.default.setOriginalNode(updated, original);
                        typescript_1.default.setTextRange(updated, original);
                        return updated;
                    }
                    return typescript_1.default.visitEachChild(node, visit, context);
                }
                return typescript_1.default.visitEachChild(root, visit, context);
            }
            else
                return root;
        };
    }
    exports.rename_exports = rename_exports;
    function fix_esmodule() {
        return (context) => (root) => {
            const { factory } = context;
            let found = false;
            const statements = root.statements.map((node) => {
                if (!found && typescript_1.default.isExpressionStatement(node)) {
                    const expr = node.expression;
                    if (typescript_1.default.isCallExpression(expr) && expr.arguments.length == 3) {
                        const [, arg] = expr.arguments;
                        if (typescript_1.default.isStringLiteral(arg) && arg.text == "__esModule") {
                            found = true;
                            const es_module = factory.createIdentifier("__esModule");
                            const call = factory.createCallExpression(es_module, [], []);
                            return factory.createExpressionStatement(call);
                        }
                    }
                }
                return node;
            });
            return factory.updateSourceFile(root, statements);
        };
    }
    exports.fix_esmodule = fix_esmodule;
    function remove_void0() {
        return (context) => (root) => {
            const { factory } = context;
            let found = false;
            const statements = root.statements.filter((node) => {
                if (!found && typescript_1.default.isExpressionStatement(node)) {
                    let { expression } = node;
                    while (typescript_1.default.isBinaryExpression(expression) &&
                        typescript_1.default.isPropertyAccessExpression(expression.left) &&
                        typescript_1.default.isIdentifier(expression.left.expression) &&
                        expression.left.expression.text == "exports") {
                        expression = expression.right;
                    }
                    if (typescript_1.default.isVoidExpression(expression)) {
                        found = true;
                        return false;
                    }
                }
                return true;
            });
            return factory.updateSourceFile(root, statements);
        };
    }
    exports.remove_void0 = remove_void0;
    function fix_esexports() {
        return (context) => (root) => {
            const { factory } = context;
            const statements = root.statements.map((node) => {
                if (typescript_1.default.isExpressionStatement(node)) {
                    const expr = node.expression;
                    if (typescript_1.default.isCallExpression(expr) && typescript_1.default.isPropertyAccessExpression(expr.expression) && expr.arguments.length == 3) {
                        const { expression, name } = expr.expression;
                        if (typescript_1.default.isIdentifier(expression) && expression.text == "Object" &&
                            typescript_1.default.isIdentifier(name) && name.text == "defineProperty") {
                            const [exports, name, config] = expr.arguments;
                            if (typescript_1.default.isIdentifier(exports) && exports.text == "exports" &&
                                typescript_1.default.isStringLiteral(name) &&
                                typescript_1.default.isObjectLiteralExpression(config)) {
                                for (const item of config.properties) {
                                    if (typescript_1.default.isPropertyAssignment(item) &&
                                        typescript_1.default.isIdentifier(item.name) && item.name.text == "get" &&
                                        typescript_1.default.isFunctionExpression(item.initializer)) {
                                        const { statements } = item.initializer.body;
                                        if (statements.length == 1) {
                                            const [stmt] = statements;
                                            if (typescript_1.default.isReturnStatement(stmt) && stmt.expression != null) {
                                                const es_export = factory.createIdentifier("__esExport");
                                                const call = factory.createCallExpression(es_export, [], [name, stmt.expression]);
                                                return factory.createExpressionStatement(call);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
                return node;
            });
            return factory.updateSourceFile(root, statements);
        };
    }
    exports.fix_esexports = fix_esexports;
    function fix_regl() {
        return (context) => (root) => {
            if (!root.fileName.endsWith("regl.js")) {
                return root;
            }
            const { factory } = context;
            function visit(node) {
                if (typescript_1.default.isFunctionDeclaration(node) && node.name != null && typescript_1.default.isIdentifier(node.name)) {
                    if (node.name.text == "guessCommand" || node.name.text == "guessCallSite") {
                        const value = factory.createStringLiteral("unknown");
                        const body = factory.createBlock([factory.createReturnStatement(value)]);
                        return factory.createFunctionDeclaration(undefined, undefined, node.name, undefined, [], undefined, body);
                    }
                }
                return typescript_1.default.visitEachChild(node, visit, context);
            }
            return typescript_1.default.visitEachChild(root, visit, context);
        };
    }
    exports.fix_regl = fix_regl;
    function wrap_in_function(module_name) {
        return (context) => (root) => {
            const { factory } = context;
            const p = (name) => factory.createParameterDeclaration(undefined, undefined, name);
            const params = [p("require"), p("module"), p("exports"), p("__esModule"), p("__esExport")];
            const block = factory.createBlock(root.statements, true);
            const func = factory.createFunctionDeclaration(undefined, undefined, "_", undefined, params, undefined, block);
            typescript_1.default.addSyntheticLeadingComment(func, typescript_1.default.SyntaxKind.MultiLineCommentTrivia, ` ${module_name} `, false);
            return factory.updateSourceFile(root, [func]);
        };
    }
    exports.wrap_in_function = wrap_in_function;
    function parse_es(file, code, target = typescript_1.default.ScriptTarget.ES2017) {
        return typescript_1.default.createSourceFile(file, code != null ? code : typescript_1.default.sys.readFile(file), target, true, typescript_1.default.ScriptKind.JS);
    }
    exports.parse_es = parse_es;
    function print_es(source) {
        const printer = typescript_1.default.createPrinter();
        return printer.printNode(typescript_1.default.EmitHint.SourceFile, source, source);
    }
    exports.print_es = print_es;
    
},
/* error.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.BuildError = void 0;
    class BuildError extends Error {
        component;
        static __name__ = "BuildError";
        constructor(component, message) {
            super(message);
            this.component = component;
        }
    }
    exports.BuildError = BuildError;
    
},
/* linker.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.minify = exports.transpile = exports.Linker = exports.Artifact = exports.Bundle = void 0;
    const path_1 = require("path");
    const module_1 = __importDefault(require("module"));
    const crypto_1 = __importDefault(require("crypto"));
    const typescript_1 = __importDefault(require(21) /* typescript */);
    const terser = __importStar(require(45) /* terser */);
    const chalk_1 = __importDefault(require(37) /* chalk */);
    const combine = __importStar(require(48) /* combine-source-map */);
    const convert = __importStar(require(49) /* convert-source-map */);
    const sys_1 = require(20) /* ./sys */;
    const compiler_1 = require(36) /* ./compiler */;
    const transforms = __importStar(require(42) /* ./transforms */);
    const error_1 = require(43) /* ./error */;
    const graph_1 = require(54) /* ./graph */;
    const root_path = process.cwd();
    const cache_version = 4;
    const to_obj = (map) => {
        const obj = Object.create(null);
        for (const [key, val] of map) {
            obj[key] = val;
        }
        return obj;
    };
    const dense_assembly = {
        prefix: "[",
        suffix: "]",
        wrap: (_, source) => source,
    };
    const sparse_assembly = {
        prefix: "{",
        suffix: "}",
        wrap: (id, source) => `${id}: ${source}`,
    };
    class Bundle {
        entry;
        artifacts;
        builtins;
        bases;
        static __name__ = "Bundle";
        constructor(entry, artifacts, builtins, bases = []) {
            this.entry = entry;
            this.artifacts = artifacts;
            this.builtins = builtins;
            this.bases = bases;
        }
        assemble(options) {
            let line = 0;
            let sources = "";
            const sourcemap = combine.create();
            const aliases = new Map();
            const externals = new Map();
            const newlines = (source) => {
                const result = source.match(/\n/g);
                return result != null ? result.length : 0;
            };
            const safe_id = (module) => {
                const { id } = module;
                return typeof id == "number" ? id.toString() : JSON.stringify(id);
            };
            const { entry, artifacts, bases } = this;
            const minified = options.minified ?? false;
            const plugin = bases.length != 0;
            const { prefix, suffix, wrap } = !plugin ? dense_assembly : sparse_assembly;
            const prelude = !plugin ? options.prelude.main : options.prelude.plugin;
            const postlude = !plugin ? options.postlude.main : options.postlude.plugin;
            sources += `${prelude}(${prefix}\n`;
            line += newlines(sources);
            for (const artifact of artifacts) {
                const { module } = artifact;
                if (module.canonical != null)
                    aliases.set(module.canonical, module.id);
                for (const external of module.externals)
                    externals.set(external, true);
                for (const external of module.shims)
                    externals.set(external, false);
                const start = wrap(safe_id(module), "");
                sources += start;
                line += newlines(start);
                const source_with_sourcemap = minified ? artifact.code.min_source : artifact.code.source;
                const source = combine.removeComments(source_with_sourcemap).trimEnd();
                sources += source;
                const map_path = (0, path_1.join)("@@", (0, path_1.relative)(root_path, module.file));
                sourcemap.addFile({ source: source_with_sourcemap, sourceFile: map_path }, { line });
                line += newlines(source);
                const end = ",\n";
                sources += end;
                line += newlines(end);
            }
            const aliases_json = JSON.stringify(to_obj(aliases));
            const externals_json = JSON.stringify(to_obj(externals));
            sources += `${suffix}, ${safe_id(entry)}, ${aliases_json}, ${externals_json});${postlude}`;
            const source_map = convert.fromBase64(sourcemap.base64()).toObject();
            return new Artifact(sources, minified ? null : source_map, aliases);
        }
        *collect_exported(entry) {
            for (const item of entry.exported) {
                switch (item.type) {
                    case "bindings": {
                        for (const [, name] of item.bindings) {
                            yield name;
                        }
                        break;
                    }
                    case "named": {
                        yield item.name;
                        break;
                    }
                    case "namespace": {
                        const { name } = item;
                        if (name != null)
                            yield name;
                        else {
                            const module = entry.dependencies.get(item.module);
                            if (module != null) {
                                yield* this.collect_exported(module);
                            }
                        }
                        break;
                    }
                }
            }
        }
    }
    exports.Bundle = Bundle;
    class Artifact {
        source;
        sourcemap;
        exported;
        static __name__ = "Artifact";
        constructor(source, sourcemap, exported) {
            this.source = source;
            this.sourcemap = sourcemap;
            this.exported = exported;
        }
        full_source(name) {
            if (this.sourcemap != null)
                return `${this.source}\n${convert.generateMapFileComment(name)}\n`;
            else
                return `${this.source}\n`;
        }
        get module_names() {
            return Array.from(this.exported.keys());
        }
        write(path) {
            const dir = (0, path_1.dirname)(path);
            const name = (0, path_1.basename)(path, ".js");
            (0, sys_1.write)(path, this.full_source(`${name}.js.map`));
            if (this.sourcemap != null) {
                (0, sys_1.write)((0, path_1.join)(dir, `${name}.js.map`), JSON.stringify(this.sourcemap));
            }
        }
    }
    exports.Artifact = Artifact;
    class Linker {
        static __name__ = "Linker";
        entries;
        bases;
        excludes;
        external_modules;
        external_regex;
        excluded;
        builtins;
        cache_path;
        cache;
        target;
        es_modules;
        minify;
        plugin;
        exports;
        shims;
        detect_cycles;
        overrides;
        apply_transforms;
        constructor(opts) {
            this.entries = opts.entries.map((path) => (0, path_1.resolve)(path));
            this.bases = (opts.bases ?? []).map((path) => (0, path_1.resolve)(path));
            this.excludes = new Set((opts.excludes ?? []).map((path) => (0, path_1.resolve)(path)));
            this.external_modules = new Set((opts.externals ?? []).filter((s) => typeof s === "string"));
            this.external_regex = (opts.externals ?? []).filter((s) => s instanceof RegExp);
            this.excluded = opts.excluded ?? (() => false);
            this.builtins = opts.builtins ?? false;
            this.exports = new Set(opts.exports ?? []);
            if (this.builtins) {
                this.external_modules.add("module");
                this.external_modules.add("constants");
                for (const lib of module_1.default.builtinModules)
                    this.external_modules.add(lib);
            }
            for (const entry of this.entries) {
                if (!(0, sys_1.file_exists)(entry))
                    throw new error_1.BuildError("linker", `entry path ${entry} doesn't exist or isn't a file`);
            }
            for (const base of this.bases) {
                if (!(0, sys_1.directory_exists)(base))
                    throw new error_1.BuildError("linker", `base path ${base} doesn't exist or isn't a directory`);
            }
            this.cache_path = opts.cache;
            this.cache = new Map();
            this.target = opts.target ?? null;
            this.es_modules = opts.es_modules ?? true;
            this.minify = opts.minify ?? true;
            this.plugin = opts.plugin ?? false;
            this.shims = new Set(opts.shims ?? []);
            this.detect_cycles = opts.detect_cycles ?? true;
            this.overrides = new Map(Object.entries(opts.overrides ?? {}));
            this.apply_transforms = opts.apply_transforms ?? true;
        }
        is_external(dep) {
            return this.external_modules.has(dep) || this.external_regex.some((re) => re.test(dep));
        }
        is_shimmed(dep) {
            return this.shims.has(dep);
        }
        async link() {
            let status = true;
            const [entries] = this.resolve(this.entries);
            const [main, ...plugins] = entries;
            const dirnames = plugins.map((plugin) => (0, path_1.dirname)(plugin.file));
            const is_excluded = (module) => {
                return dirnames.find((e) => module.file.startsWith(e)) != null;
            };
            const main_modules = this.reachable(main, is_excluded);
            const parents = new Set(main_modules);
            const plugin_modules = [];
            for (const plugin of plugins) {
                const files = this.reachable(plugin, (module) => parents.has(module));
                plugin_modules.push(files);
            }
            const all_modules = main_modules.concat(...plugin_modules);
            if (!this.plugin)
                all_modules.forEach((module, i) => module.id = i);
            else
                all_modules.forEach((module) => module.id = module.hash.slice(0, 10));
            if (this.detect_cycles) {
                function is_internal(module) {
                    return module.canonical != null;
                }
                const nodes = all_modules.filter(is_internal);
                const graph = new Map();
                for (const node of nodes) {
                    const deps = [...node.dependencies.values()];
                    graph.set(node, deps.filter(is_internal));
                }
                const cycles = (0, graph_1.detect_cycles)(graph);
                if (cycles.length != 0) {
                    status = false;
                    for (const cycle of cycles) {
                        console.log(`${chalk_1.default.red("\u2717")} cycle detected:`);
                        for (const module of cycle) {
                            const is_last = cycle[cycle.length - 1] == module;
                            console.log(`${is_last ? "\u2514" : "\u251c"}\u2500 ${module.canonical ?? module.base_path}`);
                        }
                    }
                }
            }
            const transformers = (module) => {
                const transformers = [];
                if (this.apply_transforms) {
                    const remove_use_strict = transforms.remove_use_strict();
                    transformers.push(remove_use_strict);
                    const fix_esmodule = transforms.fix_esmodule();
                    transformers.push(fix_esmodule);
                    const remove_void0 = transforms.remove_void0();
                    transformers.push(remove_void0);
                    const fix_esexports = transforms.fix_esexports();
                    transformers.push(fix_esexports);
                    const fix_regl = transforms.fix_regl();
                    transformers.push(fix_regl);
                }
                const rewrite_deps = transforms.rewrite_deps((dep) => {
                    const module_dep = module.dependencies.get(dep);
                    return module_dep != null ? module_dep.id : undefined;
                });
                transformers.push(rewrite_deps);
                transformers.push(transforms.wrap_in_function(module.base_path));
                return transformers;
            };
            const print = (module) => {
                let ast = module.ast ?? this.parse_module(module);
                ast = transforms.apply(ast, ...transformers(module));
                const source = transforms.print_es(ast);
                return convert.removeMapFileComments(source);
            };
            const deps_changed = (module, cached) => {
                if (module.dependencies.size != cached.dependencies.size)
                    return false;
                for (const [dep, module_dep] of module.dependencies) {
                    const cached_dep = cached.dependencies.get(dep);
                    if (cached_dep == null || cached_dep.id != module_dep.id)
                        return true;
                }
                return false;
            };
            const artifacts = async (modules) => {
                const result = [];
                for (const module of modules) {
                    const cached = this.cache.get(module.file);
                    let code;
                    if (module.changed || (cached != null && deps_changed(module, cached.module))) {
                        const source = print(module);
                        const ecma = (() => {
                            switch (this.target) {
                                case "ES2022": return 2020; // TODO: 2022
                                case "ES2020": return 2020;
                                case null:
                                case "ES2017": return 2017;
                                case "ES2015": return 5;
                            }
                        })();
                        const minified = this.minify ? await minify(module, source, ecma) : { min_source: source };
                        code = { source, ...minified };
                    }
                    else
                        code = cached.code;
                    result.push({ module, code });
                }
                return result;
            };
            const main_bundle = new Bundle(main, await artifacts(main_modules), this.builtins);
            const plugin_bundles = [];
            for (let j = 0; j < plugins.length; j++) {
                const plugin_bundle = new Bundle(plugins[j], await artifacts(plugin_modules[j]), this.builtins, [main_bundle]);
                plugin_bundles.push(plugin_bundle);
            }
            const bundles = [main_bundle, ...plugin_bundles];
            this.cache.clear();
            for (const bundle of bundles) {
                for (const artifact of bundle.artifacts) {
                    this.cache.set(artifact.module.file, artifact);
                }
            }
            return { bundles, status };
        }
        load_cache() {
            const { cache_path } = this;
            if (cache_path == null || !(0, sys_1.file_exists)(cache_path))
                return;
            this.cache.clear();
            const json = JSON.parse((0, sys_1.read)(cache_path));
            if (json.version !== cache_version) {
                console.warn("ignoring cache due to format version mismatch");
                return;
            }
            for (const { module, code } of json.artifacts) {
                const artifact = {
                    module: {
                        ...module,
                        ast: undefined,
                        changed: false,
                        dependencies: new Map(),
                        dependency_map: new Map(module.dependency_map),
                        dependency_paths: new Map(module.dependency_paths),
                        externals: new Set(module.externals),
                        shims: new Set(module.shims),
                    },
                    code,
                };
                this.cache.set(artifact.module.file, artifact);
            }
            for (const { module } of this.cache.values()) {
                for (const [dep, file] of module.dependency_paths) {
                    const file_entry = this.cache.get(file);
                    if (file_entry == null)
                        throw new Error(`${file} not in cache`);
                    module.dependencies.set(dep, file_entry.module);
                }
            }
        }
        store_cache() {
            if (this.cache_path == null)
                return;
            const artifacts = [];
            for (const artifact of this.cache.values()) {
                const module = {
                    ...artifact.module,
                    changed: undefined,
                    ast: undefined,
                    dependencies: undefined,
                };
                artifacts.push({
                    module: {
                        ...module,
                        dependency_map: [...module.dependency_map.entries()],
                        dependency_paths: [...module.dependency_paths.entries()],
                        externals: [...module.externals.values()],
                        shims: [...module.shims.values()],
                    },
                    code: artifact.code,
                });
            }
            const json = JSON.stringify({ version: cache_version, artifacts });
            (0, sys_1.write)(this.cache_path, json);
        }
        ext = ".js";
        get_package(dir) {
            const pkg_path = (0, path_1.join)(dir, "package.json");
            if ((0, sys_1.file_exists)(pkg_path))
                return JSON.parse((0, sys_1.read)(pkg_path));
            else
                return {};
        }
        resolve_export_map(dir, subpath) {
            const pkg = this.get_package(dir);
            const export_map = (pkg.exports ?? {});
            const path = (0, path_1.join)(dir, subpath);
            for (const [key, val] of Object.entries(export_map)) {
                if ((0, path_1.join)(dir, key) == path) {
                    return (0, path_1.join)(dir, val);
                }
            }
            return null;
        }
        resolve_package(dir) {
            const pkg = this.get_package(dir);
            const index = (() => {
                if (this.target != null && pkg.module != null)
                    return pkg.module;
                else if (pkg.main != null)
                    return pkg.main;
                else
                    return "index.js";
            })();
            const path = (0, path_1.join)(dir, index);
            if ((0, sys_1.file_exists)(path))
                return path;
            const js_file = `${path}.js`;
            if ((0, sys_1.file_exists)(js_file))
                return js_file;
            const json_file = `${path}.json`;
            if ((0, sys_1.file_exists)(json_file))
                return json_file;
            if ((0, sys_1.directory_exists)(path)) {
                const index = (0, path_1.join)(path, "index.js");
                if ((0, sys_1.file_exists)(index))
                    return index;
            }
            return null;
        }
        resolve_relative(dep, parent) {
            const path = (0, path_1.resolve)((0, path_1.dirname)(parent.file), dep);
            if ((0, sys_1.file_exists)(path))
                return path;
            const js_file = `${path}.js`;
            const json_file = `${path}.json`;
            const has_js_file = (0, sys_1.file_exists)(js_file);
            const has_json_file = (0, sys_1.file_exists)(json_file);
            const has_file = has_js_file || has_json_file;
            if ((0, sys_1.directory_exists)(path)) {
                const pkg_file = this.resolve_package(path);
                if (pkg_file != null) {
                    if (!has_file)
                        return pkg_file;
                    else
                        return new error_1.BuildError("linker", `both ${has_js_file ? js_file : json_file} and ${pkg_file} exist`);
                }
            }
            if (has_js_file)
                return js_file;
            else if (has_json_file)
                return json_file;
            else
                return new error_1.BuildError("linker", `can't resolve '${dep}' from '${parent.file}'`);
        }
        resolve_absolute(dep, parent) {
            for (const base of this.bases) {
                let path = (0, path_1.join)(base, dep);
                if ((0, sys_1.file_exists)(path))
                    return path;
                const js_file = `${path}.js`;
                if ((0, sys_1.file_exists)(js_file))
                    return js_file;
                const json_file = `${path}.json`;
                if ((0, sys_1.file_exists)(json_file))
                    return json_file;
                if ((0, sys_1.directory_exists)(path)) {
                    const file = this.resolve_package(path);
                    if (file != null)
                        return file;
                }
                const [dir, ...rest] = dep.split(path_1.sep);
                if (rest.length >= 1) {
                    const path = (0, path_1.join)(base, dir);
                    if ((0, sys_1.directory_exists)(path)) {
                        const file = this.resolve_export_map(path, rest.join(path_1.sep));
                        if (file != null)
                            return file;
                    }
                }
                if (parent.file.startsWith(base)) {
                    let base_path = parent.file;
                    while (true) {
                        base_path = (0, path_1.dirname)(base_path);
                        if (base_path == base)
                            break;
                        path = (0, path_1.join)(base_path, "node_modules", dep);
                        if ((0, sys_1.directory_exists)(path)) {
                            const file = this.resolve_package(path);
                            if (file != null)
                                return file;
                        }
                    }
                }
            }
            return new error_1.BuildError("linker", `can't resolve '${dep}' from '${parent.file}'`);
        }
        resolve_file(dep, parent) {
            if (dep.startsWith("."))
                return this.resolve_relative(dep, parent);
            else
                return this.resolve_absolute(dep, parent);
        }
        parse_module({ file, source }) {
            return transforms.parse_es(file, source);
        }
        new_module(file) {
            let source = (0, sys_1.read)(file);
            if (source == null) {
                throw new error_1.BuildError("linker", `'${file} doesn't exist`);
            }
            for (const [path, override] of this.overrides) {
                if (file.endsWith((0, path_1.normalize)(path))) {
                    source = override;
                    break;
                }
            }
            const hash = crypto_1.default.createHash("sha256").update(source).digest("hex");
            const type = (() => {
                switch ((0, path_1.extname)(file)) {
                    case ".json": return "json";
                    case ".json5": return "json5";
                    case ".yaml": return "yaml";
                    case ".css": return "css";
                    case ".mjs": return "js";
                    case ".cjs": return "js";
                    case ".js": return "js";
                    default:
                        throw new error_1.BuildError("linker", `unsupported extension of ${file}`);
                }
            })();
            const export_type = this.es_modules ? "default" : "=";
            switch (type) {
                case "json": {
                    source = `\
const json = ${source};
export ${export_type} json;
`;
                    break;
                }
                case "json5": {
                    source = `\
const json5 = \`
${source}
\`;
export ${export_type} json5;
`;
                    break;
                }
                case "css": {
                    source = `\
const css = \`${source}\`;
export ${export_type} css;
`;
                    break;
                }
                case "yaml": {
                    source = `\
const yaml = \`
${source}
\`;
export ${export_type} yaml;
`;
                    break;
                }
                case "js": {
                    break;
                }
            }
            const [base, base_path, canonical, resolution] = (() => {
                const [primary, ...secondary] = this.bases;
                function canonicalize(path) {
                    return path.replace(/\.js$/, "").replace(/\\/g, "/");
                }
                function get_package(base, path) {
                    const root = (0, path_1.join)(base, path);
                    base = (0, path_1.normalize)(base);
                    path = (0, path_1.normalize)(root);
                    while (path != base) {
                        if ((0, sys_1.directory_exists)(path)) {
                            const pkg_path = (0, path_1.join)(path, "package.json");
                            if ((0, sys_1.file_exists)(pkg_path))
                                return { dir: path, pkg: JSON.parse((0, sys_1.read)(pkg_path)) };
                        }
                        path = (0, path_1.dirname)(path);
                    }
                    throw new error_1.BuildError("linker", `can't resolve package.json for ${root}`);
                }
                const path = (0, path_1.relative)(primary, file);
                if (!path.startsWith("..")) {
                    return [primary, path, canonicalize(path), "ESM"];
                }
                for (const base of secondary) {
                    const path = (0, path_1.relative)(base, file);
                    if (!path.startsWith("..")) {
                        if (type == "js") {
                            const { dir, pkg } = get_package(base, path);
                            const reso = pkg.type == "module" || pkg.module != null ? "ESM" : "CJS";
                            const entry = pkg.module ?? pkg.name;
                            const primary = entry != null && (0, path_1.join)(dir, entry) == (0, path_1.join)(base, path);
                            const name = canonicalize(primary ? (0, path_1.basename)(dir) : path);
                            const exported = this.exports.has(name);
                            return [base, path, exported ? name : undefined, reso];
                        }
                        else {
                            return [base, path, undefined, "ESM"];
                        }
                    }
                }
                throw new error_1.BuildError("linker", `${file} is not under any of base paths`);
            })();
            const cached = this.cache.get(file);
            let ast;
            let dependency_paths;
            let externals;
            let shims;
            let exported = [];
            const changed = cached == null || cached.module.hash != hash;
            if (changed) {
                let collected = null;
                if ((this.target != null && resolution == "ESM") || type == "json") {
                    const { ES2022, ES2020, ES2017, ES2015 } = typescript_1.default.ScriptTarget;
                    const target = (() => {
                        switch (this.target) {
                            case "ES2022": return ES2022;
                            case "ES2020": return ES2020;
                            case null:
                            case "ES2017": return ES2017;
                            case "ES2015": return ES2015;
                        }
                    })();
                    const imports = new Set();
                    if (canonical != "tslib") {
                        imports.add("tslib");
                    }
                    const transform = {
                        before: [transforms.collect_imports(imports), transforms.rename_exports(), transforms.collect_exports(exported)],
                        after: [],
                    };
                    // XXX: .json extension will cause an internal error
                    const { output, error } = transpile(type == "json" ? `${file}.ts` : file, source, target, transform);
                    if (error != null)
                        throw new error_1.BuildError("linker", error);
                    else {
                        source = output;
                        collected = [...imports];
                    }
                }
                ast = this.parse_module({ file, source });
                if (collected == null)
                    collected = transforms.collect_deps(ast);
                const filtered = collected.filter((dep) => !this.is_external(dep) && !this.excluded(dep) && !this.is_shimmed(dep));
                dependency_paths = new Map();
                for (const dep of filtered) {
                    const resolved = this.resolve_file(dep, { file });
                    if (resolved instanceof Error)
                        console.log(resolved);
                    else
                        dependency_paths.set(dep, resolved);
                }
                externals = new Set(collected.filter((dep) => this.is_external(dep)));
                shims = new Set(collected.filter((dep) => this.is_shimmed(dep)));
            }
            else {
                dependency_paths = cached.module.dependency_paths;
                exported = cached.module.exported;
                externals = cached.module.externals;
                shims = cached.module.shims;
                source = cached.module.source;
            }
            return {
                file,
                base,
                base_path,
                canonical,
                resolution,
                id: NaN,
                hash,
                changed,
                source,
                ast,
                type,
                dependency_paths,
                dependency_map: new Map(),
                dependencies: new Map(),
                exported,
                externals,
                shims,
            };
        }
        resolve(files) {
            const visited = new Map();
            const pending = [...files];
            for (;;) {
                const file = pending.shift();
                if (file == null)
                    break;
                if (visited.has(file) || this.excludes.has(file))
                    continue;
                const module = this.new_module(file);
                visited.set(module.file, module);
                pending.unshift(...module.dependency_paths.values());
            }
            for (const module of visited.values()) {
                for (const [dep, file] of module.dependency_paths) {
                    module.dependencies.set(dep, visited.get(file));
                }
            }
            const entries = files.map((file) => visited.get(file));
            return [entries, [...visited.values()]];
        }
        reachable(entry, is_excluded) {
            const reached = new Set();
            const pending = [entry];
            for (;;) {
                const module = pending.shift();
                if (module == null)
                    break;
                if (reached.has(module) || this.excludes.has(module.file) || is_excluded(module))
                    continue;
                reached.add(module);
                pending.unshift(...module.dependencies.values());
            }
            return [...reached.values()];
        }
    }
    exports.Linker = Linker;
    function transpile(file, source, target, transformers) {
        const { outputText: output, diagnostics } = typescript_1.default.transpileModule(source, {
            fileName: file,
            reportDiagnostics: true,
            compilerOptions: {
                target,
                module: typescript_1.default.ModuleKind.CommonJS,
                esModuleInterop: true,
                importHelpers: true,
                downlevelIteration: true,
            },
            transformers,
        });
        if (diagnostics == null || diagnostics.length == 0)
            return { output };
        else {
            const { text } = (0, compiler_1.report_diagnostics)(diagnostics);
            return { output, error: text };
        }
    }
    exports.transpile = transpile;
    async function minify(module, source, ecma) {
        const name = (0, path_1.basename)(module.file);
        const min_js = (0, sys_1.rename)(name, { ext: ".min.js" });
        const min_js_map = (0, sys_1.rename)(name, { ext: ".min.js.map" });
        const minify_opts = {
            ecma,
            format: {
                comments: /^!|copyright|license|\(c\)/i,
                // https://github.com/terser/terser/issues/410
                ascii_only: true,
            },
            sourceMap: {
                filename: (0, path_1.basename)(min_js),
                url: (0, path_1.basename)(min_js_map),
            },
        };
        try {
            const { code, map } = await terser.minify(source, minify_opts);
            return {
                min_source: code ?? "",
                min_map: typeof map === "string" ? map : undefined,
            };
        }
        catch (error) {
            throw new error_1.BuildError("linker", `${error}`);
        }
    }
    exports.minify = minify;
    
},
/* terser/dist/bundle.min.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require(46) /* @jridgewell/source-map */) :
            typeof define === 'function' && define.amd ? define(['exports', '@jridgewell/source-map'], factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.Terser = {}, global.sourceMap));
    }(this, (function (exports, sourceMap) {
        'use strict';
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function characters(str) {
            return str.split("");
        }
        function member(name, array) {
            return array.includes(name);
        }
        class DefaultsError extends Error {
            constructor(msg, defs) {
                super();
                this.name = "DefaultsError";
                this.message = msg;
                this.defs = defs;
            }
        }
        function defaults(args, defs, croak) {
            if (args === true) {
                args = {};
            }
            else if (args != null && typeof args === "object") {
                args = { ...args };
            }
            const ret = args || {};
            if (croak)
                for (const i in ret)
                    if (HOP(ret, i) && !HOP(defs, i)) {
                        throw new DefaultsError("`" + i + "` is not a supported option", defs);
                    }
            for (const i in defs)
                if (HOP(defs, i)) {
                    if (!args || !HOP(args, i)) {
                        ret[i] = defs[i];
                    }
                    else if (i === "ecma") {
                        let ecma = args[i] | 0;
                        if (ecma > 5 && ecma < 2015)
                            ecma += 2009;
                        ret[i] = ecma;
                    }
                    else {
                        ret[i] = (args && HOP(args, i)) ? args[i] : defs[i];
                    }
                }
            return ret;
        }
        function noop() { }
        function return_false() { return false; }
        function return_true() { return true; }
        function return_this() { return this; }
        function return_null() { return null; }
        var MAP = (function () {
            function MAP(a, tw, allow_splicing = true) {
                const new_a = [];
                for (let i = 0; i < a.length; ++i) {
                    let item = a[i];
                    let ret = item.transform(tw, allow_splicing);
                    if (ret instanceof AST_Node) {
                        new_a.push(ret);
                    }
                    else if (ret instanceof Splice) {
                        new_a.push(...ret.v);
                    }
                }
                return new_a;
            }
            MAP.splice = function (val) { return new Splice(val); };
            MAP.skip = {};
            function Splice(val) { this.v = val; }
            return MAP;
        })();
        function make_node(ctor, orig, props) {
            if (!props)
                props = {};
            if (orig) {
                if (!props.start)
                    props.start = orig.start;
                if (!props.end)
                    props.end = orig.end;
            }
            return new ctor(props);
        }
        function push_uniq(array, el) {
            if (!array.includes(el))
                array.push(el);
        }
        function string_template(text, props) {
            return text.replace(/{(.+?)}/g, function (str, p) {
                return props && props[p];
            });
        }
        function remove(array, el) {
            for (var i = array.length; --i >= 0;) {
                if (array[i] === el)
                    array.splice(i, 1);
            }
        }
        function mergeSort(array, cmp) {
            if (array.length < 2)
                return array.slice();
            function merge(a, b) {
                var r = [], ai = 0, bi = 0, i = 0;
                while (ai < a.length && bi < b.length) {
                    cmp(a[ai], b[bi]) <= 0
                        ? r[i++] = a[ai++]
                        : r[i++] = b[bi++];
                }
                if (ai < a.length)
                    r.push.apply(r, a.slice(ai));
                if (bi < b.length)
                    r.push.apply(r, b.slice(bi));
                return r;
            }
            function _ms(a) {
                if (a.length <= 1)
                    return a;
                var m = Math.floor(a.length / 2), left = a.slice(0, m), right = a.slice(m);
                left = _ms(left);
                right = _ms(right);
                return merge(left, right);
            }
            return _ms(array);
        }
        function makePredicate(words) {
            if (!Array.isArray(words))
                words = words.split(" ");
            return new Set(words.sort());
        }
        function map_add(map, key, value) {
            if (map.has(key)) {
                map.get(key).push(value);
            }
            else {
                map.set(key, [value]);
            }
        }
        function map_from_object(obj) {
            var map = new Map();
            for (var key in obj) {
                if (HOP(obj, key) && key.charAt(0) === "$") {
                    map.set(key.substr(1), obj[key]);
                }
            }
            return map;
        }
        function map_to_object(map) {
            var obj = Object.create(null);
            map.forEach(function (value, key) {
                obj["$" + key] = value;
            });
            return obj;
        }
        function HOP(obj, prop) {
            return Object.prototype.hasOwnProperty.call(obj, prop);
        }
        function keep_name(keep_setting, name) {
            return keep_setting === true
                || (keep_setting instanceof RegExp && keep_setting.test(name));
        }
        var lineTerminatorEscape = {
            "\0": "0",
            "\n": "n",
            "\r": "r",
            "\u2028": "u2028",
            "\u2029": "u2029",
        };
        function regexp_source_fix(source) {
            // V8 does not escape line terminators in regexp patterns in node 12
            // We'll also remove literal \0
            return source.replace(/[\0\n\r\u2028\u2029]/g, function (match, offset) {
                var escaped = source[offset - 1] == "\\"
                    && (source[offset - 2] != "\\"
                        || /(?:^|[^\\])(?:\\{2})*$/.test(source.slice(0, offset - 1)));
                return (escaped ? "" : "\\") + lineTerminatorEscape[match];
            });
        }
        // Subset of regexps that is not going to cause regexp based DDOS
        // https://owasp.org/www-community/attacks/Regular_expression_Denial_of_Service_-_ReDoS
        const re_safe_regexp = /^[\\/|\0\s\w^$.[\]()]*$/;
        /** Check if the regexp is safe for Terser to create without risking a RegExp DOS */
        const regexp_is_safe = (source) => re_safe_regexp.test(source);
        const all_flags = "dgimsuy";
        function sort_regexp_flags(flags) {
            const existing_flags = new Set(flags.split(""));
            let out = "";
            for (const flag of all_flags) {
                if (existing_flags.has(flag)) {
                    out += flag;
                    existing_flags.delete(flag);
                }
            }
            if (existing_flags.size) {
                // Flags Terser doesn't know about
                existing_flags.forEach(flag => { out += flag; });
            }
            return out;
        }
        function has_annotation(node, annotation) {
            return node._annotations & annotation;
        }
        function set_annotation(node, annotation) {
            node._annotations |= annotation;
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
            Parser based on parse-js (http://marijn.haverbeke.nl/parse-js/).
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        var LATEST_RAW = ""; // Only used for numbers and template strings
        var TEMPLATE_RAWS = new Map(); // Raw template strings
        var KEYWORDS = "break case catch class const continue debugger default delete do else export extends finally for function if in instanceof let new return switch throw try typeof var void while with";
        var KEYWORDS_ATOM = "false null true";
        var RESERVED_WORDS = "enum import super this " + KEYWORDS_ATOM + " " + KEYWORDS;
        var ALL_RESERVED_WORDS = "implements interface package private protected public static " + RESERVED_WORDS;
        var KEYWORDS_BEFORE_EXPRESSION = "return new delete throw else case yield await";
        KEYWORDS = makePredicate(KEYWORDS);
        RESERVED_WORDS = makePredicate(RESERVED_WORDS);
        KEYWORDS_BEFORE_EXPRESSION = makePredicate(KEYWORDS_BEFORE_EXPRESSION);
        KEYWORDS_ATOM = makePredicate(KEYWORDS_ATOM);
        ALL_RESERVED_WORDS = makePredicate(ALL_RESERVED_WORDS);
        var OPERATOR_CHARS = makePredicate(characters("+-*&%=<>!?|~^"));
        var RE_NUM_LITERAL = /[0-9a-f]/i;
        var RE_HEX_NUMBER = /^0x[0-9a-f]+$/i;
        var RE_OCT_NUMBER = /^0[0-7]+$/;
        var RE_ES6_OCT_NUMBER = /^0o[0-7]+$/i;
        var RE_BIN_NUMBER = /^0b[01]+$/i;
        var RE_DEC_NUMBER = /^\d*\.?\d*(?:e[+-]?\d*(?:\d\.?|\.?\d)\d*)?$/i;
        var RE_BIG_INT = /^(0[xob])?[0-9a-f]+n$/i;
        var OPERATORS = makePredicate([
            "in",
            "instanceof",
            "typeof",
            "new",
            "void",
            "delete",
            "++",
            "--",
            "+",
            "-",
            "!",
            "~",
            "&",
            "|",
            "^",
            "*",
            "**",
            "/",
            "%",
            ">>",
            "<<",
            ">>>",
            "<",
            ">",
            "<=",
            ">=",
            "==",
            "===",
            "!=",
            "!==",
            "?",
            "=",
            "+=",
            "-=",
            "||=",
            "&&=",
            "??=",
            "/=",
            "*=",
            "**=",
            "%=",
            ">>=",
            "<<=",
            ">>>=",
            "|=",
            "^=",
            "&=",
            "&&",
            "??",
            "||",
        ]);
        var WHITESPACE_CHARS = makePredicate(characters(" \u00a0\n\r\t\f\u000b\u200b\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u2028\u2029\u202f\u205f\u3000\uFEFF"));
        var NEWLINE_CHARS = makePredicate(characters("\n\r\u2028\u2029"));
        var PUNC_AFTER_EXPRESSION = makePredicate(characters(";]),:"));
        var PUNC_BEFORE_EXPRESSION = makePredicate(characters("[{(,;:"));
        var PUNC_CHARS = makePredicate(characters("[]{}(),;:"));
        /* -----[ Tokenizer ]----- */
        // surrogate safe regexps adapted from https://github.com/mathiasbynens/unicode-8.0.0/tree/89b412d8a71ecca9ed593d9e9fa073ab64acfebe/Binary_Property
        var UNICODE = {
            ID_Start: /[$A-Z_a-z\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AD\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]/,
            ID_Continue: /(?:[$0-9A-Z_a-z\xAA\xB5\xB7\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1369-\u1371\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFC-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AD\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C4\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF])+/,
        };
        try {
            UNICODE = {
                // https://262.ecma-international.org/13.0/#prod-IdentifierStartChar
                // $, _, ID_Start
                ID_Start: new RegExp("[_$\\p{ID_Start}]", "u"),
                // https://262.ecma-international.org/13.0/#prod-IdentifierPartChar
                // $, zero-width-joiner, zero-width-non-joiner, ID_Continue
                ID_Continue: new RegExp("[$\\u200C\\u200D\\p{ID_Continue}]+", "u"),
            };
        }
        catch (e) {
            // Could not use modern JS \p{...}. UNICODE is already defined above so let's continue
        }
        function get_full_char(str, pos) {
            if (is_surrogate_pair_head(str.charCodeAt(pos))) {
                if (is_surrogate_pair_tail(str.charCodeAt(pos + 1))) {
                    return str.charAt(pos) + str.charAt(pos + 1);
                }
            }
            else if (is_surrogate_pair_tail(str.charCodeAt(pos))) {
                if (is_surrogate_pair_head(str.charCodeAt(pos - 1))) {
                    return str.charAt(pos - 1) + str.charAt(pos);
                }
            }
            return str.charAt(pos);
        }
        function get_full_char_code(str, pos) {
            // https://en.wikipedia.org/wiki/Universal_Character_Set_characters#Surrogates
            if (is_surrogate_pair_head(str.charCodeAt(pos))) {
                return 0x10000 + (str.charCodeAt(pos) - 0xd800 << 10) + str.charCodeAt(pos + 1) - 0xdc00;
            }
            return str.charCodeAt(pos);
        }
        function get_full_char_length(str) {
            var surrogates = 0;
            for (var i = 0; i < str.length; i++) {
                if (is_surrogate_pair_head(str.charCodeAt(i)) && is_surrogate_pair_tail(str.charCodeAt(i + 1))) {
                    surrogates++;
                    i++;
                }
            }
            return str.length - surrogates;
        }
        function from_char_code(code) {
            // Based on https://github.com/mathiasbynens/String.fromCodePoint/blob/master/fromcodepoint.js
            if (code > 0xFFFF) {
                code -= 0x10000;
                return (String.fromCharCode((code >> 10) + 0xD800) +
                    String.fromCharCode((code % 0x400) + 0xDC00));
            }
            return String.fromCharCode(code);
        }
        function is_surrogate_pair_head(code) {
            return code >= 0xd800 && code <= 0xdbff;
        }
        function is_surrogate_pair_tail(code) {
            return code >= 0xdc00 && code <= 0xdfff;
        }
        function is_digit(code) {
            return code >= 48 && code <= 57;
        }
        function is_identifier_start(ch) {
            return UNICODE.ID_Start.test(ch);
        }
        function is_identifier_char(ch) {
            return UNICODE.ID_Continue.test(ch);
        }
        const BASIC_IDENT = /^[a-z_$][a-z0-9_$]*$/i;
        function is_basic_identifier_string(str) {
            return BASIC_IDENT.test(str);
        }
        function is_identifier_string(str, allow_surrogates) {
            if (BASIC_IDENT.test(str)) {
                return true;
            }
            if (!allow_surrogates && /[\ud800-\udfff]/.test(str)) {
                return false;
            }
            var match = UNICODE.ID_Start.exec(str);
            if (!match || match.index !== 0) {
                return false;
            }
            str = str.slice(match[0].length);
            if (!str) {
                return true;
            }
            match = UNICODE.ID_Continue.exec(str);
            return !!match && match[0].length === str.length;
        }
        function parse_js_number(num, allow_e = true) {
            if (!allow_e && num.includes("e")) {
                return NaN;
            }
            if (RE_HEX_NUMBER.test(num)) {
                return parseInt(num.substr(2), 16);
            }
            else if (RE_OCT_NUMBER.test(num)) {
                return parseInt(num.substr(1), 8);
            }
            else if (RE_ES6_OCT_NUMBER.test(num)) {
                return parseInt(num.substr(2), 8);
            }
            else if (RE_BIN_NUMBER.test(num)) {
                return parseInt(num.substr(2), 2);
            }
            else if (RE_DEC_NUMBER.test(num)) {
                return parseFloat(num);
            }
            else {
                var val = parseFloat(num);
                if (val == num)
                    return val;
            }
        }
        class JS_Parse_Error extends Error {
            constructor(message, filename, line, col, pos) {
                super();
                this.name = "SyntaxError";
                this.message = message;
                this.filename = filename;
                this.line = line;
                this.col = col;
                this.pos = pos;
            }
        }
        function js_error(message, filename, line, col, pos) {
            throw new JS_Parse_Error(message, filename, line, col, pos);
        }
        function is_token(token, type, val) {
            return token.type == type && (val == null || token.value == val);
        }
        var EX_EOF = {};
        function tokenizer($TEXT, filename, html5_comments, shebang) {
            var S = {
                text: $TEXT,
                filename: filename,
                pos: 0,
                tokpos: 0,
                line: 1,
                tokline: 0,
                col: 0,
                tokcol: 0,
                newline_before: false,
                regex_allowed: false,
                brace_counter: 0,
                template_braces: [],
                comments_before: [],
                directives: {},
                directive_stack: []
            };
            function peek() { return get_full_char(S.text, S.pos); }
            // Used because parsing ?. involves a lookahead for a digit
            function is_option_chain_op() {
                const must_be_dot = S.text.charCodeAt(S.pos + 1) === 46;
                if (!must_be_dot)
                    return false;
                const cannot_be_digit = S.text.charCodeAt(S.pos + 2);
                return cannot_be_digit < 48 || cannot_be_digit > 57;
            }
            function next(signal_eof, in_string) {
                var ch = get_full_char(S.text, S.pos++);
                if (signal_eof && !ch)
                    throw EX_EOF;
                if (NEWLINE_CHARS.has(ch)) {
                    S.newline_before = S.newline_before || !in_string;
                    ++S.line;
                    S.col = 0;
                    if (ch == "\r" && peek() == "\n") {
                        // treat a \r\n sequence as a single \n
                        ++S.pos;
                        ch = "\n";
                    }
                }
                else {
                    if (ch.length > 1) {
                        ++S.pos;
                        ++S.col;
                    }
                    ++S.col;
                }
                return ch;
            }
            function forward(i) {
                while (i--)
                    next();
            }
            function looking_at(str) {
                return S.text.substr(S.pos, str.length) == str;
            }
            function find_eol() {
                var text = S.text;
                for (var i = S.pos, n = S.text.length; i < n; ++i) {
                    var ch = text[i];
                    if (NEWLINE_CHARS.has(ch))
                        return i;
                }
                return -1;
            }
            function find(what, signal_eof) {
                var pos = S.text.indexOf(what, S.pos);
                if (signal_eof && pos == -1)
                    throw EX_EOF;
                return pos;
            }
            function start_token() {
                S.tokline = S.line;
                S.tokcol = S.col;
                S.tokpos = S.pos;
            }
            var prev_was_dot = false;
            var previous_token = null;
            function token(type, value, is_comment) {
                S.regex_allowed = ((type == "operator" && !UNARY_POSTFIX.has(value)) ||
                    (type == "keyword" && KEYWORDS_BEFORE_EXPRESSION.has(value)) ||
                    (type == "punc" && PUNC_BEFORE_EXPRESSION.has(value))) ||
                    (type == "arrow");
                if (type == "punc" && (value == "." || value == "?.")) {
                    prev_was_dot = true;
                }
                else if (!is_comment) {
                    prev_was_dot = false;
                }
                const line = S.tokline;
                const col = S.tokcol;
                const pos = S.tokpos;
                const nlb = S.newline_before;
                const file = filename;
                let comments_before = [];
                let comments_after = [];
                if (!is_comment) {
                    comments_before = S.comments_before;
                    comments_after = S.comments_before = [];
                }
                S.newline_before = false;
                const tok = new AST_Token(type, value, line, col, pos, nlb, comments_before, comments_after, file);
                if (!is_comment)
                    previous_token = tok;
                return tok;
            }
            function skip_whitespace() {
                while (WHITESPACE_CHARS.has(peek()))
                    next();
            }
            function read_while(pred) {
                var ret = "", ch, i = 0;
                while ((ch = peek()) && pred(ch, i++))
                    ret += next();
                return ret;
            }
            function parse_error(err) {
                js_error(err, filename, S.tokline, S.tokcol, S.tokpos);
            }
            function read_num(prefix) {
                var has_e = false, after_e = false, has_x = false, has_dot = prefix == ".", is_big_int = false, numeric_separator = false;
                var num = read_while(function (ch, i) {
                    if (is_big_int)
                        return false;
                    var code = ch.charCodeAt(0);
                    switch (code) {
                        case 95: // _
                            return (numeric_separator = true);
                        case 98:
                        case 66: // bB
                            return (has_x = true); // Can occur in hex sequence, don't return false yet
                        case 111:
                        case 79: // oO
                        case 120:
                        case 88: // xX
                            return has_x ? false : (has_x = true);
                        case 101:
                        case 69: // eE
                            return has_x ? true : has_e ? false : (has_e = after_e = true);
                        case 45: // -
                            return after_e || (i == 0 && !prefix);
                        case 43: // +
                            return after_e;
                        case (after_e = false, 46): // .
                            return (!has_dot && !has_x && !has_e) ? (has_dot = true) : false;
                    }
                    if (ch === "n") {
                        is_big_int = true;
                        return true;
                    }
                    return RE_NUM_LITERAL.test(ch);
                });
                if (prefix)
                    num = prefix + num;
                LATEST_RAW = num;
                if (RE_OCT_NUMBER.test(num) && next_token.has_directive("use strict")) {
                    parse_error("Legacy octal literals are not allowed in strict mode");
                }
                if (numeric_separator) {
                    if (num.endsWith("_")) {
                        parse_error("Numeric separators are not allowed at the end of numeric literals");
                    }
                    else if (num.includes("__")) {
                        parse_error("Only one underscore is allowed as numeric separator");
                    }
                    num = num.replace(/_/g, "");
                }
                if (num.endsWith("n")) {
                    const without_n = num.slice(0, -1);
                    const allow_e = RE_HEX_NUMBER.test(without_n);
                    const valid = parse_js_number(without_n, allow_e);
                    if (!has_dot && RE_BIG_INT.test(num) && !isNaN(valid))
                        return token("big_int", without_n);
                    parse_error("Invalid or unexpected token");
                }
                var valid = parse_js_number(num);
                if (!isNaN(valid)) {
                    return token("num", valid);
                }
                else {
                    parse_error("Invalid syntax: " + num);
                }
            }
            function is_octal(ch) {
                return ch >= "0" && ch <= "7";
            }
            function read_escaped_char(in_string, strict_hex, template_string) {
                var ch = next(true, in_string);
                switch (ch.charCodeAt(0)) {
                    case 110: return "\n";
                    case 114: return "\r";
                    case 116: return "\t";
                    case 98: return "\b";
                    case 118: return "\u000b"; // \v
                    case 102: return "\f";
                    case 120: return String.fromCharCode(hex_bytes(2, strict_hex)); // \x
                    case 117: // \u
                        if (peek() == "{") {
                            next(true);
                            if (peek() === "}")
                                parse_error("Expecting hex-character between {}");
                            while (peek() == "0")
                                next(true); // No significance
                            var result, length = find("}", true) - S.pos;
                            // Avoid 32 bit integer overflow (1 << 32 === 1)
                            // We know first character isn't 0 and thus out of range anyway
                            if (length > 6 || (result = hex_bytes(length, strict_hex)) > 0x10FFFF) {
                                parse_error("Unicode reference out of bounds");
                            }
                            next(true);
                            return from_char_code(result);
                        }
                        return String.fromCharCode(hex_bytes(4, strict_hex));
                    case 10: return ""; // newline
                    case 13: // \r
                        if (peek() == "\n") { // DOS newline
                            next(true, in_string);
                            return "";
                        }
                }
                if (is_octal(ch)) {
                    if (template_string && strict_hex) {
                        const represents_null_character = ch === "0" && !is_octal(peek());
                        if (!represents_null_character) {
                            parse_error("Octal escape sequences are not allowed in template strings");
                        }
                    }
                    return read_octal_escape_sequence(ch, strict_hex);
                }
                return ch;
            }
            function read_octal_escape_sequence(ch, strict_octal) {
                // Read
                var p = peek();
                if (p >= "0" && p <= "7") {
                    ch += next(true);
                    if (ch[0] <= "3" && (p = peek()) >= "0" && p <= "7")
                        ch += next(true);
                }
                // Parse
                if (ch === "0")
                    return "\0";
                if (ch.length > 0 && next_token.has_directive("use strict") && strict_octal)
                    parse_error("Legacy octal escape sequences are not allowed in strict mode");
                return String.fromCharCode(parseInt(ch, 8));
            }
            function hex_bytes(n, strict_hex) {
                var num = 0;
                for (; n > 0; --n) {
                    if (!strict_hex && isNaN(parseInt(peek(), 16))) {
                        return parseInt(num, 16) || "";
                    }
                    var digit = next(true);
                    if (isNaN(parseInt(digit, 16)))
                        parse_error("Invalid hex-character pattern in string");
                    num += digit;
                }
                return parseInt(num, 16);
            }
            var read_string = with_eof_error("Unterminated string constant", function () {
                const start_pos = S.pos;
                var quote = next(), ret = [];
                for (;;) {
                    var ch = next(true, true);
                    if (ch == "\\")
                        ch = read_escaped_char(true, true);
                    else if (ch == "\r" || ch == "\n")
                        parse_error("Unterminated string constant");
                    else if (ch == quote)
                        break;
                    ret.push(ch);
                }
                var tok = token("string", ret.join(""));
                LATEST_RAW = S.text.slice(start_pos, S.pos);
                tok.quote = quote;
                return tok;
            });
            var read_template_characters = with_eof_error("Unterminated template", function (begin) {
                if (begin) {
                    S.template_braces.push(S.brace_counter);
                }
                var content = "", raw = "", ch, tok;
                next(true, true);
                while ((ch = next(true, true)) != "`") {
                    if (ch == "\r") {
                        if (peek() == "\n")
                            ++S.pos;
                        ch = "\n";
                    }
                    else if (ch == "$" && peek() == "{") {
                        next(true, true);
                        S.brace_counter++;
                        tok = token(begin ? "template_head" : "template_substitution", content);
                        TEMPLATE_RAWS.set(tok, raw);
                        tok.template_end = false;
                        return tok;
                    }
                    raw += ch;
                    if (ch == "\\") {
                        var tmp = S.pos;
                        var prev_is_tag = previous_token && (previous_token.type === "name" || previous_token.type === "punc" && (previous_token.value === ")" || previous_token.value === "]"));
                        ch = read_escaped_char(true, !prev_is_tag, true);
                        raw += S.text.substr(tmp, S.pos - tmp);
                    }
                    content += ch;
                }
                S.template_braces.pop();
                tok = token(begin ? "template_head" : "template_substitution", content);
                TEMPLATE_RAWS.set(tok, raw);
                tok.template_end = true;
                return tok;
            });
            function skip_line_comment(type) {
                var regex_allowed = S.regex_allowed;
                var i = find_eol(), ret;
                if (i == -1) {
                    ret = S.text.substr(S.pos);
                    S.pos = S.text.length;
                }
                else {
                    ret = S.text.substring(S.pos, i);
                    S.pos = i;
                }
                S.col = S.tokcol + (S.pos - S.tokpos);
                S.comments_before.push(token(type, ret, true));
                S.regex_allowed = regex_allowed;
                return next_token;
            }
            var skip_multiline_comment = with_eof_error("Unterminated multiline comment", function () {
                var regex_allowed = S.regex_allowed;
                var i = find("*/", true);
                var text = S.text.substring(S.pos, i).replace(/\r\n|\r|\u2028|\u2029/g, "\n");
                // update stream position
                forward(get_full_char_length(text) /* text length doesn't count \r\n as 2 char while S.pos - i does */ + 2);
                S.comments_before.push(token("comment2", text, true));
                S.newline_before = S.newline_before || text.includes("\n");
                S.regex_allowed = regex_allowed;
                return next_token;
            });
            var read_name = with_eof_error("Unterminated identifier name", function () {
                var name = [], ch, escaped = false;
                var read_escaped_identifier_char = function () {
                    escaped = true;
                    next();
                    if (peek() !== "u") {
                        parse_error("Expecting UnicodeEscapeSequence -- uXXXX or u{XXXX}");
                    }
                    return read_escaped_char(false, true);
                };
                // Read first character (ID_Start)
                if ((ch = peek()) === "\\") {
                    ch = read_escaped_identifier_char();
                    if (!is_identifier_start(ch)) {
                        parse_error("First identifier char is an invalid identifier char");
                    }
                }
                else if (is_identifier_start(ch)) {
                    next();
                }
                else {
                    return "";
                }
                name.push(ch);
                // Read ID_Continue
                while ((ch = peek()) != null) {
                    if ((ch = peek()) === "\\") {
                        ch = read_escaped_identifier_char();
                        if (!is_identifier_char(ch)) {
                            parse_error("Invalid escaped identifier char");
                        }
                    }
                    else {
                        if (!is_identifier_char(ch)) {
                            break;
                        }
                        next();
                    }
                    name.push(ch);
                }
                const name_str = name.join("");
                if (RESERVED_WORDS.has(name_str) && escaped) {
                    parse_error("Escaped characters are not allowed in keywords");
                }
                return name_str;
            });
            var read_regexp = with_eof_error("Unterminated regular expression", function (source) {
                var prev_backslash = false, ch, in_class = false;
                while ((ch = next(true)))
                    if (NEWLINE_CHARS.has(ch)) {
                        parse_error("Unexpected line terminator");
                    }
                    else if (prev_backslash) {
                        source += "\\" + ch;
                        prev_backslash = false;
                    }
                    else if (ch == "[") {
                        in_class = true;
                        source += ch;
                    }
                    else if (ch == "]" && in_class) {
                        in_class = false;
                        source += ch;
                    }
                    else if (ch == "/" && !in_class) {
                        break;
                    }
                    else if (ch == "\\") {
                        prev_backslash = true;
                    }
                    else {
                        source += ch;
                    }
                const flags = read_name();
                return token("regexp", "/" + source + "/" + flags);
            });
            function read_operator(prefix) {
                function grow(op) {
                    if (!peek())
                        return op;
                    var bigger = op + peek();
                    if (OPERATORS.has(bigger)) {
                        next();
                        return grow(bigger);
                    }
                    else {
                        return op;
                    }
                }
                return token("operator", grow(prefix || next()));
            }
            function handle_slash() {
                next();
                switch (peek()) {
                    case "/":
                        next();
                        return skip_line_comment("comment1");
                    case "*":
                        next();
                        return skip_multiline_comment();
                }
                return S.regex_allowed ? read_regexp("") : read_operator("/");
            }
            function handle_eq_sign() {
                next();
                if (peek() === ">") {
                    next();
                    return token("arrow", "=>");
                }
                else {
                    return read_operator("=");
                }
            }
            function handle_dot() {
                next();
                if (is_digit(peek().charCodeAt(0))) {
                    return read_num(".");
                }
                if (peek() === ".") {
                    next(); // Consume second dot
                    next(); // Consume third dot
                    return token("expand", "...");
                }
                return token("punc", ".");
            }
            function read_word() {
                var word = read_name();
                if (prev_was_dot)
                    return token("name", word);
                return KEYWORDS_ATOM.has(word) ? token("atom", word)
                    : !KEYWORDS.has(word) ? token("name", word)
                        : OPERATORS.has(word) ? token("operator", word)
                            : token("keyword", word);
            }
            function read_private_word() {
                next();
                return token("privatename", read_name());
            }
            function with_eof_error(eof_error, cont) {
                return function (x) {
                    try {
                        return cont(x);
                    }
                    catch (ex) {
                        if (ex === EX_EOF)
                            parse_error(eof_error);
                        else
                            throw ex;
                    }
                };
            }
            function next_token(force_regexp) {
                if (force_regexp != null)
                    return read_regexp(force_regexp);
                if (shebang && S.pos == 0 && looking_at("#!")) {
                    start_token();
                    forward(2);
                    skip_line_comment("comment5");
                }
                for (;;) {
                    skip_whitespace();
                    start_token();
                    if (html5_comments) {
                        if (looking_at("<!--")) {
                            forward(4);
                            skip_line_comment("comment3");
                            continue;
                        }
                        if (looking_at("-->") && S.newline_before) {
                            forward(3);
                            skip_line_comment("comment4");
                            continue;
                        }
                    }
                    var ch = peek();
                    if (!ch)
                        return token("eof");
                    var code = ch.charCodeAt(0);
                    switch (code) {
                        case 34:
                        case 39: return read_string();
                        case 46: return handle_dot();
                        case 47: {
                            var tok = handle_slash();
                            if (tok === next_token)
                                continue;
                            return tok;
                        }
                        case 61: return handle_eq_sign();
                        case 63: {
                            if (!is_option_chain_op())
                                break; // Handled below
                            next(); // ?
                            next(); // .
                            return token("punc", "?.");
                        }
                        case 96: return read_template_characters(true);
                        case 123:
                            S.brace_counter++;
                            break;
                        case 125:
                            S.brace_counter--;
                            if (S.template_braces.length > 0
                                && S.template_braces[S.template_braces.length - 1] === S.brace_counter)
                                return read_template_characters(false);
                            break;
                    }
                    if (is_digit(code))
                        return read_num();
                    if (PUNC_CHARS.has(ch))
                        return token("punc", next());
                    if (OPERATOR_CHARS.has(ch))
                        return read_operator();
                    if (code == 92 || is_identifier_start(ch))
                        return read_word();
                    if (code == 35)
                        return read_private_word();
                    break;
                }
                parse_error("Unexpected character '" + ch + "'");
            }
            next_token.next = next;
            next_token.peek = peek;
            next_token.context = function (nc) {
                if (nc)
                    S = nc;
                return S;
            };
            next_token.add_directive = function (directive) {
                S.directive_stack[S.directive_stack.length - 1].push(directive);
                if (S.directives[directive] === undefined) {
                    S.directives[directive] = 1;
                }
                else {
                    S.directives[directive]++;
                }
            };
            next_token.push_directives_stack = function () {
                S.directive_stack.push([]);
            };
            next_token.pop_directives_stack = function () {
                var directives = S.directive_stack[S.directive_stack.length - 1];
                for (var i = 0; i < directives.length; i++) {
                    S.directives[directives[i]]--;
                }
                S.directive_stack.pop();
            };
            next_token.has_directive = function (directive) {
                return S.directives[directive] > 0;
            };
            return next_token;
        }
        /* -----[ Parser (constants) ]----- */
        var UNARY_PREFIX = makePredicate([
            "typeof",
            "void",
            "delete",
            "--",
            "++",
            "!",
            "~",
            "-",
            "+"
        ]);
        var UNARY_POSTFIX = makePredicate(["--", "++"]);
        var ASSIGNMENT = makePredicate(["=", "+=", "-=", "??=", "&&=", "||=", "/=", "*=", "**=", "%=", ">>=", "<<=", ">>>=", "|=", "^=", "&="]);
        var LOGICAL_ASSIGNMENT = makePredicate(["??=", "&&=", "||="]);
        var PRECEDENCE = (function (a, ret) {
            for (var i = 0; i < a.length; ++i) {
                var b = a[i];
                for (var j = 0; j < b.length; ++j) {
                    ret[b[j]] = i + 1;
                }
            }
            return ret;
        })([
            ["||"],
            ["??"],
            ["&&"],
            ["|"],
            ["^"],
            ["&"],
            ["==", "===", "!=", "!=="],
            ["<", ">", "<=", ">=", "in", "instanceof"],
            [">>", "<<", ">>>"],
            ["+", "-"],
            ["*", "/", "%"],
            ["**"]
        ], {});
        var ATOMIC_START_TOKEN = makePredicate(["atom", "num", "big_int", "string", "regexp", "name"]);
        /* -----[ Parser ]----- */
        function parse($TEXT, options) {
            // maps start tokens to count of comments found outside of their parens
            // Example: /* I count */ ( /* I don't */ foo() )
            // Useful because comments_before property of call with parens outside
            // contains both comments inside and outside these parens. Used to find the
            const outer_comments_before_counts = new WeakMap();
            options = defaults(options, {
                bare_returns: false,
                ecma: null,
                expression: false,
                filename: null,
                html5_comments: true,
                module: false,
                shebang: true,
                strict: false,
                toplevel: null,
            }, true);
            var S = {
                input: (typeof $TEXT == "string"
                    ? tokenizer($TEXT, options.filename, options.html5_comments, options.shebang)
                    : $TEXT),
                token: null,
                prev: null,
                peeked: null,
                in_function: 0,
                in_async: -1,
                in_generator: -1,
                in_directives: true,
                in_loop: 0,
                labels: []
            };
            S.token = next();
            function is(type, value) {
                return is_token(S.token, type, value);
            }
            function peek() { return S.peeked || (S.peeked = S.input()); }
            function next() {
                S.prev = S.token;
                if (!S.peeked)
                    peek();
                S.token = S.peeked;
                S.peeked = null;
                S.in_directives = S.in_directives && (S.token.type == "string" || is("punc", ";"));
                return S.token;
            }
            function prev() {
                return S.prev;
            }
            function croak(msg, line, col, pos) {
                var ctx = S.input.context();
                js_error(msg, ctx.filename, line != null ? line : ctx.tokline, col != null ? col : ctx.tokcol, pos != null ? pos : ctx.tokpos);
            }
            function token_error(token, msg) {
                croak(msg, token.line, token.col);
            }
            function unexpected(token) {
                if (token == null)
                    token = S.token;
                token_error(token, "Unexpected token: " + token.type + " (" + token.value + ")");
            }
            function expect_token(type, val) {
                if (is(type, val)) {
                    return next();
                }
                token_error(S.token, "Unexpected token " + S.token.type + " «" + S.token.value + "»" + ", expected " + type + " «" + val + "»");
            }
            function expect(punc) { return expect_token("punc", punc); }
            function has_newline_before(token) {
                return token.nlb || !token.comments_before.every((comment) => !comment.nlb);
            }
            function can_insert_semicolon() {
                return !options.strict
                    && (is("eof") || is("punc", "}") || has_newline_before(S.token));
            }
            function is_in_generator() {
                return S.in_generator === S.in_function;
            }
            function is_in_async() {
                return S.in_async === S.in_function;
            }
            function can_await() {
                return (S.in_async === S.in_function
                    || S.in_function === 0 && S.input.has_directive("use strict"));
            }
            function semicolon(optional) {
                if (is("punc", ";"))
                    next();
                else if (!optional && !can_insert_semicolon())
                    unexpected();
            }
            function parenthesised() {
                expect("(");
                var exp = expression(true);
                expect(")");
                return exp;
            }
            function embed_tokens(parser) {
                return function _embed_tokens_wrapper(...args) {
                    const start = S.token;
                    const expr = parser(...args);
                    expr.start = start;
                    expr.end = prev();
                    return expr;
                };
            }
            function handle_regexp() {
                if (is("operator", "/") || is("operator", "/=")) {
                    S.peeked = null;
                    S.token = S.input(S.token.value.substr(1)); // force regexp
                }
            }
            var statement = embed_tokens(function statement(is_export_default, is_for_body, is_if_body) {
                handle_regexp();
                switch (S.token.type) {
                    case "string":
                        if (S.in_directives) {
                            var token = peek();
                            if (!LATEST_RAW.includes("\\")
                                && (is_token(token, "punc", ";")
                                    || is_token(token, "punc", "}")
                                    || has_newline_before(token)
                                    || is_token(token, "eof"))) {
                                S.input.add_directive(S.token.value);
                            }
                            else {
                                S.in_directives = false;
                            }
                        }
                        var dir = S.in_directives, stat = simple_statement();
                        return dir && stat.body instanceof AST_String ? new AST_Directive(stat.body) : stat;
                    case "template_head":
                    case "num":
                    case "big_int":
                    case "regexp":
                    case "operator":
                    case "atom":
                        return simple_statement();
                    case "name":
                    case "privatename":
                        if (is("privatename") && !S.in_class)
                            croak("Private field must be used in an enclosing class");
                        if (S.token.value == "async" && is_token(peek(), "keyword", "function")) {
                            next();
                            next();
                            if (is_for_body) {
                                croak("functions are not allowed as the body of a loop");
                            }
                            return function_(AST_Defun, false, true, is_export_default);
                        }
                        if (S.token.value == "import" && !is_token(peek(), "punc", "(") && !is_token(peek(), "punc", ".")) {
                            next();
                            var node = import_statement();
                            semicolon();
                            return node;
                        }
                        return is_token(peek(), "punc", ":")
                            ? labeled_statement()
                            : simple_statement();
                    case "punc":
                        switch (S.token.value) {
                            case "{":
                                return new AST_BlockStatement({
                                    start: S.token,
                                    body: block_(),
                                    end: prev()
                                });
                            case "[":
                            case "(":
                                return simple_statement();
                            case ";":
                                S.in_directives = false;
                                next();
                                return new AST_EmptyStatement();
                            default:
                                unexpected();
                        }
                    case "keyword":
                        switch (S.token.value) {
                            case "break":
                                next();
                                return break_cont(AST_Break);
                            case "continue":
                                next();
                                return break_cont(AST_Continue);
                            case "debugger":
                                next();
                                semicolon();
                                return new AST_Debugger();
                            case "do":
                                next();
                                var body = in_loop(statement);
                                expect_token("keyword", "while");
                                var condition = parenthesised();
                                semicolon(true);
                                return new AST_Do({
                                    body: body,
                                    condition: condition
                                });
                            case "while":
                                next();
                                return new AST_While({
                                    condition: parenthesised(),
                                    body: in_loop(function () { return statement(false, true); })
                                });
                            case "for":
                                next();
                                return for_();
                            case "class":
                                next();
                                if (is_for_body) {
                                    croak("classes are not allowed as the body of a loop");
                                }
                                if (is_if_body) {
                                    croak("classes are not allowed as the body of an if");
                                }
                                return class_(AST_DefClass, is_export_default);
                            case "function":
                                next();
                                if (is_for_body) {
                                    croak("functions are not allowed as the body of a loop");
                                }
                                return function_(AST_Defun, false, false, is_export_default);
                            case "if":
                                next();
                                return if_();
                            case "return":
                                if (S.in_function == 0 && !options.bare_returns)
                                    croak("'return' outside of function");
                                next();
                                var value = null;
                                if (is("punc", ";")) {
                                    next();
                                }
                                else if (!can_insert_semicolon()) {
                                    value = expression(true);
                                    semicolon();
                                }
                                return new AST_Return({
                                    value: value
                                });
                            case "switch":
                                next();
                                return new AST_Switch({
                                    expression: parenthesised(),
                                    body: in_loop(switch_body_)
                                });
                            case "throw":
                                next();
                                if (has_newline_before(S.token))
                                    croak("Illegal newline after 'throw'");
                                var value = expression(true);
                                semicolon();
                                return new AST_Throw({
                                    value: value
                                });
                            case "try":
                                next();
                                return try_();
                            case "var":
                                next();
                                var node = var_();
                                semicolon();
                                return node;
                            case "let":
                                next();
                                var node = let_();
                                semicolon();
                                return node;
                            case "const":
                                next();
                                var node = const_();
                                semicolon();
                                return node;
                            case "with":
                                if (S.input.has_directive("use strict")) {
                                    croak("Strict mode may not include a with statement");
                                }
                                next();
                                return new AST_With({
                                    expression: parenthesised(),
                                    body: statement()
                                });
                            case "export":
                                if (!is_token(peek(), "punc", "(")) {
                                    next();
                                    var node = export_statement();
                                    if (is("punc", ";"))
                                        semicolon();
                                    return node;
                                }
                        }
                }
                unexpected();
            });
            function labeled_statement() {
                var label = as_symbol(AST_Label);
                if (label.name === "await" && is_in_async()) {
                    token_error(S.prev, "await cannot be used as label inside async function");
                }
                if (S.labels.some((l) => l.name === label.name)) {
                    // ECMA-262, 12.12: An ECMAScript program is considered
                    // syntactically incorrect if it contains a
                    // LabelledStatement that is enclosed by a
                    // LabelledStatement with the same Identifier as label.
                    croak("Label " + label.name + " defined twice");
                }
                expect(":");
                S.labels.push(label);
                var stat = statement();
                S.labels.pop();
                if (!(stat instanceof AST_IterationStatement)) {
                    // check for `continue` that refers to this label.
                    // those should be reported as syntax errors.
                    // https://github.com/mishoo/UglifyJS2/issues/287
                    label.references.forEach(function (ref) {
                        if (ref instanceof AST_Continue) {
                            ref = ref.label.start;
                            croak("Continue label `" + label.name + "` refers to non-IterationStatement.", ref.line, ref.col, ref.pos);
                        }
                    });
                }
                return new AST_LabeledStatement({ body: stat, label: label });
            }
            function simple_statement(tmp) {
                return new AST_SimpleStatement({ body: (tmp = expression(true), semicolon(), tmp) });
            }
            function break_cont(type) {
                var label = null, ldef;
                if (!can_insert_semicolon()) {
                    label = as_symbol(AST_LabelRef, true);
                }
                if (label != null) {
                    ldef = S.labels.find((l) => l.name === label.name);
                    if (!ldef)
                        croak("Undefined label " + label.name);
                    label.thedef = ldef;
                }
                else if (S.in_loop == 0)
                    croak(type.TYPE + " not inside a loop or switch");
                semicolon();
                var stat = new type({ label: label });
                if (ldef)
                    ldef.references.push(stat);
                return stat;
            }
            function for_() {
                var for_await_error = "`for await` invalid in this context";
                var await_tok = S.token;
                if (await_tok.type == "name" && await_tok.value == "await") {
                    if (!can_await()) {
                        token_error(await_tok, for_await_error);
                    }
                    next();
                }
                else {
                    await_tok = false;
                }
                expect("(");
                var init = null;
                if (!is("punc", ";")) {
                    init =
                        is("keyword", "var") ? (next(), var_(true)) :
                            is("keyword", "let") ? (next(), let_(true)) :
                                is("keyword", "const") ? (next(), const_(true)) :
                                    expression(true, true);
                    var is_in = is("operator", "in");
                    var is_of = is("name", "of");
                    if (await_tok && !is_of) {
                        token_error(await_tok, for_await_error);
                    }
                    if (is_in || is_of) {
                        if (init instanceof AST_Definitions) {
                            if (init.definitions.length > 1)
                                token_error(init.start, "Only one variable declaration allowed in for..in loop");
                        }
                        else if (!(is_assignable(init) || (init = to_destructuring(init)) instanceof AST_Destructuring)) {
                            token_error(init.start, "Invalid left-hand side in for..in loop");
                        }
                        next();
                        if (is_in) {
                            return for_in(init);
                        }
                        else {
                            return for_of(init, !!await_tok);
                        }
                    }
                }
                else if (await_tok) {
                    token_error(await_tok, for_await_error);
                }
                return regular_for(init);
            }
            function regular_for(init) {
                expect(";");
                var test = is("punc", ";") ? null : expression(true);
                expect(";");
                var step = is("punc", ")") ? null : expression(true);
                expect(")");
                return new AST_For({
                    init: init,
                    condition: test,
                    step: step,
                    body: in_loop(function () { return statement(false, true); })
                });
            }
            function for_of(init, is_await) {
                var lhs = init instanceof AST_Definitions ? init.definitions[0].name : null;
                var obj = expression(true);
                expect(")");
                return new AST_ForOf({
                    await: is_await,
                    init: init,
                    name: lhs,
                    object: obj,
                    body: in_loop(function () { return statement(false, true); })
                });
            }
            function for_in(init) {
                var obj = expression(true);
                expect(")");
                return new AST_ForIn({
                    init: init,
                    object: obj,
                    body: in_loop(function () { return statement(false, true); })
                });
            }
            var arrow_function = function (start, argnames, is_async) {
                if (has_newline_before(S.token)) {
                    croak("Unexpected newline before arrow (=>)");
                }
                expect_token("arrow", "=>");
                var body = _function_body(is("punc", "{"), false, is_async);
                var end = body instanceof Array && body.length ? body[body.length - 1].end :
                    body instanceof Array ? start :
                        body.end;
                return new AST_Arrow({
                    start: start,
                    end: end,
                    async: is_async,
                    argnames: argnames,
                    body: body
                });
            };
            var function_ = function (ctor, is_generator_property, is_async, is_export_default) {
                var in_statement = ctor === AST_Defun;
                var is_generator = is("operator", "*");
                if (is_generator) {
                    next();
                }
                var name = is("name") ? as_symbol(in_statement ? AST_SymbolDefun : AST_SymbolLambda) : null;
                if (in_statement && !name) {
                    if (is_export_default) {
                        ctor = AST_Function;
                    }
                    else {
                        unexpected();
                    }
                }
                if (name && ctor !== AST_Accessor && !(name instanceof AST_SymbolDeclaration))
                    unexpected(prev());
                var args = [];
                var body = _function_body(true, is_generator || is_generator_property, is_async, name, args);
                return new ctor({
                    start: args.start,
                    end: body.end,
                    is_generator: is_generator,
                    async: is_async,
                    name: name,
                    argnames: args,
                    body: body
                });
            };
            class UsedParametersTracker {
                constructor(is_parameter, strict, duplicates_ok = false) {
                    this.is_parameter = is_parameter;
                    this.duplicates_ok = duplicates_ok;
                    this.parameters = new Set();
                    this.duplicate = null;
                    this.default_assignment = false;
                    this.spread = false;
                    this.strict_mode = !!strict;
                }
                add_parameter(token) {
                    if (this.parameters.has(token.value)) {
                        if (this.duplicate === null) {
                            this.duplicate = token;
                        }
                        this.check_strict();
                    }
                    else {
                        this.parameters.add(token.value);
                        if (this.is_parameter) {
                            switch (token.value) {
                                case "arguments":
                                case "eval":
                                case "yield":
                                    if (this.strict_mode) {
                                        token_error(token, "Unexpected " + token.value + " identifier as parameter inside strict mode");
                                    }
                                    break;
                                default:
                                    if (RESERVED_WORDS.has(token.value)) {
                                        unexpected();
                                    }
                            }
                        }
                    }
                }
                mark_default_assignment(token) {
                    if (this.default_assignment === false) {
                        this.default_assignment = token;
                    }
                }
                mark_spread(token) {
                    if (this.spread === false) {
                        this.spread = token;
                    }
                }
                mark_strict_mode() {
                    this.strict_mode = true;
                }
                is_strict() {
                    return this.default_assignment !== false || this.spread !== false || this.strict_mode;
                }
                check_strict() {
                    if (this.is_strict() && this.duplicate !== null && !this.duplicates_ok) {
                        token_error(this.duplicate, "Parameter " + this.duplicate.value + " was used already");
                    }
                }
            }
            function parameters(params) {
                var used_parameters = new UsedParametersTracker(true, S.input.has_directive("use strict"));
                expect("(");
                while (!is("punc", ")")) {
                    var param = parameter(used_parameters);
                    params.push(param);
                    if (!is("punc", ")")) {
                        expect(",");
                    }
                    if (param instanceof AST_Expansion) {
                        break;
                    }
                }
                next();
            }
            function parameter(used_parameters, symbol_type) {
                var param;
                var expand = false;
                if (used_parameters === undefined) {
                    used_parameters = new UsedParametersTracker(true, S.input.has_directive("use strict"));
                }
                if (is("expand", "...")) {
                    expand = S.token;
                    used_parameters.mark_spread(S.token);
                    next();
                }
                param = binding_element(used_parameters, symbol_type);
                if (is("operator", "=") && expand === false) {
                    used_parameters.mark_default_assignment(S.token);
                    next();
                    param = new AST_DefaultAssign({
                        start: param.start,
                        left: param,
                        operator: "=",
                        right: expression(false),
                        end: S.token
                    });
                }
                if (expand !== false) {
                    if (!is("punc", ")")) {
                        unexpected();
                    }
                    param = new AST_Expansion({
                        start: expand,
                        expression: param,
                        end: expand
                    });
                }
                used_parameters.check_strict();
                return param;
            }
            function binding_element(used_parameters, symbol_type) {
                var elements = [];
                var first = true;
                var is_expand = false;
                var expand_token;
                var first_token = S.token;
                if (used_parameters === undefined) {
                    const strict = S.input.has_directive("use strict");
                    const duplicates_ok = symbol_type === AST_SymbolVar;
                    used_parameters = new UsedParametersTracker(false, strict, duplicates_ok);
                }
                symbol_type = symbol_type === undefined ? AST_SymbolFunarg : symbol_type;
                if (is("punc", "[")) {
                    next();
                    while (!is("punc", "]")) {
                        if (first) {
                            first = false;
                        }
                        else {
                            expect(",");
                        }
                        if (is("expand", "...")) {
                            is_expand = true;
                            expand_token = S.token;
                            used_parameters.mark_spread(S.token);
                            next();
                        }
                        if (is("punc")) {
                            switch (S.token.value) {
                                case ",":
                                    elements.push(new AST_Hole({
                                        start: S.token,
                                        end: S.token
                                    }));
                                    continue;
                                case "]": // Trailing comma after last element
                                    break;
                                case "[":
                                case "{":
                                    elements.push(binding_element(used_parameters, symbol_type));
                                    break;
                                default:
                                    unexpected();
                            }
                        }
                        else if (is("name")) {
                            used_parameters.add_parameter(S.token);
                            elements.push(as_symbol(symbol_type));
                        }
                        else {
                            croak("Invalid function parameter");
                        }
                        if (is("operator", "=") && is_expand === false) {
                            used_parameters.mark_default_assignment(S.token);
                            next();
                            elements[elements.length - 1] = new AST_DefaultAssign({
                                start: elements[elements.length - 1].start,
                                left: elements[elements.length - 1],
                                operator: "=",
                                right: expression(false),
                                end: S.token
                            });
                        }
                        if (is_expand) {
                            if (!is("punc", "]")) {
                                croak("Rest element must be last element");
                            }
                            elements[elements.length - 1] = new AST_Expansion({
                                start: expand_token,
                                expression: elements[elements.length - 1],
                                end: expand_token
                            });
                        }
                    }
                    expect("]");
                    used_parameters.check_strict();
                    return new AST_Destructuring({
                        start: first_token,
                        names: elements,
                        is_array: true,
                        end: prev()
                    });
                }
                else if (is("punc", "{")) {
                    next();
                    while (!is("punc", "}")) {
                        if (first) {
                            first = false;
                        }
                        else {
                            expect(",");
                        }
                        if (is("expand", "...")) {
                            is_expand = true;
                            expand_token = S.token;
                            used_parameters.mark_spread(S.token);
                            next();
                        }
                        if (is("name") && (is_token(peek(), "punc") || is_token(peek(), "operator")) && [",", "}", "="].includes(peek().value)) {
                            used_parameters.add_parameter(S.token);
                            var start = prev();
                            var value = as_symbol(symbol_type);
                            if (is_expand) {
                                elements.push(new AST_Expansion({
                                    start: expand_token,
                                    expression: value,
                                    end: value.end,
                                }));
                            }
                            else {
                                elements.push(new AST_ObjectKeyVal({
                                    start: start,
                                    key: value.name,
                                    value: value,
                                    end: value.end,
                                }));
                            }
                        }
                        else if (is("punc", "}")) {
                            continue; // Allow trailing hole
                        }
                        else {
                            var property_token = S.token;
                            var property = as_property_name();
                            if (property === null) {
                                unexpected(prev());
                            }
                            else if (prev().type === "name" && !is("punc", ":")) {
                                elements.push(new AST_ObjectKeyVal({
                                    start: prev(),
                                    key: property,
                                    value: new symbol_type({
                                        start: prev(),
                                        name: property,
                                        end: prev()
                                    }),
                                    end: prev()
                                }));
                            }
                            else {
                                expect(":");
                                elements.push(new AST_ObjectKeyVal({
                                    start: property_token,
                                    quote: property_token.quote,
                                    key: property,
                                    value: binding_element(used_parameters, symbol_type),
                                    end: prev()
                                }));
                            }
                        }
                        if (is_expand) {
                            if (!is("punc", "}")) {
                                croak("Rest element must be last element");
                            }
                        }
                        else if (is("operator", "=")) {
                            used_parameters.mark_default_assignment(S.token);
                            next();
                            elements[elements.length - 1].value = new AST_DefaultAssign({
                                start: elements[elements.length - 1].value.start,
                                left: elements[elements.length - 1].value,
                                operator: "=",
                                right: expression(false),
                                end: S.token
                            });
                        }
                    }
                    expect("}");
                    used_parameters.check_strict();
                    return new AST_Destructuring({
                        start: first_token,
                        names: elements,
                        is_array: false,
                        end: prev()
                    });
                }
                else if (is("name")) {
                    used_parameters.add_parameter(S.token);
                    return as_symbol(symbol_type);
                }
                else {
                    croak("Invalid function parameter");
                }
            }
            function params_or_seq_(allow_arrows, maybe_sequence) {
                var spread_token;
                var invalid_sequence;
                var trailing_comma;
                var a = [];
                expect("(");
                while (!is("punc", ")")) {
                    if (spread_token)
                        unexpected(spread_token);
                    if (is("expand", "...")) {
                        spread_token = S.token;
                        if (maybe_sequence)
                            invalid_sequence = S.token;
                        next();
                        a.push(new AST_Expansion({
                            start: prev(),
                            expression: expression(),
                            end: S.token,
                        }));
                    }
                    else {
                        a.push(expression());
                    }
                    if (!is("punc", ")")) {
                        expect(",");
                        if (is("punc", ")")) {
                            trailing_comma = prev();
                            if (maybe_sequence)
                                invalid_sequence = trailing_comma;
                        }
                    }
                }
                expect(")");
                if (allow_arrows && is("arrow", "=>")) {
                    if (spread_token && trailing_comma)
                        unexpected(trailing_comma);
                }
                else if (invalid_sequence) {
                    unexpected(invalid_sequence);
                }
                return a;
            }
            function _function_body(block, generator, is_async, name, args) {
                var loop = S.in_loop;
                var labels = S.labels;
                var current_generator = S.in_generator;
                var current_async = S.in_async;
                ++S.in_function;
                if (generator)
                    S.in_generator = S.in_function;
                if (is_async)
                    S.in_async = S.in_function;
                if (args)
                    parameters(args);
                if (block)
                    S.in_directives = true;
                S.in_loop = 0;
                S.labels = [];
                if (block) {
                    S.input.push_directives_stack();
                    var a = block_();
                    if (name)
                        _verify_symbol(name);
                    if (args)
                        args.forEach(_verify_symbol);
                    S.input.pop_directives_stack();
                }
                else {
                    var a = [new AST_Return({
                            start: S.token,
                            value: expression(false),
                            end: S.token
                        })];
                }
                --S.in_function;
                S.in_loop = loop;
                S.labels = labels;
                S.in_generator = current_generator;
                S.in_async = current_async;
                return a;
            }
            function _await_expression() {
                // Previous token must be "await" and not be interpreted as an identifier
                if (!can_await()) {
                    croak("Unexpected await expression outside async function", S.prev.line, S.prev.col, S.prev.pos);
                }
                // the await expression is parsed as a unary expression in Babel
                return new AST_Await({
                    start: prev(),
                    end: S.token,
                    expression: maybe_unary(true),
                });
            }
            function _yield_expression() {
                // Previous token must be keyword yield and not be interpret as an identifier
                if (!is_in_generator()) {
                    croak("Unexpected yield expression outside generator function", S.prev.line, S.prev.col, S.prev.pos);
                }
                var start = S.token;
                var star = false;
                var has_expression = true;
                // Attempt to get expression or star (and then the mandatory expression)
                // behind yield on the same line.
                //
                // If nothing follows on the same line of the yieldExpression,
                // it should default to the value `undefined` for yield to return.
                // In that case, the `undefined` stored as `null` in ast.
                //
                // Note 1: It isn't allowed for yield* to close without an expression
                // Note 2: If there is a nlb between yield and star, it is interpret as
                //         yield <explicit undefined> <inserted automatic semicolon> *
                if (can_insert_semicolon() ||
                    (is("punc") && PUNC_AFTER_EXPRESSION.has(S.token.value))) {
                    has_expression = false;
                }
                else if (is("operator", "*")) {
                    star = true;
                    next();
                }
                return new AST_Yield({
                    start: start,
                    is_star: star,
                    expression: has_expression ? expression() : null,
                    end: prev()
                });
            }
            function if_() {
                var cond = parenthesised(), body = statement(false, false, true), belse = null;
                if (is("keyword", "else")) {
                    next();
                    belse = statement(false, false, true);
                }
                return new AST_If({
                    condition: cond,
                    body: body,
                    alternative: belse
                });
            }
            function block_() {
                expect("{");
                var a = [];
                while (!is("punc", "}")) {
                    if (is("eof"))
                        unexpected();
                    a.push(statement());
                }
                next();
                return a;
            }
            function switch_body_() {
                expect("{");
                var a = [], cur = null, branch = null, tmp;
                while (!is("punc", "}")) {
                    if (is("eof"))
                        unexpected();
                    if (is("keyword", "case")) {
                        if (branch)
                            branch.end = prev();
                        cur = [];
                        branch = new AST_Case({
                            start: (tmp = S.token, next(), tmp),
                            expression: expression(true),
                            body: cur
                        });
                        a.push(branch);
                        expect(":");
                    }
                    else if (is("keyword", "default")) {
                        if (branch)
                            branch.end = prev();
                        cur = [];
                        branch = new AST_Default({
                            start: (tmp = S.token, next(), expect(":"), tmp),
                            body: cur
                        });
                        a.push(branch);
                    }
                    else {
                        if (!cur)
                            unexpected();
                        cur.push(statement());
                    }
                }
                if (branch)
                    branch.end = prev();
                next();
                return a;
            }
            function try_() {
                var body, bcatch = null, bfinally = null;
                body = new AST_TryBlock({
                    start: S.token,
                    body: block_(),
                    end: prev(),
                });
                if (is("keyword", "catch")) {
                    var start = S.token;
                    next();
                    if (is("punc", "{")) {
                        var name = null;
                    }
                    else {
                        expect("(");
                        var name = parameter(undefined, AST_SymbolCatch);
                        expect(")");
                    }
                    bcatch = new AST_Catch({
                        start: start,
                        argname: name,
                        body: block_(),
                        end: prev()
                    });
                }
                if (is("keyword", "finally")) {
                    var start = S.token;
                    next();
                    bfinally = new AST_Finally({
                        start: start,
                        body: block_(),
                        end: prev()
                    });
                }
                if (!bcatch && !bfinally)
                    croak("Missing catch/finally blocks");
                return new AST_Try({
                    body: body,
                    bcatch: bcatch,
                    bfinally: bfinally
                });
            }
            /**
             * var
             *   vardef1 = 2,
             *   vardef2 = 3;
             */
            function vardefs(no_in, kind) {
                var var_defs = [];
                var def;
                for (;;) {
                    var sym_type = kind === "var" ? AST_SymbolVar :
                        kind === "const" ? AST_SymbolConst :
                            kind === "let" ? AST_SymbolLet : null;
                    // var { a } = b
                    if (is("punc", "{") || is("punc", "[")) {
                        def = new AST_VarDef({
                            start: S.token,
                            name: binding_element(undefined, sym_type),
                            value: is("operator", "=") ? (expect_token("operator", "="), expression(false, no_in)) : null,
                            end: prev()
                        });
                    }
                    else {
                        def = new AST_VarDef({
                            start: S.token,
                            name: as_symbol(sym_type),
                            value: is("operator", "=")
                                ? (next(), expression(false, no_in))
                                : !no_in && kind === "const"
                                    ? croak("Missing initializer in const declaration") : null,
                            end: prev()
                        });
                        if (def.name.name == "import")
                            croak("Unexpected token: import");
                    }
                    var_defs.push(def);
                    if (!is("punc", ","))
                        break;
                    next();
                }
                return var_defs;
            }
            var var_ = function (no_in) {
                return new AST_Var({
                    start: prev(),
                    definitions: vardefs(no_in, "var"),
                    end: prev()
                });
            };
            var let_ = function (no_in) {
                return new AST_Let({
                    start: prev(),
                    definitions: vardefs(no_in, "let"),
                    end: prev()
                });
            };
            var const_ = function (no_in) {
                return new AST_Const({
                    start: prev(),
                    definitions: vardefs(no_in, "const"),
                    end: prev()
                });
            };
            var new_ = function (allow_calls) {
                var start = S.token;
                expect_token("operator", "new");
                if (is("punc", ".")) {
                    next();
                    expect_token("name", "target");
                    return subscripts(new AST_NewTarget({
                        start: start,
                        end: prev()
                    }), allow_calls);
                }
                var newexp = expr_atom(false), args;
                if (is("punc", "(")) {
                    next();
                    args = expr_list(")", true);
                }
                else {
                    args = [];
                }
                var call = new AST_New({
                    start: start,
                    expression: newexp,
                    args: args,
                    end: prev()
                });
                annotate(call);
                return subscripts(call, allow_calls);
            };
            function as_atom_node() {
                var tok = S.token, ret;
                switch (tok.type) {
                    case "name":
                        ret = _make_symbol(AST_SymbolRef);
                        break;
                    case "num":
                        ret = new AST_Number({
                            start: tok,
                            end: tok,
                            value: tok.value,
                            raw: LATEST_RAW
                        });
                        break;
                    case "big_int":
                        ret = new AST_BigInt({ start: tok, end: tok, value: tok.value });
                        break;
                    case "string":
                        ret = new AST_String({
                            start: tok,
                            end: tok,
                            value: tok.value,
                            quote: tok.quote
                        });
                        break;
                    case "regexp":
                        const [_, source, flags] = tok.value.match(/^\/(.*)\/(\w*)$/);
                        ret = new AST_RegExp({ start: tok, end: tok, value: { source, flags } });
                        break;
                    case "atom":
                        switch (tok.value) {
                            case "false":
                                ret = new AST_False({ start: tok, end: tok });
                                break;
                            case "true":
                                ret = new AST_True({ start: tok, end: tok });
                                break;
                            case "null":
                                ret = new AST_Null({ start: tok, end: tok });
                                break;
                        }
                        break;
                }
                next();
                return ret;
            }
            function to_fun_args(ex, default_seen_above) {
                var insert_default = function (ex, default_value) {
                    if (default_value) {
                        return new AST_DefaultAssign({
                            start: ex.start,
                            left: ex,
                            operator: "=",
                            right: default_value,
                            end: default_value.end
                        });
                    }
                    return ex;
                };
                if (ex instanceof AST_Object) {
                    return insert_default(new AST_Destructuring({
                        start: ex.start,
                        end: ex.end,
                        is_array: false,
                        names: ex.properties.map(prop => to_fun_args(prop))
                    }), default_seen_above);
                }
                else if (ex instanceof AST_ObjectKeyVal) {
                    ex.value = to_fun_args(ex.value);
                    return insert_default(ex, default_seen_above);
                }
                else if (ex instanceof AST_Hole) {
                    return ex;
                }
                else if (ex instanceof AST_Destructuring) {
                    ex.names = ex.names.map(name => to_fun_args(name));
                    return insert_default(ex, default_seen_above);
                }
                else if (ex instanceof AST_SymbolRef) {
                    return insert_default(new AST_SymbolFunarg({
                        name: ex.name,
                        start: ex.start,
                        end: ex.end
                    }), default_seen_above);
                }
                else if (ex instanceof AST_Expansion) {
                    ex.expression = to_fun_args(ex.expression);
                    return insert_default(ex, default_seen_above);
                }
                else if (ex instanceof AST_Array) {
                    return insert_default(new AST_Destructuring({
                        start: ex.start,
                        end: ex.end,
                        is_array: true,
                        names: ex.elements.map(elm => to_fun_args(elm))
                    }), default_seen_above);
                }
                else if (ex instanceof AST_Assign) {
                    return insert_default(to_fun_args(ex.left, ex.right), default_seen_above);
                }
                else if (ex instanceof AST_DefaultAssign) {
                    ex.left = to_fun_args(ex.left);
                    return ex;
                }
                else {
                    croak("Invalid function parameter", ex.start.line, ex.start.col);
                }
            }
            var expr_atom = function (allow_calls, allow_arrows) {
                if (is("operator", "new")) {
                    return new_(allow_calls);
                }
                if (is("name", "import") && is_token(peek(), "punc", ".")) {
                    return import_meta();
                }
                var start = S.token;
                var peeked;
                var async = is("name", "async")
                    && (peeked = peek()).value != "["
                    && peeked.type != "arrow"
                    && as_atom_node();
                if (is("punc")) {
                    switch (S.token.value) {
                        case "(":
                            if (async && !allow_calls)
                                break;
                            var exprs = params_or_seq_(allow_arrows, !async);
                            if (allow_arrows && is("arrow", "=>")) {
                                return arrow_function(start, exprs.map(e => to_fun_args(e)), !!async);
                            }
                            var ex = async ? new AST_Call({
                                expression: async,
                                args: exprs
                            }) : exprs.length == 1 ? exprs[0] : new AST_Sequence({
                                expressions: exprs
                            });
                            if (ex.start) {
                                const outer_comments_before = start.comments_before.length;
                                outer_comments_before_counts.set(start, outer_comments_before);
                                ex.start.comments_before.unshift(...start.comments_before);
                                start.comments_before = ex.start.comments_before;
                                if (outer_comments_before == 0 && start.comments_before.length > 0) {
                                    var comment = start.comments_before[0];
                                    if (!comment.nlb) {
                                        comment.nlb = start.nlb;
                                        start.nlb = false;
                                    }
                                }
                                start.comments_after = ex.start.comments_after;
                            }
                            ex.start = start;
                            var end = prev();
                            if (ex.end) {
                                end.comments_before = ex.end.comments_before;
                                ex.end.comments_after.push(...end.comments_after);
                                end.comments_after = ex.end.comments_after;
                            }
                            ex.end = end;
                            if (ex instanceof AST_Call)
                                annotate(ex);
                            return subscripts(ex, allow_calls);
                        case "[":
                            return subscripts(array_(), allow_calls);
                        case "{":
                            return subscripts(object_or_destructuring_(), allow_calls);
                    }
                    if (!async)
                        unexpected();
                }
                if (allow_arrows && is("name") && is_token(peek(), "arrow")) {
                    var param = new AST_SymbolFunarg({
                        name: S.token.value,
                        start: start,
                        end: start,
                    });
                    next();
                    return arrow_function(start, [param], !!async);
                }
                if (is("keyword", "function")) {
                    next();
                    var func = function_(AST_Function, false, !!async);
                    func.start = start;
                    func.end = prev();
                    return subscripts(func, allow_calls);
                }
                if (async)
                    return subscripts(async, allow_calls);
                if (is("keyword", "class")) {
                    next();
                    var cls = class_(AST_ClassExpression);
                    cls.start = start;
                    cls.end = prev();
                    return subscripts(cls, allow_calls);
                }
                if (is("template_head")) {
                    return subscripts(template_string(), allow_calls);
                }
                if (is("privatename")) {
                    if (!S.in_class) {
                        croak("Private field must be used in an enclosing class");
                    }
                    const start = S.token;
                    const key = new AST_SymbolPrivateProperty({
                        start,
                        name: start.value,
                        end: start
                    });
                    next();
                    expect_token("operator", "in");
                    const private_in = new AST_PrivateIn({
                        start,
                        key,
                        value: subscripts(as_atom_node(), allow_calls),
                        end: prev()
                    });
                    return subscripts(private_in, allow_calls);
                }
                if (ATOMIC_START_TOKEN.has(S.token.type)) {
                    return subscripts(as_atom_node(), allow_calls);
                }
                unexpected();
            };
            function template_string() {
                var segments = [], start = S.token;
                segments.push(new AST_TemplateSegment({
                    start: S.token,
                    raw: TEMPLATE_RAWS.get(S.token),
                    value: S.token.value,
                    end: S.token
                }));
                while (!S.token.template_end) {
                    next();
                    handle_regexp();
                    segments.push(expression(true));
                    segments.push(new AST_TemplateSegment({
                        start: S.token,
                        raw: TEMPLATE_RAWS.get(S.token),
                        value: S.token.value,
                        end: S.token
                    }));
                }
                next();
                return new AST_TemplateString({
                    start: start,
                    segments: segments,
                    end: S.token
                });
            }
            function expr_list(closing, allow_trailing_comma, allow_empty) {
                var first = true, a = [];
                while (!is("punc", closing)) {
                    if (first)
                        first = false;
                    else
                        expect(",");
                    if (allow_trailing_comma && is("punc", closing))
                        break;
                    if (is("punc", ",") && allow_empty) {
                        a.push(new AST_Hole({ start: S.token, end: S.token }));
                    }
                    else if (is("expand", "...")) {
                        next();
                        a.push(new AST_Expansion({ start: prev(), expression: expression(), end: S.token }));
                    }
                    else {
                        a.push(expression(false));
                    }
                }
                next();
                return a;
            }
            var array_ = embed_tokens(function () {
                expect("[");
                return new AST_Array({
                    elements: expr_list("]", !options.strict, true)
                });
            });
            var create_accessor = embed_tokens((is_generator, is_async) => {
                return function_(AST_Accessor, is_generator, is_async);
            });
            var object_or_destructuring_ = embed_tokens(function object_or_destructuring_() {
                var start = S.token, first = true, a = [];
                expect("{");
                while (!is("punc", "}")) {
                    if (first)
                        first = false;
                    else
                        expect(",");
                    if (!options.strict && is("punc", "}"))
                        // allow trailing comma
                        break;
                    start = S.token;
                    if (start.type == "expand") {
                        next();
                        a.push(new AST_Expansion({
                            start: start,
                            expression: expression(false),
                            end: prev(),
                        }));
                        continue;
                    }
                    if (is("privatename")) {
                        croak("private fields are not allowed in an object");
                    }
                    var name = as_property_name();
                    var value;
                    // Check property and fetch value
                    if (!is("punc", ":")) {
                        var concise = concise_method_or_getset(name, start);
                        if (concise) {
                            a.push(concise);
                            continue;
                        }
                        value = new AST_SymbolRef({
                            start: prev(),
                            name: name,
                            end: prev()
                        });
                    }
                    else if (name === null) {
                        unexpected(prev());
                    }
                    else {
                        next(); // `:` - see first condition
                        value = expression(false);
                    }
                    // Check for default value and alter value accordingly if necessary
                    if (is("operator", "=")) {
                        next();
                        value = new AST_Assign({
                            start: start,
                            left: value,
                            operator: "=",
                            right: expression(false),
                            logical: false,
                            end: prev()
                        });
                    }
                    // Create property
                    a.push(new AST_ObjectKeyVal({
                        start: start,
                        quote: start.quote,
                        key: name instanceof AST_Node ? name : "" + name,
                        value: value,
                        end: prev()
                    }));
                }
                next();
                return new AST_Object({ properties: a });
            });
            function class_(KindOfClass, is_export_default) {
                var start, method, class_name, extends_, a = [];
                S.input.push_directives_stack(); // Push directive stack, but not scope stack
                S.input.add_directive("use strict");
                if (S.token.type == "name" && S.token.value != "extends") {
                    class_name = as_symbol(KindOfClass === AST_DefClass ? AST_SymbolDefClass : AST_SymbolClass);
                }
                if (KindOfClass === AST_DefClass && !class_name) {
                    if (is_export_default) {
                        KindOfClass = AST_ClassExpression;
                    }
                    else {
                        unexpected();
                    }
                }
                if (S.token.value == "extends") {
                    next();
                    extends_ = expression(true);
                }
                expect("{");
                // mark in class feild,
                const save_in_class = S.in_class;
                S.in_class = true;
                while (is("punc", ";")) {
                    next();
                } // Leading semicolons are okay in class bodies.
                while (!is("punc", "}")) {
                    start = S.token;
                    method = concise_method_or_getset(as_property_name(), start, true);
                    if (!method) {
                        unexpected();
                    }
                    a.push(method);
                    while (is("punc", ";")) {
                        next();
                    }
                }
                // mark in class feild,
                S.in_class = save_in_class;
                S.input.pop_directives_stack();
                next();
                return new KindOfClass({
                    start: start,
                    name: class_name,
                    extends: extends_,
                    properties: a,
                    end: prev(),
                });
            }
            function concise_method_or_getset(name, start, is_class) {
                const get_symbol_ast = (name, SymbolClass = AST_SymbolMethod) => {
                    if (typeof name === "string" || typeof name === "number") {
                        return new SymbolClass({
                            start,
                            name: "" + name,
                            end: prev()
                        });
                    }
                    else if (name === null) {
                        unexpected();
                    }
                    return name;
                };
                const is_not_method_start = () => !is("punc", "(") && !is("punc", ",") && !is("punc", "}") && !is("punc", ";") && !is("operator", "=");
                var is_async = false;
                var is_static = false;
                var is_generator = false;
                var is_private = false;
                var accessor_type = null;
                if (is_class && name === "static" && is_not_method_start()) {
                    const static_block = class_static_block();
                    if (static_block != null) {
                        return static_block;
                    }
                    is_static = true;
                    name = as_property_name();
                }
                if (name === "async" && is_not_method_start()) {
                    is_async = true;
                    name = as_property_name();
                }
                if (prev().type === "operator" && prev().value === "*") {
                    is_generator = true;
                    name = as_property_name();
                }
                if ((name === "get" || name === "set") && is_not_method_start()) {
                    accessor_type = name;
                    name = as_property_name();
                }
                if (prev().type === "privatename") {
                    is_private = true;
                }
                const property_token = prev();
                if (accessor_type != null) {
                    if (!is_private) {
                        const AccessorClass = accessor_type === "get"
                            ? AST_ObjectGetter
                            : AST_ObjectSetter;
                        name = get_symbol_ast(name);
                        return new AccessorClass({
                            start,
                            static: is_static,
                            key: name,
                            quote: name instanceof AST_SymbolMethod ? property_token.quote : undefined,
                            value: create_accessor(),
                            end: prev()
                        });
                    }
                    else {
                        const AccessorClass = accessor_type === "get"
                            ? AST_PrivateGetter
                            : AST_PrivateSetter;
                        return new AccessorClass({
                            start,
                            static: is_static,
                            key: get_symbol_ast(name),
                            value: create_accessor(),
                            end: prev(),
                        });
                    }
                }
                if (is("punc", "(")) {
                    name = get_symbol_ast(name);
                    const AST_MethodVariant = is_private
                        ? AST_PrivateMethod
                        : AST_ConciseMethod;
                    var node = new AST_MethodVariant({
                        start: start,
                        static: is_static,
                        is_generator: is_generator,
                        async: is_async,
                        key: name,
                        quote: name instanceof AST_SymbolMethod ?
                            property_token.quote : undefined,
                        value: create_accessor(is_generator, is_async),
                        end: prev()
                    });
                    return node;
                }
                if (is_class) {
                    const key = get_symbol_ast(name, AST_SymbolClassProperty);
                    const quote = key instanceof AST_SymbolClassProperty
                        ? property_token.quote
                        : undefined;
                    const AST_ClassPropertyVariant = is_private
                        ? AST_ClassPrivateProperty
                        : AST_ClassProperty;
                    if (is("operator", "=")) {
                        next();
                        return new AST_ClassPropertyVariant({
                            start,
                            static: is_static,
                            quote,
                            key,
                            value: expression(false),
                            end: prev()
                        });
                    }
                    else if (is("name")
                        || is("privatename")
                        || is("operator", "*")
                        || is("punc", ";")
                        || is("punc", "}")) {
                        return new AST_ClassPropertyVariant({
                            start,
                            static: is_static,
                            quote,
                            key,
                            end: prev()
                        });
                    }
                }
            }
            function class_static_block() {
                if (!is("punc", "{")) {
                    return null;
                }
                const start = S.token;
                const body = [];
                next();
                while (!is("punc", "}")) {
                    body.push(statement());
                }
                next();
                return new AST_ClassStaticBlock({ start, body, end: prev() });
            }
            function maybe_import_assertion() {
                if (is("name", "assert") && !has_newline_before(S.token)) {
                    next();
                    return object_or_destructuring_();
                }
                return null;
            }
            function import_statement() {
                var start = prev();
                var imported_name;
                var imported_names;
                if (is("name")) {
                    imported_name = as_symbol(AST_SymbolImport);
                }
                if (is("punc", ",")) {
                    next();
                }
                imported_names = map_names(true);
                if (imported_names || imported_name) {
                    expect_token("name", "from");
                }
                var mod_str = S.token;
                if (mod_str.type !== "string") {
                    unexpected();
                }
                next();
                const assert_clause = maybe_import_assertion();
                return new AST_Import({
                    start,
                    imported_name,
                    imported_names,
                    module_name: new AST_String({
                        start: mod_str,
                        value: mod_str.value,
                        quote: mod_str.quote,
                        end: mod_str,
                    }),
                    assert_clause,
                    end: S.token,
                });
            }
            function import_meta() {
                var start = S.token;
                expect_token("name", "import");
                expect_token("punc", ".");
                expect_token("name", "meta");
                return subscripts(new AST_ImportMeta({
                    start: start,
                    end: prev()
                }), false);
            }
            function map_name(is_import) {
                function make_symbol(type, quote) {
                    return new type({
                        name: as_property_name(),
                        quote: quote || undefined,
                        start: prev(),
                        end: prev()
                    });
                }
                var foreign_type = is_import ? AST_SymbolImportForeign : AST_SymbolExportForeign;
                var type = is_import ? AST_SymbolImport : AST_SymbolExport;
                var start = S.token;
                var foreign_name;
                var name;
                if (is_import) {
                    foreign_name = make_symbol(foreign_type, start.quote);
                }
                else {
                    name = make_symbol(type, start.quote);
                }
                if (is("name", "as")) {
                    next(); // The "as" word
                    if (is_import) {
                        name = make_symbol(type);
                    }
                    else {
                        foreign_name = make_symbol(foreign_type, S.token.quote);
                    }
                }
                else if (is_import) {
                    name = new type(foreign_name);
                }
                else {
                    foreign_name = new foreign_type(name);
                }
                return new AST_NameMapping({
                    start: start,
                    foreign_name: foreign_name,
                    name: name,
                    end: prev(),
                });
            }
            function map_nameAsterisk(is_import, import_or_export_foreign_name) {
                var foreign_type = is_import ? AST_SymbolImportForeign : AST_SymbolExportForeign;
                var type = is_import ? AST_SymbolImport : AST_SymbolExport;
                var start = S.token;
                var name, foreign_name;
                var end = prev();
                if (is_import) {
                    name = import_or_export_foreign_name;
                }
                else {
                    foreign_name = import_or_export_foreign_name;
                }
                name = name || new type({
                    start: start,
                    name: "*",
                    end: end,
                });
                foreign_name = foreign_name || new foreign_type({
                    start: start,
                    name: "*",
                    end: end,
                });
                return new AST_NameMapping({
                    start: start,
                    foreign_name: foreign_name,
                    name: name,
                    end: end,
                });
            }
            function map_names(is_import) {
                var names;
                if (is("punc", "{")) {
                    next();
                    names = [];
                    while (!is("punc", "}")) {
                        names.push(map_name(is_import));
                        if (is("punc", ",")) {
                            next();
                        }
                    }
                    next();
                }
                else if (is("operator", "*")) {
                    var name;
                    next();
                    if (is("name", "as")) {
                        next(); // The "as" word
                        name = is_import ? as_symbol(AST_SymbolImport) : as_symbol_or_string(AST_SymbolExportForeign);
                    }
                    names = [map_nameAsterisk(is_import, name)];
                }
                return names;
            }
            function export_statement() {
                var start = S.token;
                var is_default;
                var exported_names;
                if (is("keyword", "default")) {
                    is_default = true;
                    next();
                }
                else if (exported_names = map_names(false)) {
                    if (is("name", "from")) {
                        next();
                        var mod_str = S.token;
                        if (mod_str.type !== "string") {
                            unexpected();
                        }
                        next();
                        const assert_clause = maybe_import_assertion();
                        return new AST_Export({
                            start: start,
                            is_default: is_default,
                            exported_names: exported_names,
                            module_name: new AST_String({
                                start: mod_str,
                                value: mod_str.value,
                                quote: mod_str.quote,
                                end: mod_str,
                            }),
                            end: prev(),
                            assert_clause
                        });
                    }
                    else {
                        return new AST_Export({
                            start: start,
                            is_default: is_default,
                            exported_names: exported_names,
                            end: prev(),
                        });
                    }
                }
                var node;
                var exported_value;
                var exported_definition;
                if (is("punc", "{")
                    || is_default
                        && (is("keyword", "class") || is("keyword", "function"))
                        && is_token(peek(), "punc")) {
                    exported_value = expression(false);
                    semicolon();
                }
                else if ((node = statement(is_default)) instanceof AST_Definitions && is_default) {
                    unexpected(node.start);
                }
                else if (node instanceof AST_Definitions
                    || node instanceof AST_Defun
                    || node instanceof AST_DefClass) {
                    exported_definition = node;
                }
                else if (node instanceof AST_ClassExpression
                    || node instanceof AST_Function) {
                    exported_value = node;
                }
                else if (node instanceof AST_SimpleStatement) {
                    exported_value = node.body;
                }
                else {
                    unexpected(node.start);
                }
                return new AST_Export({
                    start: start,
                    is_default: is_default,
                    exported_value: exported_value,
                    exported_definition: exported_definition,
                    end: prev(),
                    assert_clause: null
                });
            }
            function as_property_name() {
                var tmp = S.token;
                switch (tmp.type) {
                    case "punc":
                        if (tmp.value === "[") {
                            next();
                            var ex = expression(false);
                            expect("]");
                            return ex;
                        }
                        else
                            unexpected(tmp);
                    case "operator":
                        if (tmp.value === "*") {
                            next();
                            return null;
                        }
                        if (!["delete", "in", "instanceof", "new", "typeof", "void"].includes(tmp.value)) {
                            unexpected(tmp);
                        }
                    /* falls through */
                    case "name":
                    case "privatename":
                    case "string":
                    case "num":
                    case "big_int":
                    case "keyword":
                    case "atom":
                        next();
                        return tmp.value;
                    default:
                        unexpected(tmp);
                }
            }
            function as_name() {
                var tmp = S.token;
                if (tmp.type != "name" && tmp.type != "privatename")
                    unexpected();
                next();
                return tmp.value;
            }
            function _make_symbol(type) {
                var name = S.token.value;
                return new (name == "this" ? AST_This :
                    name == "super" ? AST_Super :
                        type)({
                    name: String(name),
                    start: S.token,
                    end: S.token
                });
            }
            function _verify_symbol(sym) {
                var name = sym.name;
                if (is_in_generator() && name == "yield") {
                    token_error(sym.start, "Yield cannot be used as identifier inside generators");
                }
                if (S.input.has_directive("use strict")) {
                    if (name == "yield") {
                        token_error(sym.start, "Unexpected yield identifier inside strict mode");
                    }
                    if (sym instanceof AST_SymbolDeclaration && (name == "arguments" || name == "eval")) {
                        token_error(sym.start, "Unexpected " + name + " in strict mode");
                    }
                }
            }
            function as_symbol(type, noerror) {
                if (!is("name")) {
                    if (!noerror)
                        croak("Name expected");
                    return null;
                }
                var sym = _make_symbol(type);
                _verify_symbol(sym);
                next();
                return sym;
            }
            function as_symbol_or_string(type) {
                if (!is("name")) {
                    if (!is("string")) {
                        croak("Name or string expected");
                    }
                    var tok = S.token;
                    var ret = new type({
                        start: tok,
                        end: tok,
                        name: tok.value,
                        quote: tok.quote
                    });
                    next();
                    return ret;
                }
                var sym = _make_symbol(type);
                _verify_symbol(sym);
                next();
                return sym;
            }
            // Annotate AST_Call, AST_Lambda or AST_New with the special comments
            function annotate(node) {
                var start = node.start;
                var comments = start.comments_before;
                const comments_outside_parens = outer_comments_before_counts.get(start);
                var i = comments_outside_parens != null ? comments_outside_parens : comments.length;
                while (--i >= 0) {
                    var comment = comments[i];
                    if (/[@#]__/.test(comment.value)) {
                        if (/[@#]__PURE__/.test(comment.value)) {
                            set_annotation(node, _PURE);
                            break;
                        }
                        if (/[@#]__INLINE__/.test(comment.value)) {
                            set_annotation(node, _INLINE);
                            break;
                        }
                        if (/[@#]__NOINLINE__/.test(comment.value)) {
                            set_annotation(node, _NOINLINE);
                            break;
                        }
                    }
                }
            }
            var subscripts = function (expr, allow_calls, is_chain) {
                var start = expr.start;
                if (is("punc", ".")) {
                    next();
                    if (is("privatename") && !S.in_class)
                        croak("Private field must be used in an enclosing class");
                    const AST_DotVariant = is("privatename") ? AST_DotHash : AST_Dot;
                    return subscripts(new AST_DotVariant({
                        start: start,
                        expression: expr,
                        optional: false,
                        property: as_name(),
                        end: prev()
                    }), allow_calls, is_chain);
                }
                if (is("punc", "[")) {
                    next();
                    var prop = expression(true);
                    expect("]");
                    return subscripts(new AST_Sub({
                        start: start,
                        expression: expr,
                        optional: false,
                        property: prop,
                        end: prev()
                    }), allow_calls, is_chain);
                }
                if (allow_calls && is("punc", "(")) {
                    next();
                    var call = new AST_Call({
                        start: start,
                        expression: expr,
                        optional: false,
                        args: call_args(),
                        end: prev()
                    });
                    annotate(call);
                    return subscripts(call, true, is_chain);
                }
                if (is("punc", "?.")) {
                    next();
                    let chain_contents;
                    if (allow_calls && is("punc", "(")) {
                        next();
                        const call = new AST_Call({
                            start,
                            optional: true,
                            expression: expr,
                            args: call_args(),
                            end: prev()
                        });
                        annotate(call);
                        chain_contents = subscripts(call, true, true);
                    }
                    else if (is("name") || is("privatename")) {
                        if (is("privatename") && !S.in_class)
                            croak("Private field must be used in an enclosing class");
                        const AST_DotVariant = is("privatename") ? AST_DotHash : AST_Dot;
                        chain_contents = subscripts(new AST_DotVariant({
                            start,
                            expression: expr,
                            optional: true,
                            property: as_name(),
                            end: prev()
                        }), allow_calls, true);
                    }
                    else if (is("punc", "[")) {
                        next();
                        const property = expression(true);
                        expect("]");
                        chain_contents = subscripts(new AST_Sub({
                            start,
                            expression: expr,
                            optional: true,
                            property,
                            end: prev()
                        }), allow_calls, true);
                    }
                    if (!chain_contents)
                        unexpected();
                    if (chain_contents instanceof AST_Chain)
                        return chain_contents;
                    return new AST_Chain({
                        start,
                        expression: chain_contents,
                        end: prev()
                    });
                }
                if (is("template_head")) {
                    if (is_chain) {
                        // a?.b`c` is a syntax error
                        unexpected();
                    }
                    return subscripts(new AST_PrefixedTemplateString({
                        start: start,
                        prefix: expr,
                        template_string: template_string(),
                        end: prev()
                    }), allow_calls);
                }
                return expr;
            };
            function call_args() {
                var args = [];
                while (!is("punc", ")")) {
                    if (is("expand", "...")) {
                        next();
                        args.push(new AST_Expansion({
                            start: prev(),
                            expression: expression(false),
                            end: prev()
                        }));
                    }
                    else {
                        args.push(expression(false));
                    }
                    if (!is("punc", ")")) {
                        expect(",");
                    }
                }
                next();
                return args;
            }
            var maybe_unary = function (allow_calls, allow_arrows) {
                var start = S.token;
                if (start.type == "name" && start.value == "await" && can_await()) {
                    next();
                    return _await_expression();
                }
                if (is("operator") && UNARY_PREFIX.has(start.value)) {
                    next();
                    handle_regexp();
                    var ex = make_unary(AST_UnaryPrefix, start, maybe_unary(allow_calls));
                    ex.start = start;
                    ex.end = prev();
                    return ex;
                }
                var val = expr_atom(allow_calls, allow_arrows);
                while (is("operator") && UNARY_POSTFIX.has(S.token.value) && !has_newline_before(S.token)) {
                    if (val instanceof AST_Arrow)
                        unexpected();
                    val = make_unary(AST_UnaryPostfix, S.token, val);
                    val.start = start;
                    val.end = S.token;
                    next();
                }
                return val;
            };
            function make_unary(ctor, token, expr) {
                var op = token.value;
                switch (op) {
                    case "++":
                    case "--":
                        if (!is_assignable(expr))
                            croak("Invalid use of " + op + " operator", token.line, token.col, token.pos);
                        break;
                    case "delete":
                        if (expr instanceof AST_SymbolRef && S.input.has_directive("use strict"))
                            croak("Calling delete on expression not allowed in strict mode", expr.start.line, expr.start.col, expr.start.pos);
                        break;
                }
                return new ctor({ operator: op, expression: expr });
            }
            var expr_op = function (left, min_prec, no_in) {
                var op = is("operator") ? S.token.value : null;
                if (op == "in" && no_in)
                    op = null;
                if (op == "**" && left instanceof AST_UnaryPrefix
                    /* unary token in front not allowed - parenthesis required */
                    && !is_token(left.start, "punc", "(")
                    && left.operator !== "--" && left.operator !== "++")
                    unexpected(left.start);
                var prec = op != null ? PRECEDENCE[op] : null;
                if (prec != null && (prec > min_prec || (op === "**" && min_prec === prec))) {
                    next();
                    var right = expr_op(maybe_unary(true), prec, no_in);
                    return expr_op(new AST_Binary({
                        start: left.start,
                        left: left,
                        operator: op,
                        right: right,
                        end: right.end
                    }), min_prec, no_in);
                }
                return left;
            };
            function expr_ops(no_in) {
                return expr_op(maybe_unary(true, true), 0, no_in);
            }
            var maybe_conditional = function (no_in) {
                var start = S.token;
                var expr = expr_ops(no_in);
                if (is("operator", "?")) {
                    next();
                    var yes = expression(false);
                    expect(":");
                    return new AST_Conditional({
                        start: start,
                        condition: expr,
                        consequent: yes,
                        alternative: expression(false, no_in),
                        end: prev()
                    });
                }
                return expr;
            };
            function is_assignable(expr) {
                return expr instanceof AST_PropAccess || expr instanceof AST_SymbolRef;
            }
            function to_destructuring(node) {
                if (node instanceof AST_Object) {
                    node = new AST_Destructuring({
                        start: node.start,
                        names: node.properties.map(to_destructuring),
                        is_array: false,
                        end: node.end
                    });
                }
                else if (node instanceof AST_Array) {
                    var names = [];
                    for (var i = 0; i < node.elements.length; i++) {
                        // Only allow expansion as last element
                        if (node.elements[i] instanceof AST_Expansion) {
                            if (i + 1 !== node.elements.length) {
                                token_error(node.elements[i].start, "Spread must the be last element in destructuring array");
                            }
                            node.elements[i].expression = to_destructuring(node.elements[i].expression);
                        }
                        names.push(to_destructuring(node.elements[i]));
                    }
                    node = new AST_Destructuring({
                        start: node.start,
                        names: names,
                        is_array: true,
                        end: node.end
                    });
                }
                else if (node instanceof AST_ObjectProperty) {
                    node.value = to_destructuring(node.value);
                }
                else if (node instanceof AST_Assign) {
                    node = new AST_DefaultAssign({
                        start: node.start,
                        left: node.left,
                        operator: "=",
                        right: node.right,
                        end: node.end
                    });
                }
                return node;
            }
            // In ES6, AssignmentExpression can also be an ArrowFunction
            var maybe_assign = function (no_in) {
                handle_regexp();
                var start = S.token;
                if (start.type == "name" && start.value == "yield") {
                    if (is_in_generator()) {
                        next();
                        return _yield_expression();
                    }
                    else if (S.input.has_directive("use strict")) {
                        token_error(S.token, "Unexpected yield identifier inside strict mode");
                    }
                }
                var left = maybe_conditional(no_in);
                var val = S.token.value;
                if (is("operator") && ASSIGNMENT.has(val)) {
                    if (is_assignable(left) || (left = to_destructuring(left)) instanceof AST_Destructuring) {
                        next();
                        return new AST_Assign({
                            start: start,
                            left: left,
                            operator: val,
                            right: maybe_assign(no_in),
                            logical: LOGICAL_ASSIGNMENT.has(val),
                            end: prev()
                        });
                    }
                    croak("Invalid assignment");
                }
                return left;
            };
            var expression = function (commas, no_in) {
                var start = S.token;
                var exprs = [];
                while (true) {
                    exprs.push(maybe_assign(no_in));
                    if (!commas || !is("punc", ","))
                        break;
                    next();
                    commas = true;
                }
                return exprs.length == 1 ? exprs[0] : new AST_Sequence({
                    start: start,
                    expressions: exprs,
                    end: peek()
                });
            };
            function in_loop(cont) {
                ++S.in_loop;
                var ret = cont();
                --S.in_loop;
                return ret;
            }
            if (options.expression) {
                return expression(true);
            }
            return (function parse_toplevel() {
                var start = S.token;
                var body = [];
                S.input.push_directives_stack();
                if (options.module)
                    S.input.add_directive("use strict");
                while (!is("eof")) {
                    body.push(statement());
                }
                S.input.pop_directives_stack();
                var end = prev();
                var toplevel = options.toplevel;
                if (toplevel) {
                    toplevel.body = toplevel.body.concat(body);
                    toplevel.end = end;
                }
                else {
                    toplevel = new AST_Toplevel({ start: start, body: body, end: end });
                }
                TEMPLATE_RAWS = new Map();
                return toplevel;
            })();
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function DEFNODE(type, props, ctor, methods, base = AST_Node) {
            if (!props)
                props = [];
            else
                props = props.split(/\s+/);
            var self_props = props;
            if (base && base.PROPS)
                props = props.concat(base.PROPS);
            const proto = base && Object.create(base.prototype);
            if (proto) {
                ctor.prototype = proto;
                ctor.BASE = base;
            }
            if (base)
                base.SUBCLASSES.push(ctor);
            ctor.prototype.CTOR = ctor;
            ctor.prototype.constructor = ctor;
            ctor.PROPS = props || null;
            ctor.SELF_PROPS = self_props;
            ctor.SUBCLASSES = [];
            if (type) {
                ctor.prototype.TYPE = ctor.TYPE = type;
            }
            if (methods)
                for (let i in methods)
                    if (HOP(methods, i)) {
                        if (i[0] === "$") {
                            ctor[i.substr(1)] = methods[i];
                        }
                        else {
                            ctor.prototype[i] = methods[i];
                        }
                    }
            ctor.DEFMETHOD = function (name, method) {
                this.prototype[name] = method;
            };
            return ctor;
        }
        const has_tok_flag = (tok, flag) => Boolean(tok.flags & flag);
        const set_tok_flag = (tok, flag, truth) => {
            if (truth) {
                tok.flags |= flag;
            }
            else {
                tok.flags &= ~flag;
            }
        };
        const TOK_FLAG_NLB = 0b0001;
        const TOK_FLAG_QUOTE_SINGLE = 0b0010;
        const TOK_FLAG_QUOTE_EXISTS = 0b0100;
        const TOK_FLAG_TEMPLATE_END = 0b1000;
        class AST_Token {
            constructor(type, value, line, col, pos, nlb, comments_before, comments_after, file) {
                this.flags = (nlb ? 1 : 0);
                this.type = type;
                this.value = value;
                this.line = line;
                this.col = col;
                this.pos = pos;
                this.comments_before = comments_before;
                this.comments_after = comments_after;
                this.file = file;
                Object.seal(this);
            }
            // Return a string summary of the token for node.js console.log
            [Symbol.for("nodejs.util.inspect.custom")](_depth, options) {
                const special = str => options.stylize(str, "special");
                const quote = typeof this.value === "string" && this.value.includes("`") ? "'" : "`";
                const value = `${quote}${this.value}${quote}`;
                return `${special("[AST_Token")} ${value} at ${this.line}:${this.col}${special("]")}`;
            }
            get nlb() {
                return has_tok_flag(this, TOK_FLAG_NLB);
            }
            set nlb(new_nlb) {
                set_tok_flag(this, TOK_FLAG_NLB, new_nlb);
            }
            get quote() {
                return !has_tok_flag(this, TOK_FLAG_QUOTE_EXISTS)
                    ? ""
                    : (has_tok_flag(this, TOK_FLAG_QUOTE_SINGLE) ? "'" : '"');
            }
            set quote(quote_type) {
                set_tok_flag(this, TOK_FLAG_QUOTE_SINGLE, quote_type === "'");
                set_tok_flag(this, TOK_FLAG_QUOTE_EXISTS, !!quote_type);
            }
            get template_end() {
                return has_tok_flag(this, TOK_FLAG_TEMPLATE_END);
            }
            set template_end(new_template_end) {
                set_tok_flag(this, TOK_FLAG_TEMPLATE_END, new_template_end);
            }
        }
        var AST_Node = DEFNODE("Node", "start end", function AST_Node(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            _clone: function (deep) {
                if (deep) {
                    var self = this.clone();
                    return self.transform(new TreeTransformer(function (node) {
                        if (node !== self) {
                            return node.clone(true);
                        }
                    }));
                }
                return new this.CTOR(this);
            },
            clone: function (deep) {
                return this._clone(deep);
            },
            $documentation: "Base class of all AST nodes",
            $propdoc: {
                start: "[AST_Token] The first token of this node",
                end: "[AST_Token] The last token of this node"
            },
            _walk: function (visitor) {
                return visitor._visit(this);
            },
            walk: function (visitor) {
                return this._walk(visitor); // not sure the indirection will be any help
            },
            _children_backwards: () => { }
        }, null);
        /* -----[ statements ]----- */
        var AST_Statement = DEFNODE("Statement", null, function AST_Statement(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class of all statements",
        });
        var AST_Debugger = DEFNODE("Debugger", null, function AST_Debugger(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Represents a debugger statement",
        }, AST_Statement);
        var AST_Directive = DEFNODE("Directive", "value quote", function AST_Directive(props) {
            if (props) {
                this.value = props.value;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Represents a directive, like \"use strict\";",
            $propdoc: {
                value: "[string] The value of this directive as a plain string (it's not an AST_String!)",
                quote: "[string] the original quote character"
            },
        }, AST_Statement);
        var AST_SimpleStatement = DEFNODE("SimpleStatement", "body", function AST_SimpleStatement(props) {
            if (props) {
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A statement consisting of an expression, i.e. a = 1 + 2",
            $propdoc: {
                body: "[AST_Node] an expression node (should not be instanceof AST_Statement)"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
            }
        }, AST_Statement);
        function walk_body(node, visitor) {
            const body = node.body;
            if (visitor.walk_defun_first) {
                for (var i = 0, len = body.length; i < len; i++) {
                    if (body[i] instanceof AST_Defun) {
                        body[i]._walk(visitor);
                    }
                }
                for (var i = 0, len = body.length; i < len; i++) {
                    if (!(body[i] instanceof AST_Defun)) {
                        body[i]._walk(visitor);
                    }
                }
            }
            else {
                for (var i = 0, len = body.length; i < len; i++) {
                    body[i]._walk(visitor);
                }
            }
        }
        function clone_block_scope(deep) {
            var clone = this._clone(deep);
            if (this.block_scope) {
                clone.block_scope = this.block_scope.clone();
            }
            return clone;
        }
        var AST_Block = DEFNODE("Block", "body block_scope", function AST_Block(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A body of statements (usually braced)",
            $propdoc: {
                body: "[AST_Statement*] an array of statements",
                block_scope: "[AST_Scope] the block scope"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
            },
            clone: clone_block_scope
        }, AST_Statement);
        var AST_BlockStatement = DEFNODE("BlockStatement", null, function AST_BlockStatement(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A block statement",
        }, AST_Block);
        var AST_EmptyStatement = DEFNODE("EmptyStatement", null, function AST_EmptyStatement(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The empty statement (empty block or simply a semicolon)"
        }, AST_Statement);
        var AST_StatementWithBody = DEFNODE("StatementWithBody", "body", function AST_StatementWithBody(props) {
            if (props) {
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for all statements that contain one nested body: `For`, `ForIn`, `Do`, `While`, `With`",
            $propdoc: {
                body: "[AST_Statement] the body; this should always be present, even if it's an AST_EmptyStatement"
            }
        }, AST_Statement);
        var AST_LabeledStatement = DEFNODE("LabeledStatement", "label", function AST_LabeledStatement(props) {
            if (props) {
                this.label = props.label;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Statement with a label",
            $propdoc: {
                label: "[AST_Label] a label definition"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.label._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                push(this.label);
            },
            clone: function (deep) {
                var node = this._clone(deep);
                if (deep) {
                    var label = node.label;
                    var def = this.label;
                    node.walk(new TreeWalker(function (node) {
                        if (node instanceof AST_LoopControl
                            && node.label && node.label.thedef === def) {
                            node.label.thedef = label;
                            label.references.push(node);
                        }
                    }));
                }
                return node;
            }
        }, AST_StatementWithBody);
        var AST_IterationStatement = DEFNODE("IterationStatement", "block_scope", function AST_IterationStatement(props) {
            if (props) {
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Internal class.  All loops inherit from it.",
            $propdoc: {
                block_scope: "[AST_Scope] the block scope for this iteration statement."
            },
            clone: clone_block_scope
        }, AST_StatementWithBody);
        var AST_DWLoop = DEFNODE("DWLoop", "condition", function AST_DWLoop(props) {
            if (props) {
                this.condition = props.condition;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for do/while statements",
            $propdoc: {
                condition: "[AST_Node] the loop condition.  Should not be instanceof AST_Statement"
            }
        }, AST_IterationStatement);
        var AST_Do = DEFNODE("Do", null, function AST_Do(props) {
            if (props) {
                this.condition = props.condition;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `do` statement",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.body._walk(visitor);
                    this.condition._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.condition);
                push(this.body);
            }
        }, AST_DWLoop);
        var AST_While = DEFNODE("While", null, function AST_While(props) {
            if (props) {
                this.condition = props.condition;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `while` statement",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.condition._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                push(this.condition);
            },
        }, AST_DWLoop);
        var AST_For = DEFNODE("For", "init condition step", function AST_For(props) {
            if (props) {
                this.init = props.init;
                this.condition = props.condition;
                this.step = props.step;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `for` statement",
            $propdoc: {
                init: "[AST_Node?] the `for` initialization code, or null if empty",
                condition: "[AST_Node?] the `for` termination clause, or null if empty",
                step: "[AST_Node?] the `for` update clause, or null if empty"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.init)
                        this.init._walk(visitor);
                    if (this.condition)
                        this.condition._walk(visitor);
                    if (this.step)
                        this.step._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                if (this.step)
                    push(this.step);
                if (this.condition)
                    push(this.condition);
                if (this.init)
                    push(this.init);
            },
        }, AST_IterationStatement);
        var AST_ForIn = DEFNODE("ForIn", "init object", function AST_ForIn(props) {
            if (props) {
                this.init = props.init;
                this.object = props.object;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `for ... in` statement",
            $propdoc: {
                init: "[AST_Node] the `for/in` initialization code",
                object: "[AST_Node] the object that we're looping through"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.init._walk(visitor);
                    this.object._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                if (this.object)
                    push(this.object);
                if (this.init)
                    push(this.init);
            },
        }, AST_IterationStatement);
        var AST_ForOf = DEFNODE("ForOf", "await", function AST_ForOf(props) {
            if (props) {
                this.await = props.await;
                this.init = props.init;
                this.object = props.object;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `for ... of` statement",
        }, AST_ForIn);
        var AST_With = DEFNODE("With", "expression", function AST_With(props) {
            if (props) {
                this.expression = props.expression;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `with` statement",
            $propdoc: {
                expression: "[AST_Node] the `with` expression"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                push(this.expression);
            },
        }, AST_StatementWithBody);
        /* -----[ scope and functions ]----- */
        var AST_Scope = DEFNODE("Scope", "variables uses_with uses_eval parent_scope enclosed cname", function AST_Scope(props) {
            if (props) {
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for all statements introducing a lexical scope",
            $propdoc: {
                variables: "[Map/S] a map of name -> SymbolDef for all variables/functions defined in this scope",
                uses_with: "[boolean/S] tells whether this scope uses the `with` statement",
                uses_eval: "[boolean/S] tells whether this scope contains a direct call to the global `eval`",
                parent_scope: "[AST_Scope?/S] link to the parent scope",
                enclosed: "[SymbolDef*/S] a list of all symbol definitions that are accessed from this scope or any subscopes",
                cname: "[integer/S] current index for mangling variables (used internally by the mangler)",
            },
            get_defun_scope: function () {
                var self = this;
                while (self.is_block_scope()) {
                    self = self.parent_scope;
                }
                return self;
            },
            clone: function (deep, toplevel) {
                var node = this._clone(deep);
                if (deep && this.variables && toplevel && !this._block_scope) {
                    node.figure_out_scope({}, {
                        toplevel: toplevel,
                        parent_scope: this.parent_scope
                    });
                }
                else {
                    if (this.variables)
                        node.variables = new Map(this.variables);
                    if (this.enclosed)
                        node.enclosed = this.enclosed.slice();
                    if (this._block_scope)
                        node._block_scope = this._block_scope;
                }
                return node;
            },
            pinned: function () {
                return this.uses_eval || this.uses_with;
            }
        }, AST_Block);
        var AST_Toplevel = DEFNODE("Toplevel", "globals", function AST_Toplevel(props) {
            if (props) {
                this.globals = props.globals;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The toplevel scope",
            $propdoc: {
                globals: "[Map/S] a map of name -> SymbolDef for all undeclared names",
            },
            wrap_commonjs: function (name) {
                var body = this.body;
                var wrapped_tl = "(function(exports){'$ORIG';})(typeof " + name + "=='undefined'?(" + name + "={}):" + name + ");";
                wrapped_tl = parse(wrapped_tl);
                wrapped_tl = wrapped_tl.transform(new TreeTransformer(function (node) {
                    if (node instanceof AST_Directive && node.value == "$ORIG") {
                        return MAP.splice(body);
                    }
                }));
                return wrapped_tl;
            },
            wrap_enclose: function (args_values) {
                if (typeof args_values != "string")
                    args_values = "";
                var index = args_values.indexOf(":");
                if (index < 0)
                    index = args_values.length;
                var body = this.body;
                return parse([
                    "(function(",
                    args_values.slice(0, index),
                    '){"$ORIG"})(',
                    args_values.slice(index + 1),
                    ")"
                ].join("")).transform(new TreeTransformer(function (node) {
                    if (node instanceof AST_Directive && node.value == "$ORIG") {
                        return MAP.splice(body);
                    }
                }));
            }
        }, AST_Scope);
        var AST_Expansion = DEFNODE("Expansion", "expression", function AST_Expansion(props) {
            if (props) {
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An expandible argument, such as ...rest, a splat, such as [1,2,...all], or an expansion in a variable declaration, such as var [first, ...rest] = list",
            $propdoc: {
                expression: "[AST_Node] the thing to be expanded"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression.walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        });
        var AST_Lambda = DEFNODE("Lambda", "name argnames uses_arguments is_generator async", function AST_Lambda(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for functions",
            $propdoc: {
                name: "[AST_SymbolDeclaration?] the name of this function",
                argnames: "[AST_SymbolFunarg|AST_Destructuring|AST_Expansion|AST_DefaultAssign*] array of function arguments, destructurings, or expanding arguments",
                uses_arguments: "[boolean/S] tells whether this function accesses the arguments array",
                is_generator: "[boolean] is this a generator method",
                async: "[boolean] is this method async",
            },
            args_as_names: function () {
                var out = [];
                for (var i = 0; i < this.argnames.length; i++) {
                    if (this.argnames[i] instanceof AST_Destructuring) {
                        out.push(...this.argnames[i].all_symbols());
                    }
                    else {
                        out.push(this.argnames[i]);
                    }
                }
                return out;
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.name)
                        this.name._walk(visitor);
                    var argnames = this.argnames;
                    for (var i = 0, len = argnames.length; i < len; i++) {
                        argnames[i]._walk(visitor);
                    }
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
                i = this.argnames.length;
                while (i--)
                    push(this.argnames[i]);
                if (this.name)
                    push(this.name);
            },
            is_braceless() {
                return this.body[0] instanceof AST_Return && this.body[0].value;
            },
            // Default args and expansion don't count, so .argnames.length doesn't cut it
            length_property() {
                let length = 0;
                for (const arg of this.argnames) {
                    if (arg instanceof AST_SymbolFunarg || arg instanceof AST_Destructuring) {
                        length++;
                    }
                }
                return length;
            }
        }, AST_Scope);
        var AST_Accessor = DEFNODE("Accessor", null, function AST_Accessor(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A setter/getter function.  The `name` property is always null."
        }, AST_Lambda);
        var AST_Function = DEFNODE("Function", null, function AST_Function(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A function expression"
        }, AST_Lambda);
        var AST_Arrow = DEFNODE("Arrow", null, function AST_Arrow(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An ES6 Arrow function ((a) => b)"
        }, AST_Lambda);
        var AST_Defun = DEFNODE("Defun", null, function AST_Defun(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A function definition"
        }, AST_Lambda);
        /* -----[ DESTRUCTURING ]----- */
        var AST_Destructuring = DEFNODE("Destructuring", "names is_array", function AST_Destructuring(props) {
            if (props) {
                this.names = props.names;
                this.is_array = props.is_array;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A destructuring of several names. Used in destructuring assignment and with destructuring function argument names",
            $propdoc: {
                "names": "[AST_Node*] Array of properties or elements",
                "is_array": "[Boolean] Whether the destructuring represents an object or array"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.names.forEach(function (name) {
                        name._walk(visitor);
                    });
                });
            },
            _children_backwards(push) {
                let i = this.names.length;
                while (i--)
                    push(this.names[i]);
            },
            all_symbols: function () {
                var out = [];
                this.walk(new TreeWalker(function (node) {
                    if (node instanceof AST_Symbol) {
                        out.push(node);
                    }
                }));
                return out;
            }
        });
        var AST_PrefixedTemplateString = DEFNODE("PrefixedTemplateString", "template_string prefix", function AST_PrefixedTemplateString(props) {
            if (props) {
                this.template_string = props.template_string;
                this.prefix = props.prefix;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A templatestring with a prefix, such as String.raw`foobarbaz`",
            $propdoc: {
                template_string: "[AST_TemplateString] The template string",
                prefix: "[AST_Node] The prefix, which will get called."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.prefix._walk(visitor);
                    this.template_string._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.template_string);
                push(this.prefix);
            },
        });
        var AST_TemplateString = DEFNODE("TemplateString", "segments", function AST_TemplateString(props) {
            if (props) {
                this.segments = props.segments;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A template string literal",
            $propdoc: {
                segments: "[AST_Node*] One or more segments, starting with AST_TemplateSegment. AST_Node may follow AST_TemplateSegment, but each AST_Node must be followed by AST_TemplateSegment."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.segments.forEach(function (seg) {
                        seg._walk(visitor);
                    });
                });
            },
            _children_backwards(push) {
                let i = this.segments.length;
                while (i--)
                    push(this.segments[i]);
            }
        });
        var AST_TemplateSegment = DEFNODE("TemplateSegment", "value raw", function AST_TemplateSegment(props) {
            if (props) {
                this.value = props.value;
                this.raw = props.raw;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A segment of a template string literal",
            $propdoc: {
                value: "Content of the segment",
                raw: "Raw source of the segment",
            }
        });
        /* -----[ JUMPS ]----- */
        var AST_Jump = DEFNODE("Jump", null, function AST_Jump(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for “jumps” (for now that's `return`, `throw`, `break` and `continue`)"
        }, AST_Statement);
        /** Base class for “exits” (`return` and `throw`) */
        var AST_Exit = DEFNODE("Exit", "value", function AST_Exit(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for “exits” (`return` and `throw`)",
            $propdoc: {
                value: "[AST_Node?] the value returned or thrown by this statement; could be null for AST_Return"
            },
            _walk: function (visitor) {
                return visitor._visit(this, this.value && function () {
                    this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.value)
                    push(this.value);
            },
        }, AST_Jump);
        var AST_Return = DEFNODE("Return", null, function AST_Return(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `return` statement"
        }, AST_Exit);
        var AST_Throw = DEFNODE("Throw", null, function AST_Throw(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `throw` statement"
        }, AST_Exit);
        var AST_LoopControl = DEFNODE("LoopControl", "label", function AST_LoopControl(props) {
            if (props) {
                this.label = props.label;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for loop control statements (`break` and `continue`)",
            $propdoc: {
                label: "[AST_LabelRef?] the label, or null if none",
            },
            _walk: function (visitor) {
                return visitor._visit(this, this.label && function () {
                    this.label._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.label)
                    push(this.label);
            },
        }, AST_Jump);
        var AST_Break = DEFNODE("Break", null, function AST_Break(props) {
            if (props) {
                this.label = props.label;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `break` statement"
        }, AST_LoopControl);
        var AST_Continue = DEFNODE("Continue", null, function AST_Continue(props) {
            if (props) {
                this.label = props.label;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `continue` statement"
        }, AST_LoopControl);
        var AST_Await = DEFNODE("Await", "expression", function AST_Await(props) {
            if (props) {
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An `await` statement",
            $propdoc: {
                expression: "[AST_Node] the mandatory expression being awaited",
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        });
        var AST_Yield = DEFNODE("Yield", "expression is_star", function AST_Yield(props) {
            if (props) {
                this.expression = props.expression;
                this.is_star = props.is_star;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `yield` statement",
            $propdoc: {
                expression: "[AST_Node?] the value returned or thrown by this statement; could be null (representing undefined) but only when is_star is set to false",
                is_star: "[Boolean] Whether this is a yield or yield* statement"
            },
            _walk: function (visitor) {
                return visitor._visit(this, this.expression && function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.expression)
                    push(this.expression);
            }
        });
        /* -----[ IF ]----- */
        var AST_If = DEFNODE("If", "condition alternative", function AST_If(props) {
            if (props) {
                this.condition = props.condition;
                this.alternative = props.alternative;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `if` statement",
            $propdoc: {
                condition: "[AST_Node] the `if` condition",
                alternative: "[AST_Statement?] the `else` part, or null if not present"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.condition._walk(visitor);
                    this.body._walk(visitor);
                    if (this.alternative)
                        this.alternative._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.alternative) {
                    push(this.alternative);
                }
                push(this.body);
                push(this.condition);
            }
        }, AST_StatementWithBody);
        /* -----[ SWITCH ]----- */
        var AST_Switch = DEFNODE("Switch", "expression", function AST_Switch(props) {
            if (props) {
                this.expression = props.expression;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `switch` statement",
            $propdoc: {
                expression: "[AST_Node] the `switch` “discriminant”"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
                push(this.expression);
            }
        }, AST_Block);
        var AST_SwitchBranch = DEFNODE("SwitchBranch", null, function AST_SwitchBranch(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for `switch` branches",
        }, AST_Block);
        var AST_Default = DEFNODE("Default", null, function AST_Default(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `default` switch branch",
        }, AST_SwitchBranch);
        var AST_Case = DEFNODE("Case", "expression", function AST_Case(props) {
            if (props) {
                this.expression = props.expression;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `case` switch branch",
            $propdoc: {
                expression: "[AST_Node] the `case` expression"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
                push(this.expression);
            },
        }, AST_SwitchBranch);
        /* -----[ EXCEPTIONS ]----- */
        var AST_Try = DEFNODE("Try", "body bcatch bfinally", function AST_Try(props) {
            if (props) {
                this.body = props.body;
                this.bcatch = props.bcatch;
                this.bfinally = props.bfinally;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `try` statement",
            $propdoc: {
                body: "[AST_TryBlock] the try block",
                bcatch: "[AST_Catch?] the catch block, or null if not present",
                bfinally: "[AST_Finally?] the finally block, or null if not present"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.body._walk(visitor);
                    if (this.bcatch)
                        this.bcatch._walk(visitor);
                    if (this.bfinally)
                        this.bfinally._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.bfinally)
                    push(this.bfinally);
                if (this.bcatch)
                    push(this.bcatch);
                push(this.body);
            },
        }, AST_Statement);
        var AST_TryBlock = DEFNODE("TryBlock", null, function AST_TryBlock(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `try` block of a try statement"
        }, AST_Block);
        var AST_Catch = DEFNODE("Catch", "argname", function AST_Catch(props) {
            if (props) {
                this.argname = props.argname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `catch` node; only makes sense as part of a `try` statement",
            $propdoc: {
                argname: "[AST_SymbolCatch|AST_Destructuring|AST_Expansion|AST_DefaultAssign] symbol for the exception"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.argname)
                        this.argname._walk(visitor);
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
                if (this.argname)
                    push(this.argname);
            },
        }, AST_Block);
        var AST_Finally = DEFNODE("Finally", null, function AST_Finally(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `finally` node; only makes sense as part of a `try` statement"
        }, AST_Block);
        /* -----[ VAR/CONST ]----- */
        var AST_Definitions = DEFNODE("Definitions", "definitions", function AST_Definitions(props) {
            if (props) {
                this.definitions = props.definitions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for `var` or `const` nodes (variable declarations/initializations)",
            $propdoc: {
                definitions: "[AST_VarDef*] array of variable definitions"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    var definitions = this.definitions;
                    for (var i = 0, len = definitions.length; i < len; i++) {
                        definitions[i]._walk(visitor);
                    }
                });
            },
            _children_backwards(push) {
                let i = this.definitions.length;
                while (i--)
                    push(this.definitions[i]);
            },
        }, AST_Statement);
        var AST_Var = DEFNODE("Var", null, function AST_Var(props) {
            if (props) {
                this.definitions = props.definitions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `var` statement"
        }, AST_Definitions);
        var AST_Let = DEFNODE("Let", null, function AST_Let(props) {
            if (props) {
                this.definitions = props.definitions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `let` statement"
        }, AST_Definitions);
        var AST_Const = DEFNODE("Const", null, function AST_Const(props) {
            if (props) {
                this.definitions = props.definitions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `const` statement"
        }, AST_Definitions);
        var AST_VarDef = DEFNODE("VarDef", "name value", function AST_VarDef(props) {
            if (props) {
                this.name = props.name;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A variable declaration; only appears in a AST_Definitions node",
            $propdoc: {
                name: "[AST_Destructuring|AST_SymbolConst|AST_SymbolLet|AST_SymbolVar] name of the variable",
                value: "[AST_Node?] initializer, or null of there's no initializer"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.name._walk(visitor);
                    if (this.value)
                        this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.value)
                    push(this.value);
                push(this.name);
            },
        });
        var AST_NameMapping = DEFNODE("NameMapping", "foreign_name name", function AST_NameMapping(props) {
            if (props) {
                this.foreign_name = props.foreign_name;
                this.name = props.name;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The part of the export/import statement that declare names from a module.",
            $propdoc: {
                foreign_name: "[AST_SymbolExportForeign|AST_SymbolImportForeign] The name being exported/imported (as specified in the module)",
                name: "[AST_SymbolExport|AST_SymbolImport] The name as it is visible to this module."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.foreign_name._walk(visitor);
                    this.name._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.name);
                push(this.foreign_name);
            },
        });
        var AST_Import = DEFNODE("Import", "imported_name imported_names module_name assert_clause", function AST_Import(props) {
            if (props) {
                this.imported_name = props.imported_name;
                this.imported_names = props.imported_names;
                this.module_name = props.module_name;
                this.assert_clause = props.assert_clause;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An `import` statement",
            $propdoc: {
                imported_name: "[AST_SymbolImport] The name of the variable holding the module's default export.",
                imported_names: "[AST_NameMapping*] The names of non-default imported variables",
                module_name: "[AST_String] String literal describing where this module came from",
                assert_clause: "[AST_Object?] The import assertion"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.imported_name) {
                        this.imported_name._walk(visitor);
                    }
                    if (this.imported_names) {
                        this.imported_names.forEach(function (name_import) {
                            name_import._walk(visitor);
                        });
                    }
                    this.module_name._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.module_name);
                if (this.imported_names) {
                    let i = this.imported_names.length;
                    while (i--)
                        push(this.imported_names[i]);
                }
                if (this.imported_name)
                    push(this.imported_name);
            },
        });
        var AST_ImportMeta = DEFNODE("ImportMeta", null, function AST_ImportMeta(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A reference to import.meta",
        });
        var AST_Export = DEFNODE("Export", "exported_definition exported_value is_default exported_names module_name assert_clause", function AST_Export(props) {
            if (props) {
                this.exported_definition = props.exported_definition;
                this.exported_value = props.exported_value;
                this.is_default = props.is_default;
                this.exported_names = props.exported_names;
                this.module_name = props.module_name;
                this.assert_clause = props.assert_clause;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An `export` statement",
            $propdoc: {
                exported_definition: "[AST_Defun|AST_Definitions|AST_DefClass?] An exported definition",
                exported_value: "[AST_Node?] An exported value",
                exported_names: "[AST_NameMapping*?] List of exported names",
                module_name: "[AST_String?] Name of the file to load exports from",
                is_default: "[Boolean] Whether this is the default exported value of this module",
                assert_clause: "[AST_Object?] The import assertion"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.exported_definition) {
                        this.exported_definition._walk(visitor);
                    }
                    if (this.exported_value) {
                        this.exported_value._walk(visitor);
                    }
                    if (this.exported_names) {
                        this.exported_names.forEach(function (name_export) {
                            name_export._walk(visitor);
                        });
                    }
                    if (this.module_name) {
                        this.module_name._walk(visitor);
                    }
                });
            },
            _children_backwards(push) {
                if (this.module_name)
                    push(this.module_name);
                if (this.exported_names) {
                    let i = this.exported_names.length;
                    while (i--)
                        push(this.exported_names[i]);
                }
                if (this.exported_value)
                    push(this.exported_value);
                if (this.exported_definition)
                    push(this.exported_definition);
            }
        }, AST_Statement);
        /* -----[ OTHER ]----- */
        var AST_Call = DEFNODE("Call", "expression args optional _annotations", function AST_Call(props) {
            if (props) {
                this.expression = props.expression;
                this.args = props.args;
                this.optional = props.optional;
                this._annotations = props._annotations;
                this.start = props.start;
                this.end = props.end;
                this.initialize();
            }
            this.flags = 0;
        }, {
            $documentation: "A function call expression",
            $propdoc: {
                expression: "[AST_Node] expression to invoke as function",
                args: "[AST_Node*] array of arguments",
                optional: "[boolean] whether this is an optional call (IE ?.() )",
                _annotations: "[number] bitfield containing information about the call"
            },
            initialize() {
                if (this._annotations == null)
                    this._annotations = 0;
            },
            _walk(visitor) {
                return visitor._visit(this, function () {
                    var args = this.args;
                    for (var i = 0, len = args.length; i < len; i++) {
                        args[i]._walk(visitor);
                    }
                    this.expression._walk(visitor); // TODO why do we need to crawl this last?
                });
            },
            _children_backwards(push) {
                let i = this.args.length;
                while (i--)
                    push(this.args[i]);
                push(this.expression);
            },
        });
        var AST_New = DEFNODE("New", null, function AST_New(props) {
            if (props) {
                this.expression = props.expression;
                this.args = props.args;
                this.optional = props.optional;
                this._annotations = props._annotations;
                this.start = props.start;
                this.end = props.end;
                this.initialize();
            }
            this.flags = 0;
        }, {
            $documentation: "An object instantiation.  Derives from a function call since it has exactly the same properties"
        }, AST_Call);
        var AST_Sequence = DEFNODE("Sequence", "expressions", function AST_Sequence(props) {
            if (props) {
                this.expressions = props.expressions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A sequence expression (comma-separated expressions)",
            $propdoc: {
                expressions: "[AST_Node*] array of expressions (at least two)"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expressions.forEach(function (node) {
                        node._walk(visitor);
                    });
                });
            },
            _children_backwards(push) {
                let i = this.expressions.length;
                while (i--)
                    push(this.expressions[i]);
            },
        });
        var AST_PropAccess = DEFNODE("PropAccess", "expression property optional", function AST_PropAccess(props) {
            if (props) {
                this.expression = props.expression;
                this.property = props.property;
                this.optional = props.optional;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for property access expressions, i.e. `a.foo` or `a[\"foo\"]`",
            $propdoc: {
                expression: "[AST_Node] the “container” expression",
                property: "[AST_Node|string] the property to access.  For AST_Dot & AST_DotHash this is always a plain string, while for AST_Sub it's an arbitrary AST_Node",
                optional: "[boolean] whether this is an optional property access (IE ?.)"
            }
        });
        var AST_Dot = DEFNODE("Dot", "quote", function AST_Dot(props) {
            if (props) {
                this.quote = props.quote;
                this.expression = props.expression;
                this.property = props.property;
                this.optional = props.optional;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A dotted property access expression",
            $propdoc: {
                quote: "[string] the original quote character when transformed from AST_Sub",
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        }, AST_PropAccess);
        var AST_DotHash = DEFNODE("DotHash", "", function AST_DotHash(props) {
            if (props) {
                this.expression = props.expression;
                this.property = props.property;
                this.optional = props.optional;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A dotted property access to a private property",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        }, AST_PropAccess);
        var AST_Sub = DEFNODE("Sub", null, function AST_Sub(props) {
            if (props) {
                this.expression = props.expression;
                this.property = props.property;
                this.optional = props.optional;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Index-style property access, i.e. `a[\"foo\"]`",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                    this.property._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.property);
                push(this.expression);
            },
        }, AST_PropAccess);
        var AST_Chain = DEFNODE("Chain", "expression", function AST_Chain(props) {
            if (props) {
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A chain expression like a?.b?.(c)?.[d]",
            $propdoc: {
                expression: "[AST_Call|AST_Dot|AST_DotHash|AST_Sub] chain element."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        });
        var AST_Unary = DEFNODE("Unary", "operator expression", function AST_Unary(props) {
            if (props) {
                this.operator = props.operator;
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for unary expressions",
            $propdoc: {
                operator: "[string] the operator",
                expression: "[AST_Node] expression that this unary operator applies to"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        });
        var AST_UnaryPrefix = DEFNODE("UnaryPrefix", null, function AST_UnaryPrefix(props) {
            if (props) {
                this.operator = props.operator;
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Unary prefix expression, i.e. `typeof i` or `++i`"
        }, AST_Unary);
        var AST_UnaryPostfix = DEFNODE("UnaryPostfix", null, function AST_UnaryPostfix(props) {
            if (props) {
                this.operator = props.operator;
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Unary postfix expression, i.e. `i++`"
        }, AST_Unary);
        var AST_Binary = DEFNODE("Binary", "operator left right", function AST_Binary(props) {
            if (props) {
                this.operator = props.operator;
                this.left = props.left;
                this.right = props.right;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Binary expression, i.e. `a + b`",
            $propdoc: {
                left: "[AST_Node] left-hand side expression",
                operator: "[string] the operator",
                right: "[AST_Node] right-hand side expression"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.left._walk(visitor);
                    this.right._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.right);
                push(this.left);
            },
        });
        var AST_Conditional = DEFNODE("Conditional", "condition consequent alternative", function AST_Conditional(props) {
            if (props) {
                this.condition = props.condition;
                this.consequent = props.consequent;
                this.alternative = props.alternative;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Conditional expression using the ternary operator, i.e. `a ? b : c`",
            $propdoc: {
                condition: "[AST_Node]",
                consequent: "[AST_Node]",
                alternative: "[AST_Node]"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.condition._walk(visitor);
                    this.consequent._walk(visitor);
                    this.alternative._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.alternative);
                push(this.consequent);
                push(this.condition);
            },
        });
        var AST_Assign = DEFNODE("Assign", "logical", function AST_Assign(props) {
            if (props) {
                this.logical = props.logical;
                this.operator = props.operator;
                this.left = props.left;
                this.right = props.right;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An assignment expression — `a = b + 5`",
            $propdoc: {
                logical: "Whether it's a logical assignment"
            }
        }, AST_Binary);
        var AST_DefaultAssign = DEFNODE("DefaultAssign", null, function AST_DefaultAssign(props) {
            if (props) {
                this.operator = props.operator;
                this.left = props.left;
                this.right = props.right;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A default assignment expression like in `(a = 3) => a`"
        }, AST_Binary);
        /* -----[ LITERALS ]----- */
        var AST_Array = DEFNODE("Array", "elements", function AST_Array(props) {
            if (props) {
                this.elements = props.elements;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An array literal",
            $propdoc: {
                elements: "[AST_Node*] array of elements"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    var elements = this.elements;
                    for (var i = 0, len = elements.length; i < len; i++) {
                        elements[i]._walk(visitor);
                    }
                });
            },
            _children_backwards(push) {
                let i = this.elements.length;
                while (i--)
                    push(this.elements[i]);
            },
        });
        var AST_Object = DEFNODE("Object", "properties", function AST_Object(props) {
            if (props) {
                this.properties = props.properties;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An object literal",
            $propdoc: {
                properties: "[AST_ObjectProperty*] array of properties"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    var properties = this.properties;
                    for (var i = 0, len = properties.length; i < len; i++) {
                        properties[i]._walk(visitor);
                    }
                });
            },
            _children_backwards(push) {
                let i = this.properties.length;
                while (i--)
                    push(this.properties[i]);
            },
        });
        var AST_ObjectProperty = DEFNODE("ObjectProperty", "key value", function AST_ObjectProperty(props) {
            if (props) {
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for literal object properties",
            $propdoc: {
                key: "[string|AST_Node] property name. For ObjectKeyVal this is a string. For getters, setters and computed property this is an AST_Node.",
                value: "[AST_Node] property value.  For getters and setters this is an AST_Accessor."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.key instanceof AST_Node)
                        this.key._walk(visitor);
                    this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.value);
                if (this.key instanceof AST_Node)
                    push(this.key);
            }
        });
        var AST_ObjectKeyVal = DEFNODE("ObjectKeyVal", "quote", function AST_ObjectKeyVal(props) {
            if (props) {
                this.quote = props.quote;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A key: value object property",
            $propdoc: {
                quote: "[string] the original quote character"
            },
            computed_key() {
                return this.key instanceof AST_Node;
            }
        }, AST_ObjectProperty);
        var AST_PrivateSetter = DEFNODE("PrivateSetter", "static", function AST_PrivateSetter(props) {
            if (props) {
                this.static = props.static;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                static: "[boolean] whether this is a static private setter"
            },
            $documentation: "A private setter property",
            computed_key() {
                return false;
            }
        }, AST_ObjectProperty);
        var AST_PrivateGetter = DEFNODE("PrivateGetter", "static", function AST_PrivateGetter(props) {
            if (props) {
                this.static = props.static;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                static: "[boolean] whether this is a static private getter"
            },
            $documentation: "A private getter property",
            computed_key() {
                return false;
            }
        }, AST_ObjectProperty);
        var AST_ObjectSetter = DEFNODE("ObjectSetter", "quote static", function AST_ObjectSetter(props) {
            if (props) {
                this.quote = props.quote;
                this.static = props.static;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                quote: "[string|undefined] the original quote character, if any",
                static: "[boolean] whether this is a static setter (classes only)"
            },
            $documentation: "An object setter property",
            computed_key() {
                return !(this.key instanceof AST_SymbolMethod);
            }
        }, AST_ObjectProperty);
        var AST_ObjectGetter = DEFNODE("ObjectGetter", "quote static", function AST_ObjectGetter(props) {
            if (props) {
                this.quote = props.quote;
                this.static = props.static;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                quote: "[string|undefined] the original quote character, if any",
                static: "[boolean] whether this is a static getter (classes only)"
            },
            $documentation: "An object getter property",
            computed_key() {
                return !(this.key instanceof AST_SymbolMethod);
            }
        }, AST_ObjectProperty);
        var AST_ConciseMethod = DEFNODE("ConciseMethod", "quote static is_generator async", function AST_ConciseMethod(props) {
            if (props) {
                this.quote = props.quote;
                this.static = props.static;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                quote: "[string|undefined] the original quote character, if any",
                static: "[boolean] is this method static (classes only)",
                is_generator: "[boolean] is this a generator method",
                async: "[boolean] is this method async",
            },
            $documentation: "An ES6 concise method inside an object or class",
            computed_key() {
                return !(this.key instanceof AST_SymbolMethod);
            }
        }, AST_ObjectProperty);
        var AST_PrivateMethod = DEFNODE("PrivateMethod", "", function AST_PrivateMethod(props) {
            if (props) {
                this.quote = props.quote;
                this.static = props.static;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A private class method inside a class",
        }, AST_ConciseMethod);
        var AST_Class = DEFNODE("Class", "name extends properties", function AST_Class(props) {
            if (props) {
                this.name = props.name;
                this.extends = props.extends;
                this.properties = props.properties;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                name: "[AST_SymbolClass|AST_SymbolDefClass?] optional class name.",
                extends: "[AST_Node]? optional parent class",
                properties: "[AST_ObjectProperty*] array of properties"
            },
            $documentation: "An ES6 class",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.name) {
                        this.name._walk(visitor);
                    }
                    if (this.extends) {
                        this.extends._walk(visitor);
                    }
                    this.properties.forEach((prop) => prop._walk(visitor));
                });
            },
            _children_backwards(push) {
                let i = this.properties.length;
                while (i--)
                    push(this.properties[i]);
                if (this.extends)
                    push(this.extends);
                if (this.name)
                    push(this.name);
            },
        }, AST_Scope /* TODO a class might have a scope but it's not a scope */);
        var AST_ClassProperty = DEFNODE("ClassProperty", "static quote", function AST_ClassProperty(props) {
            if (props) {
                this.static = props.static;
                this.quote = props.quote;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A class property",
            $propdoc: {
                static: "[boolean] whether this is a static key",
                quote: "[string] which quote is being used"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.key instanceof AST_Node)
                        this.key._walk(visitor);
                    if (this.value instanceof AST_Node)
                        this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.value instanceof AST_Node)
                    push(this.value);
                if (this.key instanceof AST_Node)
                    push(this.key);
            },
            computed_key() {
                return !(this.key instanceof AST_SymbolClassProperty);
            }
        }, AST_ObjectProperty);
        var AST_ClassPrivateProperty = DEFNODE("ClassPrivateProperty", "", function AST_ClassPrivateProperty(props) {
            if (props) {
                this.static = props.static;
                this.quote = props.quote;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A class property for a private property",
        }, AST_ClassProperty);
        var AST_PrivateIn = DEFNODE("PrivateIn", "key value", function AST_PrivateIn(props) {
            if (props) {
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An `in` binop when the key is private, eg #x in this",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.key._walk(visitor);
                    this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.value);
                push(this.key);
            },
        });
        var AST_DefClass = DEFNODE("DefClass", null, function AST_DefClass(props) {
            if (props) {
                this.name = props.name;
                this.extends = props.extends;
                this.properties = props.properties;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A class definition",
        }, AST_Class);
        var AST_ClassStaticBlock = DEFNODE("ClassStaticBlock", "body block_scope", function AST_ClassStaticBlock(props) {
            this.body = props.body;
            this.block_scope = props.block_scope;
            this.start = props.start;
            this.end = props.end;
        }, {
            $documentation: "A block containing statements to be executed in the context of the class",
            $propdoc: {
                body: "[AST_Statement*] an array of statements",
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
            },
            clone: clone_block_scope,
        }, AST_Scope);
        var AST_ClassExpression = DEFNODE("ClassExpression", null, function AST_ClassExpression(props) {
            if (props) {
                this.name = props.name;
                this.extends = props.extends;
                this.properties = props.properties;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A class expression."
        }, AST_Class);
        var AST_Symbol = DEFNODE("Symbol", "scope name thedef", function AST_Symbol(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                name: "[string] name of this symbol",
                scope: "[AST_Scope/S] the current scope (not necessarily the definition scope)",
                thedef: "[SymbolDef/S] the definition of this symbol"
            },
            $documentation: "Base class for all symbols"
        });
        var AST_NewTarget = DEFNODE("NewTarget", null, function AST_NewTarget(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A reference to new.target"
        });
        var AST_SymbolDeclaration = DEFNODE("SymbolDeclaration", "init", function AST_SymbolDeclaration(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A declaration symbol (symbol in var/const, function name or argument, symbol in catch)",
        }, AST_Symbol);
        var AST_SymbolVar = DEFNODE("SymbolVar", null, function AST_SymbolVar(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol defining a variable",
        }, AST_SymbolDeclaration);
        var AST_SymbolBlockDeclaration = DEFNODE("SymbolBlockDeclaration", null, function AST_SymbolBlockDeclaration(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for block-scoped declaration symbols"
        }, AST_SymbolDeclaration);
        var AST_SymbolConst = DEFNODE("SymbolConst", null, function AST_SymbolConst(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A constant declaration"
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolLet = DEFNODE("SymbolLet", null, function AST_SymbolLet(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A block-scoped `let` declaration"
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolFunarg = DEFNODE("SymbolFunarg", null, function AST_SymbolFunarg(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a function argument",
        }, AST_SymbolVar);
        var AST_SymbolDefun = DEFNODE("SymbolDefun", null, function AST_SymbolDefun(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol defining a function",
        }, AST_SymbolDeclaration);
        var AST_SymbolMethod = DEFNODE("SymbolMethod", null, function AST_SymbolMethod(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol in an object defining a method",
        }, AST_Symbol);
        var AST_SymbolClassProperty = DEFNODE("SymbolClassProperty", null, function AST_SymbolClassProperty(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol for a class property",
        }, AST_Symbol);
        var AST_SymbolLambda = DEFNODE("SymbolLambda", null, function AST_SymbolLambda(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a function expression",
        }, AST_SymbolDeclaration);
        var AST_SymbolDefClass = DEFNODE("SymbolDefClass", null, function AST_SymbolDefClass(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a class's name in a class declaration. Lexically scoped to its containing scope, and accessible within the class."
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolClass = DEFNODE("SymbolClass", null, function AST_SymbolClass(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a class's name. Lexically scoped to the class."
        }, AST_SymbolDeclaration);
        var AST_SymbolCatch = DEFNODE("SymbolCatch", null, function AST_SymbolCatch(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming the exception in catch",
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolImport = DEFNODE("SymbolImport", null, function AST_SymbolImport(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol referring to an imported name",
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolImportForeign = DEFNODE("SymbolImportForeign", null, function AST_SymbolImportForeign(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A symbol imported from a module, but it is defined in the other module, and its real name is irrelevant for this module's purposes",
        }, AST_Symbol);
        var AST_Label = DEFNODE("Label", "references", function AST_Label(props) {
            if (props) {
                this.references = props.references;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
                this.initialize();
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a label (declaration)",
            $propdoc: {
                references: "[AST_LoopControl*] a list of nodes referring to this label"
            },
            initialize: function () {
                this.references = [];
                this.thedef = this;
            }
        }, AST_Symbol);
        var AST_SymbolRef = DEFNODE("SymbolRef", null, function AST_SymbolRef(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Reference to some symbol (not definition/declaration)",
        }, AST_Symbol);
        var AST_SymbolExport = DEFNODE("SymbolExport", null, function AST_SymbolExport(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol referring to a name to export",
        }, AST_SymbolRef);
        var AST_SymbolExportForeign = DEFNODE("SymbolExportForeign", null, function AST_SymbolExportForeign(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A symbol exported from this module, but it is used in the other module, and its real name is irrelevant for this module's purposes",
        }, AST_Symbol);
        var AST_LabelRef = DEFNODE("LabelRef", null, function AST_LabelRef(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Reference to a label symbol",
        }, AST_Symbol);
        var AST_SymbolPrivateProperty = DEFNODE("SymbolPrivateProperty", null, function AST_SymbolPrivateProperty(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A symbol that refers to a private property",
        }, AST_Symbol);
        var AST_This = DEFNODE("This", null, function AST_This(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `this` symbol",
        }, AST_Symbol);
        var AST_Super = DEFNODE("Super", null, function AST_Super(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `super` symbol",
        }, AST_This);
        var AST_Constant = DEFNODE("Constant", null, function AST_Constant(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for all constants",
            getValue: function () {
                return this.value;
            }
        });
        var AST_String = DEFNODE("String", "value quote", function AST_String(props) {
            if (props) {
                this.value = props.value;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A string literal",
            $propdoc: {
                value: "[string] the contents of this string",
                quote: "[string] the original quote character"
            }
        }, AST_Constant);
        var AST_Number = DEFNODE("Number", "value raw", function AST_Number(props) {
            if (props) {
                this.value = props.value;
                this.raw = props.raw;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A number literal",
            $propdoc: {
                value: "[number] the numeric value",
                raw: "[string] numeric value as string"
            }
        }, AST_Constant);
        var AST_BigInt = DEFNODE("BigInt", "value", function AST_BigInt(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A big int literal",
            $propdoc: {
                value: "[string] big int value"
            }
        }, AST_Constant);
        var AST_RegExp = DEFNODE("RegExp", "value", function AST_RegExp(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A regexp literal",
            $propdoc: {
                value: "[RegExp] the actual regexp",
            }
        }, AST_Constant);
        var AST_Atom = DEFNODE("Atom", null, function AST_Atom(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for atoms",
        }, AST_Constant);
        var AST_Null = DEFNODE("Null", null, function AST_Null(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `null` atom",
            value: null
        }, AST_Atom);
        var AST_NaN = DEFNODE("NaN", null, function AST_NaN(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The impossible value",
            value: 0 / 0
        }, AST_Atom);
        var AST_Undefined = DEFNODE("Undefined", null, function AST_Undefined(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `undefined` value",
            value: (function () { }())
        }, AST_Atom);
        var AST_Hole = DEFNODE("Hole", null, function AST_Hole(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A hole in an array",
            value: (function () { }())
        }, AST_Atom);
        var AST_Infinity = DEFNODE("Infinity", null, function AST_Infinity(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `Infinity` value",
            value: 1 / 0
        }, AST_Atom);
        var AST_Boolean = DEFNODE("Boolean", null, function AST_Boolean(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for booleans",
        }, AST_Atom);
        var AST_False = DEFNODE("False", null, function AST_False(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `false` atom",
            value: false
        }, AST_Boolean);
        var AST_True = DEFNODE("True", null, function AST_True(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `true` atom",
            value: true
        }, AST_Boolean);
        /* -----[ Walk function ]---- */
        /**
         * Walk nodes in depth-first search fashion.
         * Callback can return `walk_abort` symbol to stop iteration.
         * It can also return `true` to stop iteration just for child nodes.
         * Iteration can be stopped and continued by passing the `to_visit` argument,
         * which is given to the callback in the second argument.
         **/
        function walk(node, cb, to_visit = [node]) {
            const push = to_visit.push.bind(to_visit);
            while (to_visit.length) {
                const node = to_visit.pop();
                const ret = cb(node, to_visit);
                if (ret) {
                    if (ret === walk_abort)
                        return true;
                    continue;
                }
                node._children_backwards(push);
            }
            return false;
        }
        /**
         * Walks an AST node and its children.
         *
         * {cb} can return `walk_abort` to interrupt the walk.
         *
         * @param node
         * @param cb {(node, info: { parent: (nth) => any }) => (boolean | undefined)}
         *
         * @returns {boolean} whether the walk was aborted
         *
         * @example
         * const found_some_cond = walk_parent(my_ast_node, (node, { parent }) => {
         *   if (some_cond(node, parent())) return walk_abort
         * });
         */
        function walk_parent(node, cb, initial_stack) {
            const to_visit = [node];
            const push = to_visit.push.bind(to_visit);
            const stack = initial_stack ? initial_stack.slice() : [];
            const parent_pop_indices = [];
            let current;
            const info = {
                parent: (n = 0) => {
                    if (n === -1) {
                        return current;
                    }
                    // [ p1 p0 ] [ 1 0 ]
                    if (initial_stack && n >= stack.length) {
                        n -= stack.length;
                        return initial_stack[initial_stack.length - (n + 1)];
                    }
                    return stack[stack.length - (1 + n)];
                },
            };
            while (to_visit.length) {
                current = to_visit.pop();
                while (parent_pop_indices.length &&
                    to_visit.length == parent_pop_indices[parent_pop_indices.length - 1]) {
                    stack.pop();
                    parent_pop_indices.pop();
                }
                const ret = cb(current, info);
                if (ret) {
                    if (ret === walk_abort)
                        return true;
                    continue;
                }
                const visit_length = to_visit.length;
                current._children_backwards(push);
                // Push only if we're going to traverse the children
                if (to_visit.length > visit_length) {
                    stack.push(current);
                    parent_pop_indices.push(visit_length - 1);
                }
            }
            return false;
        }
        const walk_abort = Symbol("abort walk");
        /* -----[ TreeWalker ]----- */
        class TreeWalker {
            constructor(callback, { walk_defun_first = false } = {}) {
                this.visit = callback;
                this.stack = [];
                this.directives = Object.create(null);
                this.walk_defun_first = walk_defun_first;
            }
            _visit(node, descend) {
                this.push(node);
                var ret = this.visit(node, descend ? function () {
                    descend.call(node);
                } : noop);
                if (!ret && descend) {
                    descend.call(node);
                }
                this.pop();
                return ret;
            }
            parent(n) {
                return this.stack[this.stack.length - 2 - (n || 0)];
            }
            push(node) {
                if (node instanceof AST_Lambda) {
                    this.directives = Object.create(this.directives);
                }
                else if (node instanceof AST_Directive && !this.directives[node.value]) {
                    this.directives[node.value] = node;
                }
                else if (node instanceof AST_Class) {
                    this.directives = Object.create(this.directives);
                    if (!this.directives["use strict"]) {
                        this.directives["use strict"] = node;
                    }
                }
                this.stack.push(node);
            }
            pop() {
                var node = this.stack.pop();
                if (node instanceof AST_Lambda || node instanceof AST_Class) {
                    this.directives = Object.getPrototypeOf(this.directives);
                }
            }
            self() {
                return this.stack[this.stack.length - 1];
            }
            find_parent(type) {
                var stack = this.stack;
                for (var i = stack.length; --i >= 0;) {
                    var x = stack[i];
                    if (x instanceof type)
                        return x;
                }
            }
            find_scope() {
                var stack = this.stack;
                for (var i = stack.length; --i >= 0;) {
                    const p = stack[i];
                    if (p instanceof AST_Toplevel)
                        return p;
                    if (p instanceof AST_Lambda)
                        return p;
                    if (p.block_scope)
                        return p.block_scope;
                }
            }
            has_directive(type) {
                var dir = this.directives[type];
                if (dir)
                    return dir;
                var node = this.stack[this.stack.length - 1];
                if (node instanceof AST_Scope && node.body) {
                    for (var i = 0; i < node.body.length; ++i) {
                        var st = node.body[i];
                        if (!(st instanceof AST_Directive))
                            break;
                        if (st.value == type)
                            return st;
                    }
                }
            }
            loopcontrol_target(node) {
                var stack = this.stack;
                if (node.label)
                    for (var i = stack.length; --i >= 0;) {
                        var x = stack[i];
                        if (x instanceof AST_LabeledStatement && x.label.name == node.label.name)
                            return x.body;
                    }
                else
                    for (var i = stack.length; --i >= 0;) {
                        var x = stack[i];
                        if (x instanceof AST_IterationStatement
                            || node instanceof AST_Break && x instanceof AST_Switch)
                            return x;
                    }
            }
        }
        // Tree transformer helpers.
        class TreeTransformer extends TreeWalker {
            constructor(before, after) {
                super();
                this.before = before;
                this.after = after;
            }
        }
        const _PURE = 0b00000001;
        const _INLINE = 0b00000010;
        const _NOINLINE = 0b00000100;
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function def_transform(node, descend) {
            node.DEFMETHOD("transform", function (tw, in_list) {
                let transformed = undefined;
                tw.push(this);
                if (tw.before)
                    transformed = tw.before(this, descend, in_list);
                if (transformed === undefined) {
                    transformed = this;
                    descend(transformed, tw);
                    if (tw.after) {
                        const after_ret = tw.after(transformed, in_list);
                        if (after_ret !== undefined)
                            transformed = after_ret;
                    }
                }
                tw.pop();
                return transformed;
            });
        }
        def_transform(AST_Node, noop);
        def_transform(AST_LabeledStatement, function (self, tw) {
            self.label = self.label.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_SimpleStatement, function (self, tw) {
            self.body = self.body.transform(tw);
        });
        def_transform(AST_Block, function (self, tw) {
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Do, function (self, tw) {
            self.body = self.body.transform(tw);
            self.condition = self.condition.transform(tw);
        });
        def_transform(AST_While, function (self, tw) {
            self.condition = self.condition.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_For, function (self, tw) {
            if (self.init)
                self.init = self.init.transform(tw);
            if (self.condition)
                self.condition = self.condition.transform(tw);
            if (self.step)
                self.step = self.step.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_ForIn, function (self, tw) {
            self.init = self.init.transform(tw);
            self.object = self.object.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_With, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_Exit, function (self, tw) {
            if (self.value)
                self.value = self.value.transform(tw);
        });
        def_transform(AST_LoopControl, function (self, tw) {
            if (self.label)
                self.label = self.label.transform(tw);
        });
        def_transform(AST_If, function (self, tw) {
            self.condition = self.condition.transform(tw);
            self.body = self.body.transform(tw);
            if (self.alternative)
                self.alternative = self.alternative.transform(tw);
        });
        def_transform(AST_Switch, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Case, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Try, function (self, tw) {
            self.body = self.body.transform(tw);
            if (self.bcatch)
                self.bcatch = self.bcatch.transform(tw);
            if (self.bfinally)
                self.bfinally = self.bfinally.transform(tw);
        });
        def_transform(AST_Catch, function (self, tw) {
            if (self.argname)
                self.argname = self.argname.transform(tw);
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Definitions, function (self, tw) {
            self.definitions = MAP(self.definitions, tw);
        });
        def_transform(AST_VarDef, function (self, tw) {
            self.name = self.name.transform(tw);
            if (self.value)
                self.value = self.value.transform(tw);
        });
        def_transform(AST_Destructuring, function (self, tw) {
            self.names = MAP(self.names, tw);
        });
        def_transform(AST_Lambda, function (self, tw) {
            if (self.name)
                self.name = self.name.transform(tw);
            self.argnames = MAP(self.argnames, tw, /* allow_splicing */ false);
            if (self.body instanceof AST_Node) {
                self.body = self.body.transform(tw);
            }
            else {
                self.body = MAP(self.body, tw);
            }
        });
        def_transform(AST_Call, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.args = MAP(self.args, tw, /* allow_splicing */ false);
        });
        def_transform(AST_Sequence, function (self, tw) {
            const result = MAP(self.expressions, tw);
            self.expressions = result.length
                ? result
                : [new AST_Number({ value: 0 })];
        });
        def_transform(AST_PropAccess, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Sub, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.property = self.property.transform(tw);
        });
        def_transform(AST_Chain, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Yield, function (self, tw) {
            if (self.expression)
                self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Await, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Unary, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Binary, function (self, tw) {
            self.left = self.left.transform(tw);
            self.right = self.right.transform(tw);
        });
        def_transform(AST_PrivateIn, function (self, tw) {
            self.key = self.key.transform(tw);
            self.value = self.value.transform(tw);
        });
        def_transform(AST_Conditional, function (self, tw) {
            self.condition = self.condition.transform(tw);
            self.consequent = self.consequent.transform(tw);
            self.alternative = self.alternative.transform(tw);
        });
        def_transform(AST_Array, function (self, tw) {
            self.elements = MAP(self.elements, tw);
        });
        def_transform(AST_Object, function (self, tw) {
            self.properties = MAP(self.properties, tw);
        });
        def_transform(AST_ObjectProperty, function (self, tw) {
            if (self.key instanceof AST_Node) {
                self.key = self.key.transform(tw);
            }
            if (self.value)
                self.value = self.value.transform(tw);
        });
        def_transform(AST_Class, function (self, tw) {
            if (self.name)
                self.name = self.name.transform(tw);
            if (self.extends)
                self.extends = self.extends.transform(tw);
            self.properties = MAP(self.properties, tw);
        });
        def_transform(AST_ClassStaticBlock, function (self, tw) {
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Expansion, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_NameMapping, function (self, tw) {
            self.foreign_name = self.foreign_name.transform(tw);
            self.name = self.name.transform(tw);
        });
        def_transform(AST_Import, function (self, tw) {
            if (self.imported_name)
                self.imported_name = self.imported_name.transform(tw);
            if (self.imported_names)
                MAP(self.imported_names, tw);
            self.module_name = self.module_name.transform(tw);
        });
        def_transform(AST_Export, function (self, tw) {
            if (self.exported_definition)
                self.exported_definition = self.exported_definition.transform(tw);
            if (self.exported_value)
                self.exported_value = self.exported_value.transform(tw);
            if (self.exported_names)
                MAP(self.exported_names, tw);
            if (self.module_name)
                self.module_name = self.module_name.transform(tw);
        });
        def_transform(AST_TemplateString, function (self, tw) {
            self.segments = MAP(self.segments, tw);
        });
        def_transform(AST_PrefixedTemplateString, function (self, tw) {
            self.prefix = self.prefix.transform(tw);
            self.template_string = self.template_string.transform(tw);
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        (function () {
            var normalize_directives = function (body) {
                var in_directive = true;
                for (var i = 0; i < body.length; i++) {
                    if (in_directive && body[i] instanceof AST_Statement && body[i].body instanceof AST_String) {
                        body[i] = new AST_Directive({
                            start: body[i].start,
                            end: body[i].end,
                            value: body[i].body.value
                        });
                    }
                    else if (in_directive && !(body[i] instanceof AST_Statement && body[i].body instanceof AST_String)) {
                        in_directive = false;
                    }
                }
                return body;
            };
            const assert_clause_from_moz = (assertions) => {
                if (assertions && assertions.length > 0) {
                    return new AST_Object({
                        start: my_start_token(assertions),
                        end: my_end_token(assertions),
                        properties: assertions.map((assertion_kv) => new AST_ObjectKeyVal({
                            start: my_start_token(assertion_kv),
                            end: my_end_token(assertion_kv),
                            key: assertion_kv.key.name || assertion_kv.key.value,
                            value: from_moz(assertion_kv.value)
                        }))
                    });
                }
                return null;
            };
            var MOZ_TO_ME = {
                Program: function (M) {
                    return new AST_Toplevel({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: normalize_directives(M.body.map(from_moz))
                    });
                },
                ArrayPattern: function (M) {
                    return new AST_Destructuring({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        names: M.elements.map(function (elm) {
                            if (elm === null) {
                                return new AST_Hole();
                            }
                            return from_moz(elm);
                        }),
                        is_array: true
                    });
                },
                ObjectPattern: function (M) {
                    return new AST_Destructuring({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        names: M.properties.map(from_moz),
                        is_array: false
                    });
                },
                AssignmentPattern: function (M) {
                    return new AST_DefaultAssign({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        left: from_moz(M.left),
                        operator: "=",
                        right: from_moz(M.right)
                    });
                },
                SpreadElement: function (M) {
                    return new AST_Expansion({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.argument)
                    });
                },
                RestElement: function (M) {
                    return new AST_Expansion({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.argument)
                    });
                },
                TemplateElement: function (M) {
                    return new AST_TemplateSegment({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        value: M.value.cooked,
                        raw: M.value.raw
                    });
                },
                TemplateLiteral: function (M) {
                    var segments = [];
                    for (var i = 0; i < M.quasis.length; i++) {
                        segments.push(from_moz(M.quasis[i]));
                        if (M.expressions[i]) {
                            segments.push(from_moz(M.expressions[i]));
                        }
                    }
                    return new AST_TemplateString({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        segments: segments
                    });
                },
                TaggedTemplateExpression: function (M) {
                    return new AST_PrefixedTemplateString({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        template_string: from_moz(M.quasi),
                        prefix: from_moz(M.tag)
                    });
                },
                FunctionDeclaration: function (M) {
                    return new AST_Defun({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: from_moz(M.id),
                        argnames: M.params.map(from_moz),
                        is_generator: M.generator,
                        async: M.async,
                        body: normalize_directives(from_moz(M.body).body)
                    });
                },
                FunctionExpression: function (M) {
                    return new AST_Function({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: from_moz(M.id),
                        argnames: M.params.map(from_moz),
                        is_generator: M.generator,
                        async: M.async,
                        body: normalize_directives(from_moz(M.body).body)
                    });
                },
                ArrowFunctionExpression: function (M) {
                    const body = M.body.type === "BlockStatement"
                        ? from_moz(M.body).body
                        : [make_node(AST_Return, {}, { value: from_moz(M.body) })];
                    return new AST_Arrow({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        argnames: M.params.map(from_moz),
                        body,
                        async: M.async,
                    });
                },
                ExpressionStatement: function (M) {
                    return new AST_SimpleStatement({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: from_moz(M.expression)
                    });
                },
                TryStatement: function (M) {
                    var handlers = M.handlers || [M.handler];
                    if (handlers.length > 1 || M.guardedHandlers && M.guardedHandlers.length) {
                        throw new Error("Multiple catch clauses are not supported.");
                    }
                    return new AST_Try({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: new AST_TryBlock(from_moz(M.block)),
                        bcatch: from_moz(handlers[0]),
                        bfinally: M.finalizer ? new AST_Finally(from_moz(M.finalizer)) : null
                    });
                },
                Property: function (M) {
                    var key = M.key;
                    var args = {
                        start: my_start_token(key || M.value),
                        end: my_end_token(M.value),
                        key: key.type == "Identifier" ? key.name : key.value,
                        value: from_moz(M.value)
                    };
                    if (M.computed) {
                        args.key = from_moz(M.key);
                    }
                    if (M.method) {
                        args.is_generator = M.value.generator;
                        args.async = M.value.async;
                        if (!M.computed) {
                            args.key = new AST_SymbolMethod({ name: args.key });
                        }
                        else {
                            args.key = from_moz(M.key);
                        }
                        return new AST_ConciseMethod(args);
                    }
                    if (M.kind == "init") {
                        if (key.type != "Identifier" && key.type != "Literal") {
                            args.key = from_moz(key);
                        }
                        return new AST_ObjectKeyVal(args);
                    }
                    if (typeof args.key === "string" || typeof args.key === "number") {
                        args.key = new AST_SymbolMethod({
                            name: args.key
                        });
                    }
                    args.value = new AST_Accessor(args.value);
                    if (M.kind == "get")
                        return new AST_ObjectGetter(args);
                    if (M.kind == "set")
                        return new AST_ObjectSetter(args);
                    if (M.kind == "method") {
                        args.async = M.value.async;
                        args.is_generator = M.value.generator;
                        args.quote = M.computed ? "\"" : null;
                        return new AST_ConciseMethod(args);
                    }
                },
                MethodDefinition: function (M) {
                    var args = {
                        start: my_start_token(M),
                        end: my_end_token(M),
                        key: M.computed ? from_moz(M.key) : new AST_SymbolMethod({ name: M.key.name || M.key.value }),
                        value: from_moz(M.value),
                        static: M.static,
                    };
                    if (M.kind == "get") {
                        return new AST_ObjectGetter(args);
                    }
                    if (M.kind == "set") {
                        return new AST_ObjectSetter(args);
                    }
                    args.is_generator = M.value.generator;
                    args.async = M.value.async;
                    return new AST_ConciseMethod(args);
                },
                FieldDefinition: function (M) {
                    let key;
                    if (M.computed) {
                        key = from_moz(M.key);
                    }
                    else {
                        if (M.key.type !== "Identifier")
                            throw new Error("Non-Identifier key in FieldDefinition");
                        key = from_moz(M.key);
                    }
                    return new AST_ClassProperty({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        key,
                        value: from_moz(M.value),
                        static: M.static,
                    });
                },
                PropertyDefinition: function (M) {
                    let key;
                    if (M.computed) {
                        key = from_moz(M.key);
                    }
                    else {
                        if (M.key.type !== "Identifier" && M.key.type !== "PrivateIdentifier") {
                            throw new Error("Non-Identifier key in PropertyDefinition");
                        }
                        key = from_moz(M.key);
                    }
                    return new AST_ClassProperty({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        key,
                        value: from_moz(M.value),
                        static: M.static,
                    });
                },
                StaticBlock: function (M) {
                    return new AST_ClassStaticBlock({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: M.body.map(from_moz),
                    });
                },
                ArrayExpression: function (M) {
                    return new AST_Array({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        elements: M.elements.map(function (elem) {
                            return elem === null ? new AST_Hole() : from_moz(elem);
                        })
                    });
                },
                ObjectExpression: function (M) {
                    return new AST_Object({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        properties: M.properties.map(function (prop) {
                            if (prop.type === "SpreadElement") {
                                return from_moz(prop);
                            }
                            prop.type = "Property";
                            return from_moz(prop);
                        })
                    });
                },
                SequenceExpression: function (M) {
                    return new AST_Sequence({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expressions: M.expressions.map(from_moz)
                    });
                },
                MemberExpression: function (M) {
                    return new (M.computed ? AST_Sub : AST_Dot)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        property: M.computed ? from_moz(M.property) : M.property.name,
                        expression: from_moz(M.object),
                        optional: M.optional || false
                    });
                },
                ChainExpression: function (M) {
                    return new AST_Chain({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.expression)
                    });
                },
                SwitchCase: function (M) {
                    return new (M.test ? AST_Case : AST_Default)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.test),
                        body: M.consequent.map(from_moz)
                    });
                },
                VariableDeclaration: function (M) {
                    return new (M.kind === "const" ? AST_Const :
                        M.kind === "let" ? AST_Let : AST_Var)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        definitions: M.declarations.map(from_moz)
                    });
                },
                ImportDeclaration: function (M) {
                    var imported_name = null;
                    var imported_names = null;
                    M.specifiers.forEach(function (specifier) {
                        if (specifier.type === "ImportSpecifier" || specifier.type === "ImportNamespaceSpecifier") {
                            if (!imported_names) {
                                imported_names = [];
                            }
                            imported_names.push(from_moz(specifier));
                        }
                        else if (specifier.type === "ImportDefaultSpecifier") {
                            imported_name = from_moz(specifier);
                        }
                    });
                    return new AST_Import({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        imported_name: imported_name,
                        imported_names: imported_names,
                        module_name: from_moz(M.source),
                        assert_clause: assert_clause_from_moz(M.assertions)
                    });
                },
                ImportSpecifier: function (M) {
                    return new AST_NameMapping({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        foreign_name: from_moz(M.imported),
                        name: from_moz(M.local)
                    });
                },
                ImportDefaultSpecifier: function (M) {
                    return from_moz(M.local);
                },
                ImportNamespaceSpecifier: function (M) {
                    return new AST_NameMapping({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        foreign_name: new AST_SymbolImportForeign({ name: "*" }),
                        name: from_moz(M.local)
                    });
                },
                ExportAllDeclaration: function (M) {
                    var foreign_name = M.exported == null ?
                        new AST_SymbolExportForeign({ name: "*" }) :
                        from_moz(M.exported);
                    return new AST_Export({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        exported_names: [
                            new AST_NameMapping({
                                name: new AST_SymbolExportForeign({ name: "*" }),
                                foreign_name: foreign_name
                            })
                        ],
                        module_name: from_moz(M.source),
                        assert_clause: assert_clause_from_moz(M.assertions)
                    });
                },
                ExportNamedDeclaration: function (M) {
                    return new AST_Export({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        exported_definition: from_moz(M.declaration),
                        exported_names: M.specifiers && M.specifiers.length ? M.specifiers.map(function (specifier) {
                            return from_moz(specifier);
                        }) : null,
                        module_name: from_moz(M.source),
                        assert_clause: assert_clause_from_moz(M.assertions)
                    });
                },
                ExportDefaultDeclaration: function (M) {
                    return new AST_Export({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        exported_value: from_moz(M.declaration),
                        is_default: true
                    });
                },
                ExportSpecifier: function (M) {
                    return new AST_NameMapping({
                        foreign_name: from_moz(M.exported),
                        name: from_moz(M.local)
                    });
                },
                Literal: function (M) {
                    var val = M.value, args = {
                        start: my_start_token(M),
                        end: my_end_token(M)
                    };
                    var rx = M.regex;
                    if (rx && rx.pattern) {
                        // RegExpLiteral as per ESTree AST spec
                        args.value = {
                            source: rx.pattern,
                            flags: rx.flags
                        };
                        return new AST_RegExp(args);
                    }
                    else if (rx) {
                        // support legacy RegExp
                        const rx_source = M.raw || val;
                        const match = rx_source.match(/^\/(.*)\/(\w*)$/);
                        if (!match)
                            throw new Error("Invalid regex source " + rx_source);
                        const [_, source, flags] = match;
                        args.value = { source, flags };
                        return new AST_RegExp(args);
                    }
                    if (val === null)
                        return new AST_Null(args);
                    switch (typeof val) {
                        case "string":
                            args.quote = "\"";
                            var p = FROM_MOZ_STACK[FROM_MOZ_STACK.length - 2];
                            if (p.type == "ImportSpecifier") {
                                args.name = val;
                                return new AST_SymbolImportForeign(args);
                            }
                            else if (p.type == "ExportSpecifier") {
                                args.name = val;
                                if (M == p.exported) {
                                    return new AST_SymbolExportForeign(args);
                                }
                                else {
                                    return new AST_SymbolExport(args);
                                }
                            }
                            else if (p.type == "ExportAllDeclaration" && M == p.exported) {
                                args.name = val;
                                return new AST_SymbolExportForeign(args);
                            }
                            args.value = val;
                            return new AST_String(args);
                        case "number":
                            args.value = val;
                            args.raw = M.raw || val.toString();
                            return new AST_Number(args);
                        case "boolean":
                            return new (val ? AST_True : AST_False)(args);
                    }
                },
                MetaProperty: function (M) {
                    if (M.meta.name === "new" && M.property.name === "target") {
                        return new AST_NewTarget({
                            start: my_start_token(M),
                            end: my_end_token(M)
                        });
                    }
                    else if (M.meta.name === "import" && M.property.name === "meta") {
                        return new AST_ImportMeta({
                            start: my_start_token(M),
                            end: my_end_token(M)
                        });
                    }
                },
                Identifier: function (M) {
                    var p = FROM_MOZ_STACK[FROM_MOZ_STACK.length - 2];
                    return new (p.type == "LabeledStatement" ? AST_Label
                        : p.type == "VariableDeclarator" && p.id === M ? (p.kind == "const" ? AST_SymbolConst : p.kind == "let" ? AST_SymbolLet : AST_SymbolVar)
                            : /Import.*Specifier/.test(p.type) ? (p.local === M ? AST_SymbolImport : AST_SymbolImportForeign)
                                : p.type == "ExportSpecifier" ? (p.local === M ? AST_SymbolExport : AST_SymbolExportForeign)
                                    : p.type == "FunctionExpression" ? (p.id === M ? AST_SymbolLambda : AST_SymbolFunarg)
                                        : p.type == "FunctionDeclaration" ? (p.id === M ? AST_SymbolDefun : AST_SymbolFunarg)
                                            : p.type == "ArrowFunctionExpression" ? (p.params.includes(M)) ? AST_SymbolFunarg : AST_SymbolRef
                                                : p.type == "ClassExpression" ? (p.id === M ? AST_SymbolClass : AST_SymbolRef)
                                                    : p.type == "Property" ? (p.key === M && p.computed || p.value === M ? AST_SymbolRef : AST_SymbolMethod)
                                                        : p.type == "PropertyDefinition" || p.type === "FieldDefinition" ? (p.key === M && p.computed || p.value === M ? AST_SymbolRef : AST_SymbolClassProperty)
                                                            : p.type == "ClassDeclaration" ? (p.id === M ? AST_SymbolDefClass : AST_SymbolRef)
                                                                : p.type == "MethodDefinition" ? (p.computed ? AST_SymbolRef : AST_SymbolMethod)
                                                                    : p.type == "CatchClause" ? AST_SymbolCatch
                                                                        : p.type == "BreakStatement" || p.type == "ContinueStatement" ? AST_LabelRef
                                                                            : AST_SymbolRef)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: M.name
                    });
                },
                BigIntLiteral(M) {
                    return new AST_BigInt({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        value: M.value
                    });
                },
                EmptyStatement: function (M) {
                    return new AST_EmptyStatement({
                        start: my_start_token(M),
                        end: my_end_token(M)
                    });
                },
                BlockStatement: function (M) {
                    return new AST_BlockStatement({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: M.body.map(from_moz)
                    });
                },
                IfStatement: function (M) {
                    return new AST_If({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        condition: from_moz(M.test),
                        body: from_moz(M.consequent),
                        alternative: from_moz(M.alternate)
                    });
                },
                LabeledStatement: function (M) {
                    return new AST_LabeledStatement({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        label: from_moz(M.label),
                        body: from_moz(M.body)
                    });
                },
                BreakStatement: function (M) {
                    return new AST_Break({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        label: from_moz(M.label)
                    });
                },
                ContinueStatement: function (M) {
                    return new AST_Continue({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        label: from_moz(M.label)
                    });
                },
                WithStatement: function (M) {
                    return new AST_With({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.object),
                        body: from_moz(M.body)
                    });
                },
                SwitchStatement: function (M) {
                    return new AST_Switch({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.discriminant),
                        body: M.cases.map(from_moz)
                    });
                },
                ReturnStatement: function (M) {
                    return new AST_Return({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        value: from_moz(M.argument)
                    });
                },
                ThrowStatement: function (M) {
                    return new AST_Throw({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        value: from_moz(M.argument)
                    });
                },
                WhileStatement: function (M) {
                    return new AST_While({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        condition: from_moz(M.test),
                        body: from_moz(M.body)
                    });
                },
                DoWhileStatement: function (M) {
                    return new AST_Do({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        condition: from_moz(M.test),
                        body: from_moz(M.body)
                    });
                },
                ForStatement: function (M) {
                    return new AST_For({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        init: from_moz(M.init),
                        condition: from_moz(M.test),
                        step: from_moz(M.update),
                        body: from_moz(M.body)
                    });
                },
                ForInStatement: function (M) {
                    return new AST_ForIn({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        init: from_moz(M.left),
                        object: from_moz(M.right),
                        body: from_moz(M.body)
                    });
                },
                ForOfStatement: function (M) {
                    return new AST_ForOf({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        init: from_moz(M.left),
                        object: from_moz(M.right),
                        body: from_moz(M.body),
                        await: M.await
                    });
                },
                AwaitExpression: function (M) {
                    return new AST_Await({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.argument)
                    });
                },
                YieldExpression: function (M) {
                    return new AST_Yield({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.argument),
                        is_star: M.delegate
                    });
                },
                DebuggerStatement: function (M) {
                    return new AST_Debugger({
                        start: my_start_token(M),
                        end: my_end_token(M)
                    });
                },
                VariableDeclarator: function (M) {
                    return new AST_VarDef({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: from_moz(M.id),
                        value: from_moz(M.init)
                    });
                },
                CatchClause: function (M) {
                    return new AST_Catch({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        argname: from_moz(M.param),
                        body: from_moz(M.body).body
                    });
                },
                ThisExpression: function (M) {
                    return new AST_This({
                        start: my_start_token(M),
                        end: my_end_token(M)
                    });
                },
                Super: function (M) {
                    return new AST_Super({
                        start: my_start_token(M),
                        end: my_end_token(M)
                    });
                },
                BinaryExpression: function (M) {
                    if (M.left.type === "PrivateIdentifier") {
                        return new AST_PrivateIn({
                            start: my_start_token(M),
                            end: my_end_token(M),
                            key: new AST_SymbolPrivateProperty({
                                start: my_start_token(M.left),
                                end: my_end_token(M.left),
                                name: M.left.name
                            }),
                            value: from_moz(M.right),
                        });
                    }
                    return new AST_Binary({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        operator: M.operator,
                        left: from_moz(M.left),
                        right: from_moz(M.right)
                    });
                },
                LogicalExpression: function (M) {
                    return new AST_Binary({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        operator: M.operator,
                        left: from_moz(M.left),
                        right: from_moz(M.right)
                    });
                },
                AssignmentExpression: function (M) {
                    return new AST_Assign({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        operator: M.operator,
                        left: from_moz(M.left),
                        right: from_moz(M.right)
                    });
                },
                ConditionalExpression: function (M) {
                    return new AST_Conditional({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        condition: from_moz(M.test),
                        consequent: from_moz(M.consequent),
                        alternative: from_moz(M.alternate)
                    });
                },
                NewExpression: function (M) {
                    return new AST_New({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.callee),
                        args: M.arguments.map(from_moz)
                    });
                },
                CallExpression: function (M) {
                    return new AST_Call({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.callee),
                        optional: M.optional,
                        args: M.arguments.map(from_moz)
                    });
                }
            };
            MOZ_TO_ME.UpdateExpression =
                MOZ_TO_ME.UnaryExpression = function To_Moz_Unary(M) {
                    var prefix = "prefix" in M ? M.prefix
                        : M.type == "UnaryExpression" ? true : false;
                    return new (prefix ? AST_UnaryPrefix : AST_UnaryPostfix)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        operator: M.operator,
                        expression: from_moz(M.argument)
                    });
                };
            MOZ_TO_ME.ClassDeclaration =
                MOZ_TO_ME.ClassExpression = function From_Moz_Class(M) {
                    return new (M.type === "ClassDeclaration" ? AST_DefClass : AST_ClassExpression)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: from_moz(M.id),
                        extends: from_moz(M.superClass),
                        properties: M.body.body.map(from_moz)
                    });
                };
            def_to_moz(AST_EmptyStatement, function To_Moz_EmptyStatement() {
                return {
                    type: "EmptyStatement"
                };
            });
            def_to_moz(AST_BlockStatement, function To_Moz_BlockStatement(M) {
                return {
                    type: "BlockStatement",
                    body: M.body.map(to_moz)
                };
            });
            def_to_moz(AST_If, function To_Moz_IfStatement(M) {
                return {
                    type: "IfStatement",
                    test: to_moz(M.condition),
                    consequent: to_moz(M.body),
                    alternate: to_moz(M.alternative)
                };
            });
            def_to_moz(AST_LabeledStatement, function To_Moz_LabeledStatement(M) {
                return {
                    type: "LabeledStatement",
                    label: to_moz(M.label),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_Break, function To_Moz_BreakStatement(M) {
                return {
                    type: "BreakStatement",
                    label: to_moz(M.label)
                };
            });
            def_to_moz(AST_Continue, function To_Moz_ContinueStatement(M) {
                return {
                    type: "ContinueStatement",
                    label: to_moz(M.label)
                };
            });
            def_to_moz(AST_With, function To_Moz_WithStatement(M) {
                return {
                    type: "WithStatement",
                    object: to_moz(M.expression),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_Switch, function To_Moz_SwitchStatement(M) {
                return {
                    type: "SwitchStatement",
                    discriminant: to_moz(M.expression),
                    cases: M.body.map(to_moz)
                };
            });
            def_to_moz(AST_Return, function To_Moz_ReturnStatement(M) {
                return {
                    type: "ReturnStatement",
                    argument: to_moz(M.value)
                };
            });
            def_to_moz(AST_Throw, function To_Moz_ThrowStatement(M) {
                return {
                    type: "ThrowStatement",
                    argument: to_moz(M.value)
                };
            });
            def_to_moz(AST_While, function To_Moz_WhileStatement(M) {
                return {
                    type: "WhileStatement",
                    test: to_moz(M.condition),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_Do, function To_Moz_DoWhileStatement(M) {
                return {
                    type: "DoWhileStatement",
                    test: to_moz(M.condition),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_For, function To_Moz_ForStatement(M) {
                return {
                    type: "ForStatement",
                    init: to_moz(M.init),
                    test: to_moz(M.condition),
                    update: to_moz(M.step),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_ForIn, function To_Moz_ForInStatement(M) {
                return {
                    type: "ForInStatement",
                    left: to_moz(M.init),
                    right: to_moz(M.object),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_ForOf, function To_Moz_ForOfStatement(M) {
                return {
                    type: "ForOfStatement",
                    left: to_moz(M.init),
                    right: to_moz(M.object),
                    body: to_moz(M.body),
                    await: M.await
                };
            });
            def_to_moz(AST_Await, function To_Moz_AwaitExpression(M) {
                return {
                    type: "AwaitExpression",
                    argument: to_moz(M.expression)
                };
            });
            def_to_moz(AST_Yield, function To_Moz_YieldExpression(M) {
                return {
                    type: "YieldExpression",
                    argument: to_moz(M.expression),
                    delegate: M.is_star
                };
            });
            def_to_moz(AST_Debugger, function To_Moz_DebuggerStatement() {
                return {
                    type: "DebuggerStatement"
                };
            });
            def_to_moz(AST_VarDef, function To_Moz_VariableDeclarator(M) {
                return {
                    type: "VariableDeclarator",
                    id: to_moz(M.name),
                    init: to_moz(M.value)
                };
            });
            def_to_moz(AST_Catch, function To_Moz_CatchClause(M) {
                return {
                    type: "CatchClause",
                    param: to_moz(M.argname),
                    body: to_moz_block(M)
                };
            });
            def_to_moz(AST_This, function To_Moz_ThisExpression() {
                return {
                    type: "ThisExpression"
                };
            });
            def_to_moz(AST_Super, function To_Moz_Super() {
                return {
                    type: "Super"
                };
            });
            def_to_moz(AST_Binary, function To_Moz_BinaryExpression(M) {
                return {
                    type: "BinaryExpression",
                    operator: M.operator,
                    left: to_moz(M.left),
                    right: to_moz(M.right)
                };
            });
            def_to_moz(AST_Binary, function To_Moz_LogicalExpression(M) {
                return {
                    type: "LogicalExpression",
                    operator: M.operator,
                    left: to_moz(M.left),
                    right: to_moz(M.right)
                };
            });
            def_to_moz(AST_Assign, function To_Moz_AssignmentExpression(M) {
                return {
                    type: "AssignmentExpression",
                    operator: M.operator,
                    left: to_moz(M.left),
                    right: to_moz(M.right)
                };
            });
            def_to_moz(AST_Conditional, function To_Moz_ConditionalExpression(M) {
                return {
                    type: "ConditionalExpression",
                    test: to_moz(M.condition),
                    consequent: to_moz(M.consequent),
                    alternate: to_moz(M.alternative)
                };
            });
            def_to_moz(AST_New, function To_Moz_NewExpression(M) {
                return {
                    type: "NewExpression",
                    callee: to_moz(M.expression),
                    arguments: M.args.map(to_moz)
                };
            });
            def_to_moz(AST_Call, function To_Moz_CallExpression(M) {
                return {
                    type: "CallExpression",
                    callee: to_moz(M.expression),
                    optional: M.optional,
                    arguments: M.args.map(to_moz)
                };
            });
            def_to_moz(AST_Toplevel, function To_Moz_Program(M) {
                return to_moz_scope("Program", M);
            });
            def_to_moz(AST_Expansion, function To_Moz_Spread(M) {
                return {
                    type: to_moz_in_destructuring() ? "RestElement" : "SpreadElement",
                    argument: to_moz(M.expression)
                };
            });
            def_to_moz(AST_PrefixedTemplateString, function To_Moz_TaggedTemplateExpression(M) {
                return {
                    type: "TaggedTemplateExpression",
                    tag: to_moz(M.prefix),
                    quasi: to_moz(M.template_string)
                };
            });
            def_to_moz(AST_TemplateString, function To_Moz_TemplateLiteral(M) {
                var quasis = [];
                var expressions = [];
                for (var i = 0; i < M.segments.length; i++) {
                    if (i % 2 !== 0) {
                        expressions.push(to_moz(M.segments[i]));
                    }
                    else {
                        quasis.push({
                            type: "TemplateElement",
                            value: {
                                raw: M.segments[i].raw,
                                cooked: M.segments[i].value
                            },
                            tail: i === M.segments.length - 1
                        });
                    }
                }
                return {
                    type: "TemplateLiteral",
                    quasis: quasis,
                    expressions: expressions
                };
            });
            def_to_moz(AST_Defun, function To_Moz_FunctionDeclaration(M) {
                return {
                    type: "FunctionDeclaration",
                    id: to_moz(M.name),
                    params: M.argnames.map(to_moz),
                    generator: M.is_generator,
                    async: M.async,
                    body: to_moz_scope("BlockStatement", M)
                };
            });
            def_to_moz(AST_Function, function To_Moz_FunctionExpression(M, parent) {
                var is_generator = parent.is_generator !== undefined ?
                    parent.is_generator : M.is_generator;
                return {
                    type: "FunctionExpression",
                    id: to_moz(M.name),
                    params: M.argnames.map(to_moz),
                    generator: is_generator,
                    async: M.async,
                    body: to_moz_scope("BlockStatement", M)
                };
            });
            def_to_moz(AST_Arrow, function To_Moz_ArrowFunctionExpression(M) {
                var body = {
                    type: "BlockStatement",
                    body: M.body.map(to_moz)
                };
                return {
                    type: "ArrowFunctionExpression",
                    params: M.argnames.map(to_moz),
                    async: M.async,
                    body: body
                };
            });
            def_to_moz(AST_Destructuring, function To_Moz_ObjectPattern(M) {
                if (M.is_array) {
                    return {
                        type: "ArrayPattern",
                        elements: M.names.map(to_moz)
                    };
                }
                return {
                    type: "ObjectPattern",
                    properties: M.names.map(to_moz)
                };
            });
            def_to_moz(AST_Directive, function To_Moz_Directive(M) {
                return {
                    type: "ExpressionStatement",
                    expression: {
                        type: "Literal",
                        value: M.value,
                        raw: M.print_to_string()
                    },
                    directive: M.value
                };
            });
            def_to_moz(AST_SimpleStatement, function To_Moz_ExpressionStatement(M) {
                return {
                    type: "ExpressionStatement",
                    expression: to_moz(M.body)
                };
            });
            def_to_moz(AST_SwitchBranch, function To_Moz_SwitchCase(M) {
                return {
                    type: "SwitchCase",
                    test: to_moz(M.expression),
                    consequent: M.body.map(to_moz)
                };
            });
            def_to_moz(AST_Try, function To_Moz_TryStatement(M) {
                return {
                    type: "TryStatement",
                    block: to_moz_block(M.body),
                    handler: to_moz(M.bcatch),
                    guardedHandlers: [],
                    finalizer: to_moz(M.bfinally)
                };
            });
            def_to_moz(AST_Catch, function To_Moz_CatchClause(M) {
                return {
                    type: "CatchClause",
                    param: to_moz(M.argname),
                    guard: null,
                    body: to_moz_block(M)
                };
            });
            def_to_moz(AST_Definitions, function To_Moz_VariableDeclaration(M) {
                return {
                    type: "VariableDeclaration",
                    kind: M instanceof AST_Const ? "const" :
                        M instanceof AST_Let ? "let" : "var",
                    declarations: M.definitions.map(to_moz)
                };
            });
            const assert_clause_to_moz = assert_clause => {
                const assertions = [];
                if (assert_clause) {
                    for (const { key, value } of assert_clause.properties) {
                        const key_moz = is_basic_identifier_string(key)
                            ? { type: "Identifier", name: key }
                            : { type: "Literal", value: key, raw: JSON.stringify(key) };
                        assertions.push({
                            type: "ImportAttribute",
                            key: key_moz,
                            value: to_moz(value)
                        });
                    }
                }
                return assertions;
            };
            def_to_moz(AST_Export, function To_Moz_ExportDeclaration(M) {
                if (M.exported_names) {
                    var first_exported = M.exported_names[0];
                    var first_exported_name = first_exported.name;
                    if (first_exported_name.name === "*" && !first_exported_name.quote) {
                        var foreign_name = first_exported.foreign_name;
                        var exported = foreign_name.name === "*" && !foreign_name.quote
                            ? null
                            : to_moz(foreign_name);
                        return {
                            type: "ExportAllDeclaration",
                            source: to_moz(M.module_name),
                            exported: exported,
                            assertions: assert_clause_to_moz(M.assert_clause)
                        };
                    }
                    return {
                        type: "ExportNamedDeclaration",
                        specifiers: M.exported_names.map(function (name_mapping) {
                            return {
                                type: "ExportSpecifier",
                                exported: to_moz(name_mapping.foreign_name),
                                local: to_moz(name_mapping.name)
                            };
                        }),
                        declaration: to_moz(M.exported_definition),
                        source: to_moz(M.module_name),
                        assertions: assert_clause_to_moz(M.assert_clause)
                    };
                }
                return {
                    type: M.is_default ? "ExportDefaultDeclaration" : "ExportNamedDeclaration",
                    declaration: to_moz(M.exported_value || M.exported_definition)
                };
            });
            def_to_moz(AST_Import, function To_Moz_ImportDeclaration(M) {
                var specifiers = [];
                if (M.imported_name) {
                    specifiers.push({
                        type: "ImportDefaultSpecifier",
                        local: to_moz(M.imported_name)
                    });
                }
                if (M.imported_names) {
                    var first_imported_foreign_name = M.imported_names[0].foreign_name;
                    if (first_imported_foreign_name.name === "*" && !first_imported_foreign_name.quote) {
                        specifiers.push({
                            type: "ImportNamespaceSpecifier",
                            local: to_moz(M.imported_names[0].name)
                        });
                    }
                    else {
                        M.imported_names.forEach(function (name_mapping) {
                            specifiers.push({
                                type: "ImportSpecifier",
                                local: to_moz(name_mapping.name),
                                imported: to_moz(name_mapping.foreign_name)
                            });
                        });
                    }
                }
                return {
                    type: "ImportDeclaration",
                    specifiers: specifiers,
                    source: to_moz(M.module_name),
                    assertions: assert_clause_to_moz(M.assert_clause)
                };
            });
            def_to_moz(AST_ImportMeta, function To_Moz_MetaProperty() {
                return {
                    type: "MetaProperty",
                    meta: {
                        type: "Identifier",
                        name: "import"
                    },
                    property: {
                        type: "Identifier",
                        name: "meta"
                    }
                };
            });
            def_to_moz(AST_Sequence, function To_Moz_SequenceExpression(M) {
                return {
                    type: "SequenceExpression",
                    expressions: M.expressions.map(to_moz)
                };
            });
            def_to_moz(AST_DotHash, function To_Moz_PrivateMemberExpression(M) {
                return {
                    type: "MemberExpression",
                    object: to_moz(M.expression),
                    computed: false,
                    property: {
                        type: "PrivateIdentifier",
                        name: M.property
                    },
                    optional: M.optional
                };
            });
            def_to_moz(AST_PropAccess, function To_Moz_MemberExpression(M) {
                var isComputed = M instanceof AST_Sub;
                return {
                    type: "MemberExpression",
                    object: to_moz(M.expression),
                    computed: isComputed,
                    property: isComputed ? to_moz(M.property) : { type: "Identifier", name: M.property },
                    optional: M.optional
                };
            });
            def_to_moz(AST_Chain, function To_Moz_ChainExpression(M) {
                return {
                    type: "ChainExpression",
                    expression: to_moz(M.expression)
                };
            });
            def_to_moz(AST_Unary, function To_Moz_Unary(M) {
                return {
                    type: M.operator == "++" || M.operator == "--" ? "UpdateExpression" : "UnaryExpression",
                    operator: M.operator,
                    prefix: M instanceof AST_UnaryPrefix,
                    argument: to_moz(M.expression)
                };
            });
            def_to_moz(AST_Binary, function To_Moz_BinaryExpression(M) {
                if (M.operator == "=" && to_moz_in_destructuring()) {
                    return {
                        type: "AssignmentPattern",
                        left: to_moz(M.left),
                        right: to_moz(M.right)
                    };
                }
                const type = M.operator == "&&" || M.operator == "||" || M.operator === "??"
                    ? "LogicalExpression"
                    : "BinaryExpression";
                return {
                    type,
                    left: to_moz(M.left),
                    operator: M.operator,
                    right: to_moz(M.right)
                };
            });
            def_to_moz(AST_PrivateIn, function To_Moz_BinaryExpression_PrivateIn(M) {
                return {
                    type: "BinaryExpression",
                    left: { type: "PrivateIdentifier", name: M.key.name },
                    operator: "in",
                    right: to_moz(M.value),
                };
            });
            def_to_moz(AST_Array, function To_Moz_ArrayExpression(M) {
                return {
                    type: "ArrayExpression",
                    elements: M.elements.map(to_moz)
                };
            });
            def_to_moz(AST_Object, function To_Moz_ObjectExpression(M) {
                return {
                    type: "ObjectExpression",
                    properties: M.properties.map(to_moz)
                };
            });
            def_to_moz(AST_ObjectProperty, function To_Moz_Property(M, parent) {
                var key = M.key instanceof AST_Node ? to_moz(M.key) : {
                    type: "Identifier",
                    value: M.key
                };
                if (typeof M.key === "number") {
                    key = {
                        type: "Literal",
                        value: Number(M.key)
                    };
                }
                if (typeof M.key === "string") {
                    key = {
                        type: "Identifier",
                        name: M.key
                    };
                }
                var kind;
                var string_or_num = typeof M.key === "string" || typeof M.key === "number";
                var computed = string_or_num ? false : !(M.key instanceof AST_Symbol) || M.key instanceof AST_SymbolRef;
                if (M instanceof AST_ObjectKeyVal) {
                    kind = "init";
                    computed = !string_or_num;
                }
                else if (M instanceof AST_ObjectGetter) {
                    kind = "get";
                }
                else if (M instanceof AST_ObjectSetter) {
                    kind = "set";
                }
                if (M instanceof AST_PrivateGetter || M instanceof AST_PrivateSetter) {
                    const kind = M instanceof AST_PrivateGetter ? "get" : "set";
                    return {
                        type: "MethodDefinition",
                        computed: false,
                        kind: kind,
                        static: M.static,
                        key: {
                            type: "PrivateIdentifier",
                            name: M.key.name
                        },
                        value: to_moz(M.value)
                    };
                }
                if (M instanceof AST_ClassPrivateProperty) {
                    return {
                        type: "PropertyDefinition",
                        key: {
                            type: "PrivateIdentifier",
                            name: M.key.name
                        },
                        value: to_moz(M.value),
                        computed: false,
                        static: M.static
                    };
                }
                if (M instanceof AST_ClassProperty) {
                    return {
                        type: "PropertyDefinition",
                        key,
                        value: to_moz(M.value),
                        computed,
                        static: M.static
                    };
                }
                if (parent instanceof AST_Class) {
                    return {
                        type: "MethodDefinition",
                        computed: computed,
                        kind: kind,
                        static: M.static,
                        key: to_moz(M.key),
                        value: to_moz(M.value)
                    };
                }
                return {
                    type: "Property",
                    computed: computed,
                    kind: kind,
                    key: key,
                    value: to_moz(M.value)
                };
            });
            def_to_moz(AST_ConciseMethod, function To_Moz_MethodDefinition(M, parent) {
                if (parent instanceof AST_Object) {
                    return {
                        type: "Property",
                        computed: !(M.key instanceof AST_Symbol) || M.key instanceof AST_SymbolRef,
                        kind: "init",
                        method: true,
                        shorthand: false,
                        key: to_moz(M.key),
                        value: to_moz(M.value)
                    };
                }
                const key = M instanceof AST_PrivateMethod
                    ? {
                        type: "PrivateIdentifier",
                        name: M.key.name
                    }
                    : to_moz(M.key);
                return {
                    type: "MethodDefinition",
                    kind: M.key === "constructor" ? "constructor" : "method",
                    key,
                    value: to_moz(M.value),
                    computed: !(M.key instanceof AST_Symbol) || M.key instanceof AST_SymbolRef,
                    static: M.static,
                };
            });
            def_to_moz(AST_Class, function To_Moz_Class(M) {
                var type = M instanceof AST_ClassExpression ? "ClassExpression" : "ClassDeclaration";
                return {
                    type: type,
                    superClass: to_moz(M.extends),
                    id: M.name ? to_moz(M.name) : null,
                    body: {
                        type: "ClassBody",
                        body: M.properties.map(to_moz)
                    }
                };
            });
            def_to_moz(AST_ClassStaticBlock, function To_Moz_StaticBlock(M) {
                return {
                    type: "StaticBlock",
                    body: M.body.map(to_moz),
                };
            });
            def_to_moz(AST_NewTarget, function To_Moz_MetaProperty() {
                return {
                    type: "MetaProperty",
                    meta: {
                        type: "Identifier",
                        name: "new"
                    },
                    property: {
                        type: "Identifier",
                        name: "target"
                    }
                };
            });
            def_to_moz(AST_Symbol, function To_Moz_Identifier(M, parent) {
                if ((M instanceof AST_SymbolMethod && parent.quote) ||
                    ((M instanceof AST_SymbolImportForeign ||
                        M instanceof AST_SymbolExportForeign ||
                        M instanceof AST_SymbolExport) && M.quote)) {
                    return {
                        type: "Literal",
                        value: M.name
                    };
                }
                var def = M.definition();
                return {
                    type: "Identifier",
                    name: def ? def.mangled_name || def.name : M.name
                };
            });
            def_to_moz(AST_RegExp, function To_Moz_RegExpLiteral(M) {
                const pattern = M.value.source;
                const flags = M.value.flags;
                return {
                    type: "Literal",
                    value: null,
                    raw: M.print_to_string(),
                    regex: { pattern, flags }
                };
            });
            def_to_moz(AST_Constant, function To_Moz_Literal(M) {
                var value = M.value;
                return {
                    type: "Literal",
                    value: value,
                    raw: M.raw || M.print_to_string()
                };
            });
            def_to_moz(AST_Atom, function To_Moz_Atom(M) {
                return {
                    type: "Identifier",
                    name: String(M.value)
                };
            });
            def_to_moz(AST_BigInt, M => ({
                type: "BigIntLiteral",
                value: M.value
            }));
            AST_Boolean.DEFMETHOD("to_mozilla_ast", AST_Constant.prototype.to_mozilla_ast);
            AST_Null.DEFMETHOD("to_mozilla_ast", AST_Constant.prototype.to_mozilla_ast);
            AST_Hole.DEFMETHOD("to_mozilla_ast", function To_Moz_ArrayHole() { return null; });
            AST_Block.DEFMETHOD("to_mozilla_ast", AST_BlockStatement.prototype.to_mozilla_ast);
            AST_Lambda.DEFMETHOD("to_mozilla_ast", AST_Function.prototype.to_mozilla_ast);
            /* -----[ tools ]----- */
            function my_start_token(moznode) {
                var loc = moznode.loc, start = loc && loc.start;
                var range = moznode.range;
                return new AST_Token("", "", start && start.line || 0, start && start.column || 0, range ? range[0] : moznode.start, false, [], [], loc && loc.source);
            }
            function my_end_token(moznode) {
                var loc = moznode.loc, end = loc && loc.end;
                var range = moznode.range;
                return new AST_Token("", "", end && end.line || 0, end && end.column || 0, range ? range[0] : moznode.end, false, [], [], loc && loc.source);
            }
            var FROM_MOZ_STACK = null;
            function from_moz(node) {
                FROM_MOZ_STACK.push(node);
                var ret = node != null ? MOZ_TO_ME[node.type](node) : null;
                FROM_MOZ_STACK.pop();
                return ret;
            }
            AST_Node.from_mozilla_ast = function (node) {
                var save_stack = FROM_MOZ_STACK;
                FROM_MOZ_STACK = [];
                var ast = from_moz(node);
                FROM_MOZ_STACK = save_stack;
                return ast;
            };
            function set_moz_loc(mynode, moznode) {
                var start = mynode.start;
                var end = mynode.end;
                if (!(start && end)) {
                    return moznode;
                }
                if (start.pos != null && end.endpos != null) {
                    moznode.range = [start.pos, end.endpos];
                }
                if (start.line) {
                    moznode.loc = {
                        start: { line: start.line, column: start.col },
                        end: end.endline ? { line: end.endline, column: end.endcol } : null
                    };
                    if (start.file) {
                        moznode.loc.source = start.file;
                    }
                }
                return moznode;
            }
            function def_to_moz(mytype, handler) {
                mytype.DEFMETHOD("to_mozilla_ast", function (parent) {
                    return set_moz_loc(this, handler(this, parent));
                });
            }
            var TO_MOZ_STACK = null;
            function to_moz(node) {
                if (TO_MOZ_STACK === null) {
                    TO_MOZ_STACK = [];
                }
                TO_MOZ_STACK.push(node);
                var ast = node != null ? node.to_mozilla_ast(TO_MOZ_STACK[TO_MOZ_STACK.length - 2]) : null;
                TO_MOZ_STACK.pop();
                if (TO_MOZ_STACK.length === 0) {
                    TO_MOZ_STACK = null;
                }
                return ast;
            }
            function to_moz_in_destructuring() {
                var i = TO_MOZ_STACK.length;
                while (i--) {
                    if (TO_MOZ_STACK[i] instanceof AST_Destructuring) {
                        return true;
                    }
                }
                return false;
            }
            function to_moz_block(node) {
                return {
                    type: "BlockStatement",
                    body: node.body.map(to_moz)
                };
            }
            function to_moz_scope(type, node) {
                var body = node.body.map(to_moz);
                if (node.body[0] instanceof AST_SimpleStatement && node.body[0].body instanceof AST_String) {
                    body.unshift(to_moz(new AST_EmptyStatement(node.body[0])));
                }
                return {
                    type: type,
                    body: body
                };
            }
        })();
        // return true if the node at the top of the stack (that means the
        // innermost node in the current output) is lexically the first in
        // a statement.
        function first_in_statement(stack) {
            let node = stack.parent(-1);
            for (let i = 0, p; p = stack.parent(i); i++) {
                if (p instanceof AST_Statement && p.body === node)
                    return true;
                if ((p instanceof AST_Sequence && p.expressions[0] === node) ||
                    (p.TYPE === "Call" && p.expression === node) ||
                    (p instanceof AST_PrefixedTemplateString && p.prefix === node) ||
                    (p instanceof AST_Dot && p.expression === node) ||
                    (p instanceof AST_Sub && p.expression === node) ||
                    (p instanceof AST_Chain && p.expression === node) ||
                    (p instanceof AST_Conditional && p.condition === node) ||
                    (p instanceof AST_Binary && p.left === node) ||
                    (p instanceof AST_UnaryPostfix && p.expression === node)) {
                    node = p;
                }
                else {
                    return false;
                }
            }
        }
        // Returns whether the leftmost item in the expression is an object
        function left_is_object(node) {
            if (node instanceof AST_Object)
                return true;
            if (node instanceof AST_Sequence)
                return left_is_object(node.expressions[0]);
            if (node.TYPE === "Call")
                return left_is_object(node.expression);
            if (node instanceof AST_PrefixedTemplateString)
                return left_is_object(node.prefix);
            if (node instanceof AST_Dot || node instanceof AST_Sub)
                return left_is_object(node.expression);
            if (node instanceof AST_Chain)
                return left_is_object(node.expression);
            if (node instanceof AST_Conditional)
                return left_is_object(node.condition);
            if (node instanceof AST_Binary)
                return left_is_object(node.left);
            if (node instanceof AST_UnaryPostfix)
                return left_is_object(node.expression);
            return false;
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        const EXPECT_DIRECTIVE = /^$|[;{][\s\n]*$/;
        const CODE_LINE_BREAK = 10;
        const CODE_SPACE = 32;
        const r_annotation = /[@#]__(PURE|INLINE|NOINLINE)__/g;
        function is_some_comments(comment) {
            // multiline comment
            return ((comment.type === "comment2" || comment.type === "comment1")
                && /@preserve|@copyright|@lic|@cc_on|^\**!/i.test(comment.value));
        }
        class Rope {
            constructor() {
                this.committed = "";
                this.current = "";
            }
            append(str) {
                this.current += str;
            }
            insertAt(char, index) {
                const { committed, current } = this;
                if (index < committed.length) {
                    this.committed = committed.slice(0, index) + char + committed.slice(index);
                }
                else if (index === committed.length) {
                    this.committed += char;
                }
                else {
                    index -= committed.length;
                    this.committed += current.slice(0, index) + char;
                    this.current = current.slice(index);
                }
            }
            charAt(index) {
                const { committed } = this;
                if (index < committed.length)
                    return committed[index];
                return this.current[index - committed.length];
            }
            curLength() {
                return this.current.length;
            }
            length() {
                return this.committed.length + this.current.length;
            }
            toString() {
                return this.committed + this.current;
            }
        }
        function OutputStream(options) {
            var readonly = !options;
            options = defaults(options, {
                ascii_only: false,
                beautify: false,
                braces: false,
                comments: "some",
                ecma: 5,
                ie8: false,
                indent_level: 4,
                indent_start: 0,
                inline_script: true,
                keep_numbers: false,
                keep_quoted_props: false,
                max_line_len: false,
                preamble: null,
                preserve_annotations: false,
                quote_keys: false,
                quote_style: 0,
                safari10: false,
                semicolons: true,
                shebang: true,
                shorthand: undefined,
                source_map: null,
                webkit: false,
                width: 80,
                wrap_iife: false,
                wrap_func_args: true,
                _destroy_ast: false
            }, true);
            if (options.shorthand === undefined)
                options.shorthand = options.ecma > 5;
            // Convert comment option to RegExp if necessary and set up comments filter
            var comment_filter = return_false; // Default case, throw all comments away
            if (options.comments) {
                let comments = options.comments;
                if (typeof options.comments === "string" && /^\/.*\/[a-zA-Z]*$/.test(options.comments)) {
                    var regex_pos = options.comments.lastIndexOf("/");
                    comments = new RegExp(options.comments.substr(1, regex_pos - 1), options.comments.substr(regex_pos + 1));
                }
                if (comments instanceof RegExp) {
                    comment_filter = function (comment) {
                        return comment.type != "comment5" && comments.test(comment.value);
                    };
                }
                else if (typeof comments === "function") {
                    comment_filter = function (comment) {
                        return comment.type != "comment5" && comments(this, comment);
                    };
                }
                else if (comments === "some") {
                    comment_filter = is_some_comments;
                }
                else { // NOTE includes "all" option
                    comment_filter = return_true;
                }
            }
            var indentation = 0;
            var current_col = 0;
            var current_line = 1;
            var current_pos = 0;
            var OUTPUT = new Rope();
            let printed_comments = new Set();
            var to_utf8 = options.ascii_only ? function (str, identifier = false, regexp = false) {
                if (options.ecma >= 2015 && !options.safari10 && !regexp) {
                    str = str.replace(/[\ud800-\udbff][\udc00-\udfff]/g, function (ch) {
                        var code = get_full_char_code(ch, 0).toString(16);
                        return "\\u{" + code + "}";
                    });
                }
                return str.replace(/[\u0000-\u001f\u007f-\uffff]/g, function (ch) {
                    var code = ch.charCodeAt(0).toString(16);
                    if (code.length <= 2 && !identifier) {
                        while (code.length < 2)
                            code = "0" + code;
                        return "\\x" + code;
                    }
                    else {
                        while (code.length < 4)
                            code = "0" + code;
                        return "\\u" + code;
                    }
                });
            } : function (str) {
                return str.replace(/[\ud800-\udbff][\udc00-\udfff]|([\ud800-\udbff]|[\udc00-\udfff])/g, function (match, lone) {
                    if (lone) {
                        return "\\u" + lone.charCodeAt(0).toString(16);
                    }
                    return match;
                });
            };
            function make_string(str, quote) {
                var dq = 0, sq = 0;
                str = str.replace(/[\\\b\f\n\r\v\t\x22\x27\u2028\u2029\0\ufeff]/g, function (s, i) {
                    switch (s) {
                        case '"':
                            ++dq;
                            return '"';
                        case "'":
                            ++sq;
                            return "'";
                        case "\\": return "\\\\";
                        case "\n": return "\\n";
                        case "\r": return "\\r";
                        case "\t": return "\\t";
                        case "\b": return "\\b";
                        case "\f": return "\\f";
                        case "\x0B": return options.ie8 ? "\\x0B" : "\\v";
                        case "\u2028": return "\\u2028";
                        case "\u2029": return "\\u2029";
                        case "\ufeff": return "\\ufeff";
                        case "\0":
                            return /[0-9]/.test(get_full_char(str, i + 1)) ? "\\x00" : "\\0";
                    }
                    return s;
                });
                function quote_single() {
                    return "'" + str.replace(/\x27/g, "\\'") + "'";
                }
                function quote_double() {
                    return '"' + str.replace(/\x22/g, '\\"') + '"';
                }
                function quote_template() {
                    return "`" + str.replace(/`/g, "\\`") + "`";
                }
                str = to_utf8(str);
                if (quote === "`")
                    return quote_template();
                switch (options.quote_style) {
                    case 1:
                        return quote_single();
                    case 2:
                        return quote_double();
                    case 3:
                        return quote == "'" ? quote_single() : quote_double();
                    default:
                        return dq > sq ? quote_single() : quote_double();
                }
            }
            function encode_string(str, quote) {
                var ret = make_string(str, quote);
                if (options.inline_script) {
                    ret = ret.replace(/<\x2f(script)([>\/\t\n\f\r ])/gi, "<\\/$1$2");
                    ret = ret.replace(/\x3c!--/g, "\\x3c!--");
                    ret = ret.replace(/--\x3e/g, "--\\x3e");
                }
                return ret;
            }
            function make_name(name) {
                name = name.toString();
                name = to_utf8(name, true);
                return name;
            }
            function make_indent(back) {
                return " ".repeat(options.indent_start + indentation - back * options.indent_level);
            }
            /* -----[ beautification/minification ]----- */
            var has_parens = false;
            var might_need_space = false;
            var might_need_semicolon = false;
            var might_add_newline = 0;
            var need_newline_indented = false;
            var need_space = false;
            var newline_insert = -1;
            var last = "";
            var mapping_token, mapping_name, mappings = options.source_map && [];
            var do_add_mapping = mappings ? function () {
                mappings.forEach(function (mapping) {
                    try {
                        let { name, token } = mapping;
                        if (token.type == "name" || token.type === "privatename") {
                            name = token.value;
                        }
                        else if (name instanceof AST_Symbol) {
                            name = token.type === "string" ? token.value : name.name;
                        }
                        options.source_map.add(mapping.token.file, mapping.line, mapping.col, mapping.token.line, mapping.token.col, is_basic_identifier_string(name) ? name : undefined);
                    }
                    catch (ex) {
                        // Ignore bad mapping
                    }
                });
                mappings = [];
            } : noop;
            var ensure_line_len = options.max_line_len ? function () {
                if (current_col > options.max_line_len) {
                    if (might_add_newline) {
                        OUTPUT.insertAt("\n", might_add_newline);
                        const curLength = OUTPUT.curLength();
                        if (mappings) {
                            var delta = curLength - current_col;
                            mappings.forEach(function (mapping) {
                                mapping.line++;
                                mapping.col += delta;
                            });
                        }
                        current_line++;
                        current_pos++;
                        current_col = curLength;
                    }
                }
                if (might_add_newline) {
                    might_add_newline = 0;
                    do_add_mapping();
                }
            } : noop;
            var requireSemicolonChars = makePredicate("( [ + * / - , . `");
            function print(str) {
                str = String(str);
                var ch = get_full_char(str, 0);
                if (need_newline_indented && ch) {
                    need_newline_indented = false;
                    if (ch !== "\n") {
                        print("\n");
                        indent();
                    }
                }
                if (need_space && ch) {
                    need_space = false;
                    if (!/[\s;})]/.test(ch)) {
                        space();
                    }
                }
                newline_insert = -1;
                var prev = last.charAt(last.length - 1);
                if (might_need_semicolon) {
                    might_need_semicolon = false;
                    if (prev === ":" && ch === "}" || (!ch || !";}".includes(ch)) && prev !== ";") {
                        if (options.semicolons || requireSemicolonChars.has(ch)) {
                            OUTPUT.append(";");
                            current_col++;
                            current_pos++;
                        }
                        else {
                            ensure_line_len();
                            if (current_col > 0) {
                                OUTPUT.append("\n");
                                current_pos++;
                                current_line++;
                                current_col = 0;
                            }
                            if (/^\s+$/.test(str)) {
                                // reset the semicolon flag, since we didn't print one
                                // now and might still have to later
                                might_need_semicolon = true;
                            }
                        }
                        if (!options.beautify)
                            might_need_space = false;
                    }
                }
                if (might_need_space) {
                    if ((is_identifier_char(prev)
                        && (is_identifier_char(ch) || ch == "\\"))
                        || (ch == "/" && ch == prev)
                        || ((ch == "+" || ch == "-") && ch == last)) {
                        OUTPUT.append(" ");
                        current_col++;
                        current_pos++;
                    }
                    might_need_space = false;
                }
                if (mapping_token) {
                    mappings.push({
                        token: mapping_token,
                        name: mapping_name,
                        line: current_line,
                        col: current_col
                    });
                    mapping_token = false;
                    if (!might_add_newline)
                        do_add_mapping();
                }
                OUTPUT.append(str);
                has_parens = str[str.length - 1] == "(";
                current_pos += str.length;
                var a = str.split(/\r?\n/), n = a.length - 1;
                current_line += n;
                current_col += a[0].length;
                if (n > 0) {
                    ensure_line_len();
                    current_col = a[n].length;
                }
                last = str;
            }
            var star = function () {
                print("*");
            };
            var space = options.beautify ? function () {
                print(" ");
            } : function () {
                might_need_space = true;
            };
            var indent = options.beautify ? function (half) {
                if (options.beautify) {
                    print(make_indent(half ? 0.5 : 0));
                }
            } : noop;
            var with_indent = options.beautify ? function (col, cont) {
                if (col === true)
                    col = next_indent();
                var save_indentation = indentation;
                indentation = col;
                var ret = cont();
                indentation = save_indentation;
                return ret;
            } : function (col, cont) { return cont(); };
            var newline = options.beautify ? function () {
                if (newline_insert < 0)
                    return print("\n");
                if (OUTPUT.charAt(newline_insert) != "\n") {
                    OUTPUT.insertAt("\n", newline_insert);
                    current_pos++;
                    current_line++;
                }
                newline_insert++;
            } : options.max_line_len ? function () {
                ensure_line_len();
                might_add_newline = OUTPUT.length();
            } : noop;
            var semicolon = options.beautify ? function () {
                print(";");
            } : function () {
                might_need_semicolon = true;
            };
            function force_semicolon() {
                might_need_semicolon = false;
                print(";");
            }
            function next_indent() {
                return indentation + options.indent_level;
            }
            function with_block(cont) {
                var ret;
                print("{");
                newline();
                with_indent(next_indent(), function () {
                    ret = cont();
                });
                indent();
                print("}");
                return ret;
            }
            function with_parens(cont) {
                print("(");
                //XXX: still nice to have that for argument lists
                //var ret = with_indent(current_col, cont);
                var ret = cont();
                print(")");
                return ret;
            }
            function with_square(cont) {
                print("[");
                //var ret = with_indent(current_col, cont);
                var ret = cont();
                print("]");
                return ret;
            }
            function comma() {
                print(",");
                space();
            }
            function colon() {
                print(":");
                space();
            }
            var add_mapping = mappings ? function (token, name) {
                mapping_token = token;
                mapping_name = name;
            } : noop;
            function get() {
                if (might_add_newline) {
                    ensure_line_len();
                }
                return OUTPUT.toString();
            }
            function has_nlb() {
                const output = OUTPUT.toString();
                let n = output.length - 1;
                while (n >= 0) {
                    const code = output.charCodeAt(n);
                    if (code === CODE_LINE_BREAK) {
                        return true;
                    }
                    if (code !== CODE_SPACE) {
                        return false;
                    }
                    n--;
                }
                return true;
            }
            function filter_comment(comment) {
                if (!options.preserve_annotations) {
                    comment = comment.replace(r_annotation, " ");
                }
                if (/^\s*$/.test(comment)) {
                    return "";
                }
                return comment.replace(/(<\s*\/\s*)(script)/i, "<\\/$2");
            }
            function prepend_comments(node) {
                var self = this;
                var start = node.start;
                if (!start)
                    return;
                var printed_comments = self.printed_comments;
                // There cannot be a newline between return and its value.
                const return_with_value = node instanceof AST_Exit && node.value;
                if (start.comments_before
                    && printed_comments.has(start.comments_before)) {
                    if (return_with_value) {
                        start.comments_before = [];
                    }
                    else {
                        return;
                    }
                }
                var comments = start.comments_before;
                if (!comments) {
                    comments = start.comments_before = [];
                }
                printed_comments.add(comments);
                if (return_with_value) {
                    var tw = new TreeWalker(function (node) {
                        var parent = tw.parent();
                        if (parent instanceof AST_Exit
                            || parent instanceof AST_Binary && parent.left === node
                            || parent.TYPE == "Call" && parent.expression === node
                            || parent instanceof AST_Conditional && parent.condition === node
                            || parent instanceof AST_Dot && parent.expression === node
                            || parent instanceof AST_Sequence && parent.expressions[0] === node
                            || parent instanceof AST_Sub && parent.expression === node
                            || parent instanceof AST_UnaryPostfix) {
                            if (!node.start)
                                return;
                            var text = node.start.comments_before;
                            if (text && !printed_comments.has(text)) {
                                printed_comments.add(text);
                                comments = comments.concat(text);
                            }
                        }
                        else {
                            return true;
                        }
                    });
                    tw.push(node);
                    node.value.walk(tw);
                }
                if (current_pos == 0) {
                    if (comments.length > 0 && options.shebang && comments[0].type === "comment5"
                        && !printed_comments.has(comments[0])) {
                        print("#!" + comments.shift().value + "\n");
                        indent();
                    }
                    var preamble = options.preamble;
                    if (preamble) {
                        print(preamble.replace(/\r\n?|[\n\u2028\u2029]|\s*$/g, "\n"));
                    }
                }
                comments = comments.filter(comment_filter, node).filter(c => !printed_comments.has(c));
                if (comments.length == 0)
                    return;
                var last_nlb = has_nlb();
                comments.forEach(function (c, i) {
                    printed_comments.add(c);
                    if (!last_nlb) {
                        if (c.nlb) {
                            print("\n");
                            indent();
                            last_nlb = true;
                        }
                        else if (i > 0) {
                            space();
                        }
                    }
                    if (/comment[134]/.test(c.type)) {
                        var value = filter_comment(c.value);
                        if (value) {
                            print("//" + value + "\n");
                            indent();
                        }
                        last_nlb = true;
                    }
                    else if (c.type == "comment2") {
                        var value = filter_comment(c.value);
                        if (value) {
                            print("/*" + value + "*/");
                        }
                        last_nlb = false;
                    }
                });
                if (!last_nlb) {
                    if (start.nlb) {
                        print("\n");
                        indent();
                    }
                    else {
                        space();
                    }
                }
            }
            function append_comments(node, tail) {
                var self = this;
                var token = node.end;
                if (!token)
                    return;
                var printed_comments = self.printed_comments;
                var comments = token[tail ? "comments_before" : "comments_after"];
                if (!comments || printed_comments.has(comments))
                    return;
                if (!(node instanceof AST_Statement || comments.every((c) => !/comment[134]/.test(c.type))))
                    return;
                printed_comments.add(comments);
                var insert = OUTPUT.length();
                comments.filter(comment_filter, node).forEach(function (c, i) {
                    if (printed_comments.has(c))
                        return;
                    printed_comments.add(c);
                    need_space = false;
                    if (need_newline_indented) {
                        print("\n");
                        indent();
                        need_newline_indented = false;
                    }
                    else if (c.nlb && (i > 0 || !has_nlb())) {
                        print("\n");
                        indent();
                    }
                    else if (i > 0 || !tail) {
                        space();
                    }
                    if (/comment[134]/.test(c.type)) {
                        const value = filter_comment(c.value);
                        if (value) {
                            print("//" + value);
                        }
                        need_newline_indented = true;
                    }
                    else if (c.type == "comment2") {
                        const value = filter_comment(c.value);
                        if (value) {
                            print("/*" + value + "*/");
                        }
                        need_space = true;
                    }
                });
                if (OUTPUT.length() > insert)
                    newline_insert = insert;
            }
            /**
             * When output.option("_destroy_ast") is enabled, destroy the function.
             * Call this after printing it.
             */
            const gc_scope = options["_destroy_ast"]
                ? function gc_scope(scope) {
                    scope.body.length = 0;
                    scope.argnames.length = 0;
                }
                : noop;
            var stack = [];
            return {
                get: get,
                toString: get,
                indent: indent,
                in_directive: false,
                use_asm: null,
                active_scope: null,
                indentation: function () { return indentation; },
                current_width: function () { return current_col - indentation; },
                should_break: function () { return options.width && this.current_width() >= options.width; },
                has_parens: function () { return has_parens; },
                newline: newline,
                print: print,
                star: star,
                space: space,
                comma: comma,
                colon: colon,
                last: function () { return last; },
                semicolon: semicolon,
                force_semicolon: force_semicolon,
                to_utf8: to_utf8,
                print_name: function (name) { print(make_name(name)); },
                print_string: function (str, quote, escape_directive) {
                    var encoded = encode_string(str, quote);
                    if (escape_directive === true && !encoded.includes("\\")) {
                        // Insert semicolons to break directive prologue
                        if (!EXPECT_DIRECTIVE.test(OUTPUT.toString())) {
                            force_semicolon();
                        }
                        force_semicolon();
                    }
                    print(encoded);
                },
                print_template_string_chars: function (str) {
                    var encoded = encode_string(str, "`").replace(/\${/g, "\\${");
                    return print(encoded.substr(1, encoded.length - 2));
                },
                encode_string: encode_string,
                next_indent: next_indent,
                with_indent: with_indent,
                with_block: with_block,
                with_parens: with_parens,
                with_square: with_square,
                add_mapping: add_mapping,
                option: function (opt) { return options[opt]; },
                gc_scope,
                printed_comments: printed_comments,
                prepend_comments: readonly ? noop : prepend_comments,
                append_comments: readonly || comment_filter === return_false ? noop : append_comments,
                line: function () { return current_line; },
                col: function () { return current_col; },
                pos: function () { return current_pos; },
                push_node: function (node) { stack.push(node); },
                pop_node: function () { return stack.pop(); },
                parent: function (n) {
                    return stack[stack.length - 2 - (n || 0)];
                }
            };
        }
        /* -----[ code generators ]----- */
        (function () {
            /* -----[ utils ]----- */
            function DEFPRINT(nodetype, generator) {
                nodetype.DEFMETHOD("_codegen", generator);
            }
            AST_Node.DEFMETHOD("print", function (output, force_parens) {
                var self = this, generator = self._codegen;
                if (self instanceof AST_Scope) {
                    output.active_scope = self;
                }
                else if (!output.use_asm && self instanceof AST_Directive && self.value == "use asm") {
                    output.use_asm = output.active_scope;
                }
                function doit() {
                    output.prepend_comments(self);
                    self.add_source_map(output);
                    generator(self, output);
                    output.append_comments(self);
                }
                output.push_node(self);
                if (force_parens || self.needs_parens(output)) {
                    output.with_parens(doit);
                }
                else {
                    doit();
                }
                output.pop_node();
                if (self === output.use_asm) {
                    output.use_asm = null;
                }
            });
            AST_Node.DEFMETHOD("_print", AST_Node.prototype.print);
            AST_Node.DEFMETHOD("print_to_string", function (options) {
                var output = OutputStream(options);
                this.print(output);
                return output.get();
            });
            /* -----[ PARENTHESES ]----- */
            function PARENS(nodetype, func) {
                if (Array.isArray(nodetype)) {
                    nodetype.forEach(function (nodetype) {
                        PARENS(nodetype, func);
                    });
                }
                else {
                    nodetype.DEFMETHOD("needs_parens", func);
                }
            }
            PARENS(AST_Node, return_false);
            // a function expression needs parens around it when it's provably
            // the first token to appear in a statement.
            PARENS(AST_Function, function (output) {
                if (!output.has_parens() && first_in_statement(output)) {
                    return true;
                }
                if (output.option("webkit")) {
                    var p = output.parent();
                    if (p instanceof AST_PropAccess && p.expression === this) {
                        return true;
                    }
                }
                if (output.option("wrap_iife")) {
                    var p = output.parent();
                    if (p instanceof AST_Call && p.expression === this) {
                        return true;
                    }
                }
                if (output.option("wrap_func_args")) {
                    var p = output.parent();
                    if (p instanceof AST_Call && p.args.includes(this)) {
                        return true;
                    }
                }
                return false;
            });
            PARENS(AST_Arrow, function (output) {
                var p = output.parent();
                if (output.option("wrap_func_args")
                    && p instanceof AST_Call
                    && p.args.includes(this)) {
                    return true;
                }
                return p instanceof AST_PropAccess && p.expression === this;
            });
            // same goes for an object literal (as in AST_Function), because
            // otherwise {...} would be interpreted as a block of code.
            PARENS(AST_Object, function (output) {
                return !output.has_parens() && first_in_statement(output);
            });
            PARENS(AST_ClassExpression, first_in_statement);
            PARENS(AST_Unary, function (output) {
                var p = output.parent();
                return p instanceof AST_PropAccess && p.expression === this
                    || p instanceof AST_Call && p.expression === this
                    || p instanceof AST_Binary
                        && p.operator === "**"
                        && this instanceof AST_UnaryPrefix
                        && p.left === this
                        && this.operator !== "++"
                        && this.operator !== "--";
            });
            PARENS(AST_Await, function (output) {
                var p = output.parent();
                return p instanceof AST_PropAccess && p.expression === this
                    || p instanceof AST_Call && p.expression === this
                    || p instanceof AST_Binary && p.operator === "**" && p.left === this
                    || output.option("safari10") && p instanceof AST_UnaryPrefix;
            });
            PARENS(AST_Sequence, function (output) {
                var p = output.parent();
                return p instanceof AST_Call // (foo, bar)() or foo(1, (2, 3), 4)
                    || p instanceof AST_Unary // !(foo, bar, baz)
                    || p instanceof AST_Binary // 1 + (2, 3) + 4 ==> 8
                    || p instanceof AST_VarDef // var a = (1, 2), b = a + a; ==> b == 4
                    || p instanceof AST_PropAccess // (1, {foo:2}).foo or (1, {foo:2})["foo"] ==> 2
                    || p instanceof AST_Array // [ 1, (2, 3), 4 ] ==> [ 1, 3, 4 ]
                    || p instanceof AST_ObjectProperty // { foo: (1, 2) }.foo ==> 2
                    || p instanceof AST_Conditional /* (false, true) ? (a = 10, b = 20) : (c = 30)
                                                                   * ==> 20 (side effect, set a := 10 and b := 20) */
                    || p instanceof AST_Arrow // x => (x, x)
                    || p instanceof AST_DefaultAssign // x => (x = (0, function(){}))
                    || p instanceof AST_Expansion // [...(a, b)]
                    || p instanceof AST_ForOf && this === p.object // for (e of (foo, bar)) {}
                    || p instanceof AST_Yield // yield (foo, bar)
                    || p instanceof AST_Export // export default (foo, bar)
                ;
            });
            PARENS(AST_Binary, function (output) {
                var p = output.parent();
                // (foo && bar)()
                if (p instanceof AST_Call && p.expression === this)
                    return true;
                // typeof (foo && bar)
                if (p instanceof AST_Unary)
                    return true;
                // (foo && bar)["prop"], (foo && bar).prop
                if (p instanceof AST_PropAccess && p.expression === this)
                    return true;
                // this deals with precedence: 3 * (2 + 1)
                if (p instanceof AST_Binary) {
                    const po = p.operator;
                    const so = this.operator;
                    if (so === "??" && (po === "||" || po === "&&")) {
                        return true;
                    }
                    if (po === "??" && (so === "||" || so === "&&")) {
                        return true;
                    }
                    const pp = PRECEDENCE[po];
                    const sp = PRECEDENCE[so];
                    if (pp > sp
                        || (pp == sp
                            && (this === p.right || po == "**"))) {
                        return true;
                    }
                }
            });
            PARENS(AST_Yield, function (output) {
                var p = output.parent();
                // (yield 1) + (yield 2)
                // a = yield 3
                if (p instanceof AST_Binary && p.operator !== "=")
                    return true;
                // (yield 1)()
                // new (yield 1)()
                if (p instanceof AST_Call && p.expression === this)
                    return true;
                // (yield 1) ? yield 2 : yield 3
                if (p instanceof AST_Conditional && p.condition === this)
                    return true;
                // -(yield 4)
                if (p instanceof AST_Unary)
                    return true;
                // (yield x).foo
                // (yield x)['foo']
                if (p instanceof AST_PropAccess && p.expression === this)
                    return true;
            });
            PARENS(AST_PropAccess, function (output) {
                var p = output.parent();
                if (p instanceof AST_New && p.expression === this) {
                    // i.e. new (foo.bar().baz)
                    //
                    // if there's one call into this subtree, then we need
                    // parens around it too, otherwise the call will be
                    // interpreted as passing the arguments to the upper New
                    // expression.
                    return walk(this, node => {
                        if (node instanceof AST_Scope)
                            return true;
                        if (node instanceof AST_Call) {
                            return walk_abort; // makes walk() return true.
                        }
                    });
                }
            });
            PARENS(AST_Call, function (output) {
                var p = output.parent(), p1;
                if (p instanceof AST_New && p.expression === this
                    || p instanceof AST_Export && p.is_default && this.expression instanceof AST_Function)
                    return true;
                // workaround for Safari bug.
                // https://bugs.webkit.org/show_bug.cgi?id=123506
                return this.expression instanceof AST_Function
                    && p instanceof AST_PropAccess
                    && p.expression === this
                    && (p1 = output.parent(1)) instanceof AST_Assign
                    && p1.left === p;
            });
            PARENS(AST_New, function (output) {
                var p = output.parent();
                if (this.args.length === 0
                    && (p instanceof AST_PropAccess // (new Date).getTime(), (new Date)["getTime"]()
                        || p instanceof AST_Call && p.expression === this
                        || p instanceof AST_PrefixedTemplateString && p.prefix === this)) // (new foo)(bar)
                    return true;
            });
            PARENS(AST_Number, function (output) {
                var p = output.parent();
                if (p instanceof AST_PropAccess && p.expression === this) {
                    var value = this.getValue();
                    if (value < 0 || /^0/.test(make_num(value))) {
                        return true;
                    }
                }
            });
            PARENS(AST_BigInt, function (output) {
                var p = output.parent();
                if (p instanceof AST_PropAccess && p.expression === this) {
                    var value = this.getValue();
                    if (value.startsWith("-")) {
                        return true;
                    }
                }
            });
            PARENS([AST_Assign, AST_Conditional], function (output) {
                var p = output.parent();
                // !(a = false) → true
                if (p instanceof AST_Unary)
                    return true;
                // 1 + (a = 2) + 3 → 6, side effect setting a = 2
                if (p instanceof AST_Binary && !(p instanceof AST_Assign))
                    return true;
                // (a = func)() —or— new (a = Object)()
                if (p instanceof AST_Call && p.expression === this)
                    return true;
                // (a = foo) ? bar : baz
                if (p instanceof AST_Conditional && p.condition === this)
                    return true;
                // (a = foo)["prop"] —or— (a = foo).prop
                if (p instanceof AST_PropAccess && p.expression === this)
                    return true;
                // ({a, b} = {a: 1, b: 2}), a destructuring assignment
                if (this instanceof AST_Assign && this.left instanceof AST_Destructuring && this.left.is_array === false)
                    return true;
            });
            /* -----[ PRINTERS ]----- */
            DEFPRINT(AST_Directive, function (self, output) {
                output.print_string(self.value, self.quote);
                output.semicolon();
            });
            DEFPRINT(AST_Expansion, function (self, output) {
                output.print("...");
                self.expression.print(output);
            });
            DEFPRINT(AST_Destructuring, function (self, output) {
                output.print(self.is_array ? "[" : "{");
                var len = self.names.length;
                self.names.forEach(function (name, i) {
                    if (i > 0)
                        output.comma();
                    name.print(output);
                    // If the final element is a hole, we need to make sure it
                    // doesn't look like a trailing comma, by inserting an actual
                    // trailing comma.
                    if (i == len - 1 && name instanceof AST_Hole)
                        output.comma();
                });
                output.print(self.is_array ? "]" : "}");
            });
            DEFPRINT(AST_Debugger, function (self, output) {
                output.print("debugger");
                output.semicolon();
            });
            /* -----[ statements ]----- */
            function display_body(body, is_toplevel, output, allow_directives) {
                var last = body.length - 1;
                output.in_directive = allow_directives;
                body.forEach(function (stmt, i) {
                    if (output.in_directive === true && !(stmt instanceof AST_Directive ||
                        stmt instanceof AST_EmptyStatement ||
                        (stmt instanceof AST_SimpleStatement && stmt.body instanceof AST_String))) {
                        output.in_directive = false;
                    }
                    if (!(stmt instanceof AST_EmptyStatement)) {
                        output.indent();
                        stmt.print(output);
                        if (!(i == last && is_toplevel)) {
                            output.newline();
                            if (is_toplevel)
                                output.newline();
                        }
                    }
                    if (output.in_directive === true &&
                        stmt instanceof AST_SimpleStatement &&
                        stmt.body instanceof AST_String) {
                        output.in_directive = false;
                    }
                });
                output.in_directive = false;
            }
            AST_StatementWithBody.DEFMETHOD("_do_print_body", function (output) {
                print_maybe_braced_body(this.body, output);
            });
            DEFPRINT(AST_Statement, function (self, output) {
                self.body.print(output);
                output.semicolon();
            });
            DEFPRINT(AST_Toplevel, function (self, output) {
                display_body(self.body, true, output, true);
                output.print("");
            });
            DEFPRINT(AST_LabeledStatement, function (self, output) {
                self.label.print(output);
                output.colon();
                self.body.print(output);
            });
            DEFPRINT(AST_SimpleStatement, function (self, output) {
                self.body.print(output);
                output.semicolon();
            });
            function print_braced_empty(self, output) {
                output.print("{");
                output.with_indent(output.next_indent(), function () {
                    output.append_comments(self, true);
                });
                output.add_mapping(self.end);
                output.print("}");
            }
            function print_braced(self, output, allow_directives) {
                if (self.body.length > 0) {
                    output.with_block(function () {
                        display_body(self.body, false, output, allow_directives);
                        output.add_mapping(self.end);
                    });
                }
                else
                    print_braced_empty(self, output);
            }
            DEFPRINT(AST_BlockStatement, function (self, output) {
                print_braced(self, output);
            });
            DEFPRINT(AST_EmptyStatement, function (self, output) {
                output.semicolon();
            });
            DEFPRINT(AST_Do, function (self, output) {
                output.print("do");
                output.space();
                make_block(self.body, output);
                output.space();
                output.print("while");
                output.space();
                output.with_parens(function () {
                    self.condition.print(output);
                });
                output.semicolon();
            });
            DEFPRINT(AST_While, function (self, output) {
                output.print("while");
                output.space();
                output.with_parens(function () {
                    self.condition.print(output);
                });
                output.space();
                self._do_print_body(output);
            });
            DEFPRINT(AST_For, function (self, output) {
                output.print("for");
                output.space();
                output.with_parens(function () {
                    if (self.init) {
                        if (self.init instanceof AST_Definitions) {
                            self.init.print(output);
                        }
                        else {
                            parenthesize_for_noin(self.init, output, true);
                        }
                        output.print(";");
                        output.space();
                    }
                    else {
                        output.print(";");
                    }
                    if (self.condition) {
                        self.condition.print(output);
                        output.print(";");
                        output.space();
                    }
                    else {
                        output.print(";");
                    }
                    if (self.step) {
                        self.step.print(output);
                    }
                });
                output.space();
                self._do_print_body(output);
            });
            DEFPRINT(AST_ForIn, function (self, output) {
                output.print("for");
                if (self.await) {
                    output.space();
                    output.print("await");
                }
                output.space();
                output.with_parens(function () {
                    self.init.print(output);
                    output.space();
                    output.print(self instanceof AST_ForOf ? "of" : "in");
                    output.space();
                    self.object.print(output);
                });
                output.space();
                self._do_print_body(output);
            });
            DEFPRINT(AST_With, function (self, output) {
                output.print("with");
                output.space();
                output.with_parens(function () {
                    self.expression.print(output);
                });
                output.space();
                self._do_print_body(output);
            });
            /* -----[ functions ]----- */
            AST_Lambda.DEFMETHOD("_do_print", function (output, nokeyword) {
                var self = this;
                if (!nokeyword) {
                    if (self.async) {
                        output.print("async");
                        output.space();
                    }
                    output.print("function");
                    if (self.is_generator) {
                        output.star();
                    }
                    if (self.name) {
                        output.space();
                    }
                }
                if (self.name instanceof AST_Symbol) {
                    self.name.print(output);
                }
                else if (nokeyword && self.name instanceof AST_Node) {
                    output.with_square(function () {
                        self.name.print(output); // Computed method name
                    });
                }
                output.with_parens(function () {
                    self.argnames.forEach(function (arg, i) {
                        if (i)
                            output.comma();
                        arg.print(output);
                    });
                });
                output.space();
                print_braced(self, output, true);
            });
            DEFPRINT(AST_Lambda, function (self, output) {
                self._do_print(output);
                output.gc_scope(self);
            });
            DEFPRINT(AST_PrefixedTemplateString, function (self, output) {
                var tag = self.prefix;
                var parenthesize_tag = tag instanceof AST_Lambda
                    || tag instanceof AST_Binary
                    || tag instanceof AST_Conditional
                    || tag instanceof AST_Sequence
                    || tag instanceof AST_Unary
                    || tag instanceof AST_Dot && tag.expression instanceof AST_Object;
                if (parenthesize_tag)
                    output.print("(");
                self.prefix.print(output);
                if (parenthesize_tag)
                    output.print(")");
                self.template_string.print(output);
            });
            DEFPRINT(AST_TemplateString, function (self, output) {
                var is_tagged = output.parent() instanceof AST_PrefixedTemplateString;
                output.print("`");
                for (var i = 0; i < self.segments.length; i++) {
                    if (!(self.segments[i] instanceof AST_TemplateSegment)) {
                        output.print("${");
                        self.segments[i].print(output);
                        output.print("}");
                    }
                    else if (is_tagged) {
                        output.print(self.segments[i].raw);
                    }
                    else {
                        output.print_template_string_chars(self.segments[i].value);
                    }
                }
                output.print("`");
            });
            DEFPRINT(AST_TemplateSegment, function (self, output) {
                output.print_template_string_chars(self.value);
            });
            AST_Arrow.DEFMETHOD("_do_print", function (output) {
                var self = this;
                var parent = output.parent();
                var needs_parens = (parent instanceof AST_Binary && !(parent instanceof AST_Assign)) ||
                    parent instanceof AST_Unary ||
                    (parent instanceof AST_Call && self === parent.expression);
                if (needs_parens) {
                    output.print("(");
                }
                if (self.async) {
                    output.print("async");
                    output.space();
                }
                if (self.argnames.length === 1 && self.argnames[0] instanceof AST_Symbol) {
                    self.argnames[0].print(output);
                }
                else {
                    output.with_parens(function () {
                        self.argnames.forEach(function (arg, i) {
                            if (i)
                                output.comma();
                            arg.print(output);
                        });
                    });
                }
                output.space();
                output.print("=>");
                output.space();
                const first_statement = self.body[0];
                if (self.body.length === 1
                    && first_statement instanceof AST_Return) {
                    const returned = first_statement.value;
                    if (!returned) {
                        output.print("{}");
                    }
                    else if (left_is_object(returned)) {
                        output.print("(");
                        returned.print(output);
                        output.print(")");
                    }
                    else {
                        returned.print(output);
                    }
                }
                else {
                    print_braced(self, output);
                }
                if (needs_parens) {
                    output.print(")");
                }
                output.gc_scope(self);
            });
            /* -----[ exits ]----- */
            AST_Exit.DEFMETHOD("_do_print", function (output, kind) {
                output.print(kind);
                if (this.value) {
                    output.space();
                    const comments = this.value.start.comments_before;
                    if (comments && comments.length && !output.printed_comments.has(comments)) {
                        output.print("(");
                        this.value.print(output);
                        output.print(")");
                    }
                    else {
                        this.value.print(output);
                    }
                }
                output.semicolon();
            });
            DEFPRINT(AST_Return, function (self, output) {
                self._do_print(output, "return");
            });
            DEFPRINT(AST_Throw, function (self, output) {
                self._do_print(output, "throw");
            });
            /* -----[ yield ]----- */
            DEFPRINT(AST_Yield, function (self, output) {
                var star = self.is_star ? "*" : "";
                output.print("yield" + star);
                if (self.expression) {
                    output.space();
                    self.expression.print(output);
                }
            });
            DEFPRINT(AST_Await, function (self, output) {
                output.print("await");
                output.space();
                var e = self.expression;
                var parens = !(e instanceof AST_Call
                    || e instanceof AST_SymbolRef
                    || e instanceof AST_PropAccess
                    || e instanceof AST_Unary
                    || e instanceof AST_Constant
                    || e instanceof AST_Await
                    || e instanceof AST_Object);
                if (parens)
                    output.print("(");
                self.expression.print(output);
                if (parens)
                    output.print(")");
            });
            /* -----[ loop control ]----- */
            AST_LoopControl.DEFMETHOD("_do_print", function (output, kind) {
                output.print(kind);
                if (this.label) {
                    output.space();
                    this.label.print(output);
                }
                output.semicolon();
            });
            DEFPRINT(AST_Break, function (self, output) {
                self._do_print(output, "break");
            });
            DEFPRINT(AST_Continue, function (self, output) {
                self._do_print(output, "continue");
            });
            /* -----[ if ]----- */
            function make_then(self, output) {
                var b = self.body;
                if (output.option("braces")
                    || output.option("ie8") && b instanceof AST_Do)
                    return make_block(b, output);
                // The squeezer replaces "block"-s that contain only a single
                // statement with the statement itself; technically, the AST
                // is correct, but this can create problems when we output an
                // IF having an ELSE clause where the THEN clause ends in an
                // IF *without* an ELSE block (then the outer ELSE would refer
                // to the inner IF).  This function checks for this case and
                // adds the block braces if needed.
                if (!b)
                    return output.force_semicolon();
                while (true) {
                    if (b instanceof AST_If) {
                        if (!b.alternative) {
                            make_block(self.body, output);
                            return;
                        }
                        b = b.alternative;
                    }
                    else if (b instanceof AST_StatementWithBody) {
                        b = b.body;
                    }
                    else
                        break;
                }
                print_maybe_braced_body(self.body, output);
            }
            DEFPRINT(AST_If, function (self, output) {
                output.print("if");
                output.space();
                output.with_parens(function () {
                    self.condition.print(output);
                });
                output.space();
                if (self.alternative) {
                    make_then(self, output);
                    output.space();
                    output.print("else");
                    output.space();
                    if (self.alternative instanceof AST_If)
                        self.alternative.print(output);
                    else
                        print_maybe_braced_body(self.alternative, output);
                }
                else {
                    self._do_print_body(output);
                }
            });
            /* -----[ switch ]----- */
            DEFPRINT(AST_Switch, function (self, output) {
                output.print("switch");
                output.space();
                output.with_parens(function () {
                    self.expression.print(output);
                });
                output.space();
                var last = self.body.length - 1;
                if (last < 0)
                    print_braced_empty(self, output);
                else
                    output.with_block(function () {
                        self.body.forEach(function (branch, i) {
                            output.indent(true);
                            branch.print(output);
                            if (i < last && branch.body.length > 0)
                                output.newline();
                        });
                    });
            });
            AST_SwitchBranch.DEFMETHOD("_do_print_body", function (output) {
                output.newline();
                this.body.forEach(function (stmt) {
                    output.indent();
                    stmt.print(output);
                    output.newline();
                });
            });
            DEFPRINT(AST_Default, function (self, output) {
                output.print("default:");
                self._do_print_body(output);
            });
            DEFPRINT(AST_Case, function (self, output) {
                output.print("case");
                output.space();
                self.expression.print(output);
                output.print(":");
                self._do_print_body(output);
            });
            /* -----[ exceptions ]----- */
            DEFPRINT(AST_Try, function (self, output) {
                output.print("try");
                output.space();
                self.body.print(output);
                if (self.bcatch) {
                    output.space();
                    self.bcatch.print(output);
                }
                if (self.bfinally) {
                    output.space();
                    self.bfinally.print(output);
                }
            });
            DEFPRINT(AST_TryBlock, function (self, output) {
                print_braced(self, output);
            });
            DEFPRINT(AST_Catch, function (self, output) {
                output.print("catch");
                if (self.argname) {
                    output.space();
                    output.with_parens(function () {
                        self.argname.print(output);
                    });
                }
                output.space();
                print_braced(self, output);
            });
            DEFPRINT(AST_Finally, function (self, output) {
                output.print("finally");
                output.space();
                print_braced(self, output);
            });
            /* -----[ var/const ]----- */
            AST_Definitions.DEFMETHOD("_do_print", function (output, kind) {
                output.print(kind);
                output.space();
                this.definitions.forEach(function (def, i) {
                    if (i)
                        output.comma();
                    def.print(output);
                });
                var p = output.parent();
                var in_for = p instanceof AST_For || p instanceof AST_ForIn;
                var output_semicolon = !in_for || p && p.init !== this;
                if (output_semicolon)
                    output.semicolon();
            });
            DEFPRINT(AST_Let, function (self, output) {
                self._do_print(output, "let");
            });
            DEFPRINT(AST_Var, function (self, output) {
                self._do_print(output, "var");
            });
            DEFPRINT(AST_Const, function (self, output) {
                self._do_print(output, "const");
            });
            DEFPRINT(AST_Import, function (self, output) {
                output.print("import");
                output.space();
                if (self.imported_name) {
                    self.imported_name.print(output);
                }
                if (self.imported_name && self.imported_names) {
                    output.print(",");
                    output.space();
                }
                if (self.imported_names) {
                    if (self.imported_names.length === 1 &&
                        self.imported_names[0].foreign_name.name === "*" &&
                        !self.imported_names[0].foreign_name.quote) {
                        self.imported_names[0].print(output);
                    }
                    else {
                        output.print("{");
                        self.imported_names.forEach(function (name_import, i) {
                            output.space();
                            name_import.print(output);
                            if (i < self.imported_names.length - 1) {
                                output.print(",");
                            }
                        });
                        output.space();
                        output.print("}");
                    }
                }
                if (self.imported_name || self.imported_names) {
                    output.space();
                    output.print("from");
                    output.space();
                }
                self.module_name.print(output);
                if (self.assert_clause) {
                    output.print("assert");
                    self.assert_clause.print(output);
                }
                output.semicolon();
            });
            DEFPRINT(AST_ImportMeta, function (self, output) {
                output.print("import.meta");
            });
            DEFPRINT(AST_NameMapping, function (self, output) {
                var is_import = output.parent() instanceof AST_Import;
                var definition = self.name.definition();
                var foreign_name = self.foreign_name;
                var names_are_different = (definition && definition.mangled_name || self.name.name) !==
                    foreign_name.name;
                if (!names_are_different &&
                    foreign_name.name === "*" &&
                    foreign_name.quote != self.name.quote) {
                    // export * as "*"
                    names_are_different = true;
                }
                var foreign_name_is_name = foreign_name.quote == null;
                if (names_are_different) {
                    if (is_import) {
                        if (foreign_name_is_name) {
                            output.print(foreign_name.name);
                        }
                        else {
                            output.print_string(foreign_name.name, foreign_name.quote);
                        }
                    }
                    else {
                        if (self.name.quote == null) {
                            self.name.print(output);
                        }
                        else {
                            output.print_string(self.name.name, self.name.quote);
                        }
                    }
                    output.space();
                    output.print("as");
                    output.space();
                    if (is_import) {
                        self.name.print(output);
                    }
                    else {
                        if (foreign_name_is_name) {
                            output.print(foreign_name.name);
                        }
                        else {
                            output.print_string(foreign_name.name, foreign_name.quote);
                        }
                    }
                }
                else {
                    if (self.name.quote == null) {
                        self.name.print(output);
                    }
                    else {
                        output.print_string(self.name.name, self.name.quote);
                    }
                }
            });
            DEFPRINT(AST_Export, function (self, output) {
                output.print("export");
                output.space();
                if (self.is_default) {
                    output.print("default");
                    output.space();
                }
                if (self.exported_names) {
                    if (self.exported_names.length === 1 &&
                        self.exported_names[0].name.name === "*" &&
                        !self.exported_names[0].name.quote) {
                        self.exported_names[0].print(output);
                    }
                    else {
                        output.print("{");
                        self.exported_names.forEach(function (name_export, i) {
                            output.space();
                            name_export.print(output);
                            if (i < self.exported_names.length - 1) {
                                output.print(",");
                            }
                        });
                        output.space();
                        output.print("}");
                    }
                }
                else if (self.exported_value) {
                    self.exported_value.print(output);
                }
                else if (self.exported_definition) {
                    self.exported_definition.print(output);
                    if (self.exported_definition instanceof AST_Definitions)
                        return;
                }
                if (self.module_name) {
                    output.space();
                    output.print("from");
                    output.space();
                    self.module_name.print(output);
                }
                if (self.assert_clause) {
                    output.print("assert");
                    self.assert_clause.print(output);
                }
                if (self.exported_value
                    && !(self.exported_value instanceof AST_Defun ||
                        self.exported_value instanceof AST_Function ||
                        self.exported_value instanceof AST_Class)
                    || self.module_name
                    || self.exported_names) {
                    output.semicolon();
                }
            });
            function parenthesize_for_noin(node, output, noin) {
                var parens = false;
                // need to take some precautions here:
                //    https://github.com/mishoo/UglifyJS2/issues/60
                if (noin) {
                    parens = walk(node, node => {
                        // Don't go into scopes -- except arrow functions:
                        // https://github.com/terser/terser/issues/1019#issuecomment-877642607
                        if (node instanceof AST_Scope && !(node instanceof AST_Arrow)) {
                            return true;
                        }
                        if (node instanceof AST_Binary && node.operator == "in"
                            || node instanceof AST_PrivateIn) {
                            return walk_abort; // makes walk() return true
                        }
                    });
                }
                node.print(output, parens);
            }
            DEFPRINT(AST_VarDef, function (self, output) {
                self.name.print(output);
                if (self.value) {
                    output.space();
                    output.print("=");
                    output.space();
                    var p = output.parent(1);
                    var noin = p instanceof AST_For || p instanceof AST_ForIn;
                    parenthesize_for_noin(self.value, output, noin);
                }
            });
            /* -----[ other expressions ]----- */
            DEFPRINT(AST_Call, function (self, output) {
                self.expression.print(output);
                if (self instanceof AST_New && self.args.length === 0)
                    return;
                if (self.expression instanceof AST_Call || self.expression instanceof AST_Lambda) {
                    output.add_mapping(self.start);
                }
                if (self.optional)
                    output.print("?.");
                output.with_parens(function () {
                    self.args.forEach(function (expr, i) {
                        if (i)
                            output.comma();
                        expr.print(output);
                    });
                });
            });
            DEFPRINT(AST_New, function (self, output) {
                output.print("new");
                output.space();
                AST_Call.prototype._codegen(self, output);
            });
            AST_Sequence.DEFMETHOD("_do_print", function (output) {
                this.expressions.forEach(function (node, index) {
                    if (index > 0) {
                        output.comma();
                        if (output.should_break()) {
                            output.newline();
                            output.indent();
                        }
                    }
                    node.print(output);
                });
            });
            DEFPRINT(AST_Sequence, function (self, output) {
                self._do_print(output);
                // var p = output.parent();
                // if (p instanceof AST_Statement) {
                //     output.with_indent(output.next_indent(), function(){
                //         self._do_print(output);
                //     });
                // } else {
                //     self._do_print(output);
                // }
            });
            DEFPRINT(AST_Dot, function (self, output) {
                var expr = self.expression;
                expr.print(output);
                var prop = self.property;
                var print_computed = ALL_RESERVED_WORDS.has(prop)
                    ? output.option("ie8")
                    : !is_identifier_string(prop, output.option("ecma") >= 2015 || output.option("safari10"));
                if (self.optional)
                    output.print("?.");
                if (print_computed) {
                    output.print("[");
                    output.add_mapping(self.end);
                    output.print_string(prop);
                    output.print("]");
                }
                else {
                    if (expr instanceof AST_Number && expr.getValue() >= 0) {
                        if (!/[xa-f.)]/i.test(output.last())) {
                            output.print(".");
                        }
                    }
                    if (!self.optional)
                        output.print(".");
                    // the name after dot would be mapped about here.
                    output.add_mapping(self.end);
                    output.print_name(prop);
                }
            });
            DEFPRINT(AST_DotHash, function (self, output) {
                var expr = self.expression;
                expr.print(output);
                var prop = self.property;
                if (self.optional)
                    output.print("?");
                output.print(".#");
                output.add_mapping(self.end);
                output.print_name(prop);
            });
            DEFPRINT(AST_Sub, function (self, output) {
                self.expression.print(output);
                if (self.optional)
                    output.print("?.");
                output.print("[");
                self.property.print(output);
                output.print("]");
            });
            DEFPRINT(AST_Chain, function (self, output) {
                self.expression.print(output);
            });
            DEFPRINT(AST_UnaryPrefix, function (self, output) {
                var op = self.operator;
                output.print(op);
                if (/^[a-z]/i.test(op)
                    || (/[+-]$/.test(op)
                        && self.expression instanceof AST_UnaryPrefix
                        && /^[+-]/.test(self.expression.operator))) {
                    output.space();
                }
                self.expression.print(output);
            });
            DEFPRINT(AST_UnaryPostfix, function (self, output) {
                self.expression.print(output);
                output.print(self.operator);
            });
            DEFPRINT(AST_Binary, function (self, output) {
                var op = self.operator;
                self.left.print(output);
                if (op[0] == ">" /* ">>" ">>>" ">" ">=" */
                    && self.left instanceof AST_UnaryPostfix
                    && self.left.operator == "--") {
                    // space is mandatory to avoid outputting -->
                    output.print(" ");
                }
                else {
                    // the space is optional depending on "beautify"
                    output.space();
                }
                output.print(op);
                if ((op == "<" || op == "<<")
                    && self.right instanceof AST_UnaryPrefix
                    && self.right.operator == "!"
                    && self.right.expression instanceof AST_UnaryPrefix
                    && self.right.expression.operator == "--") {
                    // space is mandatory to avoid outputting <!--
                    output.print(" ");
                }
                else {
                    // the space is optional depending on "beautify"
                    output.space();
                }
                self.right.print(output);
            });
            DEFPRINT(AST_Conditional, function (self, output) {
                self.condition.print(output);
                output.space();
                output.print("?");
                output.space();
                self.consequent.print(output);
                output.space();
                output.colon();
                self.alternative.print(output);
            });
            /* -----[ literals ]----- */
            DEFPRINT(AST_Array, function (self, output) {
                output.with_square(function () {
                    var a = self.elements, len = a.length;
                    if (len > 0)
                        output.space();
                    a.forEach(function (exp, i) {
                        if (i)
                            output.comma();
                        exp.print(output);
                        // If the final element is a hole, we need to make sure it
                        // doesn't look like a trailing comma, by inserting an actual
                        // trailing comma.
                        if (i === len - 1 && exp instanceof AST_Hole)
                            output.comma();
                    });
                    if (len > 0)
                        output.space();
                });
            });
            DEFPRINT(AST_Object, function (self, output) {
                if (self.properties.length > 0)
                    output.with_block(function () {
                        self.properties.forEach(function (prop, i) {
                            if (i) {
                                output.print(",");
                                output.newline();
                            }
                            output.indent();
                            prop.print(output);
                        });
                        output.newline();
                    });
                else
                    print_braced_empty(self, output);
            });
            DEFPRINT(AST_Class, function (self, output) {
                output.print("class");
                output.space();
                if (self.name) {
                    self.name.print(output);
                    output.space();
                }
                if (self.extends) {
                    var parens = (!(self.extends instanceof AST_SymbolRef)
                        && !(self.extends instanceof AST_PropAccess)
                        && !(self.extends instanceof AST_ClassExpression)
                        && !(self.extends instanceof AST_Function));
                    output.print("extends");
                    if (parens) {
                        output.print("(");
                    }
                    else {
                        output.space();
                    }
                    self.extends.print(output);
                    if (parens) {
                        output.print(")");
                    }
                    else {
                        output.space();
                    }
                }
                if (self.properties.length > 0)
                    output.with_block(function () {
                        self.properties.forEach(function (prop, i) {
                            if (i) {
                                output.newline();
                            }
                            output.indent();
                            prop.print(output);
                        });
                        output.newline();
                    });
                else
                    output.print("{}");
            });
            DEFPRINT(AST_NewTarget, function (self, output) {
                output.print("new.target");
            });
            function print_property_name(key, quote, output) {
                if (output.option("quote_keys")) {
                    return output.print_string(key);
                }
                if ("" + +key == key && key >= 0) {
                    if (output.option("keep_numbers")) {
                        return output.print(key);
                    }
                    return output.print(make_num(key));
                }
                var print_string = ALL_RESERVED_WORDS.has(key)
                    ? output.option("ie8")
                    : (output.option("ecma") < 2015 || output.option("safari10")
                        ? !is_basic_identifier_string(key)
                        : !is_identifier_string(key, true));
                if (print_string || (quote && output.option("keep_quoted_props"))) {
                    return output.print_string(key, quote);
                }
                return output.print_name(key);
            }
            DEFPRINT(AST_ObjectKeyVal, function (self, output) {
                function get_name(self) {
                    var def = self.definition();
                    return def ? def.mangled_name || def.name : self.name;
                }
                var allowShortHand = output.option("shorthand");
                if (allowShortHand &&
                    self.value instanceof AST_Symbol &&
                    is_identifier_string(self.key, output.option("ecma") >= 2015 || output.option("safari10")) &&
                    get_name(self.value) === self.key &&
                    !ALL_RESERVED_WORDS.has(self.key)) {
                    print_property_name(self.key, self.quote, output);
                }
                else if (allowShortHand &&
                    self.value instanceof AST_DefaultAssign &&
                    self.value.left instanceof AST_Symbol &&
                    is_identifier_string(self.key, output.option("ecma") >= 2015 || output.option("safari10")) &&
                    get_name(self.value.left) === self.key) {
                    print_property_name(self.key, self.quote, output);
                    output.space();
                    output.print("=");
                    output.space();
                    self.value.right.print(output);
                }
                else {
                    if (!(self.key instanceof AST_Node)) {
                        print_property_name(self.key, self.quote, output);
                    }
                    else {
                        output.with_square(function () {
                            self.key.print(output);
                        });
                    }
                    output.colon();
                    self.value.print(output);
                }
            });
            DEFPRINT(AST_ClassPrivateProperty, (self, output) => {
                if (self.static) {
                    output.print("static");
                    output.space();
                }
                output.print("#");
                print_property_name(self.key.name, self.quote, output);
                if (self.value) {
                    output.print("=");
                    self.value.print(output);
                }
                output.semicolon();
            });
            DEFPRINT(AST_ClassProperty, (self, output) => {
                if (self.static) {
                    output.print("static");
                    output.space();
                }
                if (self.key instanceof AST_SymbolClassProperty) {
                    print_property_name(self.key.name, self.quote, output);
                }
                else {
                    output.print("[");
                    self.key.print(output);
                    output.print("]");
                }
                if (self.value) {
                    output.print("=");
                    self.value.print(output);
                }
                output.semicolon();
            });
            AST_ObjectProperty.DEFMETHOD("_print_getter_setter", function (type, is_private, output) {
                var self = this;
                if (self.static) {
                    output.print("static");
                    output.space();
                }
                if (type) {
                    output.print(type);
                    output.space();
                }
                if (self.key instanceof AST_SymbolMethod) {
                    if (is_private)
                        output.print("#");
                    print_property_name(self.key.name, self.quote, output);
                }
                else {
                    output.with_square(function () {
                        self.key.print(output);
                    });
                }
                self.value._do_print(output, true);
            });
            DEFPRINT(AST_ObjectSetter, function (self, output) {
                self._print_getter_setter("set", false, output);
            });
            DEFPRINT(AST_ObjectGetter, function (self, output) {
                self._print_getter_setter("get", false, output);
            });
            DEFPRINT(AST_PrivateSetter, function (self, output) {
                self._print_getter_setter("set", true, output);
            });
            DEFPRINT(AST_PrivateGetter, function (self, output) {
                self._print_getter_setter("get", true, output);
            });
            DEFPRINT(AST_PrivateMethod, function (self, output) {
                var type;
                if (self.is_generator && self.async) {
                    type = "async*";
                }
                else if (self.is_generator) {
                    type = "*";
                }
                else if (self.async) {
                    type = "async";
                }
                self._print_getter_setter(type, true, output);
            });
            DEFPRINT(AST_PrivateIn, function (self, output) {
                self.key.print(output);
                output.space();
                output.print("in");
                output.space();
                self.value.print(output);
            });
            DEFPRINT(AST_SymbolPrivateProperty, function (self, output) {
                output.print("#" + self.name);
            });
            DEFPRINT(AST_ConciseMethod, function (self, output) {
                var type;
                if (self.is_generator && self.async) {
                    type = "async*";
                }
                else if (self.is_generator) {
                    type = "*";
                }
                else if (self.async) {
                    type = "async";
                }
                self._print_getter_setter(type, false, output);
            });
            DEFPRINT(AST_ClassStaticBlock, function (self, output) {
                output.print("static");
                output.space();
                print_braced(self, output);
            });
            AST_Symbol.DEFMETHOD("_do_print", function (output) {
                var def = this.definition();
                output.print_name(def ? def.mangled_name || def.name : this.name);
            });
            DEFPRINT(AST_Symbol, function (self, output) {
                self._do_print(output);
            });
            DEFPRINT(AST_Hole, noop);
            DEFPRINT(AST_This, function (self, output) {
                output.print("this");
            });
            DEFPRINT(AST_Super, function (self, output) {
                output.print("super");
            });
            DEFPRINT(AST_Constant, function (self, output) {
                output.print(self.getValue());
            });
            DEFPRINT(AST_String, function (self, output) {
                output.print_string(self.getValue(), self.quote, output.in_directive);
            });
            DEFPRINT(AST_Number, function (self, output) {
                if ((output.option("keep_numbers") || output.use_asm) && self.raw) {
                    output.print(self.raw);
                }
                else {
                    output.print(make_num(self.getValue()));
                }
            });
            DEFPRINT(AST_BigInt, function (self, output) {
                output.print(self.getValue() + "n");
            });
            const r_slash_script = /(<\s*\/\s*script)/i;
            const slash_script_replace = (_, $1) => $1.replace("/", "\\/");
            DEFPRINT(AST_RegExp, function (self, output) {
                let { source, flags } = self.getValue();
                source = regexp_source_fix(source);
                flags = flags ? sort_regexp_flags(flags) : "";
                source = source.replace(r_slash_script, slash_script_replace);
                output.print(output.to_utf8(`/${source}/${flags}`, false, true));
                const parent = output.parent();
                if (parent instanceof AST_Binary
                    && /^\w/.test(parent.operator)
                    && parent.left === self) {
                    output.print(" ");
                }
            });
            /** if, for, while, may or may not have braces surrounding its body */
            function print_maybe_braced_body(stat, output) {
                if (output.option("braces")) {
                    make_block(stat, output);
                }
                else {
                    if (!stat || stat instanceof AST_EmptyStatement)
                        output.force_semicolon();
                    else if (stat instanceof AST_Let || stat instanceof AST_Const || stat instanceof AST_Class)
                        make_block(stat, output);
                    else
                        stat.print(output);
                }
            }
            function best_of(a) {
                var best = a[0], len = best.length;
                for (var i = 1; i < a.length; ++i) {
                    if (a[i].length < len) {
                        best = a[i];
                        len = best.length;
                    }
                }
                return best;
            }
            function make_num(num) {
                var str = num.toString(10).replace(/^0\./, ".").replace("e+", "e");
                var candidates = [str];
                if (Math.floor(num) === num) {
                    if (num < 0) {
                        candidates.push("-0x" + (-num).toString(16).toLowerCase());
                    }
                    else {
                        candidates.push("0x" + num.toString(16).toLowerCase());
                    }
                }
                var match, len, digits;
                if (match = /^\.0+/.exec(str)) {
                    len = match[0].length;
                    digits = str.slice(len);
                    candidates.push(digits + "e-" + (digits.length + len - 1));
                }
                else if (match = /0+$/.exec(str)) {
                    len = match[0].length;
                    candidates.push(str.slice(0, -len) + "e" + len);
                }
                else if (match = /^(\d)\.(\d+)e(-?\d+)$/.exec(str)) {
                    candidates.push(match[1] + match[2] + "e" + (match[3] - match[2].length));
                }
                return best_of(candidates);
            }
            function make_block(stmt, output) {
                if (!stmt || stmt instanceof AST_EmptyStatement)
                    output.print("{}");
                else if (stmt instanceof AST_BlockStatement)
                    stmt.print(output);
                else
                    output.with_block(function () {
                        output.indent();
                        stmt.print(output);
                        output.newline();
                    });
            }
            /* -----[ source map generators ]----- */
            function DEFMAP(nodetype, generator) {
                nodetype.forEach(function (nodetype) {
                    nodetype.DEFMETHOD("add_source_map", generator);
                });
            }
            DEFMAP([
                // We could easily add info for ALL nodes, but it seems to me that
                // would be quite wasteful, hence this noop in the base class.
                AST_Node,
                // since the label symbol will mark it
                AST_LabeledStatement,
                AST_Toplevel,
            ], noop);
            // XXX: I'm not exactly sure if we need it for all of these nodes,
            // or if we should add even more.
            DEFMAP([
                AST_Array,
                AST_BlockStatement,
                AST_Catch,
                AST_Class,
                AST_Constant,
                AST_Debugger,
                AST_Definitions,
                AST_Directive,
                AST_Finally,
                AST_Jump,
                AST_Lambda,
                AST_New,
                AST_Object,
                AST_StatementWithBody,
                AST_Symbol,
                AST_Switch,
                AST_SwitchBranch,
                AST_TemplateString,
                AST_TemplateSegment,
                AST_Try,
            ], function (output) {
                output.add_mapping(this.start);
            });
            DEFMAP([
                AST_ObjectGetter,
                AST_ObjectSetter,
                AST_PrivateGetter,
                AST_PrivateSetter,
            ], function (output) {
                output.add_mapping(this.key.end, this.key.name);
            });
            DEFMAP([AST_ObjectProperty], function (output) {
                output.add_mapping(this.start, this.key);
            });
        })();
        const shallow_cmp = (node1, node2) => {
            return (node1 === null && node2 === null
                || node1.TYPE === node2.TYPE && node1.shallow_cmp(node2));
        };
        const equivalent_to = (tree1, tree2) => {
            if (!shallow_cmp(tree1, tree2))
                return false;
            const walk_1_state = [tree1];
            const walk_2_state = [tree2];
            const walk_1_push = walk_1_state.push.bind(walk_1_state);
            const walk_2_push = walk_2_state.push.bind(walk_2_state);
            while (walk_1_state.length && walk_2_state.length) {
                const node_1 = walk_1_state.pop();
                const node_2 = walk_2_state.pop();
                if (!shallow_cmp(node_1, node_2))
                    return false;
                node_1._children_backwards(walk_1_push);
                node_2._children_backwards(walk_2_push);
                if (walk_1_state.length !== walk_2_state.length) {
                    // Different number of children
                    return false;
                }
            }
            return walk_1_state.length == 0 && walk_2_state.length == 0;
        };
        const pass_through = () => true;
        AST_Node.prototype.shallow_cmp = function () {
            throw new Error("did not find a shallow_cmp function for " + this.constructor.name);
        };
        AST_Debugger.prototype.shallow_cmp = pass_through;
        AST_Directive.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_SimpleStatement.prototype.shallow_cmp = pass_through;
        AST_Block.prototype.shallow_cmp = pass_through;
        AST_EmptyStatement.prototype.shallow_cmp = pass_through;
        AST_LabeledStatement.prototype.shallow_cmp = function (other) {
            return this.label.name === other.label.name;
        };
        AST_Do.prototype.shallow_cmp = pass_through;
        AST_While.prototype.shallow_cmp = pass_through;
        AST_For.prototype.shallow_cmp = function (other) {
            return (this.init == null ? other.init == null : this.init === other.init) && (this.condition == null ? other.condition == null : this.condition === other.condition) && (this.step == null ? other.step == null : this.step === other.step);
        };
        AST_ForIn.prototype.shallow_cmp = pass_through;
        AST_ForOf.prototype.shallow_cmp = pass_through;
        AST_With.prototype.shallow_cmp = pass_through;
        AST_Toplevel.prototype.shallow_cmp = pass_through;
        AST_Expansion.prototype.shallow_cmp = pass_through;
        AST_Lambda.prototype.shallow_cmp = function (other) {
            return this.is_generator === other.is_generator && this.async === other.async;
        };
        AST_Destructuring.prototype.shallow_cmp = function (other) {
            return this.is_array === other.is_array;
        };
        AST_PrefixedTemplateString.prototype.shallow_cmp = pass_through;
        AST_TemplateString.prototype.shallow_cmp = pass_through;
        AST_TemplateSegment.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_Jump.prototype.shallow_cmp = pass_through;
        AST_LoopControl.prototype.shallow_cmp = pass_through;
        AST_Await.prototype.shallow_cmp = pass_through;
        AST_Yield.prototype.shallow_cmp = function (other) {
            return this.is_star === other.is_star;
        };
        AST_If.prototype.shallow_cmp = function (other) {
            return this.alternative == null ? other.alternative == null : this.alternative === other.alternative;
        };
        AST_Switch.prototype.shallow_cmp = pass_through;
        AST_SwitchBranch.prototype.shallow_cmp = pass_through;
        AST_Try.prototype.shallow_cmp = function (other) {
            return (this.body === other.body) && (this.bcatch == null ? other.bcatch == null : this.bcatch === other.bcatch) && (this.bfinally == null ? other.bfinally == null : this.bfinally === other.bfinally);
        };
        AST_Catch.prototype.shallow_cmp = function (other) {
            return this.argname == null ? other.argname == null : this.argname === other.argname;
        };
        AST_Finally.prototype.shallow_cmp = pass_through;
        AST_Definitions.prototype.shallow_cmp = pass_through;
        AST_VarDef.prototype.shallow_cmp = function (other) {
            return this.value == null ? other.value == null : this.value === other.value;
        };
        AST_NameMapping.prototype.shallow_cmp = pass_through;
        AST_Import.prototype.shallow_cmp = function (other) {
            return (this.imported_name == null ? other.imported_name == null : this.imported_name === other.imported_name) && (this.imported_names == null ? other.imported_names == null : this.imported_names === other.imported_names);
        };
        AST_ImportMeta.prototype.shallow_cmp = pass_through;
        AST_Export.prototype.shallow_cmp = function (other) {
            return (this.exported_definition == null ? other.exported_definition == null : this.exported_definition === other.exported_definition) && (this.exported_value == null ? other.exported_value == null : this.exported_value === other.exported_value) && (this.exported_names == null ? other.exported_names == null : this.exported_names === other.exported_names) && this.module_name === other.module_name && this.is_default === other.is_default;
        };
        AST_Call.prototype.shallow_cmp = pass_through;
        AST_Sequence.prototype.shallow_cmp = pass_through;
        AST_PropAccess.prototype.shallow_cmp = pass_through;
        AST_Chain.prototype.shallow_cmp = pass_through;
        AST_Dot.prototype.shallow_cmp = function (other) {
            return this.property === other.property;
        };
        AST_DotHash.prototype.shallow_cmp = function (other) {
            return this.property === other.property;
        };
        AST_Unary.prototype.shallow_cmp = function (other) {
            return this.operator === other.operator;
        };
        AST_Binary.prototype.shallow_cmp = function (other) {
            return this.operator === other.operator;
        };
        AST_Conditional.prototype.shallow_cmp = pass_through;
        AST_Array.prototype.shallow_cmp = pass_through;
        AST_Object.prototype.shallow_cmp = pass_through;
        AST_ObjectProperty.prototype.shallow_cmp = pass_through;
        AST_ObjectKeyVal.prototype.shallow_cmp = function (other) {
            return this.key === other.key;
        };
        AST_ObjectSetter.prototype.shallow_cmp = function (other) {
            return this.static === other.static;
        };
        AST_ObjectGetter.prototype.shallow_cmp = function (other) {
            return this.static === other.static;
        };
        AST_ConciseMethod.prototype.shallow_cmp = function (other) {
            return this.static === other.static && this.is_generator === other.is_generator && this.async === other.async;
        };
        AST_Class.prototype.shallow_cmp = function (other) {
            return (this.name == null ? other.name == null : this.name === other.name) && (this.extends == null ? other.extends == null : this.extends === other.extends);
        };
        AST_ClassProperty.prototype.shallow_cmp = function (other) {
            return this.static === other.static;
        };
        AST_Symbol.prototype.shallow_cmp = function (other) {
            return this.name === other.name;
        };
        AST_NewTarget.prototype.shallow_cmp = pass_through;
        AST_This.prototype.shallow_cmp = pass_through;
        AST_Super.prototype.shallow_cmp = pass_through;
        AST_String.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_Number.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_BigInt.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_RegExp.prototype.shallow_cmp = function (other) {
            return (this.value.flags === other.value.flags
                && this.value.source === other.value.source);
        };
        AST_Atom.prototype.shallow_cmp = pass_through;
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        const MASK_EXPORT_DONT_MANGLE = 1 << 0;
        const MASK_EXPORT_WANT_MANGLE = 1 << 1;
        let function_defs = null;
        let unmangleable_names = null;
        /**
         * When defined, there is a function declaration somewhere that's inside of a block.
         * See https://tc39.es/ecma262/multipage/additional-ecmascript-features-for-web-browsers.html#sec-block-level-function-declarations-web-legacy-compatibility-semantics
        */
        let scopes_with_block_defuns = null;
        class SymbolDef {
            constructor(scope, orig, init) {
                this.name = orig.name;
                this.orig = [orig];
                this.init = init;
                this.eliminated = 0;
                this.assignments = 0;
                this.scope = scope;
                this.replaced = 0;
                this.global = false;
                this.export = 0;
                this.mangled_name = null;
                this.undeclared = false;
                this.id = SymbolDef.next_id++;
                this.chained = false;
                this.direct_access = false;
                this.escaped = 0;
                this.recursive_refs = 0;
                this.references = [];
                this.should_replace = undefined;
                this.single_use = false;
                this.fixed = false;
                Object.seal(this);
            }
            fixed_value() {
                if (!this.fixed || this.fixed instanceof AST_Node)
                    return this.fixed;
                return this.fixed();
            }
            unmangleable(options) {
                if (!options)
                    options = {};
                if (function_defs &&
                    function_defs.has(this.id) &&
                    keep_name(options.keep_fnames, this.orig[0].name))
                    return true;
                return this.global && !options.toplevel
                    || (this.export & MASK_EXPORT_DONT_MANGLE)
                    || this.undeclared
                    || !options.eval && this.scope.pinned()
                    || (this.orig[0] instanceof AST_SymbolLambda
                        || this.orig[0] instanceof AST_SymbolDefun) && keep_name(options.keep_fnames, this.orig[0].name)
                    || this.orig[0] instanceof AST_SymbolMethod
                    || (this.orig[0] instanceof AST_SymbolClass
                        || this.orig[0] instanceof AST_SymbolDefClass) && keep_name(options.keep_classnames, this.orig[0].name);
            }
            mangle(options) {
                const cache = options.cache && options.cache.props;
                if (this.global && cache && cache.has(this.name)) {
                    this.mangled_name = cache.get(this.name);
                }
                else if (!this.mangled_name && !this.unmangleable(options)) {
                    var s = this.scope;
                    var sym = this.orig[0];
                    if (options.ie8 && sym instanceof AST_SymbolLambda)
                        s = s.parent_scope;
                    const redefinition = redefined_catch_def(this);
                    this.mangled_name = redefinition
                        ? redefinition.mangled_name || redefinition.name
                        : s.next_mangled(options, this);
                    if (this.global && cache) {
                        cache.set(this.name, this.mangled_name);
                    }
                }
            }
        }
        SymbolDef.next_id = 1;
        function redefined_catch_def(def) {
            if (def.orig[0] instanceof AST_SymbolCatch
                && def.scope.is_block_scope()) {
                return def.scope.get_defun_scope().variables.get(def.name);
            }
        }
        AST_Scope.DEFMETHOD("figure_out_scope", function (options, { parent_scope = null, toplevel = this } = {}) {
            options = defaults(options, {
                cache: null,
                ie8: false,
                safari10: false,
            });
            if (!(toplevel instanceof AST_Toplevel)) {
                throw new Error("Invalid toplevel scope");
            }
            // pass 1: setup scope chaining and handle definitions
            var scope = this.parent_scope = parent_scope;
            var labels = new Map();
            var defun = null;
            var in_destructuring = null;
            var for_scopes = [];
            var tw = new TreeWalker((node, descend) => {
                if (node.is_block_scope()) {
                    const save_scope = scope;
                    node.block_scope = scope = new AST_Scope(node);
                    scope._block_scope = true;
                    scope.init_scope_vars(save_scope);
                    scope.uses_with = save_scope.uses_with;
                    scope.uses_eval = save_scope.uses_eval;
                    if (options.safari10) {
                        if (node instanceof AST_For || node instanceof AST_ForIn || node instanceof AST_ForOf) {
                            for_scopes.push(scope);
                        }
                    }
                    if (node instanceof AST_Switch) {
                        // XXX: HACK! Ensure the switch expression gets the correct scope (the parent scope) and the body gets the contained scope
                        // AST_Switch has a scope within the body, but it itself "is a block scope"
                        // This means the switched expression has to belong to the outer scope
                        // while the body inside belongs to the switch itself.
                        // This is pretty nasty and warrants an AST change
                        const the_block_scope = scope;
                        scope = save_scope;
                        node.expression.walk(tw);
                        scope = the_block_scope;
                        for (let i = 0; i < node.body.length; i++) {
                            node.body[i].walk(tw);
                        }
                    }
                    else {
                        descend();
                    }
                    scope = save_scope;
                    return true;
                }
                if (node instanceof AST_Destructuring) {
                    const save_destructuring = in_destructuring;
                    in_destructuring = node;
                    descend();
                    in_destructuring = save_destructuring;
                    return true;
                }
                if (node instanceof AST_Scope) {
                    node.init_scope_vars(scope);
                    var save_scope = scope;
                    var save_defun = defun;
                    var save_labels = labels;
                    defun = scope = node;
                    labels = new Map();
                    descend();
                    scope = save_scope;
                    defun = save_defun;
                    labels = save_labels;
                    return true; // don't descend again in TreeWalker
                }
                if (node instanceof AST_LabeledStatement) {
                    var l = node.label;
                    if (labels.has(l.name)) {
                        throw new Error(string_template("Label {name} defined twice", l));
                    }
                    labels.set(l.name, l);
                    descend();
                    labels.delete(l.name);
                    return true; // no descend again
                }
                if (node instanceof AST_With) {
                    for (var s = scope; s; s = s.parent_scope)
                        s.uses_with = true;
                    return;
                }
                if (node instanceof AST_Symbol) {
                    node.scope = scope;
                }
                if (node instanceof AST_Label) {
                    node.thedef = node;
                    node.references = [];
                }
                if (node instanceof AST_SymbolLambda) {
                    defun.def_function(node, node.name == "arguments" ? undefined : defun);
                }
                else if (node instanceof AST_SymbolDefun) {
                    // Careful here, the scope where this should be defined is
                    // the parent scope.  The reason is that we enter a new
                    // scope when we encounter the AST_Defun node (which is
                    // instanceof AST_Scope) but we get to the symbol a bit
                    // later.
                    const closest_scope = defun.parent_scope;
                    // In strict mode, function definitions are block-scoped
                    node.scope = tw.directives["use strict"]
                        ? closest_scope
                        : closest_scope.get_defun_scope();
                    mark_export(node.scope.def_function(node, defun), 1);
                }
                else if (node instanceof AST_SymbolClass) {
                    mark_export(defun.def_variable(node, defun), 1);
                }
                else if (node instanceof AST_SymbolImport) {
                    scope.def_variable(node);
                }
                else if (node instanceof AST_SymbolDefClass) {
                    // This deals with the name of the class being available
                    // inside the class.
                    mark_export((node.scope = defun.parent_scope).def_function(node, defun), 1);
                }
                else if (node instanceof AST_SymbolVar
                    || node instanceof AST_SymbolLet
                    || node instanceof AST_SymbolConst
                    || node instanceof AST_SymbolCatch) {
                    var def;
                    if (node instanceof AST_SymbolBlockDeclaration) {
                        def = scope.def_variable(node, null);
                    }
                    else {
                        def = defun.def_variable(node, node.TYPE == "SymbolVar" ? null : undefined);
                    }
                    if (!def.orig.every((sym) => {
                        if (sym === node)
                            return true;
                        if (node instanceof AST_SymbolBlockDeclaration) {
                            return sym instanceof AST_SymbolLambda;
                        }
                        return !(sym instanceof AST_SymbolLet || sym instanceof AST_SymbolConst);
                    })) {
                        js_error(`"${node.name}" is redeclared`, node.start.file, node.start.line, node.start.col, node.start.pos);
                    }
                    if (!(node instanceof AST_SymbolFunarg))
                        mark_export(def, 2);
                    if (defun !== scope) {
                        node.mark_enclosed();
                        var def = scope.find_variable(node);
                        if (node.thedef !== def) {
                            node.thedef = def;
                            node.reference();
                        }
                    }
                }
                else if (node instanceof AST_LabelRef) {
                    var sym = labels.get(node.name);
                    if (!sym)
                        throw new Error(string_template("Undefined label {name} [{line},{col}]", {
                            name: node.name,
                            line: node.start.line,
                            col: node.start.col
                        }));
                    node.thedef = sym;
                }
                if (!(scope instanceof AST_Toplevel) && (node instanceof AST_Export || node instanceof AST_Import)) {
                    js_error(`"${node.TYPE}" statement may only appear at the top level`, node.start.file, node.start.line, node.start.col, node.start.pos);
                }
            });
            this.walk(tw);
            function mark_export(def, level) {
                if (in_destructuring) {
                    var i = 0;
                    do {
                        level++;
                    } while (tw.parent(i++) !== in_destructuring);
                }
                var node = tw.parent(level);
                if (def.export = node instanceof AST_Export ? MASK_EXPORT_DONT_MANGLE : 0) {
                    var exported = node.exported_definition;
                    if ((exported instanceof AST_Defun || exported instanceof AST_DefClass) && node.is_default) {
                        def.export = MASK_EXPORT_WANT_MANGLE;
                    }
                }
            }
            // pass 2: find back references and eval
            const is_toplevel = this instanceof AST_Toplevel;
            if (is_toplevel) {
                this.globals = new Map();
            }
            var tw = new TreeWalker(node => {
                if (node instanceof AST_LoopControl && node.label) {
                    node.label.thedef.references.push(node);
                    return true;
                }
                if (node instanceof AST_SymbolRef) {
                    var name = node.name;
                    if (name == "eval" && tw.parent() instanceof AST_Call) {
                        for (var s = node.scope; s && !s.uses_eval; s = s.parent_scope) {
                            s.uses_eval = true;
                        }
                    }
                    var sym;
                    if (tw.parent() instanceof AST_NameMapping && tw.parent(1).module_name
                        || !(sym = node.scope.find_variable(name))) {
                        sym = toplevel.def_global(node);
                        if (node instanceof AST_SymbolExport)
                            sym.export = MASK_EXPORT_DONT_MANGLE;
                    }
                    else if (sym.scope instanceof AST_Lambda && name == "arguments") {
                        sym.scope.get_defun_scope().uses_arguments = true;
                    }
                    node.thedef = sym;
                    node.reference();
                    if (node.scope.is_block_scope()
                        && !(sym.orig[0] instanceof AST_SymbolBlockDeclaration)) {
                        node.scope = node.scope.get_defun_scope();
                    }
                    return true;
                }
                // ensure mangling works if catch reuses a scope variable
                var def;
                if (node instanceof AST_SymbolCatch && (def = redefined_catch_def(node.definition()))) {
                    var s = node.scope;
                    while (s) {
                        push_uniq(s.enclosed, def);
                        if (s === def.scope)
                            break;
                        s = s.parent_scope;
                    }
                }
            });
            this.walk(tw);
            // pass 3: work around IE8 and Safari catch scope bugs
            if (options.ie8 || options.safari10) {
                walk(this, node => {
                    if (node instanceof AST_SymbolCatch) {
                        var name = node.name;
                        var refs = node.thedef.references;
                        var scope = node.scope.get_defun_scope();
                        var def = scope.find_variable(name)
                            || toplevel.globals.get(name)
                            || scope.def_variable(node);
                        refs.forEach(function (ref) {
                            ref.thedef = def;
                            ref.reference();
                        });
                        node.thedef = def;
                        node.reference();
                        return true;
                    }
                });
            }
            // pass 4: add symbol definitions to loop scopes
            // Safari/Webkit bug workaround - loop init let variable shadowing argument.
            // https://github.com/mishoo/UglifyJS2/issues/1753
            // https://bugs.webkit.org/show_bug.cgi?id=171041
            if (options.safari10) {
                for (const scope of for_scopes) {
                    scope.parent_scope.variables.forEach(function (def) {
                        push_uniq(scope.enclosed, def);
                    });
                }
            }
        });
        AST_Toplevel.DEFMETHOD("def_global", function (node) {
            var globals = this.globals, name = node.name;
            if (globals.has(name)) {
                return globals.get(name);
            }
            else {
                var g = new SymbolDef(this, node);
                g.undeclared = true;
                g.global = true;
                globals.set(name, g);
                return g;
            }
        });
        AST_Scope.DEFMETHOD("init_scope_vars", function (parent_scope) {
            this.variables = new Map(); // map name to AST_SymbolVar (variables defined in this scope; includes functions)
            this.uses_with = false; // will be set to true if this or some nested scope uses the `with` statement
            this.uses_eval = false; // will be set to true if this or nested scope uses the global `eval`
            this.parent_scope = parent_scope; // the parent scope
            this.enclosed = []; // a list of variables from this or outer scope(s) that are referenced from this or inner scopes
            this.cname = -1; // the current index for mangling functions/variables
        });
        AST_Scope.DEFMETHOD("conflicting_def", function (name) {
            return (this.enclosed.find(def => def.name === name)
                || this.variables.has(name)
                || (this.parent_scope && this.parent_scope.conflicting_def(name)));
        });
        AST_Scope.DEFMETHOD("conflicting_def_shallow", function (name) {
            return (this.enclosed.find(def => def.name === name)
                || this.variables.has(name));
        });
        AST_Scope.DEFMETHOD("add_child_scope", function (scope) {
            // `scope` is going to be moved into `this` right now.
            // Update the required scopes' information
            if (scope.parent_scope === this)
                return;
            scope.parent_scope = this;
            // Propagate to this.uses_arguments from arrow functions
            if ((scope instanceof AST_Arrow) && !this.uses_arguments) {
                this.uses_arguments = walk(scope, node => {
                    if (node instanceof AST_SymbolRef
                        && node.scope instanceof AST_Lambda
                        && node.name === "arguments") {
                        return walk_abort;
                    }
                    if (node instanceof AST_Lambda && !(node instanceof AST_Arrow)) {
                        return true;
                    }
                });
            }
            this.uses_with = this.uses_with || scope.uses_with;
            this.uses_eval = this.uses_eval || scope.uses_eval;
            const scope_ancestry = (() => {
                const ancestry = [];
                let cur = this;
                do {
                    ancestry.push(cur);
                } while ((cur = cur.parent_scope));
                ancestry.reverse();
                return ancestry;
            })();
            const new_scope_enclosed_set = new Set(scope.enclosed);
            const to_enclose = [];
            for (const scope_topdown of scope_ancestry) {
                to_enclose.forEach(e => push_uniq(scope_topdown.enclosed, e));
                for (const def of scope_topdown.variables.values()) {
                    if (new_scope_enclosed_set.has(def)) {
                        push_uniq(to_enclose, def);
                        push_uniq(scope_topdown.enclosed, def);
                    }
                }
            }
        });
        function find_scopes_visible_from(scopes) {
            const found_scopes = new Set();
            for (const scope of new Set(scopes)) {
                (function bubble_up(scope) {
                    if (scope == null || found_scopes.has(scope))
                        return;
                    found_scopes.add(scope);
                    bubble_up(scope.parent_scope);
                })(scope);
            }
            return [...found_scopes];
        }
        // Creates a symbol during compression
        AST_Scope.DEFMETHOD("create_symbol", function (SymClass, { source, tentative_name, scope, conflict_scopes = [scope], init = null } = {}) {
            let symbol_name;
            conflict_scopes = find_scopes_visible_from(conflict_scopes);
            if (tentative_name) {
                // Implement hygiene (no new names are conflicting with existing names)
                tentative_name =
                    symbol_name =
                        tentative_name.replace(/(?:^[^a-z_$]|[^a-z0-9_$])/ig, "_");
                let i = 0;
                while (conflict_scopes.find(s => s.conflicting_def_shallow(symbol_name))) {
                    symbol_name = tentative_name + "$" + i++;
                }
            }
            if (!symbol_name) {
                throw new Error("No symbol name could be generated in create_symbol()");
            }
            const symbol = make_node(SymClass, source, {
                name: symbol_name,
                scope
            });
            this.def_variable(symbol, init || null);
            symbol.mark_enclosed();
            return symbol;
        });
        AST_Node.DEFMETHOD("is_block_scope", return_false);
        AST_Class.DEFMETHOD("is_block_scope", return_false);
        AST_Lambda.DEFMETHOD("is_block_scope", return_false);
        AST_Toplevel.DEFMETHOD("is_block_scope", return_false);
        AST_SwitchBranch.DEFMETHOD("is_block_scope", return_false);
        AST_Block.DEFMETHOD("is_block_scope", return_true);
        AST_Scope.DEFMETHOD("is_block_scope", function () {
            return this._block_scope || false;
        });
        AST_IterationStatement.DEFMETHOD("is_block_scope", return_true);
        AST_Lambda.DEFMETHOD("init_scope_vars", function () {
            AST_Scope.prototype.init_scope_vars.apply(this, arguments);
            this.uses_arguments = false;
            this.def_variable(new AST_SymbolFunarg({
                name: "arguments",
                start: this.start,
                end: this.end
            }));
        });
        AST_Arrow.DEFMETHOD("init_scope_vars", function () {
            AST_Scope.prototype.init_scope_vars.apply(this, arguments);
            this.uses_arguments = false;
        });
        AST_Symbol.DEFMETHOD("mark_enclosed", function () {
            var def = this.definition();
            var s = this.scope;
            while (s) {
                push_uniq(s.enclosed, def);
                if (s === def.scope)
                    break;
                s = s.parent_scope;
            }
        });
        AST_Symbol.DEFMETHOD("reference", function () {
            this.definition().references.push(this);
            this.mark_enclosed();
        });
        AST_Scope.DEFMETHOD("find_variable", function (name) {
            if (name instanceof AST_Symbol)
                name = name.name;
            return this.variables.get(name)
                || (this.parent_scope && this.parent_scope.find_variable(name));
        });
        AST_Scope.DEFMETHOD("def_function", function (symbol, init) {
            var def = this.def_variable(symbol, init);
            if (!def.init || def.init instanceof AST_Defun)
                def.init = init;
            return def;
        });
        AST_Scope.DEFMETHOD("def_variable", function (symbol, init) {
            var def = this.variables.get(symbol.name);
            if (def) {
                def.orig.push(symbol);
                if (def.init && (def.scope !== symbol.scope || def.init instanceof AST_Function)) {
                    def.init = init;
                }
            }
            else {
                def = new SymbolDef(this, symbol, init);
                this.variables.set(symbol.name, def);
                def.global = !this.parent_scope;
            }
            return symbol.thedef = def;
        });
        function next_mangled(scope, options) {
            let defun_scope;
            if (scopes_with_block_defuns
                && (defun_scope = scope.get_defun_scope())
                && scopes_with_block_defuns.has(defun_scope)) {
                scope = defun_scope;
            }
            var ext = scope.enclosed;
            var nth_identifier = options.nth_identifier;
            out: while (true) {
                var m = nth_identifier.get(++scope.cname);
                if (ALL_RESERVED_WORDS.has(m))
                    continue; // skip over "do"
                // https://github.com/mishoo/UglifyJS2/issues/242 -- do not
                // shadow a name reserved from mangling.
                if (options.reserved.has(m))
                    continue;
                // Functions with short names might collide with base54 output
                // and therefore cause collisions when keep_fnames is true.
                if (unmangleable_names && unmangleable_names.has(m))
                    continue out;
                // we must ensure that the mangled name does not shadow a name
                // from some parent scope that is referenced in this or in
                // inner scopes.
                for (let i = ext.length; --i >= 0;) {
                    const def = ext[i];
                    const name = def.mangled_name || (def.unmangleable(options) && def.name);
                    if (m == name)
                        continue out;
                }
                return m;
            }
        }
        AST_Scope.DEFMETHOD("next_mangled", function (options) {
            return next_mangled(this, options);
        });
        AST_Toplevel.DEFMETHOD("next_mangled", function (options) {
            let name;
            const mangled_names = this.mangled_names;
            do {
                name = next_mangled(this, options);
            } while (mangled_names.has(name));
            return name;
        });
        AST_Function.DEFMETHOD("next_mangled", function (options, def) {
            // #179, #326
            // in Safari strict mode, something like (function x(x){...}) is a syntax error;
            // a function expression's argument cannot shadow the function expression's name
            var tricky_def = def.orig[0] instanceof AST_SymbolFunarg && this.name && this.name.definition();
            // the function's mangled_name is null when keep_fnames is true
            var tricky_name = tricky_def ? tricky_def.mangled_name || tricky_def.name : null;
            while (true) {
                var name = next_mangled(this, options);
                if (!tricky_name || tricky_name != name)
                    return name;
            }
        });
        AST_Symbol.DEFMETHOD("unmangleable", function (options) {
            var def = this.definition();
            return !def || def.unmangleable(options);
        });
        // labels are always mangleable
        AST_Label.DEFMETHOD("unmangleable", return_false);
        AST_Symbol.DEFMETHOD("unreferenced", function () {
            return !this.definition().references.length && !this.scope.pinned();
        });
        AST_Symbol.DEFMETHOD("definition", function () {
            return this.thedef;
        });
        AST_Symbol.DEFMETHOD("global", function () {
            return this.thedef.global;
        });
        /**
         * Format the mangler options (if any) into their appropriate types
         */
        function format_mangler_options(options) {
            options = defaults(options, {
                eval: false,
                nth_identifier: base54,
                ie8: false,
                keep_classnames: false,
                keep_fnames: false,
                module: false,
                reserved: [],
                toplevel: false,
            });
            if (options.module)
                options.toplevel = true;
            if (!Array.isArray(options.reserved)
                && !(options.reserved instanceof Set)) {
                options.reserved = [];
            }
            options.reserved = new Set(options.reserved);
            // Never mangle arguments
            options.reserved.add("arguments");
            return options;
        }
        AST_Toplevel.DEFMETHOD("mangle_names", function (options) {
            options = format_mangler_options(options);
            var nth_identifier = options.nth_identifier;
            // We only need to mangle declaration nodes.  Special logic wired
            // into the code generator will display the mangled name if it's
            // present (and for AST_SymbolRef-s it'll use the mangled name of
            // the AST_SymbolDeclaration that it points to).
            var lname = -1;
            var to_mangle = [];
            if (options.keep_fnames) {
                function_defs = new Set();
            }
            const mangled_names = this.mangled_names = new Set();
            unmangleable_names = new Set();
            if (options.cache) {
                this.globals.forEach(collect);
                if (options.cache.props) {
                    options.cache.props.forEach(function (mangled_name) {
                        mangled_names.add(mangled_name);
                    });
                }
            }
            var tw = new TreeWalker(function (node, descend) {
                if (node instanceof AST_LabeledStatement) {
                    // lname is incremented when we get to the AST_Label
                    var save_nesting = lname;
                    descend();
                    lname = save_nesting;
                    return true; // don't descend again in TreeWalker
                }
                if (node instanceof AST_Defun
                    && !(tw.parent() instanceof AST_Scope)) {
                    scopes_with_block_defuns = scopes_with_block_defuns || new Set();
                    scopes_with_block_defuns.add(node.parent_scope.get_defun_scope());
                }
                if (node instanceof AST_Scope) {
                    node.variables.forEach(collect);
                    return;
                }
                if (node.is_block_scope()) {
                    node.block_scope.variables.forEach(collect);
                    return;
                }
                if (function_defs
                    && node instanceof AST_VarDef
                    && node.value instanceof AST_Lambda
                    && !node.value.name
                    && keep_name(options.keep_fnames, node.name.name)) {
                    function_defs.add(node.name.definition().id);
                    return;
                }
                if (node instanceof AST_Label) {
                    let name;
                    do {
                        name = nth_identifier.get(++lname);
                    } while (ALL_RESERVED_WORDS.has(name));
                    node.mangled_name = name;
                    return true;
                }
                if (!(options.ie8 || options.safari10) && node instanceof AST_SymbolCatch) {
                    to_mangle.push(node.definition());
                    return;
                }
            });
            this.walk(tw);
            if (options.keep_fnames || options.keep_classnames) {
                // Collect a set of short names which are unmangleable,
                // for use in avoiding collisions in next_mangled.
                to_mangle.forEach(def => {
                    if (def.name.length < 6 && def.unmangleable(options)) {
                        unmangleable_names.add(def.name);
                    }
                });
            }
            to_mangle.forEach(def => { def.mangle(options); });
            function_defs = null;
            unmangleable_names = null;
            scopes_with_block_defuns = null;
            function collect(symbol) {
                if (symbol.export & MASK_EXPORT_DONT_MANGLE) {
                    unmangleable_names.add(symbol.name);
                }
                else if (!options.reserved.has(symbol.name)) {
                    to_mangle.push(symbol);
                }
            }
        });
        AST_Toplevel.DEFMETHOD("find_colliding_names", function (options) {
            const cache = options.cache && options.cache.props;
            const avoid = new Set();
            options.reserved.forEach(to_avoid);
            this.globals.forEach(add_def);
            this.walk(new TreeWalker(function (node) {
                if (node instanceof AST_Scope)
                    node.variables.forEach(add_def);
                if (node instanceof AST_SymbolCatch)
                    add_def(node.definition());
            }));
            return avoid;
            function to_avoid(name) {
                avoid.add(name);
            }
            function add_def(def) {
                var name = def.name;
                if (def.global && cache && cache.has(name))
                    name = cache.get(name);
                else if (!def.unmangleable(options))
                    return;
                to_avoid(name);
            }
        });
        AST_Toplevel.DEFMETHOD("expand_names", function (options) {
            options = format_mangler_options(options);
            var nth_identifier = options.nth_identifier;
            if (nth_identifier.reset && nth_identifier.sort) {
                nth_identifier.reset();
                nth_identifier.sort();
            }
            var avoid = this.find_colliding_names(options);
            var cname = 0;
            this.globals.forEach(rename);
            this.walk(new TreeWalker(function (node) {
                if (node instanceof AST_Scope)
                    node.variables.forEach(rename);
                if (node instanceof AST_SymbolCatch)
                    rename(node.definition());
            }));
            function next_name() {
                var name;
                do {
                    name = nth_identifier.get(cname++);
                } while (avoid.has(name) || ALL_RESERVED_WORDS.has(name));
                return name;
            }
            function rename(def) {
                if (def.global && options.cache)
                    return;
                if (def.unmangleable(options))
                    return;
                if (options.reserved.has(def.name))
                    return;
                const redefinition = redefined_catch_def(def);
                const name = def.name = redefinition ? redefinition.name : next_name();
                def.orig.forEach(function (sym) {
                    sym.name = name;
                });
                def.references.forEach(function (sym) {
                    sym.name = name;
                });
            }
        });
        AST_Node.DEFMETHOD("tail_node", return_this);
        AST_Sequence.DEFMETHOD("tail_node", function () {
            return this.expressions[this.expressions.length - 1];
        });
        AST_Toplevel.DEFMETHOD("compute_char_frequency", function (options) {
            options = format_mangler_options(options);
            var nth_identifier = options.nth_identifier;
            if (!nth_identifier.reset || !nth_identifier.consider || !nth_identifier.sort) {
                // If the identifier mangler is invariant, skip computing character frequency.
                return;
            }
            nth_identifier.reset();
            try {
                AST_Node.prototype.print = function (stream, force_parens) {
                    this._print(stream, force_parens);
                    if (this instanceof AST_Symbol && !this.unmangleable(options)) {
                        nth_identifier.consider(this.name, -1);
                    }
                    else if (options.properties) {
                        if (this instanceof AST_DotHash) {
                            nth_identifier.consider("#" + this.property, -1);
                        }
                        else if (this instanceof AST_Dot) {
                            nth_identifier.consider(this.property, -1);
                        }
                        else if (this instanceof AST_Sub) {
                            skip_string(this.property);
                        }
                    }
                };
                nth_identifier.consider(this.print_to_string(), 1);
            }
            finally {
                AST_Node.prototype.print = AST_Node.prototype._print;
            }
            nth_identifier.sort();
            function skip_string(node) {
                if (node instanceof AST_String) {
                    nth_identifier.consider(node.value, -1);
                }
                else if (node instanceof AST_Conditional) {
                    skip_string(node.consequent);
                    skip_string(node.alternative);
                }
                else if (node instanceof AST_Sequence) {
                    skip_string(node.tail_node());
                }
            }
        });
        const base54 = (() => {
            const leading = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ$_".split("");
            const digits = "0123456789".split("");
            let chars;
            let frequency;
            function reset() {
                frequency = new Map();
                leading.forEach(function (ch) {
                    frequency.set(ch, 0);
                });
                digits.forEach(function (ch) {
                    frequency.set(ch, 0);
                });
            }
            function consider(str, delta) {
                for (var i = str.length; --i >= 0;) {
                    frequency.set(str[i], frequency.get(str[i]) + delta);
                }
            }
            function compare(a, b) {
                return frequency.get(b) - frequency.get(a);
            }
            function sort() {
                chars = mergeSort(leading, compare).concat(mergeSort(digits, compare));
            }
            // Ensure this is in a usable initial state.
            reset();
            sort();
            function base54(num) {
                var ret = "", base = 54;
                num++;
                do {
                    num--;
                    ret += chars[num % base];
                    num = Math.floor(num / base);
                    base = 64;
                } while (num > 0);
                return ret;
            }
            return {
                get: base54,
                consider,
                reset,
                sort
            };
        })();
        let mangle_options = undefined;
        AST_Node.prototype.size = function (compressor, stack) {
            mangle_options = compressor && compressor.mangle_options;
            let size = 0;
            walk_parent(this, (node, info) => {
                size += node._size(info);
                // Braceless arrow functions have fake "return" statements
                if (node instanceof AST_Arrow && node.is_braceless()) {
                    size += node.body[0].value._size(info);
                    return true;
                }
            }, stack || (compressor && compressor.stack));
            // just to save a bit of memory
            mangle_options = undefined;
            return size;
        };
        AST_Node.prototype._size = () => 0;
        AST_Debugger.prototype._size = () => 8;
        AST_Directive.prototype._size = function () {
            // TODO string encoding stuff
            return 2 + this.value.length;
        };
        /** Count commas/semicolons necessary to show a list of expressions/statements */
        const list_overhead = (array) => array.length && array.length - 1;
        AST_Block.prototype._size = function () {
            return 2 + list_overhead(this.body);
        };
        AST_Toplevel.prototype._size = function () {
            return list_overhead(this.body);
        };
        AST_EmptyStatement.prototype._size = () => 1;
        AST_LabeledStatement.prototype._size = () => 2; // x:
        AST_Do.prototype._size = () => 9;
        AST_While.prototype._size = () => 7;
        AST_For.prototype._size = () => 8;
        AST_ForIn.prototype._size = () => 8;
        // AST_ForOf inherits ^
        AST_With.prototype._size = () => 6;
        AST_Expansion.prototype._size = () => 3;
        const lambda_modifiers = func => (func.is_generator ? 1 : 0) + (func.async ? 6 : 0);
        AST_Accessor.prototype._size = function () {
            return lambda_modifiers(this) + 4 + list_overhead(this.argnames) + list_overhead(this.body);
        };
        AST_Function.prototype._size = function (info) {
            const first = !!first_in_statement(info);
            return (first * 2) + lambda_modifiers(this) + 12 + list_overhead(this.argnames) + list_overhead(this.body);
        };
        AST_Defun.prototype._size = function () {
            return lambda_modifiers(this) + 13 + list_overhead(this.argnames) + list_overhead(this.body);
        };
        AST_Arrow.prototype._size = function () {
            let args_and_arrow = 2 + list_overhead(this.argnames);
            if (!(this.argnames.length === 1
                && this.argnames[0] instanceof AST_Symbol)) {
                args_and_arrow += 2; // parens around the args
            }
            const body_overhead = this.is_braceless() ? 0 : list_overhead(this.body) + 2;
            return lambda_modifiers(this) + args_and_arrow + body_overhead;
        };
        AST_Destructuring.prototype._size = () => 2;
        AST_TemplateString.prototype._size = function () {
            return 2 + (Math.floor(this.segments.length / 2) * 3); /* "${}" */
        };
        AST_TemplateSegment.prototype._size = function () {
            return this.value.length;
        };
        AST_Return.prototype._size = function () {
            return this.value ? 7 : 6;
        };
        AST_Throw.prototype._size = () => 6;
        AST_Break.prototype._size = function () {
            return this.label ? 6 : 5;
        };
        AST_Continue.prototype._size = function () {
            return this.label ? 9 : 8;
        };
        AST_If.prototype._size = () => 4;
        AST_Switch.prototype._size = function () {
            return 8 + list_overhead(this.body);
        };
        AST_Case.prototype._size = function () {
            return 5 + list_overhead(this.body);
        };
        AST_Default.prototype._size = function () {
            return 8 + list_overhead(this.body);
        };
        AST_Try.prototype._size = () => 3;
        AST_Catch.prototype._size = function () {
            let size = 7 + list_overhead(this.body);
            if (this.argname) {
                size += 2;
            }
            return size;
        };
        AST_Finally.prototype._size = function () {
            return 7 + list_overhead(this.body);
        };
        AST_Var.prototype._size = function () {
            return 4 + list_overhead(this.definitions);
        };
        AST_Let.prototype._size = function () {
            return 4 + list_overhead(this.definitions);
        };
        AST_Const.prototype._size = function () {
            return 6 + list_overhead(this.definitions);
        };
        AST_VarDef.prototype._size = function () {
            return this.value ? 1 : 0;
        };
        AST_NameMapping.prototype._size = function () {
            // foreign name isn't mangled
            return this.name ? 4 : 0;
        };
        AST_Import.prototype._size = function () {
            // import
            let size = 6;
            if (this.imported_name)
                size += 1;
            // from
            if (this.imported_name || this.imported_names)
                size += 5;
            // braces, and the commas
            if (this.imported_names) {
                size += 2 + list_overhead(this.imported_names);
            }
            return size;
        };
        AST_ImportMeta.prototype._size = () => 11;
        AST_Export.prototype._size = function () {
            let size = 7 + (this.is_default ? 8 : 0);
            if (this.exported_value) {
                size += this.exported_value._size();
            }
            if (this.exported_names) {
                // Braces and commas
                size += 2 + list_overhead(this.exported_names);
            }
            if (this.module_name) {
                // "from "
                size += 5;
            }
            return size;
        };
        AST_Call.prototype._size = function () {
            if (this.optional) {
                return 4 + list_overhead(this.args);
            }
            return 2 + list_overhead(this.args);
        };
        AST_New.prototype._size = function () {
            return 6 + list_overhead(this.args);
        };
        AST_Sequence.prototype._size = function () {
            return list_overhead(this.expressions);
        };
        AST_Dot.prototype._size = function () {
            if (this.optional) {
                return this.property.length + 2;
            }
            return this.property.length + 1;
        };
        AST_DotHash.prototype._size = function () {
            if (this.optional) {
                return this.property.length + 3;
            }
            return this.property.length + 2;
        };
        AST_Sub.prototype._size = function () {
            return this.optional ? 4 : 2;
        };
        AST_Unary.prototype._size = function () {
            if (this.operator === "typeof")
                return 7;
            if (this.operator === "void")
                return 5;
            return this.operator.length;
        };
        AST_Binary.prototype._size = function (info) {
            if (this.operator === "in")
                return 4;
            let size = this.operator.length;
            if ((this.operator === "+" || this.operator === "-")
                && this.right instanceof AST_Unary && this.right.operator === this.operator) {
                // 1+ +a > needs space between the +
                size += 1;
            }
            if (this.needs_parens(info)) {
                size += 2;
            }
            return size;
        };
        AST_Conditional.prototype._size = () => 3;
        AST_Array.prototype._size = function () {
            return 2 + list_overhead(this.elements);
        };
        AST_Object.prototype._size = function (info) {
            let base = 2;
            if (first_in_statement(info)) {
                base += 2; // parens
            }
            return base + list_overhead(this.properties);
        };
        /*#__INLINE__*/
        const key_size = key => typeof key === "string" ? key.length : 0;
        AST_ObjectKeyVal.prototype._size = function () {
            return key_size(this.key) + 1;
        };
        /*#__INLINE__*/
        const static_size = is_static => is_static ? 7 : 0;
        AST_ObjectGetter.prototype._size = function () {
            return 5 + static_size(this.static) + key_size(this.key);
        };
        AST_ObjectSetter.prototype._size = function () {
            return 5 + static_size(this.static) + key_size(this.key);
        };
        AST_ConciseMethod.prototype._size = function () {
            return static_size(this.static) + key_size(this.key) + lambda_modifiers(this);
        };
        AST_PrivateMethod.prototype._size = function () {
            return AST_ConciseMethod.prototype._size.call(this) + 1;
        };
        AST_PrivateGetter.prototype._size = AST_PrivateSetter.prototype._size = function () {
            return AST_ConciseMethod.prototype._size.call(this) + 4;
        };
        AST_PrivateIn.prototype._size = function () {
            return 5; // "#", and " in "
        };
        AST_Class.prototype._size = function () {
            return ((this.name ? 8 : 7)
                + (this.extends ? 8 : 0));
        };
        AST_ClassStaticBlock.prototype._size = function () {
            // "class{}" + semicolons
            return 7 + list_overhead(this.body);
        };
        AST_ClassProperty.prototype._size = function () {
            return (static_size(this.static)
                + (typeof this.key === "string" ? this.key.length + 2 : 0)
                + (this.value ? 1 : 0));
        };
        AST_ClassPrivateProperty.prototype._size = function () {
            return AST_ClassProperty.prototype._size.call(this) + 1;
        };
        AST_Symbol.prototype._size = function () {
            if (!(mangle_options && this.thedef && !this.thedef.unmangleable(mangle_options))) {
                return this.name.length;
            }
            else {
                return 1;
            }
        };
        // TODO take propmangle into account
        AST_SymbolClassProperty.prototype._size = function () {
            return this.name.length;
        };
        AST_SymbolRef.prototype._size = AST_SymbolDeclaration.prototype._size = function () {
            if (this.name === "arguments")
                return 9;
            return AST_Symbol.prototype._size.call(this);
        };
        AST_NewTarget.prototype._size = () => 10;
        AST_SymbolImportForeign.prototype._size = function () {
            return this.name.length;
        };
        AST_SymbolExportForeign.prototype._size = function () {
            return this.name.length;
        };
        AST_This.prototype._size = () => 4;
        AST_Super.prototype._size = () => 5;
        AST_String.prototype._size = function () {
            return this.value.length + 2;
        };
        AST_Number.prototype._size = function () {
            const { value } = this;
            if (value === 0)
                return 1;
            if (value > 0 && Math.floor(value) === value) {
                return Math.floor(Math.log10(value) + 1);
            }
            return value.toString().length;
        };
        AST_BigInt.prototype._size = function () {
            return this.value.length;
        };
        AST_RegExp.prototype._size = function () {
            return this.value.toString().length;
        };
        AST_Null.prototype._size = () => 4;
        AST_NaN.prototype._size = () => 3;
        AST_Undefined.prototype._size = () => 6; // "void 0"
        AST_Hole.prototype._size = () => 0; // comma is taken into account by list_overhead()
        AST_Infinity.prototype._size = () => 8;
        AST_True.prototype._size = () => 4;
        AST_False.prototype._size = () => 5;
        AST_Await.prototype._size = () => 6;
        AST_Yield.prototype._size = () => 6;
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // bitfield flags to be stored in node.flags.
        // These are set and unset during compression, and store information in the node without requiring multiple fields.
        const UNUSED = 0b00000001;
        const TRUTHY = 0b00000010;
        const FALSY = 0b00000100;
        const UNDEFINED = 0b00001000;
        const INLINED = 0b00010000;
        // Nodes to which values are ever written. Used when keep_assign is part of the unused option string.
        const WRITE_ONLY = 0b00100000;
        // information specific to a single compression pass
        const SQUEEZED = 0b0000000100000000;
        const OPTIMIZED = 0b0000001000000000;
        const TOP = 0b0000010000000000;
        const CLEAR_BETWEEN_PASSES = SQUEEZED | OPTIMIZED | TOP;
        const has_flag = (node, flag) => node.flags & flag;
        const set_flag = (node, flag) => { node.flags |= flag; };
        const clear_flag = (node, flag) => { node.flags &= ~flag; };
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function merge_sequence(array, node) {
            if (node instanceof AST_Sequence) {
                array.push(...node.expressions);
            }
            else {
                array.push(node);
            }
            return array;
        }
        function make_sequence(orig, expressions) {
            if (expressions.length == 1)
                return expressions[0];
            if (expressions.length == 0)
                throw new Error("trying to create a sequence with length zero!");
            return make_node(AST_Sequence, orig, {
                expressions: expressions.reduce(merge_sequence, [])
            });
        }
        function make_node_from_constant(val, orig) {
            switch (typeof val) {
                case "string":
                    return make_node(AST_String, orig, {
                        value: val
                    });
                case "number":
                    if (isNaN(val))
                        return make_node(AST_NaN, orig);
                    if (isFinite(val)) {
                        return 1 / val < 0 ? make_node(AST_UnaryPrefix, orig, {
                            operator: "-",
                            expression: make_node(AST_Number, orig, { value: -val })
                        }) : make_node(AST_Number, orig, { value: val });
                    }
                    return val < 0 ? make_node(AST_UnaryPrefix, orig, {
                        operator: "-",
                        expression: make_node(AST_Infinity, orig)
                    }) : make_node(AST_Infinity, orig);
                case "boolean":
                    return make_node(val ? AST_True : AST_False, orig);
                case "undefined":
                    return make_node(AST_Undefined, orig);
                default:
                    if (val === null) {
                        return make_node(AST_Null, orig, { value: null });
                    }
                    if (val instanceof RegExp) {
                        return make_node(AST_RegExp, orig, {
                            value: {
                                source: regexp_source_fix(val.source),
                                flags: val.flags
                            }
                        });
                    }
                    throw new Error(string_template("Can't handle constant of type: {type}", {
                        type: typeof val
                    }));
            }
        }
        function best_of_expression(ast1, ast2) {
            return ast1.size() > ast2.size() ? ast2 : ast1;
        }
        function best_of_statement(ast1, ast2) {
            return best_of_expression(make_node(AST_SimpleStatement, ast1, {
                body: ast1
            }), make_node(AST_SimpleStatement, ast2, {
                body: ast2
            })).body;
        }
        /** Find which node is smaller, and return that */
        function best_of(compressor, ast1, ast2) {
            if (first_in_statement(compressor)) {
                return best_of_statement(ast1, ast2);
            }
            else {
                return best_of_expression(ast1, ast2);
            }
        }
        /** Simplify an object property's key, if possible */
        function get_simple_key(key) {
            if (key instanceof AST_Constant) {
                return key.getValue();
            }
            if (key instanceof AST_UnaryPrefix
                && key.operator == "void"
                && key.expression instanceof AST_Constant) {
                return;
            }
            return key;
        }
        function read_property(obj, key) {
            key = get_simple_key(key);
            if (key instanceof AST_Node)
                return;
            var value;
            if (obj instanceof AST_Array) {
                var elements = obj.elements;
                if (key == "length")
                    return make_node_from_constant(elements.length, obj);
                if (typeof key == "number" && key in elements)
                    value = elements[key];
            }
            else if (obj instanceof AST_Object) {
                key = "" + key;
                var props = obj.properties;
                for (var i = props.length; --i >= 0;) {
                    var prop = props[i];
                    if (!(prop instanceof AST_ObjectKeyVal))
                        return;
                    if (!value && props[i].key === key)
                        value = props[i].value;
                }
            }
            return value instanceof AST_SymbolRef && value.fixed_value() || value;
        }
        function has_break_or_continue(loop, parent) {
            var found = false;
            var tw = new TreeWalker(function (node) {
                if (found || node instanceof AST_Scope)
                    return true;
                if (node instanceof AST_LoopControl && tw.loopcontrol_target(node) === loop) {
                    return found = true;
                }
            });
            if (parent instanceof AST_LabeledStatement)
                tw.push(parent);
            tw.push(loop);
            loop.body.walk(tw);
            return found;
        }
        // we shouldn't compress (1,func)(something) to
        // func(something) because that changes the meaning of
        // the func (becomes lexical instead of global).
        function maintain_this_binding(parent, orig, val) {
            if (parent instanceof AST_UnaryPrefix && parent.operator == "delete"
                || parent instanceof AST_Call && parent.expression === orig
                    && (val instanceof AST_PropAccess
                        || val instanceof AST_SymbolRef && val.name == "eval")) {
                const zero = make_node(AST_Number, orig, { value: 0 });
                return make_sequence(orig, [zero, val]);
            }
            else {
                return val;
            }
        }
        function is_func_expr(node) {
            return node instanceof AST_Arrow || node instanceof AST_Function;
        }
        /**
         * Used to determine whether the node can benefit from negation.
         * Not the case with arrow functions (you need an extra set of parens). */
        function is_iife_call(node) {
            if (node.TYPE != "Call")
                return false;
            return node.expression instanceof AST_Function || is_iife_call(node.expression);
        }
        function is_empty(thing) {
            if (thing === null)
                return true;
            if (thing instanceof AST_EmptyStatement)
                return true;
            if (thing instanceof AST_BlockStatement)
                return thing.body.length == 0;
            return false;
        }
        const identifier_atom = makePredicate("Infinity NaN undefined");
        function is_identifier_atom(node) {
            return node instanceof AST_Infinity
                || node instanceof AST_NaN
                || node instanceof AST_Undefined;
        }
        /** Check if this is a SymbolRef node which has one def of a certain AST type */
        function is_ref_of(ref, type) {
            if (!(ref instanceof AST_SymbolRef))
                return false;
            var orig = ref.definition().orig;
            for (var i = orig.length; --i >= 0;) {
                if (orig[i] instanceof type)
                    return true;
            }
        }
        /**Can we turn { block contents... } into just the block contents ?
         * Not if one of these is inside.
         **/
        function can_be_evicted_from_block(node) {
            return !(node instanceof AST_DefClass ||
                node instanceof AST_Defun ||
                node instanceof AST_Let ||
                node instanceof AST_Const ||
                node instanceof AST_Export ||
                node instanceof AST_Import);
        }
        function as_statement_array(thing) {
            if (thing === null)
                return [];
            if (thing instanceof AST_BlockStatement)
                return thing.body;
            if (thing instanceof AST_EmptyStatement)
                return [];
            if (thing instanceof AST_Statement)
                return [thing];
            throw new Error("Can't convert thing to statement array");
        }
        function is_reachable(scope_node, defs) {
            const find_ref = node => {
                if (node instanceof AST_SymbolRef && defs.includes(node.definition())) {
                    return walk_abort;
                }
            };
            return walk_parent(scope_node, (node, info) => {
                if (node instanceof AST_Scope && node !== scope_node) {
                    var parent = info.parent();
                    if (parent instanceof AST_Call
                        && parent.expression === node
                        // Async/Generators aren't guaranteed to sync evaluate all of
                        // their body steps, so it's possible they close over the variable.
                        && !(node.async || node.is_generator)) {
                        return;
                    }
                    if (walk(node, find_ref))
                        return walk_abort;
                    return true;
                }
            });
        }
        /** Check if a ref refers to the name of a function/class it's defined within */
        function is_recursive_ref(compressor, def) {
            var node;
            for (var i = 0; node = compressor.parent(i); i++) {
                if (node instanceof AST_Lambda || node instanceof AST_Class) {
                    var name = node.name;
                    if (name && name.definition() === def) {
                        return true;
                    }
                }
            }
            return false;
        }
        // TODO this only works with AST_Defun, shouldn't it work for other ways of defining functions?
        function retain_top_func(fn, compressor) {
            return compressor.top_retain
                && fn instanceof AST_Defun
                && has_flag(fn, TOP)
                && fn.name
                && compressor.top_retain(fn.name);
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // Lists of native methods, useful for `unsafe` option which assumes they exist.
        // Note: Lots of methods and functions are missing here, in case they aren't pure
        // or not available in all JS environments.
        function make_nested_lookup(obj) {
            const out = new Map();
            for (var key of Object.keys(obj)) {
                out.set(key, makePredicate(obj[key]));
            }
            const does_have = (global_name, fname) => {
                const inner_map = out.get(global_name);
                return inner_map != null && inner_map.has(fname);
            };
            return does_have;
        }
        // Objects which are safe to access without throwing or causing a side effect.
        // Usually we'd check the `unsafe` option first but these are way too common for that
        const pure_prop_access_globals = new Set([
            "Number",
            "String",
            "Array",
            "Object",
            "Function",
            "Promise",
        ]);
        const object_methods = [
            "constructor",
            "toString",
            "valueOf",
        ];
        const is_pure_native_method = make_nested_lookup({
            Array: [
                "at",
                "flat",
                "includes",
                "indexOf",
                "join",
                "lastIndexOf",
                "slice",
                ...object_methods,
            ],
            Boolean: object_methods,
            Function: object_methods,
            Number: [
                "toExponential",
                "toFixed",
                "toPrecision",
                ...object_methods,
            ],
            Object: object_methods,
            RegExp: [
                "test",
                ...object_methods,
            ],
            String: [
                "at",
                "charAt",
                "charCodeAt",
                "charPointAt",
                "concat",
                "endsWith",
                "fromCharCode",
                "fromCodePoint",
                "includes",
                "indexOf",
                "italics",
                "lastIndexOf",
                "localeCompare",
                "match",
                "matchAll",
                "normalize",
                "padStart",
                "padEnd",
                "repeat",
                "replace",
                "replaceAll",
                "search",
                "slice",
                "split",
                "startsWith",
                "substr",
                "substring",
                "repeat",
                "toLocaleLowerCase",
                "toLocaleUpperCase",
                "toLowerCase",
                "toUpperCase",
                "trim",
                "trimEnd",
                "trimStart",
                ...object_methods,
            ],
        });
        const is_pure_native_fn = make_nested_lookup({
            Array: [
                "isArray",
            ],
            Math: [
                "abs",
                "acos",
                "asin",
                "atan",
                "ceil",
                "cos",
                "exp",
                "floor",
                "log",
                "round",
                "sin",
                "sqrt",
                "tan",
                "atan2",
                "pow",
                "max",
                "min",
            ],
            Number: [
                "isFinite",
                "isNaN",
            ],
            Object: [
                "create",
                "getOwnPropertyDescriptor",
                "getOwnPropertyNames",
                "getPrototypeOf",
                "isExtensible",
                "isFrozen",
                "isSealed",
                "hasOwn",
                "keys",
            ],
            String: [
                "fromCharCode",
            ],
        });
        // Known numeric values which come with JS environments
        const is_pure_native_value = make_nested_lookup({
            Math: [
                "E",
                "LN10",
                "LN2",
                "LOG2E",
                "LOG10E",
                "PI",
                "SQRT1_2",
                "SQRT2",
            ],
            Number: [
                "MAX_VALUE",
                "MIN_VALUE",
                "NaN",
                "NEGATIVE_INFINITY",
                "POSITIVE_INFINITY",
            ],
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // Functions and methods to infer certain facts about expressions
        // It's not always possible to be 100% sure about something just by static analysis,
        // so `true` means yes, and `false` means maybe
        const is_undeclared_ref = (node) => node instanceof AST_SymbolRef && node.definition().undeclared;
        const lazy_op = makePredicate("&& || ??");
        const unary_side_effects = makePredicate("delete ++ --");
        // methods to determine whether an expression has a boolean result type
        (function (def_is_boolean) {
            const unary_bool = makePredicate("! delete");
            const binary_bool = makePredicate("in instanceof == != === !== < <= >= >");
            def_is_boolean(AST_Node, return_false);
            def_is_boolean(AST_UnaryPrefix, function () {
                return unary_bool.has(this.operator);
            });
            def_is_boolean(AST_Binary, function () {
                return binary_bool.has(this.operator)
                    || lazy_op.has(this.operator)
                        && this.left.is_boolean()
                        && this.right.is_boolean();
            });
            def_is_boolean(AST_Conditional, function () {
                return this.consequent.is_boolean() && this.alternative.is_boolean();
            });
            def_is_boolean(AST_Assign, function () {
                return this.operator == "=" && this.right.is_boolean();
            });
            def_is_boolean(AST_Sequence, function () {
                return this.tail_node().is_boolean();
            });
            def_is_boolean(AST_True, return_true);
            def_is_boolean(AST_False, return_true);
        })(function (node, func) {
            node.DEFMETHOD("is_boolean", func);
        });
        // methods to determine if an expression has a numeric result type
        (function (def_is_number) {
            def_is_number(AST_Node, return_false);
            def_is_number(AST_Number, return_true);
            const unary = makePredicate("+ - ~ ++ --");
            def_is_number(AST_Unary, function () {
                return unary.has(this.operator) && !(this.expression instanceof AST_BigInt);
            });
            const numeric_ops = makePredicate("- * / % & | ^ << >> >>>");
            def_is_number(AST_Binary, function (compressor) {
                return numeric_ops.has(this.operator) || this.operator == "+"
                    && this.left.is_number(compressor)
                    && this.right.is_number(compressor);
            });
            def_is_number(AST_Assign, function (compressor) {
                return numeric_ops.has(this.operator.slice(0, -1))
                    || this.operator == "=" && this.right.is_number(compressor);
            });
            def_is_number(AST_Sequence, function (compressor) {
                return this.tail_node().is_number(compressor);
            });
            def_is_number(AST_Conditional, function (compressor) {
                return this.consequent.is_number(compressor) && this.alternative.is_number(compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("is_number", func);
        });
        // methods to determine if an expression has a string result type
        (function (def_is_string) {
            def_is_string(AST_Node, return_false);
            def_is_string(AST_String, return_true);
            def_is_string(AST_TemplateString, return_true);
            def_is_string(AST_UnaryPrefix, function () {
                return this.operator == "typeof";
            });
            def_is_string(AST_Binary, function (compressor) {
                return this.operator == "+" &&
                    (this.left.is_string(compressor) || this.right.is_string(compressor));
            });
            def_is_string(AST_Assign, function (compressor) {
                return (this.operator == "=" || this.operator == "+=") && this.right.is_string(compressor);
            });
            def_is_string(AST_Sequence, function (compressor) {
                return this.tail_node().is_string(compressor);
            });
            def_is_string(AST_Conditional, function (compressor) {
                return this.consequent.is_string(compressor) && this.alternative.is_string(compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("is_string", func);
        });
        function is_undefined(node, compressor) {
            return (has_flag(node, UNDEFINED)
                || node instanceof AST_Undefined
                || node instanceof AST_UnaryPrefix
                    && node.operator == "void"
                    && !node.expression.has_side_effects(compressor));
        }
        // Is the node explicitly null or undefined.
        function is_null_or_undefined(node, compressor) {
            let fixed;
            return (node instanceof AST_Null
                || is_undefined(node, compressor)
                || (node instanceof AST_SymbolRef
                    && (fixed = node.definition().fixed) instanceof AST_Node
                    && is_nullish(fixed, compressor)));
        }
        // Find out if this expression is optionally chained from a base-point that we
        // can statically analyze as null or undefined.
        function is_nullish_shortcircuited(node, compressor) {
            if (node instanceof AST_PropAccess || node instanceof AST_Call) {
                return ((node.optional && is_null_or_undefined(node.expression, compressor))
                    || is_nullish_shortcircuited(node.expression, compressor));
            }
            if (node instanceof AST_Chain)
                return is_nullish_shortcircuited(node.expression, compressor);
            return false;
        }
        // Find out if something is == null, or can short circuit into nullish.
        // Used to optimize ?. and ??
        function is_nullish(node, compressor) {
            if (is_null_or_undefined(node, compressor))
                return true;
            return is_nullish_shortcircuited(node, compressor);
        }
        // Determine if expression might cause side effects
        // If there's a possibility that a node may change something when it's executed, this returns true
        (function (def_has_side_effects) {
            def_has_side_effects(AST_Node, return_true);
            def_has_side_effects(AST_EmptyStatement, return_false);
            def_has_side_effects(AST_Constant, return_false);
            def_has_side_effects(AST_This, return_false);
            function any(list, compressor) {
                for (var i = list.length; --i >= 0;)
                    if (list[i].has_side_effects(compressor))
                        return true;
                return false;
            }
            def_has_side_effects(AST_Block, function (compressor) {
                return any(this.body, compressor);
            });
            def_has_side_effects(AST_Call, function (compressor) {
                if (!this.is_callee_pure(compressor)
                    && (!this.expression.is_call_pure(compressor)
                        || this.expression.has_side_effects(compressor))) {
                    return true;
                }
                return any(this.args, compressor);
            });
            def_has_side_effects(AST_Switch, function (compressor) {
                return this.expression.has_side_effects(compressor)
                    || any(this.body, compressor);
            });
            def_has_side_effects(AST_Case, function (compressor) {
                return this.expression.has_side_effects(compressor)
                    || any(this.body, compressor);
            });
            def_has_side_effects(AST_Try, function (compressor) {
                return this.body.has_side_effects(compressor)
                    || this.bcatch && this.bcatch.has_side_effects(compressor)
                    || this.bfinally && this.bfinally.has_side_effects(compressor);
            });
            def_has_side_effects(AST_If, function (compressor) {
                return this.condition.has_side_effects(compressor)
                    || this.body && this.body.has_side_effects(compressor)
                    || this.alternative && this.alternative.has_side_effects(compressor);
            });
            def_has_side_effects(AST_ImportMeta, return_false);
            def_has_side_effects(AST_LabeledStatement, function (compressor) {
                return this.body.has_side_effects(compressor);
            });
            def_has_side_effects(AST_SimpleStatement, function (compressor) {
                return this.body.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Lambda, return_false);
            def_has_side_effects(AST_Class, function (compressor) {
                if (this.extends && this.extends.has_side_effects(compressor)) {
                    return true;
                }
                return any(this.properties, compressor);
            });
            def_has_side_effects(AST_ClassStaticBlock, function (compressor) {
                return any(this.body, compressor);
            });
            def_has_side_effects(AST_Binary, function (compressor) {
                return this.left.has_side_effects(compressor)
                    || this.right.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Assign, return_true);
            def_has_side_effects(AST_Conditional, function (compressor) {
                return this.condition.has_side_effects(compressor)
                    || this.consequent.has_side_effects(compressor)
                    || this.alternative.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Unary, function (compressor) {
                return unary_side_effects.has(this.operator)
                    || this.expression.has_side_effects(compressor);
            });
            def_has_side_effects(AST_SymbolRef, function (compressor) {
                return !this.is_declared(compressor) && !pure_prop_access_globals.has(this.name);
            });
            def_has_side_effects(AST_SymbolClassProperty, return_false);
            def_has_side_effects(AST_SymbolDeclaration, return_false);
            def_has_side_effects(AST_Object, function (compressor) {
                return any(this.properties, compressor);
            });
            def_has_side_effects(AST_ObjectProperty, function (compressor) {
                return (this.computed_key() && this.key.has_side_effects(compressor)
                    || this.value && this.value.has_side_effects(compressor));
            });
            def_has_side_effects(AST_ClassProperty, function (compressor) {
                return (this.computed_key() && this.key.has_side_effects(compressor)
                    || this.static && this.value && this.value.has_side_effects(compressor));
            });
            def_has_side_effects(AST_ConciseMethod, function (compressor) {
                return this.computed_key() && this.key.has_side_effects(compressor);
            });
            def_has_side_effects(AST_ObjectGetter, function (compressor) {
                return this.computed_key() && this.key.has_side_effects(compressor);
            });
            def_has_side_effects(AST_ObjectSetter, function (compressor) {
                return this.computed_key() && this.key.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Array, function (compressor) {
                return any(this.elements, compressor);
            });
            def_has_side_effects(AST_Dot, function (compressor) {
                if (is_nullish(this, compressor))
                    return false;
                return !this.optional && this.expression.may_throw_on_access(compressor)
                    || this.expression.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Sub, function (compressor) {
                if (is_nullish(this, compressor))
                    return false;
                return !this.optional && this.expression.may_throw_on_access(compressor)
                    || this.expression.has_side_effects(compressor)
                    || this.property.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Chain, function (compressor) {
                return this.expression.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Sequence, function (compressor) {
                return any(this.expressions, compressor);
            });
            def_has_side_effects(AST_Definitions, function (compressor) {
                return any(this.definitions, compressor);
            });
            def_has_side_effects(AST_VarDef, function () {
                return this.value;
            });
            def_has_side_effects(AST_TemplateSegment, return_false);
            def_has_side_effects(AST_TemplateString, function (compressor) {
                return any(this.segments, compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("has_side_effects", func);
        });
        // determine if expression may throw
        (function (def_may_throw) {
            def_may_throw(AST_Node, return_true);
            def_may_throw(AST_Constant, return_false);
            def_may_throw(AST_EmptyStatement, return_false);
            def_may_throw(AST_Lambda, return_false);
            def_may_throw(AST_SymbolDeclaration, return_false);
            def_may_throw(AST_This, return_false);
            def_may_throw(AST_ImportMeta, return_false);
            function any(list, compressor) {
                for (var i = list.length; --i >= 0;)
                    if (list[i].may_throw(compressor))
                        return true;
                return false;
            }
            def_may_throw(AST_Class, function (compressor) {
                if (this.extends && this.extends.may_throw(compressor))
                    return true;
                return any(this.properties, compressor);
            });
            def_may_throw(AST_ClassStaticBlock, function (compressor) {
                return any(this.body, compressor);
            });
            def_may_throw(AST_Array, function (compressor) {
                return any(this.elements, compressor);
            });
            def_may_throw(AST_Assign, function (compressor) {
                if (this.right.may_throw(compressor))
                    return true;
                if (!compressor.has_directive("use strict")
                    && this.operator == "="
                    && this.left instanceof AST_SymbolRef) {
                    return false;
                }
                return this.left.may_throw(compressor);
            });
            def_may_throw(AST_Binary, function (compressor) {
                return this.left.may_throw(compressor)
                    || this.right.may_throw(compressor);
            });
            def_may_throw(AST_Block, function (compressor) {
                return any(this.body, compressor);
            });
            def_may_throw(AST_Call, function (compressor) {
                if (is_nullish(this, compressor))
                    return false;
                if (any(this.args, compressor))
                    return true;
                if (this.is_callee_pure(compressor))
                    return false;
                if (this.expression.may_throw(compressor))
                    return true;
                return !(this.expression instanceof AST_Lambda)
                    || any(this.expression.body, compressor);
            });
            def_may_throw(AST_Case, function (compressor) {
                return this.expression.may_throw(compressor)
                    || any(this.body, compressor);
            });
            def_may_throw(AST_Conditional, function (compressor) {
                return this.condition.may_throw(compressor)
                    || this.consequent.may_throw(compressor)
                    || this.alternative.may_throw(compressor);
            });
            def_may_throw(AST_Definitions, function (compressor) {
                return any(this.definitions, compressor);
            });
            def_may_throw(AST_If, function (compressor) {
                return this.condition.may_throw(compressor)
                    || this.body && this.body.may_throw(compressor)
                    || this.alternative && this.alternative.may_throw(compressor);
            });
            def_may_throw(AST_LabeledStatement, function (compressor) {
                return this.body.may_throw(compressor);
            });
            def_may_throw(AST_Object, function (compressor) {
                return any(this.properties, compressor);
            });
            def_may_throw(AST_ObjectProperty, function (compressor) {
                // TODO key may throw too
                return this.value ? this.value.may_throw(compressor) : false;
            });
            def_may_throw(AST_ClassProperty, function (compressor) {
                return (this.computed_key() && this.key.may_throw(compressor)
                    || this.static && this.value && this.value.may_throw(compressor));
            });
            def_may_throw(AST_ConciseMethod, function (compressor) {
                return this.computed_key() && this.key.may_throw(compressor);
            });
            def_may_throw(AST_ObjectGetter, function (compressor) {
                return this.computed_key() && this.key.may_throw(compressor);
            });
            def_may_throw(AST_ObjectSetter, function (compressor) {
                return this.computed_key() && this.key.may_throw(compressor);
            });
            def_may_throw(AST_Return, function (compressor) {
                return this.value && this.value.may_throw(compressor);
            });
            def_may_throw(AST_Sequence, function (compressor) {
                return any(this.expressions, compressor);
            });
            def_may_throw(AST_SimpleStatement, function (compressor) {
                return this.body.may_throw(compressor);
            });
            def_may_throw(AST_Dot, function (compressor) {
                if (is_nullish(this, compressor))
                    return false;
                return !this.optional && this.expression.may_throw_on_access(compressor)
                    || this.expression.may_throw(compressor);
            });
            def_may_throw(AST_Sub, function (compressor) {
                if (is_nullish(this, compressor))
                    return false;
                return !this.optional && this.expression.may_throw_on_access(compressor)
                    || this.expression.may_throw(compressor)
                    || this.property.may_throw(compressor);
            });
            def_may_throw(AST_Chain, function (compressor) {
                return this.expression.may_throw(compressor);
            });
            def_may_throw(AST_Switch, function (compressor) {
                return this.expression.may_throw(compressor)
                    || any(this.body, compressor);
            });
            def_may_throw(AST_SymbolRef, function (compressor) {
                return !this.is_declared(compressor) && !pure_prop_access_globals.has(this.name);
            });
            def_may_throw(AST_SymbolClassProperty, return_false);
            def_may_throw(AST_Try, function (compressor) {
                return this.bcatch ? this.bcatch.may_throw(compressor) : this.body.may_throw(compressor)
                    || this.bfinally && this.bfinally.may_throw(compressor);
            });
            def_may_throw(AST_Unary, function (compressor) {
                if (this.operator == "typeof" && this.expression instanceof AST_SymbolRef)
                    return false;
                return this.expression.may_throw(compressor);
            });
            def_may_throw(AST_VarDef, function (compressor) {
                if (!this.value)
                    return false;
                return this.value.may_throw(compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("may_throw", func);
        });
        // determine if expression is constant
        (function (def_is_constant_expression) {
            function all_refs_local(scope) {
                let result = true;
                walk(this, node => {
                    if (node instanceof AST_SymbolRef) {
                        if (has_flag(this, INLINED)) {
                            result = false;
                            return walk_abort;
                        }
                        var def = node.definition();
                        if (member(def, this.enclosed)
                            && !this.variables.has(def.name)) {
                            if (scope) {
                                var scope_def = scope.find_variable(node);
                                if (def.undeclared ? !scope_def : scope_def === def) {
                                    result = "f";
                                    return true;
                                }
                            }
                            result = false;
                            return walk_abort;
                        }
                        return true;
                    }
                    if (node instanceof AST_This && this instanceof AST_Arrow) {
                        result = false;
                        return walk_abort;
                    }
                });
                return result;
            }
            def_is_constant_expression(AST_Node, return_false);
            def_is_constant_expression(AST_Constant, return_true);
            def_is_constant_expression(AST_Class, function (scope) {
                if (this.extends && !this.extends.is_constant_expression(scope)) {
                    return false;
                }
                for (const prop of this.properties) {
                    if (prop.computed_key() && !prop.key.is_constant_expression(scope)) {
                        return false;
                    }
                    if (prop.static && prop.value && !prop.value.is_constant_expression(scope)) {
                        return false;
                    }
                    if (prop instanceof AST_ClassStaticBlock) {
                        return false;
                    }
                }
                return all_refs_local.call(this, scope);
            });
            def_is_constant_expression(AST_Lambda, all_refs_local);
            def_is_constant_expression(AST_Unary, function () {
                return this.expression.is_constant_expression();
            });
            def_is_constant_expression(AST_Binary, function () {
                return this.left.is_constant_expression()
                    && this.right.is_constant_expression();
            });
            def_is_constant_expression(AST_Array, function () {
                return this.elements.every((l) => l.is_constant_expression());
            });
            def_is_constant_expression(AST_Object, function () {
                return this.properties.every((l) => l.is_constant_expression());
            });
            def_is_constant_expression(AST_ObjectProperty, function () {
                return !!(!(this.key instanceof AST_Node) && this.value && this.value.is_constant_expression());
            });
        })(function (node, func) {
            node.DEFMETHOD("is_constant_expression", func);
        });
        // may_throw_on_access()
        // returns true if this node may be null, undefined or contain `AST_Accessor`
        (function (def_may_throw_on_access) {
            AST_Node.DEFMETHOD("may_throw_on_access", function (compressor) {
                return !compressor.option("pure_getters")
                    || this._dot_throw(compressor);
            });
            function is_strict(compressor) {
                return /strict/.test(compressor.option("pure_getters"));
            }
            def_may_throw_on_access(AST_Node, is_strict);
            def_may_throw_on_access(AST_Null, return_true);
            def_may_throw_on_access(AST_Undefined, return_true);
            def_may_throw_on_access(AST_Constant, return_false);
            def_may_throw_on_access(AST_Array, return_false);
            def_may_throw_on_access(AST_Object, function (compressor) {
                if (!is_strict(compressor))
                    return false;
                for (var i = this.properties.length; --i >= 0;)
                    if (this.properties[i]._dot_throw(compressor))
                        return true;
                return false;
            });
            // Do not be as strict with classes as we are with objects.
            // Hopefully the community is not going to abuse static getters and setters.
            // https://github.com/terser/terser/issues/724#issuecomment-643655656
            def_may_throw_on_access(AST_Class, return_false);
            def_may_throw_on_access(AST_ObjectProperty, return_false);
            def_may_throw_on_access(AST_ObjectGetter, return_true);
            def_may_throw_on_access(AST_Expansion, function (compressor) {
                return this.expression._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_Function, return_false);
            def_may_throw_on_access(AST_Arrow, return_false);
            def_may_throw_on_access(AST_UnaryPostfix, return_false);
            def_may_throw_on_access(AST_UnaryPrefix, function () {
                return this.operator == "void";
            });
            def_may_throw_on_access(AST_Binary, function (compressor) {
                return (this.operator == "&&" || this.operator == "||" || this.operator == "??")
                    && (this.left._dot_throw(compressor) || this.right._dot_throw(compressor));
            });
            def_may_throw_on_access(AST_Assign, function (compressor) {
                if (this.logical)
                    return true;
                return this.operator == "="
                    && this.right._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_Conditional, function (compressor) {
                return this.consequent._dot_throw(compressor)
                    || this.alternative._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_Dot, function (compressor) {
                if (!is_strict(compressor))
                    return false;
                if (this.property == "prototype") {
                    return !(this.expression instanceof AST_Function
                        || this.expression instanceof AST_Class);
                }
                return true;
            });
            def_may_throw_on_access(AST_Chain, function (compressor) {
                return this.expression._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_Sequence, function (compressor) {
                return this.tail_node()._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_SymbolRef, function (compressor) {
                if (this.name === "arguments" && this.scope instanceof AST_Lambda)
                    return false;
                if (has_flag(this, UNDEFINED))
                    return true;
                if (!is_strict(compressor))
                    return false;
                if (is_undeclared_ref(this) && this.is_declared(compressor))
                    return false;
                if (this.is_immutable())
                    return false;
                var fixed = this.fixed_value();
                return !fixed || fixed._dot_throw(compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("_dot_throw", func);
        });
        function is_lhs(node, parent) {
            if (parent instanceof AST_Unary && unary_side_effects.has(parent.operator))
                return parent.expression;
            if (parent instanceof AST_Assign && parent.left === node)
                return node;
        }
        (function (def_find_defs) {
            function to_node(value, orig) {
                if (value instanceof AST_Node) {
                    if (!(value instanceof AST_Constant)) {
                        // Value may be a function, an array including functions and even a complex assign / block expression,
                        // so it should never be shared in different places.
                        // Otherwise wrong information may be used in the compression phase
                        value = value.clone(true);
                    }
                    return make_node(value.CTOR, orig, value);
                }
                if (Array.isArray(value))
                    return make_node(AST_Array, orig, {
                        elements: value.map(function (value) {
                            return to_node(value, orig);
                        })
                    });
                if (value && typeof value == "object") {
                    var props = [];
                    for (var key in value)
                        if (HOP(value, key)) {
                            props.push(make_node(AST_ObjectKeyVal, orig, {
                                key: key,
                                value: to_node(value[key], orig)
                            }));
                        }
                    return make_node(AST_Object, orig, {
                        properties: props
                    });
                }
                return make_node_from_constant(value, orig);
            }
            AST_Toplevel.DEFMETHOD("resolve_defines", function (compressor) {
                if (!compressor.option("global_defs"))
                    return this;
                this.figure_out_scope({ ie8: compressor.option("ie8") });
                return this.transform(new TreeTransformer(function (node) {
                    var def = node._find_defs(compressor, "");
                    if (!def)
                        return;
                    var level = 0, child = node, parent;
                    while (parent = this.parent(level++)) {
                        if (!(parent instanceof AST_PropAccess))
                            break;
                        if (parent.expression !== child)
                            break;
                        child = parent;
                    }
                    if (is_lhs(child, parent)) {
                        return;
                    }
                    return def;
                }));
            });
            def_find_defs(AST_Node, noop);
            def_find_defs(AST_Chain, function (compressor, suffix) {
                return this.expression._find_defs(compressor, suffix);
            });
            def_find_defs(AST_Dot, function (compressor, suffix) {
                return this.expression._find_defs(compressor, "." + this.property + suffix);
            });
            def_find_defs(AST_SymbolDeclaration, function () {
                if (!this.global())
                    return;
            });
            def_find_defs(AST_SymbolRef, function (compressor, suffix) {
                if (!this.global())
                    return;
                var defines = compressor.option("global_defs");
                var name = this.name + suffix;
                if (HOP(defines, name))
                    return to_node(defines[name], this);
            });
            def_find_defs(AST_ImportMeta, function (compressor, suffix) {
                var defines = compressor.option("global_defs");
                var name = "import.meta" + suffix;
                if (HOP(defines, name))
                    return to_node(defines[name], this);
            });
        })(function (node, func) {
            node.DEFMETHOD("_find_defs", func);
        });
        // method to negate an expression
        (function (def_negate) {
            function basic_negation(exp) {
                return make_node(AST_UnaryPrefix, exp, {
                    operator: "!",
                    expression: exp
                });
            }
            function best(orig, alt, first_in_statement) {
                var negated = basic_negation(orig);
                if (first_in_statement) {
                    var stat = make_node(AST_SimpleStatement, alt, {
                        body: alt
                    });
                    return best_of_expression(negated, stat) === stat ? alt : negated;
                }
                return best_of_expression(negated, alt);
            }
            def_negate(AST_Node, function () {
                return basic_negation(this);
            });
            def_negate(AST_Statement, function () {
                throw new Error("Cannot negate a statement");
            });
            def_negate(AST_Function, function () {
                return basic_negation(this);
            });
            def_negate(AST_Arrow, function () {
                return basic_negation(this);
            });
            def_negate(AST_UnaryPrefix, function () {
                if (this.operator == "!")
                    return this.expression;
                return basic_negation(this);
            });
            def_negate(AST_Sequence, function (compressor) {
                var expressions = this.expressions.slice();
                expressions.push(expressions.pop().negate(compressor));
                return make_sequence(this, expressions);
            });
            def_negate(AST_Conditional, function (compressor, first_in_statement) {
                var self = this.clone();
                self.consequent = self.consequent.negate(compressor);
                self.alternative = self.alternative.negate(compressor);
                return best(this, self, first_in_statement);
            });
            def_negate(AST_Binary, function (compressor, first_in_statement) {
                var self = this.clone(), op = this.operator;
                if (compressor.option("unsafe_comps")) {
                    switch (op) {
                        case "<=":
                            self.operator = ">";
                            return self;
                        case "<":
                            self.operator = ">=";
                            return self;
                        case ">=":
                            self.operator = "<";
                            return self;
                        case ">":
                            self.operator = "<=";
                            return self;
                    }
                }
                switch (op) {
                    case "==":
                        self.operator = "!=";
                        return self;
                    case "!=":
                        self.operator = "==";
                        return self;
                    case "===":
                        self.operator = "!==";
                        return self;
                    case "!==":
                        self.operator = "===";
                        return self;
                    case "&&":
                        self.operator = "||";
                        self.left = self.left.negate(compressor, first_in_statement);
                        self.right = self.right.negate(compressor);
                        return best(this, self, first_in_statement);
                    case "||":
                        self.operator = "&&";
                        self.left = self.left.negate(compressor, first_in_statement);
                        self.right = self.right.negate(compressor);
                        return best(this, self, first_in_statement);
                }
                return basic_negation(this);
            });
        })(function (node, func) {
            node.DEFMETHOD("negate", function (compressor, first_in_statement) {
                return func.call(this, compressor, first_in_statement);
            });
        });
        // Is the callee of this function pure?
        var global_pure_fns = makePredicate("Boolean decodeURI decodeURIComponent Date encodeURI encodeURIComponent Error escape EvalError isFinite isNaN Number Object parseFloat parseInt RangeError ReferenceError String SyntaxError TypeError unescape URIError");
        AST_Call.DEFMETHOD("is_callee_pure", function (compressor) {
            if (compressor.option("unsafe")) {
                var expr = this.expression;
                var first_arg = (this.args && this.args[0] && this.args[0].evaluate(compressor));
                if (expr.expression && expr.expression.name === "hasOwnProperty" &&
                    (first_arg == null || first_arg.thedef && first_arg.thedef.undeclared)) {
                    return false;
                }
                if (is_undeclared_ref(expr) && global_pure_fns.has(expr.name))
                    return true;
                if (expr instanceof AST_Dot
                    && is_undeclared_ref(expr.expression)
                    && is_pure_native_fn(expr.expression.name, expr.property)) {
                    return true;
                }
            }
            return !!has_annotation(this, _PURE) || !compressor.pure_funcs(this);
        });
        // If I call this, is it a pure function?
        AST_Node.DEFMETHOD("is_call_pure", return_false);
        AST_Dot.DEFMETHOD("is_call_pure", function (compressor) {
            if (!compressor.option("unsafe"))
                return;
            const expr = this.expression;
            let native_obj;
            if (expr instanceof AST_Array) {
                native_obj = "Array";
            }
            else if (expr.is_boolean()) {
                native_obj = "Boolean";
            }
            else if (expr.is_number(compressor)) {
                native_obj = "Number";
            }
            else if (expr instanceof AST_RegExp) {
                native_obj = "RegExp";
            }
            else if (expr.is_string(compressor)) {
                native_obj = "String";
            }
            else if (!this.may_throw_on_access(compressor)) {
                native_obj = "Object";
            }
            return native_obj != null && is_pure_native_method(native_obj, this.property);
        });
        // tell me if a statement aborts
        const aborts = (thing) => thing && thing.aborts();
        (function (def_aborts) {
            def_aborts(AST_Statement, return_null);
            def_aborts(AST_Jump, return_this);
            function block_aborts() {
                for (var i = 0; i < this.body.length; i++) {
                    if (aborts(this.body[i])) {
                        return this.body[i];
                    }
                }
                return null;
            }
            def_aborts(AST_Import, return_null);
            def_aborts(AST_BlockStatement, block_aborts);
            def_aborts(AST_SwitchBranch, block_aborts);
            def_aborts(AST_DefClass, function () {
                for (const prop of this.properties) {
                    if (prop instanceof AST_ClassStaticBlock) {
                        if (prop.aborts())
                            return prop;
                    }
                }
                return null;
            });
            def_aborts(AST_ClassStaticBlock, block_aborts);
            def_aborts(AST_If, function () {
                return this.alternative && aborts(this.body) && aborts(this.alternative) && this;
            });
        })(function (node, func) {
            node.DEFMETHOD("aborts", func);
        });
        function is_modified(compressor, tw, node, value, level, immutable) {
            var parent = tw.parent(level);
            var lhs = is_lhs(node, parent);
            if (lhs)
                return lhs;
            if (!immutable
                && parent instanceof AST_Call
                && parent.expression === node
                && !(value instanceof AST_Arrow)
                && !(value instanceof AST_Class)
                && !parent.is_callee_pure(compressor)
                && (!(value instanceof AST_Function)
                    || !(parent instanceof AST_New) && value.contains_this())) {
                return true;
            }
            if (parent instanceof AST_Array) {
                return is_modified(compressor, tw, parent, parent, level + 1);
            }
            if (parent instanceof AST_ObjectKeyVal && node === parent.value) {
                var obj = tw.parent(level + 1);
                return is_modified(compressor, tw, obj, obj, level + 2);
            }
            if (parent instanceof AST_PropAccess && parent.expression === node) {
                var prop = read_property(value, parent.property);
                return !immutable && is_modified(compressor, tw, parent, prop, level + 1);
            }
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // methods to evaluate a constant expression
        function def_eval(node, func) {
            node.DEFMETHOD("_eval", func);
        }
        // Used to propagate a nullish short-circuit signal upwards through the chain.
        const nullish = Symbol("This AST_Chain is nullish");
        // If the node has been successfully reduced to a constant,
        // then its value is returned; otherwise the element itself
        // is returned.
        // They can be distinguished as constant value is never a
        // descendant of AST_Node.
        AST_Node.DEFMETHOD("evaluate", function (compressor) {
            if (!compressor.option("evaluate"))
                return this;
            var val = this._eval(compressor, 1);
            if (!val || val instanceof RegExp)
                return val;
            if (typeof val == "function" || typeof val == "object" || val == nullish)
                return this;
            // Evaluated strings can be larger than the original expression
            if (typeof val === "string") {
                const unevaluated_size = this.size(compressor);
                if (val.length + 2 > unevaluated_size)
                    return this;
            }
            return val;
        });
        var unaryPrefix = makePredicate("! ~ - + void");
        AST_Node.DEFMETHOD("is_constant", function () {
            // Accomodate when compress option evaluate=false
            // as well as the common constant expressions !0 and -1
            if (this instanceof AST_Constant) {
                return !(this instanceof AST_RegExp);
            }
            else {
                return this instanceof AST_UnaryPrefix
                    && this.expression instanceof AST_Constant
                    && unaryPrefix.has(this.operator);
            }
        });
        def_eval(AST_Statement, function () {
            throw new Error(string_template("Cannot evaluate a statement [{file}:{line},{col}]", this.start));
        });
        def_eval(AST_Lambda, return_this);
        def_eval(AST_Class, return_this);
        def_eval(AST_Node, return_this);
        def_eval(AST_Constant, function () {
            return this.getValue();
        });
        def_eval(AST_BigInt, return_this);
        def_eval(AST_RegExp, function (compressor) {
            let evaluated = compressor.evaluated_regexps.get(this.value);
            if (evaluated === undefined && regexp_is_safe(this.value.source)) {
                try {
                    const { source, flags } = this.value;
                    evaluated = new RegExp(source, flags);
                }
                catch (e) {
                    evaluated = null;
                }
                compressor.evaluated_regexps.set(this.value, evaluated);
            }
            return evaluated || this;
        });
        def_eval(AST_TemplateString, function () {
            if (this.segments.length !== 1)
                return this;
            return this.segments[0].value;
        });
        def_eval(AST_Function, function (compressor) {
            if (compressor.option("unsafe")) {
                var fn = function () { };
                fn.node = this;
                fn.toString = () => this.print_to_string();
                return fn;
            }
            return this;
        });
        def_eval(AST_Array, function (compressor, depth) {
            if (compressor.option("unsafe")) {
                var elements = [];
                for (var i = 0, len = this.elements.length; i < len; i++) {
                    var element = this.elements[i];
                    var value = element._eval(compressor, depth);
                    if (element === value)
                        return this;
                    elements.push(value);
                }
                return elements;
            }
            return this;
        });
        def_eval(AST_Object, function (compressor, depth) {
            if (compressor.option("unsafe")) {
                var val = {};
                for (var i = 0, len = this.properties.length; i < len; i++) {
                    var prop = this.properties[i];
                    if (prop instanceof AST_Expansion)
                        return this;
                    var key = prop.key;
                    if (key instanceof AST_Symbol) {
                        key = key.name;
                    }
                    else if (key instanceof AST_Node) {
                        key = key._eval(compressor, depth);
                        if (key === prop.key)
                            return this;
                    }
                    if (typeof Object.prototype[key] === "function") {
                        return this;
                    }
                    if (prop.value instanceof AST_Function)
                        continue;
                    val[key] = prop.value._eval(compressor, depth);
                    if (val[key] === prop.value)
                        return this;
                }
                return val;
            }
            return this;
        });
        var non_converting_unary = makePredicate("! typeof void");
        def_eval(AST_UnaryPrefix, function (compressor, depth) {
            var e = this.expression;
            // Function would be evaluated to an array and so typeof would
            // incorrectly return 'object'. Hence making is a special case.
            if (compressor.option("typeofs")
                && this.operator == "typeof"
                && (e instanceof AST_Lambda
                    || e instanceof AST_SymbolRef
                        && e.fixed_value() instanceof AST_Lambda)) {
                return typeof function () { };
            }
            if (!non_converting_unary.has(this.operator))
                depth++;
            e = e._eval(compressor, depth);
            if (e === this.expression)
                return this;
            switch (this.operator) {
                case "!": return !e;
                case "typeof":
                    // typeof <RegExp> returns "object" or "function" on different platforms
                    // so cannot evaluate reliably
                    if (e instanceof RegExp)
                        return this;
                    return typeof e;
                case "void": return void e;
                case "~": return ~e;
                case "-": return -e;
                case "+": return +e;
            }
            return this;
        });
        var non_converting_binary = makePredicate("&& || ?? === !==");
        const identity_comparison = makePredicate("== != === !==");
        const has_identity = value => typeof value === "object"
            || typeof value === "function"
            || typeof value === "symbol";
        def_eval(AST_Binary, function (compressor, depth) {
            if (!non_converting_binary.has(this.operator))
                depth++;
            var left = this.left._eval(compressor, depth);
            if (left === this.left)
                return this;
            var right = this.right._eval(compressor, depth);
            if (right === this.right)
                return this;
            var result;
            if (left != null
                && right != null
                && identity_comparison.has(this.operator)
                && has_identity(left)
                && has_identity(right)
                && typeof left === typeof right) {
                // Do not compare by reference
                return this;
            }
            switch (this.operator) {
                case "&&":
                    result = left && right;
                    break;
                case "||":
                    result = left || right;
                    break;
                case "??":
                    result = left != null ? left : right;
                    break;
                case "|":
                    result = left | right;
                    break;
                case "&":
                    result = left & right;
                    break;
                case "^":
                    result = left ^ right;
                    break;
                case "+":
                    result = left + right;
                    break;
                case "*":
                    result = left * right;
                    break;
                case "**":
                    result = Math.pow(left, right);
                    break;
                case "/":
                    result = left / right;
                    break;
                case "%":
                    result = left % right;
                    break;
                case "-":
                    result = left - right;
                    break;
                case "<<":
                    result = left << right;
                    break;
                case ">>":
                    result = left >> right;
                    break;
                case ">>>":
                    result = left >>> right;
                    break;
                case "==":
                    result = left == right;
                    break;
                case "===":
                    result = left === right;
                    break;
                case "!=":
                    result = left != right;
                    break;
                case "!==":
                    result = left !== right;
                    break;
                case "<":
                    result = left < right;
                    break;
                case "<=":
                    result = left <= right;
                    break;
                case ">":
                    result = left > right;
                    break;
                case ">=":
                    result = left >= right;
                    break;
                default:
                    return this;
            }
            if (isNaN(result) && compressor.find_parent(AST_With)) {
                // leave original expression as is
                return this;
            }
            return result;
        });
        def_eval(AST_Conditional, function (compressor, depth) {
            var condition = this.condition._eval(compressor, depth);
            if (condition === this.condition)
                return this;
            var node = condition ? this.consequent : this.alternative;
            var value = node._eval(compressor, depth);
            return value === node ? this : value;
        });
        // Set of AST_SymbolRef which are currently being evaluated.
        // Avoids infinite recursion of ._eval()
        const reentrant_ref_eval = new Set();
        def_eval(AST_SymbolRef, function (compressor, depth) {
            if (reentrant_ref_eval.has(this))
                return this;
            var fixed = this.fixed_value();
            if (!fixed)
                return this;
            reentrant_ref_eval.add(this);
            const value = fixed._eval(compressor, depth);
            reentrant_ref_eval.delete(this);
            if (value === fixed)
                return this;
            if (value && typeof value == "object") {
                var escaped = this.definition().escaped;
                if (escaped && depth > escaped)
                    return this;
            }
            return value;
        });
        const global_objs = { Array, Math, Number, Object, String };
        const regexp_flags = new Set([
            "dotAll",
            "global",
            "ignoreCase",
            "multiline",
            "sticky",
            "unicode",
        ]);
        def_eval(AST_PropAccess, function (compressor, depth) {
            let obj = this.expression._eval(compressor, depth + 1);
            if (obj === nullish || (this.optional && obj == null))
                return nullish;
            if (compressor.option("unsafe")) {
                var key = this.property;
                if (key instanceof AST_Node) {
                    key = key._eval(compressor, depth);
                    if (key === this.property)
                        return this;
                }
                var exp = this.expression;
                if (is_undeclared_ref(exp)) {
                    var aa;
                    var first_arg = exp.name === "hasOwnProperty"
                        && key === "call"
                        && (aa = compressor.parent() && compressor.parent().args)
                        && (aa && aa[0]
                            && aa[0].evaluate(compressor));
                    first_arg = first_arg instanceof AST_Dot ? first_arg.expression : first_arg;
                    if (first_arg == null || first_arg.thedef && first_arg.thedef.undeclared) {
                        return this.clone();
                    }
                    if (!is_pure_native_value(exp.name, key))
                        return this;
                    obj = global_objs[exp.name];
                }
                else {
                    if (obj instanceof RegExp) {
                        if (key == "source") {
                            return regexp_source_fix(obj.source);
                        }
                        else if (key == "flags" || regexp_flags.has(key)) {
                            return obj[key];
                        }
                    }
                    if (!obj || obj === exp || !HOP(obj, key))
                        return this;
                    if (typeof obj == "function")
                        switch (key) {
                            case "name":
                                return obj.node.name ? obj.node.name.name : "";
                            case "length":
                                return obj.node.length_property();
                            default:
                                return this;
                        }
                }
                return obj[key];
            }
            return this;
        });
        def_eval(AST_Chain, function (compressor, depth) {
            const evaluated = this.expression._eval(compressor, depth);
            return evaluated === nullish
                ? undefined
                : evaluated === this.expression
                    ? this
                    : evaluated;
        });
        def_eval(AST_Call, function (compressor, depth) {
            var exp = this.expression;
            const callee = exp._eval(compressor, depth);
            if (callee === nullish || (this.optional && callee == null))
                return nullish;
            if (compressor.option("unsafe") && exp instanceof AST_PropAccess) {
                var key = exp.property;
                if (key instanceof AST_Node) {
                    key = key._eval(compressor, depth);
                    if (key === exp.property)
                        return this;
                }
                var val;
                var e = exp.expression;
                if (is_undeclared_ref(e)) {
                    var first_arg = e.name === "hasOwnProperty" &&
                        key === "call" &&
                        (this.args[0] && this.args[0].evaluate(compressor));
                    first_arg = first_arg instanceof AST_Dot ? first_arg.expression : first_arg;
                    if ((first_arg == null || first_arg.thedef && first_arg.thedef.undeclared)) {
                        return this.clone();
                    }
                    if (!is_pure_native_fn(e.name, key))
                        return this;
                    val = global_objs[e.name];
                }
                else {
                    val = e._eval(compressor, depth + 1);
                    if (val === e || !val)
                        return this;
                    if (!is_pure_native_method(val.constructor.name, key))
                        return this;
                }
                var args = [];
                for (var i = 0, len = this.args.length; i < len; i++) {
                    var arg = this.args[i];
                    var value = arg._eval(compressor, depth);
                    if (arg === value)
                        return this;
                    if (arg instanceof AST_Lambda)
                        return this;
                    args.push(value);
                }
                try {
                    return val[key].apply(val, args);
                }
                catch (ex) {
                    // We don't really care
                }
            }
            return this;
        });
        // Also a subclass of AST_Call
        def_eval(AST_New, return_this);
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // AST_Node#drop_side_effect_free() gets called when we don't care about the value,
        // only about side effects. We'll be defining this method for each node type in this module
        //
        // Examples:
        // foo++ -> foo++
        // 1 + func() -> func()
        // 10 -> (nothing)
        // knownPureFunc(foo++) -> foo++
        function def_drop_side_effect_free(node, func) {
            node.DEFMETHOD("drop_side_effect_free", func);
        }
        // Drop side-effect-free elements from an array of expressions.
        // Returns an array of expressions with side-effects or null
        // if all elements were dropped. Note: original array may be
        // returned if nothing changed.
        function trim(nodes, compressor, first_in_statement) {
            var len = nodes.length;
            if (!len)
                return null;
            var ret = [], changed = false;
            for (var i = 0; i < len; i++) {
                var node = nodes[i].drop_side_effect_free(compressor, first_in_statement);
                changed |= node !== nodes[i];
                if (node) {
                    ret.push(node);
                    first_in_statement = false;
                }
            }
            return changed ? ret.length ? ret : null : nodes;
        }
        def_drop_side_effect_free(AST_Node, return_this);
        def_drop_side_effect_free(AST_Constant, return_null);
        def_drop_side_effect_free(AST_This, return_null);
        def_drop_side_effect_free(AST_Call, function (compressor, first_in_statement) {
            if (is_nullish_shortcircuited(this, compressor)) {
                return this.expression.drop_side_effect_free(compressor, first_in_statement);
            }
            if (!this.is_callee_pure(compressor)) {
                if (this.expression.is_call_pure(compressor)) {
                    var exprs = this.args.slice();
                    exprs.unshift(this.expression.expression);
                    exprs = trim(exprs, compressor, first_in_statement);
                    return exprs && make_sequence(this, exprs);
                }
                if (is_func_expr(this.expression)
                    && (!this.expression.name || !this.expression.name.definition().references.length)) {
                    var node = this.clone();
                    node.expression.process_expression(false, compressor);
                    return node;
                }
                return this;
            }
            var args = trim(this.args, compressor, first_in_statement);
            return args && make_sequence(this, args);
        });
        def_drop_side_effect_free(AST_Accessor, return_null);
        def_drop_side_effect_free(AST_Function, return_null);
        def_drop_side_effect_free(AST_Arrow, return_null);
        def_drop_side_effect_free(AST_Class, function (compressor) {
            const with_effects = [];
            const trimmed_extends = this.extends && this.extends.drop_side_effect_free(compressor);
            if (trimmed_extends)
                with_effects.push(trimmed_extends);
            for (const prop of this.properties) {
                if (prop instanceof AST_ClassStaticBlock) {
                    if (prop.body.some(stat => stat.has_side_effects(compressor))) {
                        return this;
                    }
                    else {
                        continue;
                    }
                }
                const trimmed_prop = prop.drop_side_effect_free(compressor);
                if (trimmed_prop)
                    with_effects.push(trimmed_prop);
            }
            if (!with_effects.length)
                return null;
            return make_sequence(this, with_effects);
        });
        def_drop_side_effect_free(AST_Binary, function (compressor, first_in_statement) {
            var right = this.right.drop_side_effect_free(compressor);
            if (!right)
                return this.left.drop_side_effect_free(compressor, first_in_statement);
            if (lazy_op.has(this.operator)) {
                if (right === this.right)
                    return this;
                var node = this.clone();
                node.right = right;
                return node;
            }
            else {
                var left = this.left.drop_side_effect_free(compressor, first_in_statement);
                if (!left)
                    return this.right.drop_side_effect_free(compressor, first_in_statement);
                return make_sequence(this, [left, right]);
            }
        });
        def_drop_side_effect_free(AST_Assign, function (compressor) {
            if (this.logical)
                return this;
            var left = this.left;
            if (left.has_side_effects(compressor)
                || compressor.has_directive("use strict")
                    && left instanceof AST_PropAccess
                    && left.expression.is_constant()) {
                return this;
            }
            set_flag(this, WRITE_ONLY);
            while (left instanceof AST_PropAccess) {
                left = left.expression;
            }
            if (left.is_constant_expression(compressor.find_parent(AST_Scope))) {
                return this.right.drop_side_effect_free(compressor);
            }
            return this;
        });
        def_drop_side_effect_free(AST_Conditional, function (compressor) {
            var consequent = this.consequent.drop_side_effect_free(compressor);
            var alternative = this.alternative.drop_side_effect_free(compressor);
            if (consequent === this.consequent && alternative === this.alternative)
                return this;
            if (!consequent)
                return alternative ? make_node(AST_Binary, this, {
                    operator: "||",
                    left: this.condition,
                    right: alternative
                }) : this.condition.drop_side_effect_free(compressor);
            if (!alternative)
                return make_node(AST_Binary, this, {
                    operator: "&&",
                    left: this.condition,
                    right: consequent
                });
            var node = this.clone();
            node.consequent = consequent;
            node.alternative = alternative;
            return node;
        });
        def_drop_side_effect_free(AST_Unary, function (compressor, first_in_statement) {
            if (unary_side_effects.has(this.operator)) {
                if (!this.expression.has_side_effects(compressor)) {
                    set_flag(this, WRITE_ONLY);
                }
                else {
                    clear_flag(this, WRITE_ONLY);
                }
                return this;
            }
            if (this.operator == "typeof" && this.expression instanceof AST_SymbolRef)
                return null;
            var expression = this.expression.drop_side_effect_free(compressor, first_in_statement);
            if (first_in_statement && expression && is_iife_call(expression)) {
                if (expression === this.expression && this.operator == "!")
                    return this;
                return expression.negate(compressor, first_in_statement);
            }
            return expression;
        });
        def_drop_side_effect_free(AST_SymbolRef, function (compressor) {
            const safe_access = this.is_declared(compressor)
                || pure_prop_access_globals.has(this.name);
            return safe_access ? null : this;
        });
        def_drop_side_effect_free(AST_Object, function (compressor, first_in_statement) {
            var values = trim(this.properties, compressor, first_in_statement);
            return values && make_sequence(this, values);
        });
        def_drop_side_effect_free(AST_ObjectProperty, function (compressor, first_in_statement) {
            const computed_key = this instanceof AST_ObjectKeyVal && this.key instanceof AST_Node;
            const key = computed_key && this.key.drop_side_effect_free(compressor, first_in_statement);
            const value = this.value && this.value.drop_side_effect_free(compressor, first_in_statement);
            if (key && value) {
                return make_sequence(this, [key, value]);
            }
            return key || value;
        });
        def_drop_side_effect_free(AST_ClassProperty, function (compressor) {
            const key = this.computed_key() && this.key.drop_side_effect_free(compressor);
            const value = this.static && this.value
                && this.value.drop_side_effect_free(compressor);
            if (key && value)
                return make_sequence(this, [key, value]);
            return key || value || null;
        });
        def_drop_side_effect_free(AST_ConciseMethod, function () {
            return this.computed_key() ? this.key : null;
        });
        def_drop_side_effect_free(AST_ObjectGetter, function () {
            return this.computed_key() ? this.key : null;
        });
        def_drop_side_effect_free(AST_ObjectSetter, function () {
            return this.computed_key() ? this.key : null;
        });
        def_drop_side_effect_free(AST_Array, function (compressor, first_in_statement) {
            var values = trim(this.elements, compressor, first_in_statement);
            return values && make_sequence(this, values);
        });
        def_drop_side_effect_free(AST_Dot, function (compressor, first_in_statement) {
            if (is_nullish_shortcircuited(this, compressor)) {
                return this.expression.drop_side_effect_free(compressor, first_in_statement);
            }
            if (this.expression.may_throw_on_access(compressor))
                return this;
            return this.expression.drop_side_effect_free(compressor, first_in_statement);
        });
        def_drop_side_effect_free(AST_Sub, function (compressor, first_in_statement) {
            if (is_nullish_shortcircuited(this, compressor)) {
                return this.expression.drop_side_effect_free(compressor, first_in_statement);
            }
            if (this.expression.may_throw_on_access(compressor))
                return this;
            var expression = this.expression.drop_side_effect_free(compressor, first_in_statement);
            if (!expression)
                return this.property.drop_side_effect_free(compressor, first_in_statement);
            var property = this.property.drop_side_effect_free(compressor);
            if (!property)
                return expression;
            return make_sequence(this, [expression, property]);
        });
        def_drop_side_effect_free(AST_Chain, function (compressor, first_in_statement) {
            return this.expression.drop_side_effect_free(compressor, first_in_statement);
        });
        def_drop_side_effect_free(AST_Sequence, function (compressor) {
            var last = this.tail_node();
            var expr = last.drop_side_effect_free(compressor);
            if (expr === last)
                return this;
            var expressions = this.expressions.slice(0, -1);
            if (expr)
                expressions.push(expr);
            if (!expressions.length) {
                return make_node(AST_Number, this, { value: 0 });
            }
            return make_sequence(this, expressions);
        });
        def_drop_side_effect_free(AST_Expansion, function (compressor, first_in_statement) {
            return this.expression.drop_side_effect_free(compressor, first_in_statement);
        });
        def_drop_side_effect_free(AST_TemplateSegment, return_null);
        def_drop_side_effect_free(AST_TemplateString, function (compressor) {
            var values = trim(this.segments, compressor, first_in_statement);
            return values && make_sequence(this, values);
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        const r_keep_assign = /keep_assign/;
        /** Drop unused variables from this scope */
        AST_Scope.DEFMETHOD("drop_unused", function (compressor) {
            if (!compressor.option("unused"))
                return;
            if (compressor.has_directive("use asm"))
                return;
            var self = this;
            if (self.pinned())
                return;
            var drop_funcs = !(self instanceof AST_Toplevel) || compressor.toplevel.funcs;
            var drop_vars = !(self instanceof AST_Toplevel) || compressor.toplevel.vars;
            const assign_as_unused = r_keep_assign.test(compressor.option("unused")) ? return_false : function (node) {
                if (node instanceof AST_Assign
                    && !node.logical
                    && (has_flag(node, WRITE_ONLY) || node.operator == "=")) {
                    return node.left;
                }
                if (node instanceof AST_Unary && has_flag(node, WRITE_ONLY)) {
                    return node.expression;
                }
            };
            var in_use_ids = new Map();
            var fixed_ids = new Map();
            if (self instanceof AST_Toplevel && compressor.top_retain) {
                self.variables.forEach(function (def) {
                    if (compressor.top_retain(def) && !in_use_ids.has(def.id)) {
                        in_use_ids.set(def.id, def);
                    }
                });
            }
            var var_defs_by_id = new Map();
            var initializations = new Map();
            // pass 1: find out which symbols are directly used in
            // this scope (not in nested scopes).
            var scope = this;
            var tw = new TreeWalker(function (node, descend) {
                if (node instanceof AST_Lambda && node.uses_arguments && !tw.has_directive("use strict")) {
                    node.argnames.forEach(function (argname) {
                        if (!(argname instanceof AST_SymbolDeclaration))
                            return;
                        var def = argname.definition();
                        if (!in_use_ids.has(def.id)) {
                            in_use_ids.set(def.id, def);
                        }
                    });
                }
                if (node === self)
                    return;
                if (node instanceof AST_Defun || node instanceof AST_DefClass) {
                    var node_def = node.name.definition();
                    const in_export = tw.parent() instanceof AST_Export;
                    if (in_export || !drop_funcs && scope === self) {
                        if (node_def.global && !in_use_ids.has(node_def.id)) {
                            in_use_ids.set(node_def.id, node_def);
                        }
                    }
                    if (node instanceof AST_DefClass) {
                        if (node.extends
                            && (node.extends.has_side_effects(compressor)
                                || node.extends.may_throw(compressor))) {
                            node.extends.walk(tw);
                        }
                        for (const prop of node.properties) {
                            if (prop.has_side_effects(compressor) ||
                                prop.may_throw(compressor)) {
                                prop.walk(tw);
                            }
                        }
                    }
                    map_add(initializations, node_def.id, node);
                    return true; // don't go in nested scopes
                }
                if (node instanceof AST_SymbolFunarg && scope === self) {
                    map_add(var_defs_by_id, node.definition().id, node);
                }
                if (node instanceof AST_Definitions && scope === self) {
                    const in_export = tw.parent() instanceof AST_Export;
                    node.definitions.forEach(function (def) {
                        if (def.name instanceof AST_SymbolVar) {
                            map_add(var_defs_by_id, def.name.definition().id, def);
                        }
                        if (in_export || !drop_vars) {
                            walk(def.name, node => {
                                if (node instanceof AST_SymbolDeclaration) {
                                    const def = node.definition();
                                    if (def.global && !in_use_ids.has(def.id)) {
                                        in_use_ids.set(def.id, def);
                                    }
                                }
                            });
                        }
                        if (def.name instanceof AST_Destructuring) {
                            def.walk(tw);
                        }
                        if (def.name instanceof AST_SymbolDeclaration && def.value) {
                            var node_def = def.name.definition();
                            map_add(initializations, node_def.id, def.value);
                            if (!node_def.chained && def.name.fixed_value() === def.value) {
                                fixed_ids.set(node_def.id, def);
                            }
                            if (def.value.has_side_effects(compressor)) {
                                def.value.walk(tw);
                            }
                        }
                    });
                    return true;
                }
                return scan_ref_scoped(node, descend);
            });
            self.walk(tw);
            // pass 2: for every used symbol we need to walk its
            // initialization code to figure out if it uses other
            // symbols (that may not be in_use).
            tw = new TreeWalker(scan_ref_scoped);
            in_use_ids.forEach(function (def) {
                var init = initializations.get(def.id);
                if (init)
                    init.forEach(function (init) {
                        init.walk(tw);
                    });
            });
            // pass 3: we should drop declarations not in_use
            var tt = new TreeTransformer(function before(node, descend, in_list) {
                var parent = tt.parent();
                if (drop_vars) {
                    const sym = assign_as_unused(node);
                    if (sym instanceof AST_SymbolRef) {
                        var def = sym.definition();
                        var in_use = in_use_ids.has(def.id);
                        if (node instanceof AST_Assign) {
                            if (!in_use || fixed_ids.has(def.id) && fixed_ids.get(def.id) !== node) {
                                return maintain_this_binding(parent, node, node.right.transform(tt));
                            }
                        }
                        else if (!in_use)
                            return in_list ? MAP.skip : make_node(AST_Number, node, {
                                value: 0
                            });
                    }
                }
                if (scope !== self)
                    return;
                var def;
                if (node.name
                    && (node instanceof AST_ClassExpression
                        && !keep_name(compressor.option("keep_classnames"), (def = node.name.definition()).name)
                        || node instanceof AST_Function
                            && !keep_name(compressor.option("keep_fnames"), (def = node.name.definition()).name))) {
                    // any declarations with same name will overshadow
                    // name of this anonymous function and can therefore
                    // never be used anywhere
                    if (!in_use_ids.has(def.id) || def.orig.length > 1)
                        node.name = null;
                }
                if (node instanceof AST_Lambda && !(node instanceof AST_Accessor)) {
                    var trim = !compressor.option("keep_fargs");
                    for (var a = node.argnames, i = a.length; --i >= 0;) {
                        var sym = a[i];
                        if (sym instanceof AST_Expansion) {
                            sym = sym.expression;
                        }
                        if (sym instanceof AST_DefaultAssign) {
                            sym = sym.left;
                        }
                        // Do not drop destructuring arguments.
                        // They constitute a type assertion of sorts
                        if (!(sym instanceof AST_Destructuring)
                            && !in_use_ids.has(sym.definition().id)) {
                            set_flag(sym, UNUSED);
                            if (trim) {
                                a.pop();
                            }
                        }
                        else {
                            trim = false;
                        }
                    }
                }
                if ((node instanceof AST_Defun || node instanceof AST_DefClass) && node !== self) {
                    const def = node.name.definition();
                    const keep = def.global && !drop_funcs || in_use_ids.has(def.id);
                    // Class "extends" and static blocks may have side effects
                    const has_side_effects = !keep
                        && node instanceof AST_Class
                        && node.has_side_effects(compressor);
                    if (!keep && !has_side_effects) {
                        def.eliminated++;
                        return in_list ? MAP.skip : make_node(AST_EmptyStatement, node);
                    }
                }
                if (node instanceof AST_Definitions && !(parent instanceof AST_ForIn && parent.init === node)) {
                    var drop_block = !(parent instanceof AST_Toplevel) && !(node instanceof AST_Var);
                    // place uninitialized names at the start
                    var body = [], head = [], tail = [];
                    // for unused names whose initialization has
                    // side effects, we can cascade the init. code
                    // into the next one, or next statement.
                    var side_effects = [];
                    node.definitions.forEach(function (def) {
                        if (def.value)
                            def.value = def.value.transform(tt);
                        var is_destructure = def.name instanceof AST_Destructuring;
                        var sym = is_destructure
                            ? new SymbolDef(null, { name: "<destructure>" }) /* fake SymbolDef */
                            : def.name.definition();
                        if (drop_block && sym.global)
                            return tail.push(def);
                        if (!(drop_vars || drop_block)
                            || is_destructure
                                && (def.name.names.length
                                    || def.name.is_array
                                    || compressor.option("pure_getters") != true)
                            || in_use_ids.has(sym.id)) {
                            if (def.value && fixed_ids.has(sym.id) && fixed_ids.get(sym.id) !== def) {
                                def.value = def.value.drop_side_effect_free(compressor);
                            }
                            if (def.name instanceof AST_SymbolVar) {
                                var var_defs = var_defs_by_id.get(sym.id);
                                if (var_defs.length > 1 && (!def.value || sym.orig.indexOf(def.name) > sym.eliminated)) {
                                    if (def.value) {
                                        var ref = make_node(AST_SymbolRef, def.name, def.name);
                                        sym.references.push(ref);
                                        var assign = make_node(AST_Assign, def, {
                                            operator: "=",
                                            logical: false,
                                            left: ref,
                                            right: def.value
                                        });
                                        if (fixed_ids.get(sym.id) === def) {
                                            fixed_ids.set(sym.id, assign);
                                        }
                                        side_effects.push(assign.transform(tt));
                                    }
                                    remove(var_defs, def);
                                    sym.eliminated++;
                                    return;
                                }
                            }
                            if (def.value) {
                                if (side_effects.length > 0) {
                                    if (tail.length > 0) {
                                        side_effects.push(def.value);
                                        def.value = make_sequence(def.value, side_effects);
                                    }
                                    else {
                                        body.push(make_node(AST_SimpleStatement, node, {
                                            body: make_sequence(node, side_effects)
                                        }));
                                    }
                                    side_effects = [];
                                }
                                tail.push(def);
                            }
                            else {
                                head.push(def);
                            }
                        }
                        else if (sym.orig[0] instanceof AST_SymbolCatch) {
                            var value = def.value && def.value.drop_side_effect_free(compressor);
                            if (value)
                                side_effects.push(value);
                            def.value = null;
                            head.push(def);
                        }
                        else {
                            var value = def.value && def.value.drop_side_effect_free(compressor);
                            if (value) {
                                side_effects.push(value);
                            }
                            sym.eliminated++;
                        }
                    });
                    if (head.length > 0 || tail.length > 0) {
                        node.definitions = head.concat(tail);
                        body.push(node);
                    }
                    if (side_effects.length > 0) {
                        body.push(make_node(AST_SimpleStatement, node, {
                            body: make_sequence(node, side_effects)
                        }));
                    }
                    switch (body.length) {
                        case 0:
                            return in_list ? MAP.skip : make_node(AST_EmptyStatement, node);
                        case 1:
                            return body[0];
                        default:
                            return in_list ? MAP.splice(body) : make_node(AST_BlockStatement, node, {
                                body: body
                            });
                    }
                }
                // certain combination of unused name + side effect leads to:
                //    https://github.com/mishoo/UglifyJS2/issues/44
                //    https://github.com/mishoo/UglifyJS2/issues/1830
                //    https://github.com/mishoo/UglifyJS2/issues/1838
                // that's an invalid AST.
                // We fix it at this stage by moving the `var` outside the `for`.
                if (node instanceof AST_For) {
                    descend(node, this);
                    var block;
                    if (node.init instanceof AST_BlockStatement) {
                        block = node.init;
                        node.init = block.body.pop();
                        block.body.push(node);
                    }
                    if (node.init instanceof AST_SimpleStatement) {
                        node.init = node.init.body;
                    }
                    else if (is_empty(node.init)) {
                        node.init = null;
                    }
                    return !block ? node : in_list ? MAP.splice(block.body) : block;
                }
                if (node instanceof AST_LabeledStatement
                    && node.body instanceof AST_For) {
                    descend(node, this);
                    if (node.body instanceof AST_BlockStatement) {
                        var block = node.body;
                        node.body = block.body.pop();
                        block.body.push(node);
                        return in_list ? MAP.splice(block.body) : block;
                    }
                    return node;
                }
                if (node instanceof AST_BlockStatement) {
                    descend(node, this);
                    if (in_list && node.body.every(can_be_evicted_from_block)) {
                        return MAP.splice(node.body);
                    }
                    return node;
                }
                if (node instanceof AST_Scope) {
                    const save_scope = scope;
                    scope = node;
                    descend(node, this);
                    scope = save_scope;
                    return node;
                }
            });
            self.transform(tt);
            function scan_ref_scoped(node, descend) {
                var node_def;
                const sym = assign_as_unused(node);
                if (sym instanceof AST_SymbolRef
                    && !is_ref_of(node.left, AST_SymbolBlockDeclaration)
                    && self.variables.get(sym.name) === (node_def = sym.definition())) {
                    if (node instanceof AST_Assign) {
                        node.right.walk(tw);
                        if (!node_def.chained && node.left.fixed_value() === node.right) {
                            fixed_ids.set(node_def.id, node);
                        }
                    }
                    return true;
                }
                if (node instanceof AST_SymbolRef) {
                    node_def = node.definition();
                    if (!in_use_ids.has(node_def.id)) {
                        in_use_ids.set(node_def.id, node_def);
                        if (node_def.orig[0] instanceof AST_SymbolCatch) {
                            const redef = node_def.scope.is_block_scope()
                                && node_def.scope.get_defun_scope().variables.get(node_def.name);
                            if (redef)
                                in_use_ids.set(redef.id, redef);
                        }
                    }
                    return true;
                }
                if (node instanceof AST_Scope) {
                    var save_scope = scope;
                    scope = node;
                    descend();
                    scope = save_scope;
                    return true;
                }
            }
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        /**
         * Define the method AST_Node#reduce_vars, which goes through the AST in
         * execution order to perform basic flow analysis
         */
        function def_reduce_vars(node, func) {
            node.DEFMETHOD("reduce_vars", func);
        }
        def_reduce_vars(AST_Node, noop);
        /** Clear definition properties */
        function reset_def(compressor, def) {
            def.assignments = 0;
            def.chained = false;
            def.direct_access = false;
            def.escaped = 0;
            def.recursive_refs = 0;
            def.references = [];
            def.single_use = undefined;
            if (def.scope.pinned()
                || (def.orig[0] instanceof AST_SymbolFunarg && def.scope.uses_arguments)) {
                def.fixed = false;
            }
            else if (def.orig[0] instanceof AST_SymbolConst || !compressor.exposed(def)) {
                def.fixed = def.init;
            }
            else {
                def.fixed = false;
            }
        }
        function reset_variables(tw, compressor, node) {
            node.variables.forEach(function (def) {
                reset_def(compressor, def);
                if (def.fixed === null) {
                    tw.defs_to_safe_ids.set(def.id, tw.safe_ids);
                    mark(tw, def, true);
                }
                else if (def.fixed) {
                    tw.loop_ids.set(def.id, tw.in_loop);
                    mark(tw, def, true);
                }
            });
        }
        function reset_block_variables(compressor, node) {
            if (node.block_scope)
                node.block_scope.variables.forEach((def) => {
                    reset_def(compressor, def);
                });
        }
        function push(tw) {
            tw.safe_ids = Object.create(tw.safe_ids);
        }
        function pop(tw) {
            tw.safe_ids = Object.getPrototypeOf(tw.safe_ids);
        }
        function mark(tw, def, safe) {
            tw.safe_ids[def.id] = safe;
        }
        function safe_to_read(tw, def) {
            if (def.single_use == "m")
                return false;
            if (tw.safe_ids[def.id]) {
                if (def.fixed == null) {
                    var orig = def.orig[0];
                    if (orig instanceof AST_SymbolFunarg || orig.name == "arguments")
                        return false;
                    def.fixed = make_node(AST_Undefined, orig);
                }
                return true;
            }
            return def.fixed instanceof AST_Defun;
        }
        function safe_to_assign(tw, def, scope, value) {
            if (def.fixed === undefined)
                return true;
            let def_safe_ids;
            if (def.fixed === null
                && (def_safe_ids = tw.defs_to_safe_ids.get(def.id))) {
                def_safe_ids[def.id] = false;
                tw.defs_to_safe_ids.delete(def.id);
                return true;
            }
            if (!HOP(tw.safe_ids, def.id))
                return false;
            if (!safe_to_read(tw, def))
                return false;
            if (def.fixed === false)
                return false;
            if (def.fixed != null && (!value || def.references.length > def.assignments))
                return false;
            if (def.fixed instanceof AST_Defun) {
                return value instanceof AST_Node && def.fixed.parent_scope === scope;
            }
            return def.orig.every((sym) => {
                return !(sym instanceof AST_SymbolConst
                    || sym instanceof AST_SymbolDefun
                    || sym instanceof AST_SymbolLambda);
            });
        }
        function ref_once(tw, compressor, def) {
            return compressor.option("unused")
                && !def.scope.pinned()
                && def.references.length - def.recursive_refs == 1
                && tw.loop_ids.get(def.id) === tw.in_loop;
        }
        function is_immutable(value) {
            if (!value)
                return false;
            return value.is_constant()
                || value instanceof AST_Lambda
                || value instanceof AST_This;
        }
        // A definition "escapes" when its value can leave the point of use.
        // Example: `a = b || c`
        // In this example, "b" and "c" are escaping, because they're going into "a"
        //
        // def.escaped is != 0 when it escapes.
        //
        // When greater than 1, it means that N chained properties will be read off
        // of that def before an escape occurs. This is useful for evaluating
        // property accesses, where you need to know when to stop.
        function mark_escaped(tw, d, scope, node, value, level = 0, depth = 1) {
            var parent = tw.parent(level);
            if (value) {
                if (value.is_constant())
                    return;
                if (value instanceof AST_ClassExpression)
                    return;
            }
            if (parent instanceof AST_Assign && (parent.operator === "=" || parent.logical) && node === parent.right
                || parent instanceof AST_Call && (node !== parent.expression || parent instanceof AST_New)
                || parent instanceof AST_Exit && node === parent.value && node.scope !== d.scope
                || parent instanceof AST_VarDef && node === parent.value
                || parent instanceof AST_Yield && node === parent.value && node.scope !== d.scope) {
                if (depth > 1 && !(value && value.is_constant_expression(scope)))
                    depth = 1;
                if (!d.escaped || d.escaped > depth)
                    d.escaped = depth;
                return;
            }
            else if (parent instanceof AST_Array
                || parent instanceof AST_Await
                || parent instanceof AST_Binary && lazy_op.has(parent.operator)
                || parent instanceof AST_Conditional && node !== parent.condition
                || parent instanceof AST_Expansion
                || parent instanceof AST_Sequence && node === parent.tail_node()) {
                mark_escaped(tw, d, scope, parent, parent, level + 1, depth);
            }
            else if (parent instanceof AST_ObjectKeyVal && node === parent.value) {
                var obj = tw.parent(level + 1);
                mark_escaped(tw, d, scope, obj, obj, level + 2, depth);
            }
            else if (parent instanceof AST_PropAccess && node === parent.expression) {
                value = read_property(value, parent.property);
                mark_escaped(tw, d, scope, parent, value, level + 1, depth + 1);
                if (value)
                    return;
            }
            if (level > 0)
                return;
            if (parent instanceof AST_Sequence && node !== parent.tail_node())
                return;
            if (parent instanceof AST_SimpleStatement)
                return;
            d.direct_access = true;
        }
        const suppress = node => walk(node, node => {
            if (!(node instanceof AST_Symbol))
                return;
            var d = node.definition();
            if (!d)
                return;
            if (node instanceof AST_SymbolRef)
                d.references.push(node);
            d.fixed = false;
        });
        def_reduce_vars(AST_Accessor, function (tw, descend, compressor) {
            push(tw);
            reset_variables(tw, compressor, this);
            descend();
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_Assign, function (tw, descend, compressor) {
            var node = this;
            if (node.left instanceof AST_Destructuring) {
                suppress(node.left);
                return;
            }
            const finish_walk = () => {
                if (node.logical) {
                    node.left.walk(tw);
                    push(tw);
                    node.right.walk(tw);
                    pop(tw);
                    return true;
                }
            };
            var sym = node.left;
            if (!(sym instanceof AST_SymbolRef))
                return finish_walk();
            var def = sym.definition();
            var safe = safe_to_assign(tw, def, sym.scope, node.right);
            def.assignments++;
            if (!safe)
                return finish_walk();
            var fixed = def.fixed;
            if (!fixed && node.operator != "=" && !node.logical)
                return finish_walk();
            var eq = node.operator == "=";
            var value = eq ? node.right : node;
            if (is_modified(compressor, tw, node, value, 0))
                return finish_walk();
            def.references.push(sym);
            if (!node.logical) {
                if (!eq)
                    def.chained = true;
                def.fixed = eq ? function () {
                    return node.right;
                } : function () {
                    return make_node(AST_Binary, node, {
                        operator: node.operator.slice(0, -1),
                        left: fixed instanceof AST_Node ? fixed : fixed(),
                        right: node.right
                    });
                };
            }
            if (node.logical) {
                mark(tw, def, false);
                push(tw);
                node.right.walk(tw);
                pop(tw);
                return true;
            }
            mark(tw, def, false);
            node.right.walk(tw);
            mark(tw, def, true);
            mark_escaped(tw, def, sym.scope, node, value, 0, 1);
            return true;
        });
        def_reduce_vars(AST_Binary, function (tw) {
            if (!lazy_op.has(this.operator))
                return;
            this.left.walk(tw);
            push(tw);
            this.right.walk(tw);
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_Block, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
        });
        def_reduce_vars(AST_Case, function (tw) {
            push(tw);
            this.expression.walk(tw);
            pop(tw);
            push(tw);
            walk_body(this, tw);
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_Class, function (tw, descend) {
            clear_flag(this, INLINED);
            push(tw);
            descend();
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_ClassStaticBlock, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
        });
        def_reduce_vars(AST_Conditional, function (tw) {
            this.condition.walk(tw);
            push(tw);
            this.consequent.walk(tw);
            pop(tw);
            push(tw);
            this.alternative.walk(tw);
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_Chain, function (tw, descend) {
            // Chains' conditions apply left-to-right, cumulatively.
            // If we walk normally we don't go in that order because we would pop before pushing again
            // Solution: AST_PropAccess and AST_Call push when they are optional, and never pop.
            // Then we pop everything when they are done being walked.
            const safe_ids = tw.safe_ids;
            descend();
            // Unroll back to start
            tw.safe_ids = safe_ids;
            return true;
        });
        def_reduce_vars(AST_Call, function (tw) {
            this.expression.walk(tw);
            if (this.optional) {
                // Never pop -- it's popped at AST_Chain above
                push(tw);
            }
            for (const arg of this.args)
                arg.walk(tw);
            return true;
        });
        def_reduce_vars(AST_PropAccess, function (tw) {
            if (!this.optional)
                return;
            this.expression.walk(tw);
            // Never pop -- it's popped at AST_Chain above
            push(tw);
            if (this.property instanceof AST_Node)
                this.property.walk(tw);
            return true;
        });
        def_reduce_vars(AST_Default, function (tw, descend) {
            push(tw);
            descend();
            pop(tw);
            return true;
        });
        function mark_lambda(tw, descend, compressor) {
            clear_flag(this, INLINED);
            push(tw);
            reset_variables(tw, compressor, this);
            var iife;
            if (!this.name
                && !this.uses_arguments
                && !this.pinned()
                && (iife = tw.parent()) instanceof AST_Call
                && iife.expression === this
                && !iife.args.some(arg => arg instanceof AST_Expansion)
                && this.argnames.every(arg_name => arg_name instanceof AST_Symbol)) {
                // Virtually turn IIFE parameters into variable definitions:
                //   (function(a,b) {...})(c,d) => (function() {var a=c,b=d; ...})()
                // So existing transformation rules can work on them.
                this.argnames.forEach((arg, i) => {
                    if (!arg.definition)
                        return;
                    var d = arg.definition();
                    // Avoid setting fixed when there's more than one origin for a variable value
                    if (d.orig.length > 1)
                        return;
                    if (d.fixed === undefined && (!this.uses_arguments || tw.has_directive("use strict"))) {
                        d.fixed = function () {
                            return iife.args[i] || make_node(AST_Undefined, iife);
                        };
                        tw.loop_ids.set(d.id, tw.in_loop);
                        mark(tw, d, true);
                    }
                    else {
                        d.fixed = false;
                    }
                });
            }
            descend();
            pop(tw);
            return true;
        }
        def_reduce_vars(AST_Lambda, mark_lambda);
        def_reduce_vars(AST_Do, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            const saved_loop = tw.in_loop;
            tw.in_loop = this;
            push(tw);
            this.body.walk(tw);
            if (has_break_or_continue(this)) {
                pop(tw);
                push(tw);
            }
            this.condition.walk(tw);
            pop(tw);
            tw.in_loop = saved_loop;
            return true;
        });
        def_reduce_vars(AST_For, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            if (this.init)
                this.init.walk(tw);
            const saved_loop = tw.in_loop;
            tw.in_loop = this;
            push(tw);
            if (this.condition)
                this.condition.walk(tw);
            this.body.walk(tw);
            if (this.step) {
                if (has_break_or_continue(this)) {
                    pop(tw);
                    push(tw);
                }
                this.step.walk(tw);
            }
            pop(tw);
            tw.in_loop = saved_loop;
            return true;
        });
        def_reduce_vars(AST_ForIn, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            suppress(this.init);
            this.object.walk(tw);
            const saved_loop = tw.in_loop;
            tw.in_loop = this;
            push(tw);
            this.body.walk(tw);
            pop(tw);
            tw.in_loop = saved_loop;
            return true;
        });
        def_reduce_vars(AST_If, function (tw) {
            this.condition.walk(tw);
            push(tw);
            this.body.walk(tw);
            pop(tw);
            if (this.alternative) {
                push(tw);
                this.alternative.walk(tw);
                pop(tw);
            }
            return true;
        });
        def_reduce_vars(AST_LabeledStatement, function (tw) {
            push(tw);
            this.body.walk(tw);
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_SymbolCatch, function () {
            this.definition().fixed = false;
        });
        def_reduce_vars(AST_SymbolRef, function (tw, descend, compressor) {
            var d = this.definition();
            d.references.push(this);
            if (d.references.length == 1
                && !d.fixed
                && d.orig[0] instanceof AST_SymbolDefun) {
                tw.loop_ids.set(d.id, tw.in_loop);
            }
            var fixed_value;
            if (d.fixed === undefined || !safe_to_read(tw, d)) {
                d.fixed = false;
            }
            else if (d.fixed) {
                fixed_value = this.fixed_value();
                if (fixed_value instanceof AST_Lambda
                    && is_recursive_ref(tw, d)) {
                    d.recursive_refs++;
                }
                else if (fixed_value
                    && !compressor.exposed(d)
                    && ref_once(tw, compressor, d)) {
                    d.single_use =
                        fixed_value instanceof AST_Lambda && !fixed_value.pinned()
                            || fixed_value instanceof AST_Class
                            || d.scope === this.scope && fixed_value.is_constant_expression();
                }
                else {
                    d.single_use = false;
                }
                if (is_modified(compressor, tw, this, fixed_value, 0, is_immutable(fixed_value))) {
                    if (d.single_use) {
                        d.single_use = "m";
                    }
                    else {
                        d.fixed = false;
                    }
                }
            }
            mark_escaped(tw, d, this.scope, this, fixed_value, 0, 1);
        });
        def_reduce_vars(AST_Toplevel, function (tw, descend, compressor) {
            this.globals.forEach(function (def) {
                reset_def(compressor, def);
            });
            reset_variables(tw, compressor, this);
        });
        def_reduce_vars(AST_Try, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            push(tw);
            this.body.walk(tw);
            pop(tw);
            if (this.bcatch) {
                push(tw);
                this.bcatch.walk(tw);
                pop(tw);
            }
            if (this.bfinally)
                this.bfinally.walk(tw);
            return true;
        });
        def_reduce_vars(AST_Unary, function (tw) {
            var node = this;
            if (node.operator !== "++" && node.operator !== "--")
                return;
            var exp = node.expression;
            if (!(exp instanceof AST_SymbolRef))
                return;
            var def = exp.definition();
            var safe = safe_to_assign(tw, def, exp.scope, true);
            def.assignments++;
            if (!safe)
                return;
            var fixed = def.fixed;
            if (!fixed)
                return;
            def.references.push(exp);
            def.chained = true;
            def.fixed = function () {
                return make_node(AST_Binary, node, {
                    operator: node.operator.slice(0, -1),
                    left: make_node(AST_UnaryPrefix, node, {
                        operator: "+",
                        expression: fixed instanceof AST_Node ? fixed : fixed()
                    }),
                    right: make_node(AST_Number, node, {
                        value: 1
                    })
                });
            };
            mark(tw, def, true);
            return true;
        });
        def_reduce_vars(AST_VarDef, function (tw, descend) {
            var node = this;
            if (node.name instanceof AST_Destructuring) {
                suppress(node.name);
                return;
            }
            var d = node.name.definition();
            if (node.value) {
                if (safe_to_assign(tw, d, node.name.scope, node.value)) {
                    d.fixed = function () {
                        return node.value;
                    };
                    tw.loop_ids.set(d.id, tw.in_loop);
                    mark(tw, d, false);
                    descend();
                    mark(tw, d, true);
                    return true;
                }
                else {
                    d.fixed = false;
                }
            }
        });
        def_reduce_vars(AST_While, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            const saved_loop = tw.in_loop;
            tw.in_loop = this;
            push(tw);
            descend();
            pop(tw);
            tw.in_loop = saved_loop;
            return true;
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function loop_body(x) {
            if (x instanceof AST_IterationStatement) {
                return x.body instanceof AST_BlockStatement ? x.body : x;
            }
            return x;
        }
        function is_lhs_read_only(lhs) {
            if (lhs instanceof AST_This)
                return true;
            if (lhs instanceof AST_SymbolRef)
                return lhs.definition().orig[0] instanceof AST_SymbolLambda;
            if (lhs instanceof AST_PropAccess) {
                lhs = lhs.expression;
                if (lhs instanceof AST_SymbolRef) {
                    if (lhs.is_immutable())
                        return false;
                    lhs = lhs.fixed_value();
                }
                if (!lhs)
                    return true;
                if (lhs instanceof AST_RegExp)
                    return false;
                if (lhs instanceof AST_Constant)
                    return true;
                return is_lhs_read_only(lhs);
            }
            return false;
        }
        // Remove code which we know is unreachable.
        function trim_unreachable_code(compressor, stat, target) {
            walk(stat, node => {
                if (node instanceof AST_Var) {
                    node.remove_initializers();
                    target.push(node);
                    return true;
                }
                if (node instanceof AST_Defun
                    && (node === stat || !compressor.has_directive("use strict"))) {
                    target.push(node === stat ? node : make_node(AST_Var, node, {
                        definitions: [
                            make_node(AST_VarDef, node, {
                                name: make_node(AST_SymbolVar, node.name, node.name),
                                value: null
                            })
                        ]
                    }));
                    return true;
                }
                if (node instanceof AST_Export || node instanceof AST_Import) {
                    target.push(node);
                    return true;
                }
                if (node instanceof AST_Scope) {
                    return true;
                }
            });
        }
        /** Tighten a bunch of statements together, and perform statement-level optimization. */
        function tighten_body(statements, compressor) {
            const nearest_scope = compressor.find_scope();
            const defun_scope = nearest_scope.get_defun_scope();
            const { in_loop, in_try } = find_loop_scope_try();
            var CHANGED, max_iter = 10;
            do {
                CHANGED = false;
                eliminate_spurious_blocks(statements);
                if (compressor.option("dead_code")) {
                    eliminate_dead_code(statements, compressor);
                }
                if (compressor.option("if_return")) {
                    handle_if_return(statements, compressor);
                }
                if (compressor.sequences_limit > 0) {
                    sequencesize(statements, compressor);
                    sequencesize_2(statements, compressor);
                }
                if (compressor.option("join_vars")) {
                    join_consecutive_vars(statements);
                }
                if (compressor.option("collapse_vars")) {
                    collapse(statements, compressor);
                }
            } while (CHANGED && max_iter-- > 0);
            function find_loop_scope_try() {
                var node = compressor.self(), level = 0, in_loop = false, in_try = false;
                do {
                    if (node instanceof AST_IterationStatement) {
                        in_loop = true;
                    }
                    else if (node instanceof AST_Scope) {
                        break;
                    }
                    else if (node instanceof AST_TryBlock) {
                        in_try = true;
                    }
                } while (node = compressor.parent(level++));
                return { in_loop, in_try };
            }
            // Search from right to left for assignment-like expressions:
            // - `var a = x;`
            // - `a = x;`
            // - `++a`
            // For each candidate, scan from left to right for first usage, then try
            // to fold assignment into the site for compression.
            // Will not attempt to collapse assignments into or past code blocks
            // which are not sequentially executed, e.g. loops and conditionals.
            function collapse(statements, compressor) {
                if (nearest_scope.pinned() || defun_scope.pinned())
                    return statements;
                var args;
                var candidates = [];
                var stat_index = statements.length;
                var scanner = new TreeTransformer(function (node) {
                    if (abort)
                        return node;
                    // Skip nodes before `candidate` as quickly as possible
                    if (!hit) {
                        if (node !== hit_stack[hit_index])
                            return node;
                        hit_index++;
                        if (hit_index < hit_stack.length)
                            return handle_custom_scan_order(node);
                        hit = true;
                        stop_after = find_stop(node, 0);
                        if (stop_after === node)
                            abort = true;
                        return node;
                    }
                    // Stop immediately if these node types are encountered
                    var parent = scanner.parent();
                    if (node instanceof AST_Assign
                        && (node.logical || node.operator != "=" && lhs.equivalent_to(node.left))
                        || node instanceof AST_Await
                        || node instanceof AST_Call && lhs instanceof AST_PropAccess && lhs.equivalent_to(node.expression)
                        ||
                            (node instanceof AST_Call || node instanceof AST_PropAccess)
                                && node.optional
                        || node instanceof AST_Debugger
                        || node instanceof AST_Destructuring
                        || node instanceof AST_Expansion
                            && node.expression instanceof AST_Symbol
                            && (node.expression instanceof AST_This
                                || node.expression.definition().references.length > 1)
                        || node instanceof AST_IterationStatement && !(node instanceof AST_For)
                        || node instanceof AST_LoopControl
                        || node instanceof AST_Try
                        || node instanceof AST_With
                        || node instanceof AST_Yield
                        || node instanceof AST_Export
                        || node instanceof AST_Class
                        || parent instanceof AST_For && node !== parent.init
                        || !replace_all
                            && (node instanceof AST_SymbolRef
                                && !node.is_declared(compressor)
                                && !pure_prop_access_globals.has(node))
                        || node instanceof AST_SymbolRef
                            && parent instanceof AST_Call
                            && has_annotation(parent, _NOINLINE)) {
                        abort = true;
                        return node;
                    }
                    // Stop only if candidate is found within conditional branches
                    if (!stop_if_hit && (!lhs_local || !replace_all)
                        && (parent instanceof AST_Binary && lazy_op.has(parent.operator) && parent.left !== node
                            || parent instanceof AST_Conditional && parent.condition !== node
                            || parent instanceof AST_If && parent.condition !== node)) {
                        stop_if_hit = parent;
                    }
                    // Replace variable with assignment when found
                    if (can_replace
                        && !(node instanceof AST_SymbolDeclaration)
                        && lhs.equivalent_to(node)
                        && !shadows(scanner.find_scope() || nearest_scope, lvalues)) {
                        if (stop_if_hit) {
                            abort = true;
                            return node;
                        }
                        if (is_lhs(node, parent)) {
                            if (value_def)
                                replaced++;
                            return node;
                        }
                        else {
                            replaced++;
                            if (value_def && candidate instanceof AST_VarDef)
                                return node;
                        }
                        CHANGED = abort = true;
                        if (candidate instanceof AST_UnaryPostfix) {
                            return make_node(AST_UnaryPrefix, candidate, candidate);
                        }
                        if (candidate instanceof AST_VarDef) {
                            var def = candidate.name.definition();
                            var value = candidate.value;
                            if (def.references.length - def.replaced == 1 && !compressor.exposed(def)) {
                                def.replaced++;
                                if (funarg && is_identifier_atom(value)) {
                                    return value.transform(compressor);
                                }
                                else {
                                    return maintain_this_binding(parent, node, value);
                                }
                            }
                            return make_node(AST_Assign, candidate, {
                                operator: "=",
                                logical: false,
                                left: make_node(AST_SymbolRef, candidate.name, candidate.name),
                                right: value
                            });
                        }
                        clear_flag(candidate, WRITE_ONLY);
                        return candidate;
                    }
                    // These node types have child nodes that execute sequentially,
                    // but are otherwise not safe to scan into or beyond them.
                    var sym;
                    if (node instanceof AST_Call
                        || node instanceof AST_Exit
                            && (side_effects || lhs instanceof AST_PropAccess || may_modify(lhs))
                        || node instanceof AST_PropAccess
                            && (side_effects || node.expression.may_throw_on_access(compressor))
                        || node instanceof AST_SymbolRef
                            && ((lvalues.has(node.name) && lvalues.get(node.name).modified) || side_effects && may_modify(node))
                        || node instanceof AST_VarDef && node.value
                            && (lvalues.has(node.name.name) || side_effects && may_modify(node.name))
                        || (sym = is_lhs(node.left, node))
                            && (sym instanceof AST_PropAccess || lvalues.has(sym.name))
                        || may_throw
                            && (in_try ? node.has_side_effects(compressor) : side_effects_external(node))) {
                        stop_after = node;
                        if (node instanceof AST_Scope)
                            abort = true;
                    }
                    return handle_custom_scan_order(node);
                }, function (node) {
                    if (abort)
                        return;
                    if (stop_after === node)
                        abort = true;
                    if (stop_if_hit === node)
                        stop_if_hit = null;
                });
                var multi_replacer = new TreeTransformer(function (node) {
                    if (abort)
                        return node;
                    // Skip nodes before `candidate` as quickly as possible
                    if (!hit) {
                        if (node !== hit_stack[hit_index])
                            return node;
                        hit_index++;
                        if (hit_index < hit_stack.length)
                            return;
                        hit = true;
                        return node;
                    }
                    // Replace variable when found
                    if (node instanceof AST_SymbolRef
                        && node.name == def.name) {
                        if (!--replaced)
                            abort = true;
                        if (is_lhs(node, multi_replacer.parent()))
                            return node;
                        def.replaced++;
                        value_def.replaced--;
                        return candidate.value;
                    }
                    // Skip (non-executed) functions and (leading) default case in switch statements
                    if (node instanceof AST_Default || node instanceof AST_Scope)
                        return node;
                });
                while (--stat_index >= 0) {
                    // Treat parameters as collapsible in IIFE, i.e.
                    //   function(a, b){ ... }(x());
                    // would be translated into equivalent assignments:
                    //   var a = x(), b = undefined;
                    if (stat_index == 0 && compressor.option("unused"))
                        extract_args();
                    // Find collapsible assignments
                    var hit_stack = [];
                    extract_candidates(statements[stat_index]);
                    while (candidates.length > 0) {
                        hit_stack = candidates.pop();
                        var hit_index = 0;
                        var candidate = hit_stack[hit_stack.length - 1];
                        var value_def = null;
                        var stop_after = null;
                        var stop_if_hit = null;
                        var lhs = get_lhs(candidate);
                        if (!lhs || is_lhs_read_only(lhs) || lhs.has_side_effects(compressor))
                            continue;
                        // Locate symbols which may execute code outside of scanning range
                        var lvalues = get_lvalues(candidate);
                        var lhs_local = is_lhs_local(lhs);
                        if (lhs instanceof AST_SymbolRef) {
                            lvalues.set(lhs.name, { def: lhs.definition(), modified: false });
                        }
                        var side_effects = value_has_side_effects(candidate);
                        var replace_all = replace_all_symbols();
                        var may_throw = candidate.may_throw(compressor);
                        var funarg = candidate.name instanceof AST_SymbolFunarg;
                        var hit = funarg;
                        var abort = false, replaced = 0, can_replace = !args || !hit;
                        if (!can_replace) {
                            for (let j = compressor.self().argnames.lastIndexOf(candidate.name) + 1; !abort && j < args.length; j++) {
                                args[j].transform(scanner);
                            }
                            can_replace = true;
                        }
                        for (var i = stat_index; !abort && i < statements.length; i++) {
                            statements[i].transform(scanner);
                        }
                        if (value_def) {
                            var def = candidate.name.definition();
                            if (abort && def.references.length - def.replaced > replaced)
                                replaced = false;
                            else {
                                abort = false;
                                hit_index = 0;
                                hit = funarg;
                                for (var i = stat_index; !abort && i < statements.length; i++) {
                                    statements[i].transform(multi_replacer);
                                }
                                value_def.single_use = false;
                            }
                        }
                        if (replaced && !remove_candidate(candidate))
                            statements.splice(stat_index, 1);
                    }
                }
                function handle_custom_scan_order(node) {
                    // Skip (non-executed) functions
                    if (node instanceof AST_Scope)
                        return node;
                    // Scan case expressions first in a switch statement
                    if (node instanceof AST_Switch) {
                        node.expression = node.expression.transform(scanner);
                        for (var i = 0, len = node.body.length; !abort && i < len; i++) {
                            var branch = node.body[i];
                            if (branch instanceof AST_Case) {
                                if (!hit) {
                                    if (branch !== hit_stack[hit_index])
                                        continue;
                                    hit_index++;
                                }
                                branch.expression = branch.expression.transform(scanner);
                                if (!replace_all)
                                    break;
                            }
                        }
                        abort = true;
                        return node;
                    }
                }
                function redefined_within_scope(def, scope) {
                    if (def.global)
                        return false;
                    let cur_scope = def.scope;
                    while (cur_scope && cur_scope !== scope) {
                        if (cur_scope.variables.has(def.name)) {
                            return true;
                        }
                        cur_scope = cur_scope.parent_scope;
                    }
                    return false;
                }
                function has_overlapping_symbol(fn, arg, fn_strict) {
                    var found = false, scan_this = !(fn instanceof AST_Arrow);
                    arg.walk(new TreeWalker(function (node, descend) {
                        if (found)
                            return true;
                        if (node instanceof AST_SymbolRef && (fn.variables.has(node.name) || redefined_within_scope(node.definition(), fn))) {
                            var s = node.definition().scope;
                            if (s !== defun_scope)
                                while (s = s.parent_scope) {
                                    if (s === defun_scope)
                                        return true;
                                }
                            return found = true;
                        }
                        if ((fn_strict || scan_this) && node instanceof AST_This) {
                            return found = true;
                        }
                        if (node instanceof AST_Scope && !(node instanceof AST_Arrow)) {
                            var prev = scan_this;
                            scan_this = false;
                            descend();
                            scan_this = prev;
                            return true;
                        }
                    }));
                    return found;
                }
                function extract_args() {
                    var iife, fn = compressor.self();
                    if (is_func_expr(fn)
                        && !fn.name
                        && !fn.uses_arguments
                        && !fn.pinned()
                        && (iife = compressor.parent()) instanceof AST_Call
                        && iife.expression === fn
                        && iife.args.every((arg) => !(arg instanceof AST_Expansion))) {
                        var fn_strict = compressor.has_directive("use strict");
                        if (fn_strict && !member(fn_strict, fn.body))
                            fn_strict = false;
                        var len = fn.argnames.length;
                        args = iife.args.slice(len);
                        var names = new Set();
                        for (var i = len; --i >= 0;) {
                            var sym = fn.argnames[i];
                            var arg = iife.args[i];
                            // The following two line fix is a duplicate of the fix at
                            // https://github.com/terser/terser/commit/011d3eb08cefe6922c7d1bdfa113fc4aeaca1b75
                            // This might mean that these two pieces of code (one here in collapse_vars and another in reduce_vars
                            // Might be doing the exact same thing.
                            const def = sym.definition && sym.definition();
                            const is_reassigned = def && def.orig.length > 1;
                            if (is_reassigned)
                                continue;
                            args.unshift(make_node(AST_VarDef, sym, {
                                name: sym,
                                value: arg
                            }));
                            if (names.has(sym.name))
                                continue;
                            names.add(sym.name);
                            if (sym instanceof AST_Expansion) {
                                var elements = iife.args.slice(i);
                                if (elements.every((arg) => !has_overlapping_symbol(fn, arg, fn_strict))) {
                                    candidates.unshift([make_node(AST_VarDef, sym, {
                                            name: sym.expression,
                                            value: make_node(AST_Array, iife, {
                                                elements: elements
                                            })
                                        })]);
                                }
                            }
                            else {
                                if (!arg) {
                                    arg = make_node(AST_Undefined, sym).transform(compressor);
                                }
                                else if (arg instanceof AST_Lambda && arg.pinned()
                                    || has_overlapping_symbol(fn, arg, fn_strict)) {
                                    arg = null;
                                }
                                if (arg)
                                    candidates.unshift([make_node(AST_VarDef, sym, {
                                            name: sym,
                                            value: arg
                                        })]);
                            }
                        }
                    }
                }
                function extract_candidates(expr) {
                    hit_stack.push(expr);
                    if (expr instanceof AST_Assign) {
                        if (!expr.left.has_side_effects(compressor)
                            && !(expr.right instanceof AST_Chain)) {
                            candidates.push(hit_stack.slice());
                        }
                        extract_candidates(expr.right);
                    }
                    else if (expr instanceof AST_Binary) {
                        extract_candidates(expr.left);
                        extract_candidates(expr.right);
                    }
                    else if (expr instanceof AST_Call && !has_annotation(expr, _NOINLINE)) {
                        extract_candidates(expr.expression);
                        expr.args.forEach(extract_candidates);
                    }
                    else if (expr instanceof AST_Case) {
                        extract_candidates(expr.expression);
                    }
                    else if (expr instanceof AST_Conditional) {
                        extract_candidates(expr.condition);
                        extract_candidates(expr.consequent);
                        extract_candidates(expr.alternative);
                    }
                    else if (expr instanceof AST_Definitions) {
                        var len = expr.definitions.length;
                        // limit number of trailing variable definitions for consideration
                        var i = len - 200;
                        if (i < 0)
                            i = 0;
                        for (; i < len; i++) {
                            extract_candidates(expr.definitions[i]);
                        }
                    }
                    else if (expr instanceof AST_DWLoop) {
                        extract_candidates(expr.condition);
                        if (!(expr.body instanceof AST_Block)) {
                            extract_candidates(expr.body);
                        }
                    }
                    else if (expr instanceof AST_Exit) {
                        if (expr.value)
                            extract_candidates(expr.value);
                    }
                    else if (expr instanceof AST_For) {
                        if (expr.init)
                            extract_candidates(expr.init);
                        if (expr.condition)
                            extract_candidates(expr.condition);
                        if (expr.step)
                            extract_candidates(expr.step);
                        if (!(expr.body instanceof AST_Block)) {
                            extract_candidates(expr.body);
                        }
                    }
                    else if (expr instanceof AST_ForIn) {
                        extract_candidates(expr.object);
                        if (!(expr.body instanceof AST_Block)) {
                            extract_candidates(expr.body);
                        }
                    }
                    else if (expr instanceof AST_If) {
                        extract_candidates(expr.condition);
                        if (!(expr.body instanceof AST_Block)) {
                            extract_candidates(expr.body);
                        }
                        if (expr.alternative && !(expr.alternative instanceof AST_Block)) {
                            extract_candidates(expr.alternative);
                        }
                    }
                    else if (expr instanceof AST_Sequence) {
                        expr.expressions.forEach(extract_candidates);
                    }
                    else if (expr instanceof AST_SimpleStatement) {
                        extract_candidates(expr.body);
                    }
                    else if (expr instanceof AST_Switch) {
                        extract_candidates(expr.expression);
                        expr.body.forEach(extract_candidates);
                    }
                    else if (expr instanceof AST_Unary) {
                        if (expr.operator == "++" || expr.operator == "--") {
                            candidates.push(hit_stack.slice());
                        }
                    }
                    else if (expr instanceof AST_VarDef) {
                        if (expr.value && !(expr.value instanceof AST_Chain)) {
                            candidates.push(hit_stack.slice());
                            extract_candidates(expr.value);
                        }
                    }
                    hit_stack.pop();
                }
                function find_stop(node, level, write_only) {
                    var parent = scanner.parent(level);
                    if (parent instanceof AST_Assign) {
                        if (write_only
                            && !parent.logical
                            && !(parent.left instanceof AST_PropAccess
                                || lvalues.has(parent.left.name))) {
                            return find_stop(parent, level + 1, write_only);
                        }
                        return node;
                    }
                    if (parent instanceof AST_Binary) {
                        if (write_only && (!lazy_op.has(parent.operator) || parent.left === node)) {
                            return find_stop(parent, level + 1, write_only);
                        }
                        return node;
                    }
                    if (parent instanceof AST_Call)
                        return node;
                    if (parent instanceof AST_Case)
                        return node;
                    if (parent instanceof AST_Conditional) {
                        if (write_only && parent.condition === node) {
                            return find_stop(parent, level + 1, write_only);
                        }
                        return node;
                    }
                    if (parent instanceof AST_Definitions) {
                        return find_stop(parent, level + 1, true);
                    }
                    if (parent instanceof AST_Exit) {
                        return write_only ? find_stop(parent, level + 1, write_only) : node;
                    }
                    if (parent instanceof AST_If) {
                        if (write_only && parent.condition === node) {
                            return find_stop(parent, level + 1, write_only);
                        }
                        return node;
                    }
                    if (parent instanceof AST_IterationStatement)
                        return node;
                    if (parent instanceof AST_Sequence) {
                        return find_stop(parent, level + 1, parent.tail_node() !== node);
                    }
                    if (parent instanceof AST_SimpleStatement) {
                        return find_stop(parent, level + 1, true);
                    }
                    if (parent instanceof AST_Switch)
                        return node;
                    if (parent instanceof AST_VarDef)
                        return node;
                    return null;
                }
                function mangleable_var(var_def) {
                    var value = var_def.value;
                    if (!(value instanceof AST_SymbolRef))
                        return;
                    if (value.name == "arguments")
                        return;
                    var def = value.definition();
                    if (def.undeclared)
                        return;
                    return value_def = def;
                }
                function get_lhs(expr) {
                    if (expr instanceof AST_Assign && expr.logical) {
                        return false;
                    }
                    else if (expr instanceof AST_VarDef && expr.name instanceof AST_SymbolDeclaration) {
                        var def = expr.name.definition();
                        if (!member(expr.name, def.orig))
                            return;
                        var referenced = def.references.length - def.replaced;
                        if (!referenced)
                            return;
                        var declared = def.orig.length - def.eliminated;
                        if (declared > 1 && !(expr.name instanceof AST_SymbolFunarg)
                            || (referenced > 1 ? mangleable_var(expr) : !compressor.exposed(def))) {
                            return make_node(AST_SymbolRef, expr.name, expr.name);
                        }
                    }
                    else {
                        const lhs = expr instanceof AST_Assign
                            ? expr.left
                            : expr.expression;
                        return !is_ref_of(lhs, AST_SymbolConst)
                            && !is_ref_of(lhs, AST_SymbolLet) && lhs;
                    }
                }
                function get_rvalue(expr) {
                    if (expr instanceof AST_Assign) {
                        return expr.right;
                    }
                    else {
                        return expr.value;
                    }
                }
                function get_lvalues(expr) {
                    var lvalues = new Map();
                    if (expr instanceof AST_Unary)
                        return lvalues;
                    var tw = new TreeWalker(function (node) {
                        var sym = node;
                        while (sym instanceof AST_PropAccess)
                            sym = sym.expression;
                        if (sym instanceof AST_SymbolRef) {
                            const prev = lvalues.get(sym.name);
                            if (!prev || !prev.modified) {
                                lvalues.set(sym.name, {
                                    def: sym.definition(),
                                    modified: is_modified(compressor, tw, node, node, 0)
                                });
                            }
                        }
                    });
                    get_rvalue(expr).walk(tw);
                    return lvalues;
                }
                function remove_candidate(expr) {
                    if (expr.name instanceof AST_SymbolFunarg) {
                        var iife = compressor.parent(), argnames = compressor.self().argnames;
                        var index = argnames.indexOf(expr.name);
                        if (index < 0) {
                            iife.args.length = Math.min(iife.args.length, argnames.length - 1);
                        }
                        else {
                            var args = iife.args;
                            if (args[index])
                                args[index] = make_node(AST_Number, args[index], {
                                    value: 0
                                });
                        }
                        return true;
                    }
                    var found = false;
                    return statements[stat_index].transform(new TreeTransformer(function (node, descend, in_list) {
                        if (found)
                            return node;
                        if (node === expr || node.body === expr) {
                            found = true;
                            if (node instanceof AST_VarDef) {
                                node.value = node.name instanceof AST_SymbolConst
                                    ? make_node(AST_Undefined, node.value) // `const` always needs value.
                                    : null;
                                return node;
                            }
                            return in_list ? MAP.skip : null;
                        }
                    }, function (node) {
                        if (node instanceof AST_Sequence)
                            switch (node.expressions.length) {
                                case 0: return null;
                                case 1: return node.expressions[0];
                            }
                    }));
                }
                function is_lhs_local(lhs) {
                    while (lhs instanceof AST_PropAccess)
                        lhs = lhs.expression;
                    return lhs instanceof AST_SymbolRef
                        && lhs.definition().scope.get_defun_scope() === defun_scope
                        && !(in_loop
                            && (lvalues.has(lhs.name)
                                || candidate instanceof AST_Unary
                                || (candidate instanceof AST_Assign
                                    && !candidate.logical
                                    && candidate.operator != "=")));
                }
                function value_has_side_effects(expr) {
                    if (expr instanceof AST_Unary)
                        return unary_side_effects.has(expr.operator);
                    return get_rvalue(expr).has_side_effects(compressor);
                }
                function replace_all_symbols() {
                    if (side_effects)
                        return false;
                    if (value_def)
                        return true;
                    if (lhs instanceof AST_SymbolRef) {
                        var def = lhs.definition();
                        if (def.references.length - def.replaced == (candidate instanceof AST_VarDef ? 1 : 2)) {
                            return true;
                        }
                    }
                    return false;
                }
                function may_modify(sym) {
                    if (!sym.definition)
                        return true; // AST_Destructuring
                    var def = sym.definition();
                    if (def.orig.length == 1 && def.orig[0] instanceof AST_SymbolDefun)
                        return false;
                    if (def.scope.get_defun_scope() !== defun_scope)
                        return true;
                    return def.references.some((ref) => ref.scope.get_defun_scope() !== defun_scope);
                }
                function side_effects_external(node, lhs) {
                    if (node instanceof AST_Assign)
                        return side_effects_external(node.left, true);
                    if (node instanceof AST_Unary)
                        return side_effects_external(node.expression, true);
                    if (node instanceof AST_VarDef)
                        return node.value && side_effects_external(node.value);
                    if (lhs) {
                        if (node instanceof AST_Dot)
                            return side_effects_external(node.expression, true);
                        if (node instanceof AST_Sub)
                            return side_effects_external(node.expression, true);
                        if (node instanceof AST_SymbolRef)
                            return node.definition().scope.get_defun_scope() !== defun_scope;
                    }
                    return false;
                }
                /**
                 * Will any of the pulled-in lvalues shadow a variable in newScope or parents?
                 * similar to scope_encloses_variables_in_this_scope */
                function shadows(my_scope, lvalues) {
                    for (const { def } of lvalues.values()) {
                        const looked_up = my_scope.find_variable(def.name);
                        if (looked_up) {
                            if (looked_up === def)
                                continue;
                            return true;
                        }
                    }
                    return false;
                }
            }
            function eliminate_spurious_blocks(statements) {
                var seen_dirs = [];
                for (var i = 0; i < statements.length;) {
                    var stat = statements[i];
                    if (stat instanceof AST_BlockStatement && stat.body.every(can_be_evicted_from_block)) {
                        CHANGED = true;
                        eliminate_spurious_blocks(stat.body);
                        statements.splice(i, 1, ...stat.body);
                        i += stat.body.length;
                    }
                    else if (stat instanceof AST_EmptyStatement) {
                        CHANGED = true;
                        statements.splice(i, 1);
                    }
                    else if (stat instanceof AST_Directive) {
                        if (seen_dirs.indexOf(stat.value) < 0) {
                            i++;
                            seen_dirs.push(stat.value);
                        }
                        else {
                            CHANGED = true;
                            statements.splice(i, 1);
                        }
                    }
                    else
                        i++;
                }
            }
            function handle_if_return(statements, compressor) {
                var self = compressor.self();
                var multiple_if_returns = has_multiple_if_returns(statements);
                var in_lambda = self instanceof AST_Lambda;
                for (var i = statements.length; --i >= 0;) {
                    var stat = statements[i];
                    var j = next_index(i);
                    var next = statements[j];
                    if (in_lambda && !next && stat instanceof AST_Return) {
                        if (!stat.value) {
                            CHANGED = true;
                            statements.splice(i, 1);
                            continue;
                        }
                        if (stat.value instanceof AST_UnaryPrefix && stat.value.operator == "void") {
                            CHANGED = true;
                            statements[i] = make_node(AST_SimpleStatement, stat, {
                                body: stat.value.expression
                            });
                            continue;
                        }
                    }
                    if (stat instanceof AST_If) {
                        var ab = aborts(stat.body);
                        if (can_merge_flow(ab)) {
                            if (ab.label) {
                                remove(ab.label.thedef.references, ab);
                            }
                            CHANGED = true;
                            stat = stat.clone();
                            stat.condition = stat.condition.negate(compressor);
                            var body = as_statement_array_with_return(stat.body, ab);
                            stat.body = make_node(AST_BlockStatement, stat, {
                                body: as_statement_array(stat.alternative).concat(extract_functions())
                            });
                            stat.alternative = make_node(AST_BlockStatement, stat, {
                                body: body
                            });
                            statements[i] = stat.transform(compressor);
                            continue;
                        }
                        var ab = aborts(stat.alternative);
                        if (can_merge_flow(ab)) {
                            if (ab.label) {
                                remove(ab.label.thedef.references, ab);
                            }
                            CHANGED = true;
                            stat = stat.clone();
                            stat.body = make_node(AST_BlockStatement, stat.body, {
                                body: as_statement_array(stat.body).concat(extract_functions())
                            });
                            var body = as_statement_array_with_return(stat.alternative, ab);
                            stat.alternative = make_node(AST_BlockStatement, stat.alternative, {
                                body: body
                            });
                            statements[i] = stat.transform(compressor);
                            continue;
                        }
                    }
                    if (stat instanceof AST_If && stat.body instanceof AST_Return) {
                        var value = stat.body.value;
                        //---
                        // pretty silly case, but:
                        // if (foo()) return; return; ==> foo(); return;
                        if (!value && !stat.alternative
                            && (in_lambda && !next || next instanceof AST_Return && !next.value)) {
                            CHANGED = true;
                            statements[i] = make_node(AST_SimpleStatement, stat.condition, {
                                body: stat.condition
                            });
                            continue;
                        }
                        //---
                        // if (foo()) return x; return y; ==> return foo() ? x : y;
                        if (value && !stat.alternative && next instanceof AST_Return && next.value) {
                            CHANGED = true;
                            stat = stat.clone();
                            stat.alternative = next;
                            statements[i] = stat.transform(compressor);
                            statements.splice(j, 1);
                            continue;
                        }
                        //---
                        // if (foo()) return x; [ return ; ] ==> return foo() ? x : undefined;
                        if (value && !stat.alternative
                            && (!next && in_lambda && multiple_if_returns
                                || next instanceof AST_Return)) {
                            CHANGED = true;
                            stat = stat.clone();
                            stat.alternative = next || make_node(AST_Return, stat, {
                                value: null
                            });
                            statements[i] = stat.transform(compressor);
                            if (next)
                                statements.splice(j, 1);
                            continue;
                        }
                        //---
                        // if (a) return b; if (c) return d; e; ==> return a ? b : c ? d : void e;
                        //
                        // if sequences is not enabled, this can lead to an endless loop (issue #866).
                        // however, with sequences on this helps producing slightly better output for
                        // the example code.
                        var prev = statements[prev_index(i)];
                        if (compressor.option("sequences") && in_lambda && !stat.alternative
                            && prev instanceof AST_If && prev.body instanceof AST_Return
                            && next_index(j) == statements.length && next instanceof AST_SimpleStatement) {
                            CHANGED = true;
                            stat = stat.clone();
                            stat.alternative = make_node(AST_BlockStatement, next, {
                                body: [
                                    next,
                                    make_node(AST_Return, next, {
                                        value: null
                                    })
                                ]
                            });
                            statements[i] = stat.transform(compressor);
                            statements.splice(j, 1);
                            continue;
                        }
                    }
                }
                function has_multiple_if_returns(statements) {
                    var n = 0;
                    for (var i = statements.length; --i >= 0;) {
                        var stat = statements[i];
                        if (stat instanceof AST_If && stat.body instanceof AST_Return) {
                            if (++n > 1)
                                return true;
                        }
                    }
                    return false;
                }
                function is_return_void(value) {
                    return !value || value instanceof AST_UnaryPrefix && value.operator == "void";
                }
                function can_merge_flow(ab) {
                    if (!ab)
                        return false;
                    for (var j = i + 1, len = statements.length; j < len; j++) {
                        var stat = statements[j];
                        if (stat instanceof AST_Const || stat instanceof AST_Let)
                            return false;
                    }
                    var lct = ab instanceof AST_LoopControl ? compressor.loopcontrol_target(ab) : null;
                    return ab instanceof AST_Return && in_lambda && is_return_void(ab.value)
                        || ab instanceof AST_Continue && self === loop_body(lct)
                        || ab instanceof AST_Break && lct instanceof AST_BlockStatement && self === lct;
                }
                function extract_functions() {
                    var tail = statements.slice(i + 1);
                    statements.length = i + 1;
                    return tail.filter(function (stat) {
                        if (stat instanceof AST_Defun) {
                            statements.push(stat);
                            return false;
                        }
                        return true;
                    });
                }
                function as_statement_array_with_return(node, ab) {
                    var body = as_statement_array(node).slice(0, -1);
                    if (ab.value) {
                        body.push(make_node(AST_SimpleStatement, ab.value, {
                            body: ab.value.expression
                        }));
                    }
                    return body;
                }
                function next_index(i) {
                    for (var j = i + 1, len = statements.length; j < len; j++) {
                        var stat = statements[j];
                        if (!(stat instanceof AST_Var && declarations_only(stat))) {
                            break;
                        }
                    }
                    return j;
                }
                function prev_index(i) {
                    for (var j = i; --j >= 0;) {
                        var stat = statements[j];
                        if (!(stat instanceof AST_Var && declarations_only(stat))) {
                            break;
                        }
                    }
                    return j;
                }
            }
            function eliminate_dead_code(statements, compressor) {
                var has_quit;
                var self = compressor.self();
                for (var i = 0, n = 0, len = statements.length; i < len; i++) {
                    var stat = statements[i];
                    if (stat instanceof AST_LoopControl) {
                        var lct = compressor.loopcontrol_target(stat);
                        if (stat instanceof AST_Break
                            && !(lct instanceof AST_IterationStatement)
                            && loop_body(lct) === self
                            || stat instanceof AST_Continue
                                && loop_body(lct) === self) {
                            if (stat.label) {
                                remove(stat.label.thedef.references, stat);
                            }
                        }
                        else {
                            statements[n++] = stat;
                        }
                    }
                    else {
                        statements[n++] = stat;
                    }
                    if (aborts(stat)) {
                        has_quit = statements.slice(i + 1);
                        break;
                    }
                }
                statements.length = n;
                CHANGED = n != len;
                if (has_quit)
                    has_quit.forEach(function (stat) {
                        trim_unreachable_code(compressor, stat, statements);
                    });
            }
            function declarations_only(node) {
                return node.definitions.every((var_def) => !var_def.value);
            }
            function sequencesize(statements, compressor) {
                if (statements.length < 2)
                    return;
                var seq = [], n = 0;
                function push_seq() {
                    if (!seq.length)
                        return;
                    var body = make_sequence(seq[0], seq);
                    statements[n++] = make_node(AST_SimpleStatement, body, { body: body });
                    seq = [];
                }
                for (var i = 0, len = statements.length; i < len; i++) {
                    var stat = statements[i];
                    if (stat instanceof AST_SimpleStatement) {
                        if (seq.length >= compressor.sequences_limit)
                            push_seq();
                        var body = stat.body;
                        if (seq.length > 0)
                            body = body.drop_side_effect_free(compressor);
                        if (body)
                            merge_sequence(seq, body);
                    }
                    else if (stat instanceof AST_Definitions && declarations_only(stat)
                        || stat instanceof AST_Defun) {
                        statements[n++] = stat;
                    }
                    else {
                        push_seq();
                        statements[n++] = stat;
                    }
                }
                push_seq();
                statements.length = n;
                if (n != len)
                    CHANGED = true;
            }
            function to_simple_statement(block, decls) {
                if (!(block instanceof AST_BlockStatement))
                    return block;
                var stat = null;
                for (var i = 0, len = block.body.length; i < len; i++) {
                    var line = block.body[i];
                    if (line instanceof AST_Var && declarations_only(line)) {
                        decls.push(line);
                    }
                    else if (stat || line instanceof AST_Const || line instanceof AST_Let) {
                        return false;
                    }
                    else {
                        stat = line;
                    }
                }
                return stat;
            }
            function sequencesize_2(statements, compressor) {
                function cons_seq(right) {
                    n--;
                    CHANGED = true;
                    var left = prev.body;
                    return make_sequence(left, [left, right]).transform(compressor);
                }
                var n = 0, prev;
                for (var i = 0; i < statements.length; i++) {
                    var stat = statements[i];
                    if (prev) {
                        if (stat instanceof AST_Exit) {
                            stat.value = cons_seq(stat.value || make_node(AST_Undefined, stat).transform(compressor));
                        }
                        else if (stat instanceof AST_For) {
                            if (!(stat.init instanceof AST_Definitions)) {
                                const abort = walk(prev.body, node => {
                                    if (node instanceof AST_Scope)
                                        return true;
                                    if (node instanceof AST_Binary
                                        && node.operator === "in") {
                                        return walk_abort;
                                    }
                                });
                                if (!abort) {
                                    if (stat.init)
                                        stat.init = cons_seq(stat.init);
                                    else {
                                        stat.init = prev.body;
                                        n--;
                                        CHANGED = true;
                                    }
                                }
                            }
                        }
                        else if (stat instanceof AST_ForIn) {
                            if (!(stat.init instanceof AST_Const) && !(stat.init instanceof AST_Let)) {
                                stat.object = cons_seq(stat.object);
                            }
                        }
                        else if (stat instanceof AST_If) {
                            stat.condition = cons_seq(stat.condition);
                        }
                        else if (stat instanceof AST_Switch) {
                            stat.expression = cons_seq(stat.expression);
                        }
                        else if (stat instanceof AST_With) {
                            stat.expression = cons_seq(stat.expression);
                        }
                    }
                    if (compressor.option("conditionals") && stat instanceof AST_If) {
                        var decls = [];
                        var body = to_simple_statement(stat.body, decls);
                        var alt = to_simple_statement(stat.alternative, decls);
                        if (body !== false && alt !== false && decls.length > 0) {
                            var len = decls.length;
                            decls.push(make_node(AST_If, stat, {
                                condition: stat.condition,
                                body: body || make_node(AST_EmptyStatement, stat.body),
                                alternative: alt
                            }));
                            decls.unshift(n, 1);
                            [].splice.apply(statements, decls);
                            i += len;
                            n += len + 1;
                            prev = null;
                            CHANGED = true;
                            continue;
                        }
                    }
                    statements[n++] = stat;
                    prev = stat instanceof AST_SimpleStatement ? stat : null;
                }
                statements.length = n;
            }
            function join_object_assignments(defn, body) {
                if (!(defn instanceof AST_Definitions))
                    return;
                var def = defn.definitions[defn.definitions.length - 1];
                if (!(def.value instanceof AST_Object))
                    return;
                var exprs;
                if (body instanceof AST_Assign && !body.logical) {
                    exprs = [body];
                }
                else if (body instanceof AST_Sequence) {
                    exprs = body.expressions.slice();
                }
                if (!exprs)
                    return;
                var trimmed = false;
                do {
                    var node = exprs[0];
                    if (!(node instanceof AST_Assign))
                        break;
                    if (node.operator != "=")
                        break;
                    if (!(node.left instanceof AST_PropAccess))
                        break;
                    var sym = node.left.expression;
                    if (!(sym instanceof AST_SymbolRef))
                        break;
                    if (def.name.name != sym.name)
                        break;
                    if (!node.right.is_constant_expression(nearest_scope))
                        break;
                    var prop = node.left.property;
                    if (prop instanceof AST_Node) {
                        prop = prop.evaluate(compressor);
                    }
                    if (prop instanceof AST_Node)
                        break;
                    prop = "" + prop;
                    var diff = compressor.option("ecma") < 2015
                        && compressor.has_directive("use strict") ? function (node) {
                        return node.key != prop && (node.key && node.key.name != prop);
                    } : function (node) {
                        return node.key && node.key.name != prop;
                    };
                    if (!def.value.properties.every(diff))
                        break;
                    var p = def.value.properties.filter(function (p) { return p.key === prop; })[0];
                    if (!p) {
                        def.value.properties.push(make_node(AST_ObjectKeyVal, node, {
                            key: prop,
                            value: node.right
                        }));
                    }
                    else {
                        p.value = new AST_Sequence({
                            start: p.start,
                            expressions: [p.value.clone(), node.right.clone()],
                            end: p.end
                        });
                    }
                    exprs.shift();
                    trimmed = true;
                } while (exprs.length);
                return trimmed && exprs;
            }
            function join_consecutive_vars(statements) {
                var defs;
                for (var i = 0, j = -1, len = statements.length; i < len; i++) {
                    var stat = statements[i];
                    var prev = statements[j];
                    if (stat instanceof AST_Definitions) {
                        if (prev && prev.TYPE == stat.TYPE) {
                            prev.definitions = prev.definitions.concat(stat.definitions);
                            CHANGED = true;
                        }
                        else if (defs && defs.TYPE == stat.TYPE && declarations_only(stat)) {
                            defs.definitions = defs.definitions.concat(stat.definitions);
                            CHANGED = true;
                        }
                        else {
                            statements[++j] = stat;
                            defs = stat;
                        }
                    }
                    else if (stat instanceof AST_Exit) {
                        stat.value = extract_object_assignments(stat.value);
                    }
                    else if (stat instanceof AST_For) {
                        var exprs = join_object_assignments(prev, stat.init);
                        if (exprs) {
                            CHANGED = true;
                            stat.init = exprs.length ? make_sequence(stat.init, exprs) : null;
                            statements[++j] = stat;
                        }
                        else if (prev instanceof AST_Var
                            && (!stat.init || stat.init.TYPE == prev.TYPE)) {
                            if (stat.init) {
                                prev.definitions = prev.definitions.concat(stat.init.definitions);
                            }
                            stat.init = prev;
                            statements[j] = stat;
                            CHANGED = true;
                        }
                        else if (defs instanceof AST_Var
                            && stat.init instanceof AST_Var
                            && declarations_only(stat.init)) {
                            defs.definitions = defs.definitions.concat(stat.init.definitions);
                            stat.init = null;
                            statements[++j] = stat;
                            CHANGED = true;
                        }
                        else {
                            statements[++j] = stat;
                        }
                    }
                    else if (stat instanceof AST_ForIn) {
                        stat.object = extract_object_assignments(stat.object);
                    }
                    else if (stat instanceof AST_If) {
                        stat.condition = extract_object_assignments(stat.condition);
                    }
                    else if (stat instanceof AST_SimpleStatement) {
                        var exprs = join_object_assignments(prev, stat.body);
                        if (exprs) {
                            CHANGED = true;
                            if (!exprs.length)
                                continue;
                            stat.body = make_sequence(stat.body, exprs);
                        }
                        statements[++j] = stat;
                    }
                    else if (stat instanceof AST_Switch) {
                        stat.expression = extract_object_assignments(stat.expression);
                    }
                    else if (stat instanceof AST_With) {
                        stat.expression = extract_object_assignments(stat.expression);
                    }
                    else {
                        statements[++j] = stat;
                    }
                }
                statements.length = j + 1;
                function extract_object_assignments(value) {
                    statements[++j] = stat;
                    var exprs = join_object_assignments(prev, value);
                    if (exprs) {
                        CHANGED = true;
                        if (exprs.length) {
                            return make_sequence(value, exprs);
                        }
                        else if (value instanceof AST_Sequence) {
                            return value.tail_node().left;
                        }
                        else {
                            return value.left;
                        }
                    }
                    return value;
                }
            }
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        /**
         * Module that contains the inlining logic.
         *
         * @module
         *
         * The stars of the show are `inline_into_symbolref` and `inline_into_call`.
         */
        function within_array_or_object_literal(compressor) {
            var node, level = 0;
            while (node = compressor.parent(level++)) {
                if (node instanceof AST_Statement)
                    return false;
                if (node instanceof AST_Array
                    || node instanceof AST_ObjectKeyVal
                    || node instanceof AST_Object) {
                    return true;
                }
            }
            return false;
        }
        function scope_encloses_variables_in_this_scope(scope, pulled_scope) {
            for (const enclosed of pulled_scope.enclosed) {
                if (pulled_scope.variables.has(enclosed.name)) {
                    continue;
                }
                const looked_up = scope.find_variable(enclosed.name);
                if (looked_up) {
                    if (looked_up === enclosed)
                        continue;
                    return true;
                }
            }
            return false;
        }
        function inline_into_symbolref(self, compressor) {
            const parent = compressor.parent();
            const def = self.definition();
            const nearest_scope = compressor.find_scope();
            if (compressor.top_retain && def.global && compressor.top_retain(def)) {
                def.fixed = false;
                def.single_use = false;
                return self;
            }
            let fixed = self.fixed_value();
            let single_use = def.single_use
                && !(parent instanceof AST_Call
                    && (parent.is_callee_pure(compressor))
                    || has_annotation(parent, _NOINLINE))
                && !(parent instanceof AST_Export
                    && fixed instanceof AST_Lambda
                    && fixed.name);
            if (single_use && fixed instanceof AST_Node) {
                single_use =
                    !fixed.has_side_effects(compressor)
                        && !fixed.may_throw(compressor);
            }
            if (single_use && (fixed instanceof AST_Lambda || fixed instanceof AST_Class)) {
                if (retain_top_func(fixed, compressor)) {
                    single_use = false;
                }
                else if (def.scope !== self.scope
                    && (def.escaped == 1
                        || has_flag(fixed, INLINED)
                        || within_array_or_object_literal(compressor)
                        || !compressor.option("reduce_funcs"))) {
                    single_use = false;
                }
                else if (is_recursive_ref(compressor, def)) {
                    single_use = false;
                }
                else if (def.scope !== self.scope || def.orig[0] instanceof AST_SymbolFunarg) {
                    single_use = fixed.is_constant_expression(self.scope);
                    if (single_use == "f") {
                        var scope = self.scope;
                        do {
                            if (scope instanceof AST_Defun || is_func_expr(scope)) {
                                set_flag(scope, INLINED);
                            }
                        } while (scope = scope.parent_scope);
                    }
                }
            }
            if (single_use && (fixed instanceof AST_Lambda || fixed instanceof AST_Class)) {
                single_use =
                    def.scope === self.scope
                        && !scope_encloses_variables_in_this_scope(nearest_scope, fixed)
                        || parent instanceof AST_Call
                            && parent.expression === self
                            && !scope_encloses_variables_in_this_scope(nearest_scope, fixed)
                            && !(fixed.name && fixed.name.definition().recursive_refs > 0);
            }
            if (single_use && fixed) {
                if (fixed instanceof AST_DefClass) {
                    set_flag(fixed, SQUEEZED);
                    fixed = make_node(AST_ClassExpression, fixed, fixed);
                }
                if (fixed instanceof AST_Defun) {
                    set_flag(fixed, SQUEEZED);
                    fixed = make_node(AST_Function, fixed, fixed);
                }
                if (def.recursive_refs > 0 && fixed.name instanceof AST_SymbolDefun) {
                    const defun_def = fixed.name.definition();
                    let lambda_def = fixed.variables.get(fixed.name.name);
                    let name = lambda_def && lambda_def.orig[0];
                    if (!(name instanceof AST_SymbolLambda)) {
                        name = make_node(AST_SymbolLambda, fixed.name, fixed.name);
                        name.scope = fixed;
                        fixed.name = name;
                        lambda_def = fixed.def_function(name);
                    }
                    walk(fixed, node => {
                        if (node instanceof AST_SymbolRef && node.definition() === defun_def) {
                            node.thedef = lambda_def;
                            lambda_def.references.push(node);
                        }
                    });
                }
                if ((fixed instanceof AST_Lambda || fixed instanceof AST_Class)
                    && fixed.parent_scope !== nearest_scope) {
                    fixed = fixed.clone(true, compressor.get_toplevel());
                    nearest_scope.add_child_scope(fixed);
                }
                return fixed.optimize(compressor);
            }
            // multiple uses
            if (fixed) {
                let replace;
                if (fixed instanceof AST_This) {
                    if (!(def.orig[0] instanceof AST_SymbolFunarg)
                        && def.references.every((ref) => def.scope === ref.scope)) {
                        replace = fixed;
                    }
                }
                else {
                    var ev = fixed.evaluate(compressor);
                    if (ev !== fixed
                        && (compressor.option("unsafe_regexp") || !(ev instanceof RegExp))) {
                        replace = make_node_from_constant(ev, fixed);
                    }
                }
                if (replace) {
                    const name_length = self.size(compressor);
                    const replace_size = replace.size(compressor);
                    let overhead = 0;
                    if (compressor.option("unused") && !compressor.exposed(def)) {
                        overhead =
                            (name_length + 2 + replace_size) /
                                (def.references.length - def.assignments);
                    }
                    if (replace_size <= name_length + overhead) {
                        return replace;
                    }
                }
            }
            return self;
        }
        function inline_into_call(self, fn, compressor) {
            var exp = self.expression;
            var simple_args = self.args.every((arg) => !(arg instanceof AST_Expansion));
            if (compressor.option("reduce_vars")
                && fn instanceof AST_SymbolRef
                && !has_annotation(self, _NOINLINE)) {
                const fixed = fn.fixed_value();
                if (!retain_top_func(fixed, compressor)) {
                    fn = fixed;
                }
            }
            var is_func = fn instanceof AST_Lambda;
            var stat = is_func && fn.body[0];
            var is_regular_func = is_func && !fn.is_generator && !fn.async;
            var can_inline = is_regular_func && compressor.option("inline") && !self.is_callee_pure(compressor);
            if (can_inline && stat instanceof AST_Return) {
                let returned = stat.value;
                if (!returned || returned.is_constant_expression()) {
                    if (returned) {
                        returned = returned.clone(true);
                    }
                    else {
                        returned = make_node(AST_Undefined, self);
                    }
                    const args = self.args.concat(returned);
                    return make_sequence(self, args).optimize(compressor);
                }
                // optimize identity function
                if (fn.argnames.length === 1
                    && (fn.argnames[0] instanceof AST_SymbolFunarg)
                    && self.args.length < 2
                    && !(self.args[0] instanceof AST_Expansion)
                    && returned instanceof AST_SymbolRef
                    && returned.name === fn.argnames[0].name) {
                    const replacement = (self.args[0] || make_node(AST_Undefined)).optimize(compressor);
                    let parent;
                    if (replacement instanceof AST_PropAccess
                        && (parent = compressor.parent()) instanceof AST_Call
                        && parent.expression === self) {
                        // identity function was being used to remove `this`, like in
                        //
                        // id(bag.no_this)(...)
                        //
                        // Replace with a larger but more effish (0, bag.no_this) wrapper.
                        return make_sequence(self, [
                            make_node(AST_Number, self, { value: 0 }),
                            replacement
                        ]);
                    }
                    // replace call with first argument or undefined if none passed
                    return replacement;
                }
            }
            if (can_inline) {
                var scope, in_loop, level = -1;
                let def;
                let returned_value;
                let nearest_scope;
                if (simple_args
                    && !fn.uses_arguments
                    && !(compressor.parent() instanceof AST_Class)
                    && !(fn.name && fn instanceof AST_Function)
                    && (returned_value = can_flatten_body(stat))
                    && (exp === fn
                        || has_annotation(self, _INLINE)
                        || compressor.option("unused")
                            && (def = exp.definition()).references.length == 1
                            && !is_recursive_ref(compressor, def)
                            && fn.is_constant_expression(exp.scope))
                    && !has_annotation(self, _PURE | _NOINLINE)
                    && !fn.contains_this()
                    && can_inject_symbols()
                    && (nearest_scope = compressor.find_scope())
                    && !scope_encloses_variables_in_this_scope(nearest_scope, fn)
                    && !(function in_default_assign() {
                        // Due to the fact function parameters have their own scope
                        // which can't use `var something` in the function body within,
                        // we simply don't inline into DefaultAssign.
                        let i = 0;
                        let p;
                        while ((p = compressor.parent(i++))) {
                            if (p instanceof AST_DefaultAssign)
                                return true;
                            if (p instanceof AST_Block)
                                break;
                        }
                        return false;
                    })()
                    && !(scope instanceof AST_Class)) {
                    set_flag(fn, SQUEEZED);
                    nearest_scope.add_child_scope(fn);
                    return make_sequence(self, flatten_fn(returned_value)).optimize(compressor);
                }
            }
            if (can_inline && has_annotation(self, _INLINE)) {
                set_flag(fn, SQUEEZED);
                fn = make_node(fn.CTOR === AST_Defun ? AST_Function : fn.CTOR, fn, fn);
                fn = fn.clone(true);
                fn.figure_out_scope({}, {
                    parent_scope: compressor.find_scope(),
                    toplevel: compressor.get_toplevel()
                });
                return make_node(AST_Call, self, {
                    expression: fn,
                    args: self.args,
                }).optimize(compressor);
            }
            const can_drop_this_call = is_regular_func && compressor.option("side_effects") && fn.body.every(is_empty);
            if (can_drop_this_call) {
                var args = self.args.concat(make_node(AST_Undefined, self));
                return make_sequence(self, args).optimize(compressor);
            }
            if (compressor.option("negate_iife")
                && compressor.parent() instanceof AST_SimpleStatement
                && is_iife_call(self)) {
                return self.negate(compressor, true);
            }
            var ev = self.evaluate(compressor);
            if (ev !== self) {
                ev = make_node_from_constant(ev, self).optimize(compressor);
                return best_of(compressor, ev, self);
            }
            return self;
            function return_value(stat) {
                if (!stat)
                    return make_node(AST_Undefined, self);
                if (stat instanceof AST_Return) {
                    if (!stat.value)
                        return make_node(AST_Undefined, self);
                    return stat.value.clone(true);
                }
                if (stat instanceof AST_SimpleStatement) {
                    return make_node(AST_UnaryPrefix, stat, {
                        operator: "void",
                        expression: stat.body.clone(true)
                    });
                }
            }
            function can_flatten_body(stat) {
                var body = fn.body;
                var len = body.length;
                if (compressor.option("inline") < 3) {
                    return len == 1 && return_value(stat);
                }
                stat = null;
                for (var i = 0; i < len; i++) {
                    var line = body[i];
                    if (line instanceof AST_Var) {
                        if (stat && !line.definitions.every((var_def) => !var_def.value)) {
                            return false;
                        }
                    }
                    else if (stat) {
                        return false;
                    }
                    else if (!(line instanceof AST_EmptyStatement)) {
                        stat = line;
                    }
                }
                return return_value(stat);
            }
            function can_inject_args(block_scoped, safe_to_inject) {
                for (var i = 0, len = fn.argnames.length; i < len; i++) {
                    var arg = fn.argnames[i];
                    if (arg instanceof AST_DefaultAssign) {
                        if (has_flag(arg.left, UNUSED))
                            continue;
                        return false;
                    }
                    if (arg instanceof AST_Destructuring)
                        return false;
                    if (arg instanceof AST_Expansion) {
                        if (has_flag(arg.expression, UNUSED))
                            continue;
                        return false;
                    }
                    if (has_flag(arg, UNUSED))
                        continue;
                    if (!safe_to_inject
                        || block_scoped.has(arg.name)
                        || identifier_atom.has(arg.name)
                        || scope.conflicting_def(arg.name)) {
                        return false;
                    }
                    if (in_loop)
                        in_loop.push(arg.definition());
                }
                return true;
            }
            function can_inject_vars(block_scoped, safe_to_inject) {
                var len = fn.body.length;
                for (var i = 0; i < len; i++) {
                    var stat = fn.body[i];
                    if (!(stat instanceof AST_Var))
                        continue;
                    if (!safe_to_inject)
                        return false;
                    for (var j = stat.definitions.length; --j >= 0;) {
                        var name = stat.definitions[j].name;
                        if (name instanceof AST_Destructuring
                            || block_scoped.has(name.name)
                            || identifier_atom.has(name.name)
                            || scope.conflicting_def(name.name)) {
                            return false;
                        }
                        if (in_loop)
                            in_loop.push(name.definition());
                    }
                }
                return true;
            }
            function can_inject_symbols() {
                var block_scoped = new Set();
                do {
                    scope = compressor.parent(++level);
                    if (scope.is_block_scope() && scope.block_scope) {
                        // TODO this is sometimes undefined during compression.
                        // But it should always have a value!
                        scope.block_scope.variables.forEach(function (variable) {
                            block_scoped.add(variable.name);
                        });
                    }
                    if (scope instanceof AST_Catch) {
                        // TODO can we delete? AST_Catch is a block scope.
                        if (scope.argname) {
                            block_scoped.add(scope.argname.name);
                        }
                    }
                    else if (scope instanceof AST_IterationStatement) {
                        in_loop = [];
                    }
                    else if (scope instanceof AST_SymbolRef) {
                        if (scope.fixed_value() instanceof AST_Scope)
                            return false;
                    }
                } while (!(scope instanceof AST_Scope));
                var safe_to_inject = !(scope instanceof AST_Toplevel) || compressor.toplevel.vars;
                var inline = compressor.option("inline");
                if (!can_inject_vars(block_scoped, inline >= 3 && safe_to_inject))
                    return false;
                if (!can_inject_args(block_scoped, inline >= 2 && safe_to_inject))
                    return false;
                return !in_loop || in_loop.length == 0 || !is_reachable(fn, in_loop);
            }
            function append_var(decls, expressions, name, value) {
                var def = name.definition();
                // Name already exists, only when a function argument had the same name
                const already_appended = scope.variables.has(name.name);
                if (!already_appended) {
                    scope.variables.set(name.name, def);
                    scope.enclosed.push(def);
                    decls.push(make_node(AST_VarDef, name, {
                        name: name,
                        value: null
                    }));
                }
                var sym = make_node(AST_SymbolRef, name, name);
                def.references.push(sym);
                if (value)
                    expressions.push(make_node(AST_Assign, self, {
                        operator: "=",
                        logical: false,
                        left: sym,
                        right: value.clone()
                    }));
            }
            function flatten_args(decls, expressions) {
                var len = fn.argnames.length;
                for (var i = self.args.length; --i >= len;) {
                    expressions.push(self.args[i]);
                }
                for (i = len; --i >= 0;) {
                    var name = fn.argnames[i];
                    var value = self.args[i];
                    if (has_flag(name, UNUSED) || !name.name || scope.conflicting_def(name.name)) {
                        if (value)
                            expressions.push(value);
                    }
                    else {
                        var symbol = make_node(AST_SymbolVar, name, name);
                        name.definition().orig.push(symbol);
                        if (!value && in_loop)
                            value = make_node(AST_Undefined, self);
                        append_var(decls, expressions, symbol, value);
                    }
                }
                decls.reverse();
                expressions.reverse();
            }
            function flatten_vars(decls, expressions) {
                var pos = expressions.length;
                for (var i = 0, lines = fn.body.length; i < lines; i++) {
                    var stat = fn.body[i];
                    if (!(stat instanceof AST_Var))
                        continue;
                    for (var j = 0, defs = stat.definitions.length; j < defs; j++) {
                        var var_def = stat.definitions[j];
                        var name = var_def.name;
                        append_var(decls, expressions, name, var_def.value);
                        if (in_loop && fn.argnames.every((argname) => argname.name != name.name)) {
                            var def = fn.variables.get(name.name);
                            var sym = make_node(AST_SymbolRef, name, name);
                            def.references.push(sym);
                            expressions.splice(pos++, 0, make_node(AST_Assign, var_def, {
                                operator: "=",
                                logical: false,
                                left: sym,
                                right: make_node(AST_Undefined, name)
                            }));
                        }
                    }
                }
            }
            function flatten_fn(returned_value) {
                var decls = [];
                var expressions = [];
                flatten_args(decls, expressions);
                flatten_vars(decls, expressions);
                expressions.push(returned_value);
                if (decls.length) {
                    const i = scope.body.indexOf(compressor.parent(level - 1)) + 1;
                    scope.body.splice(i, 0, make_node(AST_Var, fn, {
                        definitions: decls
                    }));
                }
                return expressions.map(exp => exp.clone(true));
            }
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        class Compressor extends TreeWalker {
            constructor(options, { false_by_default = false, mangle_options = false }) {
                super();
                if (options.defaults !== undefined && !options.defaults)
                    false_by_default = true;
                this.options = defaults(options, {
                    arguments: false,
                    arrows: !false_by_default,
                    booleans: !false_by_default,
                    booleans_as_integers: false,
                    collapse_vars: !false_by_default,
                    comparisons: !false_by_default,
                    computed_props: !false_by_default,
                    conditionals: !false_by_default,
                    dead_code: !false_by_default,
                    defaults: true,
                    directives: !false_by_default,
                    drop_console: false,
                    drop_debugger: !false_by_default,
                    ecma: 5,
                    evaluate: !false_by_default,
                    expression: false,
                    global_defs: false,
                    hoist_funs: false,
                    hoist_props: !false_by_default,
                    hoist_vars: false,
                    ie8: false,
                    if_return: !false_by_default,
                    inline: !false_by_default,
                    join_vars: !false_by_default,
                    keep_classnames: false,
                    keep_fargs: true,
                    keep_fnames: false,
                    keep_infinity: false,
                    loops: !false_by_default,
                    module: false,
                    negate_iife: !false_by_default,
                    passes: 1,
                    properties: !false_by_default,
                    pure_getters: !false_by_default && "strict",
                    pure_funcs: null,
                    reduce_funcs: !false_by_default,
                    reduce_vars: !false_by_default,
                    sequences: !false_by_default,
                    side_effects: !false_by_default,
                    switches: !false_by_default,
                    top_retain: null,
                    toplevel: !!(options && options["top_retain"]),
                    typeofs: !false_by_default,
                    unsafe: false,
                    unsafe_arrows: false,
                    unsafe_comps: false,
                    unsafe_Function: false,
                    unsafe_math: false,
                    unsafe_symbols: false,
                    unsafe_methods: false,
                    unsafe_proto: false,
                    unsafe_regexp: false,
                    unsafe_undefined: false,
                    unused: !false_by_default,
                    warnings: false // legacy
                }, true);
                var global_defs = this.options["global_defs"];
                if (typeof global_defs == "object")
                    for (var key in global_defs) {
                        if (key[0] === "@" && HOP(global_defs, key)) {
                            global_defs[key.slice(1)] = parse(global_defs[key], {
                                expression: true
                            });
                        }
                    }
                if (this.options["inline"] === true)
                    this.options["inline"] = 3;
                var pure_funcs = this.options["pure_funcs"];
                if (typeof pure_funcs == "function") {
                    this.pure_funcs = pure_funcs;
                }
                else {
                    this.pure_funcs = pure_funcs ? function (node) {
                        return !pure_funcs.includes(node.expression.print_to_string());
                    } : return_true;
                }
                var top_retain = this.options["top_retain"];
                if (top_retain instanceof RegExp) {
                    this.top_retain = function (def) {
                        return top_retain.test(def.name);
                    };
                }
                else if (typeof top_retain == "function") {
                    this.top_retain = top_retain;
                }
                else if (top_retain) {
                    if (typeof top_retain == "string") {
                        top_retain = top_retain.split(/,/);
                    }
                    this.top_retain = function (def) {
                        return top_retain.includes(def.name);
                    };
                }
                if (this.options["module"]) {
                    this.directives["use strict"] = true;
                    this.options["toplevel"] = true;
                }
                var toplevel = this.options["toplevel"];
                this.toplevel = typeof toplevel == "string" ? {
                    funcs: /funcs/.test(toplevel),
                    vars: /vars/.test(toplevel)
                } : {
                    funcs: toplevel,
                    vars: toplevel
                };
                var sequences = this.options["sequences"];
                this.sequences_limit = sequences == 1 ? 800 : sequences | 0;
                this.evaluated_regexps = new Map();
                this._toplevel = undefined;
                this.mangle_options = mangle_options
                    ? format_mangler_options(mangle_options)
                    : mangle_options;
            }
            option(key) {
                return this.options[key];
            }
            exposed(def) {
                if (def.export)
                    return true;
                if (def.global)
                    for (var i = 0, len = def.orig.length; i < len; i++)
                        if (!this.toplevel[def.orig[i] instanceof AST_SymbolDefun ? "funcs" : "vars"])
                            return true;
                return false;
            }
            in_boolean_context() {
                if (!this.option("booleans"))
                    return false;
                var self = this.self();
                for (var i = 0, p; p = this.parent(i); i++) {
                    if (p instanceof AST_SimpleStatement
                        || p instanceof AST_Conditional && p.condition === self
                        || p instanceof AST_DWLoop && p.condition === self
                        || p instanceof AST_For && p.condition === self
                        || p instanceof AST_If && p.condition === self
                        || p instanceof AST_UnaryPrefix && p.operator == "!" && p.expression === self) {
                        return true;
                    }
                    if (p instanceof AST_Binary
                        && (p.operator == "&&"
                            || p.operator == "||"
                            || p.operator == "??")
                        || p instanceof AST_Conditional
                        || p.tail_node() === self) {
                        self = p;
                    }
                    else {
                        return false;
                    }
                }
            }
            get_toplevel() {
                return this._toplevel;
            }
            compress(toplevel) {
                toplevel = toplevel.resolve_defines(this);
                this._toplevel = toplevel;
                if (this.option("expression")) {
                    this._toplevel.process_expression(true);
                }
                var passes = +this.options.passes || 1;
                var min_count = 1 / 0;
                var stopping = false;
                var nth_identifier = this.mangle_options && this.mangle_options.nth_identifier || base54;
                var mangle = { ie8: this.option("ie8"), nth_identifier: nth_identifier };
                for (var pass = 0; pass < passes; pass++) {
                    this._toplevel.figure_out_scope(mangle);
                    if (pass === 0 && this.option("drop_console")) {
                        // must be run before reduce_vars and compress pass
                        this._toplevel = this._toplevel.drop_console();
                    }
                    if (pass > 0 || this.option("reduce_vars")) {
                        this._toplevel.reset_opt_flags(this);
                    }
                    this._toplevel = this._toplevel.transform(this);
                    if (passes > 1) {
                        let count = 0;
                        walk(this._toplevel, () => { count++; });
                        if (count < min_count) {
                            min_count = count;
                            stopping = false;
                        }
                        else if (stopping) {
                            break;
                        }
                        else {
                            stopping = true;
                        }
                    }
                }
                if (this.option("expression")) {
                    this._toplevel.process_expression(false);
                }
                toplevel = this._toplevel;
                this._toplevel = undefined;
                return toplevel;
            }
            before(node, descend) {
                if (has_flag(node, SQUEEZED))
                    return node;
                var was_scope = false;
                if (node instanceof AST_Scope) {
                    node = node.hoist_properties(this);
                    node = node.hoist_declarations(this);
                    was_scope = true;
                }
                // Before https://github.com/mishoo/UglifyJS2/pull/1602 AST_Node.optimize()
                // would call AST_Node.transform() if a different instance of AST_Node is
                // produced after def_optimize().
                // This corrupts TreeWalker.stack, which cause AST look-ups to malfunction.
                // Migrate and defer all children's AST_Node.transform() to below, which
                // will now happen after this parent AST_Node has been properly substituted
                // thus gives a consistent AST snapshot.
                descend(node, this);
                // Existing code relies on how AST_Node.optimize() worked, and omitting the
                // following replacement call would result in degraded efficiency of both
                // output and performance.
                descend(node, this);
                var opt = node.optimize(this);
                if (was_scope && opt instanceof AST_Scope) {
                    opt.drop_unused(this);
                    descend(opt, this);
                }
                if (opt === node)
                    set_flag(opt, SQUEEZED);
                return opt;
            }
        }
        function def_optimize(node, optimizer) {
            node.DEFMETHOD("optimize", function (compressor) {
                var self = this;
                if (has_flag(self, OPTIMIZED))
                    return self;
                if (compressor.has_directive("use asm"))
                    return self;
                var opt = optimizer(self, compressor);
                set_flag(opt, OPTIMIZED);
                return opt;
            });
        }
        def_optimize(AST_Node, function (self) {
            return self;
        });
        AST_Toplevel.DEFMETHOD("drop_console", function () {
            return this.transform(new TreeTransformer(function (self) {
                if (self.TYPE == "Call") {
                    var exp = self.expression;
                    if (exp instanceof AST_PropAccess) {
                        var name = exp.expression;
                        while (name.expression) {
                            name = name.expression;
                        }
                        if (is_undeclared_ref(name) && name.name == "console") {
                            return make_node(AST_Undefined, self);
                        }
                    }
                }
            }));
        });
        AST_Node.DEFMETHOD("equivalent_to", function (node) {
            return equivalent_to(this, node);
        });
        AST_Scope.DEFMETHOD("process_expression", function (insert, compressor) {
            var self = this;
            var tt = new TreeTransformer(function (node) {
                if (insert && node instanceof AST_SimpleStatement) {
                    return make_node(AST_Return, node, {
                        value: node.body
                    });
                }
                if (!insert && node instanceof AST_Return) {
                    if (compressor) {
                        var value = node.value && node.value.drop_side_effect_free(compressor, true);
                        return value
                            ? make_node(AST_SimpleStatement, node, { body: value })
                            : make_node(AST_EmptyStatement, node);
                    }
                    return make_node(AST_SimpleStatement, node, {
                        body: node.value || make_node(AST_UnaryPrefix, node, {
                            operator: "void",
                            expression: make_node(AST_Number, node, {
                                value: 0
                            })
                        })
                    });
                }
                if (node instanceof AST_Class || node instanceof AST_Lambda && node !== self) {
                    return node;
                }
                if (node instanceof AST_Block) {
                    var index = node.body.length - 1;
                    if (index >= 0) {
                        node.body[index] = node.body[index].transform(tt);
                    }
                }
                else if (node instanceof AST_If) {
                    node.body = node.body.transform(tt);
                    if (node.alternative) {
                        node.alternative = node.alternative.transform(tt);
                    }
                }
                else if (node instanceof AST_With) {
                    node.body = node.body.transform(tt);
                }
                return node;
            });
            self.transform(tt);
        });
        AST_Toplevel.DEFMETHOD("reset_opt_flags", function (compressor) {
            const self = this;
            const reduce_vars = compressor.option("reduce_vars");
            const preparation = new TreeWalker(function (node, descend) {
                clear_flag(node, CLEAR_BETWEEN_PASSES);
                if (reduce_vars) {
                    if (compressor.top_retain
                        && node instanceof AST_Defun // Only functions are retained
                        && preparation.parent() === self) {
                        set_flag(node, TOP);
                    }
                    return node.reduce_vars(preparation, descend, compressor);
                }
            }, { walk_defun_first: true });
            // Stack of look-up tables to keep track of whether a `SymbolDef` has been
            // properly assigned before use:
            // - `push()` & `pop()` when visiting conditional branches
            preparation.safe_ids = Object.create(null);
            preparation.in_loop = null;
            preparation.loop_ids = new Map();
            preparation.defs_to_safe_ids = new Map();
            self.walk(preparation);
        });
        AST_Symbol.DEFMETHOD("fixed_value", function () {
            var fixed = this.thedef.fixed;
            if (!fixed || fixed instanceof AST_Node)
                return fixed;
            return fixed();
        });
        AST_SymbolRef.DEFMETHOD("is_immutable", function () {
            var orig = this.definition().orig;
            return orig.length == 1 && orig[0] instanceof AST_SymbolLambda;
        });
        function find_variable(compressor, name) {
            var scope, i = 0;
            while (scope = compressor.parent(i++)) {
                if (scope instanceof AST_Scope)
                    break;
                if (scope instanceof AST_Catch && scope.argname) {
                    scope = scope.argname.definition().scope;
                    break;
                }
            }
            return scope.find_variable(name);
        }
        var global_names = makePredicate("Array Boolean clearInterval clearTimeout console Date decodeURI decodeURIComponent encodeURI encodeURIComponent Error escape eval EvalError Function isFinite isNaN JSON Math Number parseFloat parseInt RangeError ReferenceError RegExp Object setInterval setTimeout String SyntaxError TypeError unescape URIError");
        AST_SymbolRef.DEFMETHOD("is_declared", function (compressor) {
            return !this.definition().undeclared
                || compressor.option("unsafe") && global_names.has(this.name);
        });
        /* -----[ optimizers ]----- */
        var directives = new Set(["use asm", "use strict"]);
        def_optimize(AST_Directive, function (self, compressor) {
            if (compressor.option("directives")
                && (!directives.has(self.value) || compressor.has_directive(self.value) !== self)) {
                return make_node(AST_EmptyStatement, self);
            }
            return self;
        });
        def_optimize(AST_Debugger, function (self, compressor) {
            if (compressor.option("drop_debugger"))
                return make_node(AST_EmptyStatement, self);
            return self;
        });
        def_optimize(AST_LabeledStatement, function (self, compressor) {
            if (self.body instanceof AST_Break
                && compressor.loopcontrol_target(self.body) === self.body) {
                return make_node(AST_EmptyStatement, self);
            }
            return self.label.references.length == 0 ? self.body : self;
        });
        def_optimize(AST_Block, function (self, compressor) {
            tighten_body(self.body, compressor);
            return self;
        });
        function can_be_extracted_from_if_block(node) {
            return !(node instanceof AST_Const
                || node instanceof AST_Let
                || node instanceof AST_Class);
        }
        def_optimize(AST_BlockStatement, function (self, compressor) {
            tighten_body(self.body, compressor);
            switch (self.body.length) {
                case 1:
                    if (!compressor.has_directive("use strict")
                        && compressor.parent() instanceof AST_If
                        && can_be_extracted_from_if_block(self.body[0])
                        || can_be_evicted_from_block(self.body[0])) {
                        return self.body[0];
                    }
                    break;
                case 0: return make_node(AST_EmptyStatement, self);
            }
            return self;
        });
        function opt_AST_Lambda(self, compressor) {
            tighten_body(self.body, compressor);
            if (compressor.option("side_effects")
                && self.body.length == 1
                && self.body[0] === compressor.has_directive("use strict")) {
                self.body.length = 0;
            }
            return self;
        }
        def_optimize(AST_Lambda, opt_AST_Lambda);
        AST_Scope.DEFMETHOD("hoist_declarations", function (compressor) {
            var self = this;
            if (compressor.has_directive("use asm"))
                return self;
            // Hoisting makes no sense in an arrow func
            if (!Array.isArray(self.body))
                return self;
            var hoist_funs = compressor.option("hoist_funs");
            var hoist_vars = compressor.option("hoist_vars");
            if (hoist_funs || hoist_vars) {
                var dirs = [];
                var hoisted = [];
                var vars = new Map(), vars_found = 0, var_decl = 0;
                // let's count var_decl first, we seem to waste a lot of
                // space if we hoist `var` when there's only one.
                walk(self, node => {
                    if (node instanceof AST_Scope && node !== self)
                        return true;
                    if (node instanceof AST_Var) {
                        ++var_decl;
                        return true;
                    }
                });
                hoist_vars = hoist_vars && var_decl > 1;
                var tt = new TreeTransformer(function before(node) {
                    if (node !== self) {
                        if (node instanceof AST_Directive) {
                            dirs.push(node);
                            return make_node(AST_EmptyStatement, node);
                        }
                        if (hoist_funs && node instanceof AST_Defun
                            && !(tt.parent() instanceof AST_Export)
                            && tt.parent() === self) {
                            hoisted.push(node);
                            return make_node(AST_EmptyStatement, node);
                        }
                        if (hoist_vars
                            && node instanceof AST_Var
                            && !node.definitions.some(def => def.name instanceof AST_Destructuring)) {
                            node.definitions.forEach(function (def) {
                                vars.set(def.name.name, def);
                                ++vars_found;
                            });
                            var seq = node.to_assignments(compressor);
                            var p = tt.parent();
                            if (p instanceof AST_ForIn && p.init === node) {
                                if (seq == null) {
                                    var def = node.definitions[0].name;
                                    return make_node(AST_SymbolRef, def, def);
                                }
                                return seq;
                            }
                            if (p instanceof AST_For && p.init === node) {
                                return seq;
                            }
                            if (!seq)
                                return make_node(AST_EmptyStatement, node);
                            return make_node(AST_SimpleStatement, node, {
                                body: seq
                            });
                        }
                        if (node instanceof AST_Scope)
                            return node; // to avoid descending in nested scopes
                    }
                });
                self = self.transform(tt);
                if (vars_found > 0) {
                    // collect only vars which don't show up in self's arguments list
                    var defs = [];
                    const is_lambda = self instanceof AST_Lambda;
                    const args_as_names = is_lambda ? self.args_as_names() : null;
                    vars.forEach((def, name) => {
                        if (is_lambda && args_as_names.some((x) => x.name === def.name.name)) {
                            vars.delete(name);
                        }
                        else {
                            def = def.clone();
                            def.value = null;
                            defs.push(def);
                            vars.set(name, def);
                        }
                    });
                    if (defs.length > 0) {
                        // try to merge in assignments
                        for (var i = 0; i < self.body.length;) {
                            if (self.body[i] instanceof AST_SimpleStatement) {
                                var expr = self.body[i].body, sym, assign;
                                if (expr instanceof AST_Assign
                                    && expr.operator == "="
                                    && (sym = expr.left) instanceof AST_Symbol
                                    && vars.has(sym.name)) {
                                    var def = vars.get(sym.name);
                                    if (def.value)
                                        break;
                                    def.value = expr.right;
                                    remove(defs, def);
                                    defs.push(def);
                                    self.body.splice(i, 1);
                                    continue;
                                }
                                if (expr instanceof AST_Sequence
                                    && (assign = expr.expressions[0]) instanceof AST_Assign
                                    && assign.operator == "="
                                    && (sym = assign.left) instanceof AST_Symbol
                                    && vars.has(sym.name)) {
                                    var def = vars.get(sym.name);
                                    if (def.value)
                                        break;
                                    def.value = assign.right;
                                    remove(defs, def);
                                    defs.push(def);
                                    self.body[i].body = make_sequence(expr, expr.expressions.slice(1));
                                    continue;
                                }
                            }
                            if (self.body[i] instanceof AST_EmptyStatement) {
                                self.body.splice(i, 1);
                                continue;
                            }
                            if (self.body[i] instanceof AST_BlockStatement) {
                                self.body.splice(i, 1, ...self.body[i].body);
                                continue;
                            }
                            break;
                        }
                        defs = make_node(AST_Var, self, {
                            definitions: defs
                        });
                        hoisted.push(defs);
                    }
                }
                self.body = dirs.concat(hoisted, self.body);
            }
            return self;
        });
        AST_Scope.DEFMETHOD("hoist_properties", function (compressor) {
            var self = this;
            if (!compressor.option("hoist_props") || compressor.has_directive("use asm"))
                return self;
            var top_retain = self instanceof AST_Toplevel && compressor.top_retain || return_false;
            var defs_by_id = new Map();
            var hoister = new TreeTransformer(function (node, descend) {
                if (node instanceof AST_VarDef) {
                    const sym = node.name;
                    let def;
                    let value;
                    if (sym.scope === self
                        && (def = sym.definition()).escaped != 1
                        && !def.assignments
                        && !def.direct_access
                        && !def.single_use
                        && !compressor.exposed(def)
                        && !top_retain(def)
                        && (value = sym.fixed_value()) === node.value
                        && value instanceof AST_Object
                        && !value.properties.some(prop => prop instanceof AST_Expansion || prop.computed_key())) {
                        descend(node, this);
                        const defs = new Map();
                        const assignments = [];
                        value.properties.forEach(({ key, value }) => {
                            const scope = hoister.find_scope();
                            const symbol = self.create_symbol(sym.CTOR, {
                                source: sym,
                                scope,
                                conflict_scopes: new Set([
                                    scope,
                                    ...sym.definition().references.map(ref => ref.scope)
                                ]),
                                tentative_name: sym.name + "_" + key
                            });
                            defs.set(String(key), symbol.definition());
                            assignments.push(make_node(AST_VarDef, node, {
                                name: symbol,
                                value
                            }));
                        });
                        defs_by_id.set(def.id, defs);
                        return MAP.splice(assignments);
                    }
                }
                else if (node instanceof AST_PropAccess
                    && node.expression instanceof AST_SymbolRef) {
                    const defs = defs_by_id.get(node.expression.definition().id);
                    if (defs) {
                        const def = defs.get(String(get_simple_key(node.property)));
                        const sym = make_node(AST_SymbolRef, node, {
                            name: def.name,
                            scope: node.expression.scope,
                            thedef: def
                        });
                        sym.reference({});
                        return sym;
                    }
                }
            });
            return self.transform(hoister);
        });
        def_optimize(AST_SimpleStatement, function (self, compressor) {
            if (compressor.option("side_effects")) {
                var body = self.body;
                var node = body.drop_side_effect_free(compressor, true);
                if (!node) {
                    return make_node(AST_EmptyStatement, self);
                }
                if (node !== body) {
                    return make_node(AST_SimpleStatement, self, { body: node });
                }
            }
            return self;
        });
        def_optimize(AST_While, function (self, compressor) {
            return compressor.option("loops") ? make_node(AST_For, self, self).optimize(compressor) : self;
        });
        def_optimize(AST_Do, function (self, compressor) {
            if (!compressor.option("loops"))
                return self;
            var cond = self.condition.tail_node().evaluate(compressor);
            if (!(cond instanceof AST_Node)) {
                if (cond)
                    return make_node(AST_For, self, {
                        body: make_node(AST_BlockStatement, self.body, {
                            body: [
                                self.body,
                                make_node(AST_SimpleStatement, self.condition, {
                                    body: self.condition
                                })
                            ]
                        })
                    }).optimize(compressor);
                if (!has_break_or_continue(self, compressor.parent())) {
                    return make_node(AST_BlockStatement, self.body, {
                        body: [
                            self.body,
                            make_node(AST_SimpleStatement, self.condition, {
                                body: self.condition
                            })
                        ]
                    }).optimize(compressor);
                }
            }
            return self;
        });
        function if_break_in_loop(self, compressor) {
            var first = self.body instanceof AST_BlockStatement ? self.body.body[0] : self.body;
            if (compressor.option("dead_code") && is_break(first)) {
                var body = [];
                if (self.init instanceof AST_Statement) {
                    body.push(self.init);
                }
                else if (self.init) {
                    body.push(make_node(AST_SimpleStatement, self.init, {
                        body: self.init
                    }));
                }
                if (self.condition) {
                    body.push(make_node(AST_SimpleStatement, self.condition, {
                        body: self.condition
                    }));
                }
                trim_unreachable_code(compressor, self.body, body);
                return make_node(AST_BlockStatement, self, {
                    body: body
                });
            }
            if (first instanceof AST_If) {
                if (is_break(first.body)) {
                    if (self.condition) {
                        self.condition = make_node(AST_Binary, self.condition, {
                            left: self.condition,
                            operator: "&&",
                            right: first.condition.negate(compressor),
                        });
                    }
                    else {
                        self.condition = first.condition.negate(compressor);
                    }
                    drop_it(first.alternative);
                }
                else if (is_break(first.alternative)) {
                    if (self.condition) {
                        self.condition = make_node(AST_Binary, self.condition, {
                            left: self.condition,
                            operator: "&&",
                            right: first.condition,
                        });
                    }
                    else {
                        self.condition = first.condition;
                    }
                    drop_it(first.body);
                }
            }
            return self;
            function is_break(node) {
                return node instanceof AST_Break
                    && compressor.loopcontrol_target(node) === compressor.self();
            }
            function drop_it(rest) {
                rest = as_statement_array(rest);
                if (self.body instanceof AST_BlockStatement) {
                    self.body = self.body.clone();
                    self.body.body = rest.concat(self.body.body.slice(1));
                    self.body = self.body.transform(compressor);
                }
                else {
                    self.body = make_node(AST_BlockStatement, self.body, {
                        body: rest
                    }).transform(compressor);
                }
                self = if_break_in_loop(self, compressor);
            }
        }
        def_optimize(AST_For, function (self, compressor) {
            if (!compressor.option("loops"))
                return self;
            if (compressor.option("side_effects") && self.init) {
                self.init = self.init.drop_side_effect_free(compressor);
            }
            if (self.condition) {
                var cond = self.condition.evaluate(compressor);
                if (!(cond instanceof AST_Node)) {
                    if (cond)
                        self.condition = null;
                    else if (!compressor.option("dead_code")) {
                        var orig = self.condition;
                        self.condition = make_node_from_constant(cond, self.condition);
                        self.condition = best_of_expression(self.condition.transform(compressor), orig);
                    }
                }
                if (compressor.option("dead_code")) {
                    if (cond instanceof AST_Node)
                        cond = self.condition.tail_node().evaluate(compressor);
                    if (!cond) {
                        var body = [];
                        trim_unreachable_code(compressor, self.body, body);
                        if (self.init instanceof AST_Statement) {
                            body.push(self.init);
                        }
                        else if (self.init) {
                            body.push(make_node(AST_SimpleStatement, self.init, {
                                body: self.init
                            }));
                        }
                        body.push(make_node(AST_SimpleStatement, self.condition, {
                            body: self.condition
                        }));
                        return make_node(AST_BlockStatement, self, { body: body }).optimize(compressor);
                    }
                }
            }
            return if_break_in_loop(self, compressor);
        });
        def_optimize(AST_If, function (self, compressor) {
            if (is_empty(self.alternative))
                self.alternative = null;
            if (!compressor.option("conditionals"))
                return self;
            // if condition can be statically determined, drop
            // one of the blocks.  note, statically determined implies
            // “has no side effects”; also it doesn't work for cases like
            // `x && true`, though it probably should.
            var cond = self.condition.evaluate(compressor);
            if (!compressor.option("dead_code") && !(cond instanceof AST_Node)) {
                var orig = self.condition;
                self.condition = make_node_from_constant(cond, orig);
                self.condition = best_of_expression(self.condition.transform(compressor), orig);
            }
            if (compressor.option("dead_code")) {
                if (cond instanceof AST_Node)
                    cond = self.condition.tail_node().evaluate(compressor);
                if (!cond) {
                    var body = [];
                    trim_unreachable_code(compressor, self.body, body);
                    body.push(make_node(AST_SimpleStatement, self.condition, {
                        body: self.condition
                    }));
                    if (self.alternative)
                        body.push(self.alternative);
                    return make_node(AST_BlockStatement, self, { body: body }).optimize(compressor);
                }
                else if (!(cond instanceof AST_Node)) {
                    var body = [];
                    body.push(make_node(AST_SimpleStatement, self.condition, {
                        body: self.condition
                    }));
                    body.push(self.body);
                    if (self.alternative) {
                        trim_unreachable_code(compressor, self.alternative, body);
                    }
                    return make_node(AST_BlockStatement, self, { body: body }).optimize(compressor);
                }
            }
            var negated = self.condition.negate(compressor);
            var self_condition_length = self.condition.size();
            var negated_length = negated.size();
            var negated_is_best = negated_length < self_condition_length;
            if (self.alternative && negated_is_best) {
                negated_is_best = false; // because we already do the switch here.
                // no need to swap values of self_condition_length and negated_length
                // here because they are only used in an equality comparison later on.
                self.condition = negated;
                var tmp = self.body;
                self.body = self.alternative || make_node(AST_EmptyStatement, self);
                self.alternative = tmp;
            }
            if (is_empty(self.body) && is_empty(self.alternative)) {
                return make_node(AST_SimpleStatement, self.condition, {
                    body: self.condition.clone()
                }).optimize(compressor);
            }
            if (self.body instanceof AST_SimpleStatement
                && self.alternative instanceof AST_SimpleStatement) {
                return make_node(AST_SimpleStatement, self, {
                    body: make_node(AST_Conditional, self, {
                        condition: self.condition,
                        consequent: self.body.body,
                        alternative: self.alternative.body
                    })
                }).optimize(compressor);
            }
            if (is_empty(self.alternative) && self.body instanceof AST_SimpleStatement) {
                if (self_condition_length === negated_length && !negated_is_best
                    && self.condition instanceof AST_Binary && self.condition.operator == "||") {
                    // although the code length of self.condition and negated are the same,
                    // negated does not require additional surrounding parentheses.
                    // see https://github.com/mishoo/UglifyJS2/issues/979
                    negated_is_best = true;
                }
                if (negated_is_best)
                    return make_node(AST_SimpleStatement, self, {
                        body: make_node(AST_Binary, self, {
                            operator: "||",
                            left: negated,
                            right: self.body.body
                        })
                    }).optimize(compressor);
                return make_node(AST_SimpleStatement, self, {
                    body: make_node(AST_Binary, self, {
                        operator: "&&",
                        left: self.condition,
                        right: self.body.body
                    })
                }).optimize(compressor);
            }
            if (self.body instanceof AST_EmptyStatement
                && self.alternative instanceof AST_SimpleStatement) {
                return make_node(AST_SimpleStatement, self, {
                    body: make_node(AST_Binary, self, {
                        operator: "||",
                        left: self.condition,
                        right: self.alternative.body
                    })
                }).optimize(compressor);
            }
            if (self.body instanceof AST_Exit
                && self.alternative instanceof AST_Exit
                && self.body.TYPE == self.alternative.TYPE) {
                return make_node(self.body.CTOR, self, {
                    value: make_node(AST_Conditional, self, {
                        condition: self.condition,
                        consequent: self.body.value || make_node(AST_Undefined, self.body),
                        alternative: self.alternative.value || make_node(AST_Undefined, self.alternative)
                    }).transform(compressor)
                }).optimize(compressor);
            }
            if (self.body instanceof AST_If
                && !self.body.alternative
                && !self.alternative) {
                self = make_node(AST_If, self, {
                    condition: make_node(AST_Binary, self.condition, {
                        operator: "&&",
                        left: self.condition,
                        right: self.body.condition
                    }),
                    body: self.body.body,
                    alternative: null
                });
            }
            if (aborts(self.body)) {
                if (self.alternative) {
                    var alt = self.alternative;
                    self.alternative = null;
                    return make_node(AST_BlockStatement, self, {
                        body: [self, alt]
                    }).optimize(compressor);
                }
            }
            if (aborts(self.alternative)) {
                var body = self.body;
                self.body = self.alternative;
                self.condition = negated_is_best ? negated : self.condition.negate(compressor);
                self.alternative = null;
                return make_node(AST_BlockStatement, self, {
                    body: [self, body]
                }).optimize(compressor);
            }
            return self;
        });
        def_optimize(AST_Switch, function (self, compressor) {
            if (!compressor.option("switches"))
                return self;
            var branch;
            var value = self.expression.evaluate(compressor);
            if (!(value instanceof AST_Node)) {
                var orig = self.expression;
                self.expression = make_node_from_constant(value, orig);
                self.expression = best_of_expression(self.expression.transform(compressor), orig);
            }
            if (!compressor.option("dead_code"))
                return self;
            if (value instanceof AST_Node) {
                value = self.expression.tail_node().evaluate(compressor);
            }
            var decl = [];
            var body = [];
            var default_branch;
            var exact_match;
            for (var i = 0, len = self.body.length; i < len && !exact_match; i++) {
                branch = self.body[i];
                if (branch instanceof AST_Default) {
                    if (!default_branch) {
                        default_branch = branch;
                    }
                    else {
                        eliminate_branch(branch, body[body.length - 1]);
                    }
                }
                else if (!(value instanceof AST_Node)) {
                    var exp = branch.expression.evaluate(compressor);
                    if (!(exp instanceof AST_Node) && exp !== value) {
                        eliminate_branch(branch, body[body.length - 1]);
                        continue;
                    }
                    if (exp instanceof AST_Node)
                        exp = branch.expression.tail_node().evaluate(compressor);
                    if (exp === value) {
                        exact_match = branch;
                        if (default_branch) {
                            var default_index = body.indexOf(default_branch);
                            body.splice(default_index, 1);
                            eliminate_branch(default_branch, body[default_index - 1]);
                            default_branch = null;
                        }
                    }
                }
                body.push(branch);
            }
            while (i < len)
                eliminate_branch(self.body[i++], body[body.length - 1]);
            self.body = body;
            let default_or_exact = default_branch || exact_match;
            default_branch = null;
            exact_match = null;
            // group equivalent branches so they will be located next to each other,
            // that way the next micro-optimization will merge them.
            // ** bail micro-optimization if not a simple switch case with breaks
            if (body.every((branch, i) => (branch === default_or_exact || branch.expression instanceof AST_Constant)
                && (branch.body.length === 0 || aborts(branch) || body.length - 1 === i))) {
                for (let i = 0; i < body.length; i++) {
                    const branch = body[i];
                    for (let j = i + 1; j < body.length; j++) {
                        const next = body[j];
                        if (next.body.length === 0)
                            continue;
                        const last_branch = j === (body.length - 1);
                        const equivalentBranch = branches_equivalent(next, branch, false);
                        if (equivalentBranch || (last_branch && branches_equivalent(next, branch, true))) {
                            if (!equivalentBranch && last_branch) {
                                next.body.push(make_node(AST_Break));
                            }
                            // let's find previous siblings with inert fallthrough...
                            let x = j - 1;
                            let fallthroughDepth = 0;
                            while (x > i) {
                                if (is_inert_body(body[x--])) {
                                    fallthroughDepth++;
                                }
                                else {
                                    break;
                                }
                            }
                            const plucked = body.splice(j - fallthroughDepth, 1 + fallthroughDepth);
                            body.splice(i + 1, 0, ...plucked);
                            i += plucked.length;
                        }
                    }
                }
            }
            // merge equivalent branches in a row
            for (let i = 0; i < body.length; i++) {
                let branch = body[i];
                if (branch.body.length === 0)
                    continue;
                if (!aborts(branch))
                    continue;
                for (let j = i + 1; j < body.length; i++, j++) {
                    let next = body[j];
                    if (next.body.length === 0)
                        continue;
                    if (branches_equivalent(next, branch, false)
                        || (j === body.length - 1 && branches_equivalent(next, branch, true))) {
                        branch.body = [];
                        branch = next;
                        continue;
                    }
                    break;
                }
            }
            // Prune any empty branches at the end of the switch statement.
            {
                let i = body.length - 1;
                for (; i >= 0; i--) {
                    let bbody = body[i].body;
                    if (is_break(bbody[bbody.length - 1], compressor))
                        bbody.pop();
                    if (!is_inert_body(body[i]))
                        break;
                }
                // i now points to the index of a branch that contains a body. By incrementing, it's
                // pointing to the first branch that's empty.
                i++;
                if (!default_or_exact || body.indexOf(default_or_exact) >= i) {
                    // The default behavior is to do nothing. We can take advantage of that to
                    // remove all case expressions that are side-effect free that also do
                    // nothing, since they'll default to doing nothing. But we can't remove any
                    // case expressions before one that would side-effect, since they may cause
                    // the side-effect to be skipped.
                    for (let j = body.length - 1; j >= i; j--) {
                        let branch = body[j];
                        if (branch === default_or_exact) {
                            default_or_exact = null;
                            body.pop();
                        }
                        else if (!branch.expression.has_side_effects(compressor)) {
                            body.pop();
                        }
                        else {
                            break;
                        }
                    }
                }
            }
            // Prune side-effect free branches that fall into default.
            DEFAULT: if (default_or_exact) {
                let default_index = body.indexOf(default_or_exact);
                let default_body_index = default_index;
                for (; default_body_index < body.length - 1; default_body_index++) {
                    if (!is_inert_body(body[default_body_index]))
                        break;
                }
                if (default_body_index < body.length - 1) {
                    break DEFAULT;
                }
                let side_effect_index = body.length - 1;
                for (; side_effect_index >= 0; side_effect_index--) {
                    let branch = body[side_effect_index];
                    if (branch === default_or_exact)
                        continue;
                    if (branch.expression.has_side_effects(compressor))
                        break;
                }
                // If the default behavior comes after any side-effect case expressions,
                // then we can fold all side-effect free cases into the default branch.
                // If the side-effect case is after the default, then any side-effect
                // free cases could prevent the side-effect from occurring.
                if (default_body_index > side_effect_index) {
                    let prev_body_index = default_index - 1;
                    for (; prev_body_index >= 0; prev_body_index--) {
                        if (!is_inert_body(body[prev_body_index]))
                            break;
                    }
                    let before = Math.max(side_effect_index, prev_body_index) + 1;
                    let after = default_index;
                    if (side_effect_index > default_index) {
                        // If the default falls into the same body as a side-effect
                        // case, then we need preserve that case and only prune the
                        // cases after it.
                        after = side_effect_index;
                        body[side_effect_index].body = body[default_body_index].body;
                    }
                    else {
                        // The default will be the last branch.
                        default_or_exact.body = body[default_body_index].body;
                    }
                    // Prune everything after the default (or last side-effect case)
                    // until the next case with a body.
                    body.splice(after + 1, default_body_index - after);
                    // Prune everything before the default that falls into it.
                    body.splice(before, default_index - before);
                }
            }
            // See if we can remove the switch entirely if all cases (the default) fall into the same case body.
            DEFAULT: if (default_or_exact) {
                let i = body.findIndex(branch => !is_inert_body(branch));
                let caseBody;
                // `i` is equal to one of the following:
                // - `-1`, there is no body in the switch statement.
                // - `body.length - 1`, all cases fall into the same body.
                // - anything else, there are multiple bodies in the switch.
                if (i === body.length - 1) {
                    // All cases fall into the case body.
                    let branch = body[i];
                    if (has_nested_break(self))
                        break DEFAULT;
                    // This is the last case body, and we've already pruned any breaks, so it's
                    // safe to hoist.
                    caseBody = make_node(AST_BlockStatement, branch, {
                        body: branch.body
                    });
                    branch.body = [];
                }
                else if (i !== -1) {
                    // If there are multiple bodies, then we cannot optimize anything.
                    break DEFAULT;
                }
                let sideEffect = body.find(branch => {
                    return (branch !== default_or_exact
                        && branch.expression.has_side_effects(compressor));
                });
                // If no cases cause a side-effect, we can eliminate the switch entirely.
                if (!sideEffect) {
                    return make_node(AST_BlockStatement, self, {
                        body: decl.concat(statement(self.expression), default_or_exact.expression ? statement(default_or_exact.expression) : [], caseBody || [])
                    }).optimize(compressor);
                }
                // If we're this far, either there was no body or all cases fell into the same body.
                // If there was no body, then we don't need a default branch (because the default is
                // do nothing). If there was a body, we'll extract it to after the switch, so the
                // switch's new default is to do nothing and we can still prune it.
                const default_index = body.indexOf(default_or_exact);
                body.splice(default_index, 1);
                default_or_exact = null;
                if (caseBody) {
                    // Recurse into switch statement one more time so that we can append the case body
                    // outside of the switch. This recursion will only happen once since we've pruned
                    // the default case.
                    return make_node(AST_BlockStatement, self, {
                        body: decl.concat(self, caseBody)
                    }).optimize(compressor);
                }
                // If we fall here, there is a default branch somewhere, there are no case bodies,
                // and there's a side-effect somewhere. Just let the below paths take care of it.
            }
            if (body.length > 0) {
                body[0].body = decl.concat(body[0].body);
            }
            if (body.length == 0) {
                return make_node(AST_BlockStatement, self, {
                    body: decl.concat(statement(self.expression))
                }).optimize(compressor);
            }
            if (body.length == 1 && !has_nested_break(self)) {
                // This is the last case body, and we've already pruned any breaks, so it's
                // safe to hoist.
                let branch = body[0];
                return make_node(AST_If, self, {
                    condition: make_node(AST_Binary, self, {
                        operator: "===",
                        left: self.expression,
                        right: branch.expression,
                    }),
                    body: make_node(AST_BlockStatement, branch, {
                        body: branch.body
                    }),
                    alternative: null
                }).optimize(compressor);
            }
            if (body.length === 2 && default_or_exact && !has_nested_break(self)) {
                let branch = body[0] === default_or_exact ? body[1] : body[0];
                let exact_exp = default_or_exact.expression && statement(default_or_exact.expression);
                if (aborts(body[0])) {
                    // Only the first branch body could have a break (at the last statement)
                    let first = body[0];
                    if (is_break(first.body[first.body.length - 1], compressor)) {
                        first.body.pop();
                    }
                    return make_node(AST_If, self, {
                        condition: make_node(AST_Binary, self, {
                            operator: "===",
                            left: self.expression,
                            right: branch.expression,
                        }),
                        body: make_node(AST_BlockStatement, branch, {
                            body: branch.body
                        }),
                        alternative: make_node(AST_BlockStatement, default_or_exact, {
                            body: [].concat(exact_exp || [], default_or_exact.body)
                        })
                    }).optimize(compressor);
                }
                let operator = "===";
                let consequent = make_node(AST_BlockStatement, branch, {
                    body: branch.body,
                });
                let always = make_node(AST_BlockStatement, default_or_exact, {
                    body: [].concat(exact_exp || [], default_or_exact.body)
                });
                if (body[0] === default_or_exact) {
                    operator = "!==";
                    let tmp = always;
                    always = consequent;
                    consequent = tmp;
                }
                return make_node(AST_BlockStatement, self, {
                    body: [
                        make_node(AST_If, self, {
                            condition: make_node(AST_Binary, self, {
                                operator: operator,
                                left: self.expression,
                                right: branch.expression,
                            }),
                            body: consequent,
                            alternative: null
                        })
                    ].concat(always)
                }).optimize(compressor);
            }
            return self;
            function eliminate_branch(branch, prev) {
                if (prev && !aborts(prev)) {
                    prev.body = prev.body.concat(branch.body);
                }
                else {
                    trim_unreachable_code(compressor, branch, decl);
                }
            }
            function branches_equivalent(branch, prev, insertBreak) {
                let bbody = branch.body;
                let pbody = prev.body;
                if (insertBreak) {
                    bbody = bbody.concat(make_node(AST_Break));
                }
                if (bbody.length !== pbody.length)
                    return false;
                let bblock = make_node(AST_BlockStatement, branch, { body: bbody });
                let pblock = make_node(AST_BlockStatement, prev, { body: pbody });
                return bblock.equivalent_to(pblock);
            }
            function statement(expression) {
                return make_node(AST_SimpleStatement, expression, {
                    body: expression
                });
            }
            function has_nested_break(root) {
                let has_break = false;
                let tw = new TreeWalker(node => {
                    if (has_break)
                        return true;
                    if (node instanceof AST_Lambda)
                        return true;
                    if (node instanceof AST_SimpleStatement)
                        return true;
                    if (!is_break(node, tw))
                        return;
                    let parent = tw.parent();
                    if (parent instanceof AST_SwitchBranch
                        && parent.body[parent.body.length - 1] === node) {
                        return;
                    }
                    has_break = true;
                });
                root.walk(tw);
                return has_break;
            }
            function is_break(node, stack) {
                return node instanceof AST_Break
                    && stack.loopcontrol_target(node) === self;
            }
            function is_inert_body(branch) {
                return !aborts(branch) && !make_node(AST_BlockStatement, branch, {
                    body: branch.body
                }).has_side_effects(compressor);
            }
        });
        def_optimize(AST_Try, function (self, compressor) {
            if (self.bcatch && self.bfinally && self.bfinally.body.every(is_empty))
                self.bfinally = null;
            if (compressor.option("dead_code") && self.body.body.every(is_empty)) {
                var body = [];
                if (self.bcatch) {
                    trim_unreachable_code(compressor, self.bcatch, body);
                }
                if (self.bfinally)
                    body.push(...self.bfinally.body);
                return make_node(AST_BlockStatement, self, {
                    body: body
                }).optimize(compressor);
            }
            return self;
        });
        AST_Definitions.DEFMETHOD("remove_initializers", function () {
            var decls = [];
            this.definitions.forEach(function (def) {
                if (def.name instanceof AST_SymbolDeclaration) {
                    def.value = null;
                    decls.push(def);
                }
                else {
                    walk(def.name, node => {
                        if (node instanceof AST_SymbolDeclaration) {
                            decls.push(make_node(AST_VarDef, def, {
                                name: node,
                                value: null
                            }));
                        }
                    });
                }
            });
            this.definitions = decls;
        });
        AST_Definitions.DEFMETHOD("to_assignments", function (compressor) {
            var reduce_vars = compressor.option("reduce_vars");
            var assignments = [];
            for (const def of this.definitions) {
                if (def.value) {
                    var name = make_node(AST_SymbolRef, def.name, def.name);
                    assignments.push(make_node(AST_Assign, def, {
                        operator: "=",
                        logical: false,
                        left: name,
                        right: def.value
                    }));
                    if (reduce_vars)
                        name.definition().fixed = false;
                }
                const thedef = def.name.definition();
                thedef.eliminated++;
                thedef.replaced--;
            }
            if (assignments.length == 0)
                return null;
            return make_sequence(this, assignments);
        });
        def_optimize(AST_Definitions, function (self) {
            if (self.definitions.length == 0) {
                return make_node(AST_EmptyStatement, self);
            }
            return self;
        });
        def_optimize(AST_VarDef, function (self, compressor) {
            if (self.name instanceof AST_SymbolLet
                && self.value != null
                && is_undefined(self.value, compressor)) {
                self.value = null;
            }
            return self;
        });
        def_optimize(AST_Import, function (self) {
            return self;
        });
        def_optimize(AST_Call, function (self, compressor) {
            var exp = self.expression;
            var fn = exp;
            inline_array_like_spread(self.args);
            var simple_args = self.args.every((arg) => !(arg instanceof AST_Expansion));
            if (compressor.option("reduce_vars")
                && fn instanceof AST_SymbolRef
                && !has_annotation(self, _NOINLINE)) {
                const fixed = fn.fixed_value();
                if (!retain_top_func(fixed, compressor)) {
                    fn = fixed;
                }
            }
            var is_func = fn instanceof AST_Lambda;
            if (is_func && fn.pinned())
                return self;
            if (compressor.option("unused")
                && simple_args
                && is_func
                && !fn.uses_arguments) {
                var pos = 0, last = 0;
                for (var i = 0, len = self.args.length; i < len; i++) {
                    if (fn.argnames[i] instanceof AST_Expansion) {
                        if (has_flag(fn.argnames[i].expression, UNUSED))
                            while (i < len) {
                                var node = self.args[i++].drop_side_effect_free(compressor);
                                if (node) {
                                    self.args[pos++] = node;
                                }
                            }
                        else
                            while (i < len) {
                                self.args[pos++] = self.args[i++];
                            }
                        last = pos;
                        break;
                    }
                    var trim = i >= fn.argnames.length;
                    if (trim || has_flag(fn.argnames[i], UNUSED)) {
                        var node = self.args[i].drop_side_effect_free(compressor);
                        if (node) {
                            self.args[pos++] = node;
                        }
                        else if (!trim) {
                            self.args[pos++] = make_node(AST_Number, self.args[i], {
                                value: 0
                            });
                            continue;
                        }
                    }
                    else {
                        self.args[pos++] = self.args[i];
                    }
                    last = pos;
                }
                self.args.length = last;
            }
            if (compressor.option("unsafe")) {
                if (exp instanceof AST_Dot && exp.start.value === "Array" && exp.property === "from" && self.args.length === 1) {
                    const [argument] = self.args;
                    if (argument instanceof AST_Array) {
                        return make_node(AST_Array, argument, {
                            elements: argument.elements
                        }).optimize(compressor);
                    }
                }
                if (is_undeclared_ref(exp))
                    switch (exp.name) {
                        case "Array":
                            if (self.args.length != 1) {
                                return make_node(AST_Array, self, {
                                    elements: self.args
                                }).optimize(compressor);
                            }
                            else if (self.args[0] instanceof AST_Number && self.args[0].value <= 11) {
                                const elements = [];
                                for (let i = 0; i < self.args[0].value; i++)
                                    elements.push(new AST_Hole);
                                return new AST_Array({ elements });
                            }
                            break;
                        case "Object":
                            if (self.args.length == 0) {
                                return make_node(AST_Object, self, {
                                    properties: []
                                });
                            }
                            break;
                        case "String":
                            if (self.args.length == 0)
                                return make_node(AST_String, self, {
                                    value: ""
                                });
                            if (self.args.length <= 1)
                                return make_node(AST_Binary, self, {
                                    left: self.args[0],
                                    operator: "+",
                                    right: make_node(AST_String, self, { value: "" })
                                }).optimize(compressor);
                            break;
                        case "Number":
                            if (self.args.length == 0)
                                return make_node(AST_Number, self, {
                                    value: 0
                                });
                            if (self.args.length == 1 && compressor.option("unsafe_math")) {
                                return make_node(AST_UnaryPrefix, self, {
                                    expression: self.args[0],
                                    operator: "+"
                                }).optimize(compressor);
                            }
                            break;
                        case "Symbol":
                            if (self.args.length == 1 && self.args[0] instanceof AST_String && compressor.option("unsafe_symbols"))
                                self.args.length = 0;
                            break;
                        case "Boolean":
                            if (self.args.length == 0)
                                return make_node(AST_False, self);
                            if (self.args.length == 1)
                                return make_node(AST_UnaryPrefix, self, {
                                    expression: make_node(AST_UnaryPrefix, self, {
                                        expression: self.args[0],
                                        operator: "!"
                                    }),
                                    operator: "!"
                                }).optimize(compressor);
                            break;
                        case "RegExp":
                            var params = [];
                            if (self.args.length >= 1
                                && self.args.length <= 2
                                && self.args.every((arg) => {
                                    var value = arg.evaluate(compressor);
                                    params.push(value);
                                    return arg !== value;
                                })
                                && regexp_is_safe(params[0])) {
                                let [source, flags] = params;
                                source = regexp_source_fix(new RegExp(source).source);
                                const rx = make_node(AST_RegExp, self, {
                                    value: { source, flags }
                                });
                                if (rx._eval(compressor) !== rx) {
                                    return rx;
                                }
                            }
                            break;
                    }
                else if (exp instanceof AST_Dot)
                    switch (exp.property) {
                        case "toString":
                            if (self.args.length == 0 && !exp.expression.may_throw_on_access(compressor)) {
                                return make_node(AST_Binary, self, {
                                    left: make_node(AST_String, self, { value: "" }),
                                    operator: "+",
                                    right: exp.expression
                                }).optimize(compressor);
                            }
                            break;
                        case "join":
                            if (exp.expression instanceof AST_Array)
                                EXIT: {
                                    var separator;
                                    if (self.args.length > 0) {
                                        separator = self.args[0].evaluate(compressor);
                                        if (separator === self.args[0])
                                            break EXIT; // not a constant
                                    }
                                    var elements = [];
                                    var consts = [];
                                    for (var i = 0, len = exp.expression.elements.length; i < len; i++) {
                                        var el = exp.expression.elements[i];
                                        if (el instanceof AST_Expansion)
                                            break EXIT;
                                        var value = el.evaluate(compressor);
                                        if (value !== el) {
                                            consts.push(value);
                                        }
                                        else {
                                            if (consts.length > 0) {
                                                elements.push(make_node(AST_String, self, {
                                                    value: consts.join(separator)
                                                }));
                                                consts.length = 0;
                                            }
                                            elements.push(el);
                                        }
                                    }
                                    if (consts.length > 0) {
                                        elements.push(make_node(AST_String, self, {
                                            value: consts.join(separator)
                                        }));
                                    }
                                    if (elements.length == 0)
                                        return make_node(AST_String, self, { value: "" });
                                    if (elements.length == 1) {
                                        if (elements[0].is_string(compressor)) {
                                            return elements[0];
                                        }
                                        return make_node(AST_Binary, elements[0], {
                                            operator: "+",
                                            left: make_node(AST_String, self, { value: "" }),
                                            right: elements[0]
                                        });
                                    }
                                    if (separator == "") {
                                        var first;
                                        if (elements[0].is_string(compressor)
                                            || elements[1].is_string(compressor)) {
                                            first = elements.shift();
                                        }
                                        else {
                                            first = make_node(AST_String, self, { value: "" });
                                        }
                                        return elements.reduce(function (prev, el) {
                                            return make_node(AST_Binary, el, {
                                                operator: "+",
                                                left: prev,
                                                right: el
                                            });
                                        }, first).optimize(compressor);
                                    }
                                    // need this awkward cloning to not affect original element
                                    // best_of will decide which one to get through.
                                    var node = self.clone();
                                    node.expression = node.expression.clone();
                                    node.expression.expression = node.expression.expression.clone();
                                    node.expression.expression.elements = elements;
                                    return best_of(compressor, self, node);
                                }
                            break;
                        case "charAt":
                            if (exp.expression.is_string(compressor)) {
                                var arg = self.args[0];
                                var index = arg ? arg.evaluate(compressor) : 0;
                                if (index !== arg) {
                                    return make_node(AST_Sub, exp, {
                                        expression: exp.expression,
                                        property: make_node_from_constant(index | 0, arg || exp)
                                    }).optimize(compressor);
                                }
                            }
                            break;
                        case "apply":
                            if (self.args.length == 2 && self.args[1] instanceof AST_Array) {
                                var args = self.args[1].elements.slice();
                                args.unshift(self.args[0]);
                                return make_node(AST_Call, self, {
                                    expression: make_node(AST_Dot, exp, {
                                        expression: exp.expression,
                                        optional: false,
                                        property: "call"
                                    }),
                                    args: args
                                }).optimize(compressor);
                            }
                            break;
                        case "call":
                            var func = exp.expression;
                            if (func instanceof AST_SymbolRef) {
                                func = func.fixed_value();
                            }
                            if (func instanceof AST_Lambda && !func.contains_this()) {
                                return (self.args.length ? make_sequence(this, [
                                    self.args[0],
                                    make_node(AST_Call, self, {
                                        expression: exp.expression,
                                        args: self.args.slice(1)
                                    })
                                ]) : make_node(AST_Call, self, {
                                    expression: exp.expression,
                                    args: []
                                })).optimize(compressor);
                            }
                            break;
                    }
            }
            if (compressor.option("unsafe_Function")
                && is_undeclared_ref(exp)
                && exp.name == "Function") {
                // new Function() => function(){}
                if (self.args.length == 0)
                    return make_node(AST_Function, self, {
                        argnames: [],
                        body: []
                    }).optimize(compressor);
                var nth_identifier = compressor.mangle_options && compressor.mangle_options.nth_identifier || base54;
                if (self.args.every((x) => x instanceof AST_String)) {
                    // quite a corner-case, but we can handle it:
                    //   https://github.com/mishoo/UglifyJS2/issues/203
                    // if the code argument is a constant, then we can minify it.
                    try {
                        var code = "n(function(" + self.args.slice(0, -1).map(function (arg) {
                            return arg.value;
                        }).join(",") + "){" + self.args[self.args.length - 1].value + "})";
                        var ast = parse(code);
                        var mangle = { ie8: compressor.option("ie8"), nth_identifier: nth_identifier };
                        ast.figure_out_scope(mangle);
                        var comp = new Compressor(compressor.options, {
                            mangle_options: compressor.mangle_options
                        });
                        ast = ast.transform(comp);
                        ast.figure_out_scope(mangle);
                        ast.compute_char_frequency(mangle);
                        ast.mangle_names(mangle);
                        var fun;
                        walk(ast, node => {
                            if (is_func_expr(node)) {
                                fun = node;
                                return walk_abort;
                            }
                        });
                        var code = OutputStream();
                        AST_BlockStatement.prototype._codegen.call(fun, fun, code);
                        self.args = [
                            make_node(AST_String, self, {
                                value: fun.argnames.map(function (arg) {
                                    return arg.print_to_string();
                                }).join(",")
                            }),
                            make_node(AST_String, self.args[self.args.length - 1], {
                                value: code.get().replace(/^{|}$/g, "")
                            })
                        ];
                        return self;
                    }
                    catch (ex) {
                        if (!(ex instanceof JS_Parse_Error)) {
                            throw ex;
                        }
                        // Otherwise, it crashes at runtime. Or maybe it's nonstandard syntax.
                    }
                }
            }
            return inline_into_call(self, fn, compressor);
        });
        def_optimize(AST_New, function (self, compressor) {
            if (compressor.option("unsafe") &&
                is_undeclared_ref(self.expression) &&
                ["Object", "RegExp", "Function", "Error", "Array"].includes(self.expression.name))
                return make_node(AST_Call, self, self).transform(compressor);
            return self;
        });
        def_optimize(AST_Sequence, function (self, compressor) {
            if (!compressor.option("side_effects"))
                return self;
            var expressions = [];
            filter_for_side_effects();
            var end = expressions.length - 1;
            trim_right_for_undefined();
            if (end == 0) {
                self = maintain_this_binding(compressor.parent(), compressor.self(), expressions[0]);
                if (!(self instanceof AST_Sequence))
                    self = self.optimize(compressor);
                return self;
            }
            self.expressions = expressions;
            return self;
            function filter_for_side_effects() {
                var first = first_in_statement(compressor);
                var last = self.expressions.length - 1;
                self.expressions.forEach(function (expr, index) {
                    if (index < last)
                        expr = expr.drop_side_effect_free(compressor, first);
                    if (expr) {
                        merge_sequence(expressions, expr);
                        first = false;
                    }
                });
            }
            function trim_right_for_undefined() {
                while (end > 0 && is_undefined(expressions[end], compressor))
                    end--;
                if (end < expressions.length - 1) {
                    expressions[end] = make_node(AST_UnaryPrefix, self, {
                        operator: "void",
                        expression: expressions[end]
                    });
                    expressions.length = end + 1;
                }
            }
        });
        AST_Unary.DEFMETHOD("lift_sequences", function (compressor) {
            if (compressor.option("sequences")) {
                if (this.expression instanceof AST_Sequence) {
                    var x = this.expression.expressions.slice();
                    var e = this.clone();
                    e.expression = x.pop();
                    x.push(e);
                    return make_sequence(this, x).optimize(compressor);
                }
            }
            return this;
        });
        def_optimize(AST_UnaryPostfix, function (self, compressor) {
            return self.lift_sequences(compressor);
        });
        def_optimize(AST_UnaryPrefix, function (self, compressor) {
            var e = self.expression;
            if (self.operator == "delete" &&
                !(e instanceof AST_SymbolRef ||
                    e instanceof AST_PropAccess ||
                    e instanceof AST_Chain ||
                    is_identifier_atom(e))) {
                return make_sequence(self, [e, make_node(AST_True, self)]).optimize(compressor);
            }
            var seq = self.lift_sequences(compressor);
            if (seq !== self) {
                return seq;
            }
            if (compressor.option("side_effects") && self.operator == "void") {
                e = e.drop_side_effect_free(compressor);
                if (e) {
                    self.expression = e;
                    return self;
                }
                else {
                    return make_node(AST_Undefined, self).optimize(compressor);
                }
            }
            if (compressor.in_boolean_context()) {
                switch (self.operator) {
                    case "!":
                        if (e instanceof AST_UnaryPrefix && e.operator == "!") {
                            // !!foo ==> foo, if we're in boolean context
                            return e.expression;
                        }
                        if (e instanceof AST_Binary) {
                            self = best_of(compressor, self, e.negate(compressor, first_in_statement(compressor)));
                        }
                        break;
                    case "typeof":
                        // typeof always returns a non-empty string, thus it's
                        // always true in booleans
                        // And we don't need to check if it's undeclared, because in typeof, that's OK
                        return (e instanceof AST_SymbolRef ? make_node(AST_True, self) : make_sequence(self, [
                            e,
                            make_node(AST_True, self)
                        ])).optimize(compressor);
                }
            }
            if (self.operator == "-" && e instanceof AST_Infinity) {
                e = e.transform(compressor);
            }
            if (e instanceof AST_Binary
                && (self.operator == "+" || self.operator == "-")
                && (e.operator == "*" || e.operator == "/" || e.operator == "%")) {
                return make_node(AST_Binary, self, {
                    operator: e.operator,
                    left: make_node(AST_UnaryPrefix, e.left, {
                        operator: self.operator,
                        expression: e.left
                    }),
                    right: e.right
                });
            }
            // avoids infinite recursion of numerals
            if (self.operator != "-"
                || !(e instanceof AST_Number || e instanceof AST_Infinity || e instanceof AST_BigInt)) {
                var ev = self.evaluate(compressor);
                if (ev !== self) {
                    ev = make_node_from_constant(ev, self).optimize(compressor);
                    return best_of(compressor, ev, self);
                }
            }
            return self;
        });
        AST_Binary.DEFMETHOD("lift_sequences", function (compressor) {
            if (compressor.option("sequences")) {
                if (this.left instanceof AST_Sequence) {
                    var x = this.left.expressions.slice();
                    var e = this.clone();
                    e.left = x.pop();
                    x.push(e);
                    return make_sequence(this, x).optimize(compressor);
                }
                if (this.right instanceof AST_Sequence && !this.left.has_side_effects(compressor)) {
                    var assign = this.operator == "=" && this.left instanceof AST_SymbolRef;
                    var x = this.right.expressions;
                    var last = x.length - 1;
                    for (var i = 0; i < last; i++) {
                        if (!assign && x[i].has_side_effects(compressor))
                            break;
                    }
                    if (i == last) {
                        x = x.slice();
                        var e = this.clone();
                        e.right = x.pop();
                        x.push(e);
                        return make_sequence(this, x).optimize(compressor);
                    }
                    else if (i > 0) {
                        var e = this.clone();
                        e.right = make_sequence(this.right, x.slice(i));
                        x = x.slice(0, i);
                        x.push(e);
                        return make_sequence(this, x).optimize(compressor);
                    }
                }
            }
            return this;
        });
        var commutativeOperators = makePredicate("== === != !== * & | ^");
        function is_object(node) {
            return node instanceof AST_Array
                || node instanceof AST_Lambda
                || node instanceof AST_Object
                || node instanceof AST_Class;
        }
        def_optimize(AST_Binary, function (self, compressor) {
            function reversible() {
                return self.left.is_constant()
                    || self.right.is_constant()
                    || !self.left.has_side_effects(compressor)
                        && !self.right.has_side_effects(compressor);
            }
            function reverse(op) {
                if (reversible()) {
                    if (op)
                        self.operator = op;
                    var tmp = self.left;
                    self.left = self.right;
                    self.right = tmp;
                }
            }
            if (commutativeOperators.has(self.operator)) {
                if (self.right.is_constant()
                    && !self.left.is_constant()) {
                    // if right is a constant, whatever side effects the
                    // left side might have could not influence the
                    // result.  hence, force switch.
                    if (!(self.left instanceof AST_Binary
                        && PRECEDENCE[self.left.operator] >= PRECEDENCE[self.operator])) {
                        reverse();
                    }
                }
            }
            self = self.lift_sequences(compressor);
            if (compressor.option("comparisons"))
                switch (self.operator) {
                    case "===":
                    case "!==":
                        var is_strict_comparison = true;
                        if ((self.left.is_string(compressor) && self.right.is_string(compressor)) ||
                            (self.left.is_number(compressor) && self.right.is_number(compressor)) ||
                            (self.left.is_boolean() && self.right.is_boolean()) ||
                            self.left.equivalent_to(self.right)) {
                            self.operator = self.operator.substr(0, 2);
                        }
                    // XXX: intentionally falling down to the next case
                    case "==":
                    case "!=":
                        // void 0 == x => null == x
                        if (!is_strict_comparison && is_undefined(self.left, compressor)) {
                            self.left = make_node(AST_Null, self.left);
                        }
                        else if (compressor.option("typeofs")
                            // "undefined" == typeof x => undefined === x
                            && self.left instanceof AST_String
                            && self.left.value == "undefined"
                            && self.right instanceof AST_UnaryPrefix
                            && self.right.operator == "typeof") {
                            var expr = self.right.expression;
                            if (expr instanceof AST_SymbolRef ? expr.is_declared(compressor)
                                : !(expr instanceof AST_PropAccess && compressor.option("ie8"))) {
                                self.right = expr;
                                self.left = make_node(AST_Undefined, self.left).optimize(compressor);
                                if (self.operator.length == 2)
                                    self.operator += "=";
                            }
                        }
                        else if (self.left instanceof AST_SymbolRef
                            // obj !== obj => false
                            && self.right instanceof AST_SymbolRef
                            && self.left.definition() === self.right.definition()
                            && is_object(self.left.fixed_value())) {
                            return make_node(self.operator[0] == "=" ? AST_True : AST_False, self);
                        }
                        break;
                    case "&&":
                    case "||":
                        var lhs = self.left;
                        if (lhs.operator == self.operator) {
                            lhs = lhs.right;
                        }
                        if (lhs instanceof AST_Binary
                            && lhs.operator == (self.operator == "&&" ? "!==" : "===")
                            && self.right instanceof AST_Binary
                            && lhs.operator == self.right.operator
                            && (is_undefined(lhs.left, compressor) && self.right.left instanceof AST_Null
                                || lhs.left instanceof AST_Null && is_undefined(self.right.left, compressor))
                            && !lhs.right.has_side_effects(compressor)
                            && lhs.right.equivalent_to(self.right.right)) {
                            var combined = make_node(AST_Binary, self, {
                                operator: lhs.operator.slice(0, -1),
                                left: make_node(AST_Null, self),
                                right: lhs.right
                            });
                            if (lhs !== self.left) {
                                combined = make_node(AST_Binary, self, {
                                    operator: self.operator,
                                    left: self.left.left,
                                    right: combined
                                });
                            }
                            return combined;
                        }
                        break;
                }
            if (self.operator == "+" && compressor.in_boolean_context()) {
                var ll = self.left.evaluate(compressor);
                var rr = self.right.evaluate(compressor);
                if (ll && typeof ll == "string") {
                    return make_sequence(self, [
                        self.right,
                        make_node(AST_True, self)
                    ]).optimize(compressor);
                }
                if (rr && typeof rr == "string") {
                    return make_sequence(self, [
                        self.left,
                        make_node(AST_True, self)
                    ]).optimize(compressor);
                }
            }
            if (compressor.option("comparisons") && self.is_boolean()) {
                if (!(compressor.parent() instanceof AST_Binary)
                    || compressor.parent() instanceof AST_Assign) {
                    var negated = make_node(AST_UnaryPrefix, self, {
                        operator: "!",
                        expression: self.negate(compressor, first_in_statement(compressor))
                    });
                    self = best_of(compressor, self, negated);
                }
                if (compressor.option("unsafe_comps")) {
                    switch (self.operator) {
                        case "<":
                            reverse(">");
                            break;
                        case "<=":
                            reverse(">=");
                            break;
                    }
                }
            }
            if (self.operator == "+") {
                if (self.right instanceof AST_String
                    && self.right.getValue() == ""
                    && self.left.is_string(compressor)) {
                    return self.left;
                }
                if (self.left instanceof AST_String
                    && self.left.getValue() == ""
                    && self.right.is_string(compressor)) {
                    return self.right;
                }
                if (self.left instanceof AST_Binary
                    && self.left.operator == "+"
                    && self.left.left instanceof AST_String
                    && self.left.left.getValue() == ""
                    && self.right.is_string(compressor)) {
                    self.left = self.left.right;
                    return self;
                }
            }
            if (compressor.option("evaluate")) {
                switch (self.operator) {
                    case "&&":
                        var ll = has_flag(self.left, TRUTHY)
                            ? true
                            : has_flag(self.left, FALSY)
                                ? false
                                : self.left.evaluate(compressor);
                        if (!ll) {
                            return maintain_this_binding(compressor.parent(), compressor.self(), self.left).optimize(compressor);
                        }
                        else if (!(ll instanceof AST_Node)) {
                            return make_sequence(self, [self.left, self.right]).optimize(compressor);
                        }
                        var rr = self.right.evaluate(compressor);
                        if (!rr) {
                            if (compressor.in_boolean_context()) {
                                return make_sequence(self, [
                                    self.left,
                                    make_node(AST_False, self)
                                ]).optimize(compressor);
                            }
                            else {
                                set_flag(self, FALSY);
                            }
                        }
                        else if (!(rr instanceof AST_Node)) {
                            var parent = compressor.parent();
                            if (parent.operator == "&&" && parent.left === compressor.self() || compressor.in_boolean_context()) {
                                return self.left.optimize(compressor);
                            }
                        }
                        // x || false && y ---> x ? y : false
                        if (self.left.operator == "||") {
                            var lr = self.left.right.evaluate(compressor);
                            if (!lr)
                                return make_node(AST_Conditional, self, {
                                    condition: self.left.left,
                                    consequent: self.right,
                                    alternative: self.left.right
                                }).optimize(compressor);
                        }
                        break;
                    case "||":
                        var ll = has_flag(self.left, TRUTHY)
                            ? true
                            : has_flag(self.left, FALSY)
                                ? false
                                : self.left.evaluate(compressor);
                        if (!ll) {
                            return make_sequence(self, [self.left, self.right]).optimize(compressor);
                        }
                        else if (!(ll instanceof AST_Node)) {
                            return maintain_this_binding(compressor.parent(), compressor.self(), self.left).optimize(compressor);
                        }
                        var rr = self.right.evaluate(compressor);
                        if (!rr) {
                            var parent = compressor.parent();
                            if (parent.operator == "||" && parent.left === compressor.self() || compressor.in_boolean_context()) {
                                return self.left.optimize(compressor);
                            }
                        }
                        else if (!(rr instanceof AST_Node)) {
                            if (compressor.in_boolean_context()) {
                                return make_sequence(self, [
                                    self.left,
                                    make_node(AST_True, self)
                                ]).optimize(compressor);
                            }
                            else {
                                set_flag(self, TRUTHY);
                            }
                        }
                        if (self.left.operator == "&&") {
                            var lr = self.left.right.evaluate(compressor);
                            if (lr && !(lr instanceof AST_Node))
                                return make_node(AST_Conditional, self, {
                                    condition: self.left.left,
                                    consequent: self.left.right,
                                    alternative: self.right
                                }).optimize(compressor);
                        }
                        break;
                    case "??":
                        if (is_nullish(self.left, compressor)) {
                            return self.right;
                        }
                        var ll = self.left.evaluate(compressor);
                        if (!(ll instanceof AST_Node)) {
                            // if we know the value for sure we can simply compute right away.
                            return ll == null ? self.right : self.left;
                        }
                        if (compressor.in_boolean_context()) {
                            const rr = self.right.evaluate(compressor);
                            if (!(rr instanceof AST_Node) && !rr) {
                                return self.left;
                            }
                        }
                }
                var associative = true;
                switch (self.operator) {
                    case "+":
                        // (x + "foo") + "bar" => x + "foobar"
                        if (self.right instanceof AST_Constant
                            && self.left instanceof AST_Binary
                            && self.left.operator == "+"
                            && self.left.is_string(compressor)) {
                            var binary = make_node(AST_Binary, self, {
                                operator: "+",
                                left: self.left.right,
                                right: self.right,
                            });
                            var r = binary.optimize(compressor);
                            if (binary !== r) {
                                self = make_node(AST_Binary, self, {
                                    operator: "+",
                                    left: self.left.left,
                                    right: r
                                });
                            }
                        }
                        // (x + "foo") + ("bar" + y) => (x + "foobar") + y
                        if (self.left instanceof AST_Binary
                            && self.left.operator == "+"
                            && self.left.is_string(compressor)
                            && self.right instanceof AST_Binary
                            && self.right.operator == "+"
                            && self.right.is_string(compressor)) {
                            var binary = make_node(AST_Binary, self, {
                                operator: "+",
                                left: self.left.right,
                                right: self.right.left,
                            });
                            var m = binary.optimize(compressor);
                            if (binary !== m) {
                                self = make_node(AST_Binary, self, {
                                    operator: "+",
                                    left: make_node(AST_Binary, self.left, {
                                        operator: "+",
                                        left: self.left.left,
                                        right: m
                                    }),
                                    right: self.right.right
                                });
                            }
                        }
                        // a + -b => a - b
                        if (self.right instanceof AST_UnaryPrefix
                            && self.right.operator == "-"
                            && self.left.is_number(compressor)) {
                            self = make_node(AST_Binary, self, {
                                operator: "-",
                                left: self.left,
                                right: self.right.expression
                            });
                            break;
                        }
                        // -a + b => b - a
                        if (self.left instanceof AST_UnaryPrefix
                            && self.left.operator == "-"
                            && reversible()
                            && self.right.is_number(compressor)) {
                            self = make_node(AST_Binary, self, {
                                operator: "-",
                                left: self.right,
                                right: self.left.expression
                            });
                            break;
                        }
                        // `foo${bar}baz` + 1 => `foo${bar}baz1`
                        if (self.left instanceof AST_TemplateString) {
                            var l = self.left;
                            var r = self.right.evaluate(compressor);
                            if (r != self.right) {
                                l.segments[l.segments.length - 1].value += String(r);
                                return l;
                            }
                        }
                        // 1 + `foo${bar}baz` => `1foo${bar}baz`
                        if (self.right instanceof AST_TemplateString) {
                            var r = self.right;
                            var l = self.left.evaluate(compressor);
                            if (l != self.left) {
                                r.segments[0].value = String(l) + r.segments[0].value;
                                return r;
                            }
                        }
                        // `1${bar}2` + `foo${bar}baz` => `1${bar}2foo${bar}baz`
                        if (self.left instanceof AST_TemplateString
                            && self.right instanceof AST_TemplateString) {
                            var l = self.left;
                            var segments = l.segments;
                            var r = self.right;
                            segments[segments.length - 1].value += r.segments[0].value;
                            for (var i = 1; i < r.segments.length; i++) {
                                segments.push(r.segments[i]);
                            }
                            return l;
                        }
                    case "*":
                        associative = compressor.option("unsafe_math");
                    case "&":
                    case "|":
                    case "^":
                        // a + +b => +b + a
                        if (self.left.is_number(compressor)
                            && self.right.is_number(compressor)
                            && reversible()
                            && !(self.left instanceof AST_Binary
                                && self.left.operator != self.operator
                                && PRECEDENCE[self.left.operator] >= PRECEDENCE[self.operator])) {
                            var reversed = make_node(AST_Binary, self, {
                                operator: self.operator,
                                left: self.right,
                                right: self.left
                            });
                            if (self.right instanceof AST_Constant
                                && !(self.left instanceof AST_Constant)) {
                                self = best_of(compressor, reversed, self);
                            }
                            else {
                                self = best_of(compressor, self, reversed);
                            }
                        }
                        if (associative && self.is_number(compressor)) {
                            // a + (b + c) => (a + b) + c
                            if (self.right instanceof AST_Binary
                                && self.right.operator == self.operator) {
                                self = make_node(AST_Binary, self, {
                                    operator: self.operator,
                                    left: make_node(AST_Binary, self.left, {
                                        operator: self.operator,
                                        left: self.left,
                                        right: self.right.left,
                                        start: self.left.start,
                                        end: self.right.left.end
                                    }),
                                    right: self.right.right
                                });
                            }
                            // (n + 2) + 3 => 5 + n
                            // (2 * n) * 3 => 6 + n
                            if (self.right instanceof AST_Constant
                                && self.left instanceof AST_Binary
                                && self.left.operator == self.operator) {
                                if (self.left.left instanceof AST_Constant) {
                                    self = make_node(AST_Binary, self, {
                                        operator: self.operator,
                                        left: make_node(AST_Binary, self.left, {
                                            operator: self.operator,
                                            left: self.left.left,
                                            right: self.right,
                                            start: self.left.left.start,
                                            end: self.right.end
                                        }),
                                        right: self.left.right
                                    });
                                }
                                else if (self.left.right instanceof AST_Constant) {
                                    self = make_node(AST_Binary, self, {
                                        operator: self.operator,
                                        left: make_node(AST_Binary, self.left, {
                                            operator: self.operator,
                                            left: self.left.right,
                                            right: self.right,
                                            start: self.left.right.start,
                                            end: self.right.end
                                        }),
                                        right: self.left.left
                                    });
                                }
                            }
                            // (a | 1) | (2 | d) => (3 | a) | b
                            if (self.left instanceof AST_Binary
                                && self.left.operator == self.operator
                                && self.left.right instanceof AST_Constant
                                && self.right instanceof AST_Binary
                                && self.right.operator == self.operator
                                && self.right.left instanceof AST_Constant) {
                                self = make_node(AST_Binary, self, {
                                    operator: self.operator,
                                    left: make_node(AST_Binary, self.left, {
                                        operator: self.operator,
                                        left: make_node(AST_Binary, self.left.left, {
                                            operator: self.operator,
                                            left: self.left.right,
                                            right: self.right.left,
                                            start: self.left.right.start,
                                            end: self.right.left.end
                                        }),
                                        right: self.left.left
                                    }),
                                    right: self.right.right
                                });
                            }
                        }
                }
            }
            // x && (y && z)  ==>  x && y && z
            // x || (y || z)  ==>  x || y || z
            // x + ("y" + z)  ==>  x + "y" + z
            // "x" + (y + "z")==>  "x" + y + "z"
            if (self.right instanceof AST_Binary
                && self.right.operator == self.operator
                && (lazy_op.has(self.operator)
                    || (self.operator == "+"
                        && (self.right.left.is_string(compressor)
                            || (self.left.is_string(compressor)
                                && self.right.right.is_string(compressor)))))) {
                self.left = make_node(AST_Binary, self.left, {
                    operator: self.operator,
                    left: self.left.transform(compressor),
                    right: self.right.left.transform(compressor)
                });
                self.right = self.right.right.transform(compressor);
                return self.transform(compressor);
            }
            var ev = self.evaluate(compressor);
            if (ev !== self) {
                ev = make_node_from_constant(ev, self).optimize(compressor);
                return best_of(compressor, ev, self);
            }
            return self;
        });
        def_optimize(AST_SymbolExport, function (self) {
            return self;
        });
        def_optimize(AST_SymbolRef, function (self, compressor) {
            if (!compressor.option("ie8")
                && is_undeclared_ref(self)
                && !compressor.find_parent(AST_With)) {
                switch (self.name) {
                    case "undefined":
                        return make_node(AST_Undefined, self).optimize(compressor);
                    case "NaN":
                        return make_node(AST_NaN, self).optimize(compressor);
                    case "Infinity":
                        return make_node(AST_Infinity, self).optimize(compressor);
                }
            }
            const parent = compressor.parent();
            if (compressor.option("reduce_vars") && is_lhs(self, parent) !== self) {
                return inline_into_symbolref(self, compressor);
            }
            else {
                return self;
            }
        });
        function is_atomic(lhs, self) {
            return lhs instanceof AST_SymbolRef || lhs.TYPE === self.TYPE;
        }
        def_optimize(AST_Undefined, function (self, compressor) {
            if (compressor.option("unsafe_undefined")) {
                var undef = find_variable(compressor, "undefined");
                if (undef) {
                    var ref = make_node(AST_SymbolRef, self, {
                        name: "undefined",
                        scope: undef.scope,
                        thedef: undef
                    });
                    set_flag(ref, UNDEFINED);
                    return ref;
                }
            }
            var lhs = is_lhs(compressor.self(), compressor.parent());
            if (lhs && is_atomic(lhs, self))
                return self;
            return make_node(AST_UnaryPrefix, self, {
                operator: "void",
                expression: make_node(AST_Number, self, {
                    value: 0
                })
            });
        });
        def_optimize(AST_Infinity, function (self, compressor) {
            var lhs = is_lhs(compressor.self(), compressor.parent());
            if (lhs && is_atomic(lhs, self))
                return self;
            if (compressor.option("keep_infinity")
                && !(lhs && !is_atomic(lhs, self))
                && !find_variable(compressor, "Infinity")) {
                return self;
            }
            return make_node(AST_Binary, self, {
                operator: "/",
                left: make_node(AST_Number, self, {
                    value: 1
                }),
                right: make_node(AST_Number, self, {
                    value: 0
                })
            });
        });
        def_optimize(AST_NaN, function (self, compressor) {
            var lhs = is_lhs(compressor.self(), compressor.parent());
            if (lhs && !is_atomic(lhs, self)
                || find_variable(compressor, "NaN")) {
                return make_node(AST_Binary, self, {
                    operator: "/",
                    left: make_node(AST_Number, self, {
                        value: 0
                    }),
                    right: make_node(AST_Number, self, {
                        value: 0
                    })
                });
            }
            return self;
        });
        const ASSIGN_OPS = makePredicate("+ - / * % >> << >>> | ^ &");
        const ASSIGN_OPS_COMMUTATIVE = makePredicate("* | ^ &");
        def_optimize(AST_Assign, function (self, compressor) {
            if (self.logical) {
                return self.lift_sequences(compressor);
            }
            var def;
            // x = x ---> x
            if (self.operator === "="
                && self.left instanceof AST_SymbolRef
                && self.left.name !== "arguments"
                && !(def = self.left.definition()).undeclared
                && self.right.equivalent_to(self.left)) {
                return self.right;
            }
            if (compressor.option("dead_code")
                && self.left instanceof AST_SymbolRef
                && (def = self.left.definition()).scope === compressor.find_parent(AST_Lambda)) {
                var level = 0, node, parent = self;
                do {
                    node = parent;
                    parent = compressor.parent(level++);
                    if (parent instanceof AST_Exit) {
                        if (in_try(level, parent))
                            break;
                        if (is_reachable(def.scope, [def]))
                            break;
                        if (self.operator == "=")
                            return self.right;
                        def.fixed = false;
                        return make_node(AST_Binary, self, {
                            operator: self.operator.slice(0, -1),
                            left: self.left,
                            right: self.right
                        }).optimize(compressor);
                    }
                } while (parent instanceof AST_Binary && parent.right === node
                    || parent instanceof AST_Sequence && parent.tail_node() === node);
            }
            self = self.lift_sequences(compressor);
            if (self.operator == "=" && self.left instanceof AST_SymbolRef && self.right instanceof AST_Binary) {
                // x = expr1 OP expr2
                if (self.right.left instanceof AST_SymbolRef
                    && self.right.left.name == self.left.name
                    && ASSIGN_OPS.has(self.right.operator)) {
                    // x = x - 2  --->  x -= 2
                    self.operator = self.right.operator + "=";
                    self.right = self.right.right;
                }
                else if (self.right.right instanceof AST_SymbolRef
                    && self.right.right.name == self.left.name
                    && ASSIGN_OPS_COMMUTATIVE.has(self.right.operator)
                    && !self.right.left.has_side_effects(compressor)) {
                    // x = 2 & x  --->  x &= 2
                    self.operator = self.right.operator + "=";
                    self.right = self.right.left;
                }
            }
            return self;
            function in_try(level, node) {
                function may_assignment_throw() {
                    const right = self.right;
                    self.right = make_node(AST_Null, right);
                    const may_throw = node.may_throw(compressor);
                    self.right = right;
                    return may_throw;
                }
                var stop_at = self.left.definition().scope.get_defun_scope();
                var parent;
                while ((parent = compressor.parent(level++)) !== stop_at) {
                    if (parent instanceof AST_Try) {
                        if (parent.bfinally)
                            return true;
                        if (parent.bcatch && may_assignment_throw())
                            return true;
                    }
                }
            }
        });
        def_optimize(AST_DefaultAssign, function (self, compressor) {
            if (!compressor.option("evaluate")) {
                return self;
            }
            var evaluateRight = self.right.evaluate(compressor);
            // `[x = undefined] = foo` ---> `[x] = foo`
            // `(arg = undefined) => ...` ---> `(arg) => ...` (unless `keep_fargs`)
            if (evaluateRight === undefined &&
                (compressor.parent() instanceof AST_Lambda
                    ? compressor.option("keep_fargs") === false
                    : true)) {
                self = self.left;
            }
            else if (evaluateRight !== self.right) {
                evaluateRight = make_node_from_constant(evaluateRight, self.right);
                self.right = best_of_expression(evaluateRight, self.right);
            }
            return self;
        });
        function is_nullish_check(check, check_subject, compressor) {
            if (check_subject.may_throw(compressor))
                return false;
            let nullish_side;
            // foo == null
            if (check instanceof AST_Binary
                && check.operator === "=="
                // which side is nullish?
                && ((nullish_side = is_nullish(check.left, compressor) && check.left)
                    || (nullish_side = is_nullish(check.right, compressor) && check.right))
                // is the other side the same as the check_subject
                && (nullish_side === check.left
                    ? check.right
                    : check.left).equivalent_to(check_subject)) {
                return true;
            }
            // foo === null || foo === undefined
            if (check instanceof AST_Binary && check.operator === "||") {
                let null_cmp;
                let undefined_cmp;
                const find_comparison = cmp => {
                    if (!(cmp instanceof AST_Binary
                        && (cmp.operator === "===" || cmp.operator === "=="))) {
                        return false;
                    }
                    let found = 0;
                    let defined_side;
                    if (cmp.left instanceof AST_Null) {
                        found++;
                        null_cmp = cmp;
                        defined_side = cmp.right;
                    }
                    if (cmp.right instanceof AST_Null) {
                        found++;
                        null_cmp = cmp;
                        defined_side = cmp.left;
                    }
                    if (is_undefined(cmp.left, compressor)) {
                        found++;
                        undefined_cmp = cmp;
                        defined_side = cmp.right;
                    }
                    if (is_undefined(cmp.right, compressor)) {
                        found++;
                        undefined_cmp = cmp;
                        defined_side = cmp.left;
                    }
                    if (found !== 1) {
                        return false;
                    }
                    if (!defined_side.equivalent_to(check_subject)) {
                        return false;
                    }
                    return true;
                };
                if (!find_comparison(check.left))
                    return false;
                if (!find_comparison(check.right))
                    return false;
                if (null_cmp && undefined_cmp && null_cmp !== undefined_cmp) {
                    return true;
                }
            }
            return false;
        }
        def_optimize(AST_Conditional, function (self, compressor) {
            if (!compressor.option("conditionals"))
                return self;
            // This looks like lift_sequences(), should probably be under "sequences"
            if (self.condition instanceof AST_Sequence) {
                var expressions = self.condition.expressions.slice();
                self.condition = expressions.pop();
                expressions.push(self);
                return make_sequence(self, expressions);
            }
            var cond = self.condition.evaluate(compressor);
            if (cond !== self.condition) {
                if (cond) {
                    return maintain_this_binding(compressor.parent(), compressor.self(), self.consequent);
                }
                else {
                    return maintain_this_binding(compressor.parent(), compressor.self(), self.alternative);
                }
            }
            var negated = cond.negate(compressor, first_in_statement(compressor));
            if (best_of(compressor, cond, negated) === negated) {
                self = make_node(AST_Conditional, self, {
                    condition: negated,
                    consequent: self.alternative,
                    alternative: self.consequent
                });
            }
            var condition = self.condition;
            var consequent = self.consequent;
            var alternative = self.alternative;
            // x?x:y --> x||y
            if (condition instanceof AST_SymbolRef
                && consequent instanceof AST_SymbolRef
                && condition.definition() === consequent.definition()) {
                return make_node(AST_Binary, self, {
                    operator: "||",
                    left: condition,
                    right: alternative
                });
            }
            // if (foo) exp = something; else exp = something_else;
            //                   |
            //                   v
            // exp = foo ? something : something_else;
            if (consequent instanceof AST_Assign
                && alternative instanceof AST_Assign
                && consequent.operator === alternative.operator
                && consequent.logical === alternative.logical
                && consequent.left.equivalent_to(alternative.left)
                && (!self.condition.has_side_effects(compressor)
                    || consequent.operator == "="
                        && !consequent.left.has_side_effects(compressor))) {
                return make_node(AST_Assign, self, {
                    operator: consequent.operator,
                    left: consequent.left,
                    logical: consequent.logical,
                    right: make_node(AST_Conditional, self, {
                        condition: self.condition,
                        consequent: consequent.right,
                        alternative: alternative.right
                    })
                });
            }
            // x ? y(a) : y(b) --> y(x ? a : b)
            var arg_index;
            if (consequent instanceof AST_Call
                && alternative.TYPE === consequent.TYPE
                && consequent.args.length > 0
                && consequent.args.length == alternative.args.length
                && consequent.expression.equivalent_to(alternative.expression)
                && !self.condition.has_side_effects(compressor)
                && !consequent.expression.has_side_effects(compressor)
                && typeof (arg_index = single_arg_diff()) == "number") {
                var node = consequent.clone();
                node.args[arg_index] = make_node(AST_Conditional, self, {
                    condition: self.condition,
                    consequent: consequent.args[arg_index],
                    alternative: alternative.args[arg_index]
                });
                return node;
            }
            // a ? b : c ? b : d --> (a || c) ? b : d
            if (alternative instanceof AST_Conditional
                && consequent.equivalent_to(alternative.consequent)) {
                return make_node(AST_Conditional, self, {
                    condition: make_node(AST_Binary, self, {
                        operator: "||",
                        left: condition,
                        right: alternative.condition
                    }),
                    consequent: consequent,
                    alternative: alternative.alternative
                }).optimize(compressor);
            }
            // a == null ? b : a -> a ?? b
            if (compressor.option("ecma") >= 2020 &&
                is_nullish_check(condition, alternative, compressor)) {
                return make_node(AST_Binary, self, {
                    operator: "??",
                    left: alternative,
                    right: consequent
                }).optimize(compressor);
            }
            // a ? b : (c, b) --> (a || c), b
            if (alternative instanceof AST_Sequence
                && consequent.equivalent_to(alternative.expressions[alternative.expressions.length - 1])) {
                return make_sequence(self, [
                    make_node(AST_Binary, self, {
                        operator: "||",
                        left: condition,
                        right: make_sequence(self, alternative.expressions.slice(0, -1))
                    }),
                    consequent
                ]).optimize(compressor);
            }
            // a ? b : (c && b) --> (a || c) && b
            if (alternative instanceof AST_Binary
                && alternative.operator == "&&"
                && consequent.equivalent_to(alternative.right)) {
                return make_node(AST_Binary, self, {
                    operator: "&&",
                    left: make_node(AST_Binary, self, {
                        operator: "||",
                        left: condition,
                        right: alternative.left
                    }),
                    right: consequent
                }).optimize(compressor);
            }
            // x?y?z:a:a --> x&&y?z:a
            if (consequent instanceof AST_Conditional
                && consequent.alternative.equivalent_to(alternative)) {
                return make_node(AST_Conditional, self, {
                    condition: make_node(AST_Binary, self, {
                        left: self.condition,
                        operator: "&&",
                        right: consequent.condition
                    }),
                    consequent: consequent.consequent,
                    alternative: alternative
                });
            }
            // x ? y : y --> x, y
            if (consequent.equivalent_to(alternative)) {
                return make_sequence(self, [
                    self.condition,
                    consequent
                ]).optimize(compressor);
            }
            // x ? y || z : z --> x && y || z
            if (consequent instanceof AST_Binary
                && consequent.operator == "||"
                && consequent.right.equivalent_to(alternative)) {
                return make_node(AST_Binary, self, {
                    operator: "||",
                    left: make_node(AST_Binary, self, {
                        operator: "&&",
                        left: self.condition,
                        right: consequent.left
                    }),
                    right: alternative
                }).optimize(compressor);
            }
            const in_bool = compressor.in_boolean_context();
            if (is_true(self.consequent)) {
                if (is_false(self.alternative)) {
                    // c ? true : false ---> !!c
                    return booleanize(self.condition);
                }
                // c ? true : x ---> !!c || x
                return make_node(AST_Binary, self, {
                    operator: "||",
                    left: booleanize(self.condition),
                    right: self.alternative
                });
            }
            if (is_false(self.consequent)) {
                if (is_true(self.alternative)) {
                    // c ? false : true ---> !c
                    return booleanize(self.condition.negate(compressor));
                }
                // c ? false : x ---> !c && x
                return make_node(AST_Binary, self, {
                    operator: "&&",
                    left: booleanize(self.condition.negate(compressor)),
                    right: self.alternative
                });
            }
            if (is_true(self.alternative)) {
                // c ? x : true ---> !c || x
                return make_node(AST_Binary, self, {
                    operator: "||",
                    left: booleanize(self.condition.negate(compressor)),
                    right: self.consequent
                });
            }
            if (is_false(self.alternative)) {
                // c ? x : false ---> !!c && x
                return make_node(AST_Binary, self, {
                    operator: "&&",
                    left: booleanize(self.condition),
                    right: self.consequent
                });
            }
            return self;
            function booleanize(node) {
                if (node.is_boolean())
                    return node;
                // !!expression
                return make_node(AST_UnaryPrefix, node, {
                    operator: "!",
                    expression: node.negate(compressor)
                });
            }
            // AST_True or !0
            function is_true(node) {
                return node instanceof AST_True
                    || in_bool
                        && node instanceof AST_Constant
                        && node.getValue()
                    || (node instanceof AST_UnaryPrefix
                        && node.operator == "!"
                        && node.expression instanceof AST_Constant
                        && !node.expression.getValue());
            }
            // AST_False or !1
            function is_false(node) {
                return node instanceof AST_False
                    || in_bool
                        && node instanceof AST_Constant
                        && !node.getValue()
                    || (node instanceof AST_UnaryPrefix
                        && node.operator == "!"
                        && node.expression instanceof AST_Constant
                        && node.expression.getValue());
            }
            function single_arg_diff() {
                var a = consequent.args;
                var b = alternative.args;
                for (var i = 0, len = a.length; i < len; i++) {
                    if (a[i] instanceof AST_Expansion)
                        return;
                    if (!a[i].equivalent_to(b[i])) {
                        if (b[i] instanceof AST_Expansion)
                            return;
                        for (var j = i + 1; j < len; j++) {
                            if (a[j] instanceof AST_Expansion)
                                return;
                            if (!a[j].equivalent_to(b[j]))
                                return;
                        }
                        return i;
                    }
                }
            }
        });
        def_optimize(AST_Boolean, function (self, compressor) {
            if (compressor.in_boolean_context())
                return make_node(AST_Number, self, {
                    value: +self.value
                });
            var p = compressor.parent();
            if (compressor.option("booleans_as_integers")) {
                if (p instanceof AST_Binary && (p.operator == "===" || p.operator == "!==")) {
                    p.operator = p.operator.replace(/=$/, "");
                }
                return make_node(AST_Number, self, {
                    value: +self.value
                });
            }
            if (compressor.option("booleans")) {
                if (p instanceof AST_Binary && (p.operator == "=="
                    || p.operator == "!=")) {
                    return make_node(AST_Number, self, {
                        value: +self.value
                    });
                }
                return make_node(AST_UnaryPrefix, self, {
                    operator: "!",
                    expression: make_node(AST_Number, self, {
                        value: 1 - self.value
                    })
                });
            }
            return self;
        });
        function safe_to_flatten(value, compressor) {
            if (value instanceof AST_SymbolRef) {
                value = value.fixed_value();
            }
            if (!value)
                return false;
            if (!(value instanceof AST_Lambda || value instanceof AST_Class))
                return true;
            if (!(value instanceof AST_Lambda && value.contains_this()))
                return true;
            return compressor.parent() instanceof AST_New;
        }
        AST_PropAccess.DEFMETHOD("flatten_object", function (key, compressor) {
            if (!compressor.option("properties"))
                return;
            if (key === "__proto__")
                return;
            var arrows = compressor.option("unsafe_arrows") && compressor.option("ecma") >= 2015;
            var expr = this.expression;
            if (expr instanceof AST_Object) {
                var props = expr.properties;
                for (var i = props.length; --i >= 0;) {
                    var prop = props[i];
                    if ("" + (prop instanceof AST_ConciseMethod ? prop.key.name : prop.key) == key) {
                        const all_props_flattenable = props.every((p) => (p instanceof AST_ObjectKeyVal
                            || arrows && p instanceof AST_ConciseMethod && !p.is_generator)
                            && !p.computed_key());
                        if (!all_props_flattenable)
                            return;
                        if (!safe_to_flatten(prop.value, compressor))
                            return;
                        return make_node(AST_Sub, this, {
                            expression: make_node(AST_Array, expr, {
                                elements: props.map(function (prop) {
                                    var v = prop.value;
                                    if (v instanceof AST_Accessor) {
                                        v = make_node(AST_Function, v, v);
                                    }
                                    var k = prop.key;
                                    if (k instanceof AST_Node && !(k instanceof AST_SymbolMethod)) {
                                        return make_sequence(prop, [k, v]);
                                    }
                                    return v;
                                })
                            }),
                            property: make_node(AST_Number, this, {
                                value: i
                            })
                        });
                    }
                }
            }
        });
        def_optimize(AST_Sub, function (self, compressor) {
            var expr = self.expression;
            var prop = self.property;
            if (compressor.option("properties")) {
                var key = prop.evaluate(compressor);
                if (key !== prop) {
                    if (typeof key == "string") {
                        if (key == "undefined") {
                            key = undefined;
                        }
                        else {
                            var value = parseFloat(key);
                            if (value.toString() == key) {
                                key = value;
                            }
                        }
                    }
                    prop = self.property = best_of_expression(prop, make_node_from_constant(key, prop).transform(compressor));
                    var property = "" + key;
                    if (is_basic_identifier_string(property)
                        && property.length <= prop.size() + 1) {
                        return make_node(AST_Dot, self, {
                            expression: expr,
                            optional: self.optional,
                            property: property,
                            quote: prop.quote,
                        }).optimize(compressor);
                    }
                }
            }
            var fn;
            OPT_ARGUMENTS: if (compressor.option("arguments")
                && expr instanceof AST_SymbolRef
                && expr.name == "arguments"
                && expr.definition().orig.length == 1
                && (fn = expr.scope) instanceof AST_Lambda
                && fn.uses_arguments
                && !(fn instanceof AST_Arrow)
                && prop instanceof AST_Number) {
                var index = prop.getValue();
                var params = new Set();
                var argnames = fn.argnames;
                for (var n = 0; n < argnames.length; n++) {
                    if (!(argnames[n] instanceof AST_SymbolFunarg)) {
                        break OPT_ARGUMENTS; // destructuring parameter - bail
                    }
                    var param = argnames[n].name;
                    if (params.has(param)) {
                        break OPT_ARGUMENTS; // duplicate parameter - bail
                    }
                    params.add(param);
                }
                var argname = fn.argnames[index];
                if (argname && compressor.has_directive("use strict")) {
                    var def = argname.definition();
                    if (!compressor.option("reduce_vars") || def.assignments || def.orig.length > 1) {
                        argname = null;
                    }
                }
                else if (!argname && !compressor.option("keep_fargs") && index < fn.argnames.length + 5) {
                    while (index >= fn.argnames.length) {
                        argname = fn.create_symbol(AST_SymbolFunarg, {
                            source: fn,
                            scope: fn,
                            tentative_name: "argument_" + fn.argnames.length,
                        });
                        fn.argnames.push(argname);
                    }
                }
                if (argname) {
                    var sym = make_node(AST_SymbolRef, self, argname);
                    sym.reference({});
                    clear_flag(argname, UNUSED);
                    return sym;
                }
            }
            if (is_lhs(self, compressor.parent()))
                return self;
            if (key !== prop) {
                var sub = self.flatten_object(property, compressor);
                if (sub) {
                    expr = self.expression = sub.expression;
                    prop = self.property = sub.property;
                }
            }
            if (compressor.option("properties") && compressor.option("side_effects")
                && prop instanceof AST_Number && expr instanceof AST_Array) {
                var index = prop.getValue();
                var elements = expr.elements;
                var retValue = elements[index];
                FLATTEN: if (safe_to_flatten(retValue, compressor)) {
                    var flatten = true;
                    var values = [];
                    for (var i = elements.length; --i > index;) {
                        var value = elements[i].drop_side_effect_free(compressor);
                        if (value) {
                            values.unshift(value);
                            if (flatten && value.has_side_effects(compressor))
                                flatten = false;
                        }
                    }
                    if (retValue instanceof AST_Expansion)
                        break FLATTEN;
                    retValue = retValue instanceof AST_Hole ? make_node(AST_Undefined, retValue) : retValue;
                    if (!flatten)
                        values.unshift(retValue);
                    while (--i >= 0) {
                        var value = elements[i];
                        if (value instanceof AST_Expansion)
                            break FLATTEN;
                        value = value.drop_side_effect_free(compressor);
                        if (value)
                            values.unshift(value);
                        else
                            index--;
                    }
                    if (flatten) {
                        values.push(retValue);
                        return make_sequence(self, values).optimize(compressor);
                    }
                    else
                        return make_node(AST_Sub, self, {
                            expression: make_node(AST_Array, expr, {
                                elements: values
                            }),
                            property: make_node(AST_Number, prop, {
                                value: index
                            })
                        });
                }
            }
            var ev = self.evaluate(compressor);
            if (ev !== self) {
                ev = make_node_from_constant(ev, self).optimize(compressor);
                return best_of(compressor, ev, self);
            }
            return self;
        });
        def_optimize(AST_Chain, function (self, compressor) {
            if (is_nullish(self.expression, compressor)) {
                let parent = compressor.parent();
                // It's valid to delete a nullish optional chain, but if we optimized
                // this to `delete undefined` then it would appear to be a syntax error
                // when we try to optimize the delete. Thankfully, `delete 0` is fine.
                if (parent instanceof AST_UnaryPrefix && parent.operator === "delete") {
                    return make_node_from_constant(0, self);
                }
                return make_node(AST_Undefined, self);
            }
            return self;
        });
        AST_Lambda.DEFMETHOD("contains_this", function () {
            return walk(this, node => {
                if (node instanceof AST_This)
                    return walk_abort;
                if (node !== this
                    && node instanceof AST_Scope
                    && !(node instanceof AST_Arrow)) {
                    return true;
                }
            });
        });
        def_optimize(AST_Dot, function (self, compressor) {
            const parent = compressor.parent();
            if (is_lhs(self, parent))
                return self;
            if (compressor.option("unsafe_proto")
                && self.expression instanceof AST_Dot
                && self.expression.property == "prototype") {
                var exp = self.expression.expression;
                if (is_undeclared_ref(exp))
                    switch (exp.name) {
                        case "Array":
                            self.expression = make_node(AST_Array, self.expression, {
                                elements: []
                            });
                            break;
                        case "Function":
                            self.expression = make_node(AST_Function, self.expression, {
                                argnames: [],
                                body: []
                            });
                            break;
                        case "Number":
                            self.expression = make_node(AST_Number, self.expression, {
                                value: 0
                            });
                            break;
                        case "Object":
                            self.expression = make_node(AST_Object, self.expression, {
                                properties: []
                            });
                            break;
                        case "RegExp":
                            self.expression = make_node(AST_RegExp, self.expression, {
                                value: { source: "t", flags: "" }
                            });
                            break;
                        case "String":
                            self.expression = make_node(AST_String, self.expression, {
                                value: ""
                            });
                            break;
                    }
            }
            if (!(parent instanceof AST_Call) || !has_annotation(parent, _NOINLINE)) {
                const sub = self.flatten_object(self.property, compressor);
                if (sub)
                    return sub.optimize(compressor);
            }
            if (self.expression instanceof AST_PropAccess
                && parent instanceof AST_PropAccess) {
                return self;
            }
            let ev = self.evaluate(compressor);
            if (ev !== self) {
                ev = make_node_from_constant(ev, self).optimize(compressor);
                return best_of(compressor, ev, self);
            }
            return self;
        });
        function literals_in_boolean_context(self, compressor) {
            if (compressor.in_boolean_context()) {
                return best_of(compressor, self, make_sequence(self, [
                    self,
                    make_node(AST_True, self)
                ]).optimize(compressor));
            }
            return self;
        }
        function inline_array_like_spread(elements) {
            for (var i = 0; i < elements.length; i++) {
                var el = elements[i];
                if (el instanceof AST_Expansion) {
                    var expr = el.expression;
                    if (expr instanceof AST_Array
                        && !expr.elements.some(elm => elm instanceof AST_Hole)) {
                        elements.splice(i, 1, ...expr.elements);
                        // Step back one, as the element at i is now new.
                        i--;
                    }
                    // In array-like spread, spreading a non-iterable value is TypeError.
                    // We therefore can’t optimize anything else, unlike with object spread.
                }
            }
        }
        def_optimize(AST_Array, function (self, compressor) {
            var optimized = literals_in_boolean_context(self, compressor);
            if (optimized !== self) {
                return optimized;
            }
            inline_array_like_spread(self.elements);
            return self;
        });
        function inline_object_prop_spread(props, compressor) {
            for (var i = 0; i < props.length; i++) {
                var prop = props[i];
                if (prop instanceof AST_Expansion) {
                    const expr = prop.expression;
                    if (expr instanceof AST_Object
                        && expr.properties.every(prop => prop instanceof AST_ObjectKeyVal)) {
                        props.splice(i, 1, ...expr.properties);
                        // Step back one, as the property at i is now new.
                        i--;
                    }
                    else if (expr instanceof AST_Constant
                        && !(expr instanceof AST_String)) {
                        // Unlike array-like spread, in object spread, spreading a
                        // non-iterable value silently does nothing; it is thus safe
                        // to remove. AST_String is the only iterable AST_Constant.
                        props.splice(i, 1);
                        i--;
                    }
                    else if (is_nullish(expr, compressor)) {
                        // Likewise, null and undefined can be silently removed.
                        props.splice(i, 1);
                        i--;
                    }
                }
            }
        }
        def_optimize(AST_Object, function (self, compressor) {
            var optimized = literals_in_boolean_context(self, compressor);
            if (optimized !== self) {
                return optimized;
            }
            inline_object_prop_spread(self.properties, compressor);
            return self;
        });
        def_optimize(AST_RegExp, literals_in_boolean_context);
        def_optimize(AST_Return, function (self, compressor) {
            if (self.value && is_undefined(self.value, compressor)) {
                self.value = null;
            }
            return self;
        });
        def_optimize(AST_Arrow, opt_AST_Lambda);
        def_optimize(AST_Function, function (self, compressor) {
            self = opt_AST_Lambda(self, compressor);
            if (compressor.option("unsafe_arrows")
                && compressor.option("ecma") >= 2015
                && !self.name
                && !self.is_generator
                && !self.uses_arguments
                && !self.pinned()) {
                const uses_this = walk(self, node => {
                    if (node instanceof AST_This)
                        return walk_abort;
                });
                if (!uses_this)
                    return make_node(AST_Arrow, self, self).optimize(compressor);
            }
            return self;
        });
        def_optimize(AST_Class, function (self) {
            // HACK to avoid compress failure.
            // AST_Class is not really an AST_Scope/AST_Block as it lacks a body.
            return self;
        });
        def_optimize(AST_ClassStaticBlock, function (self, compressor) {
            tighten_body(self.body, compressor);
            return self;
        });
        def_optimize(AST_Yield, function (self, compressor) {
            if (self.expression && !self.is_star && is_undefined(self.expression, compressor)) {
                self.expression = null;
            }
            return self;
        });
        def_optimize(AST_TemplateString, function (self, compressor) {
            if (!compressor.option("evaluate")
                || compressor.parent() instanceof AST_PrefixedTemplateString) {
                return self;
            }
            var segments = [];
            for (var i = 0; i < self.segments.length; i++) {
                var segment = self.segments[i];
                if (segment instanceof AST_Node) {
                    var result = segment.evaluate(compressor);
                    // Evaluate to constant value
                    // Constant value shorter than ${segment}
                    if (result !== segment && (result + "").length <= segment.size() + "${}".length) {
                        // There should always be a previous and next segment if segment is a node
                        segments[segments.length - 1].value = segments[segments.length - 1].value + result + self.segments[++i].value;
                        continue;
                    }
                    // `before ${`innerBefore ${any} innerAfter`} after` => `before innerBefore ${any} innerAfter after`
                    // TODO:
                    // `before ${'test' + foo} after` => `before innerBefore ${any} innerAfter after`
                    // `before ${foo + 'test} after` => `before innerBefore ${any} innerAfter after`
                    if (segment instanceof AST_TemplateString) {
                        var inners = segment.segments;
                        segments[segments.length - 1].value += inners[0].value;
                        for (var j = 1; j < inners.length; j++) {
                            segment = inners[j];
                            segments.push(segment);
                        }
                        continue;
                    }
                }
                segments.push(segment);
            }
            self.segments = segments;
            // `foo` => "foo"
            if (segments.length == 1) {
                return make_node(AST_String, self, segments[0]);
            }
            if (segments.length === 3
                && segments[1] instanceof AST_Node
                && (segments[1].is_string(compressor)
                    || segments[1].is_number(compressor)
                    || is_nullish(segments[1], compressor)
                    || compressor.option("unsafe"))) {
                // `foo${bar}` => "foo" + bar
                if (segments[2].value === "") {
                    return make_node(AST_Binary, self, {
                        operator: "+",
                        left: make_node(AST_String, self, {
                            value: segments[0].value,
                        }),
                        right: segments[1],
                    });
                }
                // `${bar}baz` => bar + "baz"
                if (segments[0].value === "") {
                    return make_node(AST_Binary, self, {
                        operator: "+",
                        left: segments[1],
                        right: make_node(AST_String, self, {
                            value: segments[2].value,
                        }),
                    });
                }
            }
            return self;
        });
        def_optimize(AST_PrefixedTemplateString, function (self) {
            return self;
        });
        // ["p"]:1 ---> p:1
        // [42]:1 ---> 42:1
        function lift_key(self, compressor) {
            if (!compressor.option("computed_props"))
                return self;
            // save a comparison in the typical case
            if (!(self.key instanceof AST_Constant))
                return self;
            // allow certain acceptable props as not all AST_Constants are true constants
            if (self.key instanceof AST_String || self.key instanceof AST_Number) {
                if (self.key.value === "__proto__")
                    return self;
                if (self.key.value == "constructor"
                    && compressor.parent() instanceof AST_Class)
                    return self;
                if (self instanceof AST_ObjectKeyVal) {
                    self.quote = self.key.quote;
                    self.key = self.key.value;
                }
                else if (self instanceof AST_ClassProperty) {
                    self.quote = self.key.quote;
                    self.key = make_node(AST_SymbolClassProperty, self.key, {
                        name: self.key.value
                    });
                }
                else {
                    self.quote = self.key.quote;
                    self.key = make_node(AST_SymbolMethod, self.key, {
                        name: self.key.value
                    });
                }
            }
            return self;
        }
        def_optimize(AST_ObjectProperty, lift_key);
        def_optimize(AST_ConciseMethod, function (self, compressor) {
            lift_key(self, compressor);
            // p(){return x;} ---> p:()=>x
            if (compressor.option("arrows")
                && compressor.parent() instanceof AST_Object
                && !self.is_generator
                && !self.value.uses_arguments
                && !self.value.pinned()
                && self.value.body.length == 1
                && self.value.body[0] instanceof AST_Return
                && self.value.body[0].value
                && !self.value.contains_this()) {
                var arrow = make_node(AST_Arrow, self.value, self.value);
                arrow.async = self.async;
                arrow.is_generator = self.is_generator;
                return make_node(AST_ObjectKeyVal, self, {
                    key: self.key instanceof AST_SymbolMethod ? self.key.name : self.key,
                    value: arrow,
                    quote: self.quote,
                });
            }
            return self;
        });
        def_optimize(AST_ObjectKeyVal, function (self, compressor) {
            lift_key(self, compressor);
            // p:function(){} ---> p(){}
            // p:function*(){} ---> *p(){}
            // p:async function(){} ---> async p(){}
            // p:()=>{} ---> p(){}
            // p:async()=>{} ---> async p(){}
            var unsafe_methods = compressor.option("unsafe_methods");
            if (unsafe_methods
                && compressor.option("ecma") >= 2015
                && (!(unsafe_methods instanceof RegExp) || unsafe_methods.test(self.key + ""))) {
                var key = self.key;
                var value = self.value;
                var is_arrow_with_block = value instanceof AST_Arrow
                    && Array.isArray(value.body)
                    && !value.contains_this();
                if ((is_arrow_with_block || value instanceof AST_Function) && !value.name) {
                    return make_node(AST_ConciseMethod, self, {
                        async: value.async,
                        is_generator: value.is_generator,
                        key: key instanceof AST_Node ? key : make_node(AST_SymbolMethod, self, {
                            name: key,
                        }),
                        value: make_node(AST_Accessor, value, value),
                        quote: self.quote,
                    });
                }
            }
            return self;
        });
        def_optimize(AST_Destructuring, function (self, compressor) {
            if (compressor.option("pure_getters") == true
                && compressor.option("unused")
                && !self.is_array
                && Array.isArray(self.names)
                && !is_destructuring_export_decl(compressor)
                && !(self.names[self.names.length - 1] instanceof AST_Expansion)) {
                var keep = [];
                for (var i = 0; i < self.names.length; i++) {
                    var elem = self.names[i];
                    if (!(elem instanceof AST_ObjectKeyVal
                        && typeof elem.key == "string"
                        && elem.value instanceof AST_SymbolDeclaration
                        && !should_retain(compressor, elem.value.definition()))) {
                        keep.push(elem);
                    }
                }
                if (keep.length != self.names.length) {
                    self.names = keep;
                }
            }
            return self;
            function is_destructuring_export_decl(compressor) {
                var ancestors = [/^VarDef$/, /^(Const|Let|Var)$/, /^Export$/];
                for (var a = 0, p = 0, len = ancestors.length; a < len; p++) {
                    var parent = compressor.parent(p);
                    if (!parent)
                        return false;
                    if (a === 0 && parent.TYPE == "Destructuring")
                        continue;
                    if (!ancestors[a].test(parent.TYPE)) {
                        return false;
                    }
                    a++;
                }
                return true;
            }
            function should_retain(compressor, def) {
                if (def.references.length)
                    return true;
                if (!def.global)
                    return false;
                if (compressor.toplevel.vars) {
                    if (compressor.top_retain) {
                        return compressor.top_retain(def);
                    }
                    return false;
                }
                return true;
            }
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // a small wrapper around source-map and @jridgewell/source-map
        async function SourceMap(options) {
            options = defaults(options, {
                file: null,
                root: null,
                orig: null,
                files: {},
            });
            var orig_map;
            var generator = new sourceMap.SourceMapGenerator({
                file: options.file,
                sourceRoot: options.root
            });
            let sourcesContent = { __proto__: null };
            let files = options.files;
            for (var name in files)
                if (HOP(files, name)) {
                    sourcesContent[name] = files[name];
                }
            if (options.orig) {
                // We support both @jridgewell/source-map (which has a sync
                // SourceMapConsumer) and source-map (which has an async
                // SourceMapConsumer).
                orig_map = await new sourceMap.SourceMapConsumer(options.orig);
                if (orig_map.sourcesContent) {
                    orig_map.sources.forEach(function (source, i) {
                        var content = orig_map.sourcesContent[i];
                        if (content) {
                            sourcesContent[source] = content;
                        }
                    });
                }
            }
            function add(source, gen_line, gen_col, orig_line, orig_col, name) {
                let generatedPos = { line: gen_line, column: gen_col };
                if (orig_map) {
                    var info = orig_map.originalPositionFor({
                        line: orig_line,
                        column: orig_col
                    });
                    if (info.source === null) {
                        generator.addMapping({
                            generated: generatedPos,
                            original: null,
                            source: null,
                            name: null
                        });
                        return;
                    }
                    source = info.source;
                    orig_line = info.line;
                    orig_col = info.column;
                    name = info.name || name;
                }
                generator.addMapping({
                    generated: generatedPos,
                    original: { line: orig_line, column: orig_col },
                    source: source,
                    name: name
                });
                generator.setSourceContent(source, sourcesContent[source]);
            }
            function clean(map) {
                const allNull = map.sourcesContent && map.sourcesContent.every(c => c == null);
                if (allNull)
                    delete map.sourcesContent;
                if (map.file === undefined)
                    delete map.file;
                if (map.sourceRoot === undefined)
                    delete map.sourceRoot;
                return map;
            }
            function getDecoded() {
                if (!generator.toDecodedMap)
                    return null;
                return clean(generator.toDecodedMap());
            }
            function getEncoded() {
                return clean(generator.toJSON());
            }
            function destroy() {
                // @jridgewell/source-map's SourceMapConsumer does not need to be
                // manually freed.
                if (orig_map && orig_map.destroy)
                    orig_map.destroy();
            }
            return {
                add,
                getDecoded,
                getEncoded,
                destroy,
            };
        }
        var domprops = [
            "$&",
            "$'",
            "$*",
            "$+",
            "$1",
            "$2",
            "$3",
            "$4",
            "$5",
            "$6",
            "$7",
            "$8",
            "$9",
            "$_",
            "$`",
            "$input",
            "-moz-animation",
            "-moz-animation-delay",
            "-moz-animation-direction",
            "-moz-animation-duration",
            "-moz-animation-fill-mode",
            "-moz-animation-iteration-count",
            "-moz-animation-name",
            "-moz-animation-play-state",
            "-moz-animation-timing-function",
            "-moz-appearance",
            "-moz-backface-visibility",
            "-moz-border-end",
            "-moz-border-end-color",
            "-moz-border-end-style",
            "-moz-border-end-width",
            "-moz-border-image",
            "-moz-border-start",
            "-moz-border-start-color",
            "-moz-border-start-style",
            "-moz-border-start-width",
            "-moz-box-align",
            "-moz-box-direction",
            "-moz-box-flex",
            "-moz-box-ordinal-group",
            "-moz-box-orient",
            "-moz-box-pack",
            "-moz-box-sizing",
            "-moz-float-edge",
            "-moz-font-feature-settings",
            "-moz-font-language-override",
            "-moz-force-broken-image-icon",
            "-moz-hyphens",
            "-moz-image-region",
            "-moz-margin-end",
            "-moz-margin-start",
            "-moz-orient",
            "-moz-osx-font-smoothing",
            "-moz-outline-radius",
            "-moz-outline-radius-bottomleft",
            "-moz-outline-radius-bottomright",
            "-moz-outline-radius-topleft",
            "-moz-outline-radius-topright",
            "-moz-padding-end",
            "-moz-padding-start",
            "-moz-perspective",
            "-moz-perspective-origin",
            "-moz-tab-size",
            "-moz-text-size-adjust",
            "-moz-transform",
            "-moz-transform-origin",
            "-moz-transform-style",
            "-moz-transition",
            "-moz-transition-delay",
            "-moz-transition-duration",
            "-moz-transition-property",
            "-moz-transition-timing-function",
            "-moz-user-focus",
            "-moz-user-input",
            "-moz-user-modify",
            "-moz-user-select",
            "-moz-window-dragging",
            "-webkit-align-content",
            "-webkit-align-items",
            "-webkit-align-self",
            "-webkit-animation",
            "-webkit-animation-delay",
            "-webkit-animation-direction",
            "-webkit-animation-duration",
            "-webkit-animation-fill-mode",
            "-webkit-animation-iteration-count",
            "-webkit-animation-name",
            "-webkit-animation-play-state",
            "-webkit-animation-timing-function",
            "-webkit-appearance",
            "-webkit-backface-visibility",
            "-webkit-background-clip",
            "-webkit-background-origin",
            "-webkit-background-size",
            "-webkit-border-bottom-left-radius",
            "-webkit-border-bottom-right-radius",
            "-webkit-border-image",
            "-webkit-border-radius",
            "-webkit-border-top-left-radius",
            "-webkit-border-top-right-radius",
            "-webkit-box-align",
            "-webkit-box-direction",
            "-webkit-box-flex",
            "-webkit-box-ordinal-group",
            "-webkit-box-orient",
            "-webkit-box-pack",
            "-webkit-box-shadow",
            "-webkit-box-sizing",
            "-webkit-filter",
            "-webkit-flex",
            "-webkit-flex-basis",
            "-webkit-flex-direction",
            "-webkit-flex-flow",
            "-webkit-flex-grow",
            "-webkit-flex-shrink",
            "-webkit-flex-wrap",
            "-webkit-justify-content",
            "-webkit-line-clamp",
            "-webkit-mask",
            "-webkit-mask-clip",
            "-webkit-mask-composite",
            "-webkit-mask-image",
            "-webkit-mask-origin",
            "-webkit-mask-position",
            "-webkit-mask-position-x",
            "-webkit-mask-position-y",
            "-webkit-mask-repeat",
            "-webkit-mask-size",
            "-webkit-order",
            "-webkit-perspective",
            "-webkit-perspective-origin",
            "-webkit-text-fill-color",
            "-webkit-text-size-adjust",
            "-webkit-text-stroke",
            "-webkit-text-stroke-color",
            "-webkit-text-stroke-width",
            "-webkit-transform",
            "-webkit-transform-origin",
            "-webkit-transform-style",
            "-webkit-transition",
            "-webkit-transition-delay",
            "-webkit-transition-duration",
            "-webkit-transition-property",
            "-webkit-transition-timing-function",
            "-webkit-user-select",
            "0",
            "1",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
            "16",
            "17",
            "18",
            "19",
            "2",
            "20",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "@@iterator",
            "ABORT_ERR",
            "ACTIVE",
            "ACTIVE_ATTRIBUTES",
            "ACTIVE_TEXTURE",
            "ACTIVE_UNIFORMS",
            "ACTIVE_UNIFORM_BLOCKS",
            "ADDITION",
            "ALIASED_LINE_WIDTH_RANGE",
            "ALIASED_POINT_SIZE_RANGE",
            "ALLOW_KEYBOARD_INPUT",
            "ALLPASS",
            "ALPHA",
            "ALPHA_BITS",
            "ALREADY_SIGNALED",
            "ALT_MASK",
            "ALWAYS",
            "ANY_SAMPLES_PASSED",
            "ANY_SAMPLES_PASSED_CONSERVATIVE",
            "ANY_TYPE",
            "ANY_UNORDERED_NODE_TYPE",
            "ARRAY_BUFFER",
            "ARRAY_BUFFER_BINDING",
            "ATTACHED_SHADERS",
            "ATTRIBUTE_NODE",
            "AT_TARGET",
            "AbortController",
            "AbortSignal",
            "AbsoluteOrientationSensor",
            "AbstractRange",
            "Accelerometer",
            "AddSearchProvider",
            "AggregateError",
            "AnalyserNode",
            "Animation",
            "AnimationEffect",
            "AnimationEvent",
            "AnimationPlaybackEvent",
            "AnimationTimeline",
            "AnonXMLHttpRequest",
            "Any",
            "ApplicationCache",
            "ApplicationCacheErrorEvent",
            "Array",
            "ArrayBuffer",
            "ArrayType",
            "Atomics",
            "Attr",
            "Audio",
            "AudioBuffer",
            "AudioBufferSourceNode",
            "AudioContext",
            "AudioDestinationNode",
            "AudioListener",
            "AudioNode",
            "AudioParam",
            "AudioParamMap",
            "AudioProcessingEvent",
            "AudioScheduledSourceNode",
            "AudioStreamTrack",
            "AudioWorklet",
            "AudioWorkletNode",
            "AuthenticatorAssertionResponse",
            "AuthenticatorAttestationResponse",
            "AuthenticatorResponse",
            "AutocompleteErrorEvent",
            "BACK",
            "BAD_BOUNDARYPOINTS_ERR",
            "BAD_REQUEST",
            "BANDPASS",
            "BLEND",
            "BLEND_COLOR",
            "BLEND_DST_ALPHA",
            "BLEND_DST_RGB",
            "BLEND_EQUATION",
            "BLEND_EQUATION_ALPHA",
            "BLEND_EQUATION_RGB",
            "BLEND_SRC_ALPHA",
            "BLEND_SRC_RGB",
            "BLUE_BITS",
            "BLUR",
            "BOOL",
            "BOOLEAN_TYPE",
            "BOOL_VEC2",
            "BOOL_VEC3",
            "BOOL_VEC4",
            "BOTH",
            "BROWSER_DEFAULT_WEBGL",
            "BUBBLING_PHASE",
            "BUFFER_SIZE",
            "BUFFER_USAGE",
            "BYTE",
            "BYTES_PER_ELEMENT",
            "BackgroundFetchManager",
            "BackgroundFetchRecord",
            "BackgroundFetchRegistration",
            "BarProp",
            "BarcodeDetector",
            "BaseAudioContext",
            "BaseHref",
            "BatteryManager",
            "BeforeInstallPromptEvent",
            "BeforeLoadEvent",
            "BeforeUnloadEvent",
            "BigInt",
            "BigInt64Array",
            "BigUint64Array",
            "BiquadFilterNode",
            "Blob",
            "BlobEvent",
            "Bluetooth",
            "BluetoothCharacteristicProperties",
            "BluetoothDevice",
            "BluetoothRemoteGATTCharacteristic",
            "BluetoothRemoteGATTDescriptor",
            "BluetoothRemoteGATTServer",
            "BluetoothRemoteGATTService",
            "BluetoothUUID",
            "Boolean",
            "BroadcastChannel",
            "ByteLengthQueuingStrategy",
            "CAPTURING_PHASE",
            "CCW",
            "CDATASection",
            "CDATA_SECTION_NODE",
            "CHANGE",
            "CHARSET_RULE",
            "CHECKING",
            "CLAMP_TO_EDGE",
            "CLICK",
            "CLOSED",
            "CLOSING",
            "COLOR",
            "COLOR_ATTACHMENT0",
            "COLOR_ATTACHMENT1",
            "COLOR_ATTACHMENT10",
            "COLOR_ATTACHMENT11",
            "COLOR_ATTACHMENT12",
            "COLOR_ATTACHMENT13",
            "COLOR_ATTACHMENT14",
            "COLOR_ATTACHMENT15",
            "COLOR_ATTACHMENT2",
            "COLOR_ATTACHMENT3",
            "COLOR_ATTACHMENT4",
            "COLOR_ATTACHMENT5",
            "COLOR_ATTACHMENT6",
            "COLOR_ATTACHMENT7",
            "COLOR_ATTACHMENT8",
            "COLOR_ATTACHMENT9",
            "COLOR_BUFFER_BIT",
            "COLOR_CLEAR_VALUE",
            "COLOR_WRITEMASK",
            "COMMENT_NODE",
            "COMPARE_REF_TO_TEXTURE",
            "COMPILE_STATUS",
            "COMPLETION_STATUS_KHR",
            "COMPRESSED_RGBA_S3TC_DXT1_EXT",
            "COMPRESSED_RGBA_S3TC_DXT3_EXT",
            "COMPRESSED_RGBA_S3TC_DXT5_EXT",
            "COMPRESSED_RGB_S3TC_DXT1_EXT",
            "COMPRESSED_TEXTURE_FORMATS",
            "CONDITION_SATISFIED",
            "CONFIGURATION_UNSUPPORTED",
            "CONNECTING",
            "CONSTANT_ALPHA",
            "CONSTANT_COLOR",
            "CONSTRAINT_ERR",
            "CONTEXT_LOST_WEBGL",
            "CONTROL_MASK",
            "COPY_READ_BUFFER",
            "COPY_READ_BUFFER_BINDING",
            "COPY_WRITE_BUFFER",
            "COPY_WRITE_BUFFER_BINDING",
            "COUNTER_STYLE_RULE",
            "CSS",
            "CSS2Properties",
            "CSSAnimation",
            "CSSCharsetRule",
            "CSSConditionRule",
            "CSSCounterStyleRule",
            "CSSFontFaceRule",
            "CSSFontFeatureValuesRule",
            "CSSGroupingRule",
            "CSSImageValue",
            "CSSImportRule",
            "CSSKeyframeRule",
            "CSSKeyframesRule",
            "CSSKeywordValue",
            "CSSMathInvert",
            "CSSMathMax",
            "CSSMathMin",
            "CSSMathNegate",
            "CSSMathProduct",
            "CSSMathSum",
            "CSSMathValue",
            "CSSMatrixComponent",
            "CSSMediaRule",
            "CSSMozDocumentRule",
            "CSSNameSpaceRule",
            "CSSNamespaceRule",
            "CSSNumericArray",
            "CSSNumericValue",
            "CSSPageRule",
            "CSSPerspective",
            "CSSPositionValue",
            "CSSPrimitiveValue",
            "CSSRotate",
            "CSSRule",
            "CSSRuleList",
            "CSSScale",
            "CSSSkew",
            "CSSSkewX",
            "CSSSkewY",
            "CSSStyleDeclaration",
            "CSSStyleRule",
            "CSSStyleSheet",
            "CSSStyleValue",
            "CSSSupportsRule",
            "CSSTransformComponent",
            "CSSTransformValue",
            "CSSTransition",
            "CSSTranslate",
            "CSSUnitValue",
            "CSSUnknownRule",
            "CSSUnparsedValue",
            "CSSValue",
            "CSSValueList",
            "CSSVariableReferenceValue",
            "CSSVariablesDeclaration",
            "CSSVariablesRule",
            "CSSViewportRule",
            "CSS_ATTR",
            "CSS_CM",
            "CSS_COUNTER",
            "CSS_CUSTOM",
            "CSS_DEG",
            "CSS_DIMENSION",
            "CSS_EMS",
            "CSS_EXS",
            "CSS_FILTER_BLUR",
            "CSS_FILTER_BRIGHTNESS",
            "CSS_FILTER_CONTRAST",
            "CSS_FILTER_CUSTOM",
            "CSS_FILTER_DROP_SHADOW",
            "CSS_FILTER_GRAYSCALE",
            "CSS_FILTER_HUE_ROTATE",
            "CSS_FILTER_INVERT",
            "CSS_FILTER_OPACITY",
            "CSS_FILTER_REFERENCE",
            "CSS_FILTER_SATURATE",
            "CSS_FILTER_SEPIA",
            "CSS_GRAD",
            "CSS_HZ",
            "CSS_IDENT",
            "CSS_IN",
            "CSS_INHERIT",
            "CSS_KHZ",
            "CSS_MATRIX",
            "CSS_MATRIX3D",
            "CSS_MM",
            "CSS_MS",
            "CSS_NUMBER",
            "CSS_PC",
            "CSS_PERCENTAGE",
            "CSS_PERSPECTIVE",
            "CSS_PRIMITIVE_VALUE",
            "CSS_PT",
            "CSS_PX",
            "CSS_RAD",
            "CSS_RECT",
            "CSS_RGBCOLOR",
            "CSS_ROTATE",
            "CSS_ROTATE3D",
            "CSS_ROTATEX",
            "CSS_ROTATEY",
            "CSS_ROTATEZ",
            "CSS_S",
            "CSS_SCALE",
            "CSS_SCALE3D",
            "CSS_SCALEX",
            "CSS_SCALEY",
            "CSS_SCALEZ",
            "CSS_SKEW",
            "CSS_SKEWX",
            "CSS_SKEWY",
            "CSS_STRING",
            "CSS_TRANSLATE",
            "CSS_TRANSLATE3D",
            "CSS_TRANSLATEX",
            "CSS_TRANSLATEY",
            "CSS_TRANSLATEZ",
            "CSS_UNKNOWN",
            "CSS_URI",
            "CSS_VALUE_LIST",
            "CSS_VH",
            "CSS_VMAX",
            "CSS_VMIN",
            "CSS_VW",
            "CULL_FACE",
            "CULL_FACE_MODE",
            "CURRENT_PROGRAM",
            "CURRENT_QUERY",
            "CURRENT_VERTEX_ATTRIB",
            "CUSTOM",
            "CW",
            "Cache",
            "CacheStorage",
            "CanvasCaptureMediaStream",
            "CanvasCaptureMediaStreamTrack",
            "CanvasGradient",
            "CanvasPattern",
            "CanvasRenderingContext2D",
            "CaretPosition",
            "ChannelMergerNode",
            "ChannelSplitterNode",
            "CharacterData",
            "ClientRect",
            "ClientRectList",
            "Clipboard",
            "ClipboardEvent",
            "ClipboardItem",
            "CloseEvent",
            "Collator",
            "CommandEvent",
            "Comment",
            "CompileError",
            "CompositionEvent",
            "CompressionStream",
            "Console",
            "ConstantSourceNode",
            "Controllers",
            "ConvolverNode",
            "CountQueuingStrategy",
            "Counter",
            "Credential",
            "CredentialsContainer",
            "Crypto",
            "CryptoKey",
            "CustomElementRegistry",
            "CustomEvent",
            "DATABASE_ERR",
            "DATA_CLONE_ERR",
            "DATA_ERR",
            "DBLCLICK",
            "DECR",
            "DECR_WRAP",
            "DELETE_STATUS",
            "DEPTH",
            "DEPTH24_STENCIL8",
            "DEPTH32F_STENCIL8",
            "DEPTH_ATTACHMENT",
            "DEPTH_BITS",
            "DEPTH_BUFFER_BIT",
            "DEPTH_CLEAR_VALUE",
            "DEPTH_COMPONENT",
            "DEPTH_COMPONENT16",
            "DEPTH_COMPONENT24",
            "DEPTH_COMPONENT32F",
            "DEPTH_FUNC",
            "DEPTH_RANGE",
            "DEPTH_STENCIL",
            "DEPTH_STENCIL_ATTACHMENT",
            "DEPTH_TEST",
            "DEPTH_WRITEMASK",
            "DEVICE_INELIGIBLE",
            "DIRECTION_DOWN",
            "DIRECTION_LEFT",
            "DIRECTION_RIGHT",
            "DIRECTION_UP",
            "DISABLED",
            "DISPATCH_REQUEST_ERR",
            "DITHER",
            "DOCUMENT_FRAGMENT_NODE",
            "DOCUMENT_NODE",
            "DOCUMENT_POSITION_CONTAINED_BY",
            "DOCUMENT_POSITION_CONTAINS",
            "DOCUMENT_POSITION_DISCONNECTED",
            "DOCUMENT_POSITION_FOLLOWING",
            "DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC",
            "DOCUMENT_POSITION_PRECEDING",
            "DOCUMENT_TYPE_NODE",
            "DOMCursor",
            "DOMError",
            "DOMException",
            "DOMImplementation",
            "DOMImplementationLS",
            "DOMMatrix",
            "DOMMatrixReadOnly",
            "DOMParser",
            "DOMPoint",
            "DOMPointReadOnly",
            "DOMQuad",
            "DOMRect",
            "DOMRectList",
            "DOMRectReadOnly",
            "DOMRequest",
            "DOMSTRING_SIZE_ERR",
            "DOMSettableTokenList",
            "DOMStringList",
            "DOMStringMap",
            "DOMTokenList",
            "DOMTransactionEvent",
            "DOM_DELTA_LINE",
            "DOM_DELTA_PAGE",
            "DOM_DELTA_PIXEL",
            "DOM_INPUT_METHOD_DROP",
            "DOM_INPUT_METHOD_HANDWRITING",
            "DOM_INPUT_METHOD_IME",
            "DOM_INPUT_METHOD_KEYBOARD",
            "DOM_INPUT_METHOD_MULTIMODAL",
            "DOM_INPUT_METHOD_OPTION",
            "DOM_INPUT_METHOD_PASTE",
            "DOM_INPUT_METHOD_SCRIPT",
            "DOM_INPUT_METHOD_UNKNOWN",
            "DOM_INPUT_METHOD_VOICE",
            "DOM_KEY_LOCATION_JOYSTICK",
            "DOM_KEY_LOCATION_LEFT",
            "DOM_KEY_LOCATION_MOBILE",
            "DOM_KEY_LOCATION_NUMPAD",
            "DOM_KEY_LOCATION_RIGHT",
            "DOM_KEY_LOCATION_STANDARD",
            "DOM_VK_0",
            "DOM_VK_1",
            "DOM_VK_2",
            "DOM_VK_3",
            "DOM_VK_4",
            "DOM_VK_5",
            "DOM_VK_6",
            "DOM_VK_7",
            "DOM_VK_8",
            "DOM_VK_9",
            "DOM_VK_A",
            "DOM_VK_ACCEPT",
            "DOM_VK_ADD",
            "DOM_VK_ALT",
            "DOM_VK_ALTGR",
            "DOM_VK_AMPERSAND",
            "DOM_VK_ASTERISK",
            "DOM_VK_AT",
            "DOM_VK_ATTN",
            "DOM_VK_B",
            "DOM_VK_BACKSPACE",
            "DOM_VK_BACK_QUOTE",
            "DOM_VK_BACK_SLASH",
            "DOM_VK_BACK_SPACE",
            "DOM_VK_C",
            "DOM_VK_CANCEL",
            "DOM_VK_CAPS_LOCK",
            "DOM_VK_CIRCUMFLEX",
            "DOM_VK_CLEAR",
            "DOM_VK_CLOSE_BRACKET",
            "DOM_VK_CLOSE_CURLY_BRACKET",
            "DOM_VK_CLOSE_PAREN",
            "DOM_VK_COLON",
            "DOM_VK_COMMA",
            "DOM_VK_CONTEXT_MENU",
            "DOM_VK_CONTROL",
            "DOM_VK_CONVERT",
            "DOM_VK_CRSEL",
            "DOM_VK_CTRL",
            "DOM_VK_D",
            "DOM_VK_DECIMAL",
            "DOM_VK_DELETE",
            "DOM_VK_DIVIDE",
            "DOM_VK_DOLLAR",
            "DOM_VK_DOUBLE_QUOTE",
            "DOM_VK_DOWN",
            "DOM_VK_E",
            "DOM_VK_EISU",
            "DOM_VK_END",
            "DOM_VK_ENTER",
            "DOM_VK_EQUALS",
            "DOM_VK_EREOF",
            "DOM_VK_ESCAPE",
            "DOM_VK_EXCLAMATION",
            "DOM_VK_EXECUTE",
            "DOM_VK_EXSEL",
            "DOM_VK_F",
            "DOM_VK_F1",
            "DOM_VK_F10",
            "DOM_VK_F11",
            "DOM_VK_F12",
            "DOM_VK_F13",
            "DOM_VK_F14",
            "DOM_VK_F15",
            "DOM_VK_F16",
            "DOM_VK_F17",
            "DOM_VK_F18",
            "DOM_VK_F19",
            "DOM_VK_F2",
            "DOM_VK_F20",
            "DOM_VK_F21",
            "DOM_VK_F22",
            "DOM_VK_F23",
            "DOM_VK_F24",
            "DOM_VK_F25",
            "DOM_VK_F26",
            "DOM_VK_F27",
            "DOM_VK_F28",
            "DOM_VK_F29",
            "DOM_VK_F3",
            "DOM_VK_F30",
            "DOM_VK_F31",
            "DOM_VK_F32",
            "DOM_VK_F33",
            "DOM_VK_F34",
            "DOM_VK_F35",
            "DOM_VK_F36",
            "DOM_VK_F4",
            "DOM_VK_F5",
            "DOM_VK_F6",
            "DOM_VK_F7",
            "DOM_VK_F8",
            "DOM_VK_F9",
            "DOM_VK_FINAL",
            "DOM_VK_FRONT",
            "DOM_VK_G",
            "DOM_VK_GREATER_THAN",
            "DOM_VK_H",
            "DOM_VK_HANGUL",
            "DOM_VK_HANJA",
            "DOM_VK_HASH",
            "DOM_VK_HELP",
            "DOM_VK_HK_TOGGLE",
            "DOM_VK_HOME",
            "DOM_VK_HYPHEN_MINUS",
            "DOM_VK_I",
            "DOM_VK_INSERT",
            "DOM_VK_J",
            "DOM_VK_JUNJA",
            "DOM_VK_K",
            "DOM_VK_KANA",
            "DOM_VK_KANJI",
            "DOM_VK_L",
            "DOM_VK_LEFT",
            "DOM_VK_LEFT_TAB",
            "DOM_VK_LESS_THAN",
            "DOM_VK_M",
            "DOM_VK_META",
            "DOM_VK_MODECHANGE",
            "DOM_VK_MULTIPLY",
            "DOM_VK_N",
            "DOM_VK_NONCONVERT",
            "DOM_VK_NUMPAD0",
            "DOM_VK_NUMPAD1",
            "DOM_VK_NUMPAD2",
            "DOM_VK_NUMPAD3",
            "DOM_VK_NUMPAD4",
            "DOM_VK_NUMPAD5",
            "DOM_VK_NUMPAD6",
            "DOM_VK_NUMPAD7",
            "DOM_VK_NUMPAD8",
            "DOM_VK_NUMPAD9",
            "DOM_VK_NUM_LOCK",
            "DOM_VK_O",
            "DOM_VK_OEM_1",
            "DOM_VK_OEM_102",
            "DOM_VK_OEM_2",
            "DOM_VK_OEM_3",
            "DOM_VK_OEM_4",
            "DOM_VK_OEM_5",
            "DOM_VK_OEM_6",
            "DOM_VK_OEM_7",
            "DOM_VK_OEM_8",
            "DOM_VK_OEM_COMMA",
            "DOM_VK_OEM_MINUS",
            "DOM_VK_OEM_PERIOD",
            "DOM_VK_OEM_PLUS",
            "DOM_VK_OPEN_BRACKET",
            "DOM_VK_OPEN_CURLY_BRACKET",
            "DOM_VK_OPEN_PAREN",
            "DOM_VK_P",
            "DOM_VK_PA1",
            "DOM_VK_PAGEDOWN",
            "DOM_VK_PAGEUP",
            "DOM_VK_PAGE_DOWN",
            "DOM_VK_PAGE_UP",
            "DOM_VK_PAUSE",
            "DOM_VK_PERCENT",
            "DOM_VK_PERIOD",
            "DOM_VK_PIPE",
            "DOM_VK_PLAY",
            "DOM_VK_PLUS",
            "DOM_VK_PRINT",
            "DOM_VK_PRINTSCREEN",
            "DOM_VK_PROCESSKEY",
            "DOM_VK_PROPERITES",
            "DOM_VK_Q",
            "DOM_VK_QUESTION_MARK",
            "DOM_VK_QUOTE",
            "DOM_VK_R",
            "DOM_VK_REDO",
            "DOM_VK_RETURN",
            "DOM_VK_RIGHT",
            "DOM_VK_S",
            "DOM_VK_SCROLL_LOCK",
            "DOM_VK_SELECT",
            "DOM_VK_SEMICOLON",
            "DOM_VK_SEPARATOR",
            "DOM_VK_SHIFT",
            "DOM_VK_SLASH",
            "DOM_VK_SLEEP",
            "DOM_VK_SPACE",
            "DOM_VK_SUBTRACT",
            "DOM_VK_T",
            "DOM_VK_TAB",
            "DOM_VK_TILDE",
            "DOM_VK_U",
            "DOM_VK_UNDERSCORE",
            "DOM_VK_UNDO",
            "DOM_VK_UNICODE",
            "DOM_VK_UP",
            "DOM_VK_V",
            "DOM_VK_VOLUME_DOWN",
            "DOM_VK_VOLUME_MUTE",
            "DOM_VK_VOLUME_UP",
            "DOM_VK_W",
            "DOM_VK_WIN",
            "DOM_VK_WINDOW",
            "DOM_VK_WIN_ICO_00",
            "DOM_VK_WIN_ICO_CLEAR",
            "DOM_VK_WIN_ICO_HELP",
            "DOM_VK_WIN_OEM_ATTN",
            "DOM_VK_WIN_OEM_AUTO",
            "DOM_VK_WIN_OEM_BACKTAB",
            "DOM_VK_WIN_OEM_CLEAR",
            "DOM_VK_WIN_OEM_COPY",
            "DOM_VK_WIN_OEM_CUSEL",
            "DOM_VK_WIN_OEM_ENLW",
            "DOM_VK_WIN_OEM_FINISH",
            "DOM_VK_WIN_OEM_FJ_JISHO",
            "DOM_VK_WIN_OEM_FJ_LOYA",
            "DOM_VK_WIN_OEM_FJ_MASSHOU",
            "DOM_VK_WIN_OEM_FJ_ROYA",
            "DOM_VK_WIN_OEM_FJ_TOUROKU",
            "DOM_VK_WIN_OEM_JUMP",
            "DOM_VK_WIN_OEM_PA1",
            "DOM_VK_WIN_OEM_PA2",
            "DOM_VK_WIN_OEM_PA3",
            "DOM_VK_WIN_OEM_RESET",
            "DOM_VK_WIN_OEM_WSCTRL",
            "DOM_VK_X",
            "DOM_VK_XF86XK_ADD_FAVORITE",
            "DOM_VK_XF86XK_APPLICATION_LEFT",
            "DOM_VK_XF86XK_APPLICATION_RIGHT",
            "DOM_VK_XF86XK_AUDIO_CYCLE_TRACK",
            "DOM_VK_XF86XK_AUDIO_FORWARD",
            "DOM_VK_XF86XK_AUDIO_LOWER_VOLUME",
            "DOM_VK_XF86XK_AUDIO_MEDIA",
            "DOM_VK_XF86XK_AUDIO_MUTE",
            "DOM_VK_XF86XK_AUDIO_NEXT",
            "DOM_VK_XF86XK_AUDIO_PAUSE",
            "DOM_VK_XF86XK_AUDIO_PLAY",
            "DOM_VK_XF86XK_AUDIO_PREV",
            "DOM_VK_XF86XK_AUDIO_RAISE_VOLUME",
            "DOM_VK_XF86XK_AUDIO_RANDOM_PLAY",
            "DOM_VK_XF86XK_AUDIO_RECORD",
            "DOM_VK_XF86XK_AUDIO_REPEAT",
            "DOM_VK_XF86XK_AUDIO_REWIND",
            "DOM_VK_XF86XK_AUDIO_STOP",
            "DOM_VK_XF86XK_AWAY",
            "DOM_VK_XF86XK_BACK",
            "DOM_VK_XF86XK_BACK_FORWARD",
            "DOM_VK_XF86XK_BATTERY",
            "DOM_VK_XF86XK_BLUE",
            "DOM_VK_XF86XK_BLUETOOTH",
            "DOM_VK_XF86XK_BOOK",
            "DOM_VK_XF86XK_BRIGHTNESS_ADJUST",
            "DOM_VK_XF86XK_CALCULATOR",
            "DOM_VK_XF86XK_CALENDAR",
            "DOM_VK_XF86XK_CD",
            "DOM_VK_XF86XK_CLOSE",
            "DOM_VK_XF86XK_COMMUNITY",
            "DOM_VK_XF86XK_CONTRAST_ADJUST",
            "DOM_VK_XF86XK_COPY",
            "DOM_VK_XF86XK_CUT",
            "DOM_VK_XF86XK_CYCLE_ANGLE",
            "DOM_VK_XF86XK_DISPLAY",
            "DOM_VK_XF86XK_DOCUMENTS",
            "DOM_VK_XF86XK_DOS",
            "DOM_VK_XF86XK_EJECT",
            "DOM_VK_XF86XK_EXCEL",
            "DOM_VK_XF86XK_EXPLORER",
            "DOM_VK_XF86XK_FAVORITES",
            "DOM_VK_XF86XK_FINANCE",
            "DOM_VK_XF86XK_FORWARD",
            "DOM_VK_XF86XK_FRAME_BACK",
            "DOM_VK_XF86XK_FRAME_FORWARD",
            "DOM_VK_XF86XK_GAME",
            "DOM_VK_XF86XK_GO",
            "DOM_VK_XF86XK_GREEN",
            "DOM_VK_XF86XK_HIBERNATE",
            "DOM_VK_XF86XK_HISTORY",
            "DOM_VK_XF86XK_HOME_PAGE",
            "DOM_VK_XF86XK_HOT_LINKS",
            "DOM_VK_XF86XK_I_TOUCH",
            "DOM_VK_XF86XK_KBD_BRIGHTNESS_DOWN",
            "DOM_VK_XF86XK_KBD_BRIGHTNESS_UP",
            "DOM_VK_XF86XK_KBD_LIGHT_ON_OFF",
            "DOM_VK_XF86XK_LAUNCH0",
            "DOM_VK_XF86XK_LAUNCH1",
            "DOM_VK_XF86XK_LAUNCH2",
            "DOM_VK_XF86XK_LAUNCH3",
            "DOM_VK_XF86XK_LAUNCH4",
            "DOM_VK_XF86XK_LAUNCH5",
            "DOM_VK_XF86XK_LAUNCH6",
            "DOM_VK_XF86XK_LAUNCH7",
            "DOM_VK_XF86XK_LAUNCH8",
            "DOM_VK_XF86XK_LAUNCH9",
            "DOM_VK_XF86XK_LAUNCH_A",
            "DOM_VK_XF86XK_LAUNCH_B",
            "DOM_VK_XF86XK_LAUNCH_C",
            "DOM_VK_XF86XK_LAUNCH_D",
            "DOM_VK_XF86XK_LAUNCH_E",
            "DOM_VK_XF86XK_LAUNCH_F",
            "DOM_VK_XF86XK_LIGHT_BULB",
            "DOM_VK_XF86XK_LOG_OFF",
            "DOM_VK_XF86XK_MAIL",
            "DOM_VK_XF86XK_MAIL_FORWARD",
            "DOM_VK_XF86XK_MARKET",
            "DOM_VK_XF86XK_MEETING",
            "DOM_VK_XF86XK_MEMO",
            "DOM_VK_XF86XK_MENU_KB",
            "DOM_VK_XF86XK_MENU_PB",
            "DOM_VK_XF86XK_MESSENGER",
            "DOM_VK_XF86XK_MON_BRIGHTNESS_DOWN",
            "DOM_VK_XF86XK_MON_BRIGHTNESS_UP",
            "DOM_VK_XF86XK_MUSIC",
            "DOM_VK_XF86XK_MY_COMPUTER",
            "DOM_VK_XF86XK_MY_SITES",
            "DOM_VK_XF86XK_NEW",
            "DOM_VK_XF86XK_NEWS",
            "DOM_VK_XF86XK_OFFICE_HOME",
            "DOM_VK_XF86XK_OPEN",
            "DOM_VK_XF86XK_OPEN_URL",
            "DOM_VK_XF86XK_OPTION",
            "DOM_VK_XF86XK_PASTE",
            "DOM_VK_XF86XK_PHONE",
            "DOM_VK_XF86XK_PICTURES",
            "DOM_VK_XF86XK_POWER_DOWN",
            "DOM_VK_XF86XK_POWER_OFF",
            "DOM_VK_XF86XK_RED",
            "DOM_VK_XF86XK_REFRESH",
            "DOM_VK_XF86XK_RELOAD",
            "DOM_VK_XF86XK_REPLY",
            "DOM_VK_XF86XK_ROCKER_DOWN",
            "DOM_VK_XF86XK_ROCKER_ENTER",
            "DOM_VK_XF86XK_ROCKER_UP",
            "DOM_VK_XF86XK_ROTATE_WINDOWS",
            "DOM_VK_XF86XK_ROTATION_KB",
            "DOM_VK_XF86XK_ROTATION_PB",
            "DOM_VK_XF86XK_SAVE",
            "DOM_VK_XF86XK_SCREEN_SAVER",
            "DOM_VK_XF86XK_SCROLL_CLICK",
            "DOM_VK_XF86XK_SCROLL_DOWN",
            "DOM_VK_XF86XK_SCROLL_UP",
            "DOM_VK_XF86XK_SEARCH",
            "DOM_VK_XF86XK_SEND",
            "DOM_VK_XF86XK_SHOP",
            "DOM_VK_XF86XK_SPELL",
            "DOM_VK_XF86XK_SPLIT_SCREEN",
            "DOM_VK_XF86XK_STANDBY",
            "DOM_VK_XF86XK_START",
            "DOM_VK_XF86XK_STOP",
            "DOM_VK_XF86XK_SUBTITLE",
            "DOM_VK_XF86XK_SUPPORT",
            "DOM_VK_XF86XK_SUSPEND",
            "DOM_VK_XF86XK_TASK_PANE",
            "DOM_VK_XF86XK_TERMINAL",
            "DOM_VK_XF86XK_TIME",
            "DOM_VK_XF86XK_TOOLS",
            "DOM_VK_XF86XK_TOP_MENU",
            "DOM_VK_XF86XK_TO_DO_LIST",
            "DOM_VK_XF86XK_TRAVEL",
            "DOM_VK_XF86XK_USER1KB",
            "DOM_VK_XF86XK_USER2KB",
            "DOM_VK_XF86XK_USER_PB",
            "DOM_VK_XF86XK_UWB",
            "DOM_VK_XF86XK_VENDOR_HOME",
            "DOM_VK_XF86XK_VIDEO",
            "DOM_VK_XF86XK_VIEW",
            "DOM_VK_XF86XK_WAKE_UP",
            "DOM_VK_XF86XK_WEB_CAM",
            "DOM_VK_XF86XK_WHEEL_BUTTON",
            "DOM_VK_XF86XK_WLAN",
            "DOM_VK_XF86XK_WORD",
            "DOM_VK_XF86XK_WWW",
            "DOM_VK_XF86XK_XFER",
            "DOM_VK_XF86XK_YELLOW",
            "DOM_VK_XF86XK_ZOOM_IN",
            "DOM_VK_XF86XK_ZOOM_OUT",
            "DOM_VK_Y",
            "DOM_VK_Z",
            "DOM_VK_ZOOM",
            "DONE",
            "DONT_CARE",
            "DOWNLOADING",
            "DRAGDROP",
            "DRAW_BUFFER0",
            "DRAW_BUFFER1",
            "DRAW_BUFFER10",
            "DRAW_BUFFER11",
            "DRAW_BUFFER12",
            "DRAW_BUFFER13",
            "DRAW_BUFFER14",
            "DRAW_BUFFER15",
            "DRAW_BUFFER2",
            "DRAW_BUFFER3",
            "DRAW_BUFFER4",
            "DRAW_BUFFER5",
            "DRAW_BUFFER6",
            "DRAW_BUFFER7",
            "DRAW_BUFFER8",
            "DRAW_BUFFER9",
            "DRAW_FRAMEBUFFER",
            "DRAW_FRAMEBUFFER_BINDING",
            "DST_ALPHA",
            "DST_COLOR",
            "DYNAMIC_COPY",
            "DYNAMIC_DRAW",
            "DYNAMIC_READ",
            "DataChannel",
            "DataTransfer",
            "DataTransferItem",
            "DataTransferItemList",
            "DataView",
            "Date",
            "DateTimeFormat",
            "DecompressionStream",
            "DelayNode",
            "DeprecationReportBody",
            "DesktopNotification",
            "DesktopNotificationCenter",
            "DeviceLightEvent",
            "DeviceMotionEvent",
            "DeviceMotionEventAcceleration",
            "DeviceMotionEventRotationRate",
            "DeviceOrientationEvent",
            "DeviceProximityEvent",
            "DeviceStorage",
            "DeviceStorageChangeEvent",
            "Directory",
            "DisplayNames",
            "Document",
            "DocumentFragment",
            "DocumentTimeline",
            "DocumentType",
            "DragEvent",
            "DynamicsCompressorNode",
            "E",
            "ELEMENT_ARRAY_BUFFER",
            "ELEMENT_ARRAY_BUFFER_BINDING",
            "ELEMENT_NODE",
            "EMPTY",
            "ENCODING_ERR",
            "ENDED",
            "END_TO_END",
            "END_TO_START",
            "ENTITY_NODE",
            "ENTITY_REFERENCE_NODE",
            "EPSILON",
            "EQUAL",
            "EQUALPOWER",
            "ERROR",
            "EXPONENTIAL_DISTANCE",
            "Element",
            "ElementInternals",
            "ElementQuery",
            "EnterPictureInPictureEvent",
            "Entity",
            "EntityReference",
            "Error",
            "ErrorEvent",
            "EvalError",
            "Event",
            "EventException",
            "EventSource",
            "EventTarget",
            "External",
            "FASTEST",
            "FIDOSDK",
            "FILTER_ACCEPT",
            "FILTER_INTERRUPT",
            "FILTER_REJECT",
            "FILTER_SKIP",
            "FINISHED_STATE",
            "FIRST_ORDERED_NODE_TYPE",
            "FLOAT",
            "FLOAT_32_UNSIGNED_INT_24_8_REV",
            "FLOAT_MAT2",
            "FLOAT_MAT2x3",
            "FLOAT_MAT2x4",
            "FLOAT_MAT3",
            "FLOAT_MAT3x2",
            "FLOAT_MAT3x4",
            "FLOAT_MAT4",
            "FLOAT_MAT4x2",
            "FLOAT_MAT4x3",
            "FLOAT_VEC2",
            "FLOAT_VEC3",
            "FLOAT_VEC4",
            "FOCUS",
            "FONT_FACE_RULE",
            "FONT_FEATURE_VALUES_RULE",
            "FRAGMENT_SHADER",
            "FRAGMENT_SHADER_DERIVATIVE_HINT",
            "FRAGMENT_SHADER_DERIVATIVE_HINT_OES",
            "FRAMEBUFFER",
            "FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE",
            "FRAMEBUFFER_ATTACHMENT_BLUE_SIZE",
            "FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING",
            "FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE",
            "FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE",
            "FRAMEBUFFER_ATTACHMENT_GREEN_SIZE",
            "FRAMEBUFFER_ATTACHMENT_OBJECT_NAME",
            "FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE",
            "FRAMEBUFFER_ATTACHMENT_RED_SIZE",
            "FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE",
            "FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE",
            "FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER",
            "FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL",
            "FRAMEBUFFER_BINDING",
            "FRAMEBUFFER_COMPLETE",
            "FRAMEBUFFER_DEFAULT",
            "FRAMEBUFFER_INCOMPLETE_ATTACHMENT",
            "FRAMEBUFFER_INCOMPLETE_DIMENSIONS",
            "FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT",
            "FRAMEBUFFER_INCOMPLETE_MULTISAMPLE",
            "FRAMEBUFFER_UNSUPPORTED",
            "FRONT",
            "FRONT_AND_BACK",
            "FRONT_FACE",
            "FUNC_ADD",
            "FUNC_REVERSE_SUBTRACT",
            "FUNC_SUBTRACT",
            "FeaturePolicy",
            "FeaturePolicyViolationReportBody",
            "FederatedCredential",
            "Feed",
            "FeedEntry",
            "File",
            "FileError",
            "FileList",
            "FileReader",
            "FileSystem",
            "FileSystemDirectoryEntry",
            "FileSystemDirectoryReader",
            "FileSystemEntry",
            "FileSystemFileEntry",
            "FinalizationRegistry",
            "FindInPage",
            "Float32Array",
            "Float64Array",
            "FocusEvent",
            "FontFace",
            "FontFaceSet",
            "FontFaceSetLoadEvent",
            "FormData",
            "FormDataEvent",
            "FragmentDirective",
            "Function",
            "GENERATE_MIPMAP_HINT",
            "GEQUAL",
            "GREATER",
            "GREEN_BITS",
            "GainNode",
            "Gamepad",
            "GamepadAxisMoveEvent",
            "GamepadButton",
            "GamepadButtonEvent",
            "GamepadEvent",
            "GamepadHapticActuator",
            "GamepadPose",
            "Geolocation",
            "GeolocationCoordinates",
            "GeolocationPosition",
            "GeolocationPositionError",
            "GestureEvent",
            "Global",
            "Gyroscope",
            "HALF_FLOAT",
            "HAVE_CURRENT_DATA",
            "HAVE_ENOUGH_DATA",
            "HAVE_FUTURE_DATA",
            "HAVE_METADATA",
            "HAVE_NOTHING",
            "HEADERS_RECEIVED",
            "HIDDEN",
            "HIERARCHY_REQUEST_ERR",
            "HIGHPASS",
            "HIGHSHELF",
            "HIGH_FLOAT",
            "HIGH_INT",
            "HORIZONTAL",
            "HORIZONTAL_AXIS",
            "HRTF",
            "HTMLAllCollection",
            "HTMLAnchorElement",
            "HTMLAppletElement",
            "HTMLAreaElement",
            "HTMLAudioElement",
            "HTMLBRElement",
            "HTMLBaseElement",
            "HTMLBaseFontElement",
            "HTMLBlockquoteElement",
            "HTMLBodyElement",
            "HTMLButtonElement",
            "HTMLCanvasElement",
            "HTMLCollection",
            "HTMLCommandElement",
            "HTMLContentElement",
            "HTMLDListElement",
            "HTMLDataElement",
            "HTMLDataListElement",
            "HTMLDetailsElement",
            "HTMLDialogElement",
            "HTMLDirectoryElement",
            "HTMLDivElement",
            "HTMLDocument",
            "HTMLElement",
            "HTMLEmbedElement",
            "HTMLFieldSetElement",
            "HTMLFontElement",
            "HTMLFormControlsCollection",
            "HTMLFormElement",
            "HTMLFrameElement",
            "HTMLFrameSetElement",
            "HTMLHRElement",
            "HTMLHeadElement",
            "HTMLHeadingElement",
            "HTMLHtmlElement",
            "HTMLIFrameElement",
            "HTMLImageElement",
            "HTMLInputElement",
            "HTMLIsIndexElement",
            "HTMLKeygenElement",
            "HTMLLIElement",
            "HTMLLabelElement",
            "HTMLLegendElement",
            "HTMLLinkElement",
            "HTMLMapElement",
            "HTMLMarqueeElement",
            "HTMLMediaElement",
            "HTMLMenuElement",
            "HTMLMenuItemElement",
            "HTMLMetaElement",
            "HTMLMeterElement",
            "HTMLModElement",
            "HTMLOListElement",
            "HTMLObjectElement",
            "HTMLOptGroupElement",
            "HTMLOptionElement",
            "HTMLOptionsCollection",
            "HTMLOutputElement",
            "HTMLParagraphElement",
            "HTMLParamElement",
            "HTMLPictureElement",
            "HTMLPreElement",
            "HTMLProgressElement",
            "HTMLPropertiesCollection",
            "HTMLQuoteElement",
            "HTMLScriptElement",
            "HTMLSelectElement",
            "HTMLShadowElement",
            "HTMLSlotElement",
            "HTMLSourceElement",
            "HTMLSpanElement",
            "HTMLStyleElement",
            "HTMLTableCaptionElement",
            "HTMLTableCellElement",
            "HTMLTableColElement",
            "HTMLTableElement",
            "HTMLTableRowElement",
            "HTMLTableSectionElement",
            "HTMLTemplateElement",
            "HTMLTextAreaElement",
            "HTMLTimeElement",
            "HTMLTitleElement",
            "HTMLTrackElement",
            "HTMLUListElement",
            "HTMLUnknownElement",
            "HTMLVideoElement",
            "HashChangeEvent",
            "Headers",
            "History",
            "Hz",
            "ICE_CHECKING",
            "ICE_CLOSED",
            "ICE_COMPLETED",
            "ICE_CONNECTED",
            "ICE_FAILED",
            "ICE_GATHERING",
            "ICE_WAITING",
            "IDBCursor",
            "IDBCursorWithValue",
            "IDBDatabase",
            "IDBDatabaseException",
            "IDBFactory",
            "IDBFileHandle",
            "IDBFileRequest",
            "IDBIndex",
            "IDBKeyRange",
            "IDBMutableFile",
            "IDBObjectStore",
            "IDBOpenDBRequest",
            "IDBRequest",
            "IDBTransaction",
            "IDBVersionChangeEvent",
            "IDLE",
            "IIRFilterNode",
            "IMPLEMENTATION_COLOR_READ_FORMAT",
            "IMPLEMENTATION_COLOR_READ_TYPE",
            "IMPORT_RULE",
            "INCR",
            "INCR_WRAP",
            "INDEX_SIZE_ERR",
            "INT",
            "INTERLEAVED_ATTRIBS",
            "INT_2_10_10_10_REV",
            "INT_SAMPLER_2D",
            "INT_SAMPLER_2D_ARRAY",
            "INT_SAMPLER_3D",
            "INT_SAMPLER_CUBE",
            "INT_VEC2",
            "INT_VEC3",
            "INT_VEC4",
            "INUSE_ATTRIBUTE_ERR",
            "INVALID_ACCESS_ERR",
            "INVALID_CHARACTER_ERR",
            "INVALID_ENUM",
            "INVALID_EXPRESSION_ERR",
            "INVALID_FRAMEBUFFER_OPERATION",
            "INVALID_INDEX",
            "INVALID_MODIFICATION_ERR",
            "INVALID_NODE_TYPE_ERR",
            "INVALID_OPERATION",
            "INVALID_STATE_ERR",
            "INVALID_VALUE",
            "INVERSE_DISTANCE",
            "INVERT",
            "IceCandidate",
            "IdleDeadline",
            "Image",
            "ImageBitmap",
            "ImageBitmapRenderingContext",
            "ImageCapture",
            "ImageData",
            "Infinity",
            "InputDeviceCapabilities",
            "InputDeviceInfo",
            "InputEvent",
            "InputMethodContext",
            "InstallTrigger",
            "InstallTriggerImpl",
            "Instance",
            "Int16Array",
            "Int32Array",
            "Int8Array",
            "Intent",
            "InternalError",
            "IntersectionObserver",
            "IntersectionObserverEntry",
            "Intl",
            "IsSearchProviderInstalled",
            "Iterator",
            "JSON",
            "KEEP",
            "KEYDOWN",
            "KEYFRAMES_RULE",
            "KEYFRAME_RULE",
            "KEYPRESS",
            "KEYUP",
            "KeyEvent",
            "Keyboard",
            "KeyboardEvent",
            "KeyboardLayoutMap",
            "KeyframeEffect",
            "LENGTHADJUST_SPACING",
            "LENGTHADJUST_SPACINGANDGLYPHS",
            "LENGTHADJUST_UNKNOWN",
            "LEQUAL",
            "LESS",
            "LINEAR",
            "LINEAR_DISTANCE",
            "LINEAR_MIPMAP_LINEAR",
            "LINEAR_MIPMAP_NEAREST",
            "LINES",
            "LINE_LOOP",
            "LINE_STRIP",
            "LINE_WIDTH",
            "LINK_STATUS",
            "LIVE",
            "LN10",
            "LN2",
            "LOADED",
            "LOADING",
            "LOG10E",
            "LOG2E",
            "LOWPASS",
            "LOWSHELF",
            "LOW_FLOAT",
            "LOW_INT",
            "LSException",
            "LSParserFilter",
            "LUMINANCE",
            "LUMINANCE_ALPHA",
            "LargestContentfulPaint",
            "LayoutShift",
            "LayoutShiftAttribution",
            "LinearAccelerationSensor",
            "LinkError",
            "ListFormat",
            "LocalMediaStream",
            "Locale",
            "Location",
            "Lock",
            "LockManager",
            "MAX",
            "MAX_3D_TEXTURE_SIZE",
            "MAX_ARRAY_TEXTURE_LAYERS",
            "MAX_CLIENT_WAIT_TIMEOUT_WEBGL",
            "MAX_COLOR_ATTACHMENTS",
            "MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS",
            "MAX_COMBINED_TEXTURE_IMAGE_UNITS",
            "MAX_COMBINED_UNIFORM_BLOCKS",
            "MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS",
            "MAX_CUBE_MAP_TEXTURE_SIZE",
            "MAX_DRAW_BUFFERS",
            "MAX_ELEMENTS_INDICES",
            "MAX_ELEMENTS_VERTICES",
            "MAX_ELEMENT_INDEX",
            "MAX_FRAGMENT_INPUT_COMPONENTS",
            "MAX_FRAGMENT_UNIFORM_BLOCKS",
            "MAX_FRAGMENT_UNIFORM_COMPONENTS",
            "MAX_FRAGMENT_UNIFORM_VECTORS",
            "MAX_PROGRAM_TEXEL_OFFSET",
            "MAX_RENDERBUFFER_SIZE",
            "MAX_SAFE_INTEGER",
            "MAX_SAMPLES",
            "MAX_SERVER_WAIT_TIMEOUT",
            "MAX_TEXTURE_IMAGE_UNITS",
            "MAX_TEXTURE_LOD_BIAS",
            "MAX_TEXTURE_MAX_ANISOTROPY_EXT",
            "MAX_TEXTURE_SIZE",
            "MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS",
            "MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS",
            "MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS",
            "MAX_UNIFORM_BLOCK_SIZE",
            "MAX_UNIFORM_BUFFER_BINDINGS",
            "MAX_VALUE",
            "MAX_VARYING_COMPONENTS",
            "MAX_VARYING_VECTORS",
            "MAX_VERTEX_ATTRIBS",
            "MAX_VERTEX_OUTPUT_COMPONENTS",
            "MAX_VERTEX_TEXTURE_IMAGE_UNITS",
            "MAX_VERTEX_UNIFORM_BLOCKS",
            "MAX_VERTEX_UNIFORM_COMPONENTS",
            "MAX_VERTEX_UNIFORM_VECTORS",
            "MAX_VIEWPORT_DIMS",
            "MEDIA_ERR_ABORTED",
            "MEDIA_ERR_DECODE",
            "MEDIA_ERR_ENCRYPTED",
            "MEDIA_ERR_NETWORK",
            "MEDIA_ERR_SRC_NOT_SUPPORTED",
            "MEDIA_KEYERR_CLIENT",
            "MEDIA_KEYERR_DOMAIN",
            "MEDIA_KEYERR_HARDWARECHANGE",
            "MEDIA_KEYERR_OUTPUT",
            "MEDIA_KEYERR_SERVICE",
            "MEDIA_KEYERR_UNKNOWN",
            "MEDIA_RULE",
            "MEDIUM_FLOAT",
            "MEDIUM_INT",
            "META_MASK",
            "MIDIAccess",
            "MIDIConnectionEvent",
            "MIDIInput",
            "MIDIInputMap",
            "MIDIMessageEvent",
            "MIDIOutput",
            "MIDIOutputMap",
            "MIDIPort",
            "MIN",
            "MIN_PROGRAM_TEXEL_OFFSET",
            "MIN_SAFE_INTEGER",
            "MIN_VALUE",
            "MIRRORED_REPEAT",
            "MODE_ASYNCHRONOUS",
            "MODE_SYNCHRONOUS",
            "MODIFICATION",
            "MOUSEDOWN",
            "MOUSEDRAG",
            "MOUSEMOVE",
            "MOUSEOUT",
            "MOUSEOVER",
            "MOUSEUP",
            "MOZ_KEYFRAMES_RULE",
            "MOZ_KEYFRAME_RULE",
            "MOZ_SOURCE_CURSOR",
            "MOZ_SOURCE_ERASER",
            "MOZ_SOURCE_KEYBOARD",
            "MOZ_SOURCE_MOUSE",
            "MOZ_SOURCE_PEN",
            "MOZ_SOURCE_TOUCH",
            "MOZ_SOURCE_UNKNOWN",
            "MSGESTURE_FLAG_BEGIN",
            "MSGESTURE_FLAG_CANCEL",
            "MSGESTURE_FLAG_END",
            "MSGESTURE_FLAG_INERTIA",
            "MSGESTURE_FLAG_NONE",
            "MSPOINTER_TYPE_MOUSE",
            "MSPOINTER_TYPE_PEN",
            "MSPOINTER_TYPE_TOUCH",
            "MS_ASYNC_CALLBACK_STATUS_ASSIGN_DELEGATE",
            "MS_ASYNC_CALLBACK_STATUS_CANCEL",
            "MS_ASYNC_CALLBACK_STATUS_CHOOSEANY",
            "MS_ASYNC_CALLBACK_STATUS_ERROR",
            "MS_ASYNC_CALLBACK_STATUS_JOIN",
            "MS_ASYNC_OP_STATUS_CANCELED",
            "MS_ASYNC_OP_STATUS_ERROR",
            "MS_ASYNC_OP_STATUS_SUCCESS",
            "MS_MANIPULATION_STATE_ACTIVE",
            "MS_MANIPULATION_STATE_CANCELLED",
            "MS_MANIPULATION_STATE_COMMITTED",
            "MS_MANIPULATION_STATE_DRAGGING",
            "MS_MANIPULATION_STATE_INERTIA",
            "MS_MANIPULATION_STATE_PRESELECT",
            "MS_MANIPULATION_STATE_SELECTING",
            "MS_MANIPULATION_STATE_STOPPED",
            "MS_MEDIA_ERR_ENCRYPTED",
            "MS_MEDIA_KEYERR_CLIENT",
            "MS_MEDIA_KEYERR_DOMAIN",
            "MS_MEDIA_KEYERR_HARDWARECHANGE",
            "MS_MEDIA_KEYERR_OUTPUT",
            "MS_MEDIA_KEYERR_SERVICE",
            "MS_MEDIA_KEYERR_UNKNOWN",
            "Map",
            "Math",
            "MathMLElement",
            "MediaCapabilities",
            "MediaCapabilitiesInfo",
            "MediaController",
            "MediaDeviceInfo",
            "MediaDevices",
            "MediaElementAudioSourceNode",
            "MediaEncryptedEvent",
            "MediaError",
            "MediaKeyError",
            "MediaKeyEvent",
            "MediaKeyMessageEvent",
            "MediaKeyNeededEvent",
            "MediaKeySession",
            "MediaKeyStatusMap",
            "MediaKeySystemAccess",
            "MediaKeys",
            "MediaList",
            "MediaMetadata",
            "MediaQueryList",
            "MediaQueryListEvent",
            "MediaRecorder",
            "MediaRecorderErrorEvent",
            "MediaSession",
            "MediaSettingsRange",
            "MediaSource",
            "MediaStream",
            "MediaStreamAudioDestinationNode",
            "MediaStreamAudioSourceNode",
            "MediaStreamEvent",
            "MediaStreamTrack",
            "MediaStreamTrackAudioSourceNode",
            "MediaStreamTrackEvent",
            "Memory",
            "MessageChannel",
            "MessageEvent",
            "MessagePort",
            "Methods",
            "MimeType",
            "MimeTypeArray",
            "Module",
            "MouseEvent",
            "MouseScrollEvent",
            "MozAnimation",
            "MozAnimationDelay",
            "MozAnimationDirection",
            "MozAnimationDuration",
            "MozAnimationFillMode",
            "MozAnimationIterationCount",
            "MozAnimationName",
            "MozAnimationPlayState",
            "MozAnimationTimingFunction",
            "MozAppearance",
            "MozBackfaceVisibility",
            "MozBinding",
            "MozBorderBottomColors",
            "MozBorderEnd",
            "MozBorderEndColor",
            "MozBorderEndStyle",
            "MozBorderEndWidth",
            "MozBorderImage",
            "MozBorderLeftColors",
            "MozBorderRightColors",
            "MozBorderStart",
            "MozBorderStartColor",
            "MozBorderStartStyle",
            "MozBorderStartWidth",
            "MozBorderTopColors",
            "MozBoxAlign",
            "MozBoxDirection",
            "MozBoxFlex",
            "MozBoxOrdinalGroup",
            "MozBoxOrient",
            "MozBoxPack",
            "MozBoxSizing",
            "MozCSSKeyframeRule",
            "MozCSSKeyframesRule",
            "MozColumnCount",
            "MozColumnFill",
            "MozColumnGap",
            "MozColumnRule",
            "MozColumnRuleColor",
            "MozColumnRuleStyle",
            "MozColumnRuleWidth",
            "MozColumnWidth",
            "MozColumns",
            "MozContactChangeEvent",
            "MozFloatEdge",
            "MozFontFeatureSettings",
            "MozFontLanguageOverride",
            "MozForceBrokenImageIcon",
            "MozHyphens",
            "MozImageRegion",
            "MozMarginEnd",
            "MozMarginStart",
            "MozMmsEvent",
            "MozMmsMessage",
            "MozMobileMessageThread",
            "MozOSXFontSmoothing",
            "MozOrient",
            "MozOsxFontSmoothing",
            "MozOutlineRadius",
            "MozOutlineRadiusBottomleft",
            "MozOutlineRadiusBottomright",
            "MozOutlineRadiusTopleft",
            "MozOutlineRadiusTopright",
            "MozPaddingEnd",
            "MozPaddingStart",
            "MozPerspective",
            "MozPerspectiveOrigin",
            "MozPowerManager",
            "MozSettingsEvent",
            "MozSmsEvent",
            "MozSmsMessage",
            "MozStackSizing",
            "MozTabSize",
            "MozTextAlignLast",
            "MozTextDecorationColor",
            "MozTextDecorationLine",
            "MozTextDecorationStyle",
            "MozTextSizeAdjust",
            "MozTransform",
            "MozTransformOrigin",
            "MozTransformStyle",
            "MozTransition",
            "MozTransitionDelay",
            "MozTransitionDuration",
            "MozTransitionProperty",
            "MozTransitionTimingFunction",
            "MozUserFocus",
            "MozUserInput",
            "MozUserModify",
            "MozUserSelect",
            "MozWindowDragging",
            "MozWindowShadow",
            "MutationEvent",
            "MutationObserver",
            "MutationRecord",
            "NAMESPACE_ERR",
            "NAMESPACE_RULE",
            "NEAREST",
            "NEAREST_MIPMAP_LINEAR",
            "NEAREST_MIPMAP_NEAREST",
            "NEGATIVE_INFINITY",
            "NETWORK_EMPTY",
            "NETWORK_ERR",
            "NETWORK_IDLE",
            "NETWORK_LOADED",
            "NETWORK_LOADING",
            "NETWORK_NO_SOURCE",
            "NEVER",
            "NEW",
            "NEXT",
            "NEXT_NO_DUPLICATE",
            "NICEST",
            "NODE_AFTER",
            "NODE_BEFORE",
            "NODE_BEFORE_AND_AFTER",
            "NODE_INSIDE",
            "NONE",
            "NON_TRANSIENT_ERR",
            "NOTATION_NODE",
            "NOTCH",
            "NOTEQUAL",
            "NOT_ALLOWED_ERR",
            "NOT_FOUND_ERR",
            "NOT_READABLE_ERR",
            "NOT_SUPPORTED_ERR",
            "NO_DATA_ALLOWED_ERR",
            "NO_ERR",
            "NO_ERROR",
            "NO_MODIFICATION_ALLOWED_ERR",
            "NUMBER_TYPE",
            "NUM_COMPRESSED_TEXTURE_FORMATS",
            "NaN",
            "NamedNodeMap",
            "NavigationPreloadManager",
            "Navigator",
            "NearbyLinks",
            "NetworkInformation",
            "Node",
            "NodeFilter",
            "NodeIterator",
            "NodeList",
            "Notation",
            "Notification",
            "NotifyPaintEvent",
            "Number",
            "NumberFormat",
            "OBJECT_TYPE",
            "OBSOLETE",
            "OK",
            "ONE",
            "ONE_MINUS_CONSTANT_ALPHA",
            "ONE_MINUS_CONSTANT_COLOR",
            "ONE_MINUS_DST_ALPHA",
            "ONE_MINUS_DST_COLOR",
            "ONE_MINUS_SRC_ALPHA",
            "ONE_MINUS_SRC_COLOR",
            "OPEN",
            "OPENED",
            "OPENING",
            "ORDERED_NODE_ITERATOR_TYPE",
            "ORDERED_NODE_SNAPSHOT_TYPE",
            "OTHER_ERROR",
            "OUT_OF_MEMORY",
            "Object",
            "OfflineAudioCompletionEvent",
            "OfflineAudioContext",
            "OfflineResourceList",
            "OffscreenCanvas",
            "OffscreenCanvasRenderingContext2D",
            "Option",
            "OrientationSensor",
            "OscillatorNode",
            "OverconstrainedError",
            "OverflowEvent",
            "PACK_ALIGNMENT",
            "PACK_ROW_LENGTH",
            "PACK_SKIP_PIXELS",
            "PACK_SKIP_ROWS",
            "PAGE_RULE",
            "PARSE_ERR",
            "PATHSEG_ARC_ABS",
            "PATHSEG_ARC_REL",
            "PATHSEG_CLOSEPATH",
            "PATHSEG_CURVETO_CUBIC_ABS",
            "PATHSEG_CURVETO_CUBIC_REL",
            "PATHSEG_CURVETO_CUBIC_SMOOTH_ABS",
            "PATHSEG_CURVETO_CUBIC_SMOOTH_REL",
            "PATHSEG_CURVETO_QUADRATIC_ABS",
            "PATHSEG_CURVETO_QUADRATIC_REL",
            "PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS",
            "PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL",
            "PATHSEG_LINETO_ABS",
            "PATHSEG_LINETO_HORIZONTAL_ABS",
            "PATHSEG_LINETO_HORIZONTAL_REL",
            "PATHSEG_LINETO_REL",
            "PATHSEG_LINETO_VERTICAL_ABS",
            "PATHSEG_LINETO_VERTICAL_REL",
            "PATHSEG_MOVETO_ABS",
            "PATHSEG_MOVETO_REL",
            "PATHSEG_UNKNOWN",
            "PATH_EXISTS_ERR",
            "PEAKING",
            "PERMISSION_DENIED",
            "PERSISTENT",
            "PI",
            "PIXEL_PACK_BUFFER",
            "PIXEL_PACK_BUFFER_BINDING",
            "PIXEL_UNPACK_BUFFER",
            "PIXEL_UNPACK_BUFFER_BINDING",
            "PLAYING_STATE",
            "POINTS",
            "POLYGON_OFFSET_FACTOR",
            "POLYGON_OFFSET_FILL",
            "POLYGON_OFFSET_UNITS",
            "POSITION_UNAVAILABLE",
            "POSITIVE_INFINITY",
            "PREV",
            "PREV_NO_DUPLICATE",
            "PROCESSING_INSTRUCTION_NODE",
            "PageChangeEvent",
            "PageTransitionEvent",
            "PaintRequest",
            "PaintRequestList",
            "PannerNode",
            "PasswordCredential",
            "Path2D",
            "PaymentAddress",
            "PaymentInstruments",
            "PaymentManager",
            "PaymentMethodChangeEvent",
            "PaymentRequest",
            "PaymentRequestUpdateEvent",
            "PaymentResponse",
            "Performance",
            "PerformanceElementTiming",
            "PerformanceEntry",
            "PerformanceEventTiming",
            "PerformanceLongTaskTiming",
            "PerformanceMark",
            "PerformanceMeasure",
            "PerformanceNavigation",
            "PerformanceNavigationTiming",
            "PerformanceObserver",
            "PerformanceObserverEntryList",
            "PerformancePaintTiming",
            "PerformanceResourceTiming",
            "PerformanceServerTiming",
            "PerformanceTiming",
            "PeriodicSyncManager",
            "PeriodicWave",
            "PermissionStatus",
            "Permissions",
            "PhotoCapabilities",
            "PictureInPictureWindow",
            "Plugin",
            "PluginArray",
            "PluralRules",
            "PointerEvent",
            "PopStateEvent",
            "PopupBlockedEvent",
            "Presentation",
            "PresentationAvailability",
            "PresentationConnection",
            "PresentationConnectionAvailableEvent",
            "PresentationConnectionCloseEvent",
            "PresentationConnectionList",
            "PresentationReceiver",
            "PresentationRequest",
            "ProcessingInstruction",
            "ProgressEvent",
            "Promise",
            "PromiseRejectionEvent",
            "PropertyNodeList",
            "Proxy",
            "PublicKeyCredential",
            "PushManager",
            "PushSubscription",
            "PushSubscriptionOptions",
            "Q",
            "QUERY_RESULT",
            "QUERY_RESULT_AVAILABLE",
            "QUOTA_ERR",
            "QUOTA_EXCEEDED_ERR",
            "QueryInterface",
            "R11F_G11F_B10F",
            "R16F",
            "R16I",
            "R16UI",
            "R32F",
            "R32I",
            "R32UI",
            "R8",
            "R8I",
            "R8UI",
            "R8_SNORM",
            "RASTERIZER_DISCARD",
            "READ_BUFFER",
            "READ_FRAMEBUFFER",
            "READ_FRAMEBUFFER_BINDING",
            "READ_ONLY",
            "READ_ONLY_ERR",
            "READ_WRITE",
            "RED",
            "RED_BITS",
            "RED_INTEGER",
            "REMOVAL",
            "RENDERBUFFER",
            "RENDERBUFFER_ALPHA_SIZE",
            "RENDERBUFFER_BINDING",
            "RENDERBUFFER_BLUE_SIZE",
            "RENDERBUFFER_DEPTH_SIZE",
            "RENDERBUFFER_GREEN_SIZE",
            "RENDERBUFFER_HEIGHT",
            "RENDERBUFFER_INTERNAL_FORMAT",
            "RENDERBUFFER_RED_SIZE",
            "RENDERBUFFER_SAMPLES",
            "RENDERBUFFER_STENCIL_SIZE",
            "RENDERBUFFER_WIDTH",
            "RENDERER",
            "RENDERING_INTENT_ABSOLUTE_COLORIMETRIC",
            "RENDERING_INTENT_AUTO",
            "RENDERING_INTENT_PERCEPTUAL",
            "RENDERING_INTENT_RELATIVE_COLORIMETRIC",
            "RENDERING_INTENT_SATURATION",
            "RENDERING_INTENT_UNKNOWN",
            "REPEAT",
            "REPLACE",
            "RG",
            "RG16F",
            "RG16I",
            "RG16UI",
            "RG32F",
            "RG32I",
            "RG32UI",
            "RG8",
            "RG8I",
            "RG8UI",
            "RG8_SNORM",
            "RGB",
            "RGB10_A2",
            "RGB10_A2UI",
            "RGB16F",
            "RGB16I",
            "RGB16UI",
            "RGB32F",
            "RGB32I",
            "RGB32UI",
            "RGB565",
            "RGB5_A1",
            "RGB8",
            "RGB8I",
            "RGB8UI",
            "RGB8_SNORM",
            "RGB9_E5",
            "RGBA",
            "RGBA16F",
            "RGBA16I",
            "RGBA16UI",
            "RGBA32F",
            "RGBA32I",
            "RGBA32UI",
            "RGBA4",
            "RGBA8",
            "RGBA8I",
            "RGBA8UI",
            "RGBA8_SNORM",
            "RGBA_INTEGER",
            "RGBColor",
            "RGB_INTEGER",
            "RG_INTEGER",
            "ROTATION_CLOCKWISE",
            "ROTATION_COUNTERCLOCKWISE",
            "RTCCertificate",
            "RTCDTMFSender",
            "RTCDTMFToneChangeEvent",
            "RTCDataChannel",
            "RTCDataChannelEvent",
            "RTCDtlsTransport",
            "RTCError",
            "RTCErrorEvent",
            "RTCIceCandidate",
            "RTCIceTransport",
            "RTCPeerConnection",
            "RTCPeerConnectionIceErrorEvent",
            "RTCPeerConnectionIceEvent",
            "RTCRtpReceiver",
            "RTCRtpSender",
            "RTCRtpTransceiver",
            "RTCSctpTransport",
            "RTCSessionDescription",
            "RTCStatsReport",
            "RTCTrackEvent",
            "RadioNodeList",
            "Range",
            "RangeError",
            "RangeException",
            "ReadableStream",
            "ReadableStreamDefaultReader",
            "RecordErrorEvent",
            "Rect",
            "ReferenceError",
            "Reflect",
            "RegExp",
            "RelativeOrientationSensor",
            "RelativeTimeFormat",
            "RemotePlayback",
            "Report",
            "ReportBody",
            "ReportingObserver",
            "Request",
            "ResizeObserver",
            "ResizeObserverEntry",
            "ResizeObserverSize",
            "Response",
            "RuntimeError",
            "SAMPLER_2D",
            "SAMPLER_2D_ARRAY",
            "SAMPLER_2D_ARRAY_SHADOW",
            "SAMPLER_2D_SHADOW",
            "SAMPLER_3D",
            "SAMPLER_BINDING",
            "SAMPLER_CUBE",
            "SAMPLER_CUBE_SHADOW",
            "SAMPLES",
            "SAMPLE_ALPHA_TO_COVERAGE",
            "SAMPLE_BUFFERS",
            "SAMPLE_COVERAGE",
            "SAMPLE_COVERAGE_INVERT",
            "SAMPLE_COVERAGE_VALUE",
            "SAWTOOTH",
            "SCHEDULED_STATE",
            "SCISSOR_BOX",
            "SCISSOR_TEST",
            "SCROLL_PAGE_DOWN",
            "SCROLL_PAGE_UP",
            "SDP_ANSWER",
            "SDP_OFFER",
            "SDP_PRANSWER",
            "SECURITY_ERR",
            "SELECT",
            "SEPARATE_ATTRIBS",
            "SERIALIZE_ERR",
            "SEVERITY_ERROR",
            "SEVERITY_FATAL_ERROR",
            "SEVERITY_WARNING",
            "SHADER_COMPILER",
            "SHADER_TYPE",
            "SHADING_LANGUAGE_VERSION",
            "SHIFT_MASK",
            "SHORT",
            "SHOWING",
            "SHOW_ALL",
            "SHOW_ATTRIBUTE",
            "SHOW_CDATA_SECTION",
            "SHOW_COMMENT",
            "SHOW_DOCUMENT",
            "SHOW_DOCUMENT_FRAGMENT",
            "SHOW_DOCUMENT_TYPE",
            "SHOW_ELEMENT",
            "SHOW_ENTITY",
            "SHOW_ENTITY_REFERENCE",
            "SHOW_NOTATION",
            "SHOW_PROCESSING_INSTRUCTION",
            "SHOW_TEXT",
            "SIGNALED",
            "SIGNED_NORMALIZED",
            "SINE",
            "SOUNDFIELD",
            "SQLException",
            "SQRT1_2",
            "SQRT2",
            "SQUARE",
            "SRC_ALPHA",
            "SRC_ALPHA_SATURATE",
            "SRC_COLOR",
            "SRGB",
            "SRGB8",
            "SRGB8_ALPHA8",
            "START_TO_END",
            "START_TO_START",
            "STATIC_COPY",
            "STATIC_DRAW",
            "STATIC_READ",
            "STENCIL",
            "STENCIL_ATTACHMENT",
            "STENCIL_BACK_FAIL",
            "STENCIL_BACK_FUNC",
            "STENCIL_BACK_PASS_DEPTH_FAIL",
            "STENCIL_BACK_PASS_DEPTH_PASS",
            "STENCIL_BACK_REF",
            "STENCIL_BACK_VALUE_MASK",
            "STENCIL_BACK_WRITEMASK",
            "STENCIL_BITS",
            "STENCIL_BUFFER_BIT",
            "STENCIL_CLEAR_VALUE",
            "STENCIL_FAIL",
            "STENCIL_FUNC",
            "STENCIL_INDEX",
            "STENCIL_INDEX8",
            "STENCIL_PASS_DEPTH_FAIL",
            "STENCIL_PASS_DEPTH_PASS",
            "STENCIL_REF",
            "STENCIL_TEST",
            "STENCIL_VALUE_MASK",
            "STENCIL_WRITEMASK",
            "STREAM_COPY",
            "STREAM_DRAW",
            "STREAM_READ",
            "STRING_TYPE",
            "STYLE_RULE",
            "SUBPIXEL_BITS",
            "SUPPORTS_RULE",
            "SVGAElement",
            "SVGAltGlyphDefElement",
            "SVGAltGlyphElement",
            "SVGAltGlyphItemElement",
            "SVGAngle",
            "SVGAnimateColorElement",
            "SVGAnimateElement",
            "SVGAnimateMotionElement",
            "SVGAnimateTransformElement",
            "SVGAnimatedAngle",
            "SVGAnimatedBoolean",
            "SVGAnimatedEnumeration",
            "SVGAnimatedInteger",
            "SVGAnimatedLength",
            "SVGAnimatedLengthList",
            "SVGAnimatedNumber",
            "SVGAnimatedNumberList",
            "SVGAnimatedPreserveAspectRatio",
            "SVGAnimatedRect",
            "SVGAnimatedString",
            "SVGAnimatedTransformList",
            "SVGAnimationElement",
            "SVGCircleElement",
            "SVGClipPathElement",
            "SVGColor",
            "SVGComponentTransferFunctionElement",
            "SVGCursorElement",
            "SVGDefsElement",
            "SVGDescElement",
            "SVGDiscardElement",
            "SVGDocument",
            "SVGElement",
            "SVGElementInstance",
            "SVGElementInstanceList",
            "SVGEllipseElement",
            "SVGException",
            "SVGFEBlendElement",
            "SVGFEColorMatrixElement",
            "SVGFEComponentTransferElement",
            "SVGFECompositeElement",
            "SVGFEConvolveMatrixElement",
            "SVGFEDiffuseLightingElement",
            "SVGFEDisplacementMapElement",
            "SVGFEDistantLightElement",
            "SVGFEDropShadowElement",
            "SVGFEFloodElement",
            "SVGFEFuncAElement",
            "SVGFEFuncBElement",
            "SVGFEFuncGElement",
            "SVGFEFuncRElement",
            "SVGFEGaussianBlurElement",
            "SVGFEImageElement",
            "SVGFEMergeElement",
            "SVGFEMergeNodeElement",
            "SVGFEMorphologyElement",
            "SVGFEOffsetElement",
            "SVGFEPointLightElement",
            "SVGFESpecularLightingElement",
            "SVGFESpotLightElement",
            "SVGFETileElement",
            "SVGFETurbulenceElement",
            "SVGFilterElement",
            "SVGFontElement",
            "SVGFontFaceElement",
            "SVGFontFaceFormatElement",
            "SVGFontFaceNameElement",
            "SVGFontFaceSrcElement",
            "SVGFontFaceUriElement",
            "SVGForeignObjectElement",
            "SVGGElement",
            "SVGGeometryElement",
            "SVGGlyphElement",
            "SVGGlyphRefElement",
            "SVGGradientElement",
            "SVGGraphicsElement",
            "SVGHKernElement",
            "SVGImageElement",
            "SVGLength",
            "SVGLengthList",
            "SVGLineElement",
            "SVGLinearGradientElement",
            "SVGMPathElement",
            "SVGMarkerElement",
            "SVGMaskElement",
            "SVGMatrix",
            "SVGMetadataElement",
            "SVGMissingGlyphElement",
            "SVGNumber",
            "SVGNumberList",
            "SVGPaint",
            "SVGPathElement",
            "SVGPathSeg",
            "SVGPathSegArcAbs",
            "SVGPathSegArcRel",
            "SVGPathSegClosePath",
            "SVGPathSegCurvetoCubicAbs",
            "SVGPathSegCurvetoCubicRel",
            "SVGPathSegCurvetoCubicSmoothAbs",
            "SVGPathSegCurvetoCubicSmoothRel",
            "SVGPathSegCurvetoQuadraticAbs",
            "SVGPathSegCurvetoQuadraticRel",
            "SVGPathSegCurvetoQuadraticSmoothAbs",
            "SVGPathSegCurvetoQuadraticSmoothRel",
            "SVGPathSegLinetoAbs",
            "SVGPathSegLinetoHorizontalAbs",
            "SVGPathSegLinetoHorizontalRel",
            "SVGPathSegLinetoRel",
            "SVGPathSegLinetoVerticalAbs",
            "SVGPathSegLinetoVerticalRel",
            "SVGPathSegList",
            "SVGPathSegMovetoAbs",
            "SVGPathSegMovetoRel",
            "SVGPatternElement",
            "SVGPoint",
            "SVGPointList",
            "SVGPolygonElement",
            "SVGPolylineElement",
            "SVGPreserveAspectRatio",
            "SVGRadialGradientElement",
            "SVGRect",
            "SVGRectElement",
            "SVGRenderingIntent",
            "SVGSVGElement",
            "SVGScriptElement",
            "SVGSetElement",
            "SVGStopElement",
            "SVGStringList",
            "SVGStyleElement",
            "SVGSwitchElement",
            "SVGSymbolElement",
            "SVGTRefElement",
            "SVGTSpanElement",
            "SVGTextContentElement",
            "SVGTextElement",
            "SVGTextPathElement",
            "SVGTextPositioningElement",
            "SVGTitleElement",
            "SVGTransform",
            "SVGTransformList",
            "SVGUnitTypes",
            "SVGUseElement",
            "SVGVKernElement",
            "SVGViewElement",
            "SVGViewSpec",
            "SVGZoomAndPan",
            "SVGZoomEvent",
            "SVG_ANGLETYPE_DEG",
            "SVG_ANGLETYPE_GRAD",
            "SVG_ANGLETYPE_RAD",
            "SVG_ANGLETYPE_UNKNOWN",
            "SVG_ANGLETYPE_UNSPECIFIED",
            "SVG_CHANNEL_A",
            "SVG_CHANNEL_B",
            "SVG_CHANNEL_G",
            "SVG_CHANNEL_R",
            "SVG_CHANNEL_UNKNOWN",
            "SVG_COLORTYPE_CURRENTCOLOR",
            "SVG_COLORTYPE_RGBCOLOR",
            "SVG_COLORTYPE_RGBCOLOR_ICCCOLOR",
            "SVG_COLORTYPE_UNKNOWN",
            "SVG_EDGEMODE_DUPLICATE",
            "SVG_EDGEMODE_NONE",
            "SVG_EDGEMODE_UNKNOWN",
            "SVG_EDGEMODE_WRAP",
            "SVG_FEBLEND_MODE_COLOR",
            "SVG_FEBLEND_MODE_COLOR_BURN",
            "SVG_FEBLEND_MODE_COLOR_DODGE",
            "SVG_FEBLEND_MODE_DARKEN",
            "SVG_FEBLEND_MODE_DIFFERENCE",
            "SVG_FEBLEND_MODE_EXCLUSION",
            "SVG_FEBLEND_MODE_HARD_LIGHT",
            "SVG_FEBLEND_MODE_HUE",
            "SVG_FEBLEND_MODE_LIGHTEN",
            "SVG_FEBLEND_MODE_LUMINOSITY",
            "SVG_FEBLEND_MODE_MULTIPLY",
            "SVG_FEBLEND_MODE_NORMAL",
            "SVG_FEBLEND_MODE_OVERLAY",
            "SVG_FEBLEND_MODE_SATURATION",
            "SVG_FEBLEND_MODE_SCREEN",
            "SVG_FEBLEND_MODE_SOFT_LIGHT",
            "SVG_FEBLEND_MODE_UNKNOWN",
            "SVG_FECOLORMATRIX_TYPE_HUEROTATE",
            "SVG_FECOLORMATRIX_TYPE_LUMINANCETOALPHA",
            "SVG_FECOLORMATRIX_TYPE_MATRIX",
            "SVG_FECOLORMATRIX_TYPE_SATURATE",
            "SVG_FECOLORMATRIX_TYPE_UNKNOWN",
            "SVG_FECOMPONENTTRANSFER_TYPE_DISCRETE",
            "SVG_FECOMPONENTTRANSFER_TYPE_GAMMA",
            "SVG_FECOMPONENTTRANSFER_TYPE_IDENTITY",
            "SVG_FECOMPONENTTRANSFER_TYPE_LINEAR",
            "SVG_FECOMPONENTTRANSFER_TYPE_TABLE",
            "SVG_FECOMPONENTTRANSFER_TYPE_UNKNOWN",
            "SVG_FECOMPOSITE_OPERATOR_ARITHMETIC",
            "SVG_FECOMPOSITE_OPERATOR_ATOP",
            "SVG_FECOMPOSITE_OPERATOR_IN",
            "SVG_FECOMPOSITE_OPERATOR_OUT",
            "SVG_FECOMPOSITE_OPERATOR_OVER",
            "SVG_FECOMPOSITE_OPERATOR_UNKNOWN",
            "SVG_FECOMPOSITE_OPERATOR_XOR",
            "SVG_INVALID_VALUE_ERR",
            "SVG_LENGTHTYPE_CM",
            "SVG_LENGTHTYPE_EMS",
            "SVG_LENGTHTYPE_EXS",
            "SVG_LENGTHTYPE_IN",
            "SVG_LENGTHTYPE_MM",
            "SVG_LENGTHTYPE_NUMBER",
            "SVG_LENGTHTYPE_PC",
            "SVG_LENGTHTYPE_PERCENTAGE",
            "SVG_LENGTHTYPE_PT",
            "SVG_LENGTHTYPE_PX",
            "SVG_LENGTHTYPE_UNKNOWN",
            "SVG_MARKERUNITS_STROKEWIDTH",
            "SVG_MARKERUNITS_UNKNOWN",
            "SVG_MARKERUNITS_USERSPACEONUSE",
            "SVG_MARKER_ORIENT_ANGLE",
            "SVG_MARKER_ORIENT_AUTO",
            "SVG_MARKER_ORIENT_UNKNOWN",
            "SVG_MASKTYPE_ALPHA",
            "SVG_MASKTYPE_LUMINANCE",
            "SVG_MATRIX_NOT_INVERTABLE",
            "SVG_MEETORSLICE_MEET",
            "SVG_MEETORSLICE_SLICE",
            "SVG_MEETORSLICE_UNKNOWN",
            "SVG_MORPHOLOGY_OPERATOR_DILATE",
            "SVG_MORPHOLOGY_OPERATOR_ERODE",
            "SVG_MORPHOLOGY_OPERATOR_UNKNOWN",
            "SVG_PAINTTYPE_CURRENTCOLOR",
            "SVG_PAINTTYPE_NONE",
            "SVG_PAINTTYPE_RGBCOLOR",
            "SVG_PAINTTYPE_RGBCOLOR_ICCCOLOR",
            "SVG_PAINTTYPE_UNKNOWN",
            "SVG_PAINTTYPE_URI",
            "SVG_PAINTTYPE_URI_CURRENTCOLOR",
            "SVG_PAINTTYPE_URI_NONE",
            "SVG_PAINTTYPE_URI_RGBCOLOR",
            "SVG_PAINTTYPE_URI_RGBCOLOR_ICCCOLOR",
            "SVG_PRESERVEASPECTRATIO_NONE",
            "SVG_PRESERVEASPECTRATIO_UNKNOWN",
            "SVG_PRESERVEASPECTRATIO_XMAXYMAX",
            "SVG_PRESERVEASPECTRATIO_XMAXYMID",
            "SVG_PRESERVEASPECTRATIO_XMAXYMIN",
            "SVG_PRESERVEASPECTRATIO_XMIDYMAX",
            "SVG_PRESERVEASPECTRATIO_XMIDYMID",
            "SVG_PRESERVEASPECTRATIO_XMIDYMIN",
            "SVG_PRESERVEASPECTRATIO_XMINYMAX",
            "SVG_PRESERVEASPECTRATIO_XMINYMID",
            "SVG_PRESERVEASPECTRATIO_XMINYMIN",
            "SVG_SPREADMETHOD_PAD",
            "SVG_SPREADMETHOD_REFLECT",
            "SVG_SPREADMETHOD_REPEAT",
            "SVG_SPREADMETHOD_UNKNOWN",
            "SVG_STITCHTYPE_NOSTITCH",
            "SVG_STITCHTYPE_STITCH",
            "SVG_STITCHTYPE_UNKNOWN",
            "SVG_TRANSFORM_MATRIX",
            "SVG_TRANSFORM_ROTATE",
            "SVG_TRANSFORM_SCALE",
            "SVG_TRANSFORM_SKEWX",
            "SVG_TRANSFORM_SKEWY",
            "SVG_TRANSFORM_TRANSLATE",
            "SVG_TRANSFORM_UNKNOWN",
            "SVG_TURBULENCE_TYPE_FRACTALNOISE",
            "SVG_TURBULENCE_TYPE_TURBULENCE",
            "SVG_TURBULENCE_TYPE_UNKNOWN",
            "SVG_UNIT_TYPE_OBJECTBOUNDINGBOX",
            "SVG_UNIT_TYPE_UNKNOWN",
            "SVG_UNIT_TYPE_USERSPACEONUSE",
            "SVG_WRONG_TYPE_ERR",
            "SVG_ZOOMANDPAN_DISABLE",
            "SVG_ZOOMANDPAN_MAGNIFY",
            "SVG_ZOOMANDPAN_UNKNOWN",
            "SYNC_CONDITION",
            "SYNC_FENCE",
            "SYNC_FLAGS",
            "SYNC_FLUSH_COMMANDS_BIT",
            "SYNC_GPU_COMMANDS_COMPLETE",
            "SYNC_STATUS",
            "SYNTAX_ERR",
            "SavedPages",
            "Screen",
            "ScreenOrientation",
            "Script",
            "ScriptProcessorNode",
            "ScrollAreaEvent",
            "SecurityPolicyViolationEvent",
            "Selection",
            "Sensor",
            "SensorErrorEvent",
            "ServiceWorker",
            "ServiceWorkerContainer",
            "ServiceWorkerRegistration",
            "SessionDescription",
            "Set",
            "ShadowRoot",
            "SharedArrayBuffer",
            "SharedWorker",
            "SimpleGestureEvent",
            "SourceBuffer",
            "SourceBufferList",
            "SpeechSynthesis",
            "SpeechSynthesisErrorEvent",
            "SpeechSynthesisEvent",
            "SpeechSynthesisUtterance",
            "SpeechSynthesisVoice",
            "StaticRange",
            "StereoPannerNode",
            "StopIteration",
            "Storage",
            "StorageEvent",
            "StorageManager",
            "String",
            "StructType",
            "StylePropertyMap",
            "StylePropertyMapReadOnly",
            "StyleSheet",
            "StyleSheetList",
            "SubmitEvent",
            "SubtleCrypto",
            "Symbol",
            "SyncManager",
            "SyntaxError",
            "TEMPORARY",
            "TEXTPATH_METHODTYPE_ALIGN",
            "TEXTPATH_METHODTYPE_STRETCH",
            "TEXTPATH_METHODTYPE_UNKNOWN",
            "TEXTPATH_SPACINGTYPE_AUTO",
            "TEXTPATH_SPACINGTYPE_EXACT",
            "TEXTPATH_SPACINGTYPE_UNKNOWN",
            "TEXTURE",
            "TEXTURE0",
            "TEXTURE1",
            "TEXTURE10",
            "TEXTURE11",
            "TEXTURE12",
            "TEXTURE13",
            "TEXTURE14",
            "TEXTURE15",
            "TEXTURE16",
            "TEXTURE17",
            "TEXTURE18",
            "TEXTURE19",
            "TEXTURE2",
            "TEXTURE20",
            "TEXTURE21",
            "TEXTURE22",
            "TEXTURE23",
            "TEXTURE24",
            "TEXTURE25",
            "TEXTURE26",
            "TEXTURE27",
            "TEXTURE28",
            "TEXTURE29",
            "TEXTURE3",
            "TEXTURE30",
            "TEXTURE31",
            "TEXTURE4",
            "TEXTURE5",
            "TEXTURE6",
            "TEXTURE7",
            "TEXTURE8",
            "TEXTURE9",
            "TEXTURE_2D",
            "TEXTURE_2D_ARRAY",
            "TEXTURE_3D",
            "TEXTURE_BASE_LEVEL",
            "TEXTURE_BINDING_2D",
            "TEXTURE_BINDING_2D_ARRAY",
            "TEXTURE_BINDING_3D",
            "TEXTURE_BINDING_CUBE_MAP",
            "TEXTURE_COMPARE_FUNC",
            "TEXTURE_COMPARE_MODE",
            "TEXTURE_CUBE_MAP",
            "TEXTURE_CUBE_MAP_NEGATIVE_X",
            "TEXTURE_CUBE_MAP_NEGATIVE_Y",
            "TEXTURE_CUBE_MAP_NEGATIVE_Z",
            "TEXTURE_CUBE_MAP_POSITIVE_X",
            "TEXTURE_CUBE_MAP_POSITIVE_Y",
            "TEXTURE_CUBE_MAP_POSITIVE_Z",
            "TEXTURE_IMMUTABLE_FORMAT",
            "TEXTURE_IMMUTABLE_LEVELS",
            "TEXTURE_MAG_FILTER",
            "TEXTURE_MAX_ANISOTROPY_EXT",
            "TEXTURE_MAX_LEVEL",
            "TEXTURE_MAX_LOD",
            "TEXTURE_MIN_FILTER",
            "TEXTURE_MIN_LOD",
            "TEXTURE_WRAP_R",
            "TEXTURE_WRAP_S",
            "TEXTURE_WRAP_T",
            "TEXT_NODE",
            "TIMEOUT",
            "TIMEOUT_ERR",
            "TIMEOUT_EXPIRED",
            "TIMEOUT_IGNORED",
            "TOO_LARGE_ERR",
            "TRANSACTION_INACTIVE_ERR",
            "TRANSFORM_FEEDBACK",
            "TRANSFORM_FEEDBACK_ACTIVE",
            "TRANSFORM_FEEDBACK_BINDING",
            "TRANSFORM_FEEDBACK_BUFFER",
            "TRANSFORM_FEEDBACK_BUFFER_BINDING",
            "TRANSFORM_FEEDBACK_BUFFER_MODE",
            "TRANSFORM_FEEDBACK_BUFFER_SIZE",
            "TRANSFORM_FEEDBACK_BUFFER_START",
            "TRANSFORM_FEEDBACK_PAUSED",
            "TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN",
            "TRANSFORM_FEEDBACK_VARYINGS",
            "TRIANGLE",
            "TRIANGLES",
            "TRIANGLE_FAN",
            "TRIANGLE_STRIP",
            "TYPE_BACK_FORWARD",
            "TYPE_ERR",
            "TYPE_MISMATCH_ERR",
            "TYPE_NAVIGATE",
            "TYPE_RELOAD",
            "TYPE_RESERVED",
            "Table",
            "TaskAttributionTiming",
            "Text",
            "TextDecoder",
            "TextDecoderStream",
            "TextEncoder",
            "TextEncoderStream",
            "TextEvent",
            "TextMetrics",
            "TextTrack",
            "TextTrackCue",
            "TextTrackCueList",
            "TextTrackList",
            "TimeEvent",
            "TimeRanges",
            "Touch",
            "TouchEvent",
            "TouchList",
            "TrackEvent",
            "TransformStream",
            "TransitionEvent",
            "TreeWalker",
            "TrustedHTML",
            "TrustedScript",
            "TrustedScriptURL",
            "TrustedTypePolicy",
            "TrustedTypePolicyFactory",
            "TypeError",
            "TypedObject",
            "U2F",
            "UIEvent",
            "UNCACHED",
            "UNIFORM_ARRAY_STRIDE",
            "UNIFORM_BLOCK_ACTIVE_UNIFORMS",
            "UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES",
            "UNIFORM_BLOCK_BINDING",
            "UNIFORM_BLOCK_DATA_SIZE",
            "UNIFORM_BLOCK_INDEX",
            "UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER",
            "UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER",
            "UNIFORM_BUFFER",
            "UNIFORM_BUFFER_BINDING",
            "UNIFORM_BUFFER_OFFSET_ALIGNMENT",
            "UNIFORM_BUFFER_SIZE",
            "UNIFORM_BUFFER_START",
            "UNIFORM_IS_ROW_MAJOR",
            "UNIFORM_MATRIX_STRIDE",
            "UNIFORM_OFFSET",
            "UNIFORM_SIZE",
            "UNIFORM_TYPE",
            "UNKNOWN_ERR",
            "UNKNOWN_RULE",
            "UNMASKED_RENDERER_WEBGL",
            "UNMASKED_VENDOR_WEBGL",
            "UNORDERED_NODE_ITERATOR_TYPE",
            "UNORDERED_NODE_SNAPSHOT_TYPE",
            "UNPACK_ALIGNMENT",
            "UNPACK_COLORSPACE_CONVERSION_WEBGL",
            "UNPACK_FLIP_Y_WEBGL",
            "UNPACK_IMAGE_HEIGHT",
            "UNPACK_PREMULTIPLY_ALPHA_WEBGL",
            "UNPACK_ROW_LENGTH",
            "UNPACK_SKIP_IMAGES",
            "UNPACK_SKIP_PIXELS",
            "UNPACK_SKIP_ROWS",
            "UNSCHEDULED_STATE",
            "UNSENT",
            "UNSIGNALED",
            "UNSIGNED_BYTE",
            "UNSIGNED_INT",
            "UNSIGNED_INT_10F_11F_11F_REV",
            "UNSIGNED_INT_24_8",
            "UNSIGNED_INT_2_10_10_10_REV",
            "UNSIGNED_INT_5_9_9_9_REV",
            "UNSIGNED_INT_SAMPLER_2D",
            "UNSIGNED_INT_SAMPLER_2D_ARRAY",
            "UNSIGNED_INT_SAMPLER_3D",
            "UNSIGNED_INT_SAMPLER_CUBE",
            "UNSIGNED_INT_VEC2",
            "UNSIGNED_INT_VEC3",
            "UNSIGNED_INT_VEC4",
            "UNSIGNED_NORMALIZED",
            "UNSIGNED_SHORT",
            "UNSIGNED_SHORT_4_4_4_4",
            "UNSIGNED_SHORT_5_5_5_1",
            "UNSIGNED_SHORT_5_6_5",
            "UNSPECIFIED_EVENT_TYPE_ERR",
            "UPDATEREADY",
            "URIError",
            "URL",
            "URLSearchParams",
            "URLUnencoded",
            "URL_MISMATCH_ERR",
            "USB",
            "USBAlternateInterface",
            "USBConfiguration",
            "USBConnectionEvent",
            "USBDevice",
            "USBEndpoint",
            "USBInTransferResult",
            "USBInterface",
            "USBIsochronousInTransferPacket",
            "USBIsochronousInTransferResult",
            "USBIsochronousOutTransferPacket",
            "USBIsochronousOutTransferResult",
            "USBOutTransferResult",
            "UTC",
            "Uint16Array",
            "Uint32Array",
            "Uint8Array",
            "Uint8ClampedArray",
            "UserActivation",
            "UserMessageHandler",
            "UserMessageHandlersNamespace",
            "UserProximityEvent",
            "VALIDATE_STATUS",
            "VALIDATION_ERR",
            "VARIABLES_RULE",
            "VENDOR",
            "VERSION",
            "VERSION_CHANGE",
            "VERSION_ERR",
            "VERTEX_ARRAY_BINDING",
            "VERTEX_ATTRIB_ARRAY_BUFFER_BINDING",
            "VERTEX_ATTRIB_ARRAY_DIVISOR",
            "VERTEX_ATTRIB_ARRAY_DIVISOR_ANGLE",
            "VERTEX_ATTRIB_ARRAY_ENABLED",
            "VERTEX_ATTRIB_ARRAY_INTEGER",
            "VERTEX_ATTRIB_ARRAY_NORMALIZED",
            "VERTEX_ATTRIB_ARRAY_POINTER",
            "VERTEX_ATTRIB_ARRAY_SIZE",
            "VERTEX_ATTRIB_ARRAY_STRIDE",
            "VERTEX_ATTRIB_ARRAY_TYPE",
            "VERTEX_SHADER",
            "VERTICAL",
            "VERTICAL_AXIS",
            "VER_ERR",
            "VIEWPORT",
            "VIEWPORT_RULE",
            "VRDisplay",
            "VRDisplayCapabilities",
            "VRDisplayEvent",
            "VREyeParameters",
            "VRFieldOfView",
            "VRFrameData",
            "VRPose",
            "VRStageParameters",
            "VTTCue",
            "VTTRegion",
            "ValidityState",
            "VideoPlaybackQuality",
            "VideoStreamTrack",
            "VisualViewport",
            "WAIT_FAILED",
            "WEBKIT_FILTER_RULE",
            "WEBKIT_KEYFRAMES_RULE",
            "WEBKIT_KEYFRAME_RULE",
            "WEBKIT_REGION_RULE",
            "WRONG_DOCUMENT_ERR",
            "WakeLock",
            "WakeLockSentinel",
            "WasmAnyRef",
            "WaveShaperNode",
            "WeakMap",
            "WeakRef",
            "WeakSet",
            "WebAssembly",
            "WebGL2RenderingContext",
            "WebGLActiveInfo",
            "WebGLBuffer",
            "WebGLContextEvent",
            "WebGLFramebuffer",
            "WebGLProgram",
            "WebGLQuery",
            "WebGLRenderbuffer",
            "WebGLRenderingContext",
            "WebGLSampler",
            "WebGLShader",
            "WebGLShaderPrecisionFormat",
            "WebGLSync",
            "WebGLTexture",
            "WebGLTransformFeedback",
            "WebGLUniformLocation",
            "WebGLVertexArray",
            "WebGLVertexArrayObject",
            "WebKitAnimationEvent",
            "WebKitBlobBuilder",
            "WebKitCSSFilterRule",
            "WebKitCSSFilterValue",
            "WebKitCSSKeyframeRule",
            "WebKitCSSKeyframesRule",
            "WebKitCSSMatrix",
            "WebKitCSSRegionRule",
            "WebKitCSSTransformValue",
            "WebKitDataCue",
            "WebKitGamepad",
            "WebKitMediaKeyError",
            "WebKitMediaKeyMessageEvent",
            "WebKitMediaKeySession",
            "WebKitMediaKeys",
            "WebKitMediaSource",
            "WebKitMutationObserver",
            "WebKitNamespace",
            "WebKitPlaybackTargetAvailabilityEvent",
            "WebKitPoint",
            "WebKitShadowRoot",
            "WebKitSourceBuffer",
            "WebKitSourceBufferList",
            "WebKitTransitionEvent",
            "WebSocket",
            "WebkitAlignContent",
            "WebkitAlignItems",
            "WebkitAlignSelf",
            "WebkitAnimation",
            "WebkitAnimationDelay",
            "WebkitAnimationDirection",
            "WebkitAnimationDuration",
            "WebkitAnimationFillMode",
            "WebkitAnimationIterationCount",
            "WebkitAnimationName",
            "WebkitAnimationPlayState",
            "WebkitAnimationTimingFunction",
            "WebkitAppearance",
            "WebkitBackfaceVisibility",
            "WebkitBackgroundClip",
            "WebkitBackgroundOrigin",
            "WebkitBackgroundSize",
            "WebkitBorderBottomLeftRadius",
            "WebkitBorderBottomRightRadius",
            "WebkitBorderImage",
            "WebkitBorderRadius",
            "WebkitBorderTopLeftRadius",
            "WebkitBorderTopRightRadius",
            "WebkitBoxAlign",
            "WebkitBoxDirection",
            "WebkitBoxFlex",
            "WebkitBoxOrdinalGroup",
            "WebkitBoxOrient",
            "WebkitBoxPack",
            "WebkitBoxShadow",
            "WebkitBoxSizing",
            "WebkitFilter",
            "WebkitFlex",
            "WebkitFlexBasis",
            "WebkitFlexDirection",
            "WebkitFlexFlow",
            "WebkitFlexGrow",
            "WebkitFlexShrink",
            "WebkitFlexWrap",
            "WebkitJustifyContent",
            "WebkitLineClamp",
            "WebkitMask",
            "WebkitMaskClip",
            "WebkitMaskComposite",
            "WebkitMaskImage",
            "WebkitMaskOrigin",
            "WebkitMaskPosition",
            "WebkitMaskPositionX",
            "WebkitMaskPositionY",
            "WebkitMaskRepeat",
            "WebkitMaskSize",
            "WebkitOrder",
            "WebkitPerspective",
            "WebkitPerspectiveOrigin",
            "WebkitTextFillColor",
            "WebkitTextSizeAdjust",
            "WebkitTextStroke",
            "WebkitTextStrokeColor",
            "WebkitTextStrokeWidth",
            "WebkitTransform",
            "WebkitTransformOrigin",
            "WebkitTransformStyle",
            "WebkitTransition",
            "WebkitTransitionDelay",
            "WebkitTransitionDuration",
            "WebkitTransitionProperty",
            "WebkitTransitionTimingFunction",
            "WebkitUserSelect",
            "WheelEvent",
            "Window",
            "Worker",
            "Worklet",
            "WritableStream",
            "WritableStreamDefaultWriter",
            "XMLDocument",
            "XMLHttpRequest",
            "XMLHttpRequestEventTarget",
            "XMLHttpRequestException",
            "XMLHttpRequestProgressEvent",
            "XMLHttpRequestUpload",
            "XMLSerializer",
            "XMLStylesheetProcessingInstruction",
            "XPathEvaluator",
            "XPathException",
            "XPathExpression",
            "XPathNSResolver",
            "XPathResult",
            "XRBoundedReferenceSpace",
            "XRDOMOverlayState",
            "XRFrame",
            "XRHitTestResult",
            "XRHitTestSource",
            "XRInputSource",
            "XRInputSourceArray",
            "XRInputSourceEvent",
            "XRInputSourcesChangeEvent",
            "XRLayer",
            "XRPose",
            "XRRay",
            "XRReferenceSpace",
            "XRReferenceSpaceEvent",
            "XRRenderState",
            "XRRigidTransform",
            "XRSession",
            "XRSessionEvent",
            "XRSpace",
            "XRSystem",
            "XRTransientInputHitTestResult",
            "XRTransientInputHitTestSource",
            "XRView",
            "XRViewerPose",
            "XRViewport",
            "XRWebGLLayer",
            "XSLTProcessor",
            "ZERO",
            "_XD0M_",
            "_YD0M_",
            "__defineGetter__",
            "__defineSetter__",
            "__lookupGetter__",
            "__lookupSetter__",
            "__opera",
            "__proto__",
            "_browserjsran",
            "a",
            "aLink",
            "abbr",
            "abort",
            "aborted",
            "abs",
            "absolute",
            "acceleration",
            "accelerationIncludingGravity",
            "accelerator",
            "accept",
            "acceptCharset",
            "acceptNode",
            "accessKey",
            "accessKeyLabel",
            "accuracy",
            "acos",
            "acosh",
            "action",
            "actionURL",
            "actions",
            "activated",
            "active",
            "activeCues",
            "activeElement",
            "activeSourceBuffers",
            "activeSourceCount",
            "activeTexture",
            "activeVRDisplays",
            "actualBoundingBoxAscent",
            "actualBoundingBoxDescent",
            "actualBoundingBoxLeft",
            "actualBoundingBoxRight",
            "add",
            "addAll",
            "addBehavior",
            "addCandidate",
            "addColorStop",
            "addCue",
            "addElement",
            "addEventListener",
            "addFilter",
            "addFromString",
            "addFromUri",
            "addIceCandidate",
            "addImport",
            "addListener",
            "addModule",
            "addNamed",
            "addPageRule",
            "addPath",
            "addPointer",
            "addRange",
            "addRegion",
            "addRule",
            "addSearchEngine",
            "addSourceBuffer",
            "addStream",
            "addTextTrack",
            "addTrack",
            "addTransceiver",
            "addWakeLockListener",
            "added",
            "addedNodes",
            "additionalName",
            "additiveSymbols",
            "addons",
            "address",
            "addressLine",
            "adoptNode",
            "adoptedStyleSheets",
            "adr",
            "advance",
            "after",
            "album",
            "alert",
            "algorithm",
            "align",
            "align-content",
            "align-items",
            "align-self",
            "alignContent",
            "alignItems",
            "alignSelf",
            "alignmentBaseline",
            "alinkColor",
            "all",
            "allSettled",
            "allow",
            "allowFullscreen",
            "allowPaymentRequest",
            "allowedDirections",
            "allowedFeatures",
            "allowedToPlay",
            "allowsFeature",
            "alpha",
            "alt",
            "altGraphKey",
            "altHtml",
            "altKey",
            "altLeft",
            "alternate",
            "alternateSetting",
            "alternates",
            "altitude",
            "altitudeAccuracy",
            "amplitude",
            "ancestorOrigins",
            "anchor",
            "anchorNode",
            "anchorOffset",
            "anchors",
            "and",
            "angle",
            "angularAcceleration",
            "angularVelocity",
            "animVal",
            "animate",
            "animatedInstanceRoot",
            "animatedNormalizedPathSegList",
            "animatedPathSegList",
            "animatedPoints",
            "animation",
            "animation-delay",
            "animation-direction",
            "animation-duration",
            "animation-fill-mode",
            "animation-iteration-count",
            "animation-name",
            "animation-play-state",
            "animation-timing-function",
            "animationDelay",
            "animationDirection",
            "animationDuration",
            "animationFillMode",
            "animationIterationCount",
            "animationName",
            "animationPlayState",
            "animationStartTime",
            "animationTimingFunction",
            "animationsPaused",
            "anniversary",
            "antialias",
            "anticipatedRemoval",
            "any",
            "app",
            "appCodeName",
            "appMinorVersion",
            "appName",
            "appNotifications",
            "appVersion",
            "appearance",
            "append",
            "appendBuffer",
            "appendChild",
            "appendData",
            "appendItem",
            "appendMedium",
            "appendNamed",
            "appendRule",
            "appendStream",
            "appendWindowEnd",
            "appendWindowStart",
            "applets",
            "applicationCache",
            "applicationServerKey",
            "apply",
            "applyConstraints",
            "applyElement",
            "arc",
            "arcTo",
            "architecture",
            "archive",
            "areas",
            "arguments",
            "ariaAtomic",
            "ariaAutoComplete",
            "ariaBusy",
            "ariaChecked",
            "ariaColCount",
            "ariaColIndex",
            "ariaColSpan",
            "ariaCurrent",
            "ariaDescription",
            "ariaDisabled",
            "ariaExpanded",
            "ariaHasPopup",
            "ariaHidden",
            "ariaKeyShortcuts",
            "ariaLabel",
            "ariaLevel",
            "ariaLive",
            "ariaModal",
            "ariaMultiLine",
            "ariaMultiSelectable",
            "ariaOrientation",
            "ariaPlaceholder",
            "ariaPosInSet",
            "ariaPressed",
            "ariaReadOnly",
            "ariaRelevant",
            "ariaRequired",
            "ariaRoleDescription",
            "ariaRowCount",
            "ariaRowIndex",
            "ariaRowSpan",
            "ariaSelected",
            "ariaSetSize",
            "ariaSort",
            "ariaValueMax",
            "ariaValueMin",
            "ariaValueNow",
            "ariaValueText",
            "arrayBuffer",
            "artist",
            "artwork",
            "as",
            "asIntN",
            "asUintN",
            "asin",
            "asinh",
            "assert",
            "assign",
            "assignedElements",
            "assignedNodes",
            "assignedSlot",
            "async",
            "asyncIterator",
            "atEnd",
            "atan",
            "atan2",
            "atanh",
            "atob",
            "attachEvent",
            "attachInternals",
            "attachShader",
            "attachShadow",
            "attachments",
            "attack",
            "attestationObject",
            "attrChange",
            "attrName",
            "attributeFilter",
            "attributeName",
            "attributeNamespace",
            "attributeOldValue",
            "attributeStyleMap",
            "attributes",
            "attribution",
            "audioBitsPerSecond",
            "audioTracks",
            "audioWorklet",
            "authenticatedSignedWrites",
            "authenticatorData",
            "autoIncrement",
            "autobuffer",
            "autocapitalize",
            "autocomplete",
            "autocorrect",
            "autofocus",
            "automationRate",
            "autoplay",
            "availHeight",
            "availLeft",
            "availTop",
            "availWidth",
            "availability",
            "available",
            "aversion",
            "ax",
            "axes",
            "axis",
            "ay",
            "azimuth",
            "b",
            "back",
            "backface-visibility",
            "backfaceVisibility",
            "background",
            "background-attachment",
            "background-blend-mode",
            "background-clip",
            "background-color",
            "background-image",
            "background-origin",
            "background-position",
            "background-position-x",
            "background-position-y",
            "background-repeat",
            "background-size",
            "backgroundAttachment",
            "backgroundBlendMode",
            "backgroundClip",
            "backgroundColor",
            "backgroundFetch",
            "backgroundImage",
            "backgroundOrigin",
            "backgroundPosition",
            "backgroundPositionX",
            "backgroundPositionY",
            "backgroundRepeat",
            "backgroundSize",
            "badInput",
            "badge",
            "balance",
            "baseFrequencyX",
            "baseFrequencyY",
            "baseLatency",
            "baseLayer",
            "baseNode",
            "baseOffset",
            "baseURI",
            "baseVal",
            "baselineShift",
            "battery",
            "bday",
            "before",
            "beginElement",
            "beginElementAt",
            "beginPath",
            "beginQuery",
            "beginTransformFeedback",
            "behavior",
            "behaviorCookie",
            "behaviorPart",
            "behaviorUrns",
            "beta",
            "bezierCurveTo",
            "bgColor",
            "bgProperties",
            "bias",
            "big",
            "bigint64",
            "biguint64",
            "binaryType",
            "bind",
            "bindAttribLocation",
            "bindBuffer",
            "bindBufferBase",
            "bindBufferRange",
            "bindFramebuffer",
            "bindRenderbuffer",
            "bindSampler",
            "bindTexture",
            "bindTransformFeedback",
            "bindVertexArray",
            "bitness",
            "blendColor",
            "blendEquation",
            "blendEquationSeparate",
            "blendFunc",
            "blendFuncSeparate",
            "blink",
            "blitFramebuffer",
            "blob",
            "block-size",
            "blockDirection",
            "blockSize",
            "blockedURI",
            "blue",
            "bluetooth",
            "blur",
            "body",
            "bodyUsed",
            "bold",
            "bookmarks",
            "booleanValue",
            "border",
            "border-block",
            "border-block-color",
            "border-block-end",
            "border-block-end-color",
            "border-block-end-style",
            "border-block-end-width",
            "border-block-start",
            "border-block-start-color",
            "border-block-start-style",
            "border-block-start-width",
            "border-block-style",
            "border-block-width",
            "border-bottom",
            "border-bottom-color",
            "border-bottom-left-radius",
            "border-bottom-right-radius",
            "border-bottom-style",
            "border-bottom-width",
            "border-collapse",
            "border-color",
            "border-end-end-radius",
            "border-end-start-radius",
            "border-image",
            "border-image-outset",
            "border-image-repeat",
            "border-image-slice",
            "border-image-source",
            "border-image-width",
            "border-inline",
            "border-inline-color",
            "border-inline-end",
            "border-inline-end-color",
            "border-inline-end-style",
            "border-inline-end-width",
            "border-inline-start",
            "border-inline-start-color",
            "border-inline-start-style",
            "border-inline-start-width",
            "border-inline-style",
            "border-inline-width",
            "border-left",
            "border-left-color",
            "border-left-style",
            "border-left-width",
            "border-radius",
            "border-right",
            "border-right-color",
            "border-right-style",
            "border-right-width",
            "border-spacing",
            "border-start-end-radius",
            "border-start-start-radius",
            "border-style",
            "border-top",
            "border-top-color",
            "border-top-left-radius",
            "border-top-right-radius",
            "border-top-style",
            "border-top-width",
            "border-width",
            "borderBlock",
            "borderBlockColor",
            "borderBlockEnd",
            "borderBlockEndColor",
            "borderBlockEndStyle",
            "borderBlockEndWidth",
            "borderBlockStart",
            "borderBlockStartColor",
            "borderBlockStartStyle",
            "borderBlockStartWidth",
            "borderBlockStyle",
            "borderBlockWidth",
            "borderBottom",
            "borderBottomColor",
            "borderBottomLeftRadius",
            "borderBottomRightRadius",
            "borderBottomStyle",
            "borderBottomWidth",
            "borderBoxSize",
            "borderCollapse",
            "borderColor",
            "borderColorDark",
            "borderColorLight",
            "borderEndEndRadius",
            "borderEndStartRadius",
            "borderImage",
            "borderImageOutset",
            "borderImageRepeat",
            "borderImageSlice",
            "borderImageSource",
            "borderImageWidth",
            "borderInline",
            "borderInlineColor",
            "borderInlineEnd",
            "borderInlineEndColor",
            "borderInlineEndStyle",
            "borderInlineEndWidth",
            "borderInlineStart",
            "borderInlineStartColor",
            "borderInlineStartStyle",
            "borderInlineStartWidth",
            "borderInlineStyle",
            "borderInlineWidth",
            "borderLeft",
            "borderLeftColor",
            "borderLeftStyle",
            "borderLeftWidth",
            "borderRadius",
            "borderRight",
            "borderRightColor",
            "borderRightStyle",
            "borderRightWidth",
            "borderSpacing",
            "borderStartEndRadius",
            "borderStartStartRadius",
            "borderStyle",
            "borderTop",
            "borderTopColor",
            "borderTopLeftRadius",
            "borderTopRightRadius",
            "borderTopStyle",
            "borderTopWidth",
            "borderWidth",
            "bottom",
            "bottomMargin",
            "bound",
            "boundElements",
            "boundingClientRect",
            "boundingHeight",
            "boundingLeft",
            "boundingTop",
            "boundingWidth",
            "bounds",
            "boundsGeometry",
            "box-decoration-break",
            "box-shadow",
            "box-sizing",
            "boxDecorationBreak",
            "boxShadow",
            "boxSizing",
            "brand",
            "brands",
            "break-after",
            "break-before",
            "break-inside",
            "breakAfter",
            "breakBefore",
            "breakInside",
            "broadcast",
            "browserLanguage",
            "btoa",
            "bubbles",
            "buffer",
            "bufferData",
            "bufferDepth",
            "bufferSize",
            "bufferSubData",
            "buffered",
            "bufferedAmount",
            "bufferedAmountLowThreshold",
            "buildID",
            "buildNumber",
            "button",
            "buttonID",
            "buttons",
            "byteLength",
            "byteOffset",
            "bytesWritten",
            "c",
            "cache",
            "caches",
            "call",
            "caller",
            "canBeFormatted",
            "canBeMounted",
            "canBeShared",
            "canHaveChildren",
            "canHaveHTML",
            "canInsertDTMF",
            "canMakePayment",
            "canPlayType",
            "canPresent",
            "canTrickleIceCandidates",
            "cancel",
            "cancelAndHoldAtTime",
            "cancelAnimationFrame",
            "cancelBubble",
            "cancelIdleCallback",
            "cancelScheduledValues",
            "cancelVideoFrameCallback",
            "cancelWatchAvailability",
            "cancelable",
            "candidate",
            "canonicalUUID",
            "canvas",
            "capabilities",
            "caption",
            "caption-side",
            "captionSide",
            "capture",
            "captureEvents",
            "captureStackTrace",
            "captureStream",
            "caret-color",
            "caretBidiLevel",
            "caretColor",
            "caretPositionFromPoint",
            "caretRangeFromPoint",
            "cast",
            "catch",
            "category",
            "cbrt",
            "cd",
            "ceil",
            "cellIndex",
            "cellPadding",
            "cellSpacing",
            "cells",
            "ch",
            "chOff",
            "chain",
            "challenge",
            "changeType",
            "changedTouches",
            "channel",
            "channelCount",
            "channelCountMode",
            "channelInterpretation",
            "char",
            "charAt",
            "charCode",
            "charCodeAt",
            "charIndex",
            "charLength",
            "characterData",
            "characterDataOldValue",
            "characterSet",
            "characteristic",
            "charging",
            "chargingTime",
            "charset",
            "check",
            "checkEnclosure",
            "checkFramebufferStatus",
            "checkIntersection",
            "checkValidity",
            "checked",
            "childElementCount",
            "childList",
            "childNodes",
            "children",
            "chrome",
            "ciphertext",
            "cite",
            "city",
            "claimInterface",
            "claimed",
            "classList",
            "className",
            "classid",
            "clear",
            "clearAppBadge",
            "clearAttributes",
            "clearBufferfi",
            "clearBufferfv",
            "clearBufferiv",
            "clearBufferuiv",
            "clearColor",
            "clearData",
            "clearDepth",
            "clearHalt",
            "clearImmediate",
            "clearInterval",
            "clearLiveSeekableRange",
            "clearMarks",
            "clearMaxGCPauseAccumulator",
            "clearMeasures",
            "clearParameters",
            "clearRect",
            "clearResourceTimings",
            "clearShadow",
            "clearStencil",
            "clearTimeout",
            "clearWatch",
            "click",
            "clickCount",
            "clientDataJSON",
            "clientHeight",
            "clientInformation",
            "clientLeft",
            "clientRect",
            "clientRects",
            "clientTop",
            "clientWaitSync",
            "clientWidth",
            "clientX",
            "clientY",
            "clip",
            "clip-path",
            "clip-rule",
            "clipBottom",
            "clipLeft",
            "clipPath",
            "clipPathUnits",
            "clipRight",
            "clipRule",
            "clipTop",
            "clipboard",
            "clipboardData",
            "clone",
            "cloneContents",
            "cloneNode",
            "cloneRange",
            "close",
            "closePath",
            "closed",
            "closest",
            "clz",
            "clz32",
            "cm",
            "cmp",
            "code",
            "codeBase",
            "codePointAt",
            "codeType",
            "colSpan",
            "collapse",
            "collapseToEnd",
            "collapseToStart",
            "collapsed",
            "collect",
            "colno",
            "color",
            "color-adjust",
            "color-interpolation",
            "color-interpolation-filters",
            "colorAdjust",
            "colorDepth",
            "colorInterpolation",
            "colorInterpolationFilters",
            "colorMask",
            "colorType",
            "cols",
            "column-count",
            "column-fill",
            "column-gap",
            "column-rule",
            "column-rule-color",
            "column-rule-style",
            "column-rule-width",
            "column-span",
            "column-width",
            "columnCount",
            "columnFill",
            "columnGap",
            "columnNumber",
            "columnRule",
            "columnRuleColor",
            "columnRuleStyle",
            "columnRuleWidth",
            "columnSpan",
            "columnWidth",
            "columns",
            "command",
            "commit",
            "commitPreferences",
            "commitStyles",
            "commonAncestorContainer",
            "compact",
            "compareBoundaryPoints",
            "compareDocumentPosition",
            "compareEndPoints",
            "compareExchange",
            "compareNode",
            "comparePoint",
            "compatMode",
            "compatible",
            "compile",
            "compileShader",
            "compileStreaming",
            "complete",
            "component",
            "componentFromPoint",
            "composed",
            "composedPath",
            "composite",
            "compositionEndOffset",
            "compositionStartOffset",
            "compressedTexImage2D",
            "compressedTexImage3D",
            "compressedTexSubImage2D",
            "compressedTexSubImage3D",
            "computedStyleMap",
            "concat",
            "conditionText",
            "coneInnerAngle",
            "coneOuterAngle",
            "coneOuterGain",
            "configuration",
            "configurationName",
            "configurationValue",
            "configurations",
            "confirm",
            "confirmComposition",
            "confirmSiteSpecificTrackingException",
            "confirmWebWideTrackingException",
            "connect",
            "connectEnd",
            "connectShark",
            "connectStart",
            "connected",
            "connection",
            "connectionList",
            "connectionSpeed",
            "connectionState",
            "connections",
            "console",
            "consolidate",
            "constraint",
            "constrictionActive",
            "construct",
            "constructor",
            "contactID",
            "contain",
            "containerId",
            "containerName",
            "containerSrc",
            "containerType",
            "contains",
            "containsNode",
            "content",
            "contentBoxSize",
            "contentDocument",
            "contentEditable",
            "contentHint",
            "contentOverflow",
            "contentRect",
            "contentScriptType",
            "contentStyleType",
            "contentType",
            "contentWindow",
            "context",
            "contextMenu",
            "contextmenu",
            "continue",
            "continuePrimaryKey",
            "continuous",
            "control",
            "controlTransferIn",
            "controlTransferOut",
            "controller",
            "controls",
            "controlsList",
            "convertPointFromNode",
            "convertQuadFromNode",
            "convertRectFromNode",
            "convertToBlob",
            "convertToSpecifiedUnits",
            "cookie",
            "cookieEnabled",
            "coords",
            "copyBufferSubData",
            "copyFromChannel",
            "copyTexImage2D",
            "copyTexSubImage2D",
            "copyTexSubImage3D",
            "copyToChannel",
            "copyWithin",
            "correspondingElement",
            "correspondingUseElement",
            "corruptedVideoFrames",
            "cos",
            "cosh",
            "count",
            "countReset",
            "counter-increment",
            "counter-reset",
            "counter-set",
            "counterIncrement",
            "counterReset",
            "counterSet",
            "country",
            "cpuClass",
            "cpuSleepAllowed",
            "create",
            "createAnalyser",
            "createAnswer",
            "createAttribute",
            "createAttributeNS",
            "createBiquadFilter",
            "createBuffer",
            "createBufferSource",
            "createCDATASection",
            "createCSSStyleSheet",
            "createCaption",
            "createChannelMerger",
            "createChannelSplitter",
            "createComment",
            "createConstantSource",
            "createContextualFragment",
            "createControlRange",
            "createConvolver",
            "createDTMFSender",
            "createDataChannel",
            "createDelay",
            "createDelayNode",
            "createDocument",
            "createDocumentFragment",
            "createDocumentType",
            "createDynamicsCompressor",
            "createElement",
            "createElementNS",
            "createEntityReference",
            "createEvent",
            "createEventObject",
            "createExpression",
            "createFramebuffer",
            "createFunction",
            "createGain",
            "createGainNode",
            "createHTML",
            "createHTMLDocument",
            "createIIRFilter",
            "createImageBitmap",
            "createImageData",
            "createIndex",
            "createJavaScriptNode",
            "createLinearGradient",
            "createMediaElementSource",
            "createMediaKeys",
            "createMediaStreamDestination",
            "createMediaStreamSource",
            "createMediaStreamTrackSource",
            "createMutableFile",
            "createNSResolver",
            "createNodeIterator",
            "createNotification",
            "createObjectStore",
            "createObjectURL",
            "createOffer",
            "createOscillator",
            "createPanner",
            "createPattern",
            "createPeriodicWave",
            "createPolicy",
            "createPopup",
            "createProcessingInstruction",
            "createProgram",
            "createQuery",
            "createRadialGradient",
            "createRange",
            "createRangeCollection",
            "createReader",
            "createRenderbuffer",
            "createSVGAngle",
            "createSVGLength",
            "createSVGMatrix",
            "createSVGNumber",
            "createSVGPathSegArcAbs",
            "createSVGPathSegArcRel",
            "createSVGPathSegClosePath",
            "createSVGPathSegCurvetoCubicAbs",
            "createSVGPathSegCurvetoCubicRel",
            "createSVGPathSegCurvetoCubicSmoothAbs",
            "createSVGPathSegCurvetoCubicSmoothRel",
            "createSVGPathSegCurvetoQuadraticAbs",
            "createSVGPathSegCurvetoQuadraticRel",
            "createSVGPathSegCurvetoQuadraticSmoothAbs",
            "createSVGPathSegCurvetoQuadraticSmoothRel",
            "createSVGPathSegLinetoAbs",
            "createSVGPathSegLinetoHorizontalAbs",
            "createSVGPathSegLinetoHorizontalRel",
            "createSVGPathSegLinetoRel",
            "createSVGPathSegLinetoVerticalAbs",
            "createSVGPathSegLinetoVerticalRel",
            "createSVGPathSegMovetoAbs",
            "createSVGPathSegMovetoRel",
            "createSVGPoint",
            "createSVGRect",
            "createSVGTransform",
            "createSVGTransformFromMatrix",
            "createSampler",
            "createScript",
            "createScriptProcessor",
            "createScriptURL",
            "createSession",
            "createShader",
            "createShadowRoot",
            "createStereoPanner",
            "createStyleSheet",
            "createTBody",
            "createTFoot",
            "createTHead",
            "createTextNode",
            "createTextRange",
            "createTexture",
            "createTouch",
            "createTouchList",
            "createTransformFeedback",
            "createTreeWalker",
            "createVertexArray",
            "createWaveShaper",
            "creationTime",
            "credentials",
            "crossOrigin",
            "crossOriginIsolated",
            "crypto",
            "csi",
            "csp",
            "cssFloat",
            "cssRules",
            "cssText",
            "cssValueType",
            "ctrlKey",
            "ctrlLeft",
            "cues",
            "cullFace",
            "currentDirection",
            "currentLocalDescription",
            "currentNode",
            "currentPage",
            "currentRect",
            "currentRemoteDescription",
            "currentScale",
            "currentScript",
            "currentSrc",
            "currentState",
            "currentStyle",
            "currentTarget",
            "currentTime",
            "currentTranslate",
            "currentView",
            "cursor",
            "curve",
            "customElements",
            "customError",
            "cx",
            "cy",
            "d",
            "data",
            "dataFld",
            "dataFormatAs",
            "dataLoss",
            "dataLossMessage",
            "dataPageSize",
            "dataSrc",
            "dataTransfer",
            "database",
            "databases",
            "dataset",
            "dateTime",
            "db",
            "debug",
            "debuggerEnabled",
            "declare",
            "decode",
            "decodeAudioData",
            "decodeURI",
            "decodeURIComponent",
            "decodedBodySize",
            "decoding",
            "decodingInfo",
            "decrypt",
            "default",
            "defaultCharset",
            "defaultChecked",
            "defaultMuted",
            "defaultPlaybackRate",
            "defaultPolicy",
            "defaultPrevented",
            "defaultRequest",
            "defaultSelected",
            "defaultStatus",
            "defaultURL",
            "defaultValue",
            "defaultView",
            "defaultstatus",
            "defer",
            "define",
            "defineMagicFunction",
            "defineMagicVariable",
            "defineProperties",
            "defineProperty",
            "deg",
            "delay",
            "delayTime",
            "delegatesFocus",
            "delete",
            "deleteBuffer",
            "deleteCaption",
            "deleteCell",
            "deleteContents",
            "deleteData",
            "deleteDatabase",
            "deleteFramebuffer",
            "deleteFromDocument",
            "deleteIndex",
            "deleteMedium",
            "deleteObjectStore",
            "deleteProgram",
            "deleteProperty",
            "deleteQuery",
            "deleteRenderbuffer",
            "deleteRow",
            "deleteRule",
            "deleteSampler",
            "deleteShader",
            "deleteSync",
            "deleteTFoot",
            "deleteTHead",
            "deleteTexture",
            "deleteTransformFeedback",
            "deleteVertexArray",
            "deliverChangeRecords",
            "delivery",
            "deliveryInfo",
            "deliveryStatus",
            "deliveryTimestamp",
            "delta",
            "deltaMode",
            "deltaX",
            "deltaY",
            "deltaZ",
            "dependentLocality",
            "depthFar",
            "depthFunc",
            "depthMask",
            "depthNear",
            "depthRange",
            "deref",
            "deriveBits",
            "deriveKey",
            "description",
            "deselectAll",
            "designMode",
            "desiredSize",
            "destination",
            "destinationURL",
            "detach",
            "detachEvent",
            "detachShader",
            "detail",
            "details",
            "detect",
            "detune",
            "device",
            "deviceClass",
            "deviceId",
            "deviceMemory",
            "devicePixelContentBoxSize",
            "devicePixelRatio",
            "deviceProtocol",
            "deviceSubclass",
            "deviceVersionMajor",
            "deviceVersionMinor",
            "deviceVersionSubminor",
            "deviceXDPI",
            "deviceYDPI",
            "didTimeout",
            "diffuseConstant",
            "digest",
            "dimensions",
            "dir",
            "dirName",
            "direction",
            "dirxml",
            "disable",
            "disablePictureInPicture",
            "disableRemotePlayback",
            "disableVertexAttribArray",
            "disabled",
            "dischargingTime",
            "disconnect",
            "disconnectShark",
            "dispatchEvent",
            "display",
            "displayId",
            "displayName",
            "disposition",
            "distanceModel",
            "div",
            "divisor",
            "djsapi",
            "djsproxy",
            "doImport",
            "doNotTrack",
            "doScroll",
            "doctype",
            "document",
            "documentElement",
            "documentMode",
            "documentURI",
            "dolphin",
            "dolphinGameCenter",
            "dolphininfo",
            "dolphinmeta",
            "domComplete",
            "domContentLoadedEventEnd",
            "domContentLoadedEventStart",
            "domInteractive",
            "domLoading",
            "domOverlayState",
            "domain",
            "domainLookupEnd",
            "domainLookupStart",
            "dominant-baseline",
            "dominantBaseline",
            "done",
            "dopplerFactor",
            "dotAll",
            "downDegrees",
            "downlink",
            "download",
            "downloadTotal",
            "downloaded",
            "dpcm",
            "dpi",
            "dppx",
            "dragDrop",
            "draggable",
            "drawArrays",
            "drawArraysInstanced",
            "drawArraysInstancedANGLE",
            "drawBuffers",
            "drawCustomFocusRing",
            "drawElements",
            "drawElementsInstanced",
            "drawElementsInstancedANGLE",
            "drawFocusIfNeeded",
            "drawImage",
            "drawImageFromRect",
            "drawRangeElements",
            "drawSystemFocusRing",
            "drawingBufferHeight",
            "drawingBufferWidth",
            "dropEffect",
            "droppedVideoFrames",
            "dropzone",
            "dtmf",
            "dump",
            "dumpProfile",
            "duplicate",
            "durability",
            "duration",
            "dvname",
            "dvnum",
            "dx",
            "dy",
            "dynsrc",
            "e",
            "edgeMode",
            "effect",
            "effectAllowed",
            "effectiveDirective",
            "effectiveType",
            "elapsedTime",
            "element",
            "elementFromPoint",
            "elementTiming",
            "elements",
            "elementsFromPoint",
            "elevation",
            "ellipse",
            "em",
            "email",
            "embeds",
            "emma",
            "empty",
            "empty-cells",
            "emptyCells",
            "emptyHTML",
            "emptyScript",
            "emulatedPosition",
            "enable",
            "enableBackground",
            "enableDelegations",
            "enableStyleSheetsForSet",
            "enableVertexAttribArray",
            "enabled",
            "enabledPlugin",
            "encode",
            "encodeInto",
            "encodeURI",
            "encodeURIComponent",
            "encodedBodySize",
            "encoding",
            "encodingInfo",
            "encrypt",
            "enctype",
            "end",
            "endContainer",
            "endElement",
            "endElementAt",
            "endOfStream",
            "endOffset",
            "endQuery",
            "endTime",
            "endTransformFeedback",
            "ended",
            "endpoint",
            "endpointNumber",
            "endpoints",
            "endsWith",
            "enterKeyHint",
            "entities",
            "entries",
            "entryType",
            "enumerate",
            "enumerateDevices",
            "enumerateEditable",
            "environmentBlendMode",
            "equals",
            "error",
            "errorCode",
            "errorDetail",
            "errorText",
            "escape",
            "estimate",
            "eval",
            "evaluate",
            "event",
            "eventPhase",
            "every",
            "ex",
            "exception",
            "exchange",
            "exec",
            "execCommand",
            "execCommandShowHelp",
            "execScript",
            "exitFullscreen",
            "exitPictureInPicture",
            "exitPointerLock",
            "exitPresent",
            "exp",
            "expand",
            "expandEntityReferences",
            "expando",
            "expansion",
            "expiration",
            "expirationTime",
            "expires",
            "expiryDate",
            "explicitOriginalTarget",
            "expm1",
            "exponent",
            "exponentialRampToValueAtTime",
            "exportKey",
            "exports",
            "extend",
            "extensions",
            "extentNode",
            "extentOffset",
            "external",
            "externalResourcesRequired",
            "extractContents",
            "extractable",
            "eye",
            "f",
            "face",
            "factoryReset",
            "failureReason",
            "fallback",
            "family",
            "familyName",
            "farthestViewportElement",
            "fastSeek",
            "fatal",
            "featureId",
            "featurePolicy",
            "featureSettings",
            "features",
            "fenceSync",
            "fetch",
            "fetchStart",
            "fftSize",
            "fgColor",
            "fieldOfView",
            "file",
            "fileCreatedDate",
            "fileHandle",
            "fileModifiedDate",
            "fileName",
            "fileSize",
            "fileUpdatedDate",
            "filename",
            "files",
            "filesystem",
            "fill",
            "fill-opacity",
            "fill-rule",
            "fillLightMode",
            "fillOpacity",
            "fillRect",
            "fillRule",
            "fillStyle",
            "fillText",
            "filter",
            "filterResX",
            "filterResY",
            "filterUnits",
            "filters",
            "finally",
            "find",
            "findIndex",
            "findRule",
            "findText",
            "finish",
            "finished",
            "fireEvent",
            "firesTouchEvents",
            "firstChild",
            "firstElementChild",
            "firstPage",
            "fixed",
            "flags",
            "flat",
            "flatMap",
            "flex",
            "flex-basis",
            "flex-direction",
            "flex-flow",
            "flex-grow",
            "flex-shrink",
            "flex-wrap",
            "flexBasis",
            "flexDirection",
            "flexFlow",
            "flexGrow",
            "flexShrink",
            "flexWrap",
            "flipX",
            "flipY",
            "float",
            "float32",
            "float64",
            "flood-color",
            "flood-opacity",
            "floodColor",
            "floodOpacity",
            "floor",
            "flush",
            "focus",
            "focusNode",
            "focusOffset",
            "font",
            "font-family",
            "font-feature-settings",
            "font-kerning",
            "font-language-override",
            "font-optical-sizing",
            "font-size",
            "font-size-adjust",
            "font-stretch",
            "font-style",
            "font-synthesis",
            "font-variant",
            "font-variant-alternates",
            "font-variant-caps",
            "font-variant-east-asian",
            "font-variant-ligatures",
            "font-variant-numeric",
            "font-variant-position",
            "font-variation-settings",
            "font-weight",
            "fontFamily",
            "fontFeatureSettings",
            "fontKerning",
            "fontLanguageOverride",
            "fontOpticalSizing",
            "fontSize",
            "fontSizeAdjust",
            "fontSmoothingEnabled",
            "fontStretch",
            "fontStyle",
            "fontSynthesis",
            "fontVariant",
            "fontVariantAlternates",
            "fontVariantCaps",
            "fontVariantEastAsian",
            "fontVariantLigatures",
            "fontVariantNumeric",
            "fontVariantPosition",
            "fontVariationSettings",
            "fontWeight",
            "fontcolor",
            "fontfaces",
            "fonts",
            "fontsize",
            "for",
            "forEach",
            "force",
            "forceRedraw",
            "form",
            "formAction",
            "formData",
            "formEnctype",
            "formMethod",
            "formNoValidate",
            "formTarget",
            "format",
            "formatToParts",
            "forms",
            "forward",
            "forwardX",
            "forwardY",
            "forwardZ",
            "foundation",
            "fr",
            "fragmentDirective",
            "frame",
            "frameBorder",
            "frameElement",
            "frameSpacing",
            "framebuffer",
            "framebufferHeight",
            "framebufferRenderbuffer",
            "framebufferTexture2D",
            "framebufferTextureLayer",
            "framebufferWidth",
            "frames",
            "freeSpace",
            "freeze",
            "frequency",
            "frequencyBinCount",
            "from",
            "fromCharCode",
            "fromCodePoint",
            "fromElement",
            "fromEntries",
            "fromFloat32Array",
            "fromFloat64Array",
            "fromMatrix",
            "fromPoint",
            "fromQuad",
            "fromRect",
            "frontFace",
            "fround",
            "fullPath",
            "fullScreen",
            "fullVersionList",
            "fullscreen",
            "fullscreenElement",
            "fullscreenEnabled",
            "fx",
            "fy",
            "gain",
            "gamepad",
            "gamma",
            "gap",
            "gatheringState",
            "gatt",
            "genderIdentity",
            "generateCertificate",
            "generateKey",
            "generateMipmap",
            "generateRequest",
            "geolocation",
            "gestureObject",
            "get",
            "getActiveAttrib",
            "getActiveUniform",
            "getActiveUniformBlockName",
            "getActiveUniformBlockParameter",
            "getActiveUniforms",
            "getAdjacentText",
            "getAll",
            "getAllKeys",
            "getAllResponseHeaders",
            "getAllowlistForFeature",
            "getAnimations",
            "getAsFile",
            "getAsString",
            "getAttachedShaders",
            "getAttribLocation",
            "getAttribute",
            "getAttributeNS",
            "getAttributeNames",
            "getAttributeNode",
            "getAttributeNodeNS",
            "getAttributeType",
            "getAudioTracks",
            "getAvailability",
            "getBBox",
            "getBattery",
            "getBigInt64",
            "getBigUint64",
            "getBlob",
            "getBookmark",
            "getBoundingClientRect",
            "getBounds",
            "getBoxQuads",
            "getBufferParameter",
            "getBufferSubData",
            "getByteFrequencyData",
            "getByteTimeDomainData",
            "getCSSCanvasContext",
            "getCTM",
            "getCandidateWindowClientRect",
            "getCanonicalLocales",
            "getCapabilities",
            "getChannelData",
            "getCharNumAtPosition",
            "getCharacteristic",
            "getCharacteristics",
            "getClientExtensionResults",
            "getClientRect",
            "getClientRects",
            "getCoalescedEvents",
            "getCompositionAlternatives",
            "getComputedStyle",
            "getComputedTextLength",
            "getComputedTiming",
            "getConfiguration",
            "getConstraints",
            "getContext",
            "getContextAttributes",
            "getContributingSources",
            "getCounterValue",
            "getCueAsHTML",
            "getCueById",
            "getCurrentPosition",
            "getCurrentTime",
            "getData",
            "getDatabaseNames",
            "getDate",
            "getDay",
            "getDefaultComputedStyle",
            "getDescriptor",
            "getDescriptors",
            "getDestinationInsertionPoints",
            "getDevices",
            "getDirectory",
            "getDisplayMedia",
            "getDistributedNodes",
            "getEditable",
            "getElementById",
            "getElementsByClassName",
            "getElementsByName",
            "getElementsByTagName",
            "getElementsByTagNameNS",
            "getEnclosureList",
            "getEndPositionOfChar",
            "getEntries",
            "getEntriesByName",
            "getEntriesByType",
            "getError",
            "getExtension",
            "getExtentOfChar",
            "getEyeParameters",
            "getFeature",
            "getFile",
            "getFiles",
            "getFilesAndDirectories",
            "getFingerprints",
            "getFloat32",
            "getFloat64",
            "getFloatFrequencyData",
            "getFloatTimeDomainData",
            "getFloatValue",
            "getFragDataLocation",
            "getFrameData",
            "getFramebufferAttachmentParameter",
            "getFrequencyResponse",
            "getFullYear",
            "getGamepads",
            "getHighEntropyValues",
            "getHitTestResults",
            "getHitTestResultsForTransientInput",
            "getHours",
            "getIdentityAssertion",
            "getIds",
            "getImageData",
            "getIndexedParameter",
            "getInstalledRelatedApps",
            "getInt16",
            "getInt32",
            "getInt8",
            "getInternalformatParameter",
            "getIntersectionList",
            "getItem",
            "getItems",
            "getKey",
            "getKeyframes",
            "getLayers",
            "getLayoutMap",
            "getLineDash",
            "getLocalCandidates",
            "getLocalParameters",
            "getLocalStreams",
            "getMarks",
            "getMatchedCSSRules",
            "getMaxGCPauseSinceClear",
            "getMeasures",
            "getMetadata",
            "getMilliseconds",
            "getMinutes",
            "getModifierState",
            "getMonth",
            "getNamedItem",
            "getNamedItemNS",
            "getNativeFramebufferScaleFactor",
            "getNotifications",
            "getNotifier",
            "getNumberOfChars",
            "getOffsetReferenceSpace",
            "getOutputTimestamp",
            "getOverrideHistoryNavigationMode",
            "getOverrideStyle",
            "getOwnPropertyDescriptor",
            "getOwnPropertyDescriptors",
            "getOwnPropertyNames",
            "getOwnPropertySymbols",
            "getParameter",
            "getParameters",
            "getParent",
            "getPathSegAtLength",
            "getPhotoCapabilities",
            "getPhotoSettings",
            "getPointAtLength",
            "getPose",
            "getPredictedEvents",
            "getPreference",
            "getPreferenceDefault",
            "getPresentationAttribute",
            "getPreventDefault",
            "getPrimaryService",
            "getPrimaryServices",
            "getProgramInfoLog",
            "getProgramParameter",
            "getPropertyCSSValue",
            "getPropertyPriority",
            "getPropertyShorthand",
            "getPropertyType",
            "getPropertyValue",
            "getPrototypeOf",
            "getQuery",
            "getQueryParameter",
            "getRGBColorValue",
            "getRandomValues",
            "getRangeAt",
            "getReader",
            "getReceivers",
            "getRectValue",
            "getRegistration",
            "getRegistrations",
            "getRemoteCandidates",
            "getRemoteCertificates",
            "getRemoteParameters",
            "getRemoteStreams",
            "getRenderbufferParameter",
            "getResponseHeader",
            "getRoot",
            "getRootNode",
            "getRotationOfChar",
            "getSVGDocument",
            "getSamplerParameter",
            "getScreenCTM",
            "getSeconds",
            "getSelectedCandidatePair",
            "getSelection",
            "getSenders",
            "getService",
            "getSettings",
            "getShaderInfoLog",
            "getShaderParameter",
            "getShaderPrecisionFormat",
            "getShaderSource",
            "getSimpleDuration",
            "getSiteIcons",
            "getSources",
            "getSpeculativeParserUrls",
            "getStartPositionOfChar",
            "getStartTime",
            "getState",
            "getStats",
            "getStatusForPolicy",
            "getStorageUpdates",
            "getStreamById",
            "getStringValue",
            "getSubStringLength",
            "getSubscription",
            "getSupportedConstraints",
            "getSupportedExtensions",
            "getSupportedFormats",
            "getSyncParameter",
            "getSynchronizationSources",
            "getTags",
            "getTargetRanges",
            "getTexParameter",
            "getTime",
            "getTimezoneOffset",
            "getTiming",
            "getTotalLength",
            "getTrackById",
            "getTracks",
            "getTransceivers",
            "getTransform",
            "getTransformFeedbackVarying",
            "getTransformToElement",
            "getTransports",
            "getType",
            "getTypeMapping",
            "getUTCDate",
            "getUTCDay",
            "getUTCFullYear",
            "getUTCHours",
            "getUTCMilliseconds",
            "getUTCMinutes",
            "getUTCMonth",
            "getUTCSeconds",
            "getUint16",
            "getUint32",
            "getUint8",
            "getUniform",
            "getUniformBlockIndex",
            "getUniformIndices",
            "getUniformLocation",
            "getUserMedia",
            "getVRDisplays",
            "getValues",
            "getVarDate",
            "getVariableValue",
            "getVertexAttrib",
            "getVertexAttribOffset",
            "getVideoPlaybackQuality",
            "getVideoTracks",
            "getViewerPose",
            "getViewport",
            "getVoices",
            "getWakeLockState",
            "getWriter",
            "getYear",
            "givenName",
            "global",
            "globalAlpha",
            "globalCompositeOperation",
            "globalThis",
            "glyphOrientationHorizontal",
            "glyphOrientationVertical",
            "glyphRef",
            "go",
            "grabFrame",
            "grad",
            "gradientTransform",
            "gradientUnits",
            "grammars",
            "green",
            "grid",
            "grid-area",
            "grid-auto-columns",
            "grid-auto-flow",
            "grid-auto-rows",
            "grid-column",
            "grid-column-end",
            "grid-column-gap",
            "grid-column-start",
            "grid-gap",
            "grid-row",
            "grid-row-end",
            "grid-row-gap",
            "grid-row-start",
            "grid-template",
            "grid-template-areas",
            "grid-template-columns",
            "grid-template-rows",
            "gridArea",
            "gridAutoColumns",
            "gridAutoFlow",
            "gridAutoRows",
            "gridColumn",
            "gridColumnEnd",
            "gridColumnGap",
            "gridColumnStart",
            "gridGap",
            "gridRow",
            "gridRowEnd",
            "gridRowGap",
            "gridRowStart",
            "gridTemplate",
            "gridTemplateAreas",
            "gridTemplateColumns",
            "gridTemplateRows",
            "gripSpace",
            "group",
            "groupCollapsed",
            "groupEnd",
            "groupId",
            "hadRecentInput",
            "hand",
            "handedness",
            "hapticActuators",
            "hardwareConcurrency",
            "has",
            "hasAttribute",
            "hasAttributeNS",
            "hasAttributes",
            "hasBeenActive",
            "hasChildNodes",
            "hasComposition",
            "hasEnrolledInstrument",
            "hasExtension",
            "hasExternalDisplay",
            "hasFeature",
            "hasFocus",
            "hasInstance",
            "hasLayout",
            "hasOrientation",
            "hasOwnProperty",
            "hasPointerCapture",
            "hasPosition",
            "hasReading",
            "hasStorageAccess",
            "hash",
            "head",
            "headers",
            "heading",
            "height",
            "hidden",
            "hide",
            "hideFocus",
            "high",
            "highWaterMark",
            "hint",
            "history",
            "honorificPrefix",
            "honorificSuffix",
            "horizontalOverflow",
            "host",
            "hostCandidate",
            "hostname",
            "href",
            "hrefTranslate",
            "hreflang",
            "hspace",
            "html5TagCheckInerface",
            "htmlFor",
            "htmlText",
            "httpEquiv",
            "httpRequestStatusCode",
            "hwTimestamp",
            "hyphens",
            "hypot",
            "iccId",
            "iceConnectionState",
            "iceGatheringState",
            "iceTransport",
            "icon",
            "iconURL",
            "id",
            "identifier",
            "identity",
            "idpLoginUrl",
            "ignoreBOM",
            "ignoreCase",
            "ignoreDepthValues",
            "image-orientation",
            "image-rendering",
            "imageHeight",
            "imageOrientation",
            "imageRendering",
            "imageSizes",
            "imageSmoothingEnabled",
            "imageSmoothingQuality",
            "imageSrcset",
            "imageWidth",
            "images",
            "ime-mode",
            "imeMode",
            "implementation",
            "importKey",
            "importNode",
            "importStylesheet",
            "imports",
            "impp",
            "imul",
            "in",
            "in1",
            "in2",
            "inBandMetadataTrackDispatchType",
            "inRange",
            "includes",
            "incremental",
            "indeterminate",
            "index",
            "indexNames",
            "indexOf",
            "indexedDB",
            "indicate",
            "inertiaDestinationX",
            "inertiaDestinationY",
            "info",
            "init",
            "initAnimationEvent",
            "initBeforeLoadEvent",
            "initClipboardEvent",
            "initCloseEvent",
            "initCommandEvent",
            "initCompositionEvent",
            "initCustomEvent",
            "initData",
            "initDataType",
            "initDeviceMotionEvent",
            "initDeviceOrientationEvent",
            "initDragEvent",
            "initErrorEvent",
            "initEvent",
            "initFocusEvent",
            "initGestureEvent",
            "initHashChangeEvent",
            "initKeyEvent",
            "initKeyboardEvent",
            "initMSManipulationEvent",
            "initMessageEvent",
            "initMouseEvent",
            "initMouseScrollEvent",
            "initMouseWheelEvent",
            "initMutationEvent",
            "initNSMouseEvent",
            "initOverflowEvent",
            "initPageEvent",
            "initPageTransitionEvent",
            "initPointerEvent",
            "initPopStateEvent",
            "initProgressEvent",
            "initScrollAreaEvent",
            "initSimpleGestureEvent",
            "initStorageEvent",
            "initTextEvent",
            "initTimeEvent",
            "initTouchEvent",
            "initTransitionEvent",
            "initUIEvent",
            "initWebKitAnimationEvent",
            "initWebKitTransitionEvent",
            "initWebKitWheelEvent",
            "initWheelEvent",
            "initialTime",
            "initialize",
            "initiatorType",
            "inline-size",
            "inlineSize",
            "inlineVerticalFieldOfView",
            "inner",
            "innerHTML",
            "innerHeight",
            "innerText",
            "innerWidth",
            "input",
            "inputBuffer",
            "inputEncoding",
            "inputMethod",
            "inputMode",
            "inputSource",
            "inputSources",
            "inputType",
            "inputs",
            "insertAdjacentElement",
            "insertAdjacentHTML",
            "insertAdjacentText",
            "insertBefore",
            "insertCell",
            "insertDTMF",
            "insertData",
            "insertItemBefore",
            "insertNode",
            "insertRow",
            "insertRule",
            "inset",
            "inset-block",
            "inset-block-end",
            "inset-block-start",
            "inset-inline",
            "inset-inline-end",
            "inset-inline-start",
            "insetBlock",
            "insetBlockEnd",
            "insetBlockStart",
            "insetInline",
            "insetInlineEnd",
            "insetInlineStart",
            "installing",
            "instanceRoot",
            "instantiate",
            "instantiateStreaming",
            "instruments",
            "int16",
            "int32",
            "int8",
            "integrity",
            "interactionMode",
            "intercept",
            "interfaceClass",
            "interfaceName",
            "interfaceNumber",
            "interfaceProtocol",
            "interfaceSubclass",
            "interfaces",
            "interimResults",
            "internalSubset",
            "interpretation",
            "intersectionRatio",
            "intersectionRect",
            "intersectsNode",
            "interval",
            "invalidIteratorState",
            "invalidateFramebuffer",
            "invalidateSubFramebuffer",
            "inverse",
            "invertSelf",
            "is",
            "is2D",
            "isActive",
            "isAlternate",
            "isArray",
            "isBingCurrentSearchDefault",
            "isBuffer",
            "isCandidateWindowVisible",
            "isChar",
            "isCollapsed",
            "isComposing",
            "isConcatSpreadable",
            "isConnected",
            "isContentEditable",
            "isContentHandlerRegistered",
            "isContextLost",
            "isDefaultNamespace",
            "isDirectory",
            "isDisabled",
            "isEnabled",
            "isEqual",
            "isEqualNode",
            "isExtensible",
            "isExternalCTAP2SecurityKeySupported",
            "isFile",
            "isFinite",
            "isFramebuffer",
            "isFrozen",
            "isGenerator",
            "isHTML",
            "isHistoryNavigation",
            "isId",
            "isIdentity",
            "isInjected",
            "isInteger",
            "isIntersecting",
            "isLockFree",
            "isMap",
            "isMultiLine",
            "isNaN",
            "isOpen",
            "isPointInFill",
            "isPointInPath",
            "isPointInRange",
            "isPointInStroke",
            "isPrefAlternate",
            "isPresenting",
            "isPrimary",
            "isProgram",
            "isPropertyImplicit",
            "isProtocolHandlerRegistered",
            "isPrototypeOf",
            "isQuery",
            "isRenderbuffer",
            "isSafeInteger",
            "isSameNode",
            "isSampler",
            "isScript",
            "isScriptURL",
            "isSealed",
            "isSecureContext",
            "isSessionSupported",
            "isShader",
            "isSupported",
            "isSync",
            "isTextEdit",
            "isTexture",
            "isTransformFeedback",
            "isTrusted",
            "isTypeSupported",
            "isUserVerifyingPlatformAuthenticatorAvailable",
            "isVertexArray",
            "isView",
            "isVisible",
            "isochronousTransferIn",
            "isochronousTransferOut",
            "isolation",
            "italics",
            "item",
            "itemId",
            "itemProp",
            "itemRef",
            "itemScope",
            "itemType",
            "itemValue",
            "items",
            "iterateNext",
            "iterationComposite",
            "iterator",
            "javaEnabled",
            "jobTitle",
            "join",
            "json",
            "justify-content",
            "justify-items",
            "justify-self",
            "justifyContent",
            "justifyItems",
            "justifySelf",
            "k1",
            "k2",
            "k3",
            "k4",
            "kHz",
            "keepalive",
            "kernelMatrix",
            "kernelUnitLengthX",
            "kernelUnitLengthY",
            "kerning",
            "key",
            "keyCode",
            "keyFor",
            "keyIdentifier",
            "keyLightEnabled",
            "keyLocation",
            "keyPath",
            "keyStatuses",
            "keySystem",
            "keyText",
            "keyUsage",
            "keyboard",
            "keys",
            "keytype",
            "kind",
            "knee",
            "label",
            "labels",
            "lang",
            "language",
            "languages",
            "largeArcFlag",
            "lastChild",
            "lastElementChild",
            "lastEventId",
            "lastIndex",
            "lastIndexOf",
            "lastInputTime",
            "lastMatch",
            "lastMessageSubject",
            "lastMessageType",
            "lastModified",
            "lastModifiedDate",
            "lastPage",
            "lastParen",
            "lastState",
            "lastStyleSheetSet",
            "latitude",
            "layerX",
            "layerY",
            "layoutFlow",
            "layoutGrid",
            "layoutGridChar",
            "layoutGridLine",
            "layoutGridMode",
            "layoutGridType",
            "lbound",
            "left",
            "leftContext",
            "leftDegrees",
            "leftMargin",
            "leftProjectionMatrix",
            "leftViewMatrix",
            "length",
            "lengthAdjust",
            "lengthComputable",
            "letter-spacing",
            "letterSpacing",
            "level",
            "lighting-color",
            "lightingColor",
            "limitingConeAngle",
            "line",
            "line-break",
            "line-height",
            "lineAlign",
            "lineBreak",
            "lineCap",
            "lineDashOffset",
            "lineHeight",
            "lineJoin",
            "lineNumber",
            "lineTo",
            "lineWidth",
            "linearAcceleration",
            "linearRampToValueAtTime",
            "linearVelocity",
            "lineno",
            "lines",
            "link",
            "linkColor",
            "linkProgram",
            "links",
            "list",
            "list-style",
            "list-style-image",
            "list-style-position",
            "list-style-type",
            "listStyle",
            "listStyleImage",
            "listStylePosition",
            "listStyleType",
            "listener",
            "load",
            "loadEventEnd",
            "loadEventStart",
            "loadTime",
            "loadTimes",
            "loaded",
            "loading",
            "localDescription",
            "localName",
            "localService",
            "localStorage",
            "locale",
            "localeCompare",
            "location",
            "locationbar",
            "lock",
            "locked",
            "lockedFile",
            "locks",
            "log",
            "log10",
            "log1p",
            "log2",
            "logicalXDPI",
            "logicalYDPI",
            "longDesc",
            "longitude",
            "lookupNamespaceURI",
            "lookupPrefix",
            "loop",
            "loopEnd",
            "loopStart",
            "looping",
            "low",
            "lower",
            "lowerBound",
            "lowerOpen",
            "lowsrc",
            "m11",
            "m12",
            "m13",
            "m14",
            "m21",
            "m22",
            "m23",
            "m24",
            "m31",
            "m32",
            "m33",
            "m34",
            "m41",
            "m42",
            "m43",
            "m44",
            "makeXRCompatible",
            "manifest",
            "manufacturer",
            "manufacturerName",
            "map",
            "mapping",
            "margin",
            "margin-block",
            "margin-block-end",
            "margin-block-start",
            "margin-bottom",
            "margin-inline",
            "margin-inline-end",
            "margin-inline-start",
            "margin-left",
            "margin-right",
            "margin-top",
            "marginBlock",
            "marginBlockEnd",
            "marginBlockStart",
            "marginBottom",
            "marginHeight",
            "marginInline",
            "marginInlineEnd",
            "marginInlineStart",
            "marginLeft",
            "marginRight",
            "marginTop",
            "marginWidth",
            "mark",
            "marker",
            "marker-end",
            "marker-mid",
            "marker-offset",
            "marker-start",
            "markerEnd",
            "markerHeight",
            "markerMid",
            "markerOffset",
            "markerStart",
            "markerUnits",
            "markerWidth",
            "marks",
            "mask",
            "mask-clip",
            "mask-composite",
            "mask-image",
            "mask-mode",
            "mask-origin",
            "mask-position",
            "mask-position-x",
            "mask-position-y",
            "mask-repeat",
            "mask-size",
            "mask-type",
            "maskClip",
            "maskComposite",
            "maskContentUnits",
            "maskImage",
            "maskMode",
            "maskOrigin",
            "maskPosition",
            "maskPositionX",
            "maskPositionY",
            "maskRepeat",
            "maskSize",
            "maskType",
            "maskUnits",
            "match",
            "matchAll",
            "matchMedia",
            "matchMedium",
            "matches",
            "matrix",
            "matrixTransform",
            "max",
            "max-block-size",
            "max-height",
            "max-inline-size",
            "max-width",
            "maxActions",
            "maxAlternatives",
            "maxBlockSize",
            "maxChannelCount",
            "maxChannels",
            "maxConnectionsPerServer",
            "maxDecibels",
            "maxDistance",
            "maxHeight",
            "maxInlineSize",
            "maxLayers",
            "maxLength",
            "maxMessageSize",
            "maxPacketLifeTime",
            "maxRetransmits",
            "maxTouchPoints",
            "maxValue",
            "maxWidth",
            "measure",
            "measureText",
            "media",
            "mediaCapabilities",
            "mediaDevices",
            "mediaElement",
            "mediaGroup",
            "mediaKeys",
            "mediaSession",
            "mediaStream",
            "mediaText",
            "meetOrSlice",
            "memory",
            "menubar",
            "mergeAttributes",
            "message",
            "messageClass",
            "messageHandlers",
            "messageType",
            "metaKey",
            "metadata",
            "method",
            "methodDetails",
            "methodName",
            "mid",
            "mimeType",
            "mimeTypes",
            "min",
            "min-block-size",
            "min-height",
            "min-inline-size",
            "min-width",
            "minBlockSize",
            "minDecibels",
            "minHeight",
            "minInlineSize",
            "minLength",
            "minValue",
            "minWidth",
            "miterLimit",
            "mix-blend-mode",
            "mixBlendMode",
            "mm",
            "mobile",
            "mode",
            "model",
            "modify",
            "mount",
            "move",
            "moveBy",
            "moveEnd",
            "moveFirst",
            "moveFocusDown",
            "moveFocusLeft",
            "moveFocusRight",
            "moveFocusUp",
            "moveNext",
            "moveRow",
            "moveStart",
            "moveTo",
            "moveToBookmark",
            "moveToElementText",
            "moveToPoint",
            "movementX",
            "movementY",
            "mozAdd",
            "mozAnimationStartTime",
            "mozAnon",
            "mozApps",
            "mozAudioCaptured",
            "mozAudioChannelType",
            "mozAutoplayEnabled",
            "mozCancelAnimationFrame",
            "mozCancelFullScreen",
            "mozCancelRequestAnimationFrame",
            "mozCaptureStream",
            "mozCaptureStreamUntilEnded",
            "mozClearDataAt",
            "mozContact",
            "mozContacts",
            "mozCreateFileHandle",
            "mozCurrentTransform",
            "mozCurrentTransformInverse",
            "mozCursor",
            "mozDash",
            "mozDashOffset",
            "mozDecodedFrames",
            "mozExitPointerLock",
            "mozFillRule",
            "mozFragmentEnd",
            "mozFrameDelay",
            "mozFullScreen",
            "mozFullScreenElement",
            "mozFullScreenEnabled",
            "mozGetAll",
            "mozGetAllKeys",
            "mozGetAsFile",
            "mozGetDataAt",
            "mozGetMetadata",
            "mozGetUserMedia",
            "mozHasAudio",
            "mozHasItem",
            "mozHidden",
            "mozImageSmoothingEnabled",
            "mozIndexedDB",
            "mozInnerScreenX",
            "mozInnerScreenY",
            "mozInputSource",
            "mozIsTextField",
            "mozItem",
            "mozItemCount",
            "mozItems",
            "mozLength",
            "mozLockOrientation",
            "mozMatchesSelector",
            "mozMovementX",
            "mozMovementY",
            "mozOpaque",
            "mozOrientation",
            "mozPaintCount",
            "mozPaintedFrames",
            "mozParsedFrames",
            "mozPay",
            "mozPointerLockElement",
            "mozPresentedFrames",
            "mozPreservesPitch",
            "mozPressure",
            "mozPrintCallback",
            "mozRTCIceCandidate",
            "mozRTCPeerConnection",
            "mozRTCSessionDescription",
            "mozRemove",
            "mozRequestAnimationFrame",
            "mozRequestFullScreen",
            "mozRequestPointerLock",
            "mozSetDataAt",
            "mozSetImageElement",
            "mozSourceNode",
            "mozSrcObject",
            "mozSystem",
            "mozTCPSocket",
            "mozTextStyle",
            "mozTypesAt",
            "mozUnlockOrientation",
            "mozUserCancelled",
            "mozVisibilityState",
            "ms",
            "msAnimation",
            "msAnimationDelay",
            "msAnimationDirection",
            "msAnimationDuration",
            "msAnimationFillMode",
            "msAnimationIterationCount",
            "msAnimationName",
            "msAnimationPlayState",
            "msAnimationStartTime",
            "msAnimationTimingFunction",
            "msBackfaceVisibility",
            "msBlockProgression",
            "msCSSOMElementFloatMetrics",
            "msCaching",
            "msCachingEnabled",
            "msCancelRequestAnimationFrame",
            "msCapsLockWarningOff",
            "msClearImmediate",
            "msClose",
            "msContentZoomChaining",
            "msContentZoomFactor",
            "msContentZoomLimit",
            "msContentZoomLimitMax",
            "msContentZoomLimitMin",
            "msContentZoomSnap",
            "msContentZoomSnapPoints",
            "msContentZoomSnapType",
            "msContentZooming",
            "msConvertURL",
            "msCrypto",
            "msDoNotTrack",
            "msElementsFromPoint",
            "msElementsFromRect",
            "msExitFullscreen",
            "msExtendedCode",
            "msFillRule",
            "msFirstPaint",
            "msFlex",
            "msFlexAlign",
            "msFlexDirection",
            "msFlexFlow",
            "msFlexItemAlign",
            "msFlexLinePack",
            "msFlexNegative",
            "msFlexOrder",
            "msFlexPack",
            "msFlexPositive",
            "msFlexPreferredSize",
            "msFlexWrap",
            "msFlowFrom",
            "msFlowInto",
            "msFontFeatureSettings",
            "msFullscreenElement",
            "msFullscreenEnabled",
            "msGetInputContext",
            "msGetRegionContent",
            "msGetUntransformedBounds",
            "msGraphicsTrustStatus",
            "msGridColumn",
            "msGridColumnAlign",
            "msGridColumnSpan",
            "msGridColumns",
            "msGridRow",
            "msGridRowAlign",
            "msGridRowSpan",
            "msGridRows",
            "msHidden",
            "msHighContrastAdjust",
            "msHyphenateLimitChars",
            "msHyphenateLimitLines",
            "msHyphenateLimitZone",
            "msHyphens",
            "msImageSmoothingEnabled",
            "msImeAlign",
            "msIndexedDB",
            "msInterpolationMode",
            "msIsStaticHTML",
            "msKeySystem",
            "msKeys",
            "msLaunchUri",
            "msLockOrientation",
            "msManipulationViewsEnabled",
            "msMatchMedia",
            "msMatchesSelector",
            "msMaxTouchPoints",
            "msOrientation",
            "msOverflowStyle",
            "msPerspective",
            "msPerspectiveOrigin",
            "msPlayToDisabled",
            "msPlayToPreferredSourceUri",
            "msPlayToPrimary",
            "msPointerEnabled",
            "msRegionOverflow",
            "msReleasePointerCapture",
            "msRequestAnimationFrame",
            "msRequestFullscreen",
            "msSaveBlob",
            "msSaveOrOpenBlob",
            "msScrollChaining",
            "msScrollLimit",
            "msScrollLimitXMax",
            "msScrollLimitXMin",
            "msScrollLimitYMax",
            "msScrollLimitYMin",
            "msScrollRails",
            "msScrollSnapPointsX",
            "msScrollSnapPointsY",
            "msScrollSnapType",
            "msScrollSnapX",
            "msScrollSnapY",
            "msScrollTranslation",
            "msSetImmediate",
            "msSetMediaKeys",
            "msSetPointerCapture",
            "msTextCombineHorizontal",
            "msTextSizeAdjust",
            "msToBlob",
            "msTouchAction",
            "msTouchSelect",
            "msTraceAsyncCallbackCompleted",
            "msTraceAsyncCallbackStarting",
            "msTraceAsyncOperationCompleted",
            "msTraceAsyncOperationStarting",
            "msTransform",
            "msTransformOrigin",
            "msTransformStyle",
            "msTransition",
            "msTransitionDelay",
            "msTransitionDuration",
            "msTransitionProperty",
            "msTransitionTimingFunction",
            "msUnlockOrientation",
            "msUpdateAsyncCallbackRelation",
            "msUserSelect",
            "msVisibilityState",
            "msWrapFlow",
            "msWrapMargin",
            "msWrapThrough",
            "msWriteProfilerMark",
            "msZoom",
            "msZoomTo",
            "mt",
            "mul",
            "multiEntry",
            "multiSelectionObj",
            "multiline",
            "multiple",
            "multiply",
            "multiplySelf",
            "mutableFile",
            "muted",
            "n",
            "name",
            "nameProp",
            "namedItem",
            "namedRecordset",
            "names",
            "namespaceURI",
            "namespaces",
            "naturalHeight",
            "naturalWidth",
            "navigate",
            "navigation",
            "navigationMode",
            "navigationPreload",
            "navigationStart",
            "navigator",
            "near",
            "nearestViewportElement",
            "negative",
            "negotiated",
            "netscape",
            "networkState",
            "newScale",
            "newTranslate",
            "newURL",
            "newValue",
            "newValueSpecifiedUnits",
            "newVersion",
            "newhome",
            "next",
            "nextElementSibling",
            "nextHopProtocol",
            "nextNode",
            "nextPage",
            "nextSibling",
            "nickname",
            "noHref",
            "noModule",
            "noResize",
            "noShade",
            "noValidate",
            "noWrap",
            "node",
            "nodeName",
            "nodeType",
            "nodeValue",
            "nonce",
            "normalize",
            "normalizedPathSegList",
            "notationName",
            "notations",
            "note",
            "noteGrainOn",
            "noteOff",
            "noteOn",
            "notify",
            "now",
            "numOctaves",
            "number",
            "numberOfChannels",
            "numberOfInputs",
            "numberOfItems",
            "numberOfOutputs",
            "numberValue",
            "oMatchesSelector",
            "object",
            "object-fit",
            "object-position",
            "objectFit",
            "objectPosition",
            "objectStore",
            "objectStoreNames",
            "objectType",
            "observe",
            "of",
            "offscreenBuffering",
            "offset",
            "offset-anchor",
            "offset-distance",
            "offset-path",
            "offset-rotate",
            "offsetAnchor",
            "offsetDistance",
            "offsetHeight",
            "offsetLeft",
            "offsetNode",
            "offsetParent",
            "offsetPath",
            "offsetRotate",
            "offsetTop",
            "offsetWidth",
            "offsetX",
            "offsetY",
            "ok",
            "oldURL",
            "oldValue",
            "oldVersion",
            "olderShadowRoot",
            "onLine",
            "onabort",
            "onabsolutedeviceorientation",
            "onactivate",
            "onactive",
            "onaddsourcebuffer",
            "onaddstream",
            "onaddtrack",
            "onafterprint",
            "onafterscriptexecute",
            "onafterupdate",
            "onanimationcancel",
            "onanimationend",
            "onanimationiteration",
            "onanimationstart",
            "onappinstalled",
            "onaudioend",
            "onaudioprocess",
            "onaudiostart",
            "onautocomplete",
            "onautocompleteerror",
            "onauxclick",
            "onbeforeactivate",
            "onbeforecopy",
            "onbeforecut",
            "onbeforedeactivate",
            "onbeforeeditfocus",
            "onbeforeinstallprompt",
            "onbeforepaste",
            "onbeforeprint",
            "onbeforescriptexecute",
            "onbeforeunload",
            "onbeforeupdate",
            "onbeforexrselect",
            "onbegin",
            "onblocked",
            "onblur",
            "onbounce",
            "onboundary",
            "onbufferedamountlow",
            "oncached",
            "oncancel",
            "oncandidatewindowhide",
            "oncandidatewindowshow",
            "oncandidatewindowupdate",
            "oncanplay",
            "oncanplaythrough",
            "once",
            "oncellchange",
            "onchange",
            "oncharacteristicvaluechanged",
            "onchargingchange",
            "onchargingtimechange",
            "onchecking",
            "onclick",
            "onclose",
            "onclosing",
            "oncompassneedscalibration",
            "oncomplete",
            "onconnect",
            "onconnecting",
            "onconnectionavailable",
            "onconnectionstatechange",
            "oncontextmenu",
            "oncontrollerchange",
            "oncontrolselect",
            "oncopy",
            "oncuechange",
            "oncut",
            "ondataavailable",
            "ondatachannel",
            "ondatasetchanged",
            "ondatasetcomplete",
            "ondblclick",
            "ondeactivate",
            "ondevicechange",
            "ondevicelight",
            "ondevicemotion",
            "ondeviceorientation",
            "ondeviceorientationabsolute",
            "ondeviceproximity",
            "ondischargingtimechange",
            "ondisconnect",
            "ondisplay",
            "ondownloading",
            "ondrag",
            "ondragend",
            "ondragenter",
            "ondragexit",
            "ondragleave",
            "ondragover",
            "ondragstart",
            "ondrop",
            "ondurationchange",
            "onemptied",
            "onencrypted",
            "onend",
            "onended",
            "onenter",
            "onenterpictureinpicture",
            "onerror",
            "onerrorupdate",
            "onexit",
            "onfilterchange",
            "onfinish",
            "onfocus",
            "onfocusin",
            "onfocusout",
            "onformdata",
            "onfreeze",
            "onfullscreenchange",
            "onfullscreenerror",
            "ongatheringstatechange",
            "ongattserverdisconnected",
            "ongesturechange",
            "ongestureend",
            "ongesturestart",
            "ongotpointercapture",
            "onhashchange",
            "onhelp",
            "onicecandidate",
            "onicecandidateerror",
            "oniceconnectionstatechange",
            "onicegatheringstatechange",
            "oninactive",
            "oninput",
            "oninputsourceschange",
            "oninvalid",
            "onkeydown",
            "onkeypress",
            "onkeystatuseschange",
            "onkeyup",
            "onlanguagechange",
            "onlayoutcomplete",
            "onleavepictureinpicture",
            "onlevelchange",
            "onload",
            "onloadeddata",
            "onloadedmetadata",
            "onloadend",
            "onloading",
            "onloadingdone",
            "onloadingerror",
            "onloadstart",
            "onlosecapture",
            "onlostpointercapture",
            "only",
            "onmark",
            "onmessage",
            "onmessageerror",
            "onmidimessage",
            "onmousedown",
            "onmouseenter",
            "onmouseleave",
            "onmousemove",
            "onmouseout",
            "onmouseover",
            "onmouseup",
            "onmousewheel",
            "onmove",
            "onmoveend",
            "onmovestart",
            "onmozfullscreenchange",
            "onmozfullscreenerror",
            "onmozorientationchange",
            "onmozpointerlockchange",
            "onmozpointerlockerror",
            "onmscontentzoom",
            "onmsfullscreenchange",
            "onmsfullscreenerror",
            "onmsgesturechange",
            "onmsgesturedoubletap",
            "onmsgestureend",
            "onmsgesturehold",
            "onmsgesturestart",
            "onmsgesturetap",
            "onmsgotpointercapture",
            "onmsinertiastart",
            "onmslostpointercapture",
            "onmsmanipulationstatechanged",
            "onmsneedkey",
            "onmsorientationchange",
            "onmspointercancel",
            "onmspointerdown",
            "onmspointerenter",
            "onmspointerhover",
            "onmspointerleave",
            "onmspointermove",
            "onmspointerout",
            "onmspointerover",
            "onmspointerup",
            "onmssitemodejumplistitemremoved",
            "onmsthumbnailclick",
            "onmute",
            "onnegotiationneeded",
            "onnomatch",
            "onnoupdate",
            "onobsolete",
            "onoffline",
            "ononline",
            "onopen",
            "onorientationchange",
            "onpagechange",
            "onpagehide",
            "onpageshow",
            "onpaste",
            "onpause",
            "onpayerdetailchange",
            "onpaymentmethodchange",
            "onplay",
            "onplaying",
            "onpluginstreamstart",
            "onpointercancel",
            "onpointerdown",
            "onpointerenter",
            "onpointerleave",
            "onpointerlockchange",
            "onpointerlockerror",
            "onpointermove",
            "onpointerout",
            "onpointerover",
            "onpointerrawupdate",
            "onpointerup",
            "onpopstate",
            "onprocessorerror",
            "onprogress",
            "onpropertychange",
            "onratechange",
            "onreading",
            "onreadystatechange",
            "onrejectionhandled",
            "onrelease",
            "onremove",
            "onremovesourcebuffer",
            "onremovestream",
            "onremovetrack",
            "onrepeat",
            "onreset",
            "onresize",
            "onresizeend",
            "onresizestart",
            "onresourcetimingbufferfull",
            "onresult",
            "onresume",
            "onrowenter",
            "onrowexit",
            "onrowsdelete",
            "onrowsinserted",
            "onscroll",
            "onsearch",
            "onsecuritypolicyviolation",
            "onseeked",
            "onseeking",
            "onselect",
            "onselectedcandidatepairchange",
            "onselectend",
            "onselectionchange",
            "onselectstart",
            "onshippingaddresschange",
            "onshippingoptionchange",
            "onshow",
            "onsignalingstatechange",
            "onsoundend",
            "onsoundstart",
            "onsourceclose",
            "onsourceclosed",
            "onsourceended",
            "onsourceopen",
            "onspeechend",
            "onspeechstart",
            "onsqueeze",
            "onsqueezeend",
            "onsqueezestart",
            "onstalled",
            "onstart",
            "onstatechange",
            "onstop",
            "onstorage",
            "onstoragecommit",
            "onsubmit",
            "onsuccess",
            "onsuspend",
            "onterminate",
            "ontextinput",
            "ontimeout",
            "ontimeupdate",
            "ontoggle",
            "ontonechange",
            "ontouchcancel",
            "ontouchend",
            "ontouchmove",
            "ontouchstart",
            "ontrack",
            "ontransitioncancel",
            "ontransitionend",
            "ontransitionrun",
            "ontransitionstart",
            "onunhandledrejection",
            "onunload",
            "onunmute",
            "onupdate",
            "onupdateend",
            "onupdatefound",
            "onupdateready",
            "onupdatestart",
            "onupgradeneeded",
            "onuserproximity",
            "onversionchange",
            "onvisibilitychange",
            "onvoiceschanged",
            "onvolumechange",
            "onvrdisplayactivate",
            "onvrdisplayconnect",
            "onvrdisplaydeactivate",
            "onvrdisplaydisconnect",
            "onvrdisplaypresentchange",
            "onwaiting",
            "onwaitingforkey",
            "onwarning",
            "onwebkitanimationend",
            "onwebkitanimationiteration",
            "onwebkitanimationstart",
            "onwebkitcurrentplaybacktargetiswirelesschanged",
            "onwebkitfullscreenchange",
            "onwebkitfullscreenerror",
            "onwebkitkeyadded",
            "onwebkitkeyerror",
            "onwebkitkeymessage",
            "onwebkitneedkey",
            "onwebkitorientationchange",
            "onwebkitplaybacktargetavailabilitychanged",
            "onwebkitpointerlockchange",
            "onwebkitpointerlockerror",
            "onwebkitresourcetimingbufferfull",
            "onwebkittransitionend",
            "onwheel",
            "onzoom",
            "opacity",
            "open",
            "openCursor",
            "openDatabase",
            "openKeyCursor",
            "opened",
            "opener",
            "opera",
            "operationType",
            "operator",
            "opr",
            "optimum",
            "options",
            "or",
            "order",
            "orderX",
            "orderY",
            "ordered",
            "org",
            "organization",
            "orient",
            "orientAngle",
            "orientType",
            "orientation",
            "orientationX",
            "orientationY",
            "orientationZ",
            "origin",
            "originalPolicy",
            "originalTarget",
            "orphans",
            "oscpu",
            "outerHTML",
            "outerHeight",
            "outerText",
            "outerWidth",
            "outline",
            "outline-color",
            "outline-offset",
            "outline-style",
            "outline-width",
            "outlineColor",
            "outlineOffset",
            "outlineStyle",
            "outlineWidth",
            "outputBuffer",
            "outputChannelCount",
            "outputLatency",
            "outputs",
            "overflow",
            "overflow-anchor",
            "overflow-block",
            "overflow-inline",
            "overflow-wrap",
            "overflow-x",
            "overflow-y",
            "overflowAnchor",
            "overflowBlock",
            "overflowInline",
            "overflowWrap",
            "overflowX",
            "overflowY",
            "overrideMimeType",
            "oversample",
            "overscroll-behavior",
            "overscroll-behavior-block",
            "overscroll-behavior-inline",
            "overscroll-behavior-x",
            "overscroll-behavior-y",
            "overscrollBehavior",
            "overscrollBehaviorBlock",
            "overscrollBehaviorInline",
            "overscrollBehaviorX",
            "overscrollBehaviorY",
            "ownKeys",
            "ownerDocument",
            "ownerElement",
            "ownerNode",
            "ownerRule",
            "ownerSVGElement",
            "owningElement",
            "p1",
            "p2",
            "p3",
            "p4",
            "packetSize",
            "packets",
            "pad",
            "padEnd",
            "padStart",
            "padding",
            "padding-block",
            "padding-block-end",
            "padding-block-start",
            "padding-bottom",
            "padding-inline",
            "padding-inline-end",
            "padding-inline-start",
            "padding-left",
            "padding-right",
            "padding-top",
            "paddingBlock",
            "paddingBlockEnd",
            "paddingBlockStart",
            "paddingBottom",
            "paddingInline",
            "paddingInlineEnd",
            "paddingInlineStart",
            "paddingLeft",
            "paddingRight",
            "paddingTop",
            "page",
            "page-break-after",
            "page-break-before",
            "page-break-inside",
            "pageBreakAfter",
            "pageBreakBefore",
            "pageBreakInside",
            "pageCount",
            "pageLeft",
            "pageTop",
            "pageX",
            "pageXOffset",
            "pageY",
            "pageYOffset",
            "pages",
            "paint-order",
            "paintOrder",
            "paintRequests",
            "paintType",
            "paintWorklet",
            "palette",
            "pan",
            "panningModel",
            "parameterData",
            "parameters",
            "parent",
            "parentElement",
            "parentNode",
            "parentRule",
            "parentStyleSheet",
            "parentTextEdit",
            "parentWindow",
            "parse",
            "parseAll",
            "parseFloat",
            "parseFromString",
            "parseInt",
            "part",
            "participants",
            "passive",
            "password",
            "pasteHTML",
            "path",
            "pathLength",
            "pathSegList",
            "pathSegType",
            "pathSegTypeAsLetter",
            "pathname",
            "pattern",
            "patternContentUnits",
            "patternMismatch",
            "patternTransform",
            "patternUnits",
            "pause",
            "pauseAnimations",
            "pauseOnExit",
            "pauseProfilers",
            "pauseTransformFeedback",
            "paused",
            "payerEmail",
            "payerName",
            "payerPhone",
            "paymentManager",
            "pc",
            "peerIdentity",
            "pending",
            "pendingLocalDescription",
            "pendingRemoteDescription",
            "percent",
            "performance",
            "periodicSync",
            "permission",
            "permissionState",
            "permissions",
            "persist",
            "persisted",
            "personalbar",
            "perspective",
            "perspective-origin",
            "perspectiveOrigin",
            "phone",
            "phoneticFamilyName",
            "phoneticGivenName",
            "photo",
            "pictureInPictureElement",
            "pictureInPictureEnabled",
            "pictureInPictureWindow",
            "ping",
            "pipeThrough",
            "pipeTo",
            "pitch",
            "pixelBottom",
            "pixelDepth",
            "pixelHeight",
            "pixelLeft",
            "pixelRight",
            "pixelStorei",
            "pixelTop",
            "pixelUnitToMillimeterX",
            "pixelUnitToMillimeterY",
            "pixelWidth",
            "place-content",
            "place-items",
            "place-self",
            "placeContent",
            "placeItems",
            "placeSelf",
            "placeholder",
            "platformVersion",
            "platform",
            "platforms",
            "play",
            "playEffect",
            "playState",
            "playbackRate",
            "playbackState",
            "playbackTime",
            "played",
            "playoutDelayHint",
            "playsInline",
            "plugins",
            "pluginspage",
            "pname",
            "pointer-events",
            "pointerBeforeReferenceNode",
            "pointerEnabled",
            "pointerEvents",
            "pointerId",
            "pointerLockElement",
            "pointerType",
            "points",
            "pointsAtX",
            "pointsAtY",
            "pointsAtZ",
            "polygonOffset",
            "pop",
            "populateMatrix",
            "popupWindowFeatures",
            "popupWindowName",
            "popupWindowURI",
            "port",
            "port1",
            "port2",
            "ports",
            "posBottom",
            "posHeight",
            "posLeft",
            "posRight",
            "posTop",
            "posWidth",
            "pose",
            "position",
            "positionAlign",
            "positionX",
            "positionY",
            "positionZ",
            "postError",
            "postMessage",
            "postalCode",
            "poster",
            "pow",
            "powerEfficient",
            "powerOff",
            "preMultiplySelf",
            "precision",
            "preferredStyleSheetSet",
            "preferredStylesheetSet",
            "prefix",
            "preload",
            "prepend",
            "presentation",
            "preserveAlpha",
            "preserveAspectRatio",
            "preserveAspectRatioString",
            "pressed",
            "pressure",
            "prevValue",
            "preventDefault",
            "preventExtensions",
            "preventSilentAccess",
            "previousElementSibling",
            "previousNode",
            "previousPage",
            "previousRect",
            "previousScale",
            "previousSibling",
            "previousTranslate",
            "primaryKey",
            "primitiveType",
            "primitiveUnits",
            "principals",
            "print",
            "priority",
            "privateKey",
            "probablySupportsContext",
            "process",
            "processIceMessage",
            "processingEnd",
            "processingStart",
            "processorOptions",
            "product",
            "productId",
            "productName",
            "productSub",
            "profile",
            "profileEnd",
            "profiles",
            "projectionMatrix",
            "promise",
            "prompt",
            "properties",
            "propertyIsEnumerable",
            "propertyName",
            "protocol",
            "protocolLong",
            "prototype",
            "provider",
            "pseudoClass",
            "pseudoElement",
            "pt",
            "publicId",
            "publicKey",
            "published",
            "pulse",
            "push",
            "pushManager",
            "pushNotification",
            "pushState",
            "put",
            "putImageData",
            "px",
            "quadraticCurveTo",
            "qualifier",
            "quaternion",
            "query",
            "queryCommandEnabled",
            "queryCommandIndeterm",
            "queryCommandState",
            "queryCommandSupported",
            "queryCommandText",
            "queryCommandValue",
            "querySelector",
            "querySelectorAll",
            "queueMicrotask",
            "quote",
            "quotes",
            "r",
            "r1",
            "r2",
            "race",
            "rad",
            "radiogroup",
            "radiusX",
            "radiusY",
            "random",
            "range",
            "rangeCount",
            "rangeMax",
            "rangeMin",
            "rangeOffset",
            "rangeOverflow",
            "rangeParent",
            "rangeUnderflow",
            "rate",
            "ratio",
            "raw",
            "rawId",
            "read",
            "readAsArrayBuffer",
            "readAsBinaryString",
            "readAsBlob",
            "readAsDataURL",
            "readAsText",
            "readBuffer",
            "readEntries",
            "readOnly",
            "readPixels",
            "readReportRequested",
            "readText",
            "readValue",
            "readable",
            "ready",
            "readyState",
            "reason",
            "reboot",
            "receivedAlert",
            "receiver",
            "receivers",
            "recipient",
            "reconnect",
            "recordNumber",
            "recordsAvailable",
            "recordset",
            "rect",
            "red",
            "redEyeReduction",
            "redirect",
            "redirectCount",
            "redirectEnd",
            "redirectStart",
            "redirected",
            "reduce",
            "reduceRight",
            "reduction",
            "refDistance",
            "refX",
            "refY",
            "referenceNode",
            "referenceSpace",
            "referrer",
            "referrerPolicy",
            "refresh",
            "region",
            "regionAnchorX",
            "regionAnchorY",
            "regionId",
            "regions",
            "register",
            "registerContentHandler",
            "registerElement",
            "registerProperty",
            "registerProtocolHandler",
            "reject",
            "rel",
            "relList",
            "relatedAddress",
            "relatedNode",
            "relatedPort",
            "relatedTarget",
            "release",
            "releaseCapture",
            "releaseEvents",
            "releaseInterface",
            "releaseLock",
            "releasePointerCapture",
            "releaseShaderCompiler",
            "reliable",
            "reliableWrite",
            "reload",
            "rem",
            "remainingSpace",
            "remote",
            "remoteDescription",
            "remove",
            "removeAllRanges",
            "removeAttribute",
            "removeAttributeNS",
            "removeAttributeNode",
            "removeBehavior",
            "removeChild",
            "removeCue",
            "removeEventListener",
            "removeFilter",
            "removeImport",
            "removeItem",
            "removeListener",
            "removeNamedItem",
            "removeNamedItemNS",
            "removeNode",
            "removeParameter",
            "removeProperty",
            "removeRange",
            "removeRegion",
            "removeRule",
            "removeSiteSpecificTrackingException",
            "removeSourceBuffer",
            "removeStream",
            "removeTrack",
            "removeVariable",
            "removeWakeLockListener",
            "removeWebWideTrackingException",
            "removed",
            "removedNodes",
            "renderHeight",
            "renderState",
            "renderTime",
            "renderWidth",
            "renderbufferStorage",
            "renderbufferStorageMultisample",
            "renderedBuffer",
            "renderingMode",
            "renotify",
            "repeat",
            "replace",
            "replaceAdjacentText",
            "replaceAll",
            "replaceChild",
            "replaceChildren",
            "replaceData",
            "replaceId",
            "replaceItem",
            "replaceNode",
            "replaceState",
            "replaceSync",
            "replaceTrack",
            "replaceWholeText",
            "replaceWith",
            "reportValidity",
            "request",
            "requestAnimationFrame",
            "requestAutocomplete",
            "requestData",
            "requestDevice",
            "requestFrame",
            "requestFullscreen",
            "requestHitTestSource",
            "requestHitTestSourceForTransientInput",
            "requestId",
            "requestIdleCallback",
            "requestMIDIAccess",
            "requestMediaKeySystemAccess",
            "requestPermission",
            "requestPictureInPicture",
            "requestPointerLock",
            "requestPresent",
            "requestReferenceSpace",
            "requestSession",
            "requestStart",
            "requestStorageAccess",
            "requestSubmit",
            "requestVideoFrameCallback",
            "requestingWindow",
            "requireInteraction",
            "required",
            "requiredExtensions",
            "requiredFeatures",
            "reset",
            "resetPose",
            "resetTransform",
            "resize",
            "resizeBy",
            "resizeTo",
            "resolve",
            "response",
            "responseBody",
            "responseEnd",
            "responseReady",
            "responseStart",
            "responseText",
            "responseType",
            "responseURL",
            "responseXML",
            "restartIce",
            "restore",
            "result",
            "resultIndex",
            "resultType",
            "results",
            "resume",
            "resumeProfilers",
            "resumeTransformFeedback",
            "retry",
            "returnValue",
            "rev",
            "reverse",
            "reversed",
            "revocable",
            "revokeObjectURL",
            "rgbColor",
            "right",
            "rightContext",
            "rightDegrees",
            "rightMargin",
            "rightProjectionMatrix",
            "rightViewMatrix",
            "role",
            "rolloffFactor",
            "root",
            "rootBounds",
            "rootElement",
            "rootMargin",
            "rotate",
            "rotateAxisAngle",
            "rotateAxisAngleSelf",
            "rotateFromVector",
            "rotateFromVectorSelf",
            "rotateSelf",
            "rotation",
            "rotationAngle",
            "rotationRate",
            "round",
            "row-gap",
            "rowGap",
            "rowIndex",
            "rowSpan",
            "rows",
            "rtcpTransport",
            "rtt",
            "ruby-align",
            "ruby-position",
            "rubyAlign",
            "rubyOverhang",
            "rubyPosition",
            "rules",
            "runtime",
            "runtimeStyle",
            "rx",
            "ry",
            "s",
            "safari",
            "sample",
            "sampleCoverage",
            "sampleRate",
            "samplerParameterf",
            "samplerParameteri",
            "sandbox",
            "save",
            "saveData",
            "scale",
            "scale3d",
            "scale3dSelf",
            "scaleNonUniform",
            "scaleNonUniformSelf",
            "scaleSelf",
            "scheme",
            "scissor",
            "scope",
            "scopeName",
            "scoped",
            "screen",
            "screenBrightness",
            "screenEnabled",
            "screenLeft",
            "screenPixelToMillimeterX",
            "screenPixelToMillimeterY",
            "screenTop",
            "screenX",
            "screenY",
            "scriptURL",
            "scripts",
            "scroll",
            "scroll-behavior",
            "scroll-margin",
            "scroll-margin-block",
            "scroll-margin-block-end",
            "scroll-margin-block-start",
            "scroll-margin-bottom",
            "scroll-margin-inline",
            "scroll-margin-inline-end",
            "scroll-margin-inline-start",
            "scroll-margin-left",
            "scroll-margin-right",
            "scroll-margin-top",
            "scroll-padding",
            "scroll-padding-block",
            "scroll-padding-block-end",
            "scroll-padding-block-start",
            "scroll-padding-bottom",
            "scroll-padding-inline",
            "scroll-padding-inline-end",
            "scroll-padding-inline-start",
            "scroll-padding-left",
            "scroll-padding-right",
            "scroll-padding-top",
            "scroll-snap-align",
            "scroll-snap-type",
            "scrollAmount",
            "scrollBehavior",
            "scrollBy",
            "scrollByLines",
            "scrollByPages",
            "scrollDelay",
            "scrollHeight",
            "scrollIntoView",
            "scrollIntoViewIfNeeded",
            "scrollLeft",
            "scrollLeftMax",
            "scrollMargin",
            "scrollMarginBlock",
            "scrollMarginBlockEnd",
            "scrollMarginBlockStart",
            "scrollMarginBottom",
            "scrollMarginInline",
            "scrollMarginInlineEnd",
            "scrollMarginInlineStart",
            "scrollMarginLeft",
            "scrollMarginRight",
            "scrollMarginTop",
            "scrollMaxX",
            "scrollMaxY",
            "scrollPadding",
            "scrollPaddingBlock",
            "scrollPaddingBlockEnd",
            "scrollPaddingBlockStart",
            "scrollPaddingBottom",
            "scrollPaddingInline",
            "scrollPaddingInlineEnd",
            "scrollPaddingInlineStart",
            "scrollPaddingLeft",
            "scrollPaddingRight",
            "scrollPaddingTop",
            "scrollRestoration",
            "scrollSnapAlign",
            "scrollSnapType",
            "scrollTo",
            "scrollTop",
            "scrollTopMax",
            "scrollWidth",
            "scrollX",
            "scrollY",
            "scrollbar-color",
            "scrollbar-width",
            "scrollbar3dLightColor",
            "scrollbarArrowColor",
            "scrollbarBaseColor",
            "scrollbarColor",
            "scrollbarDarkShadowColor",
            "scrollbarFaceColor",
            "scrollbarHighlightColor",
            "scrollbarShadowColor",
            "scrollbarTrackColor",
            "scrollbarWidth",
            "scrollbars",
            "scrolling",
            "scrollingElement",
            "sctp",
            "sctpCauseCode",
            "sdp",
            "sdpLineNumber",
            "sdpMLineIndex",
            "sdpMid",
            "seal",
            "search",
            "searchBox",
            "searchBoxJavaBridge_",
            "searchParams",
            "sectionRowIndex",
            "secureConnectionStart",
            "security",
            "seed",
            "seekToNextFrame",
            "seekable",
            "seeking",
            "select",
            "selectAllChildren",
            "selectAlternateInterface",
            "selectConfiguration",
            "selectNode",
            "selectNodeContents",
            "selectNodes",
            "selectSingleNode",
            "selectSubString",
            "selected",
            "selectedIndex",
            "selectedOptions",
            "selectedStyleSheetSet",
            "selectedStylesheetSet",
            "selection",
            "selectionDirection",
            "selectionEnd",
            "selectionStart",
            "selector",
            "selectorText",
            "self",
            "send",
            "sendAsBinary",
            "sendBeacon",
            "sender",
            "sentAlert",
            "sentTimestamp",
            "separator",
            "serialNumber",
            "serializeToString",
            "serverTiming",
            "service",
            "serviceWorker",
            "session",
            "sessionId",
            "sessionStorage",
            "set",
            "setActionHandler",
            "setActive",
            "setAlpha",
            "setAppBadge",
            "setAttribute",
            "setAttributeNS",
            "setAttributeNode",
            "setAttributeNodeNS",
            "setBaseAndExtent",
            "setBigInt64",
            "setBigUint64",
            "setBingCurrentSearchDefault",
            "setCapture",
            "setCodecPreferences",
            "setColor",
            "setCompositeOperation",
            "setConfiguration",
            "setCurrentTime",
            "setCustomValidity",
            "setData",
            "setDate",
            "setDragImage",
            "setEnd",
            "setEndAfter",
            "setEndBefore",
            "setEndPoint",
            "setFillColor",
            "setFilterRes",
            "setFloat32",
            "setFloat64",
            "setFloatValue",
            "setFormValue",
            "setFullYear",
            "setHeaderValue",
            "setHours",
            "setIdentityProvider",
            "setImmediate",
            "setInt16",
            "setInt32",
            "setInt8",
            "setInterval",
            "setItem",
            "setKeyframes",
            "setLineCap",
            "setLineDash",
            "setLineJoin",
            "setLineWidth",
            "setLiveSeekableRange",
            "setLocalDescription",
            "setMatrix",
            "setMatrixValue",
            "setMediaKeys",
            "setMilliseconds",
            "setMinutes",
            "setMiterLimit",
            "setMonth",
            "setNamedItem",
            "setNamedItemNS",
            "setNonUserCodeExceptions",
            "setOrientToAngle",
            "setOrientToAuto",
            "setOrientation",
            "setOverrideHistoryNavigationMode",
            "setPaint",
            "setParameter",
            "setParameters",
            "setPeriodicWave",
            "setPointerCapture",
            "setPosition",
            "setPositionState",
            "setPreference",
            "setProperty",
            "setPrototypeOf",
            "setRGBColor",
            "setRGBColorICCColor",
            "setRadius",
            "setRangeText",
            "setRemoteDescription",
            "setRequestHeader",
            "setResizable",
            "setResourceTimingBufferSize",
            "setRotate",
            "setScale",
            "setSeconds",
            "setSelectionRange",
            "setServerCertificate",
            "setShadow",
            "setSinkId",
            "setSkewX",
            "setSkewY",
            "setStart",
            "setStartAfter",
            "setStartBefore",
            "setStdDeviation",
            "setStreams",
            "setStringValue",
            "setStrokeColor",
            "setSuggestResult",
            "setTargetAtTime",
            "setTargetValueAtTime",
            "setTime",
            "setTimeout",
            "setTransform",
            "setTranslate",
            "setUTCDate",
            "setUTCFullYear",
            "setUTCHours",
            "setUTCMilliseconds",
            "setUTCMinutes",
            "setUTCMonth",
            "setUTCSeconds",
            "setUint16",
            "setUint32",
            "setUint8",
            "setUri",
            "setValidity",
            "setValueAtTime",
            "setValueCurveAtTime",
            "setVariable",
            "setVelocity",
            "setVersion",
            "setYear",
            "settingName",
            "settingValue",
            "sex",
            "shaderSource",
            "shadowBlur",
            "shadowColor",
            "shadowOffsetX",
            "shadowOffsetY",
            "shadowRoot",
            "shape",
            "shape-image-threshold",
            "shape-margin",
            "shape-outside",
            "shape-rendering",
            "shapeImageThreshold",
            "shapeMargin",
            "shapeOutside",
            "shapeRendering",
            "sheet",
            "shift",
            "shiftKey",
            "shiftLeft",
            "shippingAddress",
            "shippingOption",
            "shippingType",
            "show",
            "showHelp",
            "showModal",
            "showModalDialog",
            "showModelessDialog",
            "showNotification",
            "sidebar",
            "sign",
            "signal",
            "signalingState",
            "signature",
            "silent",
            "sin",
            "singleNodeValue",
            "sinh",
            "sinkId",
            "sittingToStandingTransform",
            "size",
            "sizeToContent",
            "sizeX",
            "sizeZ",
            "sizes",
            "skewX",
            "skewXSelf",
            "skewY",
            "skewYSelf",
            "slice",
            "slope",
            "slot",
            "small",
            "smil",
            "smooth",
            "smoothingTimeConstant",
            "snapToLines",
            "snapshotItem",
            "snapshotLength",
            "some",
            "sort",
            "sortingCode",
            "source",
            "sourceBuffer",
            "sourceBuffers",
            "sourceCapabilities",
            "sourceFile",
            "sourceIndex",
            "sources",
            "spacing",
            "span",
            "speak",
            "speakAs",
            "speaking",
            "species",
            "specified",
            "specularConstant",
            "specularExponent",
            "speechSynthesis",
            "speed",
            "speedOfSound",
            "spellcheck",
            "splice",
            "split",
            "splitText",
            "spreadMethod",
            "sqrt",
            "src",
            "srcElement",
            "srcFilter",
            "srcObject",
            "srcUrn",
            "srcdoc",
            "srclang",
            "srcset",
            "stack",
            "stackTraceLimit",
            "stacktrace",
            "stageParameters",
            "standalone",
            "standby",
            "start",
            "startContainer",
            "startIce",
            "startMessages",
            "startNotifications",
            "startOffset",
            "startProfiling",
            "startRendering",
            "startShark",
            "startTime",
            "startsWith",
            "state",
            "status",
            "statusCode",
            "statusMessage",
            "statusText",
            "statusbar",
            "stdDeviationX",
            "stdDeviationY",
            "stencilFunc",
            "stencilFuncSeparate",
            "stencilMask",
            "stencilMaskSeparate",
            "stencilOp",
            "stencilOpSeparate",
            "step",
            "stepDown",
            "stepMismatch",
            "stepUp",
            "sticky",
            "stitchTiles",
            "stop",
            "stop-color",
            "stop-opacity",
            "stopColor",
            "stopImmediatePropagation",
            "stopNotifications",
            "stopOpacity",
            "stopProfiling",
            "stopPropagation",
            "stopShark",
            "stopped",
            "storage",
            "storageArea",
            "storageName",
            "storageStatus",
            "store",
            "storeSiteSpecificTrackingException",
            "storeWebWideTrackingException",
            "stpVersion",
            "stream",
            "streams",
            "stretch",
            "strike",
            "string",
            "stringValue",
            "stringify",
            "stroke",
            "stroke-dasharray",
            "stroke-dashoffset",
            "stroke-linecap",
            "stroke-linejoin",
            "stroke-miterlimit",
            "stroke-opacity",
            "stroke-width",
            "strokeDasharray",
            "strokeDashoffset",
            "strokeLinecap",
            "strokeLinejoin",
            "strokeMiterlimit",
            "strokeOpacity",
            "strokeRect",
            "strokeStyle",
            "strokeText",
            "strokeWidth",
            "style",
            "styleFloat",
            "styleMap",
            "styleMedia",
            "styleSheet",
            "styleSheetSets",
            "styleSheets",
            "sub",
            "subarray",
            "subject",
            "submit",
            "submitFrame",
            "submitter",
            "subscribe",
            "substr",
            "substring",
            "substringData",
            "subtle",
            "subtree",
            "suffix",
            "suffixes",
            "summary",
            "sup",
            "supported",
            "supportedContentEncodings",
            "supportedEntryTypes",
            "supports",
            "supportsSession",
            "surfaceScale",
            "surroundContents",
            "suspend",
            "suspendRedraw",
            "swapCache",
            "swapNode",
            "sweepFlag",
            "symbols",
            "sync",
            "sysexEnabled",
            "system",
            "systemCode",
            "systemId",
            "systemLanguage",
            "systemXDPI",
            "systemYDPI",
            "tBodies",
            "tFoot",
            "tHead",
            "tabIndex",
            "table",
            "table-layout",
            "tableLayout",
            "tableValues",
            "tag",
            "tagName",
            "tagUrn",
            "tags",
            "taintEnabled",
            "takePhoto",
            "takeRecords",
            "tan",
            "tangentialPressure",
            "tanh",
            "target",
            "targetElement",
            "targetRayMode",
            "targetRaySpace",
            "targetTouches",
            "targetX",
            "targetY",
            "tcpType",
            "tee",
            "tel",
            "terminate",
            "test",
            "texImage2D",
            "texImage3D",
            "texParameterf",
            "texParameteri",
            "texStorage2D",
            "texStorage3D",
            "texSubImage2D",
            "texSubImage3D",
            "text",
            "text-align",
            "text-align-last",
            "text-anchor",
            "text-combine-upright",
            "text-decoration",
            "text-decoration-color",
            "text-decoration-line",
            "text-decoration-skip-ink",
            "text-decoration-style",
            "text-decoration-thickness",
            "text-emphasis",
            "text-emphasis-color",
            "text-emphasis-position",
            "text-emphasis-style",
            "text-indent",
            "text-justify",
            "text-orientation",
            "text-overflow",
            "text-rendering",
            "text-shadow",
            "text-transform",
            "text-underline-offset",
            "text-underline-position",
            "textAlign",
            "textAlignLast",
            "textAnchor",
            "textAutospace",
            "textBaseline",
            "textCombineUpright",
            "textContent",
            "textDecoration",
            "textDecorationBlink",
            "textDecorationColor",
            "textDecorationLine",
            "textDecorationLineThrough",
            "textDecorationNone",
            "textDecorationOverline",
            "textDecorationSkipInk",
            "textDecorationStyle",
            "textDecorationThickness",
            "textDecorationUnderline",
            "textEmphasis",
            "textEmphasisColor",
            "textEmphasisPosition",
            "textEmphasisStyle",
            "textIndent",
            "textJustify",
            "textJustifyTrim",
            "textKashida",
            "textKashidaSpace",
            "textLength",
            "textOrientation",
            "textOverflow",
            "textRendering",
            "textShadow",
            "textTracks",
            "textTransform",
            "textUnderlineOffset",
            "textUnderlinePosition",
            "then",
            "threadId",
            "threshold",
            "thresholds",
            "tiltX",
            "tiltY",
            "time",
            "timeEnd",
            "timeLog",
            "timeOrigin",
            "timeRemaining",
            "timeStamp",
            "timecode",
            "timeline",
            "timelineTime",
            "timeout",
            "timestamp",
            "timestampOffset",
            "timing",
            "title",
            "to",
            "toArray",
            "toBlob",
            "toDataURL",
            "toDateString",
            "toElement",
            "toExponential",
            "toFixed",
            "toFloat32Array",
            "toFloat64Array",
            "toGMTString",
            "toISOString",
            "toJSON",
            "toLocaleDateString",
            "toLocaleFormat",
            "toLocaleLowerCase",
            "toLocaleString",
            "toLocaleTimeString",
            "toLocaleUpperCase",
            "toLowerCase",
            "toMatrix",
            "toMethod",
            "toPrecision",
            "toPrimitive",
            "toSdp",
            "toSource",
            "toStaticHTML",
            "toString",
            "toStringTag",
            "toSum",
            "toTimeString",
            "toUTCString",
            "toUpperCase",
            "toggle",
            "toggleAttribute",
            "toggleLongPressEnabled",
            "tone",
            "toneBuffer",
            "tooLong",
            "tooShort",
            "toolbar",
            "top",
            "topMargin",
            "total",
            "totalFrameDelay",
            "totalVideoFrames",
            "touch-action",
            "touchAction",
            "touched",
            "touches",
            "trace",
            "track",
            "trackVisibility",
            "transaction",
            "transactions",
            "transceiver",
            "transferControlToOffscreen",
            "transferFromImageBitmap",
            "transferImageBitmap",
            "transferIn",
            "transferOut",
            "transferSize",
            "transferToImageBitmap",
            "transform",
            "transform-box",
            "transform-origin",
            "transform-style",
            "transformBox",
            "transformFeedbackVaryings",
            "transformOrigin",
            "transformPoint",
            "transformString",
            "transformStyle",
            "transformToDocument",
            "transformToFragment",
            "transition",
            "transition-delay",
            "transition-duration",
            "transition-property",
            "transition-timing-function",
            "transitionDelay",
            "transitionDuration",
            "transitionProperty",
            "transitionTimingFunction",
            "translate",
            "translateSelf",
            "translationX",
            "translationY",
            "transport",
            "trim",
            "trimEnd",
            "trimLeft",
            "trimRight",
            "trimStart",
            "trueSpeed",
            "trunc",
            "truncate",
            "trustedTypes",
            "turn",
            "twist",
            "type",
            "typeDetail",
            "typeMismatch",
            "typeMustMatch",
            "types",
            "u2f",
            "ubound",
            "uint16",
            "uint32",
            "uint8",
            "uint8Clamped",
            "undefined",
            "unescape",
            "uneval",
            "unicode",
            "unicode-bidi",
            "unicodeBidi",
            "unicodeRange",
            "uniform1f",
            "uniform1fv",
            "uniform1i",
            "uniform1iv",
            "uniform1ui",
            "uniform1uiv",
            "uniform2f",
            "uniform2fv",
            "uniform2i",
            "uniform2iv",
            "uniform2ui",
            "uniform2uiv",
            "uniform3f",
            "uniform3fv",
            "uniform3i",
            "uniform3iv",
            "uniform3ui",
            "uniform3uiv",
            "uniform4f",
            "uniform4fv",
            "uniform4i",
            "uniform4iv",
            "uniform4ui",
            "uniform4uiv",
            "uniformBlockBinding",
            "uniformMatrix2fv",
            "uniformMatrix2x3fv",
            "uniformMatrix2x4fv",
            "uniformMatrix3fv",
            "uniformMatrix3x2fv",
            "uniformMatrix3x4fv",
            "uniformMatrix4fv",
            "uniformMatrix4x2fv",
            "uniformMatrix4x3fv",
            "unique",
            "uniqueID",
            "uniqueNumber",
            "unit",
            "unitType",
            "units",
            "unloadEventEnd",
            "unloadEventStart",
            "unlock",
            "unmount",
            "unobserve",
            "unpause",
            "unpauseAnimations",
            "unreadCount",
            "unregister",
            "unregisterContentHandler",
            "unregisterProtocolHandler",
            "unscopables",
            "unselectable",
            "unshift",
            "unsubscribe",
            "unsuspendRedraw",
            "unsuspendRedrawAll",
            "unwatch",
            "unwrapKey",
            "upDegrees",
            "upX",
            "upY",
            "upZ",
            "update",
            "updateCommands",
            "updateIce",
            "updateInterval",
            "updatePlaybackRate",
            "updateRenderState",
            "updateSettings",
            "updateTiming",
            "updateViaCache",
            "updateWith",
            "updated",
            "updating",
            "upgrade",
            "upload",
            "uploadTotal",
            "uploaded",
            "upper",
            "upperBound",
            "upperOpen",
            "uri",
            "url",
            "urn",
            "urns",
            "usages",
            "usb",
            "usbVersionMajor",
            "usbVersionMinor",
            "usbVersionSubminor",
            "useCurrentView",
            "useMap",
            "useProgram",
            "usedSpace",
            "user-select",
            "userActivation",
            "userAgent",
            "userAgentData",
            "userChoice",
            "userHandle",
            "userHint",
            "userLanguage",
            "userSelect",
            "userVisibleOnly",
            "username",
            "usernameFragment",
            "utterance",
            "uuid",
            "v8BreakIterator",
            "vAlign",
            "vLink",
            "valid",
            "validate",
            "validateProgram",
            "validationMessage",
            "validity",
            "value",
            "valueAsDate",
            "valueAsNumber",
            "valueAsString",
            "valueInSpecifiedUnits",
            "valueMissing",
            "valueOf",
            "valueText",
            "valueType",
            "values",
            "variable",
            "variant",
            "variationSettings",
            "vector-effect",
            "vectorEffect",
            "velocityAngular",
            "velocityExpansion",
            "velocityX",
            "velocityY",
            "vendor",
            "vendorId",
            "vendorSub",
            "verify",
            "version",
            "vertexAttrib1f",
            "vertexAttrib1fv",
            "vertexAttrib2f",
            "vertexAttrib2fv",
            "vertexAttrib3f",
            "vertexAttrib3fv",
            "vertexAttrib4f",
            "vertexAttrib4fv",
            "vertexAttribDivisor",
            "vertexAttribDivisorANGLE",
            "vertexAttribI4i",
            "vertexAttribI4iv",
            "vertexAttribI4ui",
            "vertexAttribI4uiv",
            "vertexAttribIPointer",
            "vertexAttribPointer",
            "vertical",
            "vertical-align",
            "verticalAlign",
            "verticalOverflow",
            "vh",
            "vibrate",
            "vibrationActuator",
            "videoBitsPerSecond",
            "videoHeight",
            "videoTracks",
            "videoWidth",
            "view",
            "viewBox",
            "viewBoxString",
            "viewTarget",
            "viewTargetString",
            "viewport",
            "viewportAnchorX",
            "viewportAnchorY",
            "viewportElement",
            "views",
            "violatedDirective",
            "visibility",
            "visibilityState",
            "visible",
            "visualViewport",
            "vlinkColor",
            "vmax",
            "vmin",
            "voice",
            "voiceURI",
            "volume",
            "vrml",
            "vspace",
            "vw",
            "w",
            "wait",
            "waitSync",
            "waiting",
            "wake",
            "wakeLock",
            "wand",
            "warn",
            "wasClean",
            "wasDiscarded",
            "watch",
            "watchAvailability",
            "watchPosition",
            "webdriver",
            "webkitAddKey",
            "webkitAlignContent",
            "webkitAlignItems",
            "webkitAlignSelf",
            "webkitAnimation",
            "webkitAnimationDelay",
            "webkitAnimationDirection",
            "webkitAnimationDuration",
            "webkitAnimationFillMode",
            "webkitAnimationIterationCount",
            "webkitAnimationName",
            "webkitAnimationPlayState",
            "webkitAnimationTimingFunction",
            "webkitAppearance",
            "webkitAudioContext",
            "webkitAudioDecodedByteCount",
            "webkitAudioPannerNode",
            "webkitBackfaceVisibility",
            "webkitBackground",
            "webkitBackgroundAttachment",
            "webkitBackgroundClip",
            "webkitBackgroundColor",
            "webkitBackgroundImage",
            "webkitBackgroundOrigin",
            "webkitBackgroundPosition",
            "webkitBackgroundPositionX",
            "webkitBackgroundPositionY",
            "webkitBackgroundRepeat",
            "webkitBackgroundSize",
            "webkitBackingStorePixelRatio",
            "webkitBorderBottomLeftRadius",
            "webkitBorderBottomRightRadius",
            "webkitBorderImage",
            "webkitBorderImageOutset",
            "webkitBorderImageRepeat",
            "webkitBorderImageSlice",
            "webkitBorderImageSource",
            "webkitBorderImageWidth",
            "webkitBorderRadius",
            "webkitBorderTopLeftRadius",
            "webkitBorderTopRightRadius",
            "webkitBoxAlign",
            "webkitBoxDirection",
            "webkitBoxFlex",
            "webkitBoxOrdinalGroup",
            "webkitBoxOrient",
            "webkitBoxPack",
            "webkitBoxShadow",
            "webkitBoxSizing",
            "webkitCancelAnimationFrame",
            "webkitCancelFullScreen",
            "webkitCancelKeyRequest",
            "webkitCancelRequestAnimationFrame",
            "webkitClearResourceTimings",
            "webkitClosedCaptionsVisible",
            "webkitConvertPointFromNodeToPage",
            "webkitConvertPointFromPageToNode",
            "webkitCreateShadowRoot",
            "webkitCurrentFullScreenElement",
            "webkitCurrentPlaybackTargetIsWireless",
            "webkitDecodedFrameCount",
            "webkitDirectionInvertedFromDevice",
            "webkitDisplayingFullscreen",
            "webkitDroppedFrameCount",
            "webkitEnterFullScreen",
            "webkitEnterFullscreen",
            "webkitEntries",
            "webkitExitFullScreen",
            "webkitExitFullscreen",
            "webkitExitPointerLock",
            "webkitFilter",
            "webkitFlex",
            "webkitFlexBasis",
            "webkitFlexDirection",
            "webkitFlexFlow",
            "webkitFlexGrow",
            "webkitFlexShrink",
            "webkitFlexWrap",
            "webkitFullScreenKeyboardInputAllowed",
            "webkitFullscreenElement",
            "webkitFullscreenEnabled",
            "webkitGenerateKeyRequest",
            "webkitGetAsEntry",
            "webkitGetDatabaseNames",
            "webkitGetEntries",
            "webkitGetEntriesByName",
            "webkitGetEntriesByType",
            "webkitGetFlowByName",
            "webkitGetGamepads",
            "webkitGetImageDataHD",
            "webkitGetNamedFlows",
            "webkitGetRegionFlowRanges",
            "webkitGetUserMedia",
            "webkitHasClosedCaptions",
            "webkitHidden",
            "webkitIDBCursor",
            "webkitIDBDatabase",
            "webkitIDBDatabaseError",
            "webkitIDBDatabaseException",
            "webkitIDBFactory",
            "webkitIDBIndex",
            "webkitIDBKeyRange",
            "webkitIDBObjectStore",
            "webkitIDBRequest",
            "webkitIDBTransaction",
            "webkitImageSmoothingEnabled",
            "webkitIndexedDB",
            "webkitInitMessageEvent",
            "webkitIsFullScreen",
            "webkitJustifyContent",
            "webkitKeys",
            "webkitLineClamp",
            "webkitLineDashOffset",
            "webkitLockOrientation",
            "webkitMask",
            "webkitMaskClip",
            "webkitMaskComposite",
            "webkitMaskImage",
            "webkitMaskOrigin",
            "webkitMaskPosition",
            "webkitMaskPositionX",
            "webkitMaskPositionY",
            "webkitMaskRepeat",
            "webkitMaskSize",
            "webkitMatchesSelector",
            "webkitMediaStream",
            "webkitNotifications",
            "webkitOfflineAudioContext",
            "webkitOrder",
            "webkitOrientation",
            "webkitPeerConnection00",
            "webkitPersistentStorage",
            "webkitPerspective",
            "webkitPerspectiveOrigin",
            "webkitPointerLockElement",
            "webkitPostMessage",
            "webkitPreservesPitch",
            "webkitPutImageDataHD",
            "webkitRTCPeerConnection",
            "webkitRegionOverset",
            "webkitRelativePath",
            "webkitRequestAnimationFrame",
            "webkitRequestFileSystem",
            "webkitRequestFullScreen",
            "webkitRequestFullscreen",
            "webkitRequestPointerLock",
            "webkitResolveLocalFileSystemURL",
            "webkitSetMediaKeys",
            "webkitSetResourceTimingBufferSize",
            "webkitShadowRoot",
            "webkitShowPlaybackTargetPicker",
            "webkitSlice",
            "webkitSpeechGrammar",
            "webkitSpeechGrammarList",
            "webkitSpeechRecognition",
            "webkitSpeechRecognitionError",
            "webkitSpeechRecognitionEvent",
            "webkitStorageInfo",
            "webkitSupportsFullscreen",
            "webkitTemporaryStorage",
            "webkitTextFillColor",
            "webkitTextSizeAdjust",
            "webkitTextStroke",
            "webkitTextStrokeColor",
            "webkitTextStrokeWidth",
            "webkitTransform",
            "webkitTransformOrigin",
            "webkitTransformStyle",
            "webkitTransition",
            "webkitTransitionDelay",
            "webkitTransitionDuration",
            "webkitTransitionProperty",
            "webkitTransitionTimingFunction",
            "webkitURL",
            "webkitUnlockOrientation",
            "webkitUserSelect",
            "webkitVideoDecodedByteCount",
            "webkitVisibilityState",
            "webkitWirelessVideoPlaybackDisabled",
            "webkitdirectory",
            "webkitdropzone",
            "webstore",
            "weight",
            "whatToShow",
            "wheelDelta",
            "wheelDeltaX",
            "wheelDeltaY",
            "whenDefined",
            "which",
            "white-space",
            "whiteSpace",
            "wholeText",
            "widows",
            "width",
            "will-change",
            "willChange",
            "willValidate",
            "window",
            "withCredentials",
            "word-break",
            "word-spacing",
            "word-wrap",
            "wordBreak",
            "wordSpacing",
            "wordWrap",
            "workerStart",
            "wow64",
            "wrap",
            "wrapKey",
            "writable",
            "writableAuxiliaries",
            "write",
            "writeText",
            "writeValue",
            "writeWithoutResponse",
            "writeln",
            "writing-mode",
            "writingMode",
            "x",
            "x1",
            "x2",
            "xChannelSelector",
            "xmlEncoding",
            "xmlStandalone",
            "xmlVersion",
            "xmlbase",
            "xmllang",
            "xmlspace",
            "xor",
            "xr",
            "y",
            "y1",
            "y2",
            "yChannelSelector",
            "yandex",
            "z",
            "z-index",
            "zIndex",
            "zoom",
            "zoomAndPan",
            "zoomRectScreen",
        ];
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function find_builtins(reserved) {
            domprops.forEach(add);
            // Compatibility fix for some standard defined globals not defined on every js environment
            var new_globals = ["Symbol", "Map", "Promise", "Proxy", "Reflect", "Set", "WeakMap", "WeakSet"];
            var objects = {};
            var global_ref = typeof global === "object" ? global : self;
            new_globals.forEach(function (new_global) {
                objects[new_global] = global_ref[new_global] || function () { };
            });
            [
                "null",
                "true",
                "false",
                "NaN",
                "Infinity",
                "-Infinity",
                "undefined",
            ].forEach(add);
            [Object, Array, Function, Number,
                String, Boolean, Error, Math,
                Date, RegExp, objects.Symbol, ArrayBuffer,
                DataView, decodeURI, decodeURIComponent,
                encodeURI, encodeURIComponent, eval, EvalError,
                Float32Array, Float64Array, Int8Array, Int16Array,
                Int32Array, isFinite, isNaN, JSON, objects.Map, parseFloat,
                parseInt, objects.Promise, objects.Proxy, RangeError, ReferenceError,
                objects.Reflect, objects.Set, SyntaxError, TypeError, Uint8Array,
                Uint8ClampedArray, Uint16Array, Uint32Array, URIError,
                objects.WeakMap, objects.WeakSet
            ].forEach(function (ctor) {
                Object.getOwnPropertyNames(ctor).map(add);
                if (ctor.prototype) {
                    Object.getOwnPropertyNames(ctor.prototype).map(add);
                }
            });
            function add(name) {
                reserved.add(name);
            }
        }
        function reserve_quoted_keys(ast, reserved) {
            function add(name) {
                push_uniq(reserved, name);
            }
            ast.walk(new TreeWalker(function (node) {
                if (node instanceof AST_ObjectKeyVal && node.quote) {
                    add(node.key);
                }
                else if (node instanceof AST_ObjectProperty && node.quote) {
                    add(node.key.name);
                }
                else if (node instanceof AST_Sub) {
                    addStrings(node.property, add);
                }
            }));
        }
        function addStrings(node, add) {
            node.walk(new TreeWalker(function (node) {
                if (node instanceof AST_Sequence) {
                    addStrings(node.tail_node(), add);
                }
                else if (node instanceof AST_String) {
                    add(node.value);
                }
                else if (node instanceof AST_Conditional) {
                    addStrings(node.consequent, add);
                    addStrings(node.alternative, add);
                }
                return true;
            }));
        }
        function mangle_private_properties(ast, options) {
            var cprivate = -1;
            var private_cache = new Map();
            var nth_identifier = options.nth_identifier || base54;
            ast = ast.transform(new TreeTransformer(function (node) {
                if (node instanceof AST_ClassPrivateProperty
                    || node instanceof AST_PrivateMethod
                    || node instanceof AST_PrivateGetter
                    || node instanceof AST_PrivateSetter
                    || node instanceof AST_PrivateIn) {
                    node.key.name = mangle_private(node.key.name);
                }
                else if (node instanceof AST_DotHash) {
                    node.property = mangle_private(node.property);
                }
            }));
            return ast;
            function mangle_private(name) {
                let mangled = private_cache.get(name);
                if (!mangled) {
                    mangled = nth_identifier.get(++cprivate);
                    private_cache.set(name, mangled);
                }
                return mangled;
            }
        }
        function mangle_properties(ast, options) {
            options = defaults(options, {
                builtins: false,
                cache: null,
                debug: false,
                keep_quoted: false,
                nth_identifier: base54,
                only_cache: false,
                regex: null,
                reserved: null,
                undeclared: false,
            }, true);
            var nth_identifier = options.nth_identifier;
            var reserved_option = options.reserved;
            if (!Array.isArray(reserved_option))
                reserved_option = [reserved_option];
            var reserved = new Set(reserved_option);
            if (!options.builtins)
                find_builtins(reserved);
            var cname = -1;
            var cache;
            if (options.cache) {
                cache = options.cache.props;
            }
            else {
                cache = new Map();
            }
            var regex = options.regex && new RegExp(options.regex);
            // note debug is either false (disabled), or a string of the debug suffix to use (enabled).
            // note debug may be enabled as an empty string, which is falsey. Also treat passing 'true'
            // the same as passing an empty string.
            var debug = options.debug !== false;
            var debug_name_suffix;
            if (debug) {
                debug_name_suffix = (options.debug === true ? "" : options.debug);
            }
            var names_to_mangle = new Set();
            var unmangleable = new Set();
            // Track each already-mangled name to prevent nth_identifier from generating
            // the same name.
            cache.forEach((mangled_name) => unmangleable.add(mangled_name));
            var keep_quoted = !!options.keep_quoted;
            // step 1: find candidates to mangle
            ast.walk(new TreeWalker(function (node) {
                if (node instanceof AST_ClassPrivateProperty
                    || node instanceof AST_PrivateMethod
                    || node instanceof AST_PrivateGetter
                    || node instanceof AST_PrivateSetter
                    || node instanceof AST_DotHash)
                    ;
                else if (node instanceof AST_ObjectKeyVal) {
                    if (typeof node.key == "string" && (!keep_quoted || !node.quote)) {
                        add(node.key);
                    }
                }
                else if (node instanceof AST_ObjectProperty) {
                    // setter or getter, since KeyVal is handled above
                    if (!keep_quoted || !node.quote) {
                        add(node.key.name);
                    }
                }
                else if (node instanceof AST_Dot) {
                    var declared = !!options.undeclared;
                    if (!declared) {
                        var root = node;
                        while (root.expression) {
                            root = root.expression;
                        }
                        declared = !(root.thedef && root.thedef.undeclared);
                    }
                    if (declared &&
                        (!keep_quoted || !node.quote)) {
                        add(node.property);
                    }
                }
                else if (node instanceof AST_Sub) {
                    if (!keep_quoted) {
                        addStrings(node.property, add);
                    }
                }
                else if (node instanceof AST_Call
                    && node.expression.print_to_string() == "Object.defineProperty") {
                    addStrings(node.args[1], add);
                }
                else if (node instanceof AST_Binary && node.operator === "in") {
                    addStrings(node.left, add);
                }
            }));
            // step 2: transform the tree, renaming properties
            return ast.transform(new TreeTransformer(function (node) {
                if (node instanceof AST_ClassPrivateProperty
                    || node instanceof AST_PrivateMethod
                    || node instanceof AST_PrivateGetter
                    || node instanceof AST_PrivateSetter
                    || node instanceof AST_DotHash)
                    ;
                else if (node instanceof AST_ObjectKeyVal) {
                    if (typeof node.key == "string" && (!keep_quoted || !node.quote)) {
                        node.key = mangle(node.key);
                    }
                }
                else if (node instanceof AST_ObjectProperty) {
                    // setter, getter, method or class field
                    if (!keep_quoted || !node.quote) {
                        node.key.name = mangle(node.key.name);
                    }
                }
                else if (node instanceof AST_Dot) {
                    if (!keep_quoted || !node.quote) {
                        node.property = mangle(node.property);
                    }
                }
                else if (!keep_quoted && node instanceof AST_Sub) {
                    node.property = mangleStrings(node.property);
                }
                else if (node instanceof AST_Call
                    && node.expression.print_to_string() == "Object.defineProperty") {
                    node.args[1] = mangleStrings(node.args[1]);
                }
                else if (node instanceof AST_Binary && node.operator === "in") {
                    node.left = mangleStrings(node.left);
                }
            }));
            // only function declarations after this line
            function can_mangle(name) {
                if (unmangleable.has(name))
                    return false;
                if (reserved.has(name))
                    return false;
                if (options.only_cache) {
                    return cache.has(name);
                }
                if (/^-?[0-9]+(\.[0-9]+)?(e[+-][0-9]+)?$/.test(name))
                    return false;
                return true;
            }
            function should_mangle(name) {
                if (regex && !regex.test(name))
                    return false;
                if (reserved.has(name))
                    return false;
                return cache.has(name)
                    || names_to_mangle.has(name);
            }
            function add(name) {
                if (can_mangle(name))
                    names_to_mangle.add(name);
                if (!should_mangle(name)) {
                    unmangleable.add(name);
                }
            }
            function mangle(name) {
                if (!should_mangle(name)) {
                    return name;
                }
                var mangled = cache.get(name);
                if (!mangled) {
                    if (debug) {
                        // debug mode: use a prefix and suffix to preserve readability, e.g. o.foo -> o._$foo$NNN_.
                        var debug_mangled = "_$" + name + "$" + debug_name_suffix + "_";
                        if (can_mangle(debug_mangled)) {
                            mangled = debug_mangled;
                        }
                    }
                    // either debug mode is off, or it is on and we could not use the mangled name
                    if (!mangled) {
                        do {
                            mangled = nth_identifier.get(++cname);
                        } while (!can_mangle(mangled));
                    }
                    cache.set(name, mangled);
                }
                return mangled;
            }
            function mangleStrings(node) {
                return node.transform(new TreeTransformer(function (node) {
                    if (node instanceof AST_Sequence) {
                        var last = node.expressions.length - 1;
                        node.expressions[last] = mangleStrings(node.expressions[last]);
                    }
                    else if (node instanceof AST_String) {
                        node.value = mangle(node.value);
                    }
                    else if (node instanceof AST_Conditional) {
                        node.consequent = mangleStrings(node.consequent);
                        node.alternative = mangleStrings(node.alternative);
                    }
                    return node;
                }));
            }
        }
        // to/from base64 functions
        // Prefer built-in Buffer, if available, then use hack
        // https://developer.mozilla.org/en-US/docs/Glossary/Base64#The_Unicode_Problem
        var to_ascii = typeof Buffer !== "undefined"
            ? (b64) => Buffer.from(b64, "base64").toString()
            : (b64) => decodeURIComponent(escape(atob(b64)));
        var to_base64 = typeof Buffer !== "undefined"
            ? (str) => Buffer.from(str).toString("base64")
            : (str) => btoa(unescape(encodeURIComponent(str)));
        function read_source_map(code) {
            var match = /(?:^|[^.])\/\/# sourceMappingURL=data:application\/json(;[\w=-]*)?;base64,([+/0-9A-Za-z]*=*)\s*$/.exec(code);
            if (!match) {
                console.warn("inline source map not found");
                return null;
            }
            return to_ascii(match[2]);
        }
        function set_shorthand(name, options, keys) {
            if (options[name]) {
                keys.forEach(function (key) {
                    if (options[key]) {
                        if (typeof options[key] != "object")
                            options[key] = {};
                        if (!(name in options[key]))
                            options[key][name] = options[name];
                    }
                });
            }
        }
        function init_cache(cache) {
            if (!cache)
                return;
            if (!("props" in cache)) {
                cache.props = new Map();
            }
            else if (!(cache.props instanceof Map)) {
                cache.props = map_from_object(cache.props);
            }
        }
        function cache_to_json(cache) {
            return {
                props: map_to_object(cache.props)
            };
        }
        function log_input(files, options, fs, debug_folder) {
            if (!(fs && fs.writeFileSync && fs.mkdirSync)) {
                return;
            }
            try {
                fs.mkdirSync(debug_folder);
            }
            catch (e) {
                if (e.code !== "EEXIST")
                    throw e;
            }
            const log_path = `${debug_folder}/terser-debug-${(Math.random() * 9999999) | 0}.log`;
            options = options || {};
            const options_str = JSON.stringify(options, (_key, thing) => {
                if (typeof thing === "function")
                    return "[Function " + thing.toString() + "]";
                if (thing instanceof RegExp)
                    return "[RegExp " + thing.toString() + "]";
                return thing;
            }, 4);
            const files_str = (file) => {
                if (typeof file === "object" && options.parse && options.parse.spidermonkey) {
                    return JSON.stringify(file, null, 2);
                }
                else if (typeof file === "object") {
                    return Object.keys(file)
                        .map((key) => key + ": " + files_str(file[key]))
                        .join("\n\n");
                }
                else if (typeof file === "string") {
                    return "```\n" + file + "\n```";
                }
                else {
                    return file; // What do?
                }
            };
            fs.writeFileSync(log_path, "Options: \n" + options_str + "\n\nInput files:\n\n" + files_str(files) + "\n");
        }
        async function minify(files, options, _fs_module) {
            if (_fs_module
                && typeof process === "object"
                && process.env
                && typeof process.env.TERSER_DEBUG_DIR === "string") {
                log_input(files, options, _fs_module, process.env.TERSER_DEBUG_DIR);
            }
            options = defaults(options, {
                compress: {},
                ecma: undefined,
                enclose: false,
                ie8: false,
                keep_classnames: undefined,
                keep_fnames: false,
                mangle: {},
                module: false,
                nameCache: null,
                output: null,
                format: null,
                parse: {},
                rename: undefined,
                safari10: false,
                sourceMap: false,
                spidermonkey: false,
                timings: false,
                toplevel: false,
                warnings: false,
                wrap: false,
            }, true);
            var timings = options.timings && {
                start: Date.now()
            };
            if (options.keep_classnames === undefined) {
                options.keep_classnames = options.keep_fnames;
            }
            if (options.rename === undefined) {
                options.rename = options.compress && options.mangle;
            }
            if (options.output && options.format) {
                throw new Error("Please only specify either output or format option, preferrably format.");
            }
            options.format = options.format || options.output || {};
            set_shorthand("ecma", options, ["parse", "compress", "format"]);
            set_shorthand("ie8", options, ["compress", "mangle", "format"]);
            set_shorthand("keep_classnames", options, ["compress", "mangle"]);
            set_shorthand("keep_fnames", options, ["compress", "mangle"]);
            set_shorthand("module", options, ["parse", "compress", "mangle"]);
            set_shorthand("safari10", options, ["mangle", "format"]);
            set_shorthand("toplevel", options, ["compress", "mangle"]);
            set_shorthand("warnings", options, ["compress"]); // legacy
            var quoted_props;
            if (options.mangle) {
                options.mangle = defaults(options.mangle, {
                    cache: options.nameCache && (options.nameCache.vars || {}),
                    eval: false,
                    ie8: false,
                    keep_classnames: false,
                    keep_fnames: false,
                    module: false,
                    nth_identifier: base54,
                    properties: false,
                    reserved: [],
                    safari10: false,
                    toplevel: false,
                }, true);
                if (options.mangle.properties) {
                    if (typeof options.mangle.properties != "object") {
                        options.mangle.properties = {};
                    }
                    if (options.mangle.properties.keep_quoted) {
                        quoted_props = options.mangle.properties.reserved;
                        if (!Array.isArray(quoted_props))
                            quoted_props = [];
                        options.mangle.properties.reserved = quoted_props;
                    }
                    if (options.nameCache && !("cache" in options.mangle.properties)) {
                        options.mangle.properties.cache = options.nameCache.props || {};
                    }
                }
                init_cache(options.mangle.cache);
                init_cache(options.mangle.properties.cache);
            }
            if (options.sourceMap) {
                options.sourceMap = defaults(options.sourceMap, {
                    asObject: false,
                    content: null,
                    filename: null,
                    includeSources: false,
                    root: null,
                    url: null,
                }, true);
            }
            // -- Parse phase --
            if (timings)
                timings.parse = Date.now();
            var toplevel;
            if (files instanceof AST_Toplevel) {
                toplevel = files;
            }
            else {
                if (typeof files == "string" || (options.parse.spidermonkey && !Array.isArray(files))) {
                    files = [files];
                }
                options.parse = options.parse || {};
                options.parse.toplevel = null;
                if (options.parse.spidermonkey) {
                    options.parse.toplevel = AST_Node.from_mozilla_ast(Object.keys(files).reduce(function (toplevel, name) {
                        if (!toplevel)
                            return files[name];
                        toplevel.body = toplevel.body.concat(files[name].body);
                        return toplevel;
                    }, null));
                }
                else {
                    delete options.parse.spidermonkey;
                    for (var name in files)
                        if (HOP(files, name)) {
                            options.parse.filename = name;
                            options.parse.toplevel = parse(files[name], options.parse);
                            if (options.sourceMap && options.sourceMap.content == "inline") {
                                if (Object.keys(files).length > 1)
                                    throw new Error("inline source map only works with singular input");
                                options.sourceMap.content = read_source_map(files[name]);
                            }
                        }
                }
                toplevel = options.parse.toplevel;
            }
            if (quoted_props && options.mangle.properties.keep_quoted !== "strict") {
                reserve_quoted_keys(toplevel, quoted_props);
            }
            if (options.wrap) {
                toplevel = toplevel.wrap_commonjs(options.wrap);
            }
            if (options.enclose) {
                toplevel = toplevel.wrap_enclose(options.enclose);
            }
            if (timings)
                timings.rename = Date.now();
            // -- Compress phase --
            if (timings)
                timings.compress = Date.now();
            if (options.compress) {
                toplevel = new Compressor(options.compress, {
                    mangle_options: options.mangle
                }).compress(toplevel);
            }
            // -- Mangle phase --
            if (timings)
                timings.scope = Date.now();
            if (options.mangle)
                toplevel.figure_out_scope(options.mangle);
            if (timings)
                timings.mangle = Date.now();
            if (options.mangle) {
                toplevel.compute_char_frequency(options.mangle);
                toplevel.mangle_names(options.mangle);
                toplevel = mangle_private_properties(toplevel, options.mangle);
            }
            if (timings)
                timings.properties = Date.now();
            if (options.mangle && options.mangle.properties) {
                toplevel = mangle_properties(toplevel, options.mangle.properties);
            }
            // Format phase
            if (timings)
                timings.format = Date.now();
            var result = {};
            if (options.format.ast) {
                result.ast = toplevel;
            }
            if (options.format.spidermonkey) {
                result.ast = toplevel.to_mozilla_ast();
            }
            let format_options;
            if (!HOP(options.format, "code") || options.format.code) {
                // Make a shallow copy so that we can modify without mutating the user's input.
                format_options = { ...options.format };
                if (!format_options.ast) {
                    // Destroy stuff to save RAM. (unless the deprecated `ast` option is on)
                    format_options._destroy_ast = true;
                    walk(toplevel, node => {
                        if (node instanceof AST_Scope) {
                            node.variables = undefined;
                            node.enclosed = undefined;
                            node.parent_scope = undefined;
                        }
                        if (node.block_scope) {
                            node.block_scope.variables = undefined;
                            node.block_scope.enclosed = undefined;
                            node.parent_scope = undefined;
                        }
                    });
                }
                if (options.sourceMap) {
                    if (options.sourceMap.includeSources && files instanceof AST_Toplevel) {
                        throw new Error("original source content unavailable");
                    }
                    format_options.source_map = await SourceMap({
                        file: options.sourceMap.filename,
                        orig: options.sourceMap.content,
                        root: options.sourceMap.root,
                        files: options.sourceMap.includeSources ? files : null,
                    });
                }
                delete format_options.ast;
                delete format_options.code;
                delete format_options.spidermonkey;
                var stream = OutputStream(format_options);
                toplevel.print(stream);
                result.code = stream.get();
                if (options.sourceMap) {
                    Object.defineProperty(result, "map", {
                        configurable: true,
                        enumerable: true,
                        get() {
                            const map = format_options.source_map.getEncoded();
                            return (result.map = options.sourceMap.asObject ? map : JSON.stringify(map));
                        },
                        set(value) {
                            Object.defineProperty(result, "map", {
                                value,
                                writable: true,
                            });
                        }
                    });
                    result.decoded_map = format_options.source_map.getDecoded();
                    if (options.sourceMap.url == "inline") {
                        var sourceMap = typeof result.map === "object" ? JSON.stringify(result.map) : result.map;
                        result.code += "\n//# sourceMappingURL=data:application/json;charset=utf-8;base64," + to_base64(sourceMap);
                    }
                    else if (options.sourceMap.url) {
                        result.code += "\n//# sourceMappingURL=" + options.sourceMap.url;
                    }
                }
            }
            if (options.nameCache && options.mangle) {
                if (options.mangle.cache)
                    options.nameCache.vars = cache_to_json(options.mangle.cache);
                if (options.mangle.properties && options.mangle.properties.cache) {
                    options.nameCache.props = cache_to_json(options.mangle.properties.cache);
                }
            }
            if (format_options && format_options.source_map) {
                format_options.source_map.destroy();
            }
            if (timings) {
                timings.end = Date.now();
                result.timings = {
                    parse: 1e-3 * (timings.rename - timings.parse),
                    rename: 1e-3 * (timings.compress - timings.rename),
                    compress: 1e-3 * (timings.scope - timings.compress),
                    scope: 1e-3 * (timings.mangle - timings.scope),
                    mangle: 1e-3 * (timings.properties - timings.mangle),
                    properties: 1e-3 * (timings.format - timings.properties),
                    format: 1e-3 * (timings.end - timings.format),
                    total: 1e-3 * (timings.end - timings.start)
                };
            }
            return result;
        }
        async function run_cli({ program, packageJson, fs, path }) {
            const skip_keys = new Set(["cname", "parent_scope", "scope", "uses_eval", "uses_with"]);
            var files = {};
            var options = {
                compress: false,
                mangle: false
            };
            const default_options = await _default_options();
            program.version(packageJson.name + " " + packageJson.version);
            program.parseArgv = program.parse;
            program.parse = undefined;
            if (process.argv.includes("ast"))
                program.helpInformation = describe_ast;
            else if (process.argv.includes("options"))
                program.helpInformation = function () {
                    var text = [];
                    for (var option in default_options) {
                        text.push("--" + (option === "sourceMap" ? "source-map" : option) + " options:");
                        text.push(format_object(default_options[option]));
                        text.push("");
                    }
                    return text.join("\n");
                };
            program.option("-p, --parse <options>", "Specify parser options.", parse_js());
            program.option("-c, --compress [options]", "Enable compressor/specify compressor options.", parse_js());
            program.option("-m, --mangle [options]", "Mangle names/specify mangler options.", parse_js());
            program.option("--mangle-props [options]", "Mangle properties/specify mangler options.", parse_js());
            program.option("-f, --format [options]", "Format options.", parse_js());
            program.option("-b, --beautify [options]", "Alias for --format.", parse_js());
            program.option("-o, --output <file>", "Output file (default STDOUT).");
            program.option("--comments [filter]", "Preserve copyright comments in the output.");
            program.option("--config-file <file>", "Read minify() options from JSON file.");
            program.option("-d, --define <expr>[=value]", "Global definitions.", parse_js("define"));
            program.option("--ecma <version>", "Specify ECMAScript release: 5, 2015, 2016 or 2017...");
            program.option("-e, --enclose [arg[,...][:value[,...]]]", "Embed output in a big function with configurable arguments and values.");
            program.option("--ie8", "Support non-standard Internet Explorer 8.");
            program.option("--keep-classnames", "Do not mangle/drop class names.");
            program.option("--keep-fnames", "Do not mangle/drop function names. Useful for code relying on Function.prototype.name.");
            program.option("--module", "Input is an ES6 module");
            program.option("--name-cache <file>", "File to hold mangled name mappings.");
            program.option("--rename", "Force symbol expansion.");
            program.option("--no-rename", "Disable symbol expansion.");
            program.option("--safari10", "Support non-standard Safari 10.");
            program.option("--source-map [options]", "Enable source map/specify source map options.", parse_js());
            program.option("--timings", "Display operations run time on STDERR.");
            program.option("--toplevel", "Compress and/or mangle variables in toplevel scope.");
            program.option("--wrap <name>", "Embed everything as a function with “exports” corresponding to “name” globally.");
            program.arguments("[files...]").parseArgv(process.argv);
            if (program.configFile) {
                options = JSON.parse(read_file(program.configFile));
            }
            if (!program.output && program.sourceMap && program.sourceMap.url != "inline") {
                fatal("ERROR: cannot write source map to STDOUT");
            }
            [
                "compress",
                "enclose",
                "ie8",
                "mangle",
                "module",
                "safari10",
                "sourceMap",
                "toplevel",
                "wrap"
            ].forEach(function (name) {
                if (name in program) {
                    options[name] = program[name];
                }
            });
            if ("ecma" in program) {
                if (program.ecma != (program.ecma | 0))
                    fatal("ERROR: ecma must be an integer");
                const ecma = program.ecma | 0;
                if (ecma > 5 && ecma < 2015)
                    options.ecma = ecma + 2009;
                else
                    options.ecma = ecma;
            }
            if (program.format || program.beautify) {
                const chosenOption = program.format || program.beautify;
                options.format = typeof chosenOption === "object" ? chosenOption : {};
            }
            if (program.comments) {
                if (typeof options.format != "object")
                    options.format = {};
                options.format.comments = typeof program.comments == "string" ? (program.comments == "false" ? false : program.comments) : "some";
            }
            if (program.define) {
                if (typeof options.compress != "object")
                    options.compress = {};
                if (typeof options.compress.global_defs != "object")
                    options.compress.global_defs = {};
                for (var expr in program.define) {
                    options.compress.global_defs[expr] = program.define[expr];
                }
            }
            if (program.keepClassnames) {
                options.keep_classnames = true;
            }
            if (program.keepFnames) {
                options.keep_fnames = true;
            }
            if (program.mangleProps) {
                if (program.mangleProps.domprops) {
                    delete program.mangleProps.domprops;
                }
                else {
                    if (typeof program.mangleProps != "object")
                        program.mangleProps = {};
                    if (!Array.isArray(program.mangleProps.reserved))
                        program.mangleProps.reserved = [];
                }
                if (typeof options.mangle != "object")
                    options.mangle = {};
                options.mangle.properties = program.mangleProps;
            }
            if (program.nameCache) {
                options.nameCache = JSON.parse(read_file(program.nameCache, "{}"));
            }
            if (program.output == "ast") {
                options.format = {
                    ast: true,
                    code: false
                };
            }
            if (program.parse) {
                if (!program.parse.acorn && !program.parse.spidermonkey) {
                    options.parse = program.parse;
                }
                else if (program.sourceMap && program.sourceMap.content == "inline") {
                    fatal("ERROR: inline source map only works with built-in parser");
                }
            }
            if (~program.rawArgs.indexOf("--rename")) {
                options.rename = true;
            }
            else if (!program.rename) {
                options.rename = false;
            }
            let convert_path = name => name;
            if (typeof program.sourceMap == "object" && "base" in program.sourceMap) {
                convert_path = function () {
                    var base = program.sourceMap.base;
                    delete options.sourceMap.base;
                    return function (name) {
                        return path.relative(base, name);
                    };
                }();
            }
            let filesList;
            if (options.files && options.files.length) {
                filesList = options.files;
                delete options.files;
            }
            else if (program.args.length) {
                filesList = program.args;
            }
            if (filesList) {
                simple_glob(filesList).forEach(function (name) {
                    files[convert_path(name)] = read_file(name);
                });
            }
            else {
                await new Promise((resolve) => {
                    var chunks = [];
                    process.stdin.setEncoding("utf8");
                    process.stdin.on("data", function (chunk) {
                        chunks.push(chunk);
                    }).on("end", function () {
                        files = [chunks.join("")];
                        resolve();
                    });
                    process.stdin.resume();
                });
            }
            await run_cli();
            function convert_ast(fn) {
                return AST_Node.from_mozilla_ast(Object.keys(files).reduce(fn, null));
            }
            async function run_cli() {
                var content = program.sourceMap && program.sourceMap.content;
                if (content && content !== "inline") {
                    options.sourceMap.content = read_file(content, content);
                }
                if (program.timings)
                    options.timings = true;
                try {
                    if (program.parse) {
                        if (program.parse.acorn) {
                            files = convert_ast(function (toplevel, name) {
                                return require(47) /* acorn */.parse(files[name], {
                                    ecmaVersion: 2018,
                                    locations: true,
                                    program: toplevel,
                                    sourceFile: name,
                                    sourceType: options.module || program.parse.module ? "module" : "script"
                                });
                            });
                        }
                        else if (program.parse.spidermonkey) {
                            files = convert_ast(function (toplevel, name) {
                                var obj = JSON.parse(files[name]);
                                if (!toplevel)
                                    return obj;
                                toplevel.body = toplevel.body.concat(obj.body);
                                return toplevel;
                            });
                        }
                    }
                }
                catch (ex) {
                    fatal(ex);
                }
                let result;
                try {
                    result = await minify(files, options, fs);
                }
                catch (ex) {
                    if (ex.name == "SyntaxError") {
                        print_error("Parse error at " + ex.filename + ":" + ex.line + "," + ex.col);
                        var col = ex.col;
                        var lines = files[ex.filename].split(/\r?\n/);
                        var line = lines[ex.line - 1];
                        if (!line && !col) {
                            line = lines[ex.line - 2];
                            col = line.length;
                        }
                        if (line) {
                            var limit = 70;
                            if (col > limit) {
                                line = line.slice(col - limit);
                                col = limit;
                            }
                            print_error(line.slice(0, 80));
                            print_error(line.slice(0, col).replace(/\S/g, " ") + "^");
                        }
                    }
                    if (ex.defs) {
                        print_error("Supported options:");
                        print_error(format_object(ex.defs));
                    }
                    fatal(ex);
                    return;
                }
                if (program.output == "ast") {
                    if (!options.compress && !options.mangle) {
                        result.ast.figure_out_scope({});
                    }
                    console.log(JSON.stringify(result.ast, function (key, value) {
                        if (value)
                            switch (key) {
                                case "thedef":
                                    return symdef(value);
                                case "enclosed":
                                    return value.length ? value.map(symdef) : undefined;
                                case "variables":
                                case "globals":
                                    return value.size ? collect_from_map(value, symdef) : undefined;
                            }
                        if (skip_keys.has(key))
                            return;
                        if (value instanceof AST_Token)
                            return;
                        if (value instanceof Map)
                            return;
                        if (value instanceof AST_Node) {
                            var result = {
                                _class: "AST_" + value.TYPE
                            };
                            if (value.block_scope) {
                                result.variables = value.block_scope.variables;
                                result.enclosed = value.block_scope.enclosed;
                            }
                            value.CTOR.PROPS.forEach(function (prop) {
                                if (prop !== "block_scope") {
                                    result[prop] = value[prop];
                                }
                            });
                            return result;
                        }
                        return value;
                    }, 2));
                }
                else if (program.output == "spidermonkey") {
                    try {
                        const minified = await minify(result.code, {
                            compress: false,
                            mangle: false,
                            format: {
                                ast: true,
                                code: false
                            }
                        }, fs);
                        console.log(JSON.stringify(minified.ast.to_mozilla_ast(), null, 2));
                    }
                    catch (ex) {
                        fatal(ex);
                        return;
                    }
                }
                else if (program.output) {
                    fs.writeFileSync(program.output, result.code);
                    if (options.sourceMap && options.sourceMap.url !== "inline" && result.map) {
                        fs.writeFileSync(program.output + ".map", result.map);
                    }
                }
                else {
                    console.log(result.code);
                }
                if (program.nameCache) {
                    fs.writeFileSync(program.nameCache, JSON.stringify(options.nameCache));
                }
                if (result.timings)
                    for (var phase in result.timings) {
                        print_error("- " + phase + ": " + result.timings[phase].toFixed(3) + "s");
                    }
            }
            function fatal(message) {
                if (message instanceof Error)
                    message = message.stack.replace(/^\S*?Error:/, "ERROR:");
                print_error(message);
                process.exit(1);
            }
            // A file glob function that only supports "*" and "?" wildcards in the basename.
            // Example: "foo/bar/*baz??.*.js"
            // Argument `glob` may be a string or an array of strings.
            // Returns an array of strings. Garbage in, garbage out.
            function simple_glob(glob) {
                if (Array.isArray(glob)) {
                    return [].concat.apply([], glob.map(simple_glob));
                }
                if (glob && glob.match(/[*?]/)) {
                    var dir = path.dirname(glob);
                    try {
                        var entries = fs.readdirSync(dir);
                    }
                    catch (ex) { }
                    if (entries) {
                        var pattern = "^" + path.basename(glob)
                            .replace(/[.+^$[\]\\(){}]/g, "\\$&")
                            .replace(/\*/g, "[^/\\\\]*")
                            .replace(/\?/g, "[^/\\\\]") + "$";
                        var mod = process.platform === "win32" ? "i" : "";
                        var rx = new RegExp(pattern, mod);
                        var results = entries.filter(function (name) {
                            return rx.test(name);
                        }).map(function (name) {
                            return path.join(dir, name);
                        });
                        if (results.length)
                            return results;
                    }
                }
                return [glob];
            }
            function read_file(path, default_value) {
                try {
                    return fs.readFileSync(path, "utf8");
                }
                catch (ex) {
                    if ((ex.code == "ENOENT" || ex.code == "ENAMETOOLONG") && default_value != null)
                        return default_value;
                    fatal(ex);
                }
            }
            function parse_js(flag) {
                return function (value, options) {
                    options = options || {};
                    try {
                        walk(parse(value, { expression: true }), node => {
                            if (node instanceof AST_Assign) {
                                var name = node.left.print_to_string();
                                var value = node.right;
                                if (flag) {
                                    options[name] = value;
                                }
                                else if (value instanceof AST_Array) {
                                    options[name] = value.elements.map(to_string);
                                }
                                else if (value instanceof AST_RegExp) {
                                    value = value.value;
                                    options[name] = new RegExp(value.source, value.flags);
                                }
                                else {
                                    options[name] = to_string(value);
                                }
                                return true;
                            }
                            if (node instanceof AST_Symbol || node instanceof AST_PropAccess) {
                                var name = node.print_to_string();
                                options[name] = true;
                                return true;
                            }
                            if (!(node instanceof AST_Sequence))
                                throw node;
                            function to_string(value) {
                                return value instanceof AST_Constant ? value.getValue() : value.print_to_string({
                                    quote_keys: true
                                });
                            }
                        });
                    }
                    catch (ex) {
                        if (flag) {
                            fatal("Error parsing arguments for '" + flag + "': " + value);
                        }
                        else {
                            options[value] = null;
                        }
                    }
                    return options;
                };
            }
            function symdef(def) {
                var ret = (1e6 + def.id) + " " + def.name;
                if (def.mangled_name)
                    ret += " " + def.mangled_name;
                return ret;
            }
            function collect_from_map(map, callback) {
                var result = [];
                map.forEach(function (def) {
                    result.push(callback(def));
                });
                return result;
            }
            function format_object(obj) {
                var lines = [];
                var padding = "";
                Object.keys(obj).map(function (name) {
                    if (padding.length < name.length)
                        padding = Array(name.length + 1).join(" ");
                    return [name, JSON.stringify(obj[name])];
                }).forEach(function (tokens) {
                    lines.push("  " + tokens[0] + padding.slice(tokens[0].length - 2) + tokens[1]);
                });
                return lines.join("\n");
            }
            function print_error(msg) {
                process.stderr.write(msg);
                process.stderr.write("\n");
            }
            function describe_ast() {
                var out = OutputStream({ beautify: true });
                function doitem(ctor) {
                    out.print("AST_" + ctor.TYPE);
                    const props = ctor.SELF_PROPS.filter(prop => !/^\$/.test(prop));
                    if (props.length > 0) {
                        out.space();
                        out.with_parens(function () {
                            props.forEach(function (prop, i) {
                                if (i)
                                    out.space();
                                out.print(prop);
                            });
                        });
                    }
                    if (ctor.documentation) {
                        out.space();
                        out.print_string(ctor.documentation);
                    }
                    if (ctor.SUBCLASSES.length > 0) {
                        out.space();
                        out.with_block(function () {
                            ctor.SUBCLASSES.forEach(function (ctor) {
                                out.indent();
                                doitem(ctor);
                                out.newline();
                            });
                        });
                    }
                }
                doitem(AST_Node);
                return out + "\n";
            }
        }
        async function _default_options() {
            const defs = {};
            Object.keys(infer_options({ 0: 0 })).forEach((component) => {
                const options = infer_options({
                    [component]: { 0: 0 }
                });
                if (options)
                    defs[component] = options;
            });
            return defs;
        }
        async function infer_options(options) {
            try {
                await minify("", options);
            }
            catch (error) {
                return error.defs;
            }
        }
        exports._default_options = _default_options;
        exports._run_cli = run_cli;
        exports.minify = minify;
    })));
},
/* @jridgewell/source-map/dist/source-map.umd.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
            typeof define === 'function' && define.amd ? define(['exports'], factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.sourceMap = {}));
    })(this, (function (exports) {
        'use strict';
        const comma = ','.charCodeAt(0);
        const semicolon = ';'.charCodeAt(0);
        const chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
        const intToChar = new Uint8Array(64); // 64 possible chars.
        const charToInteger = new Uint8Array(128); // z is 122 in ASCII
        for (let i = 0; i < chars.length; i++) {
            const c = chars.charCodeAt(i);
            charToInteger[c] = i;
            intToChar[i] = c;
        }
        // Provide a fallback for older environments.
        const td = typeof TextDecoder !== 'undefined'
            ? new TextDecoder()
            : typeof Buffer !== 'undefined'
                ? {
                    decode(buf) {
                        const out = Buffer.from(buf.buffer, buf.byteOffset, buf.byteLength);
                        return out.toString();
                    },
                }
                : {
                    decode(buf) {
                        let out = '';
                        for (let i = 0; i < buf.length; i++) {
                            out += String.fromCharCode(buf[i]);
                        }
                        return out;
                    },
                };
        function decode(mappings) {
            const state = new Int32Array(5);
            const decoded = [];
            let line = [];
            let sorted = true;
            let lastCol = 0;
            for (let i = 0; i < mappings.length;) {
                const c = mappings.charCodeAt(i);
                if (c === comma) {
                    i++;
                }
                else if (c === semicolon) {
                    state[0] = lastCol = 0;
                    if (!sorted)
                        sort(line);
                    sorted = true;
                    decoded.push(line);
                    line = [];
                    i++;
                }
                else {
                    i = decodeInteger(mappings, i, state, 0); // generatedCodeColumn
                    const col = state[0];
                    if (col < lastCol)
                        sorted = false;
                    lastCol = col;
                    if (!hasMoreSegments(mappings, i)) {
                        line.push([col]);
                        continue;
                    }
                    i = decodeInteger(mappings, i, state, 1); // sourceFileIndex
                    i = decodeInteger(mappings, i, state, 2); // sourceCodeLine
                    i = decodeInteger(mappings, i, state, 3); // sourceCodeColumn
                    if (!hasMoreSegments(mappings, i)) {
                        line.push([col, state[1], state[2], state[3]]);
                        continue;
                    }
                    i = decodeInteger(mappings, i, state, 4); // nameIndex
                    line.push([col, state[1], state[2], state[3], state[4]]);
                }
            }
            if (!sorted)
                sort(line);
            decoded.push(line);
            return decoded;
        }
        function decodeInteger(mappings, pos, state, j) {
            let value = 0;
            let shift = 0;
            let integer = 0;
            do {
                const c = mappings.charCodeAt(pos++);
                integer = charToInteger[c];
                value |= (integer & 31) << shift;
                shift += 5;
            } while (integer & 32);
            const shouldNegate = value & 1;
            value >>>= 1;
            if (shouldNegate) {
                value = -0x80000000 | -value;
            }
            state[j] += value;
            return pos;
        }
        function hasMoreSegments(mappings, i) {
            if (i >= mappings.length)
                return false;
            const c = mappings.charCodeAt(i);
            if (c === comma || c === semicolon)
                return false;
            return true;
        }
        function sort(line) {
            line.sort(sortComparator$1);
        }
        function sortComparator$1(a, b) {
            return a[0] - b[0];
        }
        function encode(decoded) {
            const state = new Int32Array(5);
            let buf = new Uint8Array(1024);
            let pos = 0;
            for (let i = 0; i < decoded.length; i++) {
                const line = decoded[i];
                if (i > 0) {
                    buf = reserve(buf, pos, 1);
                    buf[pos++] = semicolon;
                }
                if (line.length === 0)
                    continue;
                state[0] = 0;
                for (let j = 0; j < line.length; j++) {
                    const segment = line[j];
                    // We can push up to 5 ints, each int can take at most 7 chars, and we
                    // may push a comma.
                    buf = reserve(buf, pos, 36);
                    if (j > 0)
                        buf[pos++] = comma;
                    pos = encodeInteger(buf, pos, state, segment, 0); // generatedCodeColumn
                    if (segment.length === 1)
                        continue;
                    pos = encodeInteger(buf, pos, state, segment, 1); // sourceFileIndex
                    pos = encodeInteger(buf, pos, state, segment, 2); // sourceCodeLine
                    pos = encodeInteger(buf, pos, state, segment, 3); // sourceCodeColumn
                    if (segment.length === 4)
                        continue;
                    pos = encodeInteger(buf, pos, state, segment, 4); // nameIndex
                }
            }
            return td.decode(buf.subarray(0, pos));
        }
        function reserve(buf, pos, count) {
            if (buf.length > pos + count)
                return buf;
            const swap = new Uint8Array(buf.length * 2);
            swap.set(buf);
            return swap;
        }
        function encodeInteger(buf, pos, state, segment, j) {
            const next = segment[j];
            let num = next - state[j];
            state[j] = next;
            num = num < 0 ? (-num << 1) | 1 : num << 1;
            do {
                let clamped = num & 0b011111;
                num >>>= 5;
                if (num > 0)
                    clamped |= 0b100000;
                buf[pos++] = intToChar[clamped];
            } while (num > 0);
            return pos;
        }
        // Matches the scheme of a URL, eg "http://"
        const schemeRegex = /^[\w+.-]+:\/\//;
        /**
         * Matches the parts of a URL:
         * 1. Scheme, including ":", guaranteed.
         * 2. User/password, including "@", optional.
         * 3. Host, guaranteed.
         * 4. Port, including ":", optional.
         * 5. Path, including "/", optional.
         */
        const urlRegex = /^([\w+.-]+:)\/\/([^@/#?]*@)?([^:/#?]*)(:\d+)?(\/[^#?]*)?/;
        /**
         * File URLs are weird. They dont' need the regular `//` in the scheme, they may or may not start
         * with a leading `/`, they can have a domain (but only if they don't start with a Windows drive).
         *
         * 1. Host, optional.
         * 2. Path, which may inclue "/", guaranteed.
         */
        const fileRegex = /^file:(?:\/\/((?![a-z]:)[^/]*)?)?(\/?.*)/i;
        function isAbsoluteUrl(input) {
            return schemeRegex.test(input);
        }
        function isSchemeRelativeUrl(input) {
            return input.startsWith('//');
        }
        function isAbsolutePath(input) {
            return input.startsWith('/');
        }
        function isFileUrl(input) {
            return input.startsWith('file:');
        }
        function parseAbsoluteUrl(input) {
            const match = urlRegex.exec(input);
            return makeUrl(match[1], match[2] || '', match[3], match[4] || '', match[5] || '/');
        }
        function parseFileUrl(input) {
            const match = fileRegex.exec(input);
            const path = match[2];
            return makeUrl('file:', '', match[1] || '', '', isAbsolutePath(path) ? path : '/' + path);
        }
        function makeUrl(scheme, user, host, port, path) {
            return {
                scheme,
                user,
                host,
                port,
                path,
                relativePath: false,
            };
        }
        function parseUrl(input) {
            if (isSchemeRelativeUrl(input)) {
                const url = parseAbsoluteUrl('http:' + input);
                url.scheme = '';
                return url;
            }
            if (isAbsolutePath(input)) {
                const url = parseAbsoluteUrl('http://foo.com' + input);
                url.scheme = '';
                url.host = '';
                return url;
            }
            if (isFileUrl(input))
                return parseFileUrl(input);
            if (isAbsoluteUrl(input))
                return parseAbsoluteUrl(input);
            const url = parseAbsoluteUrl('http://foo.com/' + input);
            url.scheme = '';
            url.host = '';
            url.relativePath = true;
            return url;
        }
        function stripPathFilename(path) {
            // If a path ends with a parent directory "..", then it's a relative path with excess parent
            // paths. It's not a file, so we can't strip it.
            if (path.endsWith('/..'))
                return path;
            const index = path.lastIndexOf('/');
            return path.slice(0, index + 1);
        }
        function mergePaths(url, base) {
            // If we're not a relative path, then we're an absolute path, and it doesn't matter what base is.
            if (!url.relativePath)
                return;
            normalizePath(base);
            // If the path is just a "/", then it was an empty path to begin with (remember, we're a relative
            // path).
            if (url.path === '/') {
                url.path = base.path;
            }
            else {
                // Resolution happens relative to the base path's directory, not the file.
                url.path = stripPathFilename(base.path) + url.path;
            }
            // If the base path is absolute, then our path is now absolute too.
            url.relativePath = base.relativePath;
        }
        /**
         * The path can have empty directories "//", unneeded parents "foo/..", or current directory
         * "foo/.". We need to normalize to a standard representation.
         */
        function normalizePath(url) {
            const { relativePath } = url;
            const pieces = url.path.split('/');
            // We need to preserve the first piece always, so that we output a leading slash. The item at
            // pieces[0] is an empty string.
            let pointer = 1;
            // Positive is the number of real directories we've output, used for popping a parent directory.
            // Eg, "foo/bar/.." will have a positive 2, and we can decrement to be left with just "foo".
            let positive = 0;
            // We need to keep a trailing slash if we encounter an empty directory (eg, splitting "foo/" will
            // generate `["foo", ""]` pieces). And, if we pop a parent directory. But once we encounter a
            // real directory, we won't need to append, unless the other conditions happen again.
            let addTrailingSlash = false;
            for (let i = 1; i < pieces.length; i++) {
                const piece = pieces[i];
                // An empty directory, could be a trailing slash, or just a double "//" in the path.
                if (!piece) {
                    addTrailingSlash = true;
                    continue;
                }
                // If we encounter a real directory, then we don't need to append anymore.
                addTrailingSlash = false;
                // A current directory, which we can always drop.
                if (piece === '.')
                    continue;
                // A parent directory, we need to see if there are any real directories we can pop. Else, we
                // have an excess of parents, and we'll need to keep the "..".
                if (piece === '..') {
                    if (positive) {
                        addTrailingSlash = true;
                        positive--;
                        pointer--;
                    }
                    else if (relativePath) {
                        // If we're in a relativePath, then we need to keep the excess parents. Else, in an absolute
                        // URL, protocol relative URL, or an absolute path, we don't need to keep excess.
                        pieces[pointer++] = piece;
                    }
                    continue;
                }
                // We've encountered a real directory. Move it to the next insertion pointer, which accounts for
                // any popped or dropped directories.
                pieces[pointer++] = piece;
                positive++;
            }
            let path = '';
            for (let i = 1; i < pointer; i++) {
                path += '/' + pieces[i];
            }
            if (!path || (addTrailingSlash && !path.endsWith('/..'))) {
                path += '/';
            }
            url.path = path;
        }
        /**
         * Attempts to resolve `input` URL/path relative to `base`.
         */
        function resolve$1(input, base) {
            if (!input && !base)
                return '';
            const url = parseUrl(input);
            // If we have a base, and the input isn't already an absolute URL, then we need to merge.
            if (base && !url.scheme) {
                const baseUrl = parseUrl(base);
                url.scheme = baseUrl.scheme;
                // If there's no host, then we were just a path.
                if (!url.host) {
                    // The host, user, and port are joined, you can't copy one without the others.
                    url.user = baseUrl.user;
                    url.host = baseUrl.host;
                    url.port = baseUrl.port;
                }
                mergePaths(url, baseUrl);
            }
            normalizePath(url);
            // If the input (and base, if there was one) are both relative, then we need to output a relative.
            if (url.relativePath) {
                // The first char is always a "/".
                const path = url.path.slice(1);
                if (!path)
                    return '.';
                // If base started with a leading ".", or there is no base and input started with a ".", then we
                // need to ensure that the relative path starts with a ".". We don't know if relative starts
                // with a "..", though, so check before prepending.
                const keepRelative = (base || input).startsWith('.');
                return !keepRelative || path.startsWith('.') ? path : './' + path;
            }
            // If there's no host (and no scheme/user/port), then we need to output an absolute path.
            if (!url.scheme && !url.host)
                return url.path;
            // We're outputting either an absolute URL, or a protocol relative one.
            return `${url.scheme}//${url.user}${url.host}${url.port}${url.path}`;
        }
        function resolve(input, base) {
            // The base is always treated as a directory, if it's not empty.
            // https://github.com/mozilla/source-map/blob/8cb3ee57/lib/util.js#L327
            // https://github.com/chromium/chromium/blob/da4adbb3/third_party/blink/renderer/devtools/front_end/sdk/SourceMap.js#L400-L401
            if (base && !base.endsWith('/'))
                base += '/';
            return resolve$1(input, base);
        }
        /**
         * Removes everything after the last "/", but leaves the slash.
         */
        function stripFilename(path) {
            if (!path)
                return '';
            const index = path.lastIndexOf('/');
            return path.slice(0, index + 1);
        }
        const COLUMN$1 = 0;
        const SOURCES_INDEX$1 = 1;
        const SOURCE_LINE$1 = 2;
        const SOURCE_COLUMN$1 = 3;
        const NAMES_INDEX$1 = 4;
        function maybeSort(mappings, owned) {
            const unsortedIndex = nextUnsortedSegmentLine(mappings, 0);
            if (unsortedIndex === mappings.length)
                return mappings;
            // If we own the array (meaning we parsed it from JSON), then we're free to directly mutate it. If
            // not, we do not want to modify the consumer's input array.
            if (!owned)
                mappings = mappings.slice();
            for (let i = unsortedIndex; i < mappings.length; i = nextUnsortedSegmentLine(mappings, i + 1)) {
                mappings[i] = sortSegments(mappings[i], owned);
            }
            return mappings;
        }
        function nextUnsortedSegmentLine(mappings, start) {
            for (let i = start; i < mappings.length; i++) {
                if (!isSorted(mappings[i]))
                    return i;
            }
            return mappings.length;
        }
        function isSorted(line) {
            for (let j = 1; j < line.length; j++) {
                if (line[j][COLUMN$1] < line[j - 1][COLUMN$1]) {
                    return false;
                }
            }
            return true;
        }
        function sortSegments(line, owned) {
            if (!owned)
                line = line.slice();
            return line.sort(sortComparator);
        }
        function sortComparator(a, b) {
            return a[COLUMN$1] - b[COLUMN$1];
        }
        let found = false;
        /**
         * A binary search implementation that returns the index if a match is found.
         * If no match is found, then the left-index (the index associated with the item that comes just
         * before the desired index) is returned. To maintain proper sort order, a splice would happen at
         * the next index:
         *
         * ```js
         * const array = [1, 3];
         * const needle = 2;
         * const index = binarySearch(array, needle, (item, needle) => item - needle);
         *
         * assert.equal(index, 0);
         * array.splice(index + 1, 0, needle);
         * assert.deepEqual(array, [1, 2, 3]);
         * ```
         */
        function binarySearch(haystack, needle, low, high) {
            while (low <= high) {
                const mid = low + ((high - low) >> 1);
                const cmp = haystack[mid][COLUMN$1] - needle;
                if (cmp === 0) {
                    found = true;
                    return mid;
                }
                if (cmp < 0) {
                    low = mid + 1;
                }
                else {
                    high = mid - 1;
                }
            }
            found = false;
            return low - 1;
        }
        function upperBound(haystack, needle, index) {
            for (let i = index + 1; i < haystack.length; i++, index++) {
                if (haystack[i][COLUMN$1] !== needle)
                    break;
            }
            return index;
        }
        function lowerBound(haystack, needle, index) {
            for (let i = index - 1; i >= 0; i--, index--) {
                if (haystack[i][COLUMN$1] !== needle)
                    break;
            }
            return index;
        }
        function memoizedState() {
            return {
                lastKey: -1,
                lastNeedle: -1,
                lastIndex: -1,
            };
        }
        /**
         * This overly complicated beast is just to record the last tested line/column and the resulting
         * index, allowing us to skip a few tests if mappings are monotonically increasing.
         */
        function memoizedBinarySearch(haystack, needle, state, key) {
            const { lastKey, lastNeedle, lastIndex } = state;
            let low = 0;
            let high = haystack.length - 1;
            if (key === lastKey) {
                if (needle === lastNeedle) {
                    found = lastIndex !== -1 && haystack[lastIndex][COLUMN$1] === needle;
                    return lastIndex;
                }
                if (needle >= lastNeedle) {
                    // lastIndex may be -1 if the previous needle was not found.
                    low = lastIndex === -1 ? 0 : lastIndex;
                }
                else {
                    high = lastIndex;
                }
            }
            state.lastKey = key;
            state.lastNeedle = needle;
            return (state.lastIndex = binarySearch(haystack, needle, low, high));
        }
        const AnyMap = function (map, mapUrl) {
            const parsed = typeof map === 'string' ? JSON.parse(map) : map;
            if (!('sections' in parsed))
                return new TraceMap(parsed, mapUrl);
            const mappings = [];
            const sources = [];
            const sourcesContent = [];
            const names = [];
            const { sections } = parsed;
            let i = 0;
            for (; i < sections.length - 1; i++) {
                const no = sections[i + 1].offset;
                addSection(sections[i], mapUrl, mappings, sources, sourcesContent, names, no.line, no.column);
            }
            if (sections.length > 0) {
                addSection(sections[i], mapUrl, mappings, sources, sourcesContent, names, Infinity, Infinity);
            }
            const joined = {
                version: 3,
                file: parsed.file,
                names,
                sources,
                sourcesContent,
                mappings,
            };
            return presortedDecodedMap(joined);
        };
        function addSection(section, mapUrl, mappings, sources, sourcesContent, names, stopLine, stopColumn) {
            const map = AnyMap(section.map, mapUrl);
            const { line: lineOffset, column: columnOffset } = section.offset;
            const sourcesOffset = sources.length;
            const namesOffset = names.length;
            const decoded = decodedMappings(map);
            const { resolvedSources } = map;
            append(sources, resolvedSources);
            append(sourcesContent, map.sourcesContent || fillSourcesContent(resolvedSources.length));
            append(names, map.names);
            // If this section jumps forwards several lines, we need to add lines to the output mappings catch up.
            for (let i = mappings.length; i <= lineOffset; i++)
                mappings.push([]);
            // We can only add so many lines before we step into the range that the next section's map
            // controls. When we get to the last line, then we'll start checking the segments to see if
            // they've crossed into the column range.
            const stopI = stopLine - lineOffset;
            const len = Math.min(decoded.length, stopI + 1);
            for (let i = 0; i < len; i++) {
                const line = decoded[i];
                // On the 0th loop, the line will already exist due to a previous section, or the line catch up
                // loop above.
                const out = i === 0 ? mappings[lineOffset] : (mappings[lineOffset + i] = []);
                // On the 0th loop, the section's column offset shifts us forward. On all other lines (since the
                // map can be multiple lines), it doesn't.
                const cOffset = i === 0 ? columnOffset : 0;
                for (let j = 0; j < line.length; j++) {
                    const seg = line[j];
                    const column = cOffset + seg[COLUMN$1];
                    // If this segment steps into the column range that the next section's map controls, we need
                    // to stop early.
                    if (i === stopI && column >= stopColumn)
                        break;
                    if (seg.length === 1) {
                        out.push([column]);
                        continue;
                    }
                    const sourcesIndex = sourcesOffset + seg[SOURCES_INDEX$1];
                    const sourceLine = seg[SOURCE_LINE$1];
                    const sourceColumn = seg[SOURCE_COLUMN$1];
                    if (seg.length === 4) {
                        out.push([column, sourcesIndex, sourceLine, sourceColumn]);
                        continue;
                    }
                    out.push([column, sourcesIndex, sourceLine, sourceColumn, namesOffset + seg[NAMES_INDEX$1]]);
                }
            }
        }
        function append(arr, other) {
            for (let i = 0; i < other.length; i++)
                arr.push(other[i]);
        }
        // Sourcemaps don't need to have sourcesContent, and if they don't, we need to create an array of
        // equal length to the sources. This is because the sources and sourcesContent are paired arrays,
        // where `sourcesContent[i]` is the content of the `sources[i]` file. If we didn't, then joined
        // sourcemap would desynchronize the sources/contents.
        function fillSourcesContent(len) {
            const sourcesContent = [];
            for (let i = 0; i < len; i++)
                sourcesContent[i] = null;
            return sourcesContent;
        }
        const INVALID_ORIGINAL_MAPPING = Object.freeze({
            source: null,
            line: null,
            column: null,
            name: null,
        });
        Object.freeze({
            line: null,
            column: null,
        });
        const LINE_GTR_ZERO = '`line` must be greater than 0 (lines start at line 1)';
        const COL_GTR_EQ_ZERO = '`column` must be greater than or equal to 0 (columns start at column 0)';
        const LEAST_UPPER_BOUND = -1;
        const GREATEST_LOWER_BOUND = 1;
        /**
         * Returns the decoded (array of lines of segments) form of the SourceMap's mappings field.
         */
        let decodedMappings;
        /**
         * A higher-level API to find the source/line/column associated with a generated line/column
         * (think, from a stack trace). Line is 1-based, but column is 0-based, due to legacy behavior in
         * `source-map` library.
         */
        let originalPositionFor;
        /**
         * A helper that skips sorting of the input map's mappings array, which can be expensive for larger
         * maps.
         */
        let presortedDecodedMap;
        class TraceMap {
            constructor(map, mapUrl) {
                this._decodedMemo = memoizedState();
                this._bySources = undefined;
                this._bySourceMemos = undefined;
                const isString = typeof map === 'string';
                if (!isString && map.constructor === TraceMap)
                    return map;
                const parsed = (isString ? JSON.parse(map) : map);
                const { version, file, names, sourceRoot, sources, sourcesContent } = parsed;
                this.version = version;
                this.file = file;
                this.names = names;
                this.sourceRoot = sourceRoot;
                this.sources = sources;
                this.sourcesContent = sourcesContent;
                if (sourceRoot || mapUrl) {
                    const from = resolve(sourceRoot || '', stripFilename(mapUrl));
                    this.resolvedSources = sources.map((s) => resolve(s || '', from));
                }
                else {
                    this.resolvedSources = sources.map((s) => s || '');
                }
                const { mappings } = parsed;
                if (typeof mappings === 'string') {
                    this._encoded = mappings;
                    this._decoded = undefined;
                }
                else {
                    this._encoded = undefined;
                    this._decoded = maybeSort(mappings, isString);
                }
            }
        }
        (() => {
            decodedMappings = (map) => {
                return (map._decoded || (map._decoded = decode(map._encoded)));
            };
            originalPositionFor = (map, { line, column, bias }) => {
                line--;
                if (line < 0)
                    throw new Error(LINE_GTR_ZERO);
                if (column < 0)
                    throw new Error(COL_GTR_EQ_ZERO);
                const decoded = decodedMappings(map);
                // It's common for parent source maps to have pointers to lines that have no
                // mapping (like a "//# sourceMappingURL=") at the end of the child file.
                if (line >= decoded.length)
                    return INVALID_ORIGINAL_MAPPING;
                const segment = traceSegmentInternal(decoded[line], map._decodedMemo, line, column, bias || GREATEST_LOWER_BOUND);
                if (segment == null)
                    return INVALID_ORIGINAL_MAPPING;
                if (segment.length == 1)
                    return INVALID_ORIGINAL_MAPPING;
                const { names, resolvedSources } = map;
                return {
                    source: resolvedSources[segment[SOURCES_INDEX$1]],
                    line: segment[SOURCE_LINE$1] + 1,
                    column: segment[SOURCE_COLUMN$1],
                    name: segment.length === 5 ? names[segment[NAMES_INDEX$1]] : null,
                };
            };
            presortedDecodedMap = (map, mapUrl) => {
                const clone = Object.assign({}, map);
                clone.mappings = [];
                const tracer = new TraceMap(clone, mapUrl);
                tracer._decoded = map.mappings;
                return tracer;
            };
        })();
        function traceSegmentInternal(segments, memo, line, column, bias) {
            let index = memoizedBinarySearch(segments, column, memo, line);
            if (found) {
                index = (bias === LEAST_UPPER_BOUND ? upperBound : lowerBound)(segments, column, index);
            }
            else if (bias === LEAST_UPPER_BOUND)
                index++;
            if (index === -1 || index === segments.length)
                return null;
            return segments[index];
        }
        /**
         * Gets the index associated with `key` in the backing array, if it is already present.
         */
        let get;
        /**
         * Puts `key` into the backing array, if it is not already present. Returns
         * the index of the `key` in the backing array.
         */
        let put;
        /**
         * SetArray acts like a `Set` (allowing only one occurrence of a string `key`), but provides the
         * index of the `key` in the backing array.
         *
         * This is designed to allow synchronizing a second array with the contents of the backing array,
         * like how in a sourcemap `sourcesContent[i]` is the source content associated with `source[i]`,
         * and there are never duplicates.
         */
        class SetArray {
            constructor() {
                this._indexes = { __proto__: null };
                this.array = [];
            }
        }
        (() => {
            get = (strarr, key) => strarr._indexes[key];
            put = (strarr, key) => {
                // The key may or may not be present. If it is present, it's a number.
                const index = get(strarr, key);
                if (index !== undefined)
                    return index;
                const { array, _indexes: indexes } = strarr;
                return (indexes[key] = array.push(key) - 1);
            };
        })();
        const COLUMN = 0;
        const SOURCES_INDEX = 1;
        const SOURCE_LINE = 2;
        const SOURCE_COLUMN = 3;
        const NAMES_INDEX = 4;
        const NO_NAME = -1;
        /**
         * Same as `addMapping`, but will only add the mapping if it generates useful information in the
         * resulting map. This only works correctly if mappings are added **in order**, meaning you should
         * not add a mapping with a lower generated line/column than one that came before.
         */
        let maybeAddMapping;
        /**
         * Adds/removes the content of the source file to the source map.
         */
        let setSourceContent;
        /**
         * Returns a sourcemap object (with decoded mappings) suitable for passing to a library that expects
         * a sourcemap, or to JSON.stringify.
         */
        let toDecodedMap;
        /**
         * Returns a sourcemap object (with encoded mappings) suitable for passing to a library that expects
         * a sourcemap, or to JSON.stringify.
         */
        let toEncodedMap;
        // This split declaration is only so that terser can elminiate the static initialization block.
        let addSegmentInternal;
        /**
         * Provides the state to generate a sourcemap.
         */
        class GenMapping {
            constructor({ file, sourceRoot } = {}) {
                this._names = new SetArray();
                this._sources = new SetArray();
                this._sourcesContent = [];
                this._mappings = [];
                this.file = file;
                this.sourceRoot = sourceRoot;
            }
        }
        (() => {
            maybeAddMapping = (map, mapping) => {
                return addMappingInternal(true, map, mapping);
            };
            setSourceContent = (map, source, content) => {
                const { _sources: sources, _sourcesContent: sourcesContent } = map;
                sourcesContent[put(sources, source)] = content;
            };
            toDecodedMap = (map) => {
                const { file, sourceRoot, _mappings: mappings, _sources: sources, _sourcesContent: sourcesContent, _names: names, } = map;
                removeEmptyFinalLines(mappings);
                return {
                    version: 3,
                    file: file || undefined,
                    names: names.array,
                    sourceRoot: sourceRoot || undefined,
                    sources: sources.array,
                    sourcesContent,
                    mappings,
                };
            };
            toEncodedMap = (map) => {
                const decoded = toDecodedMap(map);
                return Object.assign(Object.assign({}, decoded), { mappings: encode(decoded.mappings) });
            };
            // Internal helpers
            addSegmentInternal = (skipable, map, genLine, genColumn, source, sourceLine, sourceColumn, name) => {
                const { _mappings: mappings, _sources: sources, _sourcesContent: sourcesContent, _names: names, } = map;
                const line = getLine(mappings, genLine);
                const index = getColumnIndex(line, genColumn);
                if (!source) {
                    if (skipable && skipSourceless(line, index))
                        return;
                    return insert(line, index, [genColumn]);
                }
                const sourcesIndex = put(sources, source);
                const namesIndex = name ? put(names, name) : NO_NAME;
                if (sourcesIndex === sourcesContent.length)
                    sourcesContent[sourcesIndex] = null;
                if (skipable && skipSource(line, index, sourcesIndex, sourceLine, sourceColumn, namesIndex)) {
                    return;
                }
                return insert(line, index, name
                    ? [genColumn, sourcesIndex, sourceLine, sourceColumn, namesIndex]
                    : [genColumn, sourcesIndex, sourceLine, sourceColumn]);
            };
        })();
        function getLine(mappings, index) {
            for (let i = mappings.length; i <= index; i++) {
                mappings[i] = [];
            }
            return mappings[index];
        }
        function getColumnIndex(line, genColumn) {
            let index = line.length;
            for (let i = index - 1; i >= 0; index = i--) {
                const current = line[i];
                if (genColumn >= current[COLUMN])
                    break;
            }
            return index;
        }
        function insert(array, index, value) {
            for (let i = array.length; i > index; i--) {
                array[i] = array[i - 1];
            }
            array[index] = value;
        }
        function removeEmptyFinalLines(mappings) {
            const { length } = mappings;
            let len = length;
            for (let i = len - 1; i >= 0; len = i, i--) {
                if (mappings[i].length > 0)
                    break;
            }
            if (len < length)
                mappings.length = len;
        }
        function skipSourceless(line, index) {
            // The start of a line is already sourceless, so adding a sourceless segment to the beginning
            // doesn't generate any useful information.
            if (index === 0)
                return true;
            const prev = line[index - 1];
            // If the previous segment is also sourceless, then adding another sourceless segment doesn't
            // genrate any new information. Else, this segment will end the source/named segment and point to
            // a sourceless position, which is useful.
            return prev.length === 1;
        }
        function skipSource(line, index, sourcesIndex, sourceLine, sourceColumn, namesIndex) {
            // A source/named segment at the start of a line gives position at that genColumn
            if (index === 0)
                return false;
            const prev = line[index - 1];
            // If the previous segment is sourceless, then we're transitioning to a source.
            if (prev.length === 1)
                return false;
            // If the previous segment maps to the exact same source position, then this segment doesn't
            // provide any new position information.
            return (sourcesIndex === prev[SOURCES_INDEX] &&
                sourceLine === prev[SOURCE_LINE] &&
                sourceColumn === prev[SOURCE_COLUMN] &&
                namesIndex === (prev.length === 5 ? prev[NAMES_INDEX] : NO_NAME));
        }
        function addMappingInternal(skipable, map, mapping) {
            const { generated, source, original, name } = mapping;
            if (!source) {
                return addSegmentInternal(skipable, map, generated.line - 1, generated.column, null, null, null, null);
            }
            const s = source;
            return addSegmentInternal(skipable, map, generated.line - 1, generated.column, s, original.line - 1, original.column, name);
        }
        class SourceMapConsumer {
            constructor(map, mapUrl) {
                const trace = (this._map = new AnyMap(map, mapUrl));
                this.file = trace.file;
                this.names = trace.names;
                this.sourceRoot = trace.sourceRoot;
                this.sources = trace.resolvedSources;
                this.sourcesContent = trace.sourcesContent;
            }
            originalPositionFor(needle) {
                return originalPositionFor(this._map, needle);
            }
            destroy() {
                // noop.
            }
        }
        class SourceMapGenerator {
            constructor(opts) {
                this._map = new GenMapping(opts);
            }
            addMapping(mapping) {
                maybeAddMapping(this._map, mapping);
            }
            setSourceContent(source, content) {
                setSourceContent(this._map, source, content);
            }
            toJSON() {
                return toEncodedMap(this._map);
            }
            toDecodedMap() {
                return toDecodedMap(this._map);
            }
        }
        exports.SourceMapConsumer = SourceMapConsumer;
        exports.SourceMapGenerator = SourceMapGenerator;
        Object.defineProperty(exports, '__esModule', { value: true });
    }));
    
},
/* acorn/dist/acorn.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
            typeof define === 'function' && define.amd ? define(['exports'], factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.acorn = {}));
    })(this, (function (exports) {
        'use strict';
        // This file was generated. Do not modify manually!
        var astralIdentifierCodes = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 81, 2, 71, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 3, 0, 158, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 10, 1, 2, 0, 49, 6, 4, 4, 14, 9, 5351, 0, 7, 14, 13835, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 101, 0, 161, 6, 10, 9, 357, 0, 62, 13, 499, 13, 983, 6, 110, 6, 6, 9, 4759, 9, 787719, 239];
        // This file was generated. Do not modify manually!
        var astralIdentifierStartCodes = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 20, 1, 64, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 16, 0, 2, 12, 2, 33, 125, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1071, 18, 5, 4026, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 16, 0, 30, 2, 3, 0, 15, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 7, 5, 262, 61, 147, 44, 11, 6, 17, 0, 322, 29, 19, 43, 485, 27, 757, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4153, 7, 221, 3, 5761, 15, 7472, 3104, 541, 1507, 4938, 6, 4191];
        // This file was generated. Do not modify manually!
        var nonASCIIidentifierChars = "\u200c\u200d\xb7\u0300-\u036f\u0387\u0483-\u0487\u0591-\u05bd\u05bf\u05c1\u05c2\u05c4\u05c5\u05c7\u0610-\u061a\u064b-\u0669\u0670\u06d6-\u06dc\u06df-\u06e4\u06e7\u06e8\u06ea-\u06ed\u06f0-\u06f9\u0711\u0730-\u074a\u07a6-\u07b0\u07c0-\u07c9\u07eb-\u07f3\u07fd\u0816-\u0819\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0859-\u085b\u0898-\u089f\u08ca-\u08e1\u08e3-\u0903\u093a-\u093c\u093e-\u094f\u0951-\u0957\u0962\u0963\u0966-\u096f\u0981-\u0983\u09bc\u09be-\u09c4\u09c7\u09c8\u09cb-\u09cd\u09d7\u09e2\u09e3\u09e6-\u09ef\u09fe\u0a01-\u0a03\u0a3c\u0a3e-\u0a42\u0a47\u0a48\u0a4b-\u0a4d\u0a51\u0a66-\u0a71\u0a75\u0a81-\u0a83\u0abc\u0abe-\u0ac5\u0ac7-\u0ac9\u0acb-\u0acd\u0ae2\u0ae3\u0ae6-\u0aef\u0afa-\u0aff\u0b01-\u0b03\u0b3c\u0b3e-\u0b44\u0b47\u0b48\u0b4b-\u0b4d\u0b55-\u0b57\u0b62\u0b63\u0b66-\u0b6f\u0b82\u0bbe-\u0bc2\u0bc6-\u0bc8\u0bca-\u0bcd\u0bd7\u0be6-\u0bef\u0c00-\u0c04\u0c3c\u0c3e-\u0c44\u0c46-\u0c48\u0c4a-\u0c4d\u0c55\u0c56\u0c62\u0c63\u0c66-\u0c6f\u0c81-\u0c83\u0cbc\u0cbe-\u0cc4\u0cc6-\u0cc8\u0cca-\u0ccd\u0cd5\u0cd6\u0ce2\u0ce3\u0ce6-\u0cef\u0cf3\u0d00-\u0d03\u0d3b\u0d3c\u0d3e-\u0d44\u0d46-\u0d48\u0d4a-\u0d4d\u0d57\u0d62\u0d63\u0d66-\u0d6f\u0d81-\u0d83\u0dca\u0dcf-\u0dd4\u0dd6\u0dd8-\u0ddf\u0de6-\u0def\u0df2\u0df3\u0e31\u0e34-\u0e3a\u0e47-\u0e4e\u0e50-\u0e59\u0eb1\u0eb4-\u0ebc\u0ec8-\u0ece\u0ed0-\u0ed9\u0f18\u0f19\u0f20-\u0f29\u0f35\u0f37\u0f39\u0f3e\u0f3f\u0f71-\u0f84\u0f86\u0f87\u0f8d-\u0f97\u0f99-\u0fbc\u0fc6\u102b-\u103e\u1040-\u1049\u1056-\u1059\u105e-\u1060\u1062-\u1064\u1067-\u106d\u1071-\u1074\u1082-\u108d\u108f-\u109d\u135d-\u135f\u1369-\u1371\u1712-\u1715\u1732-\u1734\u1752\u1753\u1772\u1773\u17b4-\u17d3\u17dd\u17e0-\u17e9\u180b-\u180d\u180f-\u1819\u18a9\u1920-\u192b\u1930-\u193b\u1946-\u194f\u19d0-\u19da\u1a17-\u1a1b\u1a55-\u1a5e\u1a60-\u1a7c\u1a7f-\u1a89\u1a90-\u1a99\u1ab0-\u1abd\u1abf-\u1ace\u1b00-\u1b04\u1b34-\u1b44\u1b50-\u1b59\u1b6b-\u1b73\u1b80-\u1b82\u1ba1-\u1bad\u1bb0-\u1bb9\u1be6-\u1bf3\u1c24-\u1c37\u1c40-\u1c49\u1c50-\u1c59\u1cd0-\u1cd2\u1cd4-\u1ce8\u1ced\u1cf4\u1cf7-\u1cf9\u1dc0-\u1dff\u203f\u2040\u2054\u20d0-\u20dc\u20e1\u20e5-\u20f0\u2cef-\u2cf1\u2d7f\u2de0-\u2dff\u302a-\u302f\u3099\u309a\ua620-\ua629\ua66f\ua674-\ua67d\ua69e\ua69f\ua6f0\ua6f1\ua802\ua806\ua80b\ua823-\ua827\ua82c\ua880\ua881\ua8b4-\ua8c5\ua8d0-\ua8d9\ua8e0-\ua8f1\ua8ff-\ua909\ua926-\ua92d\ua947-\ua953\ua980-\ua983\ua9b3-\ua9c0\ua9d0-\ua9d9\ua9e5\ua9f0-\ua9f9\uaa29-\uaa36\uaa43\uaa4c\uaa4d\uaa50-\uaa59\uaa7b-\uaa7d\uaab0\uaab2-\uaab4\uaab7\uaab8\uaabe\uaabf\uaac1\uaaeb-\uaaef\uaaf5\uaaf6\uabe3-\uabea\uabec\uabed\uabf0-\uabf9\ufb1e\ufe00-\ufe0f\ufe20-\ufe2f\ufe33\ufe34\ufe4d-\ufe4f\uff10-\uff19\uff3f";
        // This file was generated. Do not modify manually!
        var nonASCIIidentifierStartChars = "\xaa\xb5\xba\xc0-\xd6\xd8-\xf6\xf8-\u02c1\u02c6-\u02d1\u02e0-\u02e4\u02ec\u02ee\u0370-\u0374\u0376\u0377\u037a-\u037d\u037f\u0386\u0388-\u038a\u038c\u038e-\u03a1\u03a3-\u03f5\u03f7-\u0481\u048a-\u052f\u0531-\u0556\u0559\u0560-\u0588\u05d0-\u05ea\u05ef-\u05f2\u0620-\u064a\u066e\u066f\u0671-\u06d3\u06d5\u06e5\u06e6\u06ee\u06ef\u06fa-\u06fc\u06ff\u0710\u0712-\u072f\u074d-\u07a5\u07b1\u07ca-\u07ea\u07f4\u07f5\u07fa\u0800-\u0815\u081a\u0824\u0828\u0840-\u0858\u0860-\u086a\u0870-\u0887\u0889-\u088e\u08a0-\u08c9\u0904-\u0939\u093d\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098c\u098f\u0990\u0993-\u09a8\u09aa-\u09b0\u09b2\u09b6-\u09b9\u09bd\u09ce\u09dc\u09dd\u09df-\u09e1\u09f0\u09f1\u09fc\u0a05-\u0a0a\u0a0f\u0a10\u0a13-\u0a28\u0a2a-\u0a30\u0a32\u0a33\u0a35\u0a36\u0a38\u0a39\u0a59-\u0a5c\u0a5e\u0a72-\u0a74\u0a85-\u0a8d\u0a8f-\u0a91\u0a93-\u0aa8\u0aaa-\u0ab0\u0ab2\u0ab3\u0ab5-\u0ab9\u0abd\u0ad0\u0ae0\u0ae1\u0af9\u0b05-\u0b0c\u0b0f\u0b10\u0b13-\u0b28\u0b2a-\u0b30\u0b32\u0b33\u0b35-\u0b39\u0b3d\u0b5c\u0b5d\u0b5f-\u0b61\u0b71\u0b83\u0b85-\u0b8a\u0b8e-\u0b90\u0b92-\u0b95\u0b99\u0b9a\u0b9c\u0b9e\u0b9f\u0ba3\u0ba4\u0ba8-\u0baa\u0bae-\u0bb9\u0bd0\u0c05-\u0c0c\u0c0e-\u0c10\u0c12-\u0c28\u0c2a-\u0c39\u0c3d\u0c58-\u0c5a\u0c5d\u0c60\u0c61\u0c80\u0c85-\u0c8c\u0c8e-\u0c90\u0c92-\u0ca8\u0caa-\u0cb3\u0cb5-\u0cb9\u0cbd\u0cdd\u0cde\u0ce0\u0ce1\u0cf1\u0cf2\u0d04-\u0d0c\u0d0e-\u0d10\u0d12-\u0d3a\u0d3d\u0d4e\u0d54-\u0d56\u0d5f-\u0d61\u0d7a-\u0d7f\u0d85-\u0d96\u0d9a-\u0db1\u0db3-\u0dbb\u0dbd\u0dc0-\u0dc6\u0e01-\u0e30\u0e32\u0e33\u0e40-\u0e46\u0e81\u0e82\u0e84\u0e86-\u0e8a\u0e8c-\u0ea3\u0ea5\u0ea7-\u0eb0\u0eb2\u0eb3\u0ebd\u0ec0-\u0ec4\u0ec6\u0edc-\u0edf\u0f00\u0f40-\u0f47\u0f49-\u0f6c\u0f88-\u0f8c\u1000-\u102a\u103f\u1050-\u1055\u105a-\u105d\u1061\u1065\u1066\u106e-\u1070\u1075-\u1081\u108e\u10a0-\u10c5\u10c7\u10cd\u10d0-\u10fa\u10fc-\u1248\u124a-\u124d\u1250-\u1256\u1258\u125a-\u125d\u1260-\u1288\u128a-\u128d\u1290-\u12b0\u12b2-\u12b5\u12b8-\u12be\u12c0\u12c2-\u12c5\u12c8-\u12d6\u12d8-\u1310\u1312-\u1315\u1318-\u135a\u1380-\u138f\u13a0-\u13f5\u13f8-\u13fd\u1401-\u166c\u166f-\u167f\u1681-\u169a\u16a0-\u16ea\u16ee-\u16f8\u1700-\u1711\u171f-\u1731\u1740-\u1751\u1760-\u176c\u176e-\u1770\u1780-\u17b3\u17d7\u17dc\u1820-\u1878\u1880-\u18a8\u18aa\u18b0-\u18f5\u1900-\u191e\u1950-\u196d\u1970-\u1974\u1980-\u19ab\u19b0-\u19c9\u1a00-\u1a16\u1a20-\u1a54\u1aa7\u1b05-\u1b33\u1b45-\u1b4c\u1b83-\u1ba0\u1bae\u1baf\u1bba-\u1be5\u1c00-\u1c23\u1c4d-\u1c4f\u1c5a-\u1c7d\u1c80-\u1c88\u1c90-\u1cba\u1cbd-\u1cbf\u1ce9-\u1cec\u1cee-\u1cf3\u1cf5\u1cf6\u1cfa\u1d00-\u1dbf\u1e00-\u1f15\u1f18-\u1f1d\u1f20-\u1f45\u1f48-\u1f4d\u1f50-\u1f57\u1f59\u1f5b\u1f5d\u1f5f-\u1f7d\u1f80-\u1fb4\u1fb6-\u1fbc\u1fbe\u1fc2-\u1fc4\u1fc6-\u1fcc\u1fd0-\u1fd3\u1fd6-\u1fdb\u1fe0-\u1fec\u1ff2-\u1ff4\u1ff6-\u1ffc\u2071\u207f\u2090-\u209c\u2102\u2107\u210a-\u2113\u2115\u2118-\u211d\u2124\u2126\u2128\u212a-\u2139\u213c-\u213f\u2145-\u2149\u214e\u2160-\u2188\u2c00-\u2ce4\u2ceb-\u2cee\u2cf2\u2cf3\u2d00-\u2d25\u2d27\u2d2d\u2d30-\u2d67\u2d6f\u2d80-\u2d96\u2da0-\u2da6\u2da8-\u2dae\u2db0-\u2db6\u2db8-\u2dbe\u2dc0-\u2dc6\u2dc8-\u2dce\u2dd0-\u2dd6\u2dd8-\u2dde\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303c\u3041-\u3096\u309b-\u309f\u30a1-\u30fa\u30fc-\u30ff\u3105-\u312f\u3131-\u318e\u31a0-\u31bf\u31f0-\u31ff\u3400-\u4dbf\u4e00-\ua48c\ua4d0-\ua4fd\ua500-\ua60c\ua610-\ua61f\ua62a\ua62b\ua640-\ua66e\ua67f-\ua69d\ua6a0-\ua6ef\ua717-\ua71f\ua722-\ua788\ua78b-\ua7ca\ua7d0\ua7d1\ua7d3\ua7d5-\ua7d9\ua7f2-\ua801\ua803-\ua805\ua807-\ua80a\ua80c-\ua822\ua840-\ua873\ua882-\ua8b3\ua8f2-\ua8f7\ua8fb\ua8fd\ua8fe\ua90a-\ua925\ua930-\ua946\ua960-\ua97c\ua984-\ua9b2\ua9cf\ua9e0-\ua9e4\ua9e6-\ua9ef\ua9fa-\ua9fe\uaa00-\uaa28\uaa40-\uaa42\uaa44-\uaa4b\uaa60-\uaa76\uaa7a\uaa7e-\uaaaf\uaab1\uaab5\uaab6\uaab9-\uaabd\uaac0\uaac2\uaadb-\uaadd\uaae0-\uaaea\uaaf2-\uaaf4\uab01-\uab06\uab09-\uab0e\uab11-\uab16\uab20-\uab26\uab28-\uab2e\uab30-\uab5a\uab5c-\uab69\uab70-\uabe2\uac00-\ud7a3\ud7b0-\ud7c6\ud7cb-\ud7fb\uf900-\ufa6d\ufa70-\ufad9\ufb00-\ufb06\ufb13-\ufb17\ufb1d\ufb1f-\ufb28\ufb2a-\ufb36\ufb38-\ufb3c\ufb3e\ufb40\ufb41\ufb43\ufb44\ufb46-\ufbb1\ufbd3-\ufd3d\ufd50-\ufd8f\ufd92-\ufdc7\ufdf0-\ufdfb\ufe70-\ufe74\ufe76-\ufefc\uff21-\uff3a\uff41-\uff5a\uff66-\uffbe\uffc2-\uffc7\uffca-\uffcf\uffd2-\uffd7\uffda-\uffdc";
        // These are a run-length and offset encoded representation of the
        // Reserved word lists for various dialects of the language
        var reservedWords = {
            3: "abstract boolean byte char class double enum export extends final float goto implements import int interface long native package private protected public short static super synchronized throws transient volatile",
            5: "class enum extends super const export import",
            6: "enum",
            strict: "implements interface let package private protected public static yield",
            strictBind: "eval arguments"
        };
        // And the keywords
        var ecma5AndLessKeywords = "break case catch continue debugger default do else finally for function if return switch throw try var while with null true false instanceof typeof void delete new in this";
        var keywords$1 = {
            5: ecma5AndLessKeywords,
            "5module": ecma5AndLessKeywords + " export import",
            6: ecma5AndLessKeywords + " const class extends export import super"
        };
        var keywordRelationalOperator = /^in(stanceof)?$/;
        // ## Character categories
        var nonASCIIidentifierStart = new RegExp("[" + nonASCIIidentifierStartChars + "]");
        var nonASCIIidentifier = new RegExp("[" + nonASCIIidentifierStartChars + nonASCIIidentifierChars + "]");
        // This has a complexity linear to the value of the code. The
        // assumption is that looking up astral identifier characters is
        // rare.
        function isInAstralSet(code, set) {
            var pos = 0x10000;
            for (var i = 0; i < set.length; i += 2) {
                pos += set[i];
                if (pos > code) {
                    return false;
                }
                pos += set[i + 1];
                if (pos >= code) {
                    return true;
                }
            }
            return false;
        }
        // Test whether a given character code starts an identifier.
        function isIdentifierStart(code, astral) {
            if (code < 65) {
                return code === 36;
            }
            if (code < 91) {
                return true;
            }
            if (code < 97) {
                return code === 95;
            }
            if (code < 123) {
                return true;
            }
            if (code <= 0xffff) {
                return code >= 0xaa && nonASCIIidentifierStart.test(String.fromCharCode(code));
            }
            if (astral === false) {
                return false;
            }
            return isInAstralSet(code, astralIdentifierStartCodes);
        }
        // Test whether a given character is part of an identifier.
        function isIdentifierChar(code, astral) {
            if (code < 48) {
                return code === 36;
            }
            if (code < 58) {
                return true;
            }
            if (code < 65) {
                return false;
            }
            if (code < 91) {
                return true;
            }
            if (code < 97) {
                return code === 95;
            }
            if (code < 123) {
                return true;
            }
            if (code <= 0xffff) {
                return code >= 0xaa && nonASCIIidentifier.test(String.fromCharCode(code));
            }
            if (astral === false) {
                return false;
            }
            return isInAstralSet(code, astralIdentifierStartCodes) || isInAstralSet(code, astralIdentifierCodes);
        }
        // ## Token types
        // The assignment of fine-grained, information-carrying type objects
        // allows the tokenizer to store the information it has about a
        // token in a way that is very cheap for the parser to look up.
        // All token type variables start with an underscore, to make them
        // easy to recognize.
        // The `beforeExpr` property is used to disambiguate between regular
        // expressions and divisions. It is set on all token types that can
        // be followed by an expression (thus, a slash after them would be a
        // regular expression).
        //
        // The `startsExpr` property is used to check if the token ends a
        // `yield` expression. It is set on all token types that either can
        // directly start an expression (like a quotation mark) or can
        // continue an expression (like the body of a string).
        //
        // `isLoop` marks a keyword as starting a loop, which is important
        // to know when parsing a label, in order to allow or disallow
        // continue jumps to that label.
        var TokenType = function TokenType(label, conf) {
            if (conf === void 0)
                conf = {};
            this.label = label;
            this.keyword = conf.keyword;
            this.beforeExpr = !!conf.beforeExpr;
            this.startsExpr = !!conf.startsExpr;
            this.isLoop = !!conf.isLoop;
            this.isAssign = !!conf.isAssign;
            this.prefix = !!conf.prefix;
            this.postfix = !!conf.postfix;
            this.binop = conf.binop || null;
            this.updateContext = null;
        };
        function binop(name, prec) {
            return new TokenType(name, { beforeExpr: true, binop: prec });
        }
        var beforeExpr = { beforeExpr: true }, startsExpr = { startsExpr: true };
        // Map keyword names to token types.
        var keywords = {};
        // Succinct definitions of keyword token types
        function kw(name, options) {
            if (options === void 0)
                options = {};
            options.keyword = name;
            return keywords[name] = new TokenType(name, options);
        }
        var types$1 = {
            num: new TokenType("num", startsExpr),
            regexp: new TokenType("regexp", startsExpr),
            string: new TokenType("string", startsExpr),
            name: new TokenType("name", startsExpr),
            privateId: new TokenType("privateId", startsExpr),
            eof: new TokenType("eof"),
            // Punctuation token types.
            bracketL: new TokenType("[", { beforeExpr: true, startsExpr: true }),
            bracketR: new TokenType("]"),
            braceL: new TokenType("{", { beforeExpr: true, startsExpr: true }),
            braceR: new TokenType("}"),
            parenL: new TokenType("(", { beforeExpr: true, startsExpr: true }),
            parenR: new TokenType(")"),
            comma: new TokenType(",", beforeExpr),
            semi: new TokenType(";", beforeExpr),
            colon: new TokenType(":", beforeExpr),
            dot: new TokenType("."),
            question: new TokenType("?", beforeExpr),
            questionDot: new TokenType("?."),
            arrow: new TokenType("=>", beforeExpr),
            template: new TokenType("template"),
            invalidTemplate: new TokenType("invalidTemplate"),
            ellipsis: new TokenType("...", beforeExpr),
            backQuote: new TokenType("`", startsExpr),
            dollarBraceL: new TokenType("${", { beforeExpr: true, startsExpr: true }),
            // Operators. These carry several kinds of properties to help the
            // parser use them properly (the presence of these properties is
            // what categorizes them as operators).
            //
            // `binop`, when present, specifies that this operator is a binary
            // operator, and will refer to its precedence.
            //
            // `prefix` and `postfix` mark the operator as a prefix or postfix
            // unary operator.
            //
            // `isAssign` marks all of `=`, `+=`, `-=` etcetera, which act as
            // binary operators with a very low precedence, that should result
            // in AssignmentExpression nodes.
            eq: new TokenType("=", { beforeExpr: true, isAssign: true }),
            assign: new TokenType("_=", { beforeExpr: true, isAssign: true }),
            incDec: new TokenType("++/--", { prefix: true, postfix: true, startsExpr: true }),
            prefix: new TokenType("!/~", { beforeExpr: true, prefix: true, startsExpr: true }),
            logicalOR: binop("||", 1),
            logicalAND: binop("&&", 2),
            bitwiseOR: binop("|", 3),
            bitwiseXOR: binop("^", 4),
            bitwiseAND: binop("&", 5),
            equality: binop("==/!=/===/!==", 6),
            relational: binop("</>/<=/>=", 7),
            bitShift: binop("<</>>/>>>", 8),
            plusMin: new TokenType("+/-", { beforeExpr: true, binop: 9, prefix: true, startsExpr: true }),
            modulo: binop("%", 10),
            star: binop("*", 10),
            slash: binop("/", 10),
            starstar: new TokenType("**", { beforeExpr: true }),
            coalesce: binop("??", 1),
            // Keyword token types.
            _break: kw("break"),
            _case: kw("case", beforeExpr),
            _catch: kw("catch"),
            _continue: kw("continue"),
            _debugger: kw("debugger"),
            _default: kw("default", beforeExpr),
            _do: kw("do", { isLoop: true, beforeExpr: true }),
            _else: kw("else", beforeExpr),
            _finally: kw("finally"),
            _for: kw("for", { isLoop: true }),
            _function: kw("function", startsExpr),
            _if: kw("if"),
            _return: kw("return", beforeExpr),
            _switch: kw("switch"),
            _throw: kw("throw", beforeExpr),
            _try: kw("try"),
            _var: kw("var"),
            _const: kw("const"),
            _while: kw("while", { isLoop: true }),
            _with: kw("with"),
            _new: kw("new", { beforeExpr: true, startsExpr: true }),
            _this: kw("this", startsExpr),
            _super: kw("super", startsExpr),
            _class: kw("class", startsExpr),
            _extends: kw("extends", beforeExpr),
            _export: kw("export"),
            _import: kw("import", startsExpr),
            _null: kw("null", startsExpr),
            _true: kw("true", startsExpr),
            _false: kw("false", startsExpr),
            _in: kw("in", { beforeExpr: true, binop: 7 }),
            _instanceof: kw("instanceof", { beforeExpr: true, binop: 7 }),
            _typeof: kw("typeof", { beforeExpr: true, prefix: true, startsExpr: true }),
            _void: kw("void", { beforeExpr: true, prefix: true, startsExpr: true }),
            _delete: kw("delete", { beforeExpr: true, prefix: true, startsExpr: true })
        };
        // Matches a whole line break (where CRLF is considered a single
        // line break). Used to count lines.
        var lineBreak = /\r\n?|\n|\u2028|\u2029/;
        var lineBreakG = new RegExp(lineBreak.source, "g");
        function isNewLine(code) {
            return code === 10 || code === 13 || code === 0x2028 || code === 0x2029;
        }
        function nextLineBreak(code, from, end) {
            if (end === void 0)
                end = code.length;
            for (var i = from; i < end; i++) {
                var next = code.charCodeAt(i);
                if (isNewLine(next)) {
                    return i < end - 1 && next === 13 && code.charCodeAt(i + 1) === 10 ? i + 2 : i + 1;
                }
            }
            return -1;
        }
        var nonASCIIwhitespace = /[\u1680\u2000-\u200a\u202f\u205f\u3000\ufeff]/;
        var skipWhiteSpace = /(?:\s|\/\/.*|\/\*[^]*?\*\/)*/g;
        var ref = Object.prototype;
        var hasOwnProperty = ref.hasOwnProperty;
        var toString = ref.toString;
        var hasOwn = Object.hasOwn || (function (obj, propName) {
            return (hasOwnProperty.call(obj, propName));
        });
        var isArray = Array.isArray || (function (obj) {
            return (toString.call(obj) === "[object Array]");
        });
        function wordsRegexp(words) {
            return new RegExp("^(?:" + words.replace(/ /g, "|") + ")$");
        }
        function codePointToString(code) {
            // UTF-16 Decoding
            if (code <= 0xFFFF) {
                return String.fromCharCode(code);
            }
            code -= 0x10000;
            return String.fromCharCode((code >> 10) + 0xD800, (code & 1023) + 0xDC00);
        }
        var loneSurrogate = /(?:[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])/;
        // These are used when `options.locations` is on, for the
        // `startLoc` and `endLoc` properties.
        var Position = function Position(line, col) {
            this.line = line;
            this.column = col;
        };
        Position.prototype.offset = function offset(n) {
            return new Position(this.line, this.column + n);
        };
        var SourceLocation = function SourceLocation(p, start, end) {
            this.start = start;
            this.end = end;
            if (p.sourceFile !== null) {
                this.source = p.sourceFile;
            }
        };
        // The `getLineInfo` function is mostly useful when the
        // `locations` option is off (for performance reasons) and you
        // want to find the line/column position for a given character
        // offset. `input` should be the code string that the offset refers
        // into.
        function getLineInfo(input, offset) {
            for (var line = 1, cur = 0;;) {
                var nextBreak = nextLineBreak(input, cur, offset);
                if (nextBreak < 0) {
                    return new Position(line, offset - cur);
                }
                ++line;
                cur = nextBreak;
            }
        }
        // A second argument must be given to configure the parser process.
        // These options are recognized (only `ecmaVersion` is required):
        var defaultOptions = {
            // `ecmaVersion` indicates the ECMAScript version to parse. Must be
            // either 3, 5, 6 (or 2015), 7 (2016), 8 (2017), 9 (2018), 10
            // (2019), 11 (2020), 12 (2021), 13 (2022), 14 (2023), or `"latest"`
            // (the latest version the library supports). This influences
            // support for strict mode, the set of reserved words, and support
            // for new syntax features.
            ecmaVersion: null,
            // `sourceType` indicates the mode the code should be parsed in.
            // Can be either `"script"` or `"module"`. This influences global
            // strict mode and parsing of `import` and `export` declarations.
            sourceType: "script",
            // `onInsertedSemicolon` can be a callback that will be called
            // when a semicolon is automatically inserted. It will be passed
            // the position of the comma as an offset, and if `locations` is
            // enabled, it is given the location as a `{line, column}` object
            // as second argument.
            onInsertedSemicolon: null,
            // `onTrailingComma` is similar to `onInsertedSemicolon`, but for
            // trailing commas.
            onTrailingComma: null,
            // By default, reserved words are only enforced if ecmaVersion >= 5.
            // Set `allowReserved` to a boolean value to explicitly turn this on
            // an off. When this option has the value "never", reserved words
            // and keywords can also not be used as property names.
            allowReserved: null,
            // When enabled, a return at the top level is not considered an
            // error.
            allowReturnOutsideFunction: false,
            // When enabled, import/export statements are not constrained to
            // appearing at the top of the program, and an import.meta expression
            // in a script isn't considered an error.
            allowImportExportEverywhere: false,
            // By default, await identifiers are allowed to appear at the top-level scope only if ecmaVersion >= 2022.
            // When enabled, await identifiers are allowed to appear at the top-level scope,
            // but they are still not allowed in non-async functions.
            allowAwaitOutsideFunction: null,
            // When enabled, super identifiers are not constrained to
            // appearing in methods and do not raise an error when they appear elsewhere.
            allowSuperOutsideMethod: null,
            // When enabled, hashbang directive in the beginning of file is
            // allowed and treated as a line comment. Enabled by default when
            // `ecmaVersion` >= 2023.
            allowHashBang: false,
            // When `locations` is on, `loc` properties holding objects with
            // `start` and `end` properties in `{line, column}` form (with
            // line being 1-based and column 0-based) will be attached to the
            // nodes.
            locations: false,
            // A function can be passed as `onToken` option, which will
            // cause Acorn to call that function with object in the same
            // format as tokens returned from `tokenizer().getToken()`. Note
            // that you are not allowed to call the parser from the
            // callback—that will corrupt its internal state.
            onToken: null,
            // A function can be passed as `onComment` option, which will
            // cause Acorn to call that function with `(block, text, start,
            // end)` parameters whenever a comment is skipped. `block` is a
            // boolean indicating whether this is a block (`/* */`) comment,
            // `text` is the content of the comment, and `start` and `end` are
            // character offsets that denote the start and end of the comment.
            // When the `locations` option is on, two more parameters are
            // passed, the full `{line, column}` locations of the start and
            // end of the comments. Note that you are not allowed to call the
            // parser from the callback—that will corrupt its internal state.
            onComment: null,
            // Nodes have their start and end characters offsets recorded in
            // `start` and `end` properties (directly on the node, rather than
            // the `loc` object, which holds line/column data. To also add a
            // [semi-standardized][range] `range` property holding a `[start,
            // end]` array with the same numbers, set the `ranges` option to
            // `true`.
            //
            // [range]: https://bugzilla.mozilla.org/show_bug.cgi?id=745678
            ranges: false,
            // It is possible to parse multiple files into a single AST by
            // passing the tree produced by parsing the first file as
            // `program` option in subsequent parses. This will add the
            // toplevel forms of the parsed file to the `Program` (top) node
            // of an existing parse tree.
            program: null,
            // When `locations` is on, you can pass this to record the source
            // file in every node's `loc` object.
            sourceFile: null,
            // This value, if given, is stored in every node, whether
            // `locations` is on or off.
            directSourceFile: null,
            // When enabled, parenthesized expressions are represented by
            // (non-standard) ParenthesizedExpression nodes
            preserveParens: false
        };
        // Interpret and default an options object
        var warnedAboutEcmaVersion = false;
        function getOptions(opts) {
            var options = {};
            for (var opt in defaultOptions) {
                options[opt] = opts && hasOwn(opts, opt) ? opts[opt] : defaultOptions[opt];
            }
            if (options.ecmaVersion === "latest") {
                options.ecmaVersion = 1e8;
            }
            else if (options.ecmaVersion == null) {
                if (!warnedAboutEcmaVersion && typeof console === "object" && console.warn) {
                    warnedAboutEcmaVersion = true;
                    console.warn("Since Acorn 8.0.0, options.ecmaVersion is required.\nDefaulting to 2020, but this will stop working in the future.");
                }
                options.ecmaVersion = 11;
            }
            else if (options.ecmaVersion >= 2015) {
                options.ecmaVersion -= 2009;
            }
            if (options.allowReserved == null) {
                options.allowReserved = options.ecmaVersion < 5;
            }
            if (!opts || opts.allowHashBang == null) {
                options.allowHashBang = options.ecmaVersion >= 14;
            }
            if (isArray(options.onToken)) {
                var tokens = options.onToken;
                options.onToken = function (token) { return tokens.push(token); };
            }
            if (isArray(options.onComment)) {
                options.onComment = pushComment(options, options.onComment);
            }
            return options;
        }
        function pushComment(options, array) {
            return function (block, text, start, end, startLoc, endLoc) {
                var comment = {
                    type: block ? "Block" : "Line",
                    value: text,
                    start: start,
                    end: end
                };
                if (options.locations) {
                    comment.loc = new SourceLocation(this, startLoc, endLoc);
                }
                if (options.ranges) {
                    comment.range = [start, end];
                }
                array.push(comment);
            };
        }
        // Each scope gets a bitset that may contain these flags
        var SCOPE_TOP = 1, SCOPE_FUNCTION = 2, SCOPE_ASYNC = 4, SCOPE_GENERATOR = 8, SCOPE_ARROW = 16, SCOPE_SIMPLE_CATCH = 32, SCOPE_SUPER = 64, SCOPE_DIRECT_SUPER = 128, SCOPE_CLASS_STATIC_BLOCK = 256, SCOPE_VAR = SCOPE_TOP | SCOPE_FUNCTION | SCOPE_CLASS_STATIC_BLOCK;
        function functionFlags(async, generator) {
            return SCOPE_FUNCTION | (async ? SCOPE_ASYNC : 0) | (generator ? SCOPE_GENERATOR : 0);
        }
        // Used in checkLVal* and declareName to determine the type of a binding
        var BIND_NONE = 0, // Not a binding
        BIND_VAR = 1, // Var-style binding
        BIND_LEXICAL = 2, // Let- or const-style binding
        BIND_FUNCTION = 3, // Function declaration
        BIND_SIMPLE_CATCH = 4, // Simple (identifier pattern) catch binding
        BIND_OUTSIDE = 5; // Special case for function names as bound inside the function
        var Parser = function Parser(options, input, startPos) {
            this.options = options = getOptions(options);
            this.sourceFile = options.sourceFile;
            this.keywords = wordsRegexp(keywords$1[options.ecmaVersion >= 6 ? 6 : options.sourceType === "module" ? "5module" : 5]);
            var reserved = "";
            if (options.allowReserved !== true) {
                reserved = reservedWords[options.ecmaVersion >= 6 ? 6 : options.ecmaVersion === 5 ? 5 : 3];
                if (options.sourceType === "module") {
                    reserved += " await";
                }
            }
            this.reservedWords = wordsRegexp(reserved);
            var reservedStrict = (reserved ? reserved + " " : "") + reservedWords.strict;
            this.reservedWordsStrict = wordsRegexp(reservedStrict);
            this.reservedWordsStrictBind = wordsRegexp(reservedStrict + " " + reservedWords.strictBind);
            this.input = String(input);
            // Used to signal to callers of `readWord1` whether the word
            // contained any escape sequences. This is needed because words with
            // escape sequences must not be interpreted as keywords.
            this.containsEsc = false;
            // Set up token state
            // The current position of the tokenizer in the input.
            if (startPos) {
                this.pos = startPos;
                this.lineStart = this.input.lastIndexOf("\n", startPos - 1) + 1;
                this.curLine = this.input.slice(0, this.lineStart).split(lineBreak).length;
            }
            else {
                this.pos = this.lineStart = 0;
                this.curLine = 1;
            }
            // Properties of the current token:
            // Its type
            this.type = types$1.eof;
            // For tokens that include more information than their type, the value
            this.value = null;
            // Its start and end offset
            this.start = this.end = this.pos;
            // And, if locations are used, the {line, column} object
            // corresponding to those offsets
            this.startLoc = this.endLoc = this.curPosition();
            // Position information for the previous token
            this.lastTokEndLoc = this.lastTokStartLoc = null;
            this.lastTokStart = this.lastTokEnd = this.pos;
            // The context stack is used to superficially track syntactic
            // context to predict whether a regular expression is allowed in a
            // given position.
            this.context = this.initialContext();
            this.exprAllowed = true;
            // Figure out if it's a module code.
            this.inModule = options.sourceType === "module";
            this.strict = this.inModule || this.strictDirective(this.pos);
            // Used to signify the start of a potential arrow function
            this.potentialArrowAt = -1;
            this.potentialArrowInForAwait = false;
            // Positions to delayed-check that yield/await does not exist in default parameters.
            this.yieldPos = this.awaitPos = this.awaitIdentPos = 0;
            // Labels in scope.
            this.labels = [];
            // Thus-far undefined exports.
            this.undefinedExports = Object.create(null);
            // If enabled, skip leading hashbang line.
            if (this.pos === 0 && options.allowHashBang && this.input.slice(0, 2) === "#!") {
                this.skipLineComment(2);
            }
            // Scope tracking for duplicate variable names (see scope.js)
            this.scopeStack = [];
            this.enterScope(SCOPE_TOP);
            // For RegExp validation
            this.regexpState = null;
            // The stack of private names.
            // Each element has two properties: 'declared' and 'used'.
            // When it exited from the outermost class definition, all used private names must be declared.
            this.privateNameStack = [];
        };
        var prototypeAccessors = { inFunction: { configurable: true }, inGenerator: { configurable: true }, inAsync: { configurable: true }, canAwait: { configurable: true }, allowSuper: { configurable: true }, allowDirectSuper: { configurable: true }, treatFunctionsAsVar: { configurable: true }, allowNewDotTarget: { configurable: true }, inClassStaticBlock: { configurable: true } };
        Parser.prototype.parse = function parse() {
            var node = this.options.program || this.startNode();
            this.nextToken();
            return this.parseTopLevel(node);
        };
        prototypeAccessors.inFunction.get = function () { return (this.currentVarScope().flags & SCOPE_FUNCTION) > 0; };
        prototypeAccessors.inGenerator.get = function () { return (this.currentVarScope().flags & SCOPE_GENERATOR) > 0 && !this.currentVarScope().inClassFieldInit; };
        prototypeAccessors.inAsync.get = function () { return (this.currentVarScope().flags & SCOPE_ASYNC) > 0 && !this.currentVarScope().inClassFieldInit; };
        prototypeAccessors.canAwait.get = function () {
            for (var i = this.scopeStack.length - 1; i >= 0; i--) {
                var scope = this.scopeStack[i];
                if (scope.inClassFieldInit || scope.flags & SCOPE_CLASS_STATIC_BLOCK) {
                    return false;
                }
                if (scope.flags & SCOPE_FUNCTION) {
                    return (scope.flags & SCOPE_ASYNC) > 0;
                }
            }
            return (this.inModule && this.options.ecmaVersion >= 13) || this.options.allowAwaitOutsideFunction;
        };
        prototypeAccessors.allowSuper.get = function () {
            var ref = this.currentThisScope();
            var flags = ref.flags;
            var inClassFieldInit = ref.inClassFieldInit;
            return (flags & SCOPE_SUPER) > 0 || inClassFieldInit || this.options.allowSuperOutsideMethod;
        };
        prototypeAccessors.allowDirectSuper.get = function () { return (this.currentThisScope().flags & SCOPE_DIRECT_SUPER) > 0; };
        prototypeAccessors.treatFunctionsAsVar.get = function () { return this.treatFunctionsAsVarInScope(this.currentScope()); };
        prototypeAccessors.allowNewDotTarget.get = function () {
            var ref = this.currentThisScope();
            var flags = ref.flags;
            var inClassFieldInit = ref.inClassFieldInit;
            return (flags & (SCOPE_FUNCTION | SCOPE_CLASS_STATIC_BLOCK)) > 0 || inClassFieldInit;
        };
        prototypeAccessors.inClassStaticBlock.get = function () {
            return (this.currentVarScope().flags & SCOPE_CLASS_STATIC_BLOCK) > 0;
        };
        Parser.extend = function extend() {
            var plugins = [], len = arguments.length;
            while (len--)
                plugins[len] = arguments[len];
            var cls = this;
            for (var i = 0; i < plugins.length; i++) {
                cls = plugins[i](cls);
            }
            return cls;
        };
        Parser.parse = function parse(input, options) {
            return new this(options, input).parse();
        };
        Parser.parseExpressionAt = function parseExpressionAt(input, pos, options) {
            var parser = new this(options, input, pos);
            parser.nextToken();
            return parser.parseExpression();
        };
        Parser.tokenizer = function tokenizer(input, options) {
            return new this(options, input);
        };
        Object.defineProperties(Parser.prototype, prototypeAccessors);
        var pp$9 = Parser.prototype;
        // ## Parser utilities
        var literal = /^(?:'((?:\\.|[^'\\])*?)'|"((?:\\.|[^"\\])*?)")/;
        pp$9.strictDirective = function (start) {
            if (this.options.ecmaVersion < 5) {
                return false;
            }
            for (;;) {
                // Try to find string literal.
                skipWhiteSpace.lastIndex = start;
                start += skipWhiteSpace.exec(this.input)[0].length;
                var match = literal.exec(this.input.slice(start));
                if (!match) {
                    return false;
                }
                if ((match[1] || match[2]) === "use strict") {
                    skipWhiteSpace.lastIndex = start + match[0].length;
                    var spaceAfter = skipWhiteSpace.exec(this.input), end = spaceAfter.index + spaceAfter[0].length;
                    var next = this.input.charAt(end);
                    return next === ";" || next === "}" ||
                        (lineBreak.test(spaceAfter[0]) &&
                            !(/[(`.[+\-/*%<>=,?^&]/.test(next) || next === "!" && this.input.charAt(end + 1) === "="));
                }
                start += match[0].length;
                // Skip semicolon, if any.
                skipWhiteSpace.lastIndex = start;
                start += skipWhiteSpace.exec(this.input)[0].length;
                if (this.input[start] === ";") {
                    start++;
                }
            }
        };
        // Predicate that tests whether the next token is of the given
        // type, and if yes, consumes it as a side effect.
        pp$9.eat = function (type) {
            if (this.type === type) {
                this.next();
                return true;
            }
            else {
                return false;
            }
        };
        // Tests whether parsed token is a contextual keyword.
        pp$9.isContextual = function (name) {
            return this.type === types$1.name && this.value === name && !this.containsEsc;
        };
        // Consumes contextual keyword if possible.
        pp$9.eatContextual = function (name) {
            if (!this.isContextual(name)) {
                return false;
            }
            this.next();
            return true;
        };
        // Asserts that following token is given contextual keyword.
        pp$9.expectContextual = function (name) {
            if (!this.eatContextual(name)) {
                this.unexpected();
            }
        };
        // Test whether a semicolon can be inserted at the current position.
        pp$9.canInsertSemicolon = function () {
            return this.type === types$1.eof ||
                this.type === types$1.braceR ||
                lineBreak.test(this.input.slice(this.lastTokEnd, this.start));
        };
        pp$9.insertSemicolon = function () {
            if (this.canInsertSemicolon()) {
                if (this.options.onInsertedSemicolon) {
                    this.options.onInsertedSemicolon(this.lastTokEnd, this.lastTokEndLoc);
                }
                return true;
            }
        };
        // Consume a semicolon, or, failing that, see if we are allowed to
        // pretend that there is a semicolon at this position.
        pp$9.semicolon = function () {
            if (!this.eat(types$1.semi) && !this.insertSemicolon()) {
                this.unexpected();
            }
        };
        pp$9.afterTrailingComma = function (tokType, notNext) {
            if (this.type === tokType) {
                if (this.options.onTrailingComma) {
                    this.options.onTrailingComma(this.lastTokStart, this.lastTokStartLoc);
                }
                if (!notNext) {
                    this.next();
                }
                return true;
            }
        };
        // Expect a token of a given type. If found, consume it, otherwise,
        // raise an unexpected token error.
        pp$9.expect = function (type) {
            this.eat(type) || this.unexpected();
        };
        // Raise an unexpected token error.
        pp$9.unexpected = function (pos) {
            this.raise(pos != null ? pos : this.start, "Unexpected token");
        };
        var DestructuringErrors = function DestructuringErrors() {
            this.shorthandAssign =
                this.trailingComma =
                    this.parenthesizedAssign =
                        this.parenthesizedBind =
                            this.doubleProto =
                                -1;
        };
        pp$9.checkPatternErrors = function (refDestructuringErrors, isAssign) {
            if (!refDestructuringErrors) {
                return;
            }
            if (refDestructuringErrors.trailingComma > -1) {
                this.raiseRecoverable(refDestructuringErrors.trailingComma, "Comma is not permitted after the rest element");
            }
            var parens = isAssign ? refDestructuringErrors.parenthesizedAssign : refDestructuringErrors.parenthesizedBind;
            if (parens > -1) {
                this.raiseRecoverable(parens, isAssign ? "Assigning to rvalue" : "Parenthesized pattern");
            }
        };
        pp$9.checkExpressionErrors = function (refDestructuringErrors, andThrow) {
            if (!refDestructuringErrors) {
                return false;
            }
            var shorthandAssign = refDestructuringErrors.shorthandAssign;
            var doubleProto = refDestructuringErrors.doubleProto;
            if (!andThrow) {
                return shorthandAssign >= 0 || doubleProto >= 0;
            }
            if (shorthandAssign >= 0) {
                this.raise(shorthandAssign, "Shorthand property assignments are valid only in destructuring patterns");
            }
            if (doubleProto >= 0) {
                this.raiseRecoverable(doubleProto, "Redefinition of __proto__ property");
            }
        };
        pp$9.checkYieldAwaitInDefaultParams = function () {
            if (this.yieldPos && (!this.awaitPos || this.yieldPos < this.awaitPos)) {
                this.raise(this.yieldPos, "Yield expression cannot be a default value");
            }
            if (this.awaitPos) {
                this.raise(this.awaitPos, "Await expression cannot be a default value");
            }
        };
        pp$9.isSimpleAssignTarget = function (expr) {
            if (expr.type === "ParenthesizedExpression") {
                return this.isSimpleAssignTarget(expr.expression);
            }
            return expr.type === "Identifier" || expr.type === "MemberExpression";
        };
        var pp$8 = Parser.prototype;
        // ### Statement parsing
        // Parse a program. Initializes the parser, reads any number of
        // statements, and wraps them in a Program node.  Optionally takes a
        // `program` argument.  If present, the statements will be appended
        // to its body instead of creating a new node.
        pp$8.parseTopLevel = function (node) {
            var exports = Object.create(null);
            if (!node.body) {
                node.body = [];
            }
            while (this.type !== types$1.eof) {
                var stmt = this.parseStatement(null, true, exports);
                node.body.push(stmt);
            }
            if (this.inModule) {
                for (var i = 0, list = Object.keys(this.undefinedExports); i < list.length; i += 1) {
                    var name = list[i];
                    this.raiseRecoverable(this.undefinedExports[name].start, ("Export '" + name + "' is not defined"));
                }
            }
            this.adaptDirectivePrologue(node.body);
            this.next();
            node.sourceType = this.options.sourceType;
            return this.finishNode(node, "Program");
        };
        var loopLabel = { kind: "loop" }, switchLabel = { kind: "switch" };
        pp$8.isLet = function (context) {
            if (this.options.ecmaVersion < 6 || !this.isContextual("let")) {
                return false;
            }
            skipWhiteSpace.lastIndex = this.pos;
            var skip = skipWhiteSpace.exec(this.input);
            var next = this.pos + skip[0].length, nextCh = this.input.charCodeAt(next);
            // For ambiguous cases, determine if a LexicalDeclaration (or only a
            // Statement) is allowed here. If context is not empty then only a Statement
            // is allowed. However, `let [` is an explicit negative lookahead for
            // ExpressionStatement, so special-case it first.
            if (nextCh === 91 || nextCh === 92) {
                return true;
            } // '[', '/'
            if (context) {
                return false;
            }
            if (nextCh === 123 || nextCh > 0xd7ff && nextCh < 0xdc00) {
                return true;
            } // '{', astral
            if (isIdentifierStart(nextCh, true)) {
                var pos = next + 1;
                while (isIdentifierChar(nextCh = this.input.charCodeAt(pos), true)) {
                    ++pos;
                }
                if (nextCh === 92 || nextCh > 0xd7ff && nextCh < 0xdc00) {
                    return true;
                }
                var ident = this.input.slice(next, pos);
                if (!keywordRelationalOperator.test(ident)) {
                    return true;
                }
            }
            return false;
        };
        // check 'async [no LineTerminator here] function'
        // - 'async /*foo*/ function' is OK.
        // - 'async /*\n*/ function' is invalid.
        pp$8.isAsyncFunction = function () {
            if (this.options.ecmaVersion < 8 || !this.isContextual("async")) {
                return false;
            }
            skipWhiteSpace.lastIndex = this.pos;
            var skip = skipWhiteSpace.exec(this.input);
            var next = this.pos + skip[0].length, after;
            return !lineBreak.test(this.input.slice(this.pos, next)) &&
                this.input.slice(next, next + 8) === "function" &&
                (next + 8 === this.input.length ||
                    !(isIdentifierChar(after = this.input.charCodeAt(next + 8)) || after > 0xd7ff && after < 0xdc00));
        };
        // Parse a single statement.
        //
        // If expecting a statement and finding a slash operator, parse a
        // regular expression literal. This is to handle cases like
        // `if (foo) /blah/.exec(foo)`, where looking at the previous token
        // does not help.
        pp$8.parseStatement = function (context, topLevel, exports) {
            var starttype = this.type, node = this.startNode(), kind;
            if (this.isLet(context)) {
                starttype = types$1._var;
                kind = "let";
            }
            // Most types of statements are recognized by the keyword they
            // start with. Many are trivial to parse, some require a bit of
            // complexity.
            switch (starttype) {
                case types$1._break:
                case types$1._continue: return this.parseBreakContinueStatement(node, starttype.keyword);
                case types$1._debugger: return this.parseDebuggerStatement(node);
                case types$1._do: return this.parseDoStatement(node);
                case types$1._for: return this.parseForStatement(node);
                case types$1._function:
                    // Function as sole body of either an if statement or a labeled statement
                    // works, but not when it is part of a labeled statement that is the sole
                    // body of an if statement.
                    if ((context && (this.strict || context !== "if" && context !== "label")) && this.options.ecmaVersion >= 6) {
                        this.unexpected();
                    }
                    return this.parseFunctionStatement(node, false, !context);
                case types$1._class:
                    if (context) {
                        this.unexpected();
                    }
                    return this.parseClass(node, true);
                case types$1._if: return this.parseIfStatement(node);
                case types$1._return: return this.parseReturnStatement(node);
                case types$1._switch: return this.parseSwitchStatement(node);
                case types$1._throw: return this.parseThrowStatement(node);
                case types$1._try: return this.parseTryStatement(node);
                case types$1._const:
                case types$1._var:
                    kind = kind || this.value;
                    if (context && kind !== "var") {
                        this.unexpected();
                    }
                    return this.parseVarStatement(node, kind);
                case types$1._while: return this.parseWhileStatement(node);
                case types$1._with: return this.parseWithStatement(node);
                case types$1.braceL: return this.parseBlock(true, node);
                case types$1.semi: return this.parseEmptyStatement(node);
                case types$1._export:
                case types$1._import:
                    if (this.options.ecmaVersion > 10 && starttype === types$1._import) {
                        skipWhiteSpace.lastIndex = this.pos;
                        var skip = skipWhiteSpace.exec(this.input);
                        var next = this.pos + skip[0].length, nextCh = this.input.charCodeAt(next);
                        if (nextCh === 40 || nextCh === 46) // '(' or '.'
                         {
                            return this.parseExpressionStatement(node, this.parseExpression());
                        }
                    }
                    if (!this.options.allowImportExportEverywhere) {
                        if (!topLevel) {
                            this.raise(this.start, "'import' and 'export' may only appear at the top level");
                        }
                        if (!this.inModule) {
                            this.raise(this.start, "'import' and 'export' may appear only with 'sourceType: module'");
                        }
                    }
                    return starttype === types$1._import ? this.parseImport(node) : this.parseExport(node, exports);
                // If the statement does not start with a statement keyword or a
                // brace, it's an ExpressionStatement or LabeledStatement. We
                // simply start parsing an expression, and afterwards, if the
                // next token is a colon and the expression was a simple
                // Identifier node, we switch to interpreting it as a label.
                default:
                    if (this.isAsyncFunction()) {
                        if (context) {
                            this.unexpected();
                        }
                        this.next();
                        return this.parseFunctionStatement(node, true, !context);
                    }
                    var maybeName = this.value, expr = this.parseExpression();
                    if (starttype === types$1.name && expr.type === "Identifier" && this.eat(types$1.colon)) {
                        return this.parseLabeledStatement(node, maybeName, expr, context);
                    }
                    else {
                        return this.parseExpressionStatement(node, expr);
                    }
            }
        };
        pp$8.parseBreakContinueStatement = function (node, keyword) {
            var isBreak = keyword === "break";
            this.next();
            if (this.eat(types$1.semi) || this.insertSemicolon()) {
                node.label = null;
            }
            else if (this.type !== types$1.name) {
                this.unexpected();
            }
            else {
                node.label = this.parseIdent();
                this.semicolon();
            }
            // Verify that there is an actual destination to break or
            // continue to.
            var i = 0;
            for (; i < this.labels.length; ++i) {
                var lab = this.labels[i];
                if (node.label == null || lab.name === node.label.name) {
                    if (lab.kind != null && (isBreak || lab.kind === "loop")) {
                        break;
                    }
                    if (node.label && isBreak) {
                        break;
                    }
                }
            }
            if (i === this.labels.length) {
                this.raise(node.start, "Unsyntactic " + keyword);
            }
            return this.finishNode(node, isBreak ? "BreakStatement" : "ContinueStatement");
        };
        pp$8.parseDebuggerStatement = function (node) {
            this.next();
            this.semicolon();
            return this.finishNode(node, "DebuggerStatement");
        };
        pp$8.parseDoStatement = function (node) {
            this.next();
            this.labels.push(loopLabel);
            node.body = this.parseStatement("do");
            this.labels.pop();
            this.expect(types$1._while);
            node.test = this.parseParenExpression();
            if (this.options.ecmaVersion >= 6) {
                this.eat(types$1.semi);
            }
            else {
                this.semicolon();
            }
            return this.finishNode(node, "DoWhileStatement");
        };
        // Disambiguating between a `for` and a `for`/`in` or `for`/`of`
        // loop is non-trivial. Basically, we have to parse the init `var`
        // statement or expression, disallowing the `in` operator (see
        // the second parameter to `parseExpression`), and then check
        // whether the next token is `in` or `of`. When there is no init
        // part (semicolon immediately after the opening parenthesis), it
        // is a regular `for` loop.
        pp$8.parseForStatement = function (node) {
            this.next();
            var awaitAt = (this.options.ecmaVersion >= 9 && this.canAwait && this.eatContextual("await")) ? this.lastTokStart : -1;
            this.labels.push(loopLabel);
            this.enterScope(0);
            this.expect(types$1.parenL);
            if (this.type === types$1.semi) {
                if (awaitAt > -1) {
                    this.unexpected(awaitAt);
                }
                return this.parseFor(node, null);
            }
            var isLet = this.isLet();
            if (this.type === types$1._var || this.type === types$1._const || isLet) {
                var init$1 = this.startNode(), kind = isLet ? "let" : this.value;
                this.next();
                this.parseVar(init$1, true, kind);
                this.finishNode(init$1, "VariableDeclaration");
                if ((this.type === types$1._in || (this.options.ecmaVersion >= 6 && this.isContextual("of"))) && init$1.declarations.length === 1) {
                    if (this.options.ecmaVersion >= 9) {
                        if (this.type === types$1._in) {
                            if (awaitAt > -1) {
                                this.unexpected(awaitAt);
                            }
                        }
                        else {
                            node.await = awaitAt > -1;
                        }
                    }
                    return this.parseForIn(node, init$1);
                }
                if (awaitAt > -1) {
                    this.unexpected(awaitAt);
                }
                return this.parseFor(node, init$1);
            }
            var startsWithLet = this.isContextual("let"), isForOf = false;
            var refDestructuringErrors = new DestructuringErrors;
            var init = this.parseExpression(awaitAt > -1 ? "await" : true, refDestructuringErrors);
            if (this.type === types$1._in || (isForOf = this.options.ecmaVersion >= 6 && this.isContextual("of"))) {
                if (this.options.ecmaVersion >= 9) {
                    if (this.type === types$1._in) {
                        if (awaitAt > -1) {
                            this.unexpected(awaitAt);
                        }
                    }
                    else {
                        node.await = awaitAt > -1;
                    }
                }
                if (startsWithLet && isForOf) {
                    this.raise(init.start, "The left-hand side of a for-of loop may not start with 'let'.");
                }
                this.toAssignable(init, false, refDestructuringErrors);
                this.checkLValPattern(init);
                return this.parseForIn(node, init);
            }
            else {
                this.checkExpressionErrors(refDestructuringErrors, true);
            }
            if (awaitAt > -1) {
                this.unexpected(awaitAt);
            }
            return this.parseFor(node, init);
        };
        pp$8.parseFunctionStatement = function (node, isAsync, declarationPosition) {
            this.next();
            return this.parseFunction(node, FUNC_STATEMENT | (declarationPosition ? 0 : FUNC_HANGING_STATEMENT), false, isAsync);
        };
        pp$8.parseIfStatement = function (node) {
            this.next();
            node.test = this.parseParenExpression();
            // allow function declarations in branches, but only in non-strict mode
            node.consequent = this.parseStatement("if");
            node.alternate = this.eat(types$1._else) ? this.parseStatement("if") : null;
            return this.finishNode(node, "IfStatement");
        };
        pp$8.parseReturnStatement = function (node) {
            if (!this.inFunction && !this.options.allowReturnOutsideFunction) {
                this.raise(this.start, "'return' outside of function");
            }
            this.next();
            // In `return` (and `break`/`continue`), the keywords with
            // optional arguments, we eagerly look for a semicolon or the
            // possibility to insert one.
            if (this.eat(types$1.semi) || this.insertSemicolon()) {
                node.argument = null;
            }
            else {
                node.argument = this.parseExpression();
                this.semicolon();
            }
            return this.finishNode(node, "ReturnStatement");
        };
        pp$8.parseSwitchStatement = function (node) {
            this.next();
            node.discriminant = this.parseParenExpression();
            node.cases = [];
            this.expect(types$1.braceL);
            this.labels.push(switchLabel);
            this.enterScope(0);
            // Statements under must be grouped (by label) in SwitchCase
            // nodes. `cur` is used to keep the node that we are currently
            // adding statements to.
            var cur;
            for (var sawDefault = false; this.type !== types$1.braceR;) {
                if (this.type === types$1._case || this.type === types$1._default) {
                    var isCase = this.type === types$1._case;
                    if (cur) {
                        this.finishNode(cur, "SwitchCase");
                    }
                    node.cases.push(cur = this.startNode());
                    cur.consequent = [];
                    this.next();
                    if (isCase) {
                        cur.test = this.parseExpression();
                    }
                    else {
                        if (sawDefault) {
                            this.raiseRecoverable(this.lastTokStart, "Multiple default clauses");
                        }
                        sawDefault = true;
                        cur.test = null;
                    }
                    this.expect(types$1.colon);
                }
                else {
                    if (!cur) {
                        this.unexpected();
                    }
                    cur.consequent.push(this.parseStatement(null));
                }
            }
            this.exitScope();
            if (cur) {
                this.finishNode(cur, "SwitchCase");
            }
            this.next(); // Closing brace
            this.labels.pop();
            return this.finishNode(node, "SwitchStatement");
        };
        pp$8.parseThrowStatement = function (node) {
            this.next();
            if (lineBreak.test(this.input.slice(this.lastTokEnd, this.start))) {
                this.raise(this.lastTokEnd, "Illegal newline after throw");
            }
            node.argument = this.parseExpression();
            this.semicolon();
            return this.finishNode(node, "ThrowStatement");
        };
        // Reused empty array added for node fields that are always empty.
        var empty$1 = [];
        pp$8.parseTryStatement = function (node) {
            this.next();
            node.block = this.parseBlock();
            node.handler = null;
            if (this.type === types$1._catch) {
                var clause = this.startNode();
                this.next();
                if (this.eat(types$1.parenL)) {
                    clause.param = this.parseBindingAtom();
                    var simple = clause.param.type === "Identifier";
                    this.enterScope(simple ? SCOPE_SIMPLE_CATCH : 0);
                    this.checkLValPattern(clause.param, simple ? BIND_SIMPLE_CATCH : BIND_LEXICAL);
                    this.expect(types$1.parenR);
                }
                else {
                    if (this.options.ecmaVersion < 10) {
                        this.unexpected();
                    }
                    clause.param = null;
                    this.enterScope(0);
                }
                clause.body = this.parseBlock(false);
                this.exitScope();
                node.handler = this.finishNode(clause, "CatchClause");
            }
            node.finalizer = this.eat(types$1._finally) ? this.parseBlock() : null;
            if (!node.handler && !node.finalizer) {
                this.raise(node.start, "Missing catch or finally clause");
            }
            return this.finishNode(node, "TryStatement");
        };
        pp$8.parseVarStatement = function (node, kind) {
            this.next();
            this.parseVar(node, false, kind);
            this.semicolon();
            return this.finishNode(node, "VariableDeclaration");
        };
        pp$8.parseWhileStatement = function (node) {
            this.next();
            node.test = this.parseParenExpression();
            this.labels.push(loopLabel);
            node.body = this.parseStatement("while");
            this.labels.pop();
            return this.finishNode(node, "WhileStatement");
        };
        pp$8.parseWithStatement = function (node) {
            if (this.strict) {
                this.raise(this.start, "'with' in strict mode");
            }
            this.next();
            node.object = this.parseParenExpression();
            node.body = this.parseStatement("with");
            return this.finishNode(node, "WithStatement");
        };
        pp$8.parseEmptyStatement = function (node) {
            this.next();
            return this.finishNode(node, "EmptyStatement");
        };
        pp$8.parseLabeledStatement = function (node, maybeName, expr, context) {
            for (var i$1 = 0, list = this.labels; i$1 < list.length; i$1 += 1) {
                var label = list[i$1];
                if (label.name === maybeName) {
                    this.raise(expr.start, "Label '" + maybeName + "' is already declared");
                }
            }
            var kind = this.type.isLoop ? "loop" : this.type === types$1._switch ? "switch" : null;
            for (var i = this.labels.length - 1; i >= 0; i--) {
                var label$1 = this.labels[i];
                if (label$1.statementStart === node.start) {
                    // Update information about previous labels on this node
                    label$1.statementStart = this.start;
                    label$1.kind = kind;
                }
                else {
                    break;
                }
            }
            this.labels.push({ name: maybeName, kind: kind, statementStart: this.start });
            node.body = this.parseStatement(context ? context.indexOf("label") === -1 ? context + "label" : context : "label");
            this.labels.pop();
            node.label = expr;
            return this.finishNode(node, "LabeledStatement");
        };
        pp$8.parseExpressionStatement = function (node, expr) {
            node.expression = expr;
            this.semicolon();
            return this.finishNode(node, "ExpressionStatement");
        };
        // Parse a semicolon-enclosed block of statements, handling `"use
        // strict"` declarations when `allowStrict` is true (used for
        // function bodies).
        pp$8.parseBlock = function (createNewLexicalScope, node, exitStrict) {
            if (createNewLexicalScope === void 0)
                createNewLexicalScope = true;
            if (node === void 0)
                node = this.startNode();
            node.body = [];
            this.expect(types$1.braceL);
            if (createNewLexicalScope) {
                this.enterScope(0);
            }
            while (this.type !== types$1.braceR) {
                var stmt = this.parseStatement(null);
                node.body.push(stmt);
            }
            if (exitStrict) {
                this.strict = false;
            }
            this.next();
            if (createNewLexicalScope) {
                this.exitScope();
            }
            return this.finishNode(node, "BlockStatement");
        };
        // Parse a regular `for` loop. The disambiguation code in
        // `parseStatement` will already have parsed the init statement or
        // expression.
        pp$8.parseFor = function (node, init) {
            node.init = init;
            this.expect(types$1.semi);
            node.test = this.type === types$1.semi ? null : this.parseExpression();
            this.expect(types$1.semi);
            node.update = this.type === types$1.parenR ? null : this.parseExpression();
            this.expect(types$1.parenR);
            node.body = this.parseStatement("for");
            this.exitScope();
            this.labels.pop();
            return this.finishNode(node, "ForStatement");
        };
        // Parse a `for`/`in` and `for`/`of` loop, which are almost
        // same from parser's perspective.
        pp$8.parseForIn = function (node, init) {
            var isForIn = this.type === types$1._in;
            this.next();
            if (init.type === "VariableDeclaration" &&
                init.declarations[0].init != null &&
                (!isForIn ||
                    this.options.ecmaVersion < 8 ||
                    this.strict ||
                    init.kind !== "var" ||
                    init.declarations[0].id.type !== "Identifier")) {
                this.raise(init.start, ((isForIn ? "for-in" : "for-of") + " loop variable declaration may not have an initializer"));
            }
            node.left = init;
            node.right = isForIn ? this.parseExpression() : this.parseMaybeAssign();
            this.expect(types$1.parenR);
            node.body = this.parseStatement("for");
            this.exitScope();
            this.labels.pop();
            return this.finishNode(node, isForIn ? "ForInStatement" : "ForOfStatement");
        };
        // Parse a list of variable declarations.
        pp$8.parseVar = function (node, isFor, kind) {
            node.declarations = [];
            node.kind = kind;
            for (;;) {
                var decl = this.startNode();
                this.parseVarId(decl, kind);
                if (this.eat(types$1.eq)) {
                    decl.init = this.parseMaybeAssign(isFor);
                }
                else if (kind === "const" && !(this.type === types$1._in || (this.options.ecmaVersion >= 6 && this.isContextual("of")))) {
                    this.unexpected();
                }
                else if (decl.id.type !== "Identifier" && !(isFor && (this.type === types$1._in || this.isContextual("of")))) {
                    this.raise(this.lastTokEnd, "Complex binding patterns require an initialization value");
                }
                else {
                    decl.init = null;
                }
                node.declarations.push(this.finishNode(decl, "VariableDeclarator"));
                if (!this.eat(types$1.comma)) {
                    break;
                }
            }
            return node;
        };
        pp$8.parseVarId = function (decl, kind) {
            decl.id = this.parseBindingAtom();
            this.checkLValPattern(decl.id, kind === "var" ? BIND_VAR : BIND_LEXICAL, false);
        };
        var FUNC_STATEMENT = 1, FUNC_HANGING_STATEMENT = 2, FUNC_NULLABLE_ID = 4;
        // Parse a function declaration or literal (depending on the
        // `statement & FUNC_STATEMENT`).
        // Remove `allowExpressionBody` for 7.0.0, as it is only called with false
        pp$8.parseFunction = function (node, statement, allowExpressionBody, isAsync, forInit) {
            this.initFunction(node);
            if (this.options.ecmaVersion >= 9 || this.options.ecmaVersion >= 6 && !isAsync) {
                if (this.type === types$1.star && (statement & FUNC_HANGING_STATEMENT)) {
                    this.unexpected();
                }
                node.generator = this.eat(types$1.star);
            }
            if (this.options.ecmaVersion >= 8) {
                node.async = !!isAsync;
            }
            if (statement & FUNC_STATEMENT) {
                node.id = (statement & FUNC_NULLABLE_ID) && this.type !== types$1.name ? null : this.parseIdent();
                if (node.id && !(statement & FUNC_HANGING_STATEMENT)) 
                // If it is a regular function declaration in sloppy mode, then it is
                // subject to Annex B semantics (BIND_FUNCTION). Otherwise, the binding
                // mode depends on properties of the current scope (see
                // treatFunctionsAsVar).
                {
                    this.checkLValSimple(node.id, (this.strict || node.generator || node.async) ? this.treatFunctionsAsVar ? BIND_VAR : BIND_LEXICAL : BIND_FUNCTION);
                }
            }
            var oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;
            this.yieldPos = 0;
            this.awaitPos = 0;
            this.awaitIdentPos = 0;
            this.enterScope(functionFlags(node.async, node.generator));
            if (!(statement & FUNC_STATEMENT)) {
                node.id = this.type === types$1.name ? this.parseIdent() : null;
            }
            this.parseFunctionParams(node);
            this.parseFunctionBody(node, allowExpressionBody, false, forInit);
            this.yieldPos = oldYieldPos;
            this.awaitPos = oldAwaitPos;
            this.awaitIdentPos = oldAwaitIdentPos;
            return this.finishNode(node, (statement & FUNC_STATEMENT) ? "FunctionDeclaration" : "FunctionExpression");
        };
        pp$8.parseFunctionParams = function (node) {
            this.expect(types$1.parenL);
            node.params = this.parseBindingList(types$1.parenR, false, this.options.ecmaVersion >= 8);
            this.checkYieldAwaitInDefaultParams();
        };
        // Parse a class declaration or literal (depending on the
        // `isStatement` parameter).
        pp$8.parseClass = function (node, isStatement) {
            this.next();
            // ecma-262 14.6 Class Definitions
            // A class definition is always strict mode code.
            var oldStrict = this.strict;
            this.strict = true;
            this.parseClassId(node, isStatement);
            this.parseClassSuper(node);
            var privateNameMap = this.enterClassBody();
            var classBody = this.startNode();
            var hadConstructor = false;
            classBody.body = [];
            this.expect(types$1.braceL);
            while (this.type !== types$1.braceR) {
                var element = this.parseClassElement(node.superClass !== null);
                if (element) {
                    classBody.body.push(element);
                    if (element.type === "MethodDefinition" && element.kind === "constructor") {
                        if (hadConstructor) {
                            this.raise(element.start, "Duplicate constructor in the same class");
                        }
                        hadConstructor = true;
                    }
                    else if (element.key && element.key.type === "PrivateIdentifier" && isPrivateNameConflicted(privateNameMap, element)) {
                        this.raiseRecoverable(element.key.start, ("Identifier '#" + (element.key.name) + "' has already been declared"));
                    }
                }
            }
            this.strict = oldStrict;
            this.next();
            node.body = this.finishNode(classBody, "ClassBody");
            this.exitClassBody();
            return this.finishNode(node, isStatement ? "ClassDeclaration" : "ClassExpression");
        };
        pp$8.parseClassElement = function (constructorAllowsSuper) {
            if (this.eat(types$1.semi)) {
                return null;
            }
            var ecmaVersion = this.options.ecmaVersion;
            var node = this.startNode();
            var keyName = "";
            var isGenerator = false;
            var isAsync = false;
            var kind = "method";
            var isStatic = false;
            if (this.eatContextual("static")) {
                // Parse static init block
                if (ecmaVersion >= 13 && this.eat(types$1.braceL)) {
                    this.parseClassStaticBlock(node);
                    return node;
                }
                if (this.isClassElementNameStart() || this.type === types$1.star) {
                    isStatic = true;
                }
                else {
                    keyName = "static";
                }
            }
            node.static = isStatic;
            if (!keyName && ecmaVersion >= 8 && this.eatContextual("async")) {
                if ((this.isClassElementNameStart() || this.type === types$1.star) && !this.canInsertSemicolon()) {
                    isAsync = true;
                }
                else {
                    keyName = "async";
                }
            }
            if (!keyName && (ecmaVersion >= 9 || !isAsync) && this.eat(types$1.star)) {
                isGenerator = true;
            }
            if (!keyName && !isAsync && !isGenerator) {
                var lastValue = this.value;
                if (this.eatContextual("get") || this.eatContextual("set")) {
                    if (this.isClassElementNameStart()) {
                        kind = lastValue;
                    }
                    else {
                        keyName = lastValue;
                    }
                }
            }
            // Parse element name
            if (keyName) {
                // 'async', 'get', 'set', or 'static' were not a keyword contextually.
                // The last token is any of those. Make it the element name.
                node.computed = false;
                node.key = this.startNodeAt(this.lastTokStart, this.lastTokStartLoc);
                node.key.name = keyName;
                this.finishNode(node.key, "Identifier");
            }
            else {
                this.parseClassElementName(node);
            }
            // Parse element value
            if (ecmaVersion < 13 || this.type === types$1.parenL || kind !== "method" || isGenerator || isAsync) {
                var isConstructor = !node.static && checkKeyName(node, "constructor");
                var allowsDirectSuper = isConstructor && constructorAllowsSuper;
                // Couldn't move this check into the 'parseClassMethod' method for backward compatibility.
                if (isConstructor && kind !== "method") {
                    this.raise(node.key.start, "Constructor can't have get/set modifier");
                }
                node.kind = isConstructor ? "constructor" : kind;
                this.parseClassMethod(node, isGenerator, isAsync, allowsDirectSuper);
            }
            else {
                this.parseClassField(node);
            }
            return node;
        };
        pp$8.isClassElementNameStart = function () {
            return (this.type === types$1.name ||
                this.type === types$1.privateId ||
                this.type === types$1.num ||
                this.type === types$1.string ||
                this.type === types$1.bracketL ||
                this.type.keyword);
        };
        pp$8.parseClassElementName = function (element) {
            if (this.type === types$1.privateId) {
                if (this.value === "constructor") {
                    this.raise(this.start, "Classes can't have an element named '#constructor'");
                }
                element.computed = false;
                element.key = this.parsePrivateIdent();
            }
            else {
                this.parsePropertyName(element);
            }
        };
        pp$8.parseClassMethod = function (method, isGenerator, isAsync, allowsDirectSuper) {
            // Check key and flags
            var key = method.key;
            if (method.kind === "constructor") {
                if (isGenerator) {
                    this.raise(key.start, "Constructor can't be a generator");
                }
                if (isAsync) {
                    this.raise(key.start, "Constructor can't be an async method");
                }
            }
            else if (method.static && checkKeyName(method, "prototype")) {
                this.raise(key.start, "Classes may not have a static property named prototype");
            }
            // Parse value
            var value = method.value = this.parseMethod(isGenerator, isAsync, allowsDirectSuper);
            // Check value
            if (method.kind === "get" && value.params.length !== 0) {
                this.raiseRecoverable(value.start, "getter should have no params");
            }
            if (method.kind === "set" && value.params.length !== 1) {
                this.raiseRecoverable(value.start, "setter should have exactly one param");
            }
            if (method.kind === "set" && value.params[0].type === "RestElement") {
                this.raiseRecoverable(value.params[0].start, "Setter cannot use rest params");
            }
            return this.finishNode(method, "MethodDefinition");
        };
        pp$8.parseClassField = function (field) {
            if (checkKeyName(field, "constructor")) {
                this.raise(field.key.start, "Classes can't have a field named 'constructor'");
            }
            else if (field.static && checkKeyName(field, "prototype")) {
                this.raise(field.key.start, "Classes can't have a static field named 'prototype'");
            }
            if (this.eat(types$1.eq)) {
                // To raise SyntaxError if 'arguments' exists in the initializer.
                var scope = this.currentThisScope();
                var inClassFieldInit = scope.inClassFieldInit;
                scope.inClassFieldInit = true;
                field.value = this.parseMaybeAssign();
                scope.inClassFieldInit = inClassFieldInit;
            }
            else {
                field.value = null;
            }
            this.semicolon();
            return this.finishNode(field, "PropertyDefinition");
        };
        pp$8.parseClassStaticBlock = function (node) {
            node.body = [];
            var oldLabels = this.labels;
            this.labels = [];
            this.enterScope(SCOPE_CLASS_STATIC_BLOCK | SCOPE_SUPER);
            while (this.type !== types$1.braceR) {
                var stmt = this.parseStatement(null);
                node.body.push(stmt);
            }
            this.next();
            this.exitScope();
            this.labels = oldLabels;
            return this.finishNode(node, "StaticBlock");
        };
        pp$8.parseClassId = function (node, isStatement) {
            if (this.type === types$1.name) {
                node.id = this.parseIdent();
                if (isStatement) {
                    this.checkLValSimple(node.id, BIND_LEXICAL, false);
                }
            }
            else {
                if (isStatement === true) {
                    this.unexpected();
                }
                node.id = null;
            }
        };
        pp$8.parseClassSuper = function (node) {
            node.superClass = this.eat(types$1._extends) ? this.parseExprSubscripts(null, false) : null;
        };
        pp$8.enterClassBody = function () {
            var element = { declared: Object.create(null), used: [] };
            this.privateNameStack.push(element);
            return element.declared;
        };
        pp$8.exitClassBody = function () {
            var ref = this.privateNameStack.pop();
            var declared = ref.declared;
            var used = ref.used;
            var len = this.privateNameStack.length;
            var parent = len === 0 ? null : this.privateNameStack[len - 1];
            for (var i = 0; i < used.length; ++i) {
                var id = used[i];
                if (!hasOwn(declared, id.name)) {
                    if (parent) {
                        parent.used.push(id);
                    }
                    else {
                        this.raiseRecoverable(id.start, ("Private field '#" + (id.name) + "' must be declared in an enclosing class"));
                    }
                }
            }
        };
        function isPrivateNameConflicted(privateNameMap, element) {
            var name = element.key.name;
            var curr = privateNameMap[name];
            var next = "true";
            if (element.type === "MethodDefinition" && (element.kind === "get" || element.kind === "set")) {
                next = (element.static ? "s" : "i") + element.kind;
            }
            // `class { get #a(){}; static set #a(_){} }` is also conflict.
            if (curr === "iget" && next === "iset" ||
                curr === "iset" && next === "iget" ||
                curr === "sget" && next === "sset" ||
                curr === "sset" && next === "sget") {
                privateNameMap[name] = "true";
                return false;
            }
            else if (!curr) {
                privateNameMap[name] = next;
                return false;
            }
            else {
                return true;
            }
        }
        function checkKeyName(node, name) {
            var computed = node.computed;
            var key = node.key;
            return !computed && (key.type === "Identifier" && key.name === name ||
                key.type === "Literal" && key.value === name);
        }
        // Parses module export declaration.
        pp$8.parseExport = function (node, exports) {
            this.next();
            // export * from '...'
            if (this.eat(types$1.star)) {
                if (this.options.ecmaVersion >= 11) {
                    if (this.eatContextual("as")) {
                        node.exported = this.parseModuleExportName();
                        this.checkExport(exports, node.exported, this.lastTokStart);
                    }
                    else {
                        node.exported = null;
                    }
                }
                this.expectContextual("from");
                if (this.type !== types$1.string) {
                    this.unexpected();
                }
                node.source = this.parseExprAtom();
                this.semicolon();
                return this.finishNode(node, "ExportAllDeclaration");
            }
            if (this.eat(types$1._default)) { // export default ...
                this.checkExport(exports, "default", this.lastTokStart);
                var isAsync;
                if (this.type === types$1._function || (isAsync = this.isAsyncFunction())) {
                    var fNode = this.startNode();
                    this.next();
                    if (isAsync) {
                        this.next();
                    }
                    node.declaration = this.parseFunction(fNode, FUNC_STATEMENT | FUNC_NULLABLE_ID, false, isAsync);
                }
                else if (this.type === types$1._class) {
                    var cNode = this.startNode();
                    node.declaration = this.parseClass(cNode, "nullableID");
                }
                else {
                    node.declaration = this.parseMaybeAssign();
                    this.semicolon();
                }
                return this.finishNode(node, "ExportDefaultDeclaration");
            }
            // export var|const|let|function|class ...
            if (this.shouldParseExportStatement()) {
                node.declaration = this.parseStatement(null);
                if (node.declaration.type === "VariableDeclaration") {
                    this.checkVariableExport(exports, node.declaration.declarations);
                }
                else {
                    this.checkExport(exports, node.declaration.id, node.declaration.id.start);
                }
                node.specifiers = [];
                node.source = null;
            }
            else { // export { x, y as z } [from '...']
                node.declaration = null;
                node.specifiers = this.parseExportSpecifiers(exports);
                if (this.eatContextual("from")) {
                    if (this.type !== types$1.string) {
                        this.unexpected();
                    }
                    node.source = this.parseExprAtom();
                }
                else {
                    for (var i = 0, list = node.specifiers; i < list.length; i += 1) {
                        // check for keywords used as local names
                        var spec = list[i];
                        this.checkUnreserved(spec.local);
                        // check if export is defined
                        this.checkLocalExport(spec.local);
                        if (spec.local.type === "Literal") {
                            this.raise(spec.local.start, "A string literal cannot be used as an exported binding without `from`.");
                        }
                    }
                    node.source = null;
                }
                this.semicolon();
            }
            return this.finishNode(node, "ExportNamedDeclaration");
        };
        pp$8.checkExport = function (exports, name, pos) {
            if (!exports) {
                return;
            }
            if (typeof name !== "string") {
                name = name.type === "Identifier" ? name.name : name.value;
            }
            if (hasOwn(exports, name)) {
                this.raiseRecoverable(pos, "Duplicate export '" + name + "'");
            }
            exports[name] = true;
        };
        pp$8.checkPatternExport = function (exports, pat) {
            var type = pat.type;
            if (type === "Identifier") {
                this.checkExport(exports, pat, pat.start);
            }
            else if (type === "ObjectPattern") {
                for (var i = 0, list = pat.properties; i < list.length; i += 1) {
                    var prop = list[i];
                    this.checkPatternExport(exports, prop);
                }
            }
            else if (type === "ArrayPattern") {
                for (var i$1 = 0, list$1 = pat.elements; i$1 < list$1.length; i$1 += 1) {
                    var elt = list$1[i$1];
                    if (elt) {
                        this.checkPatternExport(exports, elt);
                    }
                }
            }
            else if (type === "Property") {
                this.checkPatternExport(exports, pat.value);
            }
            else if (type === "AssignmentPattern") {
                this.checkPatternExport(exports, pat.left);
            }
            else if (type === "RestElement") {
                this.checkPatternExport(exports, pat.argument);
            }
            else if (type === "ParenthesizedExpression") {
                this.checkPatternExport(exports, pat.expression);
            }
        };
        pp$8.checkVariableExport = function (exports, decls) {
            if (!exports) {
                return;
            }
            for (var i = 0, list = decls; i < list.length; i += 1) {
                var decl = list[i];
                this.checkPatternExport(exports, decl.id);
            }
        };
        pp$8.shouldParseExportStatement = function () {
            return this.type.keyword === "var" ||
                this.type.keyword === "const" ||
                this.type.keyword === "class" ||
                this.type.keyword === "function" ||
                this.isLet() ||
                this.isAsyncFunction();
        };
        // Parses a comma-separated list of module exports.
        pp$8.parseExportSpecifiers = function (exports) {
            var nodes = [], first = true;
            // export { x, y as z } [from '...']
            this.expect(types$1.braceL);
            while (!this.eat(types$1.braceR)) {
                if (!first) {
                    this.expect(types$1.comma);
                    if (this.afterTrailingComma(types$1.braceR)) {
                        break;
                    }
                }
                else {
                    first = false;
                }
                var node = this.startNode();
                node.local = this.parseModuleExportName();
                node.exported = this.eatContextual("as") ? this.parseModuleExportName() : node.local;
                this.checkExport(exports, node.exported, node.exported.start);
                nodes.push(this.finishNode(node, "ExportSpecifier"));
            }
            return nodes;
        };
        // Parses import declaration.
        pp$8.parseImport = function (node) {
            this.next();
            // import '...'
            if (this.type === types$1.string) {
                node.specifiers = empty$1;
                node.source = this.parseExprAtom();
            }
            else {
                node.specifiers = this.parseImportSpecifiers();
                this.expectContextual("from");
                node.source = this.type === types$1.string ? this.parseExprAtom() : this.unexpected();
            }
            this.semicolon();
            return this.finishNode(node, "ImportDeclaration");
        };
        // Parses a comma-separated list of module imports.
        pp$8.parseImportSpecifiers = function () {
            var nodes = [], first = true;
            if (this.type === types$1.name) {
                // import defaultObj, { x, y as z } from '...'
                var node = this.startNode();
                node.local = this.parseIdent();
                this.checkLValSimple(node.local, BIND_LEXICAL);
                nodes.push(this.finishNode(node, "ImportDefaultSpecifier"));
                if (!this.eat(types$1.comma)) {
                    return nodes;
                }
            }
            if (this.type === types$1.star) {
                var node$1 = this.startNode();
                this.next();
                this.expectContextual("as");
                node$1.local = this.parseIdent();
                this.checkLValSimple(node$1.local, BIND_LEXICAL);
                nodes.push(this.finishNode(node$1, "ImportNamespaceSpecifier"));
                return nodes;
            }
            this.expect(types$1.braceL);
            while (!this.eat(types$1.braceR)) {
                if (!first) {
                    this.expect(types$1.comma);
                    if (this.afterTrailingComma(types$1.braceR)) {
                        break;
                    }
                }
                else {
                    first = false;
                }
                var node$2 = this.startNode();
                node$2.imported = this.parseModuleExportName();
                if (this.eatContextual("as")) {
                    node$2.local = this.parseIdent();
                }
                else {
                    this.checkUnreserved(node$2.imported);
                    node$2.local = node$2.imported;
                }
                this.checkLValSimple(node$2.local, BIND_LEXICAL);
                nodes.push(this.finishNode(node$2, "ImportSpecifier"));
            }
            return nodes;
        };
        pp$8.parseModuleExportName = function () {
            if (this.options.ecmaVersion >= 13 && this.type === types$1.string) {
                var stringLiteral = this.parseLiteral(this.value);
                if (loneSurrogate.test(stringLiteral.value)) {
                    this.raise(stringLiteral.start, "An export name cannot include a lone surrogate.");
                }
                return stringLiteral;
            }
            return this.parseIdent(true);
        };
        // Set `ExpressionStatement#directive` property for directive prologues.
        pp$8.adaptDirectivePrologue = function (statements) {
            for (var i = 0; i < statements.length && this.isDirectiveCandidate(statements[i]); ++i) {
                statements[i].directive = statements[i].expression.raw.slice(1, -1);
            }
        };
        pp$8.isDirectiveCandidate = function (statement) {
            return (this.options.ecmaVersion >= 5 &&
                statement.type === "ExpressionStatement" &&
                statement.expression.type === "Literal" &&
                typeof statement.expression.value === "string" &&
                // Reject parenthesized strings.
                (this.input[statement.start] === "\"" || this.input[statement.start] === "'"));
        };
        var pp$7 = Parser.prototype;
        // Convert existing expression atom to assignable pattern
        // if possible.
        pp$7.toAssignable = function (node, isBinding, refDestructuringErrors) {
            if (this.options.ecmaVersion >= 6 && node) {
                switch (node.type) {
                    case "Identifier":
                        if (this.inAsync && node.name === "await") {
                            this.raise(node.start, "Cannot use 'await' as identifier inside an async function");
                        }
                        break;
                    case "ObjectPattern":
                    case "ArrayPattern":
                    case "AssignmentPattern":
                    case "RestElement":
                        break;
                    case "ObjectExpression":
                        node.type = "ObjectPattern";
                        if (refDestructuringErrors) {
                            this.checkPatternErrors(refDestructuringErrors, true);
                        }
                        for (var i = 0, list = node.properties; i < list.length; i += 1) {
                            var prop = list[i];
                            this.toAssignable(prop, isBinding);
                            // Early error:
                            //   AssignmentRestProperty[Yield, Await] :
                            //     `...` DestructuringAssignmentTarget[Yield, Await]
                            //
                            //   It is a Syntax Error if |DestructuringAssignmentTarget| is an |ArrayLiteral| or an |ObjectLiteral|.
                            if (prop.type === "RestElement" &&
                                (prop.argument.type === "ArrayPattern" || prop.argument.type === "ObjectPattern")) {
                                this.raise(prop.argument.start, "Unexpected token");
                            }
                        }
                        break;
                    case "Property":
                        // AssignmentProperty has type === "Property"
                        if (node.kind !== "init") {
                            this.raise(node.key.start, "Object pattern can't contain getter or setter");
                        }
                        this.toAssignable(node.value, isBinding);
                        break;
                    case "ArrayExpression":
                        node.type = "ArrayPattern";
                        if (refDestructuringErrors) {
                            this.checkPatternErrors(refDestructuringErrors, true);
                        }
                        this.toAssignableList(node.elements, isBinding);
                        break;
                    case "SpreadElement":
                        node.type = "RestElement";
                        this.toAssignable(node.argument, isBinding);
                        if (node.argument.type === "AssignmentPattern") {
                            this.raise(node.argument.start, "Rest elements cannot have a default value");
                        }
                        break;
                    case "AssignmentExpression":
                        if (node.operator !== "=") {
                            this.raise(node.left.end, "Only '=' operator can be used for specifying default value.");
                        }
                        node.type = "AssignmentPattern";
                        delete node.operator;
                        this.toAssignable(node.left, isBinding);
                        break;
                    case "ParenthesizedExpression":
                        this.toAssignable(node.expression, isBinding, refDestructuringErrors);
                        break;
                    case "ChainExpression":
                        this.raiseRecoverable(node.start, "Optional chaining cannot appear in left-hand side");
                        break;
                    case "MemberExpression":
                        if (!isBinding) {
                            break;
                        }
                    default:
                        this.raise(node.start, "Assigning to rvalue");
                }
            }
            else if (refDestructuringErrors) {
                this.checkPatternErrors(refDestructuringErrors, true);
            }
            return node;
        };
        // Convert list of expression atoms to binding list.
        pp$7.toAssignableList = function (exprList, isBinding) {
            var end = exprList.length;
            for (var i = 0; i < end; i++) {
                var elt = exprList[i];
                if (elt) {
                    this.toAssignable(elt, isBinding);
                }
            }
            if (end) {
                var last = exprList[end - 1];
                if (this.options.ecmaVersion === 6 && isBinding && last && last.type === "RestElement" && last.argument.type !== "Identifier") {
                    this.unexpected(last.argument.start);
                }
            }
            return exprList;
        };
        // Parses spread element.
        pp$7.parseSpread = function (refDestructuringErrors) {
            var node = this.startNode();
            this.next();
            node.argument = this.parseMaybeAssign(false, refDestructuringErrors);
            return this.finishNode(node, "SpreadElement");
        };
        pp$7.parseRestBinding = function () {
            var node = this.startNode();
            this.next();
            // RestElement inside of a function parameter must be an identifier
            if (this.options.ecmaVersion === 6 && this.type !== types$1.name) {
                this.unexpected();
            }
            node.argument = this.parseBindingAtom();
            return this.finishNode(node, "RestElement");
        };
        // Parses lvalue (assignable) atom.
        pp$7.parseBindingAtom = function () {
            if (this.options.ecmaVersion >= 6) {
                switch (this.type) {
                    case types$1.bracketL:
                        var node = this.startNode();
                        this.next();
                        node.elements = this.parseBindingList(types$1.bracketR, true, true);
                        return this.finishNode(node, "ArrayPattern");
                    case types$1.braceL:
                        return this.parseObj(true);
                }
            }
            return this.parseIdent();
        };
        pp$7.parseBindingList = function (close, allowEmpty, allowTrailingComma) {
            var elts = [], first = true;
            while (!this.eat(close)) {
                if (first) {
                    first = false;
                }
                else {
                    this.expect(types$1.comma);
                }
                if (allowEmpty && this.type === types$1.comma) {
                    elts.push(null);
                }
                else if (allowTrailingComma && this.afterTrailingComma(close)) {
                    break;
                }
                else if (this.type === types$1.ellipsis) {
                    var rest = this.parseRestBinding();
                    this.parseBindingListItem(rest);
                    elts.push(rest);
                    if (this.type === types$1.comma) {
                        this.raise(this.start, "Comma is not permitted after the rest element");
                    }
                    this.expect(close);
                    break;
                }
                else {
                    var elem = this.parseMaybeDefault(this.start, this.startLoc);
                    this.parseBindingListItem(elem);
                    elts.push(elem);
                }
            }
            return elts;
        };
        pp$7.parseBindingListItem = function (param) {
            return param;
        };
        // Parses assignment pattern around given atom if possible.
        pp$7.parseMaybeDefault = function (startPos, startLoc, left) {
            left = left || this.parseBindingAtom();
            if (this.options.ecmaVersion < 6 || !this.eat(types$1.eq)) {
                return left;
            }
            var node = this.startNodeAt(startPos, startLoc);
            node.left = left;
            node.right = this.parseMaybeAssign();
            return this.finishNode(node, "AssignmentPattern");
        };
        // The following three functions all verify that a node is an lvalue —
        // something that can be bound, or assigned to. In order to do so, they perform
        // a variety of checks:
        //
        // - Check that none of the bound/assigned-to identifiers are reserved words.
        // - Record name declarations for bindings in the appropriate scope.
        // - Check duplicate argument names, if checkClashes is set.
        //
        // If a complex binding pattern is encountered (e.g., object and array
        // destructuring), the entire pattern is recursively checked.
        //
        // There are three versions of checkLVal*() appropriate for different
        // circumstances:
        //
        // - checkLValSimple() shall be used if the syntactic construct supports
        //   nothing other than identifiers and member expressions. Parenthesized
        //   expressions are also correctly handled. This is generally appropriate for
        //   constructs for which the spec says
        //
        //   > It is a Syntax Error if AssignmentTargetType of [the production] is not
        //   > simple.
        //
        //   It is also appropriate for checking if an identifier is valid and not
        //   defined elsewhere, like import declarations or function/class identifiers.
        //
        //   Examples where this is used include:
        //     a += …;
        //     import a from '…';
        //   where a is the node to be checked.
        //
        // - checkLValPattern() shall be used if the syntactic construct supports
        //   anything checkLValSimple() supports, as well as object and array
        //   destructuring patterns. This is generally appropriate for constructs for
        //   which the spec says
        //
        //   > It is a Syntax Error if [the production] is neither an ObjectLiteral nor
        //   > an ArrayLiteral and AssignmentTargetType of [the production] is not
        //   > simple.
        //
        //   Examples where this is used include:
        //     (a = …);
        //     const a = …;
        //     try { … } catch (a) { … }
        //   where a is the node to be checked.
        //
        // - checkLValInnerPattern() shall be used if the syntactic construct supports
        //   anything checkLValPattern() supports, as well as default assignment
        //   patterns, rest elements, and other constructs that may appear within an
        //   object or array destructuring pattern.
        //
        //   As a special case, function parameters also use checkLValInnerPattern(),
        //   as they also support defaults and rest constructs.
        //
        // These functions deliberately support both assignment and binding constructs,
        // as the logic for both is exceedingly similar. If the node is the target of
        // an assignment, then bindingType should be set to BIND_NONE. Otherwise, it
        // should be set to the appropriate BIND_* constant, like BIND_VAR or
        // BIND_LEXICAL.
        //
        // If the function is called with a non-BIND_NONE bindingType, then
        // additionally a checkClashes object may be specified to allow checking for
        // duplicate argument names. checkClashes is ignored if the provided construct
        // is an assignment (i.e., bindingType is BIND_NONE).
        pp$7.checkLValSimple = function (expr, bindingType, checkClashes) {
            if (bindingType === void 0)
                bindingType = BIND_NONE;
            var isBind = bindingType !== BIND_NONE;
            switch (expr.type) {
                case "Identifier":
                    if (this.strict && this.reservedWordsStrictBind.test(expr.name)) {
                        this.raiseRecoverable(expr.start, (isBind ? "Binding " : "Assigning to ") + expr.name + " in strict mode");
                    }
                    if (isBind) {
                        if (bindingType === BIND_LEXICAL && expr.name === "let") {
                            this.raiseRecoverable(expr.start, "let is disallowed as a lexically bound name");
                        }
                        if (checkClashes) {
                            if (hasOwn(checkClashes, expr.name)) {
                                this.raiseRecoverable(expr.start, "Argument name clash");
                            }
                            checkClashes[expr.name] = true;
                        }
                        if (bindingType !== BIND_OUTSIDE) {
                            this.declareName(expr.name, bindingType, expr.start);
                        }
                    }
                    break;
                case "ChainExpression":
                    this.raiseRecoverable(expr.start, "Optional chaining cannot appear in left-hand side");
                    break;
                case "MemberExpression":
                    if (isBind) {
                        this.raiseRecoverable(expr.start, "Binding member expression");
                    }
                    break;
                case "ParenthesizedExpression":
                    if (isBind) {
                        this.raiseRecoverable(expr.start, "Binding parenthesized expression");
                    }
                    return this.checkLValSimple(expr.expression, bindingType, checkClashes);
                default:
                    this.raise(expr.start, (isBind ? "Binding" : "Assigning to") + " rvalue");
            }
        };
        pp$7.checkLValPattern = function (expr, bindingType, checkClashes) {
            if (bindingType === void 0)
                bindingType = BIND_NONE;
            switch (expr.type) {
                case "ObjectPattern":
                    for (var i = 0, list = expr.properties; i < list.length; i += 1) {
                        var prop = list[i];
                        this.checkLValInnerPattern(prop, bindingType, checkClashes);
                    }
                    break;
                case "ArrayPattern":
                    for (var i$1 = 0, list$1 = expr.elements; i$1 < list$1.length; i$1 += 1) {
                        var elem = list$1[i$1];
                        if (elem) {
                            this.checkLValInnerPattern(elem, bindingType, checkClashes);
                        }
                    }
                    break;
                default:
                    this.checkLValSimple(expr, bindingType, checkClashes);
            }
        };
        pp$7.checkLValInnerPattern = function (expr, bindingType, checkClashes) {
            if (bindingType === void 0)
                bindingType = BIND_NONE;
            switch (expr.type) {
                case "Property":
                    // AssignmentProperty has type === "Property"
                    this.checkLValInnerPattern(expr.value, bindingType, checkClashes);
                    break;
                case "AssignmentPattern":
                    this.checkLValPattern(expr.left, bindingType, checkClashes);
                    break;
                case "RestElement":
                    this.checkLValPattern(expr.argument, bindingType, checkClashes);
                    break;
                default:
                    this.checkLValPattern(expr, bindingType, checkClashes);
            }
        };
        // The algorithm used to determine whether a regexp can appear at a
        var TokContext = function TokContext(token, isExpr, preserveSpace, override, generator) {
            this.token = token;
            this.isExpr = !!isExpr;
            this.preserveSpace = !!preserveSpace;
            this.override = override;
            this.generator = !!generator;
        };
        var types = {
            b_stat: new TokContext("{", false),
            b_expr: new TokContext("{", true),
            b_tmpl: new TokContext("${", false),
            p_stat: new TokContext("(", false),
            p_expr: new TokContext("(", true),
            q_tmpl: new TokContext("`", true, true, function (p) { return p.tryReadTemplateToken(); }),
            f_stat: new TokContext("function", false),
            f_expr: new TokContext("function", true),
            f_expr_gen: new TokContext("function", true, false, null, true),
            f_gen: new TokContext("function", false, false, null, true)
        };
        var pp$6 = Parser.prototype;
        pp$6.initialContext = function () {
            return [types.b_stat];
        };
        pp$6.curContext = function () {
            return this.context[this.context.length - 1];
        };
        pp$6.braceIsBlock = function (prevType) {
            var parent = this.curContext();
            if (parent === types.f_expr || parent === types.f_stat) {
                return true;
            }
            if (prevType === types$1.colon && (parent === types.b_stat || parent === types.b_expr)) {
                return !parent.isExpr;
            }
            // The check for `tt.name && exprAllowed` detects whether we are
            // after a `yield` or `of` construct. See the `updateContext` for
            // `tt.name`.
            if (prevType === types$1._return || prevType === types$1.name && this.exprAllowed) {
                return lineBreak.test(this.input.slice(this.lastTokEnd, this.start));
            }
            if (prevType === types$1._else || prevType === types$1.semi || prevType === types$1.eof || prevType === types$1.parenR || prevType === types$1.arrow) {
                return true;
            }
            if (prevType === types$1.braceL) {
                return parent === types.b_stat;
            }
            if (prevType === types$1._var || prevType === types$1._const || prevType === types$1.name) {
                return false;
            }
            return !this.exprAllowed;
        };
        pp$6.inGeneratorContext = function () {
            for (var i = this.context.length - 1; i >= 1; i--) {
                var context = this.context[i];
                if (context.token === "function") {
                    return context.generator;
                }
            }
            return false;
        };
        pp$6.updateContext = function (prevType) {
            var update, type = this.type;
            if (type.keyword && prevType === types$1.dot) {
                this.exprAllowed = false;
            }
            else if (update = type.updateContext) {
                update.call(this, prevType);
            }
            else {
                this.exprAllowed = type.beforeExpr;
            }
        };
        // Used to handle egde cases when token context could not be inferred correctly during tokenization phase
        pp$6.overrideContext = function (tokenCtx) {
            if (this.curContext() !== tokenCtx) {
                this.context[this.context.length - 1] = tokenCtx;
            }
        };
        // Token-specific context update code
        types$1.parenR.updateContext = types$1.braceR.updateContext = function () {
            if (this.context.length === 1) {
                this.exprAllowed = true;
                return;
            }
            var out = this.context.pop();
            if (out === types.b_stat && this.curContext().token === "function") {
                out = this.context.pop();
            }
            this.exprAllowed = !out.isExpr;
        };
        types$1.braceL.updateContext = function (prevType) {
            this.context.push(this.braceIsBlock(prevType) ? types.b_stat : types.b_expr);
            this.exprAllowed = true;
        };
        types$1.dollarBraceL.updateContext = function () {
            this.context.push(types.b_tmpl);
            this.exprAllowed = true;
        };
        types$1.parenL.updateContext = function (prevType) {
            var statementParens = prevType === types$1._if || prevType === types$1._for || prevType === types$1._with || prevType === types$1._while;
            this.context.push(statementParens ? types.p_stat : types.p_expr);
            this.exprAllowed = true;
        };
        types$1.incDec.updateContext = function () {
            // tokExprAllowed stays unchanged
        };
        types$1._function.updateContext = types$1._class.updateContext = function (prevType) {
            if (prevType.beforeExpr && prevType !== types$1._else &&
                !(prevType === types$1.semi && this.curContext() !== types.p_stat) &&
                !(prevType === types$1._return && lineBreak.test(this.input.slice(this.lastTokEnd, this.start))) &&
                !((prevType === types$1.colon || prevType === types$1.braceL) && this.curContext() === types.b_stat)) {
                this.context.push(types.f_expr);
            }
            else {
                this.context.push(types.f_stat);
            }
            this.exprAllowed = false;
        };
        types$1.backQuote.updateContext = function () {
            if (this.curContext() === types.q_tmpl) {
                this.context.pop();
            }
            else {
                this.context.push(types.q_tmpl);
            }
            this.exprAllowed = false;
        };
        types$1.star.updateContext = function (prevType) {
            if (prevType === types$1._function) {
                var index = this.context.length - 1;
                if (this.context[index] === types.f_expr) {
                    this.context[index] = types.f_expr_gen;
                }
                else {
                    this.context[index] = types.f_gen;
                }
            }
            this.exprAllowed = true;
        };
        types$1.name.updateContext = function (prevType) {
            var allowed = false;
            if (this.options.ecmaVersion >= 6 && prevType !== types$1.dot) {
                if (this.value === "of" && !this.exprAllowed ||
                    this.value === "yield" && this.inGeneratorContext()) {
                    allowed = true;
                }
            }
            this.exprAllowed = allowed;
        };
        // A recursive descent parser operates by defining functions for all
        var pp$5 = Parser.prototype;
        // Check if property name clashes with already added.
        // Object/class getters and setters are not allowed to clash —
        // either with each other or with an init property — and in
        // strict mode, init properties are also not allowed to be repeated.
        pp$5.checkPropClash = function (prop, propHash, refDestructuringErrors) {
            if (this.options.ecmaVersion >= 9 && prop.type === "SpreadElement") {
                return;
            }
            if (this.options.ecmaVersion >= 6 && (prop.computed || prop.method || prop.shorthand)) {
                return;
            }
            var key = prop.key;
            var name;
            switch (key.type) {
                case "Identifier":
                    name = key.name;
                    break;
                case "Literal":
                    name = String(key.value);
                    break;
                default: return;
            }
            var kind = prop.kind;
            if (this.options.ecmaVersion >= 6) {
                if (name === "__proto__" && kind === "init") {
                    if (propHash.proto) {
                        if (refDestructuringErrors) {
                            if (refDestructuringErrors.doubleProto < 0) {
                                refDestructuringErrors.doubleProto = key.start;
                            }
                        }
                        else {
                            this.raiseRecoverable(key.start, "Redefinition of __proto__ property");
                        }
                    }
                    propHash.proto = true;
                }
                return;
            }
            name = "$" + name;
            var other = propHash[name];
            if (other) {
                var redefinition;
                if (kind === "init") {
                    redefinition = this.strict && other.init || other.get || other.set;
                }
                else {
                    redefinition = other.init || other[kind];
                }
                if (redefinition) {
                    this.raiseRecoverable(key.start, "Redefinition of property");
                }
            }
            else {
                other = propHash[name] = {
                    init: false,
                    get: false,
                    set: false
                };
            }
            other[kind] = true;
        };
        // ### Expression parsing
        // These nest, from the most general expression type at the top to
        // 'atomic', nondivisible expression types at the bottom. Most of
        // the functions will simply let the function(s) below them parse,
        // and, *if* the syntactic construct they handle is present, wrap
        // the AST node that the inner parser gave them in another node.
        // Parse a full expression. The optional arguments are used to
        // forbid the `in` operator (in for loops initalization expressions)
        // and provide reference for storing '=' operator inside shorthand
        // property assignment in contexts where both object expression
        // and object pattern might appear (so it's possible to raise
        // delayed syntax error at correct position).
        pp$5.parseExpression = function (forInit, refDestructuringErrors) {
            var startPos = this.start, startLoc = this.startLoc;
            var expr = this.parseMaybeAssign(forInit, refDestructuringErrors);
            if (this.type === types$1.comma) {
                var node = this.startNodeAt(startPos, startLoc);
                node.expressions = [expr];
                while (this.eat(types$1.comma)) {
                    node.expressions.push(this.parseMaybeAssign(forInit, refDestructuringErrors));
                }
                return this.finishNode(node, "SequenceExpression");
            }
            return expr;
        };
        // Parse an assignment expression. This includes applications of
        // operators like `+=`.
        pp$5.parseMaybeAssign = function (forInit, refDestructuringErrors, afterLeftParse) {
            if (this.isContextual("yield")) {
                if (this.inGenerator) {
                    return this.parseYield(forInit);
                }
                // The tokenizer will assume an expression is allowed after
                // `yield`, but this isn't that kind of yield
                else {
                    this.exprAllowed = false;
                }
            }
            var ownDestructuringErrors = false, oldParenAssign = -1, oldTrailingComma = -1, oldDoubleProto = -1;
            if (refDestructuringErrors) {
                oldParenAssign = refDestructuringErrors.parenthesizedAssign;
                oldTrailingComma = refDestructuringErrors.trailingComma;
                oldDoubleProto = refDestructuringErrors.doubleProto;
                refDestructuringErrors.parenthesizedAssign = refDestructuringErrors.trailingComma = -1;
            }
            else {
                refDestructuringErrors = new DestructuringErrors;
                ownDestructuringErrors = true;
            }
            var startPos = this.start, startLoc = this.startLoc;
            if (this.type === types$1.parenL || this.type === types$1.name) {
                this.potentialArrowAt = this.start;
                this.potentialArrowInForAwait = forInit === "await";
            }
            var left = this.parseMaybeConditional(forInit, refDestructuringErrors);
            if (afterLeftParse) {
                left = afterLeftParse.call(this, left, startPos, startLoc);
            }
            if (this.type.isAssign) {
                var node = this.startNodeAt(startPos, startLoc);
                node.operator = this.value;
                if (this.type === types$1.eq) {
                    left = this.toAssignable(left, false, refDestructuringErrors);
                }
                if (!ownDestructuringErrors) {
                    refDestructuringErrors.parenthesizedAssign = refDestructuringErrors.trailingComma = refDestructuringErrors.doubleProto = -1;
                }
                if (refDestructuringErrors.shorthandAssign >= left.start) {
                    refDestructuringErrors.shorthandAssign = -1;
                } // reset because shorthand default was used correctly
                if (this.type === types$1.eq) {
                    this.checkLValPattern(left);
                }
                else {
                    this.checkLValSimple(left);
                }
                node.left = left;
                this.next();
                node.right = this.parseMaybeAssign(forInit);
                if (oldDoubleProto > -1) {
                    refDestructuringErrors.doubleProto = oldDoubleProto;
                }
                return this.finishNode(node, "AssignmentExpression");
            }
            else {
                if (ownDestructuringErrors) {
                    this.checkExpressionErrors(refDestructuringErrors, true);
                }
            }
            if (oldParenAssign > -1) {
                refDestructuringErrors.parenthesizedAssign = oldParenAssign;
            }
            if (oldTrailingComma > -1) {
                refDestructuringErrors.trailingComma = oldTrailingComma;
            }
            return left;
        };
        // Parse a ternary conditional (`?:`) operator.
        pp$5.parseMaybeConditional = function (forInit, refDestructuringErrors) {
            var startPos = this.start, startLoc = this.startLoc;
            var expr = this.parseExprOps(forInit, refDestructuringErrors);
            if (this.checkExpressionErrors(refDestructuringErrors)) {
                return expr;
            }
            if (this.eat(types$1.question)) {
                var node = this.startNodeAt(startPos, startLoc);
                node.test = expr;
                node.consequent = this.parseMaybeAssign();
                this.expect(types$1.colon);
                node.alternate = this.parseMaybeAssign(forInit);
                return this.finishNode(node, "ConditionalExpression");
            }
            return expr;
        };
        // Start the precedence parser.
        pp$5.parseExprOps = function (forInit, refDestructuringErrors) {
            var startPos = this.start, startLoc = this.startLoc;
            var expr = this.parseMaybeUnary(refDestructuringErrors, false, false, forInit);
            if (this.checkExpressionErrors(refDestructuringErrors)) {
                return expr;
            }
            return expr.start === startPos && expr.type === "ArrowFunctionExpression" ? expr : this.parseExprOp(expr, startPos, startLoc, -1, forInit);
        };
        // Parse binary operators with the operator precedence parsing
        // algorithm. `left` is the left-hand side of the operator.
        // `minPrec` provides context that allows the function to stop and
        // defer further parser to one of its callers when it encounters an
        // operator that has a lower precedence than the set it is parsing.
        pp$5.parseExprOp = function (left, leftStartPos, leftStartLoc, minPrec, forInit) {
            var prec = this.type.binop;
            if (prec != null && (!forInit || this.type !== types$1._in)) {
                if (prec > minPrec) {
                    var logical = this.type === types$1.logicalOR || this.type === types$1.logicalAND;
                    var coalesce = this.type === types$1.coalesce;
                    if (coalesce) {
                        // Handle the precedence of `tt.coalesce` as equal to the range of logical expressions.
                        // In other words, `node.right` shouldn't contain logical expressions in order to check the mixed error.
                        prec = types$1.logicalAND.binop;
                    }
                    var op = this.value;
                    this.next();
                    var startPos = this.start, startLoc = this.startLoc;
                    var right = this.parseExprOp(this.parseMaybeUnary(null, false, false, forInit), startPos, startLoc, prec, forInit);
                    var node = this.buildBinary(leftStartPos, leftStartLoc, left, right, op, logical || coalesce);
                    if ((logical && this.type === types$1.coalesce) || (coalesce && (this.type === types$1.logicalOR || this.type === types$1.logicalAND))) {
                        this.raiseRecoverable(this.start, "Logical expressions and coalesce expressions cannot be mixed. Wrap either by parentheses");
                    }
                    return this.parseExprOp(node, leftStartPos, leftStartLoc, minPrec, forInit);
                }
            }
            return left;
        };
        pp$5.buildBinary = function (startPos, startLoc, left, right, op, logical) {
            if (right.type === "PrivateIdentifier") {
                this.raise(right.start, "Private identifier can only be left side of binary expression");
            }
            var node = this.startNodeAt(startPos, startLoc);
            node.left = left;
            node.operator = op;
            node.right = right;
            return this.finishNode(node, logical ? "LogicalExpression" : "BinaryExpression");
        };
        // Parse unary operators, both prefix and postfix.
        pp$5.parseMaybeUnary = function (refDestructuringErrors, sawUnary, incDec, forInit) {
            var startPos = this.start, startLoc = this.startLoc, expr;
            if (this.isContextual("await") && this.canAwait) {
                expr = this.parseAwait(forInit);
                sawUnary = true;
            }
            else if (this.type.prefix) {
                var node = this.startNode(), update = this.type === types$1.incDec;
                node.operator = this.value;
                node.prefix = true;
                this.next();
                node.argument = this.parseMaybeUnary(null, true, update, forInit);
                this.checkExpressionErrors(refDestructuringErrors, true);
                if (update) {
                    this.checkLValSimple(node.argument);
                }
                else if (this.strict && node.operator === "delete" &&
                    node.argument.type === "Identifier") {
                    this.raiseRecoverable(node.start, "Deleting local variable in strict mode");
                }
                else if (node.operator === "delete" && isPrivateFieldAccess(node.argument)) {
                    this.raiseRecoverable(node.start, "Private fields can not be deleted");
                }
                else {
                    sawUnary = true;
                }
                expr = this.finishNode(node, update ? "UpdateExpression" : "UnaryExpression");
            }
            else if (!sawUnary && this.type === types$1.privateId) {
                if (forInit || this.privateNameStack.length === 0) {
                    this.unexpected();
                }
                expr = this.parsePrivateIdent();
                // only could be private fields in 'in', such as #x in obj
                if (this.type !== types$1._in) {
                    this.unexpected();
                }
            }
            else {
                expr = this.parseExprSubscripts(refDestructuringErrors, forInit);
                if (this.checkExpressionErrors(refDestructuringErrors)) {
                    return expr;
                }
                while (this.type.postfix && !this.canInsertSemicolon()) {
                    var node$1 = this.startNodeAt(startPos, startLoc);
                    node$1.operator = this.value;
                    node$1.prefix = false;
                    node$1.argument = expr;
                    this.checkLValSimple(expr);
                    this.next();
                    expr = this.finishNode(node$1, "UpdateExpression");
                }
            }
            if (!incDec && this.eat(types$1.starstar)) {
                if (sawUnary) {
                    this.unexpected(this.lastTokStart);
                }
                else {
                    return this.buildBinary(startPos, startLoc, expr, this.parseMaybeUnary(null, false, false, forInit), "**", false);
                }
            }
            else {
                return expr;
            }
        };
        function isPrivateFieldAccess(node) {
            return (node.type === "MemberExpression" && node.property.type === "PrivateIdentifier" ||
                node.type === "ChainExpression" && isPrivateFieldAccess(node.expression));
        }
        // Parse call, dot, and `[]`-subscript expressions.
        pp$5.parseExprSubscripts = function (refDestructuringErrors, forInit) {
            var startPos = this.start, startLoc = this.startLoc;
            var expr = this.parseExprAtom(refDestructuringErrors, forInit);
            if (expr.type === "ArrowFunctionExpression" && this.input.slice(this.lastTokStart, this.lastTokEnd) !== ")") {
                return expr;
            }
            var result = this.parseSubscripts(expr, startPos, startLoc, false, forInit);
            if (refDestructuringErrors && result.type === "MemberExpression") {
                if (refDestructuringErrors.parenthesizedAssign >= result.start) {
                    refDestructuringErrors.parenthesizedAssign = -1;
                }
                if (refDestructuringErrors.parenthesizedBind >= result.start) {
                    refDestructuringErrors.parenthesizedBind = -1;
                }
                if (refDestructuringErrors.trailingComma >= result.start) {
                    refDestructuringErrors.trailingComma = -1;
                }
            }
            return result;
        };
        pp$5.parseSubscripts = function (base, startPos, startLoc, noCalls, forInit) {
            var maybeAsyncArrow = this.options.ecmaVersion >= 8 && base.type === "Identifier" && base.name === "async" &&
                this.lastTokEnd === base.end && !this.canInsertSemicolon() && base.end - base.start === 5 &&
                this.potentialArrowAt === base.start;
            var optionalChained = false;
            while (true) {
                var element = this.parseSubscript(base, startPos, startLoc, noCalls, maybeAsyncArrow, optionalChained, forInit);
                if (element.optional) {
                    optionalChained = true;
                }
                if (element === base || element.type === "ArrowFunctionExpression") {
                    if (optionalChained) {
                        var chainNode = this.startNodeAt(startPos, startLoc);
                        chainNode.expression = element;
                        element = this.finishNode(chainNode, "ChainExpression");
                    }
                    return element;
                }
                base = element;
            }
        };
        pp$5.parseSubscript = function (base, startPos, startLoc, noCalls, maybeAsyncArrow, optionalChained, forInit) {
            var optionalSupported = this.options.ecmaVersion >= 11;
            var optional = optionalSupported && this.eat(types$1.questionDot);
            if (noCalls && optional) {
                this.raise(this.lastTokStart, "Optional chaining cannot appear in the callee of new expressions");
            }
            var computed = this.eat(types$1.bracketL);
            if (computed || (optional && this.type !== types$1.parenL && this.type !== types$1.backQuote) || this.eat(types$1.dot)) {
                var node = this.startNodeAt(startPos, startLoc);
                node.object = base;
                if (computed) {
                    node.property = this.parseExpression();
                    this.expect(types$1.bracketR);
                }
                else if (this.type === types$1.privateId && base.type !== "Super") {
                    node.property = this.parsePrivateIdent();
                }
                else {
                    node.property = this.parseIdent(this.options.allowReserved !== "never");
                }
                node.computed = !!computed;
                if (optionalSupported) {
                    node.optional = optional;
                }
                base = this.finishNode(node, "MemberExpression");
            }
            else if (!noCalls && this.eat(types$1.parenL)) {
                var refDestructuringErrors = new DestructuringErrors, oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;
                this.yieldPos = 0;
                this.awaitPos = 0;
                this.awaitIdentPos = 0;
                var exprList = this.parseExprList(types$1.parenR, this.options.ecmaVersion >= 8, false, refDestructuringErrors);
                if (maybeAsyncArrow && !optional && !this.canInsertSemicolon() && this.eat(types$1.arrow)) {
                    this.checkPatternErrors(refDestructuringErrors, false);
                    this.checkYieldAwaitInDefaultParams();
                    if (this.awaitIdentPos > 0) {
                        this.raise(this.awaitIdentPos, "Cannot use 'await' as identifier inside an async function");
                    }
                    this.yieldPos = oldYieldPos;
                    this.awaitPos = oldAwaitPos;
                    this.awaitIdentPos = oldAwaitIdentPos;
                    return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), exprList, true, forInit);
                }
                this.checkExpressionErrors(refDestructuringErrors, true);
                this.yieldPos = oldYieldPos || this.yieldPos;
                this.awaitPos = oldAwaitPos || this.awaitPos;
                this.awaitIdentPos = oldAwaitIdentPos || this.awaitIdentPos;
                var node$1 = this.startNodeAt(startPos, startLoc);
                node$1.callee = base;
                node$1.arguments = exprList;
                if (optionalSupported) {
                    node$1.optional = optional;
                }
                base = this.finishNode(node$1, "CallExpression");
            }
            else if (this.type === types$1.backQuote) {
                if (optional || optionalChained) {
                    this.raise(this.start, "Optional chaining cannot appear in the tag of tagged template expressions");
                }
                var node$2 = this.startNodeAt(startPos, startLoc);
                node$2.tag = base;
                node$2.quasi = this.parseTemplate({ isTagged: true });
                base = this.finishNode(node$2, "TaggedTemplateExpression");
            }
            return base;
        };
        // Parse an atomic expression — either a single token that is an
        // expression, an expression started by a keyword like `function` or
        // `new`, or an expression wrapped in punctuation like `()`, `[]`,
        // or `{}`.
        pp$5.parseExprAtom = function (refDestructuringErrors, forInit) {
            // If a division operator appears in an expression position, the
            // tokenizer got confused, and we force it to read a regexp instead.
            if (this.type === types$1.slash) {
                this.readRegexp();
            }
            var node, canBeArrow = this.potentialArrowAt === this.start;
            switch (this.type) {
                case types$1._super:
                    if (!this.allowSuper) {
                        this.raise(this.start, "'super' keyword outside a method");
                    }
                    node = this.startNode();
                    this.next();
                    if (this.type === types$1.parenL && !this.allowDirectSuper) {
                        this.raise(node.start, "super() call outside constructor of a subclass");
                    }
                    // The `super` keyword can appear at below:
                    // SuperProperty:
                    //     super [ Expression ]
                    //     super . IdentifierName
                    // SuperCall:
                    //     super ( Arguments )
                    if (this.type !== types$1.dot && this.type !== types$1.bracketL && this.type !== types$1.parenL) {
                        this.unexpected();
                    }
                    return this.finishNode(node, "Super");
                case types$1._this:
                    node = this.startNode();
                    this.next();
                    return this.finishNode(node, "ThisExpression");
                case types$1.name:
                    var startPos = this.start, startLoc = this.startLoc, containsEsc = this.containsEsc;
                    var id = this.parseIdent(false);
                    if (this.options.ecmaVersion >= 8 && !containsEsc && id.name === "async" && !this.canInsertSemicolon() && this.eat(types$1._function)) {
                        this.overrideContext(types.f_expr);
                        return this.parseFunction(this.startNodeAt(startPos, startLoc), 0, false, true, forInit);
                    }
                    if (canBeArrow && !this.canInsertSemicolon()) {
                        if (this.eat(types$1.arrow)) {
                            return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), [id], false, forInit);
                        }
                        if (this.options.ecmaVersion >= 8 && id.name === "async" && this.type === types$1.name && !containsEsc &&
                            (!this.potentialArrowInForAwait || this.value !== "of" || this.containsEsc)) {
                            id = this.parseIdent(false);
                            if (this.canInsertSemicolon() || !this.eat(types$1.arrow)) {
                                this.unexpected();
                            }
                            return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), [id], true, forInit);
                        }
                    }
                    return id;
                case types$1.regexp:
                    var value = this.value;
                    node = this.parseLiteral(value.value);
                    node.regex = { pattern: value.pattern, flags: value.flags };
                    return node;
                case types$1.num:
                case types$1.string:
                    return this.parseLiteral(this.value);
                case types$1._null:
                case types$1._true:
                case types$1._false:
                    node = this.startNode();
                    node.value = this.type === types$1._null ? null : this.type === types$1._true;
                    node.raw = this.type.keyword;
                    this.next();
                    return this.finishNode(node, "Literal");
                case types$1.parenL:
                    var start = this.start, expr = this.parseParenAndDistinguishExpression(canBeArrow, forInit);
                    if (refDestructuringErrors) {
                        if (refDestructuringErrors.parenthesizedAssign < 0 && !this.isSimpleAssignTarget(expr)) {
                            refDestructuringErrors.parenthesizedAssign = start;
                        }
                        if (refDestructuringErrors.parenthesizedBind < 0) {
                            refDestructuringErrors.parenthesizedBind = start;
                        }
                    }
                    return expr;
                case types$1.bracketL:
                    node = this.startNode();
                    this.next();
                    node.elements = this.parseExprList(types$1.bracketR, true, true, refDestructuringErrors);
                    return this.finishNode(node, "ArrayExpression");
                case types$1.braceL:
                    this.overrideContext(types.b_expr);
                    return this.parseObj(false, refDestructuringErrors);
                case types$1._function:
                    node = this.startNode();
                    this.next();
                    return this.parseFunction(node, 0);
                case types$1._class:
                    return this.parseClass(this.startNode(), false);
                case types$1._new:
                    return this.parseNew();
                case types$1.backQuote:
                    return this.parseTemplate();
                case types$1._import:
                    if (this.options.ecmaVersion >= 11) {
                        return this.parseExprImport();
                    }
                    else {
                        return this.unexpected();
                    }
                default:
                    this.unexpected();
            }
        };
        pp$5.parseExprImport = function () {
            var node = this.startNode();
            // Consume `import` as an identifier for `import.meta`.
            // Because `this.parseIdent(true)` doesn't check escape sequences, it needs the check of `this.containsEsc`.
            if (this.containsEsc) {
                this.raiseRecoverable(this.start, "Escape sequence in keyword import");
            }
            var meta = this.parseIdent(true);
            switch (this.type) {
                case types$1.parenL:
                    return this.parseDynamicImport(node);
                case types$1.dot:
                    node.meta = meta;
                    return this.parseImportMeta(node);
                default:
                    this.unexpected();
            }
        };
        pp$5.parseDynamicImport = function (node) {
            this.next(); // skip `(`
            // Parse node.source.
            node.source = this.parseMaybeAssign();
            // Verify ending.
            if (!this.eat(types$1.parenR)) {
                var errorPos = this.start;
                if (this.eat(types$1.comma) && this.eat(types$1.parenR)) {
                    this.raiseRecoverable(errorPos, "Trailing comma is not allowed in import()");
                }
                else {
                    this.unexpected(errorPos);
                }
            }
            return this.finishNode(node, "ImportExpression");
        };
        pp$5.parseImportMeta = function (node) {
            this.next(); // skip `.`
            var containsEsc = this.containsEsc;
            node.property = this.parseIdent(true);
            if (node.property.name !== "meta") {
                this.raiseRecoverable(node.property.start, "The only valid meta property for import is 'import.meta'");
            }
            if (containsEsc) {
                this.raiseRecoverable(node.start, "'import.meta' must not contain escaped characters");
            }
            if (this.options.sourceType !== "module" && !this.options.allowImportExportEverywhere) {
                this.raiseRecoverable(node.start, "Cannot use 'import.meta' outside a module");
            }
            return this.finishNode(node, "MetaProperty");
        };
        pp$5.parseLiteral = function (value) {
            var node = this.startNode();
            node.value = value;
            node.raw = this.input.slice(this.start, this.end);
            if (node.raw.charCodeAt(node.raw.length - 1) === 110) {
                node.bigint = node.raw.slice(0, -1).replace(/_/g, "");
            }
            this.next();
            return this.finishNode(node, "Literal");
        };
        pp$5.parseParenExpression = function () {
            this.expect(types$1.parenL);
            var val = this.parseExpression();
            this.expect(types$1.parenR);
            return val;
        };
        pp$5.parseParenAndDistinguishExpression = function (canBeArrow, forInit) {
            var startPos = this.start, startLoc = this.startLoc, val, allowTrailingComma = this.options.ecmaVersion >= 8;
            if (this.options.ecmaVersion >= 6) {
                this.next();
                var innerStartPos = this.start, innerStartLoc = this.startLoc;
                var exprList = [], first = true, lastIsComma = false;
                var refDestructuringErrors = new DestructuringErrors, oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, spreadStart;
                this.yieldPos = 0;
                this.awaitPos = 0;
                // Do not save awaitIdentPos to allow checking awaits nested in parameters
                while (this.type !== types$1.parenR) {
                    first ? first = false : this.expect(types$1.comma);
                    if (allowTrailingComma && this.afterTrailingComma(types$1.parenR, true)) {
                        lastIsComma = true;
                        break;
                    }
                    else if (this.type === types$1.ellipsis) {
                        spreadStart = this.start;
                        exprList.push(this.parseParenItem(this.parseRestBinding()));
                        if (this.type === types$1.comma) {
                            this.raise(this.start, "Comma is not permitted after the rest element");
                        }
                        break;
                    }
                    else {
                        exprList.push(this.parseMaybeAssign(false, refDestructuringErrors, this.parseParenItem));
                    }
                }
                var innerEndPos = this.lastTokEnd, innerEndLoc = this.lastTokEndLoc;
                this.expect(types$1.parenR);
                if (canBeArrow && !this.canInsertSemicolon() && this.eat(types$1.arrow)) {
                    this.checkPatternErrors(refDestructuringErrors, false);
                    this.checkYieldAwaitInDefaultParams();
                    this.yieldPos = oldYieldPos;
                    this.awaitPos = oldAwaitPos;
                    return this.parseParenArrowList(startPos, startLoc, exprList, forInit);
                }
                if (!exprList.length || lastIsComma) {
                    this.unexpected(this.lastTokStart);
                }
                if (spreadStart) {
                    this.unexpected(spreadStart);
                }
                this.checkExpressionErrors(refDestructuringErrors, true);
                this.yieldPos = oldYieldPos || this.yieldPos;
                this.awaitPos = oldAwaitPos || this.awaitPos;
                if (exprList.length > 1) {
                    val = this.startNodeAt(innerStartPos, innerStartLoc);
                    val.expressions = exprList;
                    this.finishNodeAt(val, "SequenceExpression", innerEndPos, innerEndLoc);
                }
                else {
                    val = exprList[0];
                }
            }
            else {
                val = this.parseParenExpression();
            }
            if (this.options.preserveParens) {
                var par = this.startNodeAt(startPos, startLoc);
                par.expression = val;
                return this.finishNode(par, "ParenthesizedExpression");
            }
            else {
                return val;
            }
        };
        pp$5.parseParenItem = function (item) {
            return item;
        };
        pp$5.parseParenArrowList = function (startPos, startLoc, exprList, forInit) {
            return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), exprList, false, forInit);
        };
        // New's precedence is slightly tricky. It must allow its argument to
        // be a `[]` or dot subscript expression, but not a call — at least,
        // not without wrapping it in parentheses. Thus, it uses the noCalls
        // argument to parseSubscripts to prevent it from consuming the
        // argument list.
        var empty = [];
        pp$5.parseNew = function () {
            if (this.containsEsc) {
                this.raiseRecoverable(this.start, "Escape sequence in keyword new");
            }
            var node = this.startNode();
            var meta = this.parseIdent(true);
            if (this.options.ecmaVersion >= 6 && this.eat(types$1.dot)) {
                node.meta = meta;
                var containsEsc = this.containsEsc;
                node.property = this.parseIdent(true);
                if (node.property.name !== "target") {
                    this.raiseRecoverable(node.property.start, "The only valid meta property for new is 'new.target'");
                }
                if (containsEsc) {
                    this.raiseRecoverable(node.start, "'new.target' must not contain escaped characters");
                }
                if (!this.allowNewDotTarget) {
                    this.raiseRecoverable(node.start, "'new.target' can only be used in functions and class static block");
                }
                return this.finishNode(node, "MetaProperty");
            }
            var startPos = this.start, startLoc = this.startLoc, isImport = this.type === types$1._import;
            node.callee = this.parseSubscripts(this.parseExprAtom(), startPos, startLoc, true, false);
            if (isImport && node.callee.type === "ImportExpression") {
                this.raise(startPos, "Cannot use new with import()");
            }
            if (this.eat(types$1.parenL)) {
                node.arguments = this.parseExprList(types$1.parenR, this.options.ecmaVersion >= 8, false);
            }
            else {
                node.arguments = empty;
            }
            return this.finishNode(node, "NewExpression");
        };
        // Parse template expression.
        pp$5.parseTemplateElement = function (ref) {
            var isTagged = ref.isTagged;
            var elem = this.startNode();
            if (this.type === types$1.invalidTemplate) {
                if (!isTagged) {
                    this.raiseRecoverable(this.start, "Bad escape sequence in untagged template literal");
                }
                elem.value = {
                    raw: this.value,
                    cooked: null
                };
            }
            else {
                elem.value = {
                    raw: this.input.slice(this.start, this.end).replace(/\r\n?/g, "\n"),
                    cooked: this.value
                };
            }
            this.next();
            elem.tail = this.type === types$1.backQuote;
            return this.finishNode(elem, "TemplateElement");
        };
        pp$5.parseTemplate = function (ref) {
            if (ref === void 0)
                ref = {};
            var isTagged = ref.isTagged;
            if (isTagged === void 0)
                isTagged = false;
            var node = this.startNode();
            this.next();
            node.expressions = [];
            var curElt = this.parseTemplateElement({ isTagged: isTagged });
            node.quasis = [curElt];
            while (!curElt.tail) {
                if (this.type === types$1.eof) {
                    this.raise(this.pos, "Unterminated template literal");
                }
                this.expect(types$1.dollarBraceL);
                node.expressions.push(this.parseExpression());
                this.expect(types$1.braceR);
                node.quasis.push(curElt = this.parseTemplateElement({ isTagged: isTagged }));
            }
            this.next();
            return this.finishNode(node, "TemplateLiteral");
        };
        pp$5.isAsyncProp = function (prop) {
            return !prop.computed && prop.key.type === "Identifier" && prop.key.name === "async" &&
                (this.type === types$1.name || this.type === types$1.num || this.type === types$1.string || this.type === types$1.bracketL || this.type.keyword || (this.options.ecmaVersion >= 9 && this.type === types$1.star)) &&
                !lineBreak.test(this.input.slice(this.lastTokEnd, this.start));
        };
        // Parse an object literal or binding pattern.
        pp$5.parseObj = function (isPattern, refDestructuringErrors) {
            var node = this.startNode(), first = true, propHash = {};
            node.properties = [];
            this.next();
            while (!this.eat(types$1.braceR)) {
                if (!first) {
                    this.expect(types$1.comma);
                    if (this.options.ecmaVersion >= 5 && this.afterTrailingComma(types$1.braceR)) {
                        break;
                    }
                }
                else {
                    first = false;
                }
                var prop = this.parseProperty(isPattern, refDestructuringErrors);
                if (!isPattern) {
                    this.checkPropClash(prop, propHash, refDestructuringErrors);
                }
                node.properties.push(prop);
            }
            return this.finishNode(node, isPattern ? "ObjectPattern" : "ObjectExpression");
        };
        pp$5.parseProperty = function (isPattern, refDestructuringErrors) {
            var prop = this.startNode(), isGenerator, isAsync, startPos, startLoc;
            if (this.options.ecmaVersion >= 9 && this.eat(types$1.ellipsis)) {
                if (isPattern) {
                    prop.argument = this.parseIdent(false);
                    if (this.type === types$1.comma) {
                        this.raise(this.start, "Comma is not permitted after the rest element");
                    }
                    return this.finishNode(prop, "RestElement");
                }
                // Parse argument.
                prop.argument = this.parseMaybeAssign(false, refDestructuringErrors);
                // To disallow trailing comma via `this.toAssignable()`.
                if (this.type === types$1.comma && refDestructuringErrors && refDestructuringErrors.trailingComma < 0) {
                    refDestructuringErrors.trailingComma = this.start;
                }
                // Finish
                return this.finishNode(prop, "SpreadElement");
            }
            if (this.options.ecmaVersion >= 6) {
                prop.method = false;
                prop.shorthand = false;
                if (isPattern || refDestructuringErrors) {
                    startPos = this.start;
                    startLoc = this.startLoc;
                }
                if (!isPattern) {
                    isGenerator = this.eat(types$1.star);
                }
            }
            var containsEsc = this.containsEsc;
            this.parsePropertyName(prop);
            if (!isPattern && !containsEsc && this.options.ecmaVersion >= 8 && !isGenerator && this.isAsyncProp(prop)) {
                isAsync = true;
                isGenerator = this.options.ecmaVersion >= 9 && this.eat(types$1.star);
                this.parsePropertyName(prop);
            }
            else {
                isAsync = false;
            }
            this.parsePropertyValue(prop, isPattern, isGenerator, isAsync, startPos, startLoc, refDestructuringErrors, containsEsc);
            return this.finishNode(prop, "Property");
        };
        pp$5.parsePropertyValue = function (prop, isPattern, isGenerator, isAsync, startPos, startLoc, refDestructuringErrors, containsEsc) {
            if ((isGenerator || isAsync) && this.type === types$1.colon) {
                this.unexpected();
            }
            if (this.eat(types$1.colon)) {
                prop.value = isPattern ? this.parseMaybeDefault(this.start, this.startLoc) : this.parseMaybeAssign(false, refDestructuringErrors);
                prop.kind = "init";
            }
            else if (this.options.ecmaVersion >= 6 && this.type === types$1.parenL) {
                if (isPattern) {
                    this.unexpected();
                }
                prop.kind = "init";
                prop.method = true;
                prop.value = this.parseMethod(isGenerator, isAsync);
            }
            else if (!isPattern && !containsEsc &&
                this.options.ecmaVersion >= 5 && !prop.computed && prop.key.type === "Identifier" &&
                (prop.key.name === "get" || prop.key.name === "set") &&
                (this.type !== types$1.comma && this.type !== types$1.braceR && this.type !== types$1.eq)) {
                if (isGenerator || isAsync) {
                    this.unexpected();
                }
                prop.kind = prop.key.name;
                this.parsePropertyName(prop);
                prop.value = this.parseMethod(false);
                var paramCount = prop.kind === "get" ? 0 : 1;
                if (prop.value.params.length !== paramCount) {
                    var start = prop.value.start;
                    if (prop.kind === "get") {
                        this.raiseRecoverable(start, "getter should have no params");
                    }
                    else {
                        this.raiseRecoverable(start, "setter should have exactly one param");
                    }
                }
                else {
                    if (prop.kind === "set" && prop.value.params[0].type === "RestElement") {
                        this.raiseRecoverable(prop.value.params[0].start, "Setter cannot use rest params");
                    }
                }
            }
            else if (this.options.ecmaVersion >= 6 && !prop.computed && prop.key.type === "Identifier") {
                if (isGenerator || isAsync) {
                    this.unexpected();
                }
                this.checkUnreserved(prop.key);
                if (prop.key.name === "await" && !this.awaitIdentPos) {
                    this.awaitIdentPos = startPos;
                }
                prop.kind = "init";
                if (isPattern) {
                    prop.value = this.parseMaybeDefault(startPos, startLoc, this.copyNode(prop.key));
                }
                else if (this.type === types$1.eq && refDestructuringErrors) {
                    if (refDestructuringErrors.shorthandAssign < 0) {
                        refDestructuringErrors.shorthandAssign = this.start;
                    }
                    prop.value = this.parseMaybeDefault(startPos, startLoc, this.copyNode(prop.key));
                }
                else {
                    prop.value = this.copyNode(prop.key);
                }
                prop.shorthand = true;
            }
            else {
                this.unexpected();
            }
        };
        pp$5.parsePropertyName = function (prop) {
            if (this.options.ecmaVersion >= 6) {
                if (this.eat(types$1.bracketL)) {
                    prop.computed = true;
                    prop.key = this.parseMaybeAssign();
                    this.expect(types$1.bracketR);
                    return prop.key;
                }
                else {
                    prop.computed = false;
                }
            }
            return prop.key = this.type === types$1.num || this.type === types$1.string ? this.parseExprAtom() : this.parseIdent(this.options.allowReserved !== "never");
        };
        // Initialize empty function node.
        pp$5.initFunction = function (node) {
            node.id = null;
            if (this.options.ecmaVersion >= 6) {
                node.generator = node.expression = false;
            }
            if (this.options.ecmaVersion >= 8) {
                node.async = false;
            }
        };
        // Parse object or class method.
        pp$5.parseMethod = function (isGenerator, isAsync, allowDirectSuper) {
            var node = this.startNode(), oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;
            this.initFunction(node);
            if (this.options.ecmaVersion >= 6) {
                node.generator = isGenerator;
            }
            if (this.options.ecmaVersion >= 8) {
                node.async = !!isAsync;
            }
            this.yieldPos = 0;
            this.awaitPos = 0;
            this.awaitIdentPos = 0;
            this.enterScope(functionFlags(isAsync, node.generator) | SCOPE_SUPER | (allowDirectSuper ? SCOPE_DIRECT_SUPER : 0));
            this.expect(types$1.parenL);
            node.params = this.parseBindingList(types$1.parenR, false, this.options.ecmaVersion >= 8);
            this.checkYieldAwaitInDefaultParams();
            this.parseFunctionBody(node, false, true, false);
            this.yieldPos = oldYieldPos;
            this.awaitPos = oldAwaitPos;
            this.awaitIdentPos = oldAwaitIdentPos;
            return this.finishNode(node, "FunctionExpression");
        };
        // Parse arrow function expression with given parameters.
        pp$5.parseArrowExpression = function (node, params, isAsync, forInit) {
            var oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;
            this.enterScope(functionFlags(isAsync, false) | SCOPE_ARROW);
            this.initFunction(node);
            if (this.options.ecmaVersion >= 8) {
                node.async = !!isAsync;
            }
            this.yieldPos = 0;
            this.awaitPos = 0;
            this.awaitIdentPos = 0;
            node.params = this.toAssignableList(params, true);
            this.parseFunctionBody(node, true, false, forInit);
            this.yieldPos = oldYieldPos;
            this.awaitPos = oldAwaitPos;
            this.awaitIdentPos = oldAwaitIdentPos;
            return this.finishNode(node, "ArrowFunctionExpression");
        };
        // Parse function body and check parameters.
        pp$5.parseFunctionBody = function (node, isArrowFunction, isMethod, forInit) {
            var isExpression = isArrowFunction && this.type !== types$1.braceL;
            var oldStrict = this.strict, useStrict = false;
            if (isExpression) {
                node.body = this.parseMaybeAssign(forInit);
                node.expression = true;
                this.checkParams(node, false);
            }
            else {
                var nonSimple = this.options.ecmaVersion >= 7 && !this.isSimpleParamList(node.params);
                if (!oldStrict || nonSimple) {
                    useStrict = this.strictDirective(this.end);
                    // If this is a strict mode function, verify that argument names
                    // are not repeated, and it does not try to bind the words `eval`
                    // or `arguments`.
                    if (useStrict && nonSimple) {
                        this.raiseRecoverable(node.start, "Illegal 'use strict' directive in function with non-simple parameter list");
                    }
                }
                // Start a new scope with regard to labels and the `inFunction`
                // flag (restore them to their old value afterwards).
                var oldLabels = this.labels;
                this.labels = [];
                if (useStrict) {
                    this.strict = true;
                }
                // Add the params to varDeclaredNames to ensure that an error is thrown
                // if a let/const declaration in the function clashes with one of the params.
                this.checkParams(node, !oldStrict && !useStrict && !isArrowFunction && !isMethod && this.isSimpleParamList(node.params));
                // Ensure the function name isn't a forbidden identifier in strict mode, e.g. 'eval'
                if (this.strict && node.id) {
                    this.checkLValSimple(node.id, BIND_OUTSIDE);
                }
                node.body = this.parseBlock(false, undefined, useStrict && !oldStrict);
                node.expression = false;
                this.adaptDirectivePrologue(node.body.body);
                this.labels = oldLabels;
            }
            this.exitScope();
        };
        pp$5.isSimpleParamList = function (params) {
            for (var i = 0, list = params; i < list.length; i += 1) {
                var param = list[i];
                if (param.type !== "Identifier") {
                    return false;
                }
            }
            return true;
        };
        // Checks function params for various disallowed patterns such as using "eval"
        // or "arguments" and duplicate parameters.
        pp$5.checkParams = function (node, allowDuplicates) {
            var nameHash = Object.create(null);
            for (var i = 0, list = node.params; i < list.length; i += 1) {
                var param = list[i];
                this.checkLValInnerPattern(param, BIND_VAR, allowDuplicates ? null : nameHash);
            }
        };
        // Parses a comma-separated list of expressions, and returns them as
        // an array. `close` is the token type that ends the list, and
        // `allowEmpty` can be turned on to allow subsequent commas with
        // nothing in between them to be parsed as `null` (which is needed
        // for array literals).
        pp$5.parseExprList = function (close, allowTrailingComma, allowEmpty, refDestructuringErrors) {
            var elts = [], first = true;
            while (!this.eat(close)) {
                if (!first) {
                    this.expect(types$1.comma);
                    if (allowTrailingComma && this.afterTrailingComma(close)) {
                        break;
                    }
                }
                else {
                    first = false;
                }
                var elt = (void 0);
                if (allowEmpty && this.type === types$1.comma) {
                    elt = null;
                }
                else if (this.type === types$1.ellipsis) {
                    elt = this.parseSpread(refDestructuringErrors);
                    if (refDestructuringErrors && this.type === types$1.comma && refDestructuringErrors.trailingComma < 0) {
                        refDestructuringErrors.trailingComma = this.start;
                    }
                }
                else {
                    elt = this.parseMaybeAssign(false, refDestructuringErrors);
                }
                elts.push(elt);
            }
            return elts;
        };
        pp$5.checkUnreserved = function (ref) {
            var start = ref.start;
            var end = ref.end;
            var name = ref.name;
            if (this.inGenerator && name === "yield") {
                this.raiseRecoverable(start, "Cannot use 'yield' as identifier inside a generator");
            }
            if (this.inAsync && name === "await") {
                this.raiseRecoverable(start, "Cannot use 'await' as identifier inside an async function");
            }
            if (this.currentThisScope().inClassFieldInit && name === "arguments") {
                this.raiseRecoverable(start, "Cannot use 'arguments' in class field initializer");
            }
            if (this.inClassStaticBlock && (name === "arguments" || name === "await")) {
                this.raise(start, ("Cannot use " + name + " in class static initialization block"));
            }
            if (this.keywords.test(name)) {
                this.raise(start, ("Unexpected keyword '" + name + "'"));
            }
            if (this.options.ecmaVersion < 6 &&
                this.input.slice(start, end).indexOf("\\") !== -1) {
                return;
            }
            var re = this.strict ? this.reservedWordsStrict : this.reservedWords;
            if (re.test(name)) {
                if (!this.inAsync && name === "await") {
                    this.raiseRecoverable(start, "Cannot use keyword 'await' outside an async function");
                }
                this.raiseRecoverable(start, ("The keyword '" + name + "' is reserved"));
            }
        };
        // Parse the next token as an identifier. If `liberal` is true (used
        // when parsing properties), it will also convert keywords into
        // identifiers.
        pp$5.parseIdent = function (liberal) {
            var node = this.startNode();
            if (this.type === types$1.name) {
                node.name = this.value;
            }
            else if (this.type.keyword) {
                node.name = this.type.keyword;
                // To fix https://github.com/acornjs/acorn/issues/575
                // `class` and `function` keywords push new context into this.context.
                // But there is no chance to pop the context if the keyword is consumed as an identifier such as a property name.
                // If the previous token is a dot, this does not apply because the context-managing code already ignored the keyword
                if ((node.name === "class" || node.name === "function") &&
                    (this.lastTokEnd !== this.lastTokStart + 1 || this.input.charCodeAt(this.lastTokStart) !== 46)) {
                    this.context.pop();
                }
            }
            else {
                this.unexpected();
            }
            this.next(!!liberal);
            this.finishNode(node, "Identifier");
            if (!liberal) {
                this.checkUnreserved(node);
                if (node.name === "await" && !this.awaitIdentPos) {
                    this.awaitIdentPos = node.start;
                }
            }
            return node;
        };
        pp$5.parsePrivateIdent = function () {
            var node = this.startNode();
            if (this.type === types$1.privateId) {
                node.name = this.value;
            }
            else {
                this.unexpected();
            }
            this.next();
            this.finishNode(node, "PrivateIdentifier");
            // For validating existence
            if (this.privateNameStack.length === 0) {
                this.raise(node.start, ("Private field '#" + (node.name) + "' must be declared in an enclosing class"));
            }
            else {
                this.privateNameStack[this.privateNameStack.length - 1].used.push(node);
            }
            return node;
        };
        // Parses yield expression inside generator.
        pp$5.parseYield = function (forInit) {
            if (!this.yieldPos) {
                this.yieldPos = this.start;
            }
            var node = this.startNode();
            this.next();
            if (this.type === types$1.semi || this.canInsertSemicolon() || (this.type !== types$1.star && !this.type.startsExpr)) {
                node.delegate = false;
                node.argument = null;
            }
            else {
                node.delegate = this.eat(types$1.star);
                node.argument = this.parseMaybeAssign(forInit);
            }
            return this.finishNode(node, "YieldExpression");
        };
        pp$5.parseAwait = function (forInit) {
            if (!this.awaitPos) {
                this.awaitPos = this.start;
            }
            var node = this.startNode();
            this.next();
            node.argument = this.parseMaybeUnary(null, true, false, forInit);
            return this.finishNode(node, "AwaitExpression");
        };
        var pp$4 = Parser.prototype;
        // This function is used to raise exceptions on parse errors. It
        // takes an offset integer (into the current `input`) to indicate
        // the location of the error, attaches the position to the end
        // of the error message, and then raises a `SyntaxError` with that
        // message.
        pp$4.raise = function (pos, message) {
            var loc = getLineInfo(this.input, pos);
            message += " (" + loc.line + ":" + loc.column + ")";
            var err = new SyntaxError(message);
            err.pos = pos;
            err.loc = loc;
            err.raisedAt = this.pos;
            throw err;
        };
        pp$4.raiseRecoverable = pp$4.raise;
        pp$4.curPosition = function () {
            if (this.options.locations) {
                return new Position(this.curLine, this.pos - this.lineStart);
            }
        };
        var pp$3 = Parser.prototype;
        var Scope = function Scope(flags) {
            this.flags = flags;
            // A list of var-declared names in the current lexical scope
            this.var = [];
            // A list of lexically-declared names in the current lexical scope
            this.lexical = [];
            // A list of lexically-declared FunctionDeclaration names in the current lexical scope
            this.functions = [];
            // A switch to disallow the identifier reference 'arguments'
            this.inClassFieldInit = false;
        };
        // The functions in this module keep track of declared variables in the current scope in order to detect duplicate variable names.
        pp$3.enterScope = function (flags) {
            this.scopeStack.push(new Scope(flags));
        };
        pp$3.exitScope = function () {
            this.scopeStack.pop();
        };
        // The spec says:
        // > At the top level of a function, or script, function declarations are
        // > treated like var declarations rather than like lexical declarations.
        pp$3.treatFunctionsAsVarInScope = function (scope) {
            return (scope.flags & SCOPE_FUNCTION) || !this.inModule && (scope.flags & SCOPE_TOP);
        };
        pp$3.declareName = function (name, bindingType, pos) {
            var redeclared = false;
            if (bindingType === BIND_LEXICAL) {
                var scope = this.currentScope();
                redeclared = scope.lexical.indexOf(name) > -1 || scope.functions.indexOf(name) > -1 || scope.var.indexOf(name) > -1;
                scope.lexical.push(name);
                if (this.inModule && (scope.flags & SCOPE_TOP)) {
                    delete this.undefinedExports[name];
                }
            }
            else if (bindingType === BIND_SIMPLE_CATCH) {
                var scope$1 = this.currentScope();
                scope$1.lexical.push(name);
            }
            else if (bindingType === BIND_FUNCTION) {
                var scope$2 = this.currentScope();
                if (this.treatFunctionsAsVar) {
                    redeclared = scope$2.lexical.indexOf(name) > -1;
                }
                else {
                    redeclared = scope$2.lexical.indexOf(name) > -1 || scope$2.var.indexOf(name) > -1;
                }
                scope$2.functions.push(name);
            }
            else {
                for (var i = this.scopeStack.length - 1; i >= 0; --i) {
                    var scope$3 = this.scopeStack[i];
                    if (scope$3.lexical.indexOf(name) > -1 && !((scope$3.flags & SCOPE_SIMPLE_CATCH) && scope$3.lexical[0] === name) ||
                        !this.treatFunctionsAsVarInScope(scope$3) && scope$3.functions.indexOf(name) > -1) {
                        redeclared = true;
                        break;
                    }
                    scope$3.var.push(name);
                    if (this.inModule && (scope$3.flags & SCOPE_TOP)) {
                        delete this.undefinedExports[name];
                    }
                    if (scope$3.flags & SCOPE_VAR) {
                        break;
                    }
                }
            }
            if (redeclared) {
                this.raiseRecoverable(pos, ("Identifier '" + name + "' has already been declared"));
            }
        };
        pp$3.checkLocalExport = function (id) {
            // scope.functions must be empty as Module code is always strict.
            if (this.scopeStack[0].lexical.indexOf(id.name) === -1 &&
                this.scopeStack[0].var.indexOf(id.name) === -1) {
                this.undefinedExports[id.name] = id;
            }
        };
        pp$3.currentScope = function () {
            return this.scopeStack[this.scopeStack.length - 1];
        };
        pp$3.currentVarScope = function () {
            for (var i = this.scopeStack.length - 1;; i--) {
                var scope = this.scopeStack[i];
                if (scope.flags & SCOPE_VAR) {
                    return scope;
                }
            }
        };
        // Could be useful for `this`, `new.target`, `super()`, `super.property`, and `super[property]`.
        pp$3.currentThisScope = function () {
            for (var i = this.scopeStack.length - 1;; i--) {
                var scope = this.scopeStack[i];
                if (scope.flags & SCOPE_VAR && !(scope.flags & SCOPE_ARROW)) {
                    return scope;
                }
            }
        };
        var Node = function Node(parser, pos, loc) {
            this.type = "";
            this.start = pos;
            this.end = 0;
            if (parser.options.locations) {
                this.loc = new SourceLocation(parser, loc);
            }
            if (parser.options.directSourceFile) {
                this.sourceFile = parser.options.directSourceFile;
            }
            if (parser.options.ranges) {
                this.range = [pos, 0];
            }
        };
        // Start an AST node, attaching a start offset.
        var pp$2 = Parser.prototype;
        pp$2.startNode = function () {
            return new Node(this, this.start, this.startLoc);
        };
        pp$2.startNodeAt = function (pos, loc) {
            return new Node(this, pos, loc);
        };
        // Finish an AST node, adding `type` and `end` properties.
        function finishNodeAt(node, type, pos, loc) {
            node.type = type;
            node.end = pos;
            if (this.options.locations) {
                node.loc.end = loc;
            }
            if (this.options.ranges) {
                node.range[1] = pos;
            }
            return node;
        }
        pp$2.finishNode = function (node, type) {
            return finishNodeAt.call(this, node, type, this.lastTokEnd, this.lastTokEndLoc);
        };
        // Finish node at given position
        pp$2.finishNodeAt = function (node, type, pos, loc) {
            return finishNodeAt.call(this, node, type, pos, loc);
        };
        pp$2.copyNode = function (node) {
            var newNode = new Node(this, node.start, this.startLoc);
            for (var prop in node) {
                newNode[prop] = node[prop];
            }
            return newNode;
        };
        // This file contains Unicode properties extracted from the ECMAScript specification.
        // The lists are extracted like so:
        // $$('#table-binary-unicode-properties > figure > table > tbody > tr > td:nth-child(1) code').map(el => el.innerText)
        // #table-binary-unicode-properties
        var ecma9BinaryProperties = "ASCII ASCII_Hex_Digit AHex Alphabetic Alpha Any Assigned Bidi_Control Bidi_C Bidi_Mirrored Bidi_M Case_Ignorable CI Cased Changes_When_Casefolded CWCF Changes_When_Casemapped CWCM Changes_When_Lowercased CWL Changes_When_NFKC_Casefolded CWKCF Changes_When_Titlecased CWT Changes_When_Uppercased CWU Dash Default_Ignorable_Code_Point DI Deprecated Dep Diacritic Dia Emoji Emoji_Component Emoji_Modifier Emoji_Modifier_Base Emoji_Presentation Extender Ext Grapheme_Base Gr_Base Grapheme_Extend Gr_Ext Hex_Digit Hex IDS_Binary_Operator IDSB IDS_Trinary_Operator IDST ID_Continue IDC ID_Start IDS Ideographic Ideo Join_Control Join_C Logical_Order_Exception LOE Lowercase Lower Math Noncharacter_Code_Point NChar Pattern_Syntax Pat_Syn Pattern_White_Space Pat_WS Quotation_Mark QMark Radical Regional_Indicator RI Sentence_Terminal STerm Soft_Dotted SD Terminal_Punctuation Term Unified_Ideograph UIdeo Uppercase Upper Variation_Selector VS White_Space space XID_Continue XIDC XID_Start XIDS";
        var ecma10BinaryProperties = ecma9BinaryProperties + " Extended_Pictographic";
        var ecma11BinaryProperties = ecma10BinaryProperties;
        var ecma12BinaryProperties = ecma11BinaryProperties + " EBase EComp EMod EPres ExtPict";
        var ecma13BinaryProperties = ecma12BinaryProperties;
        var ecma14BinaryProperties = ecma13BinaryProperties;
        var unicodeBinaryProperties = {
            9: ecma9BinaryProperties,
            10: ecma10BinaryProperties,
            11: ecma11BinaryProperties,
            12: ecma12BinaryProperties,
            13: ecma13BinaryProperties,
            14: ecma14BinaryProperties
        };
        // #table-unicode-general-category-values
        var unicodeGeneralCategoryValues = "Cased_Letter LC Close_Punctuation Pe Connector_Punctuation Pc Control Cc cntrl Currency_Symbol Sc Dash_Punctuation Pd Decimal_Number Nd digit Enclosing_Mark Me Final_Punctuation Pf Format Cf Initial_Punctuation Pi Letter L Letter_Number Nl Line_Separator Zl Lowercase_Letter Ll Mark M Combining_Mark Math_Symbol Sm Modifier_Letter Lm Modifier_Symbol Sk Nonspacing_Mark Mn Number N Open_Punctuation Ps Other C Other_Letter Lo Other_Number No Other_Punctuation Po Other_Symbol So Paragraph_Separator Zp Private_Use Co Punctuation P punct Separator Z Space_Separator Zs Spacing_Mark Mc Surrogate Cs Symbol S Titlecase_Letter Lt Unassigned Cn Uppercase_Letter Lu";
        // #table-unicode-script-values
        var ecma9ScriptValues = "Adlam Adlm Ahom Anatolian_Hieroglyphs Hluw Arabic Arab Armenian Armn Avestan Avst Balinese Bali Bamum Bamu Bassa_Vah Bass Batak Batk Bengali Beng Bhaiksuki Bhks Bopomofo Bopo Brahmi Brah Braille Brai Buginese Bugi Buhid Buhd Canadian_Aboriginal Cans Carian Cari Caucasian_Albanian Aghb Chakma Cakm Cham Cham Cherokee Cher Common Zyyy Coptic Copt Qaac Cuneiform Xsux Cypriot Cprt Cyrillic Cyrl Deseret Dsrt Devanagari Deva Duployan Dupl Egyptian_Hieroglyphs Egyp Elbasan Elba Ethiopic Ethi Georgian Geor Glagolitic Glag Gothic Goth Grantha Gran Greek Grek Gujarati Gujr Gurmukhi Guru Han Hani Hangul Hang Hanunoo Hano Hatran Hatr Hebrew Hebr Hiragana Hira Imperial_Aramaic Armi Inherited Zinh Qaai Inscriptional_Pahlavi Phli Inscriptional_Parthian Prti Javanese Java Kaithi Kthi Kannada Knda Katakana Kana Kayah_Li Kali Kharoshthi Khar Khmer Khmr Khojki Khoj Khudawadi Sind Lao Laoo Latin Latn Lepcha Lepc Limbu Limb Linear_A Lina Linear_B Linb Lisu Lisu Lycian Lyci Lydian Lydi Mahajani Mahj Malayalam Mlym Mandaic Mand Manichaean Mani Marchen Marc Masaram_Gondi Gonm Meetei_Mayek Mtei Mende_Kikakui Mend Meroitic_Cursive Merc Meroitic_Hieroglyphs Mero Miao Plrd Modi Mongolian Mong Mro Mroo Multani Mult Myanmar Mymr Nabataean Nbat New_Tai_Lue Talu Newa Newa Nko Nkoo Nushu Nshu Ogham Ogam Ol_Chiki Olck Old_Hungarian Hung Old_Italic Ital Old_North_Arabian Narb Old_Permic Perm Old_Persian Xpeo Old_South_Arabian Sarb Old_Turkic Orkh Oriya Orya Osage Osge Osmanya Osma Pahawh_Hmong Hmng Palmyrene Palm Pau_Cin_Hau Pauc Phags_Pa Phag Phoenician Phnx Psalter_Pahlavi Phlp Rejang Rjng Runic Runr Samaritan Samr Saurashtra Saur Sharada Shrd Shavian Shaw Siddham Sidd SignWriting Sgnw Sinhala Sinh Sora_Sompeng Sora Soyombo Soyo Sundanese Sund Syloti_Nagri Sylo Syriac Syrc Tagalog Tglg Tagbanwa Tagb Tai_Le Tale Tai_Tham Lana Tai_Viet Tavt Takri Takr Tamil Taml Tangut Tang Telugu Telu Thaana Thaa Thai Thai Tibetan Tibt Tifinagh Tfng Tirhuta Tirh Ugaritic Ugar Vai Vaii Warang_Citi Wara Yi Yiii Zanabazar_Square Zanb";
        var ecma10ScriptValues = ecma9ScriptValues + " Dogra Dogr Gunjala_Gondi Gong Hanifi_Rohingya Rohg Makasar Maka Medefaidrin Medf Old_Sogdian Sogo Sogdian Sogd";
        var ecma11ScriptValues = ecma10ScriptValues + " Elymaic Elym Nandinagari Nand Nyiakeng_Puachue_Hmong Hmnp Wancho Wcho";
        var ecma12ScriptValues = ecma11ScriptValues + " Chorasmian Chrs Diak Dives_Akuru Khitan_Small_Script Kits Yezi Yezidi";
        var ecma13ScriptValues = ecma12ScriptValues + " Cypro_Minoan Cpmn Old_Uyghur Ougr Tangsa Tnsa Toto Vithkuqi Vith";
        var ecma14ScriptValues = ecma13ScriptValues + " Kawi Nag_Mundari Nagm";
        var unicodeScriptValues = {
            9: ecma9ScriptValues,
            10: ecma10ScriptValues,
            11: ecma11ScriptValues,
            12: ecma12ScriptValues,
            13: ecma13ScriptValues,
            14: ecma14ScriptValues
        };
        var data = {};
        function buildUnicodeData(ecmaVersion) {
            var d = data[ecmaVersion] = {
                binary: wordsRegexp(unicodeBinaryProperties[ecmaVersion] + " " + unicodeGeneralCategoryValues),
                nonBinary: {
                    General_Category: wordsRegexp(unicodeGeneralCategoryValues),
                    Script: wordsRegexp(unicodeScriptValues[ecmaVersion])
                }
            };
            d.nonBinary.Script_Extensions = d.nonBinary.Script;
            d.nonBinary.gc = d.nonBinary.General_Category;
            d.nonBinary.sc = d.nonBinary.Script;
            d.nonBinary.scx = d.nonBinary.Script_Extensions;
        }
        for (var i = 0, list = [9, 10, 11, 12, 13, 14]; i < list.length; i += 1) {
            var ecmaVersion = list[i];
            buildUnicodeData(ecmaVersion);
        }
        var pp$1 = Parser.prototype;
        var RegExpValidationState = function RegExpValidationState(parser) {
            this.parser = parser;
            this.validFlags = "gim" + (parser.options.ecmaVersion >= 6 ? "uy" : "") + (parser.options.ecmaVersion >= 9 ? "s" : "") + (parser.options.ecmaVersion >= 13 ? "d" : "");
            this.unicodeProperties = data[parser.options.ecmaVersion >= 14 ? 14 : parser.options.ecmaVersion];
            this.source = "";
            this.flags = "";
            this.start = 0;
            this.switchU = false;
            this.switchN = false;
            this.pos = 0;
            this.lastIntValue = 0;
            this.lastStringValue = "";
            this.lastAssertionIsQuantifiable = false;
            this.numCapturingParens = 0;
            this.maxBackReference = 0;
            this.groupNames = [];
            this.backReferenceNames = [];
        };
        RegExpValidationState.prototype.reset = function reset(start, pattern, flags) {
            var unicode = flags.indexOf("u") !== -1;
            this.start = start | 0;
            this.source = pattern + "";
            this.flags = flags;
            this.switchU = unicode && this.parser.options.ecmaVersion >= 6;
            this.switchN = unicode && this.parser.options.ecmaVersion >= 9;
        };
        RegExpValidationState.prototype.raise = function raise(message) {
            this.parser.raiseRecoverable(this.start, ("Invalid regular expression: /" + (this.source) + "/: " + message));
        };
        // If u flag is given, this returns the code point at the index (it combines a surrogate pair).
        // Otherwise, this returns the code unit of the index (can be a part of a surrogate pair).
        RegExpValidationState.prototype.at = function at(i, forceU) {
            if (forceU === void 0)
                forceU = false;
            var s = this.source;
            var l = s.length;
            if (i >= l) {
                return -1;
            }
            var c = s.charCodeAt(i);
            if (!(forceU || this.switchU) || c <= 0xD7FF || c >= 0xE000 || i + 1 >= l) {
                return c;
            }
            var next = s.charCodeAt(i + 1);
            return next >= 0xDC00 && next <= 0xDFFF ? (c << 10) + next - 0x35FDC00 : c;
        };
        RegExpValidationState.prototype.nextIndex = function nextIndex(i, forceU) {
            if (forceU === void 0)
                forceU = false;
            var s = this.source;
            var l = s.length;
            if (i >= l) {
                return l;
            }
            var c = s.charCodeAt(i), next;
            if (!(forceU || this.switchU) || c <= 0xD7FF || c >= 0xE000 || i + 1 >= l ||
                (next = s.charCodeAt(i + 1)) < 0xDC00 || next > 0xDFFF) {
                return i + 1;
            }
            return i + 2;
        };
        RegExpValidationState.prototype.current = function current(forceU) {
            if (forceU === void 0)
                forceU = false;
            return this.at(this.pos, forceU);
        };
        RegExpValidationState.prototype.lookahead = function lookahead(forceU) {
            if (forceU === void 0)
                forceU = false;
            return this.at(this.nextIndex(this.pos, forceU), forceU);
        };
        RegExpValidationState.prototype.advance = function advance(forceU) {
            if (forceU === void 0)
                forceU = false;
            this.pos = this.nextIndex(this.pos, forceU);
        };
        RegExpValidationState.prototype.eat = function eat(ch, forceU) {
            if (forceU === void 0)
                forceU = false;
            if (this.current(forceU) === ch) {
                this.advance(forceU);
                return true;
            }
            return false;
        };
        /**
         * Validate the flags part of a given RegExpLiteral.
         *
         * @param {RegExpValidationState} state The state to validate RegExp.
         * @returns {void}
         */
        pp$1.validateRegExpFlags = function (state) {
            var validFlags = state.validFlags;
            var flags = state.flags;
            for (var i = 0; i < flags.length; i++) {
                var flag = flags.charAt(i);
                if (validFlags.indexOf(flag) === -1) {
                    this.raise(state.start, "Invalid regular expression flag");
                }
                if (flags.indexOf(flag, i + 1) > -1) {
                    this.raise(state.start, "Duplicate regular expression flag");
                }
            }
        };
        /**
         * Validate the pattern part of a given RegExpLiteral.
         *
         * @param {RegExpValidationState} state The state to validate RegExp.
         * @returns {void}
         */
        pp$1.validateRegExpPattern = function (state) {
            this.regexp_pattern(state);
            // The goal symbol for the parse is |Pattern[~U, ~N]|. If the result of
            // parsing contains a |GroupName|, reparse with the goal symbol
            // |Pattern[~U, +N]| and use this result instead. Throw a *SyntaxError*
            // exception if _P_ did not conform to the grammar, if any elements of _P_
            // were not matched by the parse, or if any Early Error conditions exist.
            if (!state.switchN && this.options.ecmaVersion >= 9 && state.groupNames.length > 0) {
                state.switchN = true;
                this.regexp_pattern(state);
            }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Pattern
        pp$1.regexp_pattern = function (state) {
            state.pos = 0;
            state.lastIntValue = 0;
            state.lastStringValue = "";
            state.lastAssertionIsQuantifiable = false;
            state.numCapturingParens = 0;
            state.maxBackReference = 0;
            state.groupNames.length = 0;
            state.backReferenceNames.length = 0;
            this.regexp_disjunction(state);
            if (state.pos !== state.source.length) {
                // Make the same messages as V8.
                if (state.eat(0x29 /* ) */)) {
                    state.raise("Unmatched ')'");
                }
                if (state.eat(0x5D /* ] */) || state.eat(0x7D /* } */)) {
                    state.raise("Lone quantifier brackets");
                }
            }
            if (state.maxBackReference > state.numCapturingParens) {
                state.raise("Invalid escape");
            }
            for (var i = 0, list = state.backReferenceNames; i < list.length; i += 1) {
                var name = list[i];
                if (state.groupNames.indexOf(name) === -1) {
                    state.raise("Invalid named capture referenced");
                }
            }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Disjunction
        pp$1.regexp_disjunction = function (state) {
            this.regexp_alternative(state);
            while (state.eat(0x7C /* | */)) {
                this.regexp_alternative(state);
            }
            // Make the same message as V8.
            if (this.regexp_eatQuantifier(state, true)) {
                state.raise("Nothing to repeat");
            }
            if (state.eat(0x7B /* { */)) {
                state.raise("Lone quantifier brackets");
            }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Alternative
        pp$1.regexp_alternative = function (state) {
            while (state.pos < state.source.length && this.regexp_eatTerm(state)) { }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-Term
        pp$1.regexp_eatTerm = function (state) {
            if (this.regexp_eatAssertion(state)) {
                // Handle `QuantifiableAssertion Quantifier` alternative.
                // `state.lastAssertionIsQuantifiable` is true if the last eaten Assertion
                // is a QuantifiableAssertion.
                if (state.lastAssertionIsQuantifiable && this.regexp_eatQuantifier(state)) {
                    // Make the same message as V8.
                    if (state.switchU) {
                        state.raise("Invalid quantifier");
                    }
                }
                return true;
            }
            if (state.switchU ? this.regexp_eatAtom(state) : this.regexp_eatExtendedAtom(state)) {
                this.regexp_eatQuantifier(state);
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-Assertion
        pp$1.regexp_eatAssertion = function (state) {
            var start = state.pos;
            state.lastAssertionIsQuantifiable = false;
            // ^, $
            if (state.eat(0x5E /* ^ */) || state.eat(0x24 /* $ */)) {
                return true;
            }
            // \b \B
            if (state.eat(0x5C /* \ */)) {
                if (state.eat(0x42 /* B */) || state.eat(0x62 /* b */)) {
                    return true;
                }
                state.pos = start;
            }
            // Lookahead / Lookbehind
            if (state.eat(0x28 /* ( */) && state.eat(0x3F /* ? */)) {
                var lookbehind = false;
                if (this.options.ecmaVersion >= 9) {
                    lookbehind = state.eat(0x3C /* < */);
                }
                if (state.eat(0x3D /* = */) || state.eat(0x21 /* ! */)) {
                    this.regexp_disjunction(state);
                    if (!state.eat(0x29 /* ) */)) {
                        state.raise("Unterminated group");
                    }
                    state.lastAssertionIsQuantifiable = !lookbehind;
                    return true;
                }
            }
            state.pos = start;
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Quantifier
        pp$1.regexp_eatQuantifier = function (state, noError) {
            if (noError === void 0)
                noError = false;
            if (this.regexp_eatQuantifierPrefix(state, noError)) {
                state.eat(0x3F /* ? */);
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-QuantifierPrefix
        pp$1.regexp_eatQuantifierPrefix = function (state, noError) {
            return (state.eat(0x2A /* * */) ||
                state.eat(0x2B /* + */) ||
                state.eat(0x3F /* ? */) ||
                this.regexp_eatBracedQuantifier(state, noError));
        };
        pp$1.regexp_eatBracedQuantifier = function (state, noError) {
            var start = state.pos;
            if (state.eat(0x7B /* { */)) {
                var min = 0, max = -1;
                if (this.regexp_eatDecimalDigits(state)) {
                    min = state.lastIntValue;
                    if (state.eat(0x2C /* , */) && this.regexp_eatDecimalDigits(state)) {
                        max = state.lastIntValue;
                    }
                    if (state.eat(0x7D /* } */)) {
                        // SyntaxError in https://www.ecma-international.org/ecma-262/8.0/#sec-term
                        if (max !== -1 && max < min && !noError) {
                            state.raise("numbers out of order in {} quantifier");
                        }
                        return true;
                    }
                }
                if (state.switchU && !noError) {
                    state.raise("Incomplete quantifier");
                }
                state.pos = start;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Atom
        pp$1.regexp_eatAtom = function (state) {
            return (this.regexp_eatPatternCharacters(state) ||
                state.eat(0x2E /* . */) ||
                this.regexp_eatReverseSolidusAtomEscape(state) ||
                this.regexp_eatCharacterClass(state) ||
                this.regexp_eatUncapturingGroup(state) ||
                this.regexp_eatCapturingGroup(state));
        };
        pp$1.regexp_eatReverseSolidusAtomEscape = function (state) {
            var start = state.pos;
            if (state.eat(0x5C /* \ */)) {
                if (this.regexp_eatAtomEscape(state)) {
                    return true;
                }
                state.pos = start;
            }
            return false;
        };
        pp$1.regexp_eatUncapturingGroup = function (state) {
            var start = state.pos;
            if (state.eat(0x28 /* ( */)) {
                if (state.eat(0x3F /* ? */) && state.eat(0x3A /* : */)) {
                    this.regexp_disjunction(state);
                    if (state.eat(0x29 /* ) */)) {
                        return true;
                    }
                    state.raise("Unterminated group");
                }
                state.pos = start;
            }
            return false;
        };
        pp$1.regexp_eatCapturingGroup = function (state) {
            if (state.eat(0x28 /* ( */)) {
                if (this.options.ecmaVersion >= 9) {
                    this.regexp_groupSpecifier(state);
                }
                else if (state.current() === 0x3F /* ? */) {
                    state.raise("Invalid group");
                }
                this.regexp_disjunction(state);
                if (state.eat(0x29 /* ) */)) {
                    state.numCapturingParens += 1;
                    return true;
                }
                state.raise("Unterminated group");
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ExtendedAtom
        pp$1.regexp_eatExtendedAtom = function (state) {
            return (state.eat(0x2E /* . */) ||
                this.regexp_eatReverseSolidusAtomEscape(state) ||
                this.regexp_eatCharacterClass(state) ||
                this.regexp_eatUncapturingGroup(state) ||
                this.regexp_eatCapturingGroup(state) ||
                this.regexp_eatInvalidBracedQuantifier(state) ||
                this.regexp_eatExtendedPatternCharacter(state));
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-InvalidBracedQuantifier
        pp$1.regexp_eatInvalidBracedQuantifier = function (state) {
            if (this.regexp_eatBracedQuantifier(state, true)) {
                state.raise("Nothing to repeat");
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-SyntaxCharacter
        pp$1.regexp_eatSyntaxCharacter = function (state) {
            var ch = state.current();
            if (isSyntaxCharacter(ch)) {
                state.lastIntValue = ch;
                state.advance();
                return true;
            }
            return false;
        };
        function isSyntaxCharacter(ch) {
            return (ch === 0x24 /* $ */ ||
                ch >= 0x28 /* ( */ && ch <= 0x2B /* + */ ||
                ch === 0x2E /* . */ ||
                ch === 0x3F /* ? */ ||
                ch >= 0x5B /* [ */ && ch <= 0x5E /* ^ */ ||
                ch >= 0x7B /* { */ && ch <= 0x7D /* } */);
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-PatternCharacter
        // But eat eager.
        pp$1.regexp_eatPatternCharacters = function (state) {
            var start = state.pos;
            var ch = 0;
            while ((ch = state.current()) !== -1 && !isSyntaxCharacter(ch)) {
                state.advance();
            }
            return state.pos !== start;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ExtendedPatternCharacter
        pp$1.regexp_eatExtendedPatternCharacter = function (state) {
            var ch = state.current();
            if (ch !== -1 &&
                ch !== 0x24 /* $ */ &&
                !(ch >= 0x28 /* ( */ && ch <= 0x2B /* + */) &&
                ch !== 0x2E /* . */ &&
                ch !== 0x3F /* ? */ &&
                ch !== 0x5B /* [ */ &&
                ch !== 0x5E /* ^ */ &&
                ch !== 0x7C /* | */) {
                state.advance();
                return true;
            }
            return false;
        };
        // GroupSpecifier ::
        //   [empty]
        //   `?` GroupName
        pp$1.regexp_groupSpecifier = function (state) {
            if (state.eat(0x3F /* ? */)) {
                if (this.regexp_eatGroupName(state)) {
                    if (state.groupNames.indexOf(state.lastStringValue) !== -1) {
                        state.raise("Duplicate capture group name");
                    }
                    state.groupNames.push(state.lastStringValue);
                    return;
                }
                state.raise("Invalid group");
            }
        };
        // GroupName ::
        //   `<` RegExpIdentifierName `>`
        // Note: this updates `state.lastStringValue` property with the eaten name.
        pp$1.regexp_eatGroupName = function (state) {
            state.lastStringValue = "";
            if (state.eat(0x3C /* < */)) {
                if (this.regexp_eatRegExpIdentifierName(state) && state.eat(0x3E /* > */)) {
                    return true;
                }
                state.raise("Invalid capture group name");
            }
            return false;
        };
        // RegExpIdentifierName ::
        //   RegExpIdentifierStart
        //   RegExpIdentifierName RegExpIdentifierPart
        // Note: this updates `state.lastStringValue` property with the eaten name.
        pp$1.regexp_eatRegExpIdentifierName = function (state) {
            state.lastStringValue = "";
            if (this.regexp_eatRegExpIdentifierStart(state)) {
                state.lastStringValue += codePointToString(state.lastIntValue);
                while (this.regexp_eatRegExpIdentifierPart(state)) {
                    state.lastStringValue += codePointToString(state.lastIntValue);
                }
                return true;
            }
            return false;
        };
        // RegExpIdentifierStart ::
        //   UnicodeIDStart
        //   `$`
        //   `_`
        //   `\` RegExpUnicodeEscapeSequence[+U]
        pp$1.regexp_eatRegExpIdentifierStart = function (state) {
            var start = state.pos;
            var forceU = this.options.ecmaVersion >= 11;
            var ch = state.current(forceU);
            state.advance(forceU);
            if (ch === 0x5C /* \ */ && this.regexp_eatRegExpUnicodeEscapeSequence(state, forceU)) {
                ch = state.lastIntValue;
            }
            if (isRegExpIdentifierStart(ch)) {
                state.lastIntValue = ch;
                return true;
            }
            state.pos = start;
            return false;
        };
        function isRegExpIdentifierStart(ch) {
            return isIdentifierStart(ch, true) || ch === 0x24 /* $ */ || ch === 0x5F; /* _ */
        }
        // RegExpIdentifierPart ::
        //   UnicodeIDContinue
        //   `$`
        //   `_`
        //   `\` RegExpUnicodeEscapeSequence[+U]
        //   <ZWNJ>
        //   <ZWJ>
        pp$1.regexp_eatRegExpIdentifierPart = function (state) {
            var start = state.pos;
            var forceU = this.options.ecmaVersion >= 11;
            var ch = state.current(forceU);
            state.advance(forceU);
            if (ch === 0x5C /* \ */ && this.regexp_eatRegExpUnicodeEscapeSequence(state, forceU)) {
                ch = state.lastIntValue;
            }
            if (isRegExpIdentifierPart(ch)) {
                state.lastIntValue = ch;
                return true;
            }
            state.pos = start;
            return false;
        };
        function isRegExpIdentifierPart(ch) {
            return isIdentifierChar(ch, true) || ch === 0x24 /* $ */ || ch === 0x5F /* _ */ || ch === 0x200C /* <ZWNJ> */ || ch === 0x200D; /* <ZWJ> */
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-AtomEscape
        pp$1.regexp_eatAtomEscape = function (state) {
            if (this.regexp_eatBackReference(state) ||
                this.regexp_eatCharacterClassEscape(state) ||
                this.regexp_eatCharacterEscape(state) ||
                (state.switchN && this.regexp_eatKGroupName(state))) {
                return true;
            }
            if (state.switchU) {
                // Make the same message as V8.
                if (state.current() === 0x63 /* c */) {
                    state.raise("Invalid unicode escape");
                }
                state.raise("Invalid escape");
            }
            return false;
        };
        pp$1.regexp_eatBackReference = function (state) {
            var start = state.pos;
            if (this.regexp_eatDecimalEscape(state)) {
                var n = state.lastIntValue;
                if (state.switchU) {
                    // For SyntaxError in https://www.ecma-international.org/ecma-262/8.0/#sec-atomescape
                    if (n > state.maxBackReference) {
                        state.maxBackReference = n;
                    }
                    return true;
                }
                if (n <= state.numCapturingParens) {
                    return true;
                }
                state.pos = start;
            }
            return false;
        };
        pp$1.regexp_eatKGroupName = function (state) {
            if (state.eat(0x6B /* k */)) {
                if (this.regexp_eatGroupName(state)) {
                    state.backReferenceNames.push(state.lastStringValue);
                    return true;
                }
                state.raise("Invalid named reference");
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-CharacterEscape
        pp$1.regexp_eatCharacterEscape = function (state) {
            return (this.regexp_eatControlEscape(state) ||
                this.regexp_eatCControlLetter(state) ||
                this.regexp_eatZero(state) ||
                this.regexp_eatHexEscapeSequence(state) ||
                this.regexp_eatRegExpUnicodeEscapeSequence(state, false) ||
                (!state.switchU && this.regexp_eatLegacyOctalEscapeSequence(state)) ||
                this.regexp_eatIdentityEscape(state));
        };
        pp$1.regexp_eatCControlLetter = function (state) {
            var start = state.pos;
            if (state.eat(0x63 /* c */)) {
                if (this.regexp_eatControlLetter(state)) {
                    return true;
                }
                state.pos = start;
            }
            return false;
        };
        pp$1.regexp_eatZero = function (state) {
            if (state.current() === 0x30 /* 0 */ && !isDecimalDigit(state.lookahead())) {
                state.lastIntValue = 0;
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ControlEscape
        pp$1.regexp_eatControlEscape = function (state) {
            var ch = state.current();
            if (ch === 0x74 /* t */) {
                state.lastIntValue = 0x09; /* \t */
                state.advance();
                return true;
            }
            if (ch === 0x6E /* n */) {
                state.lastIntValue = 0x0A; /* \n */
                state.advance();
                return true;
            }
            if (ch === 0x76 /* v */) {
                state.lastIntValue = 0x0B; /* \v */
                state.advance();
                return true;
            }
            if (ch === 0x66 /* f */) {
                state.lastIntValue = 0x0C; /* \f */
                state.advance();
                return true;
            }
            if (ch === 0x72 /* r */) {
                state.lastIntValue = 0x0D; /* \r */
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ControlLetter
        pp$1.regexp_eatControlLetter = function (state) {
            var ch = state.current();
            if (isControlLetter(ch)) {
                state.lastIntValue = ch % 0x20;
                state.advance();
                return true;
            }
            return false;
        };
        function isControlLetter(ch) {
            return ((ch >= 0x41 /* A */ && ch <= 0x5A /* Z */) ||
                (ch >= 0x61 /* a */ && ch <= 0x7A /* z */));
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-RegExpUnicodeEscapeSequence
        pp$1.regexp_eatRegExpUnicodeEscapeSequence = function (state, forceU) {
            if (forceU === void 0)
                forceU = false;
            var start = state.pos;
            var switchU = forceU || state.switchU;
            if (state.eat(0x75 /* u */)) {
                if (this.regexp_eatFixedHexDigits(state, 4)) {
                    var lead = state.lastIntValue;
                    if (switchU && lead >= 0xD800 && lead <= 0xDBFF) {
                        var leadSurrogateEnd = state.pos;
                        if (state.eat(0x5C /* \ */) && state.eat(0x75 /* u */) && this.regexp_eatFixedHexDigits(state, 4)) {
                            var trail = state.lastIntValue;
                            if (trail >= 0xDC00 && trail <= 0xDFFF) {
                                state.lastIntValue = (lead - 0xD800) * 0x400 + (trail - 0xDC00) + 0x10000;
                                return true;
                            }
                        }
                        state.pos = leadSurrogateEnd;
                        state.lastIntValue = lead;
                    }
                    return true;
                }
                if (switchU &&
                    state.eat(0x7B /* { */) &&
                    this.regexp_eatHexDigits(state) &&
                    state.eat(0x7D /* } */) &&
                    isValidUnicode(state.lastIntValue)) {
                    return true;
                }
                if (switchU) {
                    state.raise("Invalid unicode escape");
                }
                state.pos = start;
            }
            return false;
        };
        function isValidUnicode(ch) {
            return ch >= 0 && ch <= 0x10FFFF;
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-IdentityEscape
        pp$1.regexp_eatIdentityEscape = function (state) {
            if (state.switchU) {
                if (this.regexp_eatSyntaxCharacter(state)) {
                    return true;
                }
                if (state.eat(0x2F /* / */)) {
                    state.lastIntValue = 0x2F; /* / */
                    return true;
                }
                return false;
            }
            var ch = state.current();
            if (ch !== 0x63 /* c */ && (!state.switchN || ch !== 0x6B /* k */)) {
                state.lastIntValue = ch;
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-DecimalEscape
        pp$1.regexp_eatDecimalEscape = function (state) {
            state.lastIntValue = 0;
            var ch = state.current();
            if (ch >= 0x31 /* 1 */ && ch <= 0x39 /* 9 */) {
                do {
                    state.lastIntValue = 10 * state.lastIntValue + (ch - 0x30 /* 0 */);
                    state.advance();
                } while ((ch = state.current()) >= 0x30 /* 0 */ && ch <= 0x39 /* 9 */);
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-CharacterClassEscape
        pp$1.regexp_eatCharacterClassEscape = function (state) {
            var ch = state.current();
            if (isCharacterClassEscape(ch)) {
                state.lastIntValue = -1;
                state.advance();
                return true;
            }
            if (state.switchU &&
                this.options.ecmaVersion >= 9 &&
                (ch === 0x50 /* P */ || ch === 0x70 /* p */)) {
                state.lastIntValue = -1;
                state.advance();
                if (state.eat(0x7B /* { */) &&
                    this.regexp_eatUnicodePropertyValueExpression(state) &&
                    state.eat(0x7D /* } */)) {
                    return true;
                }
                state.raise("Invalid property name");
            }
            return false;
        };
        function isCharacterClassEscape(ch) {
            return (ch === 0x64 /* d */ ||
                ch === 0x44 /* D */ ||
                ch === 0x73 /* s */ ||
                ch === 0x53 /* S */ ||
                ch === 0x77 /* w */ ||
                ch === 0x57 /* W */);
        }
        // UnicodePropertyValueExpression ::
        //   UnicodePropertyName `=` UnicodePropertyValue
        //   LoneUnicodePropertyNameOrValue
        pp$1.regexp_eatUnicodePropertyValueExpression = function (state) {
            var start = state.pos;
            // UnicodePropertyName `=` UnicodePropertyValue
            if (this.regexp_eatUnicodePropertyName(state) && state.eat(0x3D /* = */)) {
                var name = state.lastStringValue;
                if (this.regexp_eatUnicodePropertyValue(state)) {
                    var value = state.lastStringValue;
                    this.regexp_validateUnicodePropertyNameAndValue(state, name, value);
                    return true;
                }
            }
            state.pos = start;
            // LoneUnicodePropertyNameOrValue
            if (this.regexp_eatLoneUnicodePropertyNameOrValue(state)) {
                var nameOrValue = state.lastStringValue;
                this.regexp_validateUnicodePropertyNameOrValue(state, nameOrValue);
                return true;
            }
            return false;
        };
        pp$1.regexp_validateUnicodePropertyNameAndValue = function (state, name, value) {
            if (!hasOwn(state.unicodeProperties.nonBinary, name)) {
                state.raise("Invalid property name");
            }
            if (!state.unicodeProperties.nonBinary[name].test(value)) {
                state.raise("Invalid property value");
            }
        };
        pp$1.regexp_validateUnicodePropertyNameOrValue = function (state, nameOrValue) {
            if (!state.unicodeProperties.binary.test(nameOrValue)) {
                state.raise("Invalid property name");
            }
        };
        // UnicodePropertyName ::
        //   UnicodePropertyNameCharacters
        pp$1.regexp_eatUnicodePropertyName = function (state) {
            var ch = 0;
            state.lastStringValue = "";
            while (isUnicodePropertyNameCharacter(ch = state.current())) {
                state.lastStringValue += codePointToString(ch);
                state.advance();
            }
            return state.lastStringValue !== "";
        };
        function isUnicodePropertyNameCharacter(ch) {
            return isControlLetter(ch) || ch === 0x5F; /* _ */
        }
        // UnicodePropertyValue ::
        //   UnicodePropertyValueCharacters
        pp$1.regexp_eatUnicodePropertyValue = function (state) {
            var ch = 0;
            state.lastStringValue = "";
            while (isUnicodePropertyValueCharacter(ch = state.current())) {
                state.lastStringValue += codePointToString(ch);
                state.advance();
            }
            return state.lastStringValue !== "";
        };
        function isUnicodePropertyValueCharacter(ch) {
            return isUnicodePropertyNameCharacter(ch) || isDecimalDigit(ch);
        }
        // LoneUnicodePropertyNameOrValue ::
        //   UnicodePropertyValueCharacters
        pp$1.regexp_eatLoneUnicodePropertyNameOrValue = function (state) {
            return this.regexp_eatUnicodePropertyValue(state);
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-CharacterClass
        pp$1.regexp_eatCharacterClass = function (state) {
            if (state.eat(0x5B /* [ */)) {
                state.eat(0x5E /* ^ */);
                this.regexp_classRanges(state);
                if (state.eat(0x5D /* ] */)) {
                    return true;
                }
                // Unreachable since it threw "unterminated regular expression" error before.
                state.raise("Unterminated character class");
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ClassRanges
        // https://www.ecma-international.org/ecma-262/8.0/#prod-NonemptyClassRanges
        // https://www.ecma-international.org/ecma-262/8.0/#prod-NonemptyClassRangesNoDash
        pp$1.regexp_classRanges = function (state) {
            while (this.regexp_eatClassAtom(state)) {
                var left = state.lastIntValue;
                if (state.eat(0x2D /* - */) && this.regexp_eatClassAtom(state)) {
                    var right = state.lastIntValue;
                    if (state.switchU && (left === -1 || right === -1)) {
                        state.raise("Invalid character class");
                    }
                    if (left !== -1 && right !== -1 && left > right) {
                        state.raise("Range out of order in character class");
                    }
                }
            }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ClassAtom
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ClassAtomNoDash
        pp$1.regexp_eatClassAtom = function (state) {
            var start = state.pos;
            if (state.eat(0x5C /* \ */)) {
                if (this.regexp_eatClassEscape(state)) {
                    return true;
                }
                if (state.switchU) {
                    // Make the same message as V8.
                    var ch$1 = state.current();
                    if (ch$1 === 0x63 /* c */ || isOctalDigit(ch$1)) {
                        state.raise("Invalid class escape");
                    }
                    state.raise("Invalid escape");
                }
                state.pos = start;
            }
            var ch = state.current();
            if (ch !== 0x5D /* ] */) {
                state.lastIntValue = ch;
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ClassEscape
        pp$1.regexp_eatClassEscape = function (state) {
            var start = state.pos;
            if (state.eat(0x62 /* b */)) {
                state.lastIntValue = 0x08; /* <BS> */
                return true;
            }
            if (state.switchU && state.eat(0x2D /* - */)) {
                state.lastIntValue = 0x2D; /* - */
                return true;
            }
            if (!state.switchU && state.eat(0x63 /* c */)) {
                if (this.regexp_eatClassControlLetter(state)) {
                    return true;
                }
                state.pos = start;
            }
            return (this.regexp_eatCharacterClassEscape(state) ||
                this.regexp_eatCharacterEscape(state));
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ClassControlLetter
        pp$1.regexp_eatClassControlLetter = function (state) {
            var ch = state.current();
            if (isDecimalDigit(ch) || ch === 0x5F /* _ */) {
                state.lastIntValue = ch % 0x20;
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-HexEscapeSequence
        pp$1.regexp_eatHexEscapeSequence = function (state) {
            var start = state.pos;
            if (state.eat(0x78 /* x */)) {
                if (this.regexp_eatFixedHexDigits(state, 2)) {
                    return true;
                }
                if (state.switchU) {
                    state.raise("Invalid escape");
                }
                state.pos = start;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-DecimalDigits
        pp$1.regexp_eatDecimalDigits = function (state) {
            var start = state.pos;
            var ch = 0;
            state.lastIntValue = 0;
            while (isDecimalDigit(ch = state.current())) {
                state.lastIntValue = 10 * state.lastIntValue + (ch - 0x30 /* 0 */);
                state.advance();
            }
            return state.pos !== start;
        };
        function isDecimalDigit(ch) {
            return ch >= 0x30 /* 0 */ && ch <= 0x39; /* 9 */
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-HexDigits
        pp$1.regexp_eatHexDigits = function (state) {
            var start = state.pos;
            var ch = 0;
            state.lastIntValue = 0;
            while (isHexDigit(ch = state.current())) {
                state.lastIntValue = 16 * state.lastIntValue + hexToInt(ch);
                state.advance();
            }
            return state.pos !== start;
        };
        function isHexDigit(ch) {
            return ((ch >= 0x30 /* 0 */ && ch <= 0x39 /* 9 */) ||
                (ch >= 0x41 /* A */ && ch <= 0x46 /* F */) ||
                (ch >= 0x61 /* a */ && ch <= 0x66 /* f */));
        }
        function hexToInt(ch) {
            if (ch >= 0x41 /* A */ && ch <= 0x46 /* F */) {
                return 10 + (ch - 0x41 /* A */);
            }
            if (ch >= 0x61 /* a */ && ch <= 0x66 /* f */) {
                return 10 + (ch - 0x61 /* a */);
            }
            return ch - 0x30; /* 0 */
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-LegacyOctalEscapeSequence
        // Allows only 0-377(octal) i.e. 0-255(decimal).
        pp$1.regexp_eatLegacyOctalEscapeSequence = function (state) {
            if (this.regexp_eatOctalDigit(state)) {
                var n1 = state.lastIntValue;
                if (this.regexp_eatOctalDigit(state)) {
                    var n2 = state.lastIntValue;
                    if (n1 <= 3 && this.regexp_eatOctalDigit(state)) {
                        state.lastIntValue = n1 * 64 + n2 * 8 + state.lastIntValue;
                    }
                    else {
                        state.lastIntValue = n1 * 8 + n2;
                    }
                }
                else {
                    state.lastIntValue = n1;
                }
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-OctalDigit
        pp$1.regexp_eatOctalDigit = function (state) {
            var ch = state.current();
            if (isOctalDigit(ch)) {
                state.lastIntValue = ch - 0x30; /* 0 */
                state.advance();
                return true;
            }
            state.lastIntValue = 0;
            return false;
        };
        function isOctalDigit(ch) {
            return ch >= 0x30 /* 0 */ && ch <= 0x37; /* 7 */
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Hex4Digits
        // https://www.ecma-international.org/ecma-262/8.0/#prod-HexDigit
        // And HexDigit HexDigit in https://www.ecma-international.org/ecma-262/8.0/#prod-HexEscapeSequence
        pp$1.regexp_eatFixedHexDigits = function (state, length) {
            var start = state.pos;
            state.lastIntValue = 0;
            for (var i = 0; i < length; ++i) {
                var ch = state.current();
                if (!isHexDigit(ch)) {
                    state.pos = start;
                    return false;
                }
                state.lastIntValue = 16 * state.lastIntValue + hexToInt(ch);
                state.advance();
            }
            return true;
        };
        // Object type used to represent tokens. Note that normally, tokens
        // simply exist as properties on the parser object. This is only
        // used for the onToken callback and the external tokenizer.
        var Token = function Token(p) {
            this.type = p.type;
            this.value = p.value;
            this.start = p.start;
            this.end = p.end;
            if (p.options.locations) {
                this.loc = new SourceLocation(p, p.startLoc, p.endLoc);
            }
            if (p.options.ranges) {
                this.range = [p.start, p.end];
            }
        };
        // ## Tokenizer
        var pp = Parser.prototype;
        // Move to the next token
        pp.next = function (ignoreEscapeSequenceInKeyword) {
            if (!ignoreEscapeSequenceInKeyword && this.type.keyword && this.containsEsc) {
                this.raiseRecoverable(this.start, "Escape sequence in keyword " + this.type.keyword);
            }
            if (this.options.onToken) {
                this.options.onToken(new Token(this));
            }
            this.lastTokEnd = this.end;
            this.lastTokStart = this.start;
            this.lastTokEndLoc = this.endLoc;
            this.lastTokStartLoc = this.startLoc;
            this.nextToken();
        };
        pp.getToken = function () {
            this.next();
            return new Token(this);
        };
        // If we're in an ES6 environment, make parsers iterable
        if (typeof Symbol !== "undefined") {
            pp[Symbol.iterator] = function () {
                var this$1$1 = this;
                return {
                    next: function () {
                        var token = this$1$1.getToken();
                        return {
                            done: token.type === types$1.eof,
                            value: token
                        };
                    }
                };
            };
        }
        // Toggle strict mode. Re-reads the next number or string to please
        // pedantic tests (`"use strict"; 010;` should fail).
        // Read a single token, updating the parser object's token-related
        // properties.
        pp.nextToken = function () {
            var curContext = this.curContext();
            if (!curContext || !curContext.preserveSpace) {
                this.skipSpace();
            }
            this.start = this.pos;
            if (this.options.locations) {
                this.startLoc = this.curPosition();
            }
            if (this.pos >= this.input.length) {
                return this.finishToken(types$1.eof);
            }
            if (curContext.override) {
                return curContext.override(this);
            }
            else {
                this.readToken(this.fullCharCodeAtPos());
            }
        };
        pp.readToken = function (code) {
            // Identifier or keyword. '\uXXXX' sequences are allowed in
            // identifiers, so '\' also dispatches to that.
            if (isIdentifierStart(code, this.options.ecmaVersion >= 6) || code === 92 /* '\' */) {
                return this.readWord();
            }
            return this.getTokenFromCode(code);
        };
        pp.fullCharCodeAtPos = function () {
            var code = this.input.charCodeAt(this.pos);
            if (code <= 0xd7ff || code >= 0xdc00) {
                return code;
            }
            var next = this.input.charCodeAt(this.pos + 1);
            return next <= 0xdbff || next >= 0xe000 ? code : (code << 10) + next - 0x35fdc00;
        };
        pp.skipBlockComment = function () {
            var startLoc = this.options.onComment && this.curPosition();
            var start = this.pos, end = this.input.indexOf("*/", this.pos += 2);
            if (end === -1) {
                this.raise(this.pos - 2, "Unterminated comment");
            }
            this.pos = end + 2;
            if (this.options.locations) {
                for (var nextBreak = (void 0), pos = start; (nextBreak = nextLineBreak(this.input, pos, this.pos)) > -1;) {
                    ++this.curLine;
                    pos = this.lineStart = nextBreak;
                }
            }
            if (this.options.onComment) {
                this.options.onComment(true, this.input.slice(start + 2, end), start, this.pos, startLoc, this.curPosition());
            }
        };
        pp.skipLineComment = function (startSkip) {
            var start = this.pos;
            var startLoc = this.options.onComment && this.curPosition();
            var ch = this.input.charCodeAt(this.pos += startSkip);
            while (this.pos < this.input.length && !isNewLine(ch)) {
                ch = this.input.charCodeAt(++this.pos);
            }
            if (this.options.onComment) {
                this.options.onComment(false, this.input.slice(start + startSkip, this.pos), start, this.pos, startLoc, this.curPosition());
            }
        };
        // Called at the start of the parse and after every token. Skips
        // whitespace and comments, and.
        pp.skipSpace = function () {
            loop: while (this.pos < this.input.length) {
                var ch = this.input.charCodeAt(this.pos);
                switch (ch) {
                    case 32:
                    case 160: // ' '
                        ++this.pos;
                        break;
                    case 13:
                        if (this.input.charCodeAt(this.pos + 1) === 10) {
                            ++this.pos;
                        }
                    case 10:
                    case 8232:
                    case 8233:
                        ++this.pos;
                        if (this.options.locations) {
                            ++this.curLine;
                            this.lineStart = this.pos;
                        }
                        break;
                    case 47: // '/'
                        switch (this.input.charCodeAt(this.pos + 1)) {
                            case 42: // '*'
                                this.skipBlockComment();
                                break;
                            case 47:
                                this.skipLineComment(2);
                                break;
                            default:
                                break loop;
                        }
                        break;
                    default:
                        if (ch > 8 && ch < 14 || ch >= 5760 && nonASCIIwhitespace.test(String.fromCharCode(ch))) {
                            ++this.pos;
                        }
                        else {
                            break loop;
                        }
                }
            }
        };
        // Called at the end of every token. Sets `end`, `val`, and
        // maintains `context` and `exprAllowed`, and skips the space after
        // the token, so that the next one's `start` will point at the
        // right position.
        pp.finishToken = function (type, val) {
            this.end = this.pos;
            if (this.options.locations) {
                this.endLoc = this.curPosition();
            }
            var prevType = this.type;
            this.type = type;
            this.value = val;
            this.updateContext(prevType);
        };
        // ### Token reading
        // This is the function that is called to fetch the next token. It
        // is somewhat obscure, because it works in character codes rather
        // than characters, and because operator parsing has been inlined
        // into it.
        //
        // All in the name of speed.
        //
        pp.readToken_dot = function () {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next >= 48 && next <= 57) {
                return this.readNumber(true);
            }
            var next2 = this.input.charCodeAt(this.pos + 2);
            if (this.options.ecmaVersion >= 6 && next === 46 && next2 === 46) { // 46 = dot '.'
                this.pos += 3;
                return this.finishToken(types$1.ellipsis);
            }
            else {
                ++this.pos;
                return this.finishToken(types$1.dot);
            }
        };
        pp.readToken_slash = function () {
            var next = this.input.charCodeAt(this.pos + 1);
            if (this.exprAllowed) {
                ++this.pos;
                return this.readRegexp();
            }
            if (next === 61) {
                return this.finishOp(types$1.assign, 2);
            }
            return this.finishOp(types$1.slash, 1);
        };
        pp.readToken_mult_modulo_exp = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            var size = 1;
            var tokentype = code === 42 ? types$1.star : types$1.modulo;
            // exponentiation operator ** and **=
            if (this.options.ecmaVersion >= 7 && code === 42 && next === 42) {
                ++size;
                tokentype = types$1.starstar;
                next = this.input.charCodeAt(this.pos + 2);
            }
            if (next === 61) {
                return this.finishOp(types$1.assign, size + 1);
            }
            return this.finishOp(tokentype, size);
        };
        pp.readToken_pipe_amp = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next === code) {
                if (this.options.ecmaVersion >= 12) {
                    var next2 = this.input.charCodeAt(this.pos + 2);
                    if (next2 === 61) {
                        return this.finishOp(types$1.assign, 3);
                    }
                }
                return this.finishOp(code === 124 ? types$1.logicalOR : types$1.logicalAND, 2);
            }
            if (next === 61) {
                return this.finishOp(types$1.assign, 2);
            }
            return this.finishOp(code === 124 ? types$1.bitwiseOR : types$1.bitwiseAND, 1);
        };
        pp.readToken_caret = function () {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next === 61) {
                return this.finishOp(types$1.assign, 2);
            }
            return this.finishOp(types$1.bitwiseXOR, 1);
        };
        pp.readToken_plus_min = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next === code) {
                if (next === 45 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 62 &&
                    (this.lastTokEnd === 0 || lineBreak.test(this.input.slice(this.lastTokEnd, this.pos)))) {
                    // A `-->` line comment
                    this.skipLineComment(3);
                    this.skipSpace();
                    return this.nextToken();
                }
                return this.finishOp(types$1.incDec, 2);
            }
            if (next === 61) {
                return this.finishOp(types$1.assign, 2);
            }
            return this.finishOp(types$1.plusMin, 1);
        };
        pp.readToken_lt_gt = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            var size = 1;
            if (next === code) {
                size = code === 62 && this.input.charCodeAt(this.pos + 2) === 62 ? 3 : 2;
                if (this.input.charCodeAt(this.pos + size) === 61) {
                    return this.finishOp(types$1.assign, size + 1);
                }
                return this.finishOp(types$1.bitShift, size);
            }
            if (next === 33 && code === 60 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 45 &&
                this.input.charCodeAt(this.pos + 3) === 45) {
                // `<!--`, an XML-style comment that should be interpreted as a line comment
                this.skipLineComment(4);
                this.skipSpace();
                return this.nextToken();
            }
            if (next === 61) {
                size = 2;
            }
            return this.finishOp(types$1.relational, size);
        };
        pp.readToken_eq_excl = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next === 61) {
                return this.finishOp(types$1.equality, this.input.charCodeAt(this.pos + 2) === 61 ? 3 : 2);
            }
            if (code === 61 && next === 62 && this.options.ecmaVersion >= 6) { // '=>'
                this.pos += 2;
                return this.finishToken(types$1.arrow);
            }
            return this.finishOp(code === 61 ? types$1.eq : types$1.prefix, 1);
        };
        pp.readToken_question = function () {
            var ecmaVersion = this.options.ecmaVersion;
            if (ecmaVersion >= 11) {
                var next = this.input.charCodeAt(this.pos + 1);
                if (next === 46) {
                    var next2 = this.input.charCodeAt(this.pos + 2);
                    if (next2 < 48 || next2 > 57) {
                        return this.finishOp(types$1.questionDot, 2);
                    }
                }
                if (next === 63) {
                    if (ecmaVersion >= 12) {
                        var next2$1 = this.input.charCodeAt(this.pos + 2);
                        if (next2$1 === 61) {
                            return this.finishOp(types$1.assign, 3);
                        }
                    }
                    return this.finishOp(types$1.coalesce, 2);
                }
            }
            return this.finishOp(types$1.question, 1);
        };
        pp.readToken_numberSign = function () {
            var ecmaVersion = this.options.ecmaVersion;
            var code = 35; // '#'
            if (ecmaVersion >= 13) {
                ++this.pos;
                code = this.fullCharCodeAtPos();
                if (isIdentifierStart(code, true) || code === 92 /* '\' */) {
                    return this.finishToken(types$1.privateId, this.readWord1());
                }
            }
            this.raise(this.pos, "Unexpected character '" + codePointToString(code) + "'");
        };
        pp.getTokenFromCode = function (code) {
            switch (code) {
                // The interpretation of a dot depends on whether it is followed
                // by a digit or another two dots.
                case 46: // '.'
                    return this.readToken_dot();
                // Punctuation tokens.
                case 40:
                    ++this.pos;
                    return this.finishToken(types$1.parenL);
                case 41:
                    ++this.pos;
                    return this.finishToken(types$1.parenR);
                case 59:
                    ++this.pos;
                    return this.finishToken(types$1.semi);
                case 44:
                    ++this.pos;
                    return this.finishToken(types$1.comma);
                case 91:
                    ++this.pos;
                    return this.finishToken(types$1.bracketL);
                case 93:
                    ++this.pos;
                    return this.finishToken(types$1.bracketR);
                case 123:
                    ++this.pos;
                    return this.finishToken(types$1.braceL);
                case 125:
                    ++this.pos;
                    return this.finishToken(types$1.braceR);
                case 58:
                    ++this.pos;
                    return this.finishToken(types$1.colon);
                case 96: // '`'
                    if (this.options.ecmaVersion < 6) {
                        break;
                    }
                    ++this.pos;
                    return this.finishToken(types$1.backQuote);
                case 48: // '0'
                    var next = this.input.charCodeAt(this.pos + 1);
                    if (next === 120 || next === 88) {
                        return this.readRadixNumber(16);
                    } // '0x', '0X' - hex number
                    if (this.options.ecmaVersion >= 6) {
                        if (next === 111 || next === 79) {
                            return this.readRadixNumber(8);
                        } // '0o', '0O' - octal number
                        if (next === 98 || next === 66) {
                            return this.readRadixNumber(2);
                        } // '0b', '0B' - binary number
                    }
                // Anything else beginning with a digit is an integer, octal
                // number, or float.
                case 49:
                case 50:
                case 51:
                case 52:
                case 53:
                case 54:
                case 55:
                case 56:
                case 57: // 1-9
                    return this.readNumber(false);
                // Quotes produce strings.
                case 34:
                case 39: // '"', "'"
                    return this.readString(code);
                // Operators are parsed inline in tiny state machines. '=' (61) is
                // often referred to. `finishOp` simply skips the amount of
                // characters it is given as second argument, and returns a token
                // of the type given by its first argument.
                case 47: // '/'
                    return this.readToken_slash();
                case 37:
                case 42: // '%*'
                    return this.readToken_mult_modulo_exp(code);
                case 124:
                case 38: // '|&'
                    return this.readToken_pipe_amp(code);
                case 94: // '^'
                    return this.readToken_caret();
                case 43:
                case 45: // '+-'
                    return this.readToken_plus_min(code);
                case 60:
                case 62: // '<>'
                    return this.readToken_lt_gt(code);
                case 61:
                case 33: // '=!'
                    return this.readToken_eq_excl(code);
                case 63: // '?'
                    return this.readToken_question();
                case 126: // '~'
                    return this.finishOp(types$1.prefix, 1);
                case 35: // '#'
                    return this.readToken_numberSign();
            }
            this.raise(this.pos, "Unexpected character '" + codePointToString(code) + "'");
        };
        pp.finishOp = function (type, size) {
            var str = this.input.slice(this.pos, this.pos + size);
            this.pos += size;
            return this.finishToken(type, str);
        };
        pp.readRegexp = function () {
            var escaped, inClass, start = this.pos;
            for (;;) {
                if (this.pos >= this.input.length) {
                    this.raise(start, "Unterminated regular expression");
                }
                var ch = this.input.charAt(this.pos);
                if (lineBreak.test(ch)) {
                    this.raise(start, "Unterminated regular expression");
                }
                if (!escaped) {
                    if (ch === "[") {
                        inClass = true;
                    }
                    else if (ch === "]" && inClass) {
                        inClass = false;
                    }
                    else if (ch === "/" && !inClass) {
                        break;
                    }
                    escaped = ch === "\\";
                }
                else {
                    escaped = false;
                }
                ++this.pos;
            }
            var pattern = this.input.slice(start, this.pos);
            ++this.pos;
            var flagsStart = this.pos;
            var flags = this.readWord1();
            if (this.containsEsc) {
                this.unexpected(flagsStart);
            }
            // Validate pattern
            var state = this.regexpState || (this.regexpState = new RegExpValidationState(this));
            state.reset(start, pattern, flags);
            this.validateRegExpFlags(state);
            this.validateRegExpPattern(state);
            // Create Literal#value property value.
            var value = null;
            try {
                value = new RegExp(pattern, flags);
            }
            catch (e) {
                // ESTree requires null if it failed to instantiate RegExp object.
                // https://github.com/estree/estree/blob/a27003adf4fd7bfad44de9cef372a2eacd527b1c/es5.md#regexpliteral
            }
            return this.finishToken(types$1.regexp, { pattern: pattern, flags: flags, value: value });
        };
        // Read an integer in the given radix. Return null if zero digits
        // were read, the integer value otherwise. When `len` is given, this
        // will return `null` unless the integer has exactly `len` digits.
        pp.readInt = function (radix, len, maybeLegacyOctalNumericLiteral) {
            // `len` is used for character escape sequences. In that case, disallow separators.
            var allowSeparators = this.options.ecmaVersion >= 12 && len === undefined;
            // `maybeLegacyOctalNumericLiteral` is true if it doesn't have prefix (0x,0o,0b)
            // and isn't fraction part nor exponent part. In that case, if the first digit
            // is zero then disallow separators.
            var isLegacyOctalNumericLiteral = maybeLegacyOctalNumericLiteral && this.input.charCodeAt(this.pos) === 48;
            var start = this.pos, total = 0, lastCode = 0;
            for (var i = 0, e = len == null ? Infinity : len; i < e; ++i, ++this.pos) {
                var code = this.input.charCodeAt(this.pos), val = (void 0);
                if (allowSeparators && code === 95) {
                    if (isLegacyOctalNumericLiteral) {
                        this.raiseRecoverable(this.pos, "Numeric separator is not allowed in legacy octal numeric literals");
                    }
                    if (lastCode === 95) {
                        this.raiseRecoverable(this.pos, "Numeric separator must be exactly one underscore");
                    }
                    if (i === 0) {
                        this.raiseRecoverable(this.pos, "Numeric separator is not allowed at the first of digits");
                    }
                    lastCode = code;
                    continue;
                }
                if (code >= 97) {
                    val = code - 97 + 10;
                } // a
                else if (code >= 65) {
                    val = code - 65 + 10;
                } // A
                else if (code >= 48 && code <= 57) {
                    val = code - 48;
                } // 0-9
                else {
                    val = Infinity;
                }
                if (val >= radix) {
                    break;
                }
                lastCode = code;
                total = total * radix + val;
            }
            if (allowSeparators && lastCode === 95) {
                this.raiseRecoverable(this.pos - 1, "Numeric separator is not allowed at the last of digits");
            }
            if (this.pos === start || len != null && this.pos - start !== len) {
                return null;
            }
            return total;
        };
        function stringToNumber(str, isLegacyOctalNumericLiteral) {
            if (isLegacyOctalNumericLiteral) {
                return parseInt(str, 8);
            }
            // `parseFloat(value)` stops parsing at the first numeric separator then returns a wrong value.
            return parseFloat(str.replace(/_/g, ""));
        }
        function stringToBigInt(str) {
            if (typeof BigInt !== "function") {
                return null;
            }
            // `BigInt(value)` throws syntax error if the string contains numeric separators.
            return BigInt(str.replace(/_/g, ""));
        }
        pp.readRadixNumber = function (radix) {
            var start = this.pos;
            this.pos += 2; // 0x
            var val = this.readInt(radix);
            if (val == null) {
                this.raise(this.start + 2, "Expected number in radix " + radix);
            }
            if (this.options.ecmaVersion >= 11 && this.input.charCodeAt(this.pos) === 110) {
                val = stringToBigInt(this.input.slice(start, this.pos));
                ++this.pos;
            }
            else if (isIdentifierStart(this.fullCharCodeAtPos())) {
                this.raise(this.pos, "Identifier directly after number");
            }
            return this.finishToken(types$1.num, val);
        };
        // Read an integer, octal integer, or floating-point number.
        pp.readNumber = function (startsWithDot) {
            var start = this.pos;
            if (!startsWithDot && this.readInt(10, undefined, true) === null) {
                this.raise(start, "Invalid number");
            }
            var octal = this.pos - start >= 2 && this.input.charCodeAt(start) === 48;
            if (octal && this.strict) {
                this.raise(start, "Invalid number");
            }
            var next = this.input.charCodeAt(this.pos);
            if (!octal && !startsWithDot && this.options.ecmaVersion >= 11 && next === 110) {
                var val$1 = stringToBigInt(this.input.slice(start, this.pos));
                ++this.pos;
                if (isIdentifierStart(this.fullCharCodeAtPos())) {
                    this.raise(this.pos, "Identifier directly after number");
                }
                return this.finishToken(types$1.num, val$1);
            }
            if (octal && /[89]/.test(this.input.slice(start, this.pos))) {
                octal = false;
            }
            if (next === 46 && !octal) { // '.'
                ++this.pos;
                this.readInt(10);
                next = this.input.charCodeAt(this.pos);
            }
            if ((next === 69 || next === 101) && !octal) { // 'eE'
                next = this.input.charCodeAt(++this.pos);
                if (next === 43 || next === 45) {
                    ++this.pos;
                } // '+-'
                if (this.readInt(10) === null) {
                    this.raise(start, "Invalid number");
                }
            }
            if (isIdentifierStart(this.fullCharCodeAtPos())) {
                this.raise(this.pos, "Identifier directly after number");
            }
            var val = stringToNumber(this.input.slice(start, this.pos), octal);
            return this.finishToken(types$1.num, val);
        };
        // Read a string value, interpreting backslash-escapes.
        pp.readCodePoint = function () {
            var ch = this.input.charCodeAt(this.pos), code;
            if (ch === 123) { // '{'
                if (this.options.ecmaVersion < 6) {
                    this.unexpected();
                }
                var codePos = ++this.pos;
                code = this.readHexChar(this.input.indexOf("}", this.pos) - this.pos);
                ++this.pos;
                if (code > 0x10FFFF) {
                    this.invalidStringToken(codePos, "Code point out of bounds");
                }
            }
            else {
                code = this.readHexChar(4);
            }
            return code;
        };
        pp.readString = function (quote) {
            var out = "", chunkStart = ++this.pos;
            for (;;) {
                if (this.pos >= this.input.length) {
                    this.raise(this.start, "Unterminated string constant");
                }
                var ch = this.input.charCodeAt(this.pos);
                if (ch === quote) {
                    break;
                }
                if (ch === 92) { // '\'
                    out += this.input.slice(chunkStart, this.pos);
                    out += this.readEscapedChar(false);
                    chunkStart = this.pos;
                }
                else if (ch === 0x2028 || ch === 0x2029) {
                    if (this.options.ecmaVersion < 10) {
                        this.raise(this.start, "Unterminated string constant");
                    }
                    ++this.pos;
                    if (this.options.locations) {
                        this.curLine++;
                        this.lineStart = this.pos;
                    }
                }
                else {
                    if (isNewLine(ch)) {
                        this.raise(this.start, "Unterminated string constant");
                    }
                    ++this.pos;
                }
            }
            out += this.input.slice(chunkStart, this.pos++);
            return this.finishToken(types$1.string, out);
        };
        // Reads template string tokens.
        var INVALID_TEMPLATE_ESCAPE_ERROR = {};
        pp.tryReadTemplateToken = function () {
            this.inTemplateElement = true;
            try {
                this.readTmplToken();
            }
            catch (err) {
                if (err === INVALID_TEMPLATE_ESCAPE_ERROR) {
                    this.readInvalidTemplateToken();
                }
                else {
                    throw err;
                }
            }
            this.inTemplateElement = false;
        };
        pp.invalidStringToken = function (position, message) {
            if (this.inTemplateElement && this.options.ecmaVersion >= 9) {
                throw INVALID_TEMPLATE_ESCAPE_ERROR;
            }
            else {
                this.raise(position, message);
            }
        };
        pp.readTmplToken = function () {
            var out = "", chunkStart = this.pos;
            for (;;) {
                if (this.pos >= this.input.length) {
                    this.raise(this.start, "Unterminated template");
                }
                var ch = this.input.charCodeAt(this.pos);
                if (ch === 96 || ch === 36 && this.input.charCodeAt(this.pos + 1) === 123) { // '`', '${'
                    if (this.pos === this.start && (this.type === types$1.template || this.type === types$1.invalidTemplate)) {
                        if (ch === 36) {
                            this.pos += 2;
                            return this.finishToken(types$1.dollarBraceL);
                        }
                        else {
                            ++this.pos;
                            return this.finishToken(types$1.backQuote);
                        }
                    }
                    out += this.input.slice(chunkStart, this.pos);
                    return this.finishToken(types$1.template, out);
                }
                if (ch === 92) { // '\'
                    out += this.input.slice(chunkStart, this.pos);
                    out += this.readEscapedChar(true);
                    chunkStart = this.pos;
                }
                else if (isNewLine(ch)) {
                    out += this.input.slice(chunkStart, this.pos);
                    ++this.pos;
                    switch (ch) {
                        case 13:
                            if (this.input.charCodeAt(this.pos) === 10) {
                                ++this.pos;
                            }
                        case 10:
                            out += "\n";
                            break;
                        default:
                            out += String.fromCharCode(ch);
                            break;
                    }
                    if (this.options.locations) {
                        ++this.curLine;
                        this.lineStart = this.pos;
                    }
                    chunkStart = this.pos;
                }
                else {
                    ++this.pos;
                }
            }
        };
        // Reads a template token to search for the end, without validating any escape sequences
        pp.readInvalidTemplateToken = function () {
            for (; this.pos < this.input.length; this.pos++) {
                switch (this.input[this.pos]) {
                    case "\\":
                        ++this.pos;
                        break;
                    case "$":
                        if (this.input[this.pos + 1] !== "{") {
                            break;
                        }
                    // falls through
                    case "`":
                        return this.finishToken(types$1.invalidTemplate, this.input.slice(this.start, this.pos));
                    // no default
                }
            }
            this.raise(this.start, "Unterminated template");
        };
        // Used to read escaped characters
        pp.readEscapedChar = function (inTemplate) {
            var ch = this.input.charCodeAt(++this.pos);
            ++this.pos;
            switch (ch) {
                case 110: return "\n"; // 'n' -> '\n'
                case 114: return "\r"; // 'r' -> '\r'
                case 120: return String.fromCharCode(this.readHexChar(2)); // 'x'
                case 117: return codePointToString(this.readCodePoint()); // 'u'
                case 116: return "\t"; // 't' -> '\t'
                case 98: return "\b"; // 'b' -> '\b'
                case 118: return "\u000b"; // 'v' -> '\u000b'
                case 102: return "\f"; // 'f' -> '\f'
                case 13: if (this.input.charCodeAt(this.pos) === 10) {
                    ++this.pos;
                } // '\r\n'
                case 10: // ' \n'
                    if (this.options.locations) {
                        this.lineStart = this.pos;
                        ++this.curLine;
                    }
                    return "";
                case 56:
                case 57:
                    if (this.strict) {
                        this.invalidStringToken(this.pos - 1, "Invalid escape sequence");
                    }
                    if (inTemplate) {
                        var codePos = this.pos - 1;
                        this.invalidStringToken(codePos, "Invalid escape sequence in template string");
                    }
                default:
                    if (ch >= 48 && ch <= 55) {
                        var octalStr = this.input.substr(this.pos - 1, 3).match(/^[0-7]+/)[0];
                        var octal = parseInt(octalStr, 8);
                        if (octal > 255) {
                            octalStr = octalStr.slice(0, -1);
                            octal = parseInt(octalStr, 8);
                        }
                        this.pos += octalStr.length - 1;
                        ch = this.input.charCodeAt(this.pos);
                        if ((octalStr !== "0" || ch === 56 || ch === 57) && (this.strict || inTemplate)) {
                            this.invalidStringToken(this.pos - 1 - octalStr.length, inTemplate
                                ? "Octal literal in template string"
                                : "Octal literal in strict mode");
                        }
                        return String.fromCharCode(octal);
                    }
                    if (isNewLine(ch)) {
                        // Unicode new line characters after \ get removed from output in both
                        // template literals and strings
                        return "";
                    }
                    return String.fromCharCode(ch);
            }
        };
        // Used to read character escape sequences ('\x', '\u', '\U').
        pp.readHexChar = function (len) {
            var codePos = this.pos;
            var n = this.readInt(16, len);
            if (n === null) {
                this.invalidStringToken(codePos, "Bad character escape sequence");
            }
            return n;
        };
        // Read an identifier, and return it as a string. Sets `this.containsEsc`
        // to whether the word contained a '\u' escape.
        //
        // Incrementally adds only escaped chars, adding other chunks as-is
        // as a micro-optimization.
        pp.readWord1 = function () {
            this.containsEsc = false;
            var word = "", first = true, chunkStart = this.pos;
            var astral = this.options.ecmaVersion >= 6;
            while (this.pos < this.input.length) {
                var ch = this.fullCharCodeAtPos();
                if (isIdentifierChar(ch, astral)) {
                    this.pos += ch <= 0xffff ? 1 : 2;
                }
                else if (ch === 92) { // "\"
                    this.containsEsc = true;
                    word += this.input.slice(chunkStart, this.pos);
                    var escStart = this.pos;
                    if (this.input.charCodeAt(++this.pos) !== 117) // "u"
                     {
                        this.invalidStringToken(this.pos, "Expecting Unicode escape sequence \\uXXXX");
                    }
                    ++this.pos;
                    var esc = this.readCodePoint();
                    if (!(first ? isIdentifierStart : isIdentifierChar)(esc, astral)) {
                        this.invalidStringToken(escStart, "Invalid Unicode escape");
                    }
                    word += codePointToString(esc);
                    chunkStart = this.pos;
                }
                else {
                    break;
                }
                first = false;
            }
            return word + this.input.slice(chunkStart, this.pos);
        };
        // Read an identifier or keyword token. Will check for reserved
        // words when necessary.
        pp.readWord = function () {
            var word = this.readWord1();
            var type = types$1.name;
            if (this.keywords.test(word)) {
                type = keywords[word];
            }
            return this.finishToken(type, word);
        };
        // Acorn is a tiny, fast JavaScript parser written in JavaScript.
        var version = "8.8.2";
        Parser.acorn = {
            Parser: Parser,
            version: version,
            defaultOptions: defaultOptions,
            Position: Position,
            SourceLocation: SourceLocation,
            getLineInfo: getLineInfo,
            Node: Node,
            TokenType: TokenType,
            tokTypes: types$1,
            keywordTypes: keywords,
            TokContext: TokContext,
            tokContexts: types,
            isIdentifierChar: isIdentifierChar,
            isIdentifierStart: isIdentifierStart,
            Token: Token,
            isNewLine: isNewLine,
            lineBreak: lineBreak,
            lineBreakG: lineBreakG,
            nonASCIIwhitespace: nonASCIIwhitespace
        };
        // The main exported interface (under `self.acorn` when in the
        // browser) is a `parse` function that takes a code string and
        // returns an abstract syntax tree as specified by [Mozilla parser
        // API][api].
        //
        // [api]: https://developer.mozilla.org/en-US/docs/SpiderMonkey/Parser_API
        function parse(input, options) {
            return Parser.parse(input, options);
        }
        // This function tries to parse a single expression at a given
        // offset in a string. Useful for parsing mixed-language formats
        // that embed JavaScript expressions.
        function parseExpressionAt(input, pos, options) {
            return Parser.parseExpressionAt(input, pos, options);
        }
        // Acorn is organized as a tokenizer and a recursive-descent parser.
        // The `tokenizer` export provides an interface to the tokenizer.
        function tokenizer(input, options) {
            return Parser.tokenizer(input, options);
        }
        exports.Node = Node;
        exports.Parser = Parser;
        exports.Position = Position;
        exports.SourceLocation = SourceLocation;
        exports.TokContext = TokContext;
        exports.Token = Token;
        exports.TokenType = TokenType;
        exports.defaultOptions = defaultOptions;
        exports.getLineInfo = getLineInfo;
        exports.isIdentifierChar = isIdentifierChar;
        exports.isIdentifierStart = isIdentifierStart;
        exports.isNewLine = isNewLine;
        exports.keywordTypes = keywords;
        exports.lineBreak = lineBreak;
        exports.lineBreakG = lineBreakG;
        exports.nonASCIIwhitespace = nonASCIIwhitespace;
        exports.parse = parse;
        exports.parseExpressionAt = parseExpressionAt;
        exports.tokContexts = types;
        exports.tokTypes = types$1;
        exports.tokenizer = tokenizer;
        exports.version = version;
    }));
},
/* combine-source-map/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var path = require('path');
    var convert = require(49) /* convert-source-map */;
    var memoize = require(50) /* lodash.memoize */;
    var createGenerator = require(51) /* inline-source-map */;
    var pathIsAbsolute = require(52) /* ./lib/path-is-absolute */;
    var mappingsFromMap = require(53) /* ./lib/mappings-from-map */;
    var protocolRx = /^[a-z]+:\/\//;
    /**
     * Rebases a relative path in 'sourceFile' to be relative
     * to the path where 'sourceFile' is located.
     *
     * This is necessary before adding relative paths to the
     * new combined map to ensure all paths are relative to their
     * original source.
     *
     * The 'sourceRoot' from the original source map is joined
     * as well to ensure the complete path.
     *
     * Resulting paths that are absolute are passed along directly.
     *
     * @param sourceFile {String} path to the original source file that references a map
     * @param relativeRoot {String} sourceRoot in sourceFile's map to combine with relativePath
     * @param relativePath {String} source path from sourceFile's map
     */
    var rebaseRelativePath = memoize(function (sourceFile, relativeRoot, relativePath) {
        if (!relativePath) {
            return relativePath;
        }
        // join relative path to root (e.g. 'src/' + 'file.js')
        var relativeRootedPath = relativeRoot ? path.join(relativeRoot, relativePath) : relativePath;
        relativeRootedPath = relativeRootedPath.replace(/\\/g, '/');
        sourceFile = sourceFile.replace(/\\/g, '/');
        if (sourceFile === relativeRootedPath || // same path,
            pathIsAbsolute(relativeRootedPath) || // absolute path, nor
            protocolRx.test(relativeRootedPath)) { // absolute protocol need rebasing
            return relativeRootedPath;
        }
        // make relative to source file
        return path.join(path.dirname(sourceFile), relativeRootedPath).replace(/\\/g, '/');
    }, function (a, b, c) {
        return a + '::' + b + '::' + c;
    });
    function resolveMap(source) {
        var gen = convert.fromSource(source);
        return gen ? gen.toObject() : null;
    }
    function hasInlinedSource(existingMap) {
        return existingMap.sourcesContent && !!existingMap.sourcesContent[0];
    }
    function Combiner(file, sourceRoot) {
        // since we include the original code in the map sourceRoot actually not needed
        this.generator = createGenerator({ file: file || 'generated.js', sourceRoot: sourceRoot });
    }
    Combiner.prototype._addGeneratedMap = function (sourceFile, source, offset) {
        this.generator.addGeneratedMappings(sourceFile, source, offset);
        this.generator.addSourceContent(sourceFile, source);
        return this;
    };
    Combiner.prototype._addExistingMap = function (sourceFile, source, existingMap, offset) {
        var mappings = mappingsFromMap(existingMap);
        // add all of the sources from the map
        for (var i = 0, len = existingMap.sources.length; i < len; i++) {
            if (!existingMap.sourcesContent)
                continue;
            this.generator.addSourceContent(rebaseRelativePath(sourceFile, existingMap.sourceRoot, existingMap.sources[i]), existingMap.sourcesContent[i]);
        }
        // add the mappings, preserving the original mapping 'source'
        mappings.forEach(function (mapping) {
            // Add the mappings one at a time because 'inline-source-map' doesn't handle
            // mapping source filenames. The mapping.source already takes sourceRoot into account
            // per the SMConsumer.eachMapping function, so pass null for the root here.
            this.generator.addMappings(rebaseRelativePath(sourceFile, null, mapping.source), [mapping], offset);
        }, this);
        return this;
    };
    /**
     * Adds map to underlying source map.
     * If source contains a source map comment that has the source of the original file inlined it will offset these
     * mappings and include them.
     * If no source map comment is found or it has no source inlined, mappings for the file will be generated and included
     *
     * @name addMap
     * @function
     * @param opts {Object} { sourceFile: {String}, source: {String} }
     * @param offset {Object} { line: {Number}, column: {Number} }
     */
    Combiner.prototype.addFile = function (opts, offset) {
        offset = offset || {};
        if (!offset.hasOwnProperty('line'))
            offset.line = 0;
        if (!offset.hasOwnProperty('column'))
            offset.column = 0;
        var existingMap = resolveMap(opts.source);
        return existingMap && hasInlinedSource(existingMap)
            ? this._addExistingMap(opts.sourceFile, opts.source, existingMap, offset)
            : this._addGeneratedMap(opts.sourceFile, opts.source, offset);
    };
    /**
    * @name base64
    * @function
    * @return {String} base64 encoded combined source map
    */
    Combiner.prototype.base64 = function () {
        return this.generator.base64Encode();
    };
    /**
     * @name comment
     * @function
     * @return {String} base64 encoded sourceMappingUrl comment of the combined source map
     */
    Combiner.prototype.comment = function () {
        return this.generator.inlineMappingUrl();
    };
    /**
     * @name create
     * @function
     * @param file {String} optional name of the generated file
     * @param sourceRoot {String} optional sourceRoot of the map to be generated
     * @return {Object} Combiner instance to which source maps can be added and later combined
     */
    exports.create = function (file, sourceRoot) { return new Combiner(file, sourceRoot); };
    /**
     * @name removeComments
     * @function
     * @param src
     * @return {String} src with all sourceMappingUrl comments removed
     */
    exports.removeComments = function (src) {
        if (!src.replace)
            return src;
        return src.replace(convert.commentRegex, '').replace(convert.mapFileCommentRegex, '');
    };
},
/* convert-source-map/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, 'commentRegex', {
        get: function getCommentRegex() {
            // Groups: 1: media type, 2: MIME type, 3: charset, 4: encoding, 5: data.
            return /^\s*?\/[\/\*][@#]\s+?sourceMappingURL=data:(((?:application|text)\/json)(?:;charset=([^;,]+?)?)?)?(?:;(base64))?,(.*?)$/mg;
        }
    });
    Object.defineProperty(exports, 'mapFileCommentRegex', {
        get: function getMapFileCommentRegex() {
            // Matches sourceMappingURL in either // or /* comment styles.
            return /(?:\/\/[@#][ \t]+?sourceMappingURL=([^\s'"`]+?)[ \t]*?$)|(?:\/\*[@#][ \t]+sourceMappingURL=([^*]+?)[ \t]*?(?:\*\/){1}[ \t]*?$)/mg;
        }
    });
    var decodeBase64;
    if (typeof Buffer !== 'undefined') {
        if (typeof Buffer.from === 'function') {
            decodeBase64 = decodeBase64WithBufferFrom;
        }
        else {
            decodeBase64 = decodeBase64WithNewBuffer;
        }
    }
    else {
        decodeBase64 = decodeBase64WithAtob;
    }
    function decodeBase64WithBufferFrom(base64) {
        return Buffer.from(base64, 'base64').toString();
    }
    function decodeBase64WithNewBuffer(base64) {
        if (typeof value === 'number') {
            throw new TypeError('The value to decode must not be of type number.');
        }
        return new Buffer(base64, 'base64').toString();
    }
    function decodeBase64WithAtob(base64) {
        return decodeURIComponent(escape(atob(base64)));
    }
    function stripComment(sm) {
        return sm.split(',').pop();
    }
    function readFromFileMap(sm, read) {
        var r = exports.mapFileCommentRegex.exec(sm);
        // for some odd reason //# .. captures in 1 and /* .. */ in 2
        var filename = r[1] || r[2];
        try {
            var sm = read(filename);
            if (sm != null && typeof sm.catch === 'function') {
                return sm.catch(throwError);
            }
            else {
                return sm;
            }
        }
        catch (e) {
            throwError(e);
        }
        function throwError(e) {
            throw new Error('An error occurred while trying to read the map file at ' + filename + '\n' + e.stack);
        }
    }
    function Converter(sm, opts) {
        opts = opts || {};
        if (opts.hasComment) {
            sm = stripComment(sm);
        }
        if (opts.encoding === 'base64') {
            sm = decodeBase64(sm);
        }
        else if (opts.encoding === 'uri') {
            sm = decodeURIComponent(sm);
        }
        if (opts.isJSON || opts.encoding) {
            sm = JSON.parse(sm);
        }
        this.sourcemap = sm;
    }
    Converter.prototype.toJSON = function (space) {
        return JSON.stringify(this.sourcemap, null, space);
    };
    if (typeof Buffer !== 'undefined') {
        if (typeof Buffer.from === 'function') {
            Converter.prototype.toBase64 = encodeBase64WithBufferFrom;
        }
        else {
            Converter.prototype.toBase64 = encodeBase64WithNewBuffer;
        }
    }
    else {
        Converter.prototype.toBase64 = encodeBase64WithBtoa;
    }
    function encodeBase64WithBufferFrom() {
        var json = this.toJSON();
        return Buffer.from(json, 'utf8').toString('base64');
    }
    function encodeBase64WithNewBuffer() {
        var json = this.toJSON();
        if (typeof json === 'number') {
            throw new TypeError('The json to encode must not be of type number.');
        }
        return new Buffer(json, 'utf8').toString('base64');
    }
    function encodeBase64WithBtoa() {
        var json = this.toJSON();
        return btoa(unescape(encodeURIComponent(json)));
    }
    Converter.prototype.toURI = function () {
        var json = this.toJSON();
        return encodeURIComponent(json);
    };
    Converter.prototype.toComment = function (options) {
        var encoding, content, data;
        if (options != null && options.encoding === 'uri') {
            encoding = '';
            content = this.toURI();
        }
        else {
            encoding = ';base64';
            content = this.toBase64();
        }
        data = 'sourceMappingURL=data:application/json;charset=utf-8' + encoding + ',' + content;
        return options != null && options.multiline ? '/*# ' + data + ' */' : '//# ' + data;
    };
    // returns copy instead of original
    Converter.prototype.toObject = function () {
        return JSON.parse(this.toJSON());
    };
    Converter.prototype.addProperty = function (key, value) {
        if (this.sourcemap.hasOwnProperty(key))
            throw new Error('property "' + key + '" already exists on the sourcemap, use set property instead');
        return this.setProperty(key, value);
    };
    Converter.prototype.setProperty = function (key, value) {
        this.sourcemap[key] = value;
        return this;
    };
    Converter.prototype.getProperty = function (key) {
        return this.sourcemap[key];
    };
    exports.fromObject = function (obj) {
        return new Converter(obj);
    };
    exports.fromJSON = function (json) {
        return new Converter(json, { isJSON: true });
    };
    exports.fromURI = function (uri) {
        return new Converter(uri, { encoding: 'uri' });
    };
    exports.fromBase64 = function (base64) {
        return new Converter(base64, { encoding: 'base64' });
    };
    exports.fromComment = function (comment) {
        var m, encoding;
        comment = comment
            .replace(/^\/\*/g, '//')
            .replace(/\*\/$/g, '');
        m = exports.commentRegex.exec(comment);
        encoding = m && m[4] || 'uri';
        return new Converter(comment, { encoding: encoding, hasComment: true });
    };
    function makeConverter(sm) {
        return new Converter(sm, { isJSON: true });
    }
    exports.fromMapFileComment = function (comment, read) {
        if (typeof read === 'string') {
            throw new Error('String directory paths are no longer supported with `fromMapFileComment`\n' +
                'Please review the Upgrading documentation at https://github.com/thlorenz/convert-source-map#upgrading');
        }
        var sm = readFromFileMap(comment, read);
        if (sm != null && typeof sm.then === 'function') {
            return sm.then(makeConverter);
        }
        else {
            return makeConverter(sm);
        }
    };
    // Finds last sourcemap comment in file or returns null if none was found
    exports.fromSource = function (content) {
        var m = content.match(exports.commentRegex);
        return m ? exports.fromComment(m.pop()) : null;
    };
    // Finds last sourcemap comment in file or returns null if none was found
    exports.fromMapFileSource = function (content, read) {
        if (typeof read === 'string') {
            throw new Error('String directory paths are no longer supported with `fromMapFileSource`\n' +
                'Please review the Upgrading documentation at https://github.com/thlorenz/convert-source-map#upgrading');
        }
        var m = content.match(exports.mapFileCommentRegex);
        return m ? exports.fromMapFileComment(m.pop(), read) : null;
    };
    exports.removeComments = function (src) {
        return src.replace(exports.commentRegex, '');
    };
    exports.removeMapFileComments = function (src) {
        return src.replace(exports.mapFileCommentRegex, '');
    };
    exports.generateMapFileComment = function (file, options) {
        var data = 'sourceMappingURL=' + file;
        return options && options.multiline ? '/*# ' + data + ' */' : '//# ' + data;
    };
},
/* lodash.memoize/index.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * lodash 3.0.4 (Custom Build) <https://lodash.com/>
     * Build: `lodash modern modularize exports="npm" -o ./`
     * Copyright 2012-2015 The Dojo Foundation <http://dojofoundation.org/>
     * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
     * Copyright 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
     * Available under MIT license <https://lodash.com/license>
     */
    /** Used as the `TypeError` message for "Functions" methods. */
    var FUNC_ERROR_TEXT = 'Expected a function';
    /** Used for native method references. */
    var objectProto = Object.prototype;
    /** Used to check objects for own properties. */
    var hasOwnProperty = objectProto.hasOwnProperty;
    /**
     * Creates a cache object to store key/value pairs.
     *
     * @private
     * @static
     * @name Cache
     * @memberOf _.memoize
     */
    function MapCache() {
        this.__data__ = {};
    }
    /**
     * Removes `key` and its value from the cache.
     *
     * @private
     * @name delete
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed successfully, else `false`.
     */
    function mapDelete(key) {
        return this.has(key) && delete this.__data__[key];
    }
    /**
     * Gets the cached value for `key`.
     *
     * @private
     * @name get
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the cached value.
     */
    function mapGet(key) {
        return key == '__proto__' ? undefined : this.__data__[key];
    }
    /**
     * Checks if a cached value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function mapHas(key) {
        return key != '__proto__' && hasOwnProperty.call(this.__data__, key);
    }
    /**
     * Sets `value` to `key` of the cache.
     *
     * @private
     * @name set
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the value to cache.
     * @param {*} value The value to cache.
     * @returns {Object} Returns the cache object.
     */
    function mapSet(key, value) {
        if (key != '__proto__') {
            this.__data__[key] = value;
        }
        return this;
    }
    /**
     * Creates a function that memoizes the result of `func`. If `resolver` is
     * provided it determines the cache key for storing the result based on the
     * arguments provided to the memoized function. By default, the first argument
     * provided to the memoized function is coerced to a string and used as the
     * cache key. The `func` is invoked with the `this` binding of the memoized
     * function.
     *
     * **Note:** The cache is exposed as the `cache` property on the memoized
     * function. Its creation may be customized by replacing the `_.memoize.Cache`
     * constructor with one whose instances implement the [`Map`](https://people.mozilla.org/~jorendorff/es6-draft.html#sec-properties-of-the-map-prototype-object)
     * method interface of `get`, `has`, and `set`.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to have its output memoized.
     * @param {Function} [resolver] The function to resolve the cache key.
     * @returns {Function} Returns the new memoizing function.
     * @example
     *
     * var upperCase = _.memoize(function(string) {
     *   return string.toUpperCase();
     * });
     *
     * upperCase('fred');
     * // => 'FRED'
     *
     * // modifying the result cache
     * upperCase.cache.set('fred', 'BARNEY');
     * upperCase('fred');
     * // => 'BARNEY'
     *
     * // replacing `_.memoize.Cache`
     * var object = { 'user': 'fred' };
     * var other = { 'user': 'barney' };
     * var identity = _.memoize(_.identity);
     *
     * identity(object);
     * // => { 'user': 'fred' }
     * identity(other);
     * // => { 'user': 'fred' }
     *
     * _.memoize.Cache = WeakMap;
     * var identity = _.memoize(_.identity);
     *
     * identity(object);
     * // => { 'user': 'fred' }
     * identity(other);
     * // => { 'user': 'barney' }
     */
    function memoize(func, resolver) {
        if (typeof func != 'function' || (resolver && typeof resolver != 'function')) {
            throw new TypeError(FUNC_ERROR_TEXT);
        }
        var memoized = function () {
            var args = arguments, key = resolver ? resolver.apply(this, args) : args[0], cache = memoized.cache;
            if (cache.has(key)) {
                return cache.get(key);
            }
            var result = func.apply(this, args);
            memoized.cache = cache.set(key, result);
            return result;
        };
        memoized.cache = new memoize.Cache;
        return memoized;
    }
    // Add functions to the `Map` cache.
    MapCache.prototype['delete'] = mapDelete;
    MapCache.prototype.get = mapGet;
    MapCache.prototype.has = mapHas;
    MapCache.prototype.set = mapSet;
    // Assign cache to `_.memoize`.
    memoize.Cache = MapCache;
    module.exports = memoize;
},
/* inline-source-map/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var SourceMapGenerator = require(23) /* source-map */.SourceMapGenerator;
    function offsetMapping(mapping, offset) {
        return { line: offset.line + mapping.line, column: offset.column + mapping.column };
    }
    function newlinesIn(src) {
        if (!src)
            return 0;
        var newlines = src.match(/\n/g);
        return newlines ? newlines.length : 0;
    }
    function Generator(opts) {
        opts = opts || {};
        this.generator = new SourceMapGenerator({ file: opts.file || '', sourceRoot: opts.sourceRoot || '' });
        this.sourcesContent = undefined;
        this.opts = opts;
    }
    /**
     * Adds the given mappings to the generator and offsets them if offset is given
     *
     * @name addMappings
     * @function
     * @param sourceFile {String} name of the source file
     * @param mappings {Array{{Object}} each object has the form { original: { line: _, column: _ }, generated: { line: _, column: _ } }
     * @param offset {Object} offset to apply to each mapping. Has the form { line: _, column: _ }
     * @return {Object} the generator to allow chaining
     */
    Generator.prototype.addMappings = function (sourceFile, mappings, offset) {
        var generator = this.generator;
        offset = offset || {};
        offset.line = offset.hasOwnProperty('line') ? offset.line : 0;
        offset.column = offset.hasOwnProperty('column') ? offset.column : 0;
        mappings.forEach(function (m) {
            // only set source if we have original position to handle edgecase (see inline-source-map tests)
            generator.addMapping({
                source: m.original ? sourceFile : undefined,
                original: m.original,
                generated: offsetMapping(m.generated, offset)
            });
        });
        return this;
    };
    /**
     * Generates mappings for the given source, assuming that no translation from original to generated is necessary.
     *
     * @name addGeneratedMappings
     * @function
     * @param sourceFile {String} name of the source file
     * @param source {String} source of the file
     * @param offset {Object} offset to apply to each mapping. Has the form { line: _, column: _ }
     * @return {Object} the generator to allow chaining
     */
    Generator.prototype.addGeneratedMappings = function (sourceFile, source, offset) {
        var mappings = [], linesToGenerate = newlinesIn(source) + 1;
        for (var line = 1; line <= linesToGenerate; line++) {
            var location = { line: line, column: 0 };
            mappings.push({ original: location, generated: location });
        }
        return this.addMappings(sourceFile, mappings, offset);
    };
    /**
     * Adds source content for the given source file.
     *
     * @name addSourceContent
     * @function
     * @param sourceFile {String} The source file for which a mapping is included
     * @param sourcesContent {String} The content of the source file
     * @return {Object} The generator to allow chaining
     */
    Generator.prototype.addSourceContent = function (sourceFile, sourcesContent) {
        this.sourcesContent = this.sourcesContent || {};
        this.sourcesContent[sourceFile] = sourcesContent;
        return this;
    };
    /**
     * @name base64Encode
     * @function
     * @return {String} bas64 encoded representation of the added mappings
     */
    Generator.prototype.base64Encode = function () {
        var map = this.toString();
        return new Buffer(map).toString('base64');
    };
    /**
     * @name inlineMappingUrl
     * @function
     * @return {String} comment with base64 encoded representation of the added mappings. Can be inlined at the end of the generated file.
     */
    Generator.prototype.inlineMappingUrl = function () {
        var charset = this.opts.charset || 'utf-8';
        return '//# sourceMappingURL=data:application/json;charset=' + charset + ';base64,' + this.base64Encode();
    };
    Generator.prototype.toJSON = function () {
        var map = this.generator.toJSON();
        if (!this.sourcesContent)
            return map;
        var toSourcesContent = (function (s) {
            if (typeof this.sourcesContent[s] === 'string') {
                return this.sourcesContent[s];
            }
            else {
                return null;
            }
        }).bind(this);
        map.sourcesContent = map.sources.map(toSourcesContent);
        return map;
    };
    Generator.prototype.toString = function () {
        return JSON.stringify(this);
    };
    Generator.prototype._mappings = function () {
        return this.generator._mappings._array;
    };
    Generator.prototype.gen = function () {
        return this.generator;
    };
    module.exports = function (opts) { return new Generator(opts); };
    module.exports.Generator = Generator;
},
/* combine-source-map/lib/path-is-absolute.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    function posix(path) {
        return path.charAt(0) === '/';
    }
    ;
    function win32(path) {
        // https://github.com/joyent/node/blob/b3fcc245fb25539909ef1d5eaa01dbf92e168633/lib/path.js#L56
        var splitDeviceRe = /^([a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/]+[^\\\/]+)?([\\\/])?([\s\S]*?)$/;
        var result = splitDeviceRe.exec(path);
        var device = result[1] || '';
        var isUnc = !!device && device.charAt(1) !== ':';
        // UNC paths are always absolute
        return !!result[2] || isUnc;
    }
    ;
    module.exports = process.platform === 'win32' ? win32 : posix;
    module.exports.posix = posix;
    module.exports.win32 = win32;
},
/* combine-source-map/lib/mappings-from-map.js */ function _(require, module, exports, __esModule, __esExport) {
    var SMConsumer = require(23) /* source-map */.SourceMapConsumer;
    /**
     * @name mappingsFromMap
     * @function
     * @param map {Object} the JSON.parse()'ed map
     * @return {Array} array of mappings
     */
    module.exports = function (map) {
        var consumer = new SMConsumer(map);
        var mappings = [];
        consumer.eachMapping(function (mapping) {
            // only set source if we have original position to handle edgecase (see inline-source-map tests)
            mappings.push({
                original: mapping.originalColumn != null ? {
                    column: mapping.originalColumn,
                    line: mapping.originalLine
                } : undefined,
                generated: {
                    column: mapping.generatedColumn,
                    line: mapping.generatedLine
                },
                source: mapping.originalColumn != null ? mapping.source : undefined,
                name: mapping.name
            });
        });
        return mappings;
    };
},
/* graph.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.detect_cycles = void 0;
    function detect_cycles(graph) {
        const cycles = [];
        const state = new Map();
        for (const node of graph.keys()) {
            state.set(node, { visited: false, explored: false });
        }
        function detect_cycle(nodes) {
            const node = nodes[0];
            const entry = state.get(node);
            if (entry.visited)
                return false;
            if (entry.explored) {
                cycles.push(nodes);
                return true;
            }
            entry.explored = true;
            const neighbors = graph.get(node);
            for (const neighbor of neighbors) {
                const { visited } = state.get(neighbor);
                if (!visited) {
                    const cycle = detect_cycle([neighbor, ...nodes]);
                    if (cycle)
                        break;
                }
            }
            entry.explored = false;
            entry.visited = true;
            return false;
        }
        for (const node of graph.keys()) {
            detect_cycle([node]);
        }
        return cycles;
    }
    exports.detect_cycles = detect_cycles;
    
},
/* styles.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.wrap_css_modules = exports.compile_styles = void 0;
    const path_1 = require("path");
    const less_1 = __importDefault(require(56) /* less */);
    const chalk_1 = __importDefault(require(37) /* chalk */);
    const css_1 = __importDefault(require(202) /* css */);
    const sys_1 = require(20) /* ./sys */;
    async function compile_styles(styles_dir, css_dir) {
        let success = true;
        for (const src of (0, sys_1.scan)(styles_dir, [".less", ".css"])) {
            if ((0, path_1.basename)(src).startsWith("_"))
                continue;
            try {
                const style = (0, sys_1.read)(src);
                const { css } = await less_1.default.render(style, { filename: src });
                const dst = (0, sys_1.rename)(src, { base: styles_dir, dir: css_dir, ext: ".css" });
                (0, sys_1.write)(dst, css);
            }
            catch (error) {
                success = false;
                console.log(`${chalk_1.default.red("\u2717")} failed to compile ${chalk_1.default.magenta(src)}:`);
                console.log(`${error}`);
            }
        }
        return success;
    }
    exports.compile_styles = compile_styles;
    function wrap_css_modules(css_dir, js_dir, dts_dir, dts_internal_dir) {
        function* collect_classes(ast) {
            const { stylesheet } = ast;
            if (stylesheet == null)
                return;
            for (const rule of stylesheet.rules) {
                if (rule.type == "rule") {
                    const { selectors } = rule;
                    for (const selector of selectors ?? []) {
                        const classes = selector.match(/\.[A-Za-z0-9_-]+/g);
                        if (classes != null) {
                            for (const cls of classes) {
                                yield cls.substring(1);
                            }
                        }
                    }
                }
            }
        }
        for (const css_path of (0, sys_1.scan)(css_dir, [".css"])) {
            const sub_path = (0, path_1.relative)(css_dir, css_path);
            const css_in = (0, sys_1.read)(css_path);
            const ast = css_1.default.parse(css_in);
            const js = [];
            const dts = [];
            const dts_internal = [];
            dts_internal.push(`declare module "styles/${sub_path.replace(/\\/g, "/")}" {`);
            const classes = new Set(collect_classes(ast));
            for (const cls of classes) {
                if (!cls.startsWith("bk-"))
                    continue;
                const ident = cls.replace(/^bk-/, "").replace(/-/g, "_");
                js.push(`export const ${ident} = "${cls}"`);
                dts.push(`export const ${ident}: string`);
                dts_internal.push(`  export const ${ident}: string`);
            }
            const css_out = css_1.default.stringify(ast, { compress: true });
            js.push(`export default \`${css_out}\``);
            dts.push("export default \"\"");
            dts_internal.push("  export default \"\"");
            dts_internal.push("}");
            const js_file = `${(0, path_1.join)(js_dir, "styles", sub_path)}.js`;
            const dts_file = `${(0, path_1.join)(dts_dir, "styles", sub_path)}.d.ts`;
            const dts_internal_file = `${(0, path_1.join)(dts_internal_dir, "styles", sub_path)}.d.ts`;
            (0, sys_1.write)(js_file, `${js.join("\n")}\n`);
            (0, sys_1.write)(dts_file, `${dts.join("\n")}\n`);
            (0, sys_1.write)(dts_internal_file, `${dts_internal.join("\n")}\n`);
        }
    }
    exports.wrap_css_modules = wrap_css_modules;
    
},
/* less/index.js */ function _(require, module, exports, __esModule, __esExport) {
    module.exports = require(57) /* ./lib/less-node */.default;
},
/* less/lib/less-node/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var environment_1 = tslib_1.__importDefault(require(59) /* ./environment */);
    var file_manager_1 = tslib_1.__importDefault(require(62) /* ./file-manager */);
    var url_file_manager_1 = tslib_1.__importDefault(require(69) /* ./url-file-manager */);
    var less_1 = tslib_1.__importDefault(require(108) /* ../less */);
    var less = less_1.default(environment_1.default, [new file_manager_1.default(), new url_file_manager_1.default()]);
    var lessc_helper_1 = tslib_1.__importDefault(require(195) /* ./lessc-helper */);
    // allow people to create less with their own environment
    less.createFromEnvironment = less_1.default;
    less.lesscHelper = lessc_helper_1.default;
    less.PluginLoader = require(196) /* ./plugin-loader */.default;
    less.fs = require(63) /* ./fs */.default;
    less.FileManager = file_manager_1.default;
    less.UrlFileManager = url_file_manager_1.default;
    // Set up options
    less.options = require(197) /* ../less/default-options */.default();
    // provide image-size functionality
    require(198) /* ./image-size */.default(less.environment);
    exports.default = less;
    
},
/* tslib/tslib.js */ function _(require, module, exports, __esModule, __esExport) {
    /******************************************************************************
    Copyright (c) Microsoft Corporation.
    
    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.
    
    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global global, define, System, Reflect, Promise */
    var __extends;
    var __assign;
    var __rest;
    var __decorate;
    var __param;
    var __esDecorate;
    var __runInitializers;
    var __propKey;
    var __setFunctionName;
    var __metadata;
    var __awaiter;
    var __generator;
    var __exportStar;
    var __values;
    var __read;
    var __spread;
    var __spreadArrays;
    var __spreadArray;
    var __await;
    var __asyncGenerator;
    var __asyncDelegator;
    var __asyncValues;
    var __makeTemplateObject;
    var __importStar;
    var __importDefault;
    var __classPrivateFieldGet;
    var __classPrivateFieldSet;
    var __classPrivateFieldIn;
    var __createBinding;
    (function (factory) {
        var root = typeof global === "object" ? global : typeof self === "object" ? self : typeof this === "object" ? this : {};
        if (typeof define === "function" && define.amd) {
            define("tslib", ["exports"], function (exports) { factory(createExporter(root, createExporter(exports))); });
        }
        else if (typeof module === "object" && typeof module.exports === "object") {
            factory(createExporter(root, createExporter(module.exports)));
        }
        else {
            factory(createExporter(root));
        }
        function createExporter(exports, previous) {
            if (exports !== root) {
                if (typeof Object.create === "function") {
                    Object.defineProperty(exports, "__esModule", { value: true });
                }
                else {
                    exports.__esModule = true;
                }
            }
            return function (id, v) { return exports[id] = previous ? previous(id, v) : v; };
        }
    })(function (exporter) {
        var extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        __extends = function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
        __assign = Object.assign || function (t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        __rest = function (s, e) {
            var t = {};
            for (var p in s)
                if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                    t[p] = s[p];
            if (s != null && typeof Object.getOwnPropertySymbols === "function")
                for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                        t[p[i]] = s[p[i]];
                }
            return t;
        };
        __decorate = function (decorators, target, key, desc) {
            var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
            if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
                r = Reflect.decorate(decorators, target, key, desc);
            else
                for (var i = decorators.length - 1; i >= 0; i--)
                    if (d = decorators[i])
                        r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
            return c > 3 && r && Object.defineProperty(target, key, r), r;
        };
        __param = function (paramIndex, decorator) {
            return function (target, key) { decorator(target, key, paramIndex); };
        };
        __esDecorate = function (ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
            function accept(f) { if (f !== void 0 && typeof f !== "function")
                throw new TypeError("Function expected"); return f; }
            var kind = contextIn.kind, key = kind === "getter" ? "get" : kind === "setter" ? "set" : "value";
            var target = !descriptorIn && ctor ? contextIn["static"] ? ctor : ctor.prototype : null;
            var descriptor = descriptorIn || (target ? Object.getOwnPropertyDescriptor(target, contextIn.name) : {});
            var _, done = false;
            for (var i = decorators.length - 1; i >= 0; i--) {
                var context = {};
                for (var p in contextIn)
                    context[p] = p === "access" ? {} : contextIn[p];
                for (var p in contextIn.access)
                    context.access[p] = contextIn.access[p];
                context.addInitializer = function (f) { if (done)
                    throw new TypeError("Cannot add initializers after decoration has completed"); extraInitializers.push(accept(f || null)); };
                var result = (0, decorators[i])(kind === "accessor" ? { get: descriptor.get, set: descriptor.set } : descriptor[key], context);
                if (kind === "accessor") {
                    if (result === void 0)
                        continue;
                    if (result === null || typeof result !== "object")
                        throw new TypeError("Object expected");
                    if (_ = accept(result.get))
                        descriptor.get = _;
                    if (_ = accept(result.set))
                        descriptor.set = _;
                    if (_ = accept(result.init))
                        initializers.push(_);
                }
                else if (_ = accept(result)) {
                    if (kind === "field")
                        initializers.push(_);
                    else
                        descriptor[key] = _;
                }
            }
            if (target)
                Object.defineProperty(target, contextIn.name, descriptor);
            done = true;
        };
        __runInitializers = function (thisArg, initializers, value) {
            var useValue = arguments.length > 2;
            for (var i = 0; i < initializers.length; i++) {
                value = useValue ? initializers[i].call(thisArg, value) : initializers[i].call(thisArg);
            }
            return useValue ? value : void 0;
        };
        __propKey = function (x) {
            return typeof x === "symbol" ? x : "".concat(x);
        };
        __setFunctionName = function (f, name, prefix) {
            if (typeof name === "symbol")
                name = name.description ? "[".concat(name.description, "]") : "";
            return Object.defineProperty(f, "name", { configurable: true, value: prefix ? "".concat(prefix, " ", name) : name });
        };
        __metadata = function (metadataKey, metadataValue) {
            if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
                return Reflect.metadata(metadataKey, metadataValue);
        };
        __awaiter = function (thisArg, _arguments, P, generator) {
            function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
            return new (P || (P = Promise))(function (resolve, reject) {
                function fulfilled(value) { try {
                    step(generator.next(value));
                }
                catch (e) {
                    reject(e);
                } }
                function rejected(value) { try {
                    step(generator["throw"](value));
                }
                catch (e) {
                    reject(e);
                } }
                function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
                step((generator = generator.apply(thisArg, _arguments || [])).next());
            });
        };
        __generator = function (thisArg, body) {
            var _ = { label: 0, sent: function () { if (t[0] & 1)
                    throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
            return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
            function verb(n) { return function (v) { return step([n, v]); }; }
            function step(op) {
                if (f)
                    throw new TypeError("Generator is already executing.");
                while (g && (g = 0, op[0] && (_ = 0)), _)
                    try {
                        if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                            return t;
                        if (y = 0, t)
                            op = [op[0] & 2, t.value];
                        switch (op[0]) {
                            case 0:
                            case 1:
                                t = op;
                                break;
                            case 4:
                                _.label++;
                                return { value: op[1], done: false };
                            case 5:
                                _.label++;
                                y = op[1];
                                op = [0];
                                continue;
                            case 7:
                                op = _.ops.pop();
                                _.trys.pop();
                                continue;
                            default:
                                if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                    _ = 0;
                                    continue;
                                }
                                if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                    _.label = op[1];
                                    break;
                                }
                                if (op[0] === 6 && _.label < t[1]) {
                                    _.label = t[1];
                                    t = op;
                                    break;
                                }
                                if (t && _.label < t[2]) {
                                    _.label = t[2];
                                    _.ops.push(op);
                                    break;
                                }
                                if (t[2])
                                    _.ops.pop();
                                _.trys.pop();
                                continue;
                        }
                        op = body.call(thisArg, _);
                    }
                    catch (e) {
                        op = [6, e];
                        y = 0;
                    }
                    finally {
                        f = t = 0;
                    }
                if (op[0] & 5)
                    throw op[1];
                return { value: op[0] ? op[1] : void 0, done: true };
            }
        };
        __exportStar = function (m, o) {
            for (var p in m)
                if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                    __createBinding(o, m, p);
        };
        __createBinding = Object.create ? (function (o, m, k, k2) {
            if (k2 === undefined)
                k2 = k;
            var desc = Object.getOwnPropertyDescriptor(m, k);
            if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
                desc = { enumerable: true, get: function () { return m[k]; } };
            }
            Object.defineProperty(o, k2, desc);
        }) : (function (o, m, k, k2) {
            if (k2 === undefined)
                k2 = k;
            o[k2] = m[k];
        });
        __values = function (o) {
            var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
            if (m)
                return m.call(o);
            if (o && typeof o.length === "number")
                return {
                    next: function () {
                        if (o && i >= o.length)
                            o = void 0;
                        return { value: o && o[i++], done: !o };
                    }
                };
            throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
        };
        __read = function (o, n) {
            var m = typeof Symbol === "function" && o[Symbol.iterator];
            if (!m)
                return o;
            var i = m.call(o), r, ar = [], e;
            try {
                while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                    ar.push(r.value);
            }
            catch (error) {
                e = { error: error };
            }
            finally {
                try {
                    if (r && !r.done && (m = i["return"]))
                        m.call(i);
                }
                finally {
                    if (e)
                        throw e.error;
                }
            }
            return ar;
        };
        /** @deprecated */
        __spread = function () {
            for (var ar = [], i = 0; i < arguments.length; i++)
                ar = ar.concat(__read(arguments[i]));
            return ar;
        };
        /** @deprecated */
        __spreadArrays = function () {
            for (var s = 0, i = 0, il = arguments.length; i < il; i++)
                s += arguments[i].length;
            for (var r = Array(s), k = 0, i = 0; i < il; i++)
                for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                    r[k] = a[j];
            return r;
        };
        __spreadArray = function (to, from, pack) {
            if (pack || arguments.length === 2)
                for (var i = 0, l = from.length, ar; i < l; i++) {
                    if (ar || !(i in from)) {
                        if (!ar)
                            ar = Array.prototype.slice.call(from, 0, i);
                        ar[i] = from[i];
                    }
                }
            return to.concat(ar || Array.prototype.slice.call(from));
        };
        __await = function (v) {
            return this instanceof __await ? (this.v = v, this) : new __await(v);
        };
        __asyncGenerator = function (thisArg, _arguments, generator) {
            if (!Symbol.asyncIterator)
                throw new TypeError("Symbol.asyncIterator is not defined.");
            var g = generator.apply(thisArg, _arguments || []), i, q = [];
            return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
            function verb(n) { if (g[n])
                i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
            function resume(n, v) { try {
                step(g[n](v));
            }
            catch (e) {
                settle(q[0][3], e);
            } }
            function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
            function fulfill(value) { resume("next", value); }
            function reject(value) { resume("throw", value); }
            function settle(f, v) { if (f(v), q.shift(), q.length)
                resume(q[0][0], q[0][1]); }
        };
        __asyncDelegator = function (o) {
            var i, p;
            return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
            function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: false } : f ? f(v) : v; } : f; }
        };
        __asyncValues = function (o) {
            if (!Symbol.asyncIterator)
                throw new TypeError("Symbol.asyncIterator is not defined.");
            var m = o[Symbol.asyncIterator], i;
            return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
            function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
            function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
        };
        __makeTemplateObject = function (cooked, raw) {
            if (Object.defineProperty) {
                Object.defineProperty(cooked, "raw", { value: raw });
            }
            else {
                cooked.raw = raw;
            }
            return cooked;
        };
        var __setModuleDefault = Object.create ? (function (o, v) {
            Object.defineProperty(o, "default", { enumerable: true, value: v });
        }) : function (o, v) {
            o["default"] = v;
        };
        __importStar = function (mod) {
            if (mod && mod.__esModule)
                return mod;
            var result = {};
            if (mod != null)
                for (var k in mod)
                    if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                        __createBinding(result, mod, k);
            __setModuleDefault(result, mod);
            return result;
        };
        __importDefault = function (mod) {
            return (mod && mod.__esModule) ? mod : { "default": mod };
        };
        __classPrivateFieldGet = function (receiver, state, kind, f) {
            if (kind === "a" && !f)
                throw new TypeError("Private accessor was defined without a getter");
            if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
                throw new TypeError("Cannot read private member from an object whose class did not declare it");
            return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
        };
        __classPrivateFieldSet = function (receiver, state, value, kind, f) {
            if (kind === "m")
                throw new TypeError("Private method is not writable");
            if (kind === "a" && !f)
                throw new TypeError("Private accessor was defined without a setter");
            if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
                throw new TypeError("Cannot write private member to an object whose class did not declare it");
            return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
        };
        __classPrivateFieldIn = function (state, receiver) {
            if (receiver === null || (typeof receiver !== "object" && typeof receiver !== "function"))
                throw new TypeError("Cannot use 'in' operator on non-object");
            return typeof state === "function" ? receiver === state : state.has(receiver);
        };
        exporter("__extends", __extends);
        exporter("__assign", __assign);
        exporter("__rest", __rest);
        exporter("__decorate", __decorate);
        exporter("__param", __param);
        exporter("__esDecorate", __esDecorate);
        exporter("__runInitializers", __runInitializers);
        exporter("__propKey", __propKey);
        exporter("__setFunctionName", __setFunctionName);
        exporter("__metadata", __metadata);
        exporter("__awaiter", __awaiter);
        exporter("__generator", __generator);
        exporter("__exportStar", __exportStar);
        exporter("__createBinding", __createBinding);
        exporter("__values", __values);
        exporter("__read", __read);
        exporter("__spread", __spread);
        exporter("__spreadArrays", __spreadArrays);
        exporter("__spreadArray", __spreadArray);
        exporter("__await", __await);
        exporter("__asyncGenerator", __asyncGenerator);
        exporter("__asyncDelegator", __asyncDelegator);
        exporter("__asyncValues", __asyncValues);
        exporter("__makeTemplateObject", __makeTemplateObject);
        exporter("__importStar", __importStar);
        exporter("__importDefault", __importDefault);
        exporter("__classPrivateFieldGet", __classPrivateFieldGet);
        exporter("__classPrivateFieldSet", __classPrivateFieldSet);
        exporter("__classPrivateFieldIn", __classPrivateFieldIn);
    });
},
/* less/lib/less-node/environment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = {
        encodeBase64: function encodeBase64(str) {
            // Avoid Buffer constructor on newer versions of Node.js.
            var buffer = (Buffer.from ? Buffer.from(str) : (new Buffer(str)));
            return buffer.toString('base64');
        },
        mimeLookup: function (filename) {
            return require(60) /* mime */.lookup(filename);
        },
        charsetLookup: function (mime) {
            return require(60) /* mime */.charsets.lookup(mime);
        },
        getSourceMapGenerator: function getSourceMapGenerator() {
            return require(23) /* source-map */.SourceMapGenerator;
        }
    };
    
},
/* mime/mime.js */ function _(require, module, exports, __esModule, __esExport) {
    var path = require('path');
    var fs = require('fs');
    function Mime() {
        // Map of extension -> mime type
        this.types = Object.create(null);
        // Map of mime type -> extension
        this.extensions = Object.create(null);
    }
    /**
     * Define mimetype -> extension mappings.  Each key is a mime-type that maps
     * to an array of extensions associated with the type.  The first extension is
     * used as the default extension for the type.
     *
     * e.g. mime.define({'audio/ogg', ['oga', 'ogg', 'spx']});
     *
     * @param map (Object) type definitions
     */
    Mime.prototype.define = function (map) {
        for (var type in map) {
            var exts = map[type];
            for (var i = 0; i < exts.length; i++) {
                if (process.env.DEBUG_MIME && this.types[exts[i]]) {
                    console.warn((this._loading || "define()").replace(/.*\//, ''), 'changes "' + exts[i] + '" extension type from ' +
                        this.types[exts[i]] + ' to ' + type);
                }
                this.types[exts[i]] = type;
            }
            // Default extension is the first one we encounter
            if (!this.extensions[type]) {
                this.extensions[type] = exts[0];
            }
        }
    };
    /**
     * Load an Apache2-style ".types" file
     *
     * This may be called multiple times (it's expected).  Where files declare
     * overlapping types/extensions, the last file wins.
     *
     * @param file (String) path of file to load.
     */
    Mime.prototype.load = function (file) {
        this._loading = file;
        // Read file and split into lines
        var map = {}, content = fs.readFileSync(file, 'ascii'), lines = content.split(/[\r\n]+/);
        lines.forEach(function (line) {
            // Clean up whitespace/comments, and split into fields
            var fields = line.replace(/\s*#.*|^\s*|\s*$/g, '').split(/\s+/);
            map[fields.shift()] = fields;
        });
        this.define(map);
        this._loading = null;
    };
    /**
     * Lookup a mime type based on extension
     */
    Mime.prototype.lookup = function (path, fallback) {
        var ext = path.replace(/^.*[\.\/\\]/, '').toLowerCase();
        return this.types[ext] || fallback || this.default_type;
    };
    /**
     * Return file extension associated with a mime type
     */
    Mime.prototype.extension = function (mimeType) {
        var type = mimeType.match(/^\s*([^;\s]*)(?:;|\s|$)/)[1].toLowerCase();
        return this.extensions[type];
    };
    // Default instance
    var mime = new Mime();
    // Define built-in types
    mime.define(require(61) /* ./types.json */);
    // Default type
    mime.default_type = mime.lookup('bin');
    //
    // Additional API specific to the default instance
    //
    mime.Mime = Mime;
    /**
     * Lookup a charset based on mime type.
     */
    mime.charsets = {
        lookup: function (mimeType, fallback) {
            // Assume text types are utf8
            return (/^text\/|^application\/(javascript|json)/).test(mimeType) ? 'UTF-8' : fallback;
        }
    };
    module.exports = mime;
},
/* mime/types.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = { "application/andrew-inset": ["ez"], "application/applixware": ["aw"], "application/atom+xml": ["atom"], "application/atomcat+xml": ["atomcat"], "application/atomsvc+xml": ["atomsvc"], "application/bdoc": ["bdoc"], "application/ccxml+xml": ["ccxml"], "application/cdmi-capability": ["cdmia"], "application/cdmi-container": ["cdmic"], "application/cdmi-domain": ["cdmid"], "application/cdmi-object": ["cdmio"], "application/cdmi-queue": ["cdmiq"], "application/cu-seeme": ["cu"], "application/dash+xml": ["mpd"], "application/davmount+xml": ["davmount"], "application/docbook+xml": ["dbk"], "application/dssc+der": ["dssc"], "application/dssc+xml": ["xdssc"], "application/ecmascript": ["ecma"], "application/emma+xml": ["emma"], "application/epub+zip": ["epub"], "application/exi": ["exi"], "application/font-tdpfr": ["pfr"], "application/font-woff": [], "application/font-woff2": [], "application/geo+json": ["geojson"], "application/gml+xml": ["gml"], "application/gpx+xml": ["gpx"], "application/gxf": ["gxf"], "application/gzip": ["gz"], "application/hyperstudio": ["stk"], "application/inkml+xml": ["ink", "inkml"], "application/ipfix": ["ipfix"], "application/java-archive": ["jar", "war", "ear"], "application/java-serialized-object": ["ser"], "application/java-vm": ["class"], "application/javascript": ["js", "mjs"], "application/json": ["json", "map"], "application/json5": ["json5"], "application/jsonml+json": ["jsonml"], "application/ld+json": ["jsonld"], "application/lost+xml": ["lostxml"], "application/mac-binhex40": ["hqx"], "application/mac-compactpro": ["cpt"], "application/mads+xml": ["mads"], "application/manifest+json": ["webmanifest"], "application/marc": ["mrc"], "application/marcxml+xml": ["mrcx"], "application/mathematica": ["ma", "nb", "mb"], "application/mathml+xml": ["mathml"], "application/mbox": ["mbox"], "application/mediaservercontrol+xml": ["mscml"], "application/metalink+xml": ["metalink"], "application/metalink4+xml": ["meta4"], "application/mets+xml": ["mets"], "application/mods+xml": ["mods"], "application/mp21": ["m21", "mp21"], "application/mp4": ["mp4s", "m4p"], "application/msword": ["doc", "dot"], "application/mxf": ["mxf"], "application/octet-stream": ["bin", "dms", "lrf", "mar", "so", "dist", "distz", "pkg", "bpk", "dump", "elc", "deploy", "exe", "dll", "deb", "dmg", "iso", "img", "msi", "msp", "msm", "buffer"], "application/oda": ["oda"], "application/oebps-package+xml": ["opf"], "application/ogg": ["ogx"], "application/omdoc+xml": ["omdoc"], "application/onenote": ["onetoc", "onetoc2", "onetmp", "onepkg"], "application/oxps": ["oxps"], "application/patch-ops-error+xml": ["xer"], "application/pdf": ["pdf"], "application/pgp-encrypted": ["pgp"], "application/pgp-signature": ["asc", "sig"], "application/pics-rules": ["prf"], "application/pkcs10": ["p10"], "application/pkcs7-mime": ["p7m", "p7c"], "application/pkcs7-signature": ["p7s"], "application/pkcs8": ["p8"], "application/pkix-attr-cert": ["ac"], "application/pkix-cert": ["cer"], "application/pkix-crl": ["crl"], "application/pkix-pkipath": ["pkipath"], "application/pkixcmp": ["pki"], "application/pls+xml": ["pls"], "application/postscript": ["ai", "eps", "ps"], "application/prs.cww": ["cww"], "application/pskc+xml": ["pskcxml"], "application/raml+yaml": ["raml"], "application/rdf+xml": ["rdf"], "application/reginfo+xml": ["rif"], "application/relax-ng-compact-syntax": ["rnc"], "application/resource-lists+xml": ["rl"], "application/resource-lists-diff+xml": ["rld"], "application/rls-services+xml": ["rs"], "application/rpki-ghostbusters": ["gbr"], "application/rpki-manifest": ["mft"], "application/rpki-roa": ["roa"], "application/rsd+xml": ["rsd"], "application/rss+xml": ["rss"], "application/rtf": ["rtf"], "application/sbml+xml": ["sbml"], "application/scvp-cv-request": ["scq"], "application/scvp-cv-response": ["scs"], "application/scvp-vp-request": ["spq"], "application/scvp-vp-response": ["spp"], "application/sdp": ["sdp"], "application/set-payment-initiation": ["setpay"], "application/set-registration-initiation": ["setreg"], "application/shf+xml": ["shf"], "application/smil+xml": ["smi", "smil"], "application/sparql-query": ["rq"], "application/sparql-results+xml": ["srx"], "application/srgs": ["gram"], "application/srgs+xml": ["grxml"], "application/sru+xml": ["sru"], "application/ssdl+xml": ["ssdl"], "application/ssml+xml": ["ssml"], "application/tei+xml": ["tei", "teicorpus"], "application/thraud+xml": ["tfi"], "application/timestamped-data": ["tsd"], "application/vnd.3gpp.pic-bw-large": ["plb"], "application/vnd.3gpp.pic-bw-small": ["psb"], "application/vnd.3gpp.pic-bw-var": ["pvb"], "application/vnd.3gpp2.tcap": ["tcap"], "application/vnd.3m.post-it-notes": ["pwn"], "application/vnd.accpac.simply.aso": ["aso"], "application/vnd.accpac.simply.imp": ["imp"], "application/vnd.acucobol": ["acu"], "application/vnd.acucorp": ["atc", "acutc"], "application/vnd.adobe.air-application-installer-package+zip": ["air"], "application/vnd.adobe.formscentral.fcdt": ["fcdt"], "application/vnd.adobe.fxp": ["fxp", "fxpl"], "application/vnd.adobe.xdp+xml": ["xdp"], "application/vnd.adobe.xfdf": ["xfdf"], "application/vnd.ahead.space": ["ahead"], "application/vnd.airzip.filesecure.azf": ["azf"], "application/vnd.airzip.filesecure.azs": ["azs"], "application/vnd.amazon.ebook": ["azw"], "application/vnd.americandynamics.acc": ["acc"], "application/vnd.amiga.ami": ["ami"], "application/vnd.android.package-archive": ["apk"], "application/vnd.anser-web-certificate-issue-initiation": ["cii"], "application/vnd.anser-web-funds-transfer-initiation": ["fti"], "application/vnd.antix.game-component": ["atx"], "application/vnd.apple.installer+xml": ["mpkg"], "application/vnd.apple.mpegurl": ["m3u8"], "application/vnd.apple.pkpass": ["pkpass"], "application/vnd.aristanetworks.swi": ["swi"], "application/vnd.astraea-software.iota": ["iota"], "application/vnd.audiograph": ["aep"], "application/vnd.blueice.multipass": ["mpm"], "application/vnd.bmi": ["bmi"], "application/vnd.businessobjects": ["rep"], "application/vnd.chemdraw+xml": ["cdxml"], "application/vnd.chipnuts.karaoke-mmd": ["mmd"], "application/vnd.cinderella": ["cdy"], "application/vnd.claymore": ["cla"], "application/vnd.cloanto.rp9": ["rp9"], "application/vnd.clonk.c4group": ["c4g", "c4d", "c4f", "c4p", "c4u"], "application/vnd.cluetrust.cartomobile-config": ["c11amc"], "application/vnd.cluetrust.cartomobile-config-pkg": ["c11amz"], "application/vnd.commonspace": ["csp"], "application/vnd.contact.cmsg": ["cdbcmsg"], "application/vnd.cosmocaller": ["cmc"], "application/vnd.crick.clicker": ["clkx"], "application/vnd.crick.clicker.keyboard": ["clkk"], "application/vnd.crick.clicker.palette": ["clkp"], "application/vnd.crick.clicker.template": ["clkt"], "application/vnd.crick.clicker.wordbank": ["clkw"], "application/vnd.criticaltools.wbs+xml": ["wbs"], "application/vnd.ctc-posml": ["pml"], "application/vnd.cups-ppd": ["ppd"], "application/vnd.curl.car": ["car"], "application/vnd.curl.pcurl": ["pcurl"], "application/vnd.dart": ["dart"], "application/vnd.data-vision.rdz": ["rdz"], "application/vnd.dece.data": ["uvf", "uvvf", "uvd", "uvvd"], "application/vnd.dece.ttml+xml": ["uvt", "uvvt"], "application/vnd.dece.unspecified": ["uvx", "uvvx"], "application/vnd.dece.zip": ["uvz", "uvvz"], "application/vnd.denovo.fcselayout-link": ["fe_launch"], "application/vnd.dna": ["dna"], "application/vnd.dolby.mlp": ["mlp"], "application/vnd.dpgraph": ["dpg"], "application/vnd.dreamfactory": ["dfac"], "application/vnd.ds-keypoint": ["kpxx"], "application/vnd.dvb.ait": ["ait"], "application/vnd.dvb.service": ["svc"], "application/vnd.dynageo": ["geo"], "application/vnd.ecowin.chart": ["mag"], "application/vnd.enliven": ["nml"], "application/vnd.epson.esf": ["esf"], "application/vnd.epson.msf": ["msf"], "application/vnd.epson.quickanime": ["qam"], "application/vnd.epson.salt": ["slt"], "application/vnd.epson.ssf": ["ssf"], "application/vnd.eszigno3+xml": ["es3", "et3"], "application/vnd.ezpix-album": ["ez2"], "application/vnd.ezpix-package": ["ez3"], "application/vnd.fdf": ["fdf"], "application/vnd.fdsn.mseed": ["mseed"], "application/vnd.fdsn.seed": ["seed", "dataless"], "application/vnd.flographit": ["gph"], "application/vnd.fluxtime.clip": ["ftc"], "application/vnd.framemaker": ["fm", "frame", "maker", "book"], "application/vnd.frogans.fnc": ["fnc"], "application/vnd.frogans.ltf": ["ltf"], "application/vnd.fsc.weblaunch": ["fsc"], "application/vnd.fujitsu.oasys": ["oas"], "application/vnd.fujitsu.oasys2": ["oa2"], "application/vnd.fujitsu.oasys3": ["oa3"], "application/vnd.fujitsu.oasysgp": ["fg5"], "application/vnd.fujitsu.oasysprs": ["bh2"], "application/vnd.fujixerox.ddd": ["ddd"], "application/vnd.fujixerox.docuworks": ["xdw"], "application/vnd.fujixerox.docuworks.binder": ["xbd"], "application/vnd.fuzzysheet": ["fzs"], "application/vnd.genomatix.tuxedo": ["txd"], "application/vnd.geogebra.file": ["ggb"], "application/vnd.geogebra.tool": ["ggt"], "application/vnd.geometry-explorer": ["gex", "gre"], "application/vnd.geonext": ["gxt"], "application/vnd.geoplan": ["g2w"], "application/vnd.geospace": ["g3w"], "application/vnd.gmx": ["gmx"], "application/vnd.google-apps.document": ["gdoc"], "application/vnd.google-apps.presentation": ["gslides"], "application/vnd.google-apps.spreadsheet": ["gsheet"], "application/vnd.google-earth.kml+xml": ["kml"], "application/vnd.google-earth.kmz": ["kmz"], "application/vnd.grafeq": ["gqf", "gqs"], "application/vnd.groove-account": ["gac"], "application/vnd.groove-help": ["ghf"], "application/vnd.groove-identity-message": ["gim"], "application/vnd.groove-injector": ["grv"], "application/vnd.groove-tool-message": ["gtm"], "application/vnd.groove-tool-template": ["tpl"], "application/vnd.groove-vcard": ["vcg"], "application/vnd.hal+xml": ["hal"], "application/vnd.handheld-entertainment+xml": ["zmm"], "application/vnd.hbci": ["hbci"], "application/vnd.hhe.lesson-player": ["les"], "application/vnd.hp-hpgl": ["hpgl"], "application/vnd.hp-hpid": ["hpid"], "application/vnd.hp-hps": ["hps"], "application/vnd.hp-jlyt": ["jlt"], "application/vnd.hp-pcl": ["pcl"], "application/vnd.hp-pclxl": ["pclxl"], "application/vnd.hydrostatix.sof-data": ["sfd-hdstx"], "application/vnd.ibm.minipay": ["mpy"], "application/vnd.ibm.modcap": ["afp", "listafp", "list3820"], "application/vnd.ibm.rights-management": ["irm"], "application/vnd.ibm.secure-container": ["sc"], "application/vnd.iccprofile": ["icc", "icm"], "application/vnd.igloader": ["igl"], "application/vnd.immervision-ivp": ["ivp"], "application/vnd.immervision-ivu": ["ivu"], "application/vnd.insors.igm": ["igm"], "application/vnd.intercon.formnet": ["xpw", "xpx"], "application/vnd.intergeo": ["i2g"], "application/vnd.intu.qbo": ["qbo"], "application/vnd.intu.qfx": ["qfx"], "application/vnd.ipunplugged.rcprofile": ["rcprofile"], "application/vnd.irepository.package+xml": ["irp"], "application/vnd.is-xpr": ["xpr"], "application/vnd.isac.fcs": ["fcs"], "application/vnd.jam": ["jam"], "application/vnd.jcp.javame.midlet-rms": ["rms"], "application/vnd.jisp": ["jisp"], "application/vnd.joost.joda-archive": ["joda"], "application/vnd.kahootz": ["ktz", "ktr"], "application/vnd.kde.karbon": ["karbon"], "application/vnd.kde.kchart": ["chrt"], "application/vnd.kde.kformula": ["kfo"], "application/vnd.kde.kivio": ["flw"], "application/vnd.kde.kontour": ["kon"], "application/vnd.kde.kpresenter": ["kpr", "kpt"], "application/vnd.kde.kspread": ["ksp"], "application/vnd.kde.kword": ["kwd", "kwt"], "application/vnd.kenameaapp": ["htke"], "application/vnd.kidspiration": ["kia"], "application/vnd.kinar": ["kne", "knp"], "application/vnd.koan": ["skp", "skd", "skt", "skm"], "application/vnd.kodak-descriptor": ["sse"], "application/vnd.las.las+xml": ["lasxml"], "application/vnd.llamagraphics.life-balance.desktop": ["lbd"], "application/vnd.llamagraphics.life-balance.exchange+xml": ["lbe"], "application/vnd.lotus-1-2-3": ["123"], "application/vnd.lotus-approach": ["apr"], "application/vnd.lotus-freelance": ["pre"], "application/vnd.lotus-notes": ["nsf"], "application/vnd.lotus-organizer": ["org"], "application/vnd.lotus-screencam": ["scm"], "application/vnd.lotus-wordpro": ["lwp"], "application/vnd.macports.portpkg": ["portpkg"], "application/vnd.mcd": ["mcd"], "application/vnd.medcalcdata": ["mc1"], "application/vnd.mediastation.cdkey": ["cdkey"], "application/vnd.mfer": ["mwf"], "application/vnd.mfmp": ["mfm"], "application/vnd.micrografx.flo": ["flo"], "application/vnd.micrografx.igx": ["igx"], "application/vnd.mif": ["mif"], "application/vnd.mobius.daf": ["daf"], "application/vnd.mobius.dis": ["dis"], "application/vnd.mobius.mbk": ["mbk"], "application/vnd.mobius.mqy": ["mqy"], "application/vnd.mobius.msl": ["msl"], "application/vnd.mobius.plc": ["plc"], "application/vnd.mobius.txf": ["txf"], "application/vnd.mophun.application": ["mpn"], "application/vnd.mophun.certificate": ["mpc"], "application/vnd.mozilla.xul+xml": ["xul"], "application/vnd.ms-artgalry": ["cil"], "application/vnd.ms-cab-compressed": ["cab"], "application/vnd.ms-excel": ["xls", "xlm", "xla", "xlc", "xlt", "xlw"], "application/vnd.ms-excel.addin.macroenabled.12": ["xlam"], "application/vnd.ms-excel.sheet.binary.macroenabled.12": ["xlsb"], "application/vnd.ms-excel.sheet.macroenabled.12": ["xlsm"], "application/vnd.ms-excel.template.macroenabled.12": ["xltm"], "application/vnd.ms-fontobject": ["eot"], "application/vnd.ms-htmlhelp": ["chm"], "application/vnd.ms-ims": ["ims"], "application/vnd.ms-lrm": ["lrm"], "application/vnd.ms-officetheme": ["thmx"], "application/vnd.ms-outlook": ["msg"], "application/vnd.ms-pki.seccat": ["cat"], "application/vnd.ms-pki.stl": ["stl"], "application/vnd.ms-powerpoint": ["ppt", "pps", "pot"], "application/vnd.ms-powerpoint.addin.macroenabled.12": ["ppam"], "application/vnd.ms-powerpoint.presentation.macroenabled.12": ["pptm"], "application/vnd.ms-powerpoint.slide.macroenabled.12": ["sldm"], "application/vnd.ms-powerpoint.slideshow.macroenabled.12": ["ppsm"], "application/vnd.ms-powerpoint.template.macroenabled.12": ["potm"], "application/vnd.ms-project": ["mpp", "mpt"], "application/vnd.ms-word.document.macroenabled.12": ["docm"], "application/vnd.ms-word.template.macroenabled.12": ["dotm"], "application/vnd.ms-works": ["wps", "wks", "wcm", "wdb"], "application/vnd.ms-wpl": ["wpl"], "application/vnd.ms-xpsdocument": ["xps"], "application/vnd.mseq": ["mseq"], "application/vnd.musician": ["mus"], "application/vnd.muvee.style": ["msty"], "application/vnd.mynfc": ["taglet"], "application/vnd.neurolanguage.nlu": ["nlu"], "application/vnd.nitf": ["ntf", "nitf"], "application/vnd.noblenet-directory": ["nnd"], "application/vnd.noblenet-sealer": ["nns"], "application/vnd.noblenet-web": ["nnw"], "application/vnd.nokia.n-gage.data": ["ngdat"], "application/vnd.nokia.n-gage.symbian.install": ["n-gage"], "application/vnd.nokia.radio-preset": ["rpst"], "application/vnd.nokia.radio-presets": ["rpss"], "application/vnd.novadigm.edm": ["edm"], "application/vnd.novadigm.edx": ["edx"], "application/vnd.novadigm.ext": ["ext"], "application/vnd.oasis.opendocument.chart": ["odc"], "application/vnd.oasis.opendocument.chart-template": ["otc"], "application/vnd.oasis.opendocument.database": ["odb"], "application/vnd.oasis.opendocument.formula": ["odf"], "application/vnd.oasis.opendocument.formula-template": ["odft"], "application/vnd.oasis.opendocument.graphics": ["odg"], "application/vnd.oasis.opendocument.graphics-template": ["otg"], "application/vnd.oasis.opendocument.image": ["odi"], "application/vnd.oasis.opendocument.image-template": ["oti"], "application/vnd.oasis.opendocument.presentation": ["odp"], "application/vnd.oasis.opendocument.presentation-template": ["otp"], "application/vnd.oasis.opendocument.spreadsheet": ["ods"], "application/vnd.oasis.opendocument.spreadsheet-template": ["ots"], "application/vnd.oasis.opendocument.text": ["odt"], "application/vnd.oasis.opendocument.text-master": ["odm"], "application/vnd.oasis.opendocument.text-template": ["ott"], "application/vnd.oasis.opendocument.text-web": ["oth"], "application/vnd.olpc-sugar": ["xo"], "application/vnd.oma.dd2+xml": ["dd2"], "application/vnd.openofficeorg.extension": ["oxt"], "application/vnd.openxmlformats-officedocument.presentationml.presentation": ["pptx"], "application/vnd.openxmlformats-officedocument.presentationml.slide": ["sldx"], "application/vnd.openxmlformats-officedocument.presentationml.slideshow": ["ppsx"], "application/vnd.openxmlformats-officedocument.presentationml.template": ["potx"], "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet": ["xlsx"], "application/vnd.openxmlformats-officedocument.spreadsheetml.template": ["xltx"], "application/vnd.openxmlformats-officedocument.wordprocessingml.document": ["docx"], "application/vnd.openxmlformats-officedocument.wordprocessingml.template": ["dotx"], "application/vnd.osgeo.mapguide.package": ["mgp"], "application/vnd.osgi.dp": ["dp"], "application/vnd.osgi.subsystem": ["esa"], "application/vnd.palm": ["pdb", "pqa", "oprc"], "application/vnd.pawaafile": ["paw"], "application/vnd.pg.format": ["str"], "application/vnd.pg.osasli": ["ei6"], "application/vnd.picsel": ["efif"], "application/vnd.pmi.widget": ["wg"], "application/vnd.pocketlearn": ["plf"], "application/vnd.powerbuilder6": ["pbd"], "application/vnd.previewsystems.box": ["box"], "application/vnd.proteus.magazine": ["mgz"], "application/vnd.publishare-delta-tree": ["qps"], "application/vnd.pvi.ptid1": ["ptid"], "application/vnd.quark.quarkxpress": ["qxd", "qxt", "qwd", "qwt", "qxl", "qxb"], "application/vnd.realvnc.bed": ["bed"], "application/vnd.recordare.musicxml": ["mxl"], "application/vnd.recordare.musicxml+xml": ["musicxml"], "application/vnd.rig.cryptonote": ["cryptonote"], "application/vnd.rim.cod": ["cod"], "application/vnd.rn-realmedia": ["rm"], "application/vnd.rn-realmedia-vbr": ["rmvb"], "application/vnd.route66.link66+xml": ["link66"], "application/vnd.sailingtracker.track": ["st"], "application/vnd.seemail": ["see"], "application/vnd.sema": ["sema"], "application/vnd.semd": ["semd"], "application/vnd.semf": ["semf"], "application/vnd.shana.informed.formdata": ["ifm"], "application/vnd.shana.informed.formtemplate": ["itp"], "application/vnd.shana.informed.interchange": ["iif"], "application/vnd.shana.informed.package": ["ipk"], "application/vnd.simtech-mindmapper": ["twd", "twds"], "application/vnd.smaf": ["mmf"], "application/vnd.smart.teacher": ["teacher"], "application/vnd.solent.sdkm+xml": ["sdkm", "sdkd"], "application/vnd.spotfire.dxp": ["dxp"], "application/vnd.spotfire.sfs": ["sfs"], "application/vnd.stardivision.calc": ["sdc"], "application/vnd.stardivision.draw": ["sda"], "application/vnd.stardivision.impress": ["sdd"], "application/vnd.stardivision.math": ["smf"], "application/vnd.stardivision.writer": ["sdw", "vor"], "application/vnd.stardivision.writer-global": ["sgl"], "application/vnd.stepmania.package": ["smzip"], "application/vnd.stepmania.stepchart": ["sm"], "application/vnd.sun.wadl+xml": ["wadl"], "application/vnd.sun.xml.calc": ["sxc"], "application/vnd.sun.xml.calc.template": ["stc"], "application/vnd.sun.xml.draw": ["sxd"], "application/vnd.sun.xml.draw.template": ["std"], "application/vnd.sun.xml.impress": ["sxi"], "application/vnd.sun.xml.impress.template": ["sti"], "application/vnd.sun.xml.math": ["sxm"], "application/vnd.sun.xml.writer": ["sxw"], "application/vnd.sun.xml.writer.global": ["sxg"], "application/vnd.sun.xml.writer.template": ["stw"], "application/vnd.sus-calendar": ["sus", "susp"], "application/vnd.svd": ["svd"], "application/vnd.symbian.install": ["sis", "sisx"], "application/vnd.syncml+xml": ["xsm"], "application/vnd.syncml.dm+wbxml": ["bdm"], "application/vnd.syncml.dm+xml": ["xdm"], "application/vnd.tao.intent-module-archive": ["tao"], "application/vnd.tcpdump.pcap": ["pcap", "cap", "dmp"], "application/vnd.tmobile-livetv": ["tmo"], "application/vnd.trid.tpt": ["tpt"], "application/vnd.triscape.mxs": ["mxs"], "application/vnd.trueapp": ["tra"], "application/vnd.ufdl": ["ufd", "ufdl"], "application/vnd.uiq.theme": ["utz"], "application/vnd.umajin": ["umj"], "application/vnd.unity": ["unityweb"], "application/vnd.uoml+xml": ["uoml"], "application/vnd.vcx": ["vcx"], "application/vnd.visio": ["vsd", "vst", "vss", "vsw"], "application/vnd.visionary": ["vis"], "application/vnd.vsf": ["vsf"], "application/vnd.wap.wbxml": ["wbxml"], "application/vnd.wap.wmlc": ["wmlc"], "application/vnd.wap.wmlscriptc": ["wmlsc"], "application/vnd.webturbo": ["wtb"], "application/vnd.wolfram.player": ["nbp"], "application/vnd.wordperfect": ["wpd"], "application/vnd.wqd": ["wqd"], "application/vnd.wt.stf": ["stf"], "application/vnd.xara": ["xar"], "application/vnd.xfdl": ["xfdl"], "application/vnd.yamaha.hv-dic": ["hvd"], "application/vnd.yamaha.hv-script": ["hvs"], "application/vnd.yamaha.hv-voice": ["hvp"], "application/vnd.yamaha.openscoreformat": ["osf"], "application/vnd.yamaha.openscoreformat.osfpvg+xml": ["osfpvg"], "application/vnd.yamaha.smaf-audio": ["saf"], "application/vnd.yamaha.smaf-phrase": ["spf"], "application/vnd.yellowriver-custom-menu": ["cmp"], "application/vnd.zul": ["zir", "zirz"], "application/vnd.zzazz.deck+xml": ["zaz"], "application/voicexml+xml": ["vxml"], "application/wasm": ["wasm"], "application/widget": ["wgt"], "application/winhlp": ["hlp"], "application/wsdl+xml": ["wsdl"], "application/wspolicy+xml": ["wspolicy"], "application/x-7z-compressed": ["7z"], "application/x-abiword": ["abw"], "application/x-ace-compressed": ["ace"], "application/x-apple-diskimage": [], "application/x-arj": ["arj"], "application/x-authorware-bin": ["aab", "x32", "u32", "vox"], "application/x-authorware-map": ["aam"], "application/x-authorware-seg": ["aas"], "application/x-bcpio": ["bcpio"], "application/x-bdoc": [], "application/x-bittorrent": ["torrent"], "application/x-blorb": ["blb", "blorb"], "application/x-bzip": ["bz"], "application/x-bzip2": ["bz2", "boz"], "application/x-cbr": ["cbr", "cba", "cbt", "cbz", "cb7"], "application/x-cdlink": ["vcd"], "application/x-cfs-compressed": ["cfs"], "application/x-chat": ["chat"], "application/x-chess-pgn": ["pgn"], "application/x-chrome-extension": ["crx"], "application/x-cocoa": ["cco"], "application/x-conference": ["nsc"], "application/x-cpio": ["cpio"], "application/x-csh": ["csh"], "application/x-debian-package": ["udeb"], "application/x-dgc-compressed": ["dgc"], "application/x-director": ["dir", "dcr", "dxr", "cst", "cct", "cxt", "w3d", "fgd", "swa"], "application/x-doom": ["wad"], "application/x-dtbncx+xml": ["ncx"], "application/x-dtbook+xml": ["dtb"], "application/x-dtbresource+xml": ["res"], "application/x-dvi": ["dvi"], "application/x-envoy": ["evy"], "application/x-eva": ["eva"], "application/x-font-bdf": ["bdf"], "application/x-font-ghostscript": ["gsf"], "application/x-font-linux-psf": ["psf"], "application/x-font-pcf": ["pcf"], "application/x-font-snf": ["snf"], "application/x-font-type1": ["pfa", "pfb", "pfm", "afm"], "application/x-freearc": ["arc"], "application/x-futuresplash": ["spl"], "application/x-gca-compressed": ["gca"], "application/x-glulx": ["ulx"], "application/x-gnumeric": ["gnumeric"], "application/x-gramps-xml": ["gramps"], "application/x-gtar": ["gtar"], "application/x-hdf": ["hdf"], "application/x-httpd-php": ["php"], "application/x-install-instructions": ["install"], "application/x-iso9660-image": [], "application/x-java-archive-diff": ["jardiff"], "application/x-java-jnlp-file": ["jnlp"], "application/x-latex": ["latex"], "application/x-lua-bytecode": ["luac"], "application/x-lzh-compressed": ["lzh", "lha"], "application/x-makeself": ["run"], "application/x-mie": ["mie"], "application/x-mobipocket-ebook": ["prc", "mobi"], "application/x-ms-application": ["application"], "application/x-ms-shortcut": ["lnk"], "application/x-ms-wmd": ["wmd"], "application/x-ms-wmz": ["wmz"], "application/x-ms-xbap": ["xbap"], "application/x-msaccess": ["mdb"], "application/x-msbinder": ["obd"], "application/x-mscardfile": ["crd"], "application/x-msclip": ["clp"], "application/x-msdos-program": [], "application/x-msdownload": ["com", "bat"], "application/x-msmediaview": ["mvb", "m13", "m14"], "application/x-msmetafile": ["wmf", "emf", "emz"], "application/x-msmoney": ["mny"], "application/x-mspublisher": ["pub"], "application/x-msschedule": ["scd"], "application/x-msterminal": ["trm"], "application/x-mswrite": ["wri"], "application/x-netcdf": ["nc", "cdf"], "application/x-ns-proxy-autoconfig": ["pac"], "application/x-nzb": ["nzb"], "application/x-perl": ["pl", "pm"], "application/x-pilot": [], "application/x-pkcs12": ["p12", "pfx"], "application/x-pkcs7-certificates": ["p7b", "spc"], "application/x-pkcs7-certreqresp": ["p7r"], "application/x-rar-compressed": ["rar"], "application/x-redhat-package-manager": ["rpm"], "application/x-research-info-systems": ["ris"], "application/x-sea": ["sea"], "application/x-sh": ["sh"], "application/x-shar": ["shar"], "application/x-shockwave-flash": ["swf"], "application/x-silverlight-app": ["xap"], "application/x-sql": ["sql"], "application/x-stuffit": ["sit"], "application/x-stuffitx": ["sitx"], "application/x-subrip": ["srt"], "application/x-sv4cpio": ["sv4cpio"], "application/x-sv4crc": ["sv4crc"], "application/x-t3vm-image": ["t3"], "application/x-tads": ["gam"], "application/x-tar": ["tar"], "application/x-tcl": ["tcl", "tk"], "application/x-tex": ["tex"], "application/x-tex-tfm": ["tfm"], "application/x-texinfo": ["texinfo", "texi"], "application/x-tgif": ["obj"], "application/x-ustar": ["ustar"], "application/x-virtualbox-hdd": ["hdd"], "application/x-virtualbox-ova": ["ova"], "application/x-virtualbox-ovf": ["ovf"], "application/x-virtualbox-vbox": ["vbox"], "application/x-virtualbox-vbox-extpack": ["vbox-extpack"], "application/x-virtualbox-vdi": ["vdi"], "application/x-virtualbox-vhd": ["vhd"], "application/x-virtualbox-vmdk": ["vmdk"], "application/x-wais-source": ["src"], "application/x-web-app-manifest+json": ["webapp"], "application/x-x509-ca-cert": ["der", "crt", "pem"], "application/x-xfig": ["fig"], "application/x-xliff+xml": ["xlf"], "application/x-xpinstall": ["xpi"], "application/x-xz": ["xz"], "application/x-zmachine": ["z1", "z2", "z3", "z4", "z5", "z6", "z7", "z8"], "application/xaml+xml": ["xaml"], "application/xcap-diff+xml": ["xdf"], "application/xenc+xml": ["xenc"], "application/xhtml+xml": ["xhtml", "xht"], "application/xml": ["xml", "xsl", "xsd", "rng"], "application/xml-dtd": ["dtd"], "application/xop+xml": ["xop"], "application/xproc+xml": ["xpl"], "application/xslt+xml": ["xslt"], "application/xspf+xml": ["xspf"], "application/xv+xml": ["mxml", "xhvml", "xvml", "xvm"], "application/yang": ["yang"], "application/yin+xml": ["yin"], "application/zip": ["zip"], "audio/3gpp": [], "audio/adpcm": ["adp"], "audio/basic": ["au", "snd"], "audio/midi": ["mid", "midi", "kar", "rmi"], "audio/mp3": [], "audio/mp4": ["m4a", "mp4a"], "audio/mpeg": ["mpga", "mp2", "mp2a", "mp3", "m2a", "m3a"], "audio/ogg": ["oga", "ogg", "spx"], "audio/s3m": ["s3m"], "audio/silk": ["sil"], "audio/vnd.dece.audio": ["uva", "uvva"], "audio/vnd.digital-winds": ["eol"], "audio/vnd.dra": ["dra"], "audio/vnd.dts": ["dts"], "audio/vnd.dts.hd": ["dtshd"], "audio/vnd.lucent.voice": ["lvp"], "audio/vnd.ms-playready.media.pya": ["pya"], "audio/vnd.nuera.ecelp4800": ["ecelp4800"], "audio/vnd.nuera.ecelp7470": ["ecelp7470"], "audio/vnd.nuera.ecelp9600": ["ecelp9600"], "audio/vnd.rip": ["rip"], "audio/wav": ["wav"], "audio/wave": [], "audio/webm": ["weba"], "audio/x-aac": ["aac"], "audio/x-aiff": ["aif", "aiff", "aifc"], "audio/x-caf": ["caf"], "audio/x-flac": ["flac"], "audio/x-m4a": [], "audio/x-matroska": ["mka"], "audio/x-mpegurl": ["m3u"], "audio/x-ms-wax": ["wax"], "audio/x-ms-wma": ["wma"], "audio/x-pn-realaudio": ["ram", "ra"], "audio/x-pn-realaudio-plugin": ["rmp"], "audio/x-realaudio": [], "audio/x-wav": [], "audio/xm": ["xm"], "chemical/x-cdx": ["cdx"], "chemical/x-cif": ["cif"], "chemical/x-cmdf": ["cmdf"], "chemical/x-cml": ["cml"], "chemical/x-csml": ["csml"], "chemical/x-xyz": ["xyz"], "font/collection": ["ttc"], "font/otf": ["otf"], "font/ttf": ["ttf"], "font/woff": ["woff"], "font/woff2": ["woff2"], "image/apng": ["apng"], "image/bmp": ["bmp"], "image/cgm": ["cgm"], "image/g3fax": ["g3"], "image/gif": ["gif"], "image/ief": ["ief"], "image/jp2": ["jp2", "jpg2"], "image/jpeg": ["jpeg", "jpg", "jpe"], "image/jpm": ["jpm"], "image/jpx": ["jpx", "jpf"], "image/ktx": ["ktx"], "image/png": ["png"], "image/prs.btif": ["btif"], "image/sgi": ["sgi"], "image/svg+xml": ["svg", "svgz"], "image/tiff": ["tiff", "tif"], "image/vnd.adobe.photoshop": ["psd"], "image/vnd.dece.graphic": ["uvi", "uvvi", "uvg", "uvvg"], "image/vnd.djvu": ["djvu", "djv"], "image/vnd.dvb.subtitle": [], "image/vnd.dwg": ["dwg"], "image/vnd.dxf": ["dxf"], "image/vnd.fastbidsheet": ["fbs"], "image/vnd.fpx": ["fpx"], "image/vnd.fst": ["fst"], "image/vnd.fujixerox.edmics-mmr": ["mmr"], "image/vnd.fujixerox.edmics-rlc": ["rlc"], "image/vnd.ms-modi": ["mdi"], "image/vnd.ms-photo": ["wdp"], "image/vnd.net-fpx": ["npx"], "image/vnd.wap.wbmp": ["wbmp"], "image/vnd.xiff": ["xif"], "image/webp": ["webp"], "image/x-3ds": ["3ds"], "image/x-cmu-raster": ["ras"], "image/x-cmx": ["cmx"], "image/x-freehand": ["fh", "fhc", "fh4", "fh5", "fh7"], "image/x-icon": ["ico"], "image/x-jng": ["jng"], "image/x-mrsid-image": ["sid"], "image/x-ms-bmp": [], "image/x-pcx": ["pcx"], "image/x-pict": ["pic", "pct"], "image/x-portable-anymap": ["pnm"], "image/x-portable-bitmap": ["pbm"], "image/x-portable-graymap": ["pgm"], "image/x-portable-pixmap": ["ppm"], "image/x-rgb": ["rgb"], "image/x-tga": ["tga"], "image/x-xbitmap": ["xbm"], "image/x-xpixmap": ["xpm"], "image/x-xwindowdump": ["xwd"], "message/rfc822": ["eml", "mime"], "model/gltf+json": ["gltf"], "model/gltf-binary": ["glb"], "model/iges": ["igs", "iges"], "model/mesh": ["msh", "mesh", "silo"], "model/vnd.collada+xml": ["dae"], "model/vnd.dwf": ["dwf"], "model/vnd.gdl": ["gdl"], "model/vnd.gtw": ["gtw"], "model/vnd.mts": ["mts"], "model/vnd.vtu": ["vtu"], "model/vrml": ["wrl", "vrml"], "model/x3d+binary": ["x3db", "x3dbz"], "model/x3d+vrml": ["x3dv", "x3dvz"], "model/x3d+xml": ["x3d", "x3dz"], "text/cache-manifest": ["appcache", "manifest"], "text/calendar": ["ics", "ifb"], "text/coffeescript": ["coffee", "litcoffee"], "text/css": ["css"], "text/csv": ["csv"], "text/hjson": ["hjson"], "text/html": ["html", "htm", "shtml"], "text/jade": ["jade"], "text/jsx": ["jsx"], "text/less": ["less"], "text/markdown": ["markdown", "md"], "text/mathml": ["mml"], "text/n3": ["n3"], "text/plain": ["txt", "text", "conf", "def", "list", "log", "in", "ini"], "text/prs.lines.tag": ["dsc"], "text/richtext": ["rtx"], "text/rtf": [], "text/sgml": ["sgml", "sgm"], "text/slim": ["slim", "slm"], "text/stylus": ["stylus", "styl"], "text/tab-separated-values": ["tsv"], "text/troff": ["t", "tr", "roff", "man", "me", "ms"], "text/turtle": ["ttl"], "text/uri-list": ["uri", "uris", "urls"], "text/vcard": ["vcard"], "text/vnd.curl": ["curl"], "text/vnd.curl.dcurl": ["dcurl"], "text/vnd.curl.mcurl": ["mcurl"], "text/vnd.curl.scurl": ["scurl"], "text/vnd.dvb.subtitle": ["sub"], "text/vnd.fly": ["fly"], "text/vnd.fmi.flexstor": ["flx"], "text/vnd.graphviz": ["gv"], "text/vnd.in3d.3dml": ["3dml"], "text/vnd.in3d.spot": ["spot"], "text/vnd.sun.j2me.app-descriptor": ["jad"], "text/vnd.wap.wml": ["wml"], "text/vnd.wap.wmlscript": ["wmls"], "text/vtt": ["vtt"], "text/x-asm": ["s", "asm"], "text/x-c": ["c", "cc", "cxx", "cpp", "h", "hh", "dic"], "text/x-component": ["htc"], "text/x-fortran": ["f", "for", "f77", "f90"], "text/x-handlebars-template": ["hbs"], "text/x-java-source": ["java"], "text/x-lua": ["lua"], "text/x-markdown": ["mkd"], "text/x-nfo": ["nfo"], "text/x-opml": ["opml"], "text/x-org": [], "text/x-pascal": ["p", "pas"], "text/x-processing": ["pde"], "text/x-sass": ["sass"], "text/x-scss": ["scss"], "text/x-setext": ["etx"], "text/x-sfv": ["sfv"], "text/x-suse-ymp": ["ymp"], "text/x-uuencode": ["uu"], "text/x-vcalendar": ["vcs"], "text/x-vcard": ["vcf"], "text/xml": [], "text/yaml": ["yaml", "yml"], "video/3gpp": ["3gp", "3gpp"], "video/3gpp2": ["3g2"], "video/h261": ["h261"], "video/h263": ["h263"], "video/h264": ["h264"], "video/jpeg": ["jpgv"], "video/jpm": ["jpgm"], "video/mj2": ["mj2", "mjp2"], "video/mp2t": ["ts"], "video/mp4": ["mp4", "mp4v", "mpg4"], "video/mpeg": ["mpeg", "mpg", "mpe", "m1v", "m2v"], "video/ogg": ["ogv"], "video/quicktime": ["qt", "mov"], "video/vnd.dece.hd": ["uvh", "uvvh"], "video/vnd.dece.mobile": ["uvm", "uvvm"], "video/vnd.dece.pd": ["uvp", "uvvp"], "video/vnd.dece.sd": ["uvs", "uvvs"], "video/vnd.dece.video": ["uvv", "uvvv"], "video/vnd.dvb.file": ["dvb"], "video/vnd.fvt": ["fvt"], "video/vnd.mpegurl": ["mxu", "m4u"], "video/vnd.ms-playready.media.pyv": ["pyv"], "video/vnd.uvvu.mp4": ["uvu", "uvvu"], "video/vnd.vivo": ["viv"], "video/webm": ["webm"], "video/x-f4v": ["f4v"], "video/x-fli": ["fli"], "video/x-flv": ["flv"], "video/x-m4v": ["m4v"], "video/x-matroska": ["mkv", "mk3d", "mks"], "video/x-mng": ["mng"], "video/x-ms-asf": ["asf", "asx"], "video/x-ms-vob": ["vob"], "video/x-ms-wm": ["wm"], "video/x-ms-wmv": ["wmv"], "video/x-ms-wmx": ["wmx"], "video/x-ms-wvx": ["wvx"], "video/x-msvideo": ["avi"], "video/x-sgi-movie": ["movie"], "video/x-smv": ["smv"], "x-conference/x-cooltalk": ["ice"] };
    module.exports = json;
},
/* less/lib/less-node/file-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var path_1 = tslib_1.__importDefault(require("path"));
    var fs_1 = tslib_1.__importDefault(require(63) /* ./fs */);
    var abstract_file_manager_js_1 = tslib_1.__importDefault(require(68) /* ../less/environment/abstract-file-manager.js */);
    var FileManager = function () { };
    FileManager.prototype = Object.assign(new abstract_file_manager_js_1.default(), {
        supports: function () {
            return true;
        },
        supportsSync: function () {
            return true;
        },
        loadFile: function (filename, currentDirectory, options, environment, callback) {
            var fullFilename;
            var isAbsoluteFilename = this.isPathAbsolute(filename);
            var filenamesTried = [];
            var self = this;
            var prefix = filename.slice(0, 1);
            var explicit = prefix === '.' || prefix === '/';
            var result = null;
            var isNodeModule = false;
            var npmPrefix = 'npm://';
            options = options || {};
            var paths = isAbsoluteFilename ? [''] : [currentDirectory];
            if (options.paths) {
                paths.push.apply(paths, options.paths);
            }
            if (!isAbsoluteFilename && paths.indexOf('.') === -1) {
                paths.push('.');
            }
            var prefixes = options.prefixes || [''];
            var fileParts = this.extractUrlParts(filename);
            if (options.syncImport) {
                getFileData(returnData, returnData);
                if (callback) {
                    callback(result.error, result);
                }
                else {
                    return result;
                }
            }
            else {
                // promise is guaranteed to be asyncronous
                // which helps as it allows the file handle
                // to be closed before it continues with the next file
                return new Promise(getFileData);
            }
            function returnData(data) {
                if (!data.filename) {
                    result = { error: data };
                }
                else {
                    result = data;
                }
            }
            function getFileData(fulfill, reject) {
                (function tryPathIndex(i) {
                    if (i < paths.length) {
                        (function tryPrefix(j) {
                            if (j < prefixes.length) {
                                isNodeModule = false;
                                fullFilename = fileParts.rawPath + prefixes[j] + fileParts.filename;
                                if (paths[i]) {
                                    fullFilename = path_1.default.join(paths[i], fullFilename);
                                }
                                if (!explicit && paths[i] === '.') {
                                    try {
                                        fullFilename = require.resolve(fullFilename);
                                        isNodeModule = true;
                                    }
                                    catch (e) {
                                        filenamesTried.push(npmPrefix + fullFilename);
                                        tryWithExtension();
                                    }
                                }
                                else {
                                    tryWithExtension();
                                }
                                function tryWithExtension() {
                                    var extFilename = options.ext ? self.tryAppendExtension(fullFilename, options.ext) : fullFilename;
                                    if (extFilename !== fullFilename && !explicit && paths[i] === '.') {
                                        try {
                                            fullFilename = require.resolve(extFilename);
                                            isNodeModule = true;
                                        }
                                        catch (e) {
                                            filenamesTried.push(npmPrefix + extFilename);
                                            fullFilename = extFilename;
                                        }
                                    }
                                    else {
                                        fullFilename = extFilename;
                                    }
                                }
                                var readFileArgs = [fullFilename];
                                if (!options.rawBuffer) {
                                    readFileArgs.push('utf-8');
                                }
                                if (options.syncImport) {
                                    try {
                                        var data = fs_1.default.readFileSync.apply(this, readFileArgs);
                                        fulfill({ contents: data, filename: fullFilename });
                                    }
                                    catch (e) {
                                        filenamesTried.push(isNodeModule ? npmPrefix + fullFilename : fullFilename);
                                        return tryPrefix(j + 1);
                                    }
                                }
                                else {
                                    readFileArgs.push(function (e, data) {
                                        if (e) {
                                            filenamesTried.push(isNodeModule ? npmPrefix + fullFilename : fullFilename);
                                            return tryPrefix(j + 1);
                                        }
                                        fulfill({ contents: data, filename: fullFilename });
                                    });
                                    fs_1.default.readFile.apply(this, readFileArgs);
                                }
                            }
                            else {
                                tryPathIndex(i + 1);
                            }
                        })(0);
                    }
                    else {
                        reject({ type: 'File', message: "'" + filename + "' wasn't found. Tried - " + filenamesTried.join(',') });
                    }
                }(0));
            }
        },
        loadFileSync: function (filename, currentDirectory, options, environment) {
            options.syncImport = true;
            return this.loadFile(filename, currentDirectory, options, environment);
        }
    });
    exports.default = FileManager;
    
},
/* less/lib/less-node/fs.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var fs;
    try {
        fs = require(64) /* graceful-fs */;
    }
    catch (e) {
        fs = require('fs');
    }
    exports.default = fs;
    
},
/* graceful-fs/graceful-fs.js */ function _(require, module, exports, __esModule, __esExport) {
    var fs = require('fs');
    var polyfills = require(65) /* ./polyfills.js */;
    var legacy = require(66) /* ./legacy-streams.js */;
    var clone = require(67) /* ./clone.js */;
    var util = require('util');
    /* istanbul ignore next - node 0.x polyfill */
    var gracefulQueue;
    var previousSymbol;
    /* istanbul ignore else - node 0.x polyfill */
    if (typeof Symbol === 'function' && typeof Symbol.for === 'function') {
        gracefulQueue = Symbol.for('graceful-fs.queue');
        // This is used in testing by future versions
        previousSymbol = Symbol.for('graceful-fs.previous');
    }
    else {
        gracefulQueue = '___graceful-fs.queue';
        previousSymbol = '___graceful-fs.previous';
    }
    function noop() { }
    function publishQueue(context, queue) {
        Object.defineProperty(context, gracefulQueue, {
            get: function () {
                return queue;
            }
        });
    }
    var debug = noop;
    if (util.debuglog)
        debug = util.debuglog('gfs4');
    else if (/\bgfs4\b/i.test(process.env.NODE_DEBUG || ''))
        debug = function () {
            var m = util.format.apply(util, arguments);
            m = 'GFS4: ' + m.split(/\n/).join('\nGFS4: ');
            console.error(m);
        };
    // Once time initialization
    if (!fs[gracefulQueue]) {
        // This queue can be shared by multiple loaded instances
        var queue = global[gracefulQueue] || [];
        publishQueue(fs, queue);
        // Patch fs.close/closeSync to shared queue version, because we need
        // to retry() whenever a close happens *anywhere* in the program.
        // This is essential when multiple graceful-fs instances are
        // in play at the same time.
        fs.close = (function (fs$close) {
            function close(fd, cb) {
                return fs$close.call(fs, fd, function (err) {
                    // This function uses the graceful-fs shared queue
                    if (!err) {
                        resetQueue();
                    }
                    if (typeof cb === 'function')
                        cb.apply(this, arguments);
                });
            }
            Object.defineProperty(close, previousSymbol, {
                value: fs$close
            });
            return close;
        })(fs.close);
        fs.closeSync = (function (fs$closeSync) {
            function closeSync(fd) {
                // This function uses the graceful-fs shared queue
                fs$closeSync.apply(fs, arguments);
                resetQueue();
            }
            Object.defineProperty(closeSync, previousSymbol, {
                value: fs$closeSync
            });
            return closeSync;
        })(fs.closeSync);
        if (/\bgfs4\b/i.test(process.env.NODE_DEBUG || '')) {
            process.on('exit', function () {
                debug(fs[gracefulQueue]);
                require('assert').equal(fs[gracefulQueue].length, 0);
            });
        }
    }
    if (!global[gracefulQueue]) {
        publishQueue(global, fs[gracefulQueue]);
    }
    module.exports = patch(clone(fs));
    if (process.env.TEST_GRACEFUL_FS_GLOBAL_PATCH && !fs.__patched) {
        module.exports = patch(fs);
        fs.__patched = true;
    }
    function patch(fs) {
        // Everything that references the open() function needs to be in here
        polyfills(fs);
        fs.gracefulify = patch;
        fs.createReadStream = createReadStream;
        fs.createWriteStream = createWriteStream;
        var fs$readFile = fs.readFile;
        fs.readFile = readFile;
        function readFile(path, options, cb) {
            if (typeof options === 'function')
                cb = options, options = null;
            return go$readFile(path, options, cb);
            function go$readFile(path, options, cb, startTime) {
                return fs$readFile(path, options, function (err) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$readFile, [path, options, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        var fs$writeFile = fs.writeFile;
        fs.writeFile = writeFile;
        function writeFile(path, data, options, cb) {
            if (typeof options === 'function')
                cb = options, options = null;
            return go$writeFile(path, data, options, cb);
            function go$writeFile(path, data, options, cb, startTime) {
                return fs$writeFile(path, data, options, function (err) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$writeFile, [path, data, options, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        var fs$appendFile = fs.appendFile;
        if (fs$appendFile)
            fs.appendFile = appendFile;
        function appendFile(path, data, options, cb) {
            if (typeof options === 'function')
                cb = options, options = null;
            return go$appendFile(path, data, options, cb);
            function go$appendFile(path, data, options, cb, startTime) {
                return fs$appendFile(path, data, options, function (err) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$appendFile, [path, data, options, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        var fs$copyFile = fs.copyFile;
        if (fs$copyFile)
            fs.copyFile = copyFile;
        function copyFile(src, dest, flags, cb) {
            if (typeof flags === 'function') {
                cb = flags;
                flags = 0;
            }
            return go$copyFile(src, dest, flags, cb);
            function go$copyFile(src, dest, flags, cb, startTime) {
                return fs$copyFile(src, dest, flags, function (err) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$copyFile, [src, dest, flags, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        var fs$readdir = fs.readdir;
        fs.readdir = readdir;
        var noReaddirOptionVersions = /^v[0-5]\./;
        function readdir(path, options, cb) {
            if (typeof options === 'function')
                cb = options, options = null;
            var go$readdir = noReaddirOptionVersions.test(process.version)
                ? function go$readdir(path, options, cb, startTime) {
                    return fs$readdir(path, fs$readdirCallback(path, options, cb, startTime));
                }
                : function go$readdir(path, options, cb, startTime) {
                    return fs$readdir(path, options, fs$readdirCallback(path, options, cb, startTime));
                };
            return go$readdir(path, options, cb);
            function fs$readdirCallback(path, options, cb, startTime) {
                return function (err, files) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([
                            go$readdir,
                            [path, options, cb],
                            err,
                            startTime || Date.now(),
                            Date.now()
                        ]);
                    else {
                        if (files && files.sort)
                            files.sort();
                        if (typeof cb === 'function')
                            cb.call(this, err, files);
                    }
                };
            }
        }
        if (process.version.substr(0, 4) === 'v0.8') {
            var legStreams = legacy(fs);
            ReadStream = legStreams.ReadStream;
            WriteStream = legStreams.WriteStream;
        }
        var fs$ReadStream = fs.ReadStream;
        if (fs$ReadStream) {
            ReadStream.prototype = Object.create(fs$ReadStream.prototype);
            ReadStream.prototype.open = ReadStream$open;
        }
        var fs$WriteStream = fs.WriteStream;
        if (fs$WriteStream) {
            WriteStream.prototype = Object.create(fs$WriteStream.prototype);
            WriteStream.prototype.open = WriteStream$open;
        }
        Object.defineProperty(fs, 'ReadStream', {
            get: function () {
                return ReadStream;
            },
            set: function (val) {
                ReadStream = val;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(fs, 'WriteStream', {
            get: function () {
                return WriteStream;
            },
            set: function (val) {
                WriteStream = val;
            },
            enumerable: true,
            configurable: true
        });
        // legacy names
        var FileReadStream = ReadStream;
        Object.defineProperty(fs, 'FileReadStream', {
            get: function () {
                return FileReadStream;
            },
            set: function (val) {
                FileReadStream = val;
            },
            enumerable: true,
            configurable: true
        });
        var FileWriteStream = WriteStream;
        Object.defineProperty(fs, 'FileWriteStream', {
            get: function () {
                return FileWriteStream;
            },
            set: function (val) {
                FileWriteStream = val;
            },
            enumerable: true,
            configurable: true
        });
        function ReadStream(path, options) {
            if (this instanceof ReadStream)
                return fs$ReadStream.apply(this, arguments), this;
            else
                return ReadStream.apply(Object.create(ReadStream.prototype), arguments);
        }
        function ReadStream$open() {
            var that = this;
            open(that.path, that.flags, that.mode, function (err, fd) {
                if (err) {
                    if (that.autoClose)
                        that.destroy();
                    that.emit('error', err);
                }
                else {
                    that.fd = fd;
                    that.emit('open', fd);
                    that.read();
                }
            });
        }
        function WriteStream(path, options) {
            if (this instanceof WriteStream)
                return fs$WriteStream.apply(this, arguments), this;
            else
                return WriteStream.apply(Object.create(WriteStream.prototype), arguments);
        }
        function WriteStream$open() {
            var that = this;
            open(that.path, that.flags, that.mode, function (err, fd) {
                if (err) {
                    that.destroy();
                    that.emit('error', err);
                }
                else {
                    that.fd = fd;
                    that.emit('open', fd);
                }
            });
        }
        function createReadStream(path, options) {
            return new fs.ReadStream(path, options);
        }
        function createWriteStream(path, options) {
            return new fs.WriteStream(path, options);
        }
        var fs$open = fs.open;
        fs.open = open;
        function open(path, flags, mode, cb) {
            if (typeof mode === 'function')
                cb = mode, mode = null;
            return go$open(path, flags, mode, cb);
            function go$open(path, flags, mode, cb, startTime) {
                return fs$open(path, flags, mode, function (err, fd) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$open, [path, flags, mode, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        return fs;
    }
    function enqueue(elem) {
        debug('ENQUEUE', elem[0].name, elem[1]);
        fs[gracefulQueue].push(elem);
        retry();
    }
    // keep track of the timeout between retry() calls
    var retryTimer;
    // reset the startTime and lastTime to now
    // this resets the start of the 60 second overall timeout as well as the
    // delay between attempts so that we'll retry these jobs sooner
    function resetQueue() {
        var now = Date.now();
        for (var i = 0; i < fs[gracefulQueue].length; ++i) {
            // entries that are only a length of 2 are from an older version, don't
            // bother modifying those since they'll be retried anyway.
            if (fs[gracefulQueue][i].length > 2) {
                fs[gracefulQueue][i][3] = now; // startTime
                fs[gracefulQueue][i][4] = now; // lastTime
            }
        }
        // call retry to make sure we're actively processing the queue
        retry();
    }
    function retry() {
        // clear the timer and remove it to help prevent unintended concurrency
        clearTimeout(retryTimer);
        retryTimer = undefined;
        if (fs[gracefulQueue].length === 0)
            return;
        var elem = fs[gracefulQueue].shift();
        var fn = elem[0];
        var args = elem[1];
        // these items may be unset if they were added by an older graceful-fs
        var err = elem[2];
        var startTime = elem[3];
        var lastTime = elem[4];
        // if we don't have a startTime we have no way of knowing if we've waited
        // long enough, so go ahead and retry this item now
        if (startTime === undefined) {
            debug('RETRY', fn.name, args);
            fn.apply(null, args);
        }
        else if (Date.now() - startTime >= 60000) {
            // it's been more than 60 seconds total, bail now
            debug('TIMEOUT', fn.name, args);
            var cb = args.pop();
            if (typeof cb === 'function')
                cb.call(null, err);
        }
        else {
            // the amount of time between the last attempt and right now
            var sinceAttempt = Date.now() - lastTime;
            // the amount of time between when we first tried, and when we last tried
            // rounded up to at least 1
            var sinceStart = Math.max(lastTime - startTime, 1);
            // backoff. wait longer than the total time we've been retrying, but only
            // up to a maximum of 100ms
            var desiredDelay = Math.min(sinceStart * 1.2, 100);
            // it's been long enough since the last retry, do it again
            if (sinceAttempt >= desiredDelay) {
                debug('RETRY', fn.name, args);
                fn.apply(null, args.concat([startTime]));
            }
            else {
                // if we can't do this job yet, push it to the end of the queue
                // and let the next iteration check again
                fs[gracefulQueue].push(elem);
            }
        }
        // schedule our next run if one isn't already scheduled
        if (retryTimer === undefined) {
            retryTimer = setTimeout(retry, 0);
        }
    }
},
/* graceful-fs/polyfills.js */ function _(require, module, exports, __esModule, __esExport) {
    var constants = require('constants');
    var origCwd = process.cwd;
    var cwd = null;
    var platform = process.env.GRACEFUL_FS_PLATFORM || process.platform;
    process.cwd = function () {
        if (!cwd)
            cwd = origCwd.call(process);
        return cwd;
    };
    try {
        process.cwd();
    }
    catch (er) { }
    // This check is needed until node.js 12 is required
    if (typeof process.chdir === 'function') {
        var chdir = process.chdir;
        process.chdir = function (d) {
            cwd = null;
            chdir.call(process, d);
        };
        if (Object.setPrototypeOf)
            Object.setPrototypeOf(process.chdir, chdir);
    }
    module.exports = patch;
    function patch(fs) {
        // (re-)implement some things that are known busted or missing.
        // lchmod, broken prior to 0.6.2
        // back-port the fix here.
        if (constants.hasOwnProperty('O_SYMLINK') &&
            process.version.match(/^v0\.6\.[0-2]|^v0\.5\./)) {
            patchLchmod(fs);
        }
        // lutimes implementation, or no-op
        if (!fs.lutimes) {
            patchLutimes(fs);
        }
        // https://github.com/isaacs/node-graceful-fs/issues/4
        // Chown should not fail on einval or eperm if non-root.
        // It should not fail on enosys ever, as this just indicates
        // that a fs doesn't support the intended operation.
        fs.chown = chownFix(fs.chown);
        fs.fchown = chownFix(fs.fchown);
        fs.lchown = chownFix(fs.lchown);
        fs.chmod = chmodFix(fs.chmod);
        fs.fchmod = chmodFix(fs.fchmod);
        fs.lchmod = chmodFix(fs.lchmod);
        fs.chownSync = chownFixSync(fs.chownSync);
        fs.fchownSync = chownFixSync(fs.fchownSync);
        fs.lchownSync = chownFixSync(fs.lchownSync);
        fs.chmodSync = chmodFixSync(fs.chmodSync);
        fs.fchmodSync = chmodFixSync(fs.fchmodSync);
        fs.lchmodSync = chmodFixSync(fs.lchmodSync);
        fs.stat = statFix(fs.stat);
        fs.fstat = statFix(fs.fstat);
        fs.lstat = statFix(fs.lstat);
        fs.statSync = statFixSync(fs.statSync);
        fs.fstatSync = statFixSync(fs.fstatSync);
        fs.lstatSync = statFixSync(fs.lstatSync);
        // if lchmod/lchown do not exist, then make them no-ops
        if (fs.chmod && !fs.lchmod) {
            fs.lchmod = function (path, mode, cb) {
                if (cb)
                    process.nextTick(cb);
            };
            fs.lchmodSync = function () { };
        }
        if (fs.chown && !fs.lchown) {
            fs.lchown = function (path, uid, gid, cb) {
                if (cb)
                    process.nextTick(cb);
            };
            fs.lchownSync = function () { };
        }
        // on Windows, A/V software can lock the directory, causing this
        // to fail with an EACCES or EPERM if the directory contains newly
        // created files.  Try again on failure, for up to 60 seconds.
        // Set the timeout this long because some Windows Anti-Virus, such as Parity
        // bit9, may lock files for up to a minute, causing npm package install
        // failures. Also, take care to yield the scheduler. Windows scheduling gives
        // CPU to a busy looping process, which can cause the program causing the lock
        // contention to be starved of CPU by node, so the contention doesn't resolve.
        if (platform === "win32") {
            fs.rename = typeof fs.rename !== 'function' ? fs.rename
                : (function (fs$rename) {
                    function rename(from, to, cb) {
                        var start = Date.now();
                        var backoff = 0;
                        fs$rename(from, to, function CB(er) {
                            if (er
                                && (er.code === "EACCES" || er.code === "EPERM" || er.code === "EBUSY")
                                && Date.now() - start < 60000) {
                                setTimeout(function () {
                                    fs.stat(to, function (stater, st) {
                                        if (stater && stater.code === "ENOENT")
                                            fs$rename(from, to, CB);
                                        else
                                            cb(er);
                                    });
                                }, backoff);
                                if (backoff < 100)
                                    backoff += 10;
                                return;
                            }
                            if (cb)
                                cb(er);
                        });
                    }
                    if (Object.setPrototypeOf)
                        Object.setPrototypeOf(rename, fs$rename);
                    return rename;
                })(fs.rename);
        }
        // if read() returns EAGAIN, then just try it again.
        fs.read = typeof fs.read !== 'function' ? fs.read
            : (function (fs$read) {
                function read(fd, buffer, offset, length, position, callback_) {
                    var callback;
                    if (callback_ && typeof callback_ === 'function') {
                        var eagCounter = 0;
                        callback = function (er, _, __) {
                            if (er && er.code === 'EAGAIN' && eagCounter < 10) {
                                eagCounter++;
                                return fs$read.call(fs, fd, buffer, offset, length, position, callback);
                            }
                            callback_.apply(this, arguments);
                        };
                    }
                    return fs$read.call(fs, fd, buffer, offset, length, position, callback);
                }
                // This ensures `util.promisify` works as it does for native `fs.read`.
                if (Object.setPrototypeOf)
                    Object.setPrototypeOf(read, fs$read);
                return read;
            })(fs.read);
        fs.readSync = typeof fs.readSync !== 'function' ? fs.readSync
            : (function (fs$readSync) {
                return function (fd, buffer, offset, length, position) {
                    var eagCounter = 0;
                    while (true) {
                        try {
                            return fs$readSync.call(fs, fd, buffer, offset, length, position);
                        }
                        catch (er) {
                            if (er.code === 'EAGAIN' && eagCounter < 10) {
                                eagCounter++;
                                continue;
                            }
                            throw er;
                        }
                    }
                };
            })(fs.readSync);
        function patchLchmod(fs) {
            fs.lchmod = function (path, mode, callback) {
                fs.open(path, constants.O_WRONLY | constants.O_SYMLINK, mode, function (err, fd) {
                    if (err) {
                        if (callback)
                            callback(err);
                        return;
                    }
                    // prefer to return the chmod error, if one occurs,
                    // but still try to close, and report closing errors if they occur.
                    fs.fchmod(fd, mode, function (err) {
                        fs.close(fd, function (err2) {
                            if (callback)
                                callback(err || err2);
                        });
                    });
                });
            };
            fs.lchmodSync = function (path, mode) {
                var fd = fs.openSync(path, constants.O_WRONLY | constants.O_SYMLINK, mode);
                // prefer to return the chmod error, if one occurs,
                // but still try to close, and report closing errors if they occur.
                var threw = true;
                var ret;
                try {
                    ret = fs.fchmodSync(fd, mode);
                    threw = false;
                }
                finally {
                    if (threw) {
                        try {
                            fs.closeSync(fd);
                        }
                        catch (er) { }
                    }
                    else {
                        fs.closeSync(fd);
                    }
                }
                return ret;
            };
        }
        function patchLutimes(fs) {
            if (constants.hasOwnProperty("O_SYMLINK") && fs.futimes) {
                fs.lutimes = function (path, at, mt, cb) {
                    fs.open(path, constants.O_SYMLINK, function (er, fd) {
                        if (er) {
                            if (cb)
                                cb(er);
                            return;
                        }
                        fs.futimes(fd, at, mt, function (er) {
                            fs.close(fd, function (er2) {
                                if (cb)
                                    cb(er || er2);
                            });
                        });
                    });
                };
                fs.lutimesSync = function (path, at, mt) {
                    var fd = fs.openSync(path, constants.O_SYMLINK);
                    var ret;
                    var threw = true;
                    try {
                        ret = fs.futimesSync(fd, at, mt);
                        threw = false;
                    }
                    finally {
                        if (threw) {
                            try {
                                fs.closeSync(fd);
                            }
                            catch (er) { }
                        }
                        else {
                            fs.closeSync(fd);
                        }
                    }
                    return ret;
                };
            }
            else if (fs.futimes) {
                fs.lutimes = function (_a, _b, _c, cb) { if (cb)
                    process.nextTick(cb); };
                fs.lutimesSync = function () { };
            }
        }
        function chmodFix(orig) {
            if (!orig)
                return orig;
            return function (target, mode, cb) {
                return orig.call(fs, target, mode, function (er) {
                    if (chownErOk(er))
                        er = null;
                    if (cb)
                        cb.apply(this, arguments);
                });
            };
        }
        function chmodFixSync(orig) {
            if (!orig)
                return orig;
            return function (target, mode) {
                try {
                    return orig.call(fs, target, mode);
                }
                catch (er) {
                    if (!chownErOk(er))
                        throw er;
                }
            };
        }
        function chownFix(orig) {
            if (!orig)
                return orig;
            return function (target, uid, gid, cb) {
                return orig.call(fs, target, uid, gid, function (er) {
                    if (chownErOk(er))
                        er = null;
                    if (cb)
                        cb.apply(this, arguments);
                });
            };
        }
        function chownFixSync(orig) {
            if (!orig)
                return orig;
            return function (target, uid, gid) {
                try {
                    return orig.call(fs, target, uid, gid);
                }
                catch (er) {
                    if (!chownErOk(er))
                        throw er;
                }
            };
        }
        function statFix(orig) {
            if (!orig)
                return orig;
            // Older versions of Node erroneously returned signed integers for
            // uid + gid.
            return function (target, options, cb) {
                if (typeof options === 'function') {
                    cb = options;
                    options = null;
                }
                function callback(er, stats) {
                    if (stats) {
                        if (stats.uid < 0)
                            stats.uid += 0x100000000;
                        if (stats.gid < 0)
                            stats.gid += 0x100000000;
                    }
                    if (cb)
                        cb.apply(this, arguments);
                }
                return options ? orig.call(fs, target, options, callback)
                    : orig.call(fs, target, callback);
            };
        }
        function statFixSync(orig) {
            if (!orig)
                return orig;
            // Older versions of Node erroneously returned signed integers for
            // uid + gid.
            return function (target, options) {
                var stats = options ? orig.call(fs, target, options)
                    : orig.call(fs, target);
                if (stats) {
                    if (stats.uid < 0)
                        stats.uid += 0x100000000;
                    if (stats.gid < 0)
                        stats.gid += 0x100000000;
                }
                return stats;
            };
        }
        // ENOSYS means that the fs doesn't support the op. Just ignore
        // that, because it doesn't matter.
        //
        // if there's no getuid, or if getuid() is something other
        // than 0, and the error is EINVAL or EPERM, then just ignore
        // it.
        //
        // This specific case is a silent failure in cp, install, tar,
        // and most other unix tools that manage permissions.
        //
        // When running as root, or if other types of errors are
        // encountered, then it's strict.
        function chownErOk(er) {
            if (!er)
                return true;
            if (er.code === "ENOSYS")
                return true;
            var nonroot = !process.getuid || process.getuid() !== 0;
            if (nonroot) {
                if (er.code === "EINVAL" || er.code === "EPERM")
                    return true;
            }
            return false;
        }
    }
},
/* graceful-fs/legacy-streams.js */ function _(require, module, exports, __esModule, __esExport) {
    var Stream = require('stream').Stream;
    module.exports = legacy;
    function legacy(fs) {
        return {
            ReadStream: ReadStream,
            WriteStream: WriteStream
        };
        function ReadStream(path, options) {
            if (!(this instanceof ReadStream))
                return new ReadStream(path, options);
            Stream.call(this);
            var self = this;
            this.path = path;
            this.fd = null;
            this.readable = true;
            this.paused = false;
            this.flags = 'r';
            this.mode = 438; /*=0666*/
            this.bufferSize = 64 * 1024;
            options = options || {};
            // Mixin options into this
            var keys = Object.keys(options);
            for (var index = 0, length = keys.length; index < length; index++) {
                var key = keys[index];
                this[key] = options[key];
            }
            if (this.encoding)
                this.setEncoding(this.encoding);
            if (this.start !== undefined) {
                if ('number' !== typeof this.start) {
                    throw TypeError('start must be a Number');
                }
                if (this.end === undefined) {
                    this.end = Infinity;
                }
                else if ('number' !== typeof this.end) {
                    throw TypeError('end must be a Number');
                }
                if (this.start > this.end) {
                    throw new Error('start must be <= end');
                }
                this.pos = this.start;
            }
            if (this.fd !== null) {
                process.nextTick(function () {
                    self._read();
                });
                return;
            }
            fs.open(this.path, this.flags, this.mode, function (err, fd) {
                if (err) {
                    self.emit('error', err);
                    self.readable = false;
                    return;
                }
                self.fd = fd;
                self.emit('open', fd);
                self._read();
            });
        }
        function WriteStream(path, options) {
            if (!(this instanceof WriteStream))
                return new WriteStream(path, options);
            Stream.call(this);
            this.path = path;
            this.fd = null;
            this.writable = true;
            this.flags = 'w';
            this.encoding = 'binary';
            this.mode = 438; /*=0666*/
            this.bytesWritten = 0;
            options = options || {};
            // Mixin options into this
            var keys = Object.keys(options);
            for (var index = 0, length = keys.length; index < length; index++) {
                var key = keys[index];
                this[key] = options[key];
            }
            if (this.start !== undefined) {
                if ('number' !== typeof this.start) {
                    throw TypeError('start must be a Number');
                }
                if (this.start < 0) {
                    throw new Error('start must be >= zero');
                }
                this.pos = this.start;
            }
            this.busy = false;
            this._queue = [];
            if (this.fd === null) {
                this._open = fs.open;
                this._queue.push([this._open, this.path, this.flags, this.mode, undefined]);
                this.flush();
            }
        }
    }
},
/* graceful-fs/clone.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = clone;
    var getPrototypeOf = Object.getPrototypeOf || function (obj) {
        return obj.__proto__;
    };
    function clone(obj) {
        if (obj === null || typeof obj !== 'object')
            return obj;
        if (obj instanceof Object)
            var copy = { __proto__: getPrototypeOf(obj) };
        else
            var copy = Object.create(null);
        Object.getOwnPropertyNames(obj).forEach(function (key) {
            Object.defineProperty(copy, key, Object.getOwnPropertyDescriptor(obj, key));
        });
        return copy;
    }
},
/* less/lib/less/environment/abstract-file-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var AbstractFileManager = /** @class */ (function () {
        function AbstractFileManager() {
        }
        AbstractFileManager.prototype.getPath = function (filename) {
            var j = filename.lastIndexOf('?');
            if (j > 0) {
                filename = filename.slice(0, j);
            }
            j = filename.lastIndexOf('/');
            if (j < 0) {
                j = filename.lastIndexOf('\\');
            }
            if (j < 0) {
                return '';
            }
            return filename.slice(0, j + 1);
        };
        AbstractFileManager.prototype.tryAppendExtension = function (path, ext) {
            return /(\.[a-z]*$)|([\?;].*)$/.test(path) ? path : path + ext;
        };
        AbstractFileManager.prototype.tryAppendLessExtension = function (path) {
            return this.tryAppendExtension(path, '.less');
        };
        AbstractFileManager.prototype.supportsSync = function () {
            return false;
        };
        AbstractFileManager.prototype.alwaysMakePathsAbsolute = function () {
            return false;
        };
        AbstractFileManager.prototype.isPathAbsolute = function (filename) {
            return (/^(?:[a-z-]+:|\/|\\|#)/i).test(filename);
        };
        // TODO: pull out / replace?
        AbstractFileManager.prototype.join = function (basePath, laterPath) {
            if (!basePath) {
                return laterPath;
            }
            return basePath + laterPath;
        };
        AbstractFileManager.prototype.pathDiff = function (url, baseUrl) {
            // diff between two paths to create a relative path
            var urlParts = this.extractUrlParts(url);
            var baseUrlParts = this.extractUrlParts(baseUrl);
            var i;
            var max;
            var urlDirectories;
            var baseUrlDirectories;
            var diff = '';
            if (urlParts.hostPart !== baseUrlParts.hostPart) {
                return '';
            }
            max = Math.max(baseUrlParts.directories.length, urlParts.directories.length);
            for (i = 0; i < max; i++) {
                if (baseUrlParts.directories[i] !== urlParts.directories[i]) {
                    break;
                }
            }
            baseUrlDirectories = baseUrlParts.directories.slice(i);
            urlDirectories = urlParts.directories.slice(i);
            for (i = 0; i < baseUrlDirectories.length - 1; i++) {
                diff += '../';
            }
            for (i = 0; i < urlDirectories.length - 1; i++) {
                diff += urlDirectories[i] + "/";
            }
            return diff;
        };
        // helper function, not part of API
        AbstractFileManager.prototype.extractUrlParts = function (url, baseUrl) {
            // urlParts[1] = protocol://hostname/ OR /
            // urlParts[2] = / if path relative to host base
            // urlParts[3] = directories
            // urlParts[4] = filename
            // urlParts[5] = parameters
            var urlPartsRegex = /^((?:[a-z-]+:)?\/{2}(?:[^\/\?#]*\/)|([\/\\]))?((?:[^\/\\\?#]*[\/\\])*)([^\/\\\?#]*)([#\?].*)?$/i;
            var urlParts = url.match(urlPartsRegex);
            var returner = {};
            var rawDirectories = [];
            var directories = [];
            var i;
            var baseUrlParts;
            if (!urlParts) {
                throw new Error("Could not parse sheet href - '" + url + "'");
            }
            // Stylesheets in IE don't always return the full path
            if (baseUrl && (!urlParts[1] || urlParts[2])) {
                baseUrlParts = baseUrl.match(urlPartsRegex);
                if (!baseUrlParts) {
                    throw new Error("Could not parse page url - '" + baseUrl + "'");
                }
                urlParts[1] = urlParts[1] || baseUrlParts[1] || '';
                if (!urlParts[2]) {
                    urlParts[3] = baseUrlParts[3] + urlParts[3];
                }
            }
            if (urlParts[3]) {
                rawDirectories = urlParts[3].replace(/\\/g, '/').split('/');
                // collapse '..' and skip '.'
                for (i = 0; i < rawDirectories.length; i++) {
                    if (rawDirectories[i] === '..') {
                        directories.pop();
                    }
                    else if (rawDirectories[i] !== '.') {
                        directories.push(rawDirectories[i]);
                    }
                }
            }
            returner.hostPart = urlParts[1];
            returner.directories = directories;
            returner.rawPath = (urlParts[1] || '') + rawDirectories.join('/');
            returner.path = (urlParts[1] || '') + directories.join('/');
            returner.filename = urlParts[4];
            returner.fileUrl = returner.path + (urlParts[4] || '');
            returner.url = returner.fileUrl + (urlParts[5] || '');
            return returner;
        };
        return AbstractFileManager;
    }());
    exports.default = AbstractFileManager;
    
},
/* less/lib/less-node/url-file-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var isUrlRe = /^(?:https?:)?\/\//i;
    var url_1 = tslib_1.__importDefault(require("url"));
    var request;
    var abstract_file_manager_js_1 = tslib_1.__importDefault(require(68) /* ../less/environment/abstract-file-manager.js */);
    var logger_1 = tslib_1.__importDefault(require(70) /* ../less/logger */);
    var UrlFileManager = function () { };
    UrlFileManager.prototype = Object.assign(new abstract_file_manager_js_1.default(), {
        supports: function (filename, currentDirectory, options, environment) {
            return isUrlRe.test(filename) || isUrlRe.test(currentDirectory);
        },
        loadFile: function (filename, currentDirectory, options, environment) {
            return new Promise(function (fulfill, reject) {
                if (request === undefined) {
                    try {
                        request = require(71) /* needle */;
                    }
                    catch (e) {
                        request = null;
                    }
                }
                if (!request) {
                    reject({ type: 'File', message: 'optional dependency \'needle\' required to import over http(s)\n' });
                    return;
                }
                var urlStr = isUrlRe.test(filename) ? filename : url_1.default.resolve(currentDirectory, filename);
                /** native-request currently has a bug */
                var hackUrlStr = urlStr.indexOf('?') === -1 ? urlStr + '?' : urlStr;
                request.get(hackUrlStr, { follow_max: 5 }, function (err, resp, body) {
                    if (err || resp && resp.statusCode >= 400) {
                        var message = resp && resp.statusCode === 404
                            ? "resource '" + urlStr + "' was not found\n"
                            : "resource '" + urlStr + "' gave this Error:\n  " + (err || resp.statusMessage || resp.statusCode) + "\n";
                        reject({ type: 'File', message: message });
                        return;
                    }
                    if (resp.statusCode >= 300) {
                        reject({ type: 'File', message: "resource '" + urlStr + "' caused too many redirects" });
                        return;
                    }
                    body = body.toString('utf8');
                    if (!body) {
                        logger_1.default.warn("Warning: Empty body (HTTP " + resp.statusCode + ") returned by \"" + urlStr + "\"");
                    }
                    fulfill({ contents: body || '', filename: urlStr });
                });
            });
        }
    });
    exports.default = UrlFileManager;
    
},
/* less/lib/less/logger.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = {
        error: function (msg) {
            this._fireEvent('error', msg);
        },
        warn: function (msg) {
            this._fireEvent('warn', msg);
        },
        info: function (msg) {
            this._fireEvent('info', msg);
        },
        debug: function (msg) {
            this._fireEvent('debug', msg);
        },
        addListener: function (listener) {
            this._listeners.push(listener);
        },
        removeListener: function (listener) {
            for (var i = 0; i < this._listeners.length; i++) {
                if (this._listeners[i] === listener) {
                    this._listeners.splice(i, 1);
                    return;
                }
            }
        },
        _fireEvent: function (type, msg) {
            for (var i = 0; i < this._listeners.length; i++) {
                var logFunction = this._listeners[i][type];
                if (logFunction) {
                    logFunction(msg);
                }
            }
        },
        _listeners: []
    };
    
},
/* needle/lib/needle.js */ function _(require, module, exports, __esModule, __esExport) {//////////////////////////////////////////
    // Needle -- HTTP Client for Node.js
    // Written by Tomás Pollak <tomas@forkhq.com>
    // (c) 2012-2020 - Fork Ltd.
    // MIT Licensed
    //////////////////////////////////////////
    var fs = require('fs'), http = require('http'), https = require('https'), url = require('url'), stream = require('stream'), debug = require(72) /* debug */('needle'), stringify = require(77) /* ./querystring */.build, multipart = require(78) /* ./multipart */, auth = require(79) /* ./auth */, cookies = require(80) /* ./cookies */, parsers = require(81) /* ./parsers */, decoder = require(83) /* ./decoder */, utils = require(106) /* ./utils */;
    //////////////////////////////////////////
    // variabilia
    var version = require(107) /* ../package.json */.version;
    var user_agent = 'Needle/' + version;
    user_agent += ' (Node.js ' + process.version + '; ' + process.platform + ' ' + process.arch + ')';
    var tls_options = 'pfx key passphrase cert ca ciphers rejectUnauthorized secureProtocol checkServerIdentity family';
    // older versions of node (< 0.11.4) prevent the runtime from exiting
    // because of connections in keep-alive state. so if this is the case
    // we'll default new requests to set a Connection: close header.
    var close_by_default = !http.Agent || http.Agent.defaultMaxSockets != Infinity;
    // see if we have Object.assign. otherwise fall back to util._extend
    var extend = Object.assign ? Object.assign : require('util')._extend;
    // these are the status codes that Needle interprets as redirects.
    var redirect_codes = [301, 302, 303, 307, 308];
    //////////////////////////////////////////
    // decompressors for gzip/deflate/br bodies
    function bind_opts(fn, options) {
        return fn.bind(null, options);
    }
    var decompressors = {};
    try {
        var zlib = require('zlib');
        // Enable Z_SYNC_FLUSH to avoid Z_BUF_ERROR errors (Node PR #2595)
        var zlib_options = {
            flush: zlib.Z_SYNC_FLUSH,
            finishFlush: zlib.Z_SYNC_FLUSH
        };
        var br_options = {
            flush: zlib.BROTLI_OPERATION_FLUSH,
            finishFlush: zlib.BROTLI_OPERATION_FLUSH
        };
        decompressors['x-deflate'] = bind_opts(zlib.Inflate, zlib_options);
        decompressors['deflate'] = bind_opts(zlib.Inflate, zlib_options);
        decompressors['x-gzip'] = bind_opts(zlib.Gunzip, zlib_options);
        decompressors['gzip'] = bind_opts(zlib.Gunzip, zlib_options);
        if (typeof zlib.BrotliDecompress === 'function') {
            decompressors['br'] = bind_opts(zlib.BrotliDecompress, br_options);
        }
    }
    catch (e) { /* zlib not available */ }
    //////////////////////////////////////////
    // options and aliases
    var defaults = {
        // data
        boundary: '--------------------NODENEEDLEHTTPCLIENT',
        encoding: 'utf8',
        parse_response: 'all',
        proxy: null,
        // agent & headers
        agent: null,
        headers: {},
        accept: '*/*',
        user_agent: user_agent,
        // numbers
        open_timeout: 10000,
        response_timeout: 0,
        read_timeout: 0,
        follow_max: 0,
        stream_length: -1,
        // booleans
        compressed: false,
        decode_response: true,
        parse_cookies: true,
        follow_set_cookies: false,
        follow_set_referer: false,
        follow_keep_method: false,
        follow_if_same_host: false,
        follow_if_same_protocol: false,
        follow_if_same_location: false
    };
    var aliased = {
        options: {
            decode: 'decode_response',
            parse: 'parse_response',
            timeout: 'open_timeout',
            follow: 'follow_max'
        },
        inverted: {}
    };
    // only once, invert aliased keys so we can get passed options.
    Object.keys(aliased.options).map(function (k) {
        var value = aliased.options[k];
        aliased.inverted[value] = k;
    });
    //////////////////////////////////////////
    // helpers
    function keys_by_type(type) {
        return Object.keys(defaults).map(function (el) {
            if (defaults[el] !== null && defaults[el].constructor == type)
                return el;
        }).filter(function (el) { return el; });
    }
    //////////////////////////////////////////
    // the main act
    function Needle(method, uri, data, options, callback) {
        // if (!(this instanceof Needle)) {
        //   return new Needle(method, uri, data, options, callback);
        // }
        if (typeof uri !== 'string')
            throw new TypeError('URL must be a string, not ' + uri);
        this.method = method.toLowerCase();
        this.uri = uri;
        this.data = data;
        if (typeof options == 'function') {
            this.callback = options;
            this.options = {};
        }
        else {
            this.callback = callback;
            this.options = options;
        }
    }
    Needle.prototype.setup = function (uri, options) {
        function get_option(key, fallback) {
            // if original is in options, return that value
            if (typeof options[key] != 'undefined')
                return options[key];
            // otherwise, return value from alias or fallback/undefined
            return typeof options[aliased.inverted[key]] != 'undefined'
                ? options[aliased.inverted[key]] : fallback;
        }
        function check_value(expected, key) {
            var value = get_option(key), type = typeof value;
            if (type != 'undefined' && type != expected)
                throw new TypeError(type + ' received for ' + key + ', but expected a ' + expected);
            return (type == expected) ? value : defaults[key];
        }
        //////////////////////////////////////////////////
        // the basics
        var config = {
            http_opts: {
                agent: get_option('agent', defaults.agent),
                localAddress: get_option('localAddress', undefined),
                lookup: get_option('lookup', undefined)
            },
            headers: {},
            output: options.output,
            proxy: get_option('proxy', defaults.proxy),
            parser: get_option('parse_response', defaults.parse_response),
            encoding: options.encoding || (options.multipart ? 'binary' : defaults.encoding)
        };
        keys_by_type(Boolean).forEach(function (key) {
            config[key] = check_value('boolean', key);
        });
        keys_by_type(Number).forEach(function (key) {
            config[key] = check_value('number', key);
        });
        // populate http_opts with given TLS options
        tls_options.split(' ').forEach(function (key) {
            if (typeof options[key] != 'undefined') {
                if (config.http_opts.agent) { // pass option to existing agent
                    config.http_opts.agent.options[key] = options[key];
                }
                else {
                    config.http_opts[key] = options[key];
                }
            }
        });
        //////////////////////////////////////////////////
        // headers, cookies
        for (var key in defaults.headers)
            config.headers[key] = defaults.headers[key];
        config.headers['accept'] = options.accept || defaults.accept;
        config.headers['user-agent'] = options.user_agent || defaults.user_agent;
        if (options.content_type)
            config.headers['content-type'] = options.content_type;
        // set connection header if opts.connection was passed, or if node < 0.11.4 (close)
        if (options.connection || close_by_default)
            config.headers['connection'] = options.connection || 'close';
        if ((options.compressed || defaults.compressed) && typeof zlib != 'undefined')
            config.headers['accept-encoding'] = decompressors['br'] ? 'gzip, deflate, br' : 'gzip, deflate';
        if (options.cookies)
            config.headers['cookie'] = cookies.write(options.cookies);
        //////////////////////////////////////////////////
        // basic/digest auth
        if (uri.match(/[^\/]@/)) { // url contains user:pass@host, so parse it.
            var parts = (url.parse(uri).auth || '').split(':');
            options.username = parts[0];
            options.password = parts[1];
        }
        if (options.username) {
            if (options.auth && (options.auth == 'auto' || options.auth == 'digest')) {
                config.credentials = [options.username, options.password];
            }
            else {
                config.headers['authorization'] = auth.basic(options.username, options.password);
            }
        }
        var env_proxy = utils.get_env_var(['HTTP_PROXY', 'HTTPS_PROXY'], true);
        if (!config.proxy && env_proxy)
            config.proxy = env_proxy;
        // if proxy is present, set auth header from either url or proxy_user option.
        if (config.proxy) {
            if (utils.should_proxy_to(uri)) {
                if (config.proxy.indexOf('http') === -1)
                    config.proxy = 'http://' + config.proxy;
                if (config.proxy.indexOf('@') !== -1) {
                    var proxy = (url.parse(config.proxy).auth || '').split(':');
                    options.proxy_user = proxy[0];
                    options.proxy_pass = proxy[1];
                }
                if (options.proxy_user)
                    config.headers['proxy-authorization'] = auth.basic(options.proxy_user, options.proxy_pass);
            }
            else {
                delete config.proxy;
            }
        }
        // now that all our headers are set, overwrite them if instructed.
        for (var h in options.headers)
            config.headers[h.toLowerCase()] = options.headers[h];
        config.uri_modifier = get_option('uri_modifier', null);
        return config;
    };
    Needle.prototype.start = function () {
        var out = new stream.PassThrough({ objectMode: false }), uri = this.uri, data = this.data, method = this.method, callback = (typeof this.options == 'function') ? this.options : this.callback, options = this.options || {};
        // if no 'http' is found on URL, prepend it.
        if (uri.indexOf('http') === -1)
            uri = uri.replace(/^(\/\/)?/, 'http://');
        var self = this, body, waiting = false, config = this.setup(uri, options);
        // unless options.json was set to false, assume boss also wants JSON if content-type matches.
        var json = options.json || (options.json !== false && config.headers['content-type'] == 'application/json');
        if (data) {
            if (options.multipart) { // boss says we do multipart. so we do it.
                var boundary = options.boundary || defaults.boundary;
                waiting = true;
                multipart.build(data, boundary, function (err, parts) {
                    if (err)
                        throw (err);
                    config.headers['content-type'] = 'multipart/form-data; boundary=' + boundary;
                    next(parts);
                });
            }
            else if (utils.is_stream(data)) {
                if (method == 'get')
                    throw new Error('Refusing to pipe() a stream via GET. Did you mean .post?');
                if (config.stream_length > 0 || (config.stream_length === 0 && data.path)) {
                    // ok, let's get the stream's length and set it as the content-length header.
                    // this prevents some servers from cutting us off before all the data is sent.
                    waiting = true;
                    utils.get_stream_length(data, config.stream_length, function (length) {
                        data.length = length;
                        next(data);
                    });
                }
                else {
                    // if the boss doesn't want us to get the stream's length, or if it doesn't
                    // have a file descriptor for that purpose, then just head on.
                    body = data;
                }
            }
            else if (Buffer.isBuffer(data)) {
                body = data; // use the raw buffer as request body.
            }
            else if (method == 'get' && !json) {
                // append the data to the URI as a querystring.
                uri = uri.replace(/\?.*|$/, '?' + stringify(data));
            }
            else { // string or object data, no multipart.
                // if string, leave it as it is, otherwise, stringify.
                body = (typeof (data) === 'string') ? data
                    : json ? JSON.stringify(data) : stringify(data);
                // ensure we have a buffer so bytecount is correct.
                body = Buffer.from(body, config.encoding);
            }
        }
        function next(body) {
            if (body) {
                if (body.length)
                    config.headers['content-length'] = body.length;
                // if no content-type was passed, determine if json or not.
                if (!config.headers['content-type']) {
                    config.headers['content-type'] = json
                        ? 'application/json; charset=utf-8'
                        : 'application/x-www-form-urlencoded'; // no charset says W3 spec.
                }
            }
            // unless a specific accept header was set, assume json: true wants JSON back.
            if (options.json && (!options.accept && !(options.headers || {}).accept))
                config.headers['accept'] = 'application/json';
            self.send_request(1, method, uri, config, body, out, callback);
        }
        if (!waiting)
            next(body);
        return out;
    };
    Needle.prototype.get_request_opts = function (method, uri, config) {
        var opts = config.http_opts, proxy = config.proxy, remote = proxy ? url.parse(proxy) : url.parse(uri);
        opts.protocol = remote.protocol;
        opts.host = remote.hostname;
        opts.port = remote.port || (remote.protocol == 'https:' ? 443 : 80);
        opts.path = proxy ? uri : remote.pathname + (remote.search || '');
        opts.method = method;
        opts.headers = config.headers;
        if (!opts.headers['host']) {
            // if using proxy, make sure the host header shows the final destination
            var target = proxy ? url.parse(uri) : remote;
            opts.headers['host'] = target.hostname;
            // and if a non standard port was passed, append it to the port header
            if (target.port && [80, 443].indexOf(target.port) === -1) {
                opts.headers['host'] += ':' + target.port;
            }
        }
        return opts;
    };
    Needle.prototype.should_follow = function (location, config, original) {
        if (!location)
            return false;
        // returns true if location contains matching property (host or protocol)
        function matches(property) {
            var property = original[property];
            return location.indexOf(property) !== -1;
        }
        // first, check whether the requested location is actually different from the original
        if (!config.follow_if_same_location && location === original)
            return false;
        if (config.follow_if_same_host && !matches('host'))
            return false; // host does not match, so not following
        if (config.follow_if_same_protocol && !matches('protocol'))
            return false; // procotol does not match, so not following
        return true;
    };
    Needle.prototype.send_request = function (count, method, uri, config, post_data, out, callback) {
        if (typeof config.uri_modifier === 'function') {
            var modified_uri = config.uri_modifier(uri);
            debug('Modifying request URI', uri + ' => ' + modified_uri);
            uri = modified_uri;
        }
        var request, timer, returned = 0, self = this, request_opts = this.get_request_opts(method, uri, config), protocol = request_opts.protocol == 'https:' ? https : http;
        function done(err, resp) {
            if (returned++ > 0)
                return debug('Already finished, stopping here.');
            if (timer)
                clearTimeout(timer);
            request.removeListener('error', had_error);
            out.done = true;
            // An error can still be fired after closing.  In particular, on macOS.
            // See also:
            //  - https://github.com/tomas/needle/issues/391
            //  - https://github.com/less/less.js/issues/3693
            //  - https://github.com/nodejs/node/issues/27916
            request.once('error', function () { });
            if (callback)
                return callback(err, resp, resp ? resp.body : undefined);
            // NOTE: this event used to be called 'end', but the behaviour was confusing
            // when errors ocurred, because the stream would still emit an 'end' event.
            out.emit('done', err);
            // trigger the 'done' event on streams we're being piped to, if any
            var pipes = out._readableState.pipes || [];
            if (!pipes.forEach)
                pipes = [pipes];
            pipes.forEach(function (st) { st.emit('done', err); });
        }
        function had_error(err) {
            debug('Request error', err);
            out.emit('err', err);
            done(err || new Error('Unknown error when making request.'));
        }
        function set_timeout(type, milisecs) {
            if (timer)
                clearTimeout(timer);
            if (milisecs <= 0)
                return;
            timer = setTimeout(function () {
                out.emit('timeout', type);
                request.abort();
                // also invoke done() to terminate job on read_timeout
                if (type == 'read')
                    done(new Error(type + ' timeout'));
            }, milisecs);
        }
        debug('Making request #' + count, request_opts);
        request = protocol.request(request_opts, function (resp) {
            var headers = resp.headers;
            debug('Got response', resp.statusCode, headers);
            out.emit('response', resp);
            set_timeout('read', config.read_timeout);
            // if we got cookies, parse them unless we were instructed not to. make sure to include any
            // cookies that might have been set on previous redirects.
            if (config.parse_cookies && (headers['set-cookie'] || config.previous_resp_cookies)) {
                resp.cookies = extend(config.previous_resp_cookies || {}, cookies.read(headers['set-cookie']));
                debug('Got cookies', resp.cookies);
            }
            // if redirect code is found, determine if we should follow it according to the given options.
            if (redirect_codes.indexOf(resp.statusCode) !== -1 && self.should_follow(headers.location, config, uri)) {
                // clear timer before following redirects to prevent unexpected setTimeout consequence
                clearTimeout(timer);
                if (count <= config.follow_max) {
                    out.emit('redirect', headers.location);
                    // unless 'follow_keep_method' is true, rewrite the request to GET before continuing.
                    if (!config.follow_keep_method) {
                        method = 'GET';
                        post_data = null;
                        delete config.headers['content-length']; // in case the original was a multipart POST request.
                    }
                    // if follow_set_cookies is true, insert cookies in the next request's headers.
                    // we set both the original request cookies plus any response cookies we might have received.
                    if (config.follow_set_cookies && utils.host_and_ports_match(headers.location, uri)) {
                        var request_cookies = cookies.read(config.headers['cookie']);
                        config.previous_resp_cookies = resp.cookies;
                        if (Object.keys(request_cookies).length || Object.keys(resp.cookies || {}).length) {
                            config.headers['cookie'] = cookies.write(extend(request_cookies, resp.cookies));
                        }
                    }
                    else if (config.headers['cookie']) {
                        debug('Clearing original request cookie', config.headers['cookie']);
                        delete config.headers['cookie'];
                    }
                    if (config.follow_set_referer)
                        config.headers['referer'] = encodeURI(uri); // the original, not the destination URL.
                    config.headers['host'] = null; // clear previous Host header to avoid conflicts.
                    var redirect_url = utils.resolve_url(headers.location, uri);
                    debug('Redirecting to ' + redirect_url.toString());
                    return self.send_request(++count, method, redirect_url.toString(), config, post_data, out, callback);
                }
                else if (config.follow_max > 0) {
                    return done(new Error('Max redirects reached. Possible loop in: ' + headers.location));
                }
            }
            // if auth is requested and credentials were not passed, resend request, provided we have user/pass.
            if (resp.statusCode == 401 && headers['www-authenticate'] && config.credentials) {
                if (!config.headers['authorization']) { // only if authentication hasn't been sent
                    var auth_header = auth.header(headers['www-authenticate'], config.credentials, request_opts);
                    if (auth_header) {
                        config.headers['authorization'] = auth_header;
                        return self.send_request(count, method, uri, config, post_data, out, callback);
                    }
                }
            }
            // ok, so we got a valid (non-redirect & authorized) response. let's notify the stream guys.
            out.emit('header', resp.statusCode, headers);
            out.emit('headers', headers);
            var pipeline = [], mime = utils.parse_content_type(headers['content-type']), text_response = mime.type && (mime.type.indexOf('text/') != -1 || !!mime.type.match(/(\/|\+)(xml|json)$/));
            // To start, if our body is compressed and we're able to inflate it, do it.
            if (headers['content-encoding'] && decompressors[headers['content-encoding']]) {
                var decompressor = decompressors[headers['content-encoding']]();
                // make sure we catch errors triggered by the decompressor.
                decompressor.on('error', had_error);
                pipeline.push(decompressor);
            }
            // If parse is enabled and we have a parser for it, then go for it.
            if (config.parser && parsers[mime.type]) {
                // If a specific parser was requested, make sure we don't parse other types.
                var parser_name = config.parser.toString().toLowerCase();
                if (['xml', 'json'].indexOf(parser_name) == -1 || parsers[mime.type].name == parser_name) {
                    // OK, so either we're parsing all content types or the one requested matches.
                    out.parser = parsers[mime.type].name;
                    pipeline.push(parsers[mime.type].fn());
                    // Set objectMode on out stream to improve performance.
                    out._writableState.objectMode = true;
                    out._readableState.objectMode = true;
                }
                // If we're not parsing, and unless decoding was disabled, we'll try
                // decoding non UTF-8 bodies to UTF-8, using the iconv-lite library.
            }
            else if (text_response && config.decode_response && mime.charset) {
                pipeline.push(decoder(mime.charset));
            }
            // And `out` is the stream we finally push the decoded/parsed output to.
            pipeline.push(out);
            // Now, release the kraken!
            utils.pump_streams([resp].concat(pipeline), function (err) {
                if (err)
                    debug(err);
                // on node v8.x, if an error ocurrs on the receiving end,
                // then we want to abort the request to avoid having dangling sockets
                if (err && err.message == 'write after end')
                    request.destroy();
            });
            // If the user has requested and output file, pipe the output stream to it.
            // In stream mode, we will still get the response stream to play with.
            if (config.output && resp.statusCode == 200) {
                // for some reason, simply piping resp to the writable stream doesn't
                // work all the time (stream gets cut in the middle with no warning).
                // so we'll manually need to do the readable/write(chunk) trick.
                var file = fs.createWriteStream(config.output);
                file.on('error', had_error);
                out.on('end', function () {
                    if (file.writable)
                        file.end();
                });
                file.on('close', function () {
                    delete out.file;
                });
                out.on('readable', function () {
                    var chunk;
                    while ((chunk = this.read()) !== null) {
                        if (file.writable)
                            file.write(chunk);
                        // if callback was requested, also push it to resp.body
                        if (resp.body)
                            resp.body.push(chunk);
                    }
                });
                out.file = file;
            }
            // Only aggregate the full body if a callback was requested.
            if (callback) {
                resp.raw = [];
                resp.body = [];
                resp.bytes = 0;
                // Gather and count the amount of (raw) bytes using a PassThrough stream.
                var clean_pipe = new stream.PassThrough();
                clean_pipe.on('readable', function () {
                    var chunk;
                    while ((chunk = this.read()) != null) {
                        resp.bytes += chunk.length;
                        resp.raw.push(chunk);
                    }
                });
                utils.pump_streams([resp, clean_pipe], function (err) {
                    if (err)
                        debug(err);
                });
                // Listen on the 'readable' event to aggregate the chunks, but only if
                // file output wasn't requested. Otherwise we'd have two stream readers.
                if (!config.output || resp.statusCode != 200) {
                    out.on('readable', function () {
                        var chunk;
                        while ((chunk = this.read()) !== null) {
                            // We're either pushing buffers or objects, never strings.
                            if (typeof chunk == 'string')
                                chunk = Buffer.from(chunk);
                            // Push all chunks to resp.body. We'll bind them in resp.end().
                            resp.body.push(chunk);
                        }
                    });
                }
            }
            // And set the .body property once all data is in.
            out.on('end', function () {
                if (resp.body) { // callback mode
                    // we want to be able to access to the raw data later, so keep a reference.
                    resp.raw = Buffer.concat(resp.raw);
                    // if parse was successful, we should have an array with one object
                    if (resp.body[0] !== undefined && !Buffer.isBuffer(resp.body[0])) {
                        // that's our body right there.
                        resp.body = resp.body[0];
                        // set the parser property on our response. we may want to check.
                        if (out.parser)
                            resp.parser = out.parser;
                    }
                    else { // we got one or several buffers. string or binary.
                        resp.body = Buffer.concat(resp.body);
                        // if we're here and parsed is true, it means we tried to but it didn't work.
                        // so given that we got a text response, let's stringify it.
                        if (text_response || out.parser) {
                            resp.body = resp.body.toString();
                        }
                    }
                }
                // if an output file is being written to, make sure the callback
                // is triggered after all data has been written to it.
                if (out.file) {
                    out.file.on('close', function () {
                        done(null, resp);
                    });
                }
                else { // elvis has left the building.
                    done(null, resp);
                }
            });
            // out.on('error', function(err) {
            //   had_error(err);
            //   if (err.code == 'ERR_STREAM_DESTROYED' || err.code == 'ERR_STREAM_PREMATURE_CLOSE') {
            //     request.abort();
            //   }
            // })
        }); // end request call
        // unless open_timeout was disabled, set a timeout to abort the request.
        set_timeout('open', config.open_timeout);
        // handle errors on the request object. things might get bumpy.
        request.on('error', had_error);
        // make sure timer is cleared if request is aborted (issue #257)
        request.once('abort', function () {
            if (timer)
                clearTimeout(timer);
        });
        // set response timeout once we get a valid socket
        request.once('socket', function (socket) {
            if (socket.connecting) {
                socket.once('connect', function () {
                    set_timeout('response', config.response_timeout);
                });
            }
            else {
                set_timeout('response', config.response_timeout);
            }
        });
        if (post_data) {
            if (utils.is_stream(post_data)) {
                utils.pump_streams([post_data, request], function (err) {
                    if (err)
                        debug(err);
                });
            }
            else {
                request.write(post_data, config.encoding);
                request.end();
            }
        }
        else {
            request.end();
        }
        out.abort = function () { request.abort(); }; // easier access
        out.request = request;
        return out;
    };
    //////////////////////////////////////////
    // exports
    if (typeof Promise !== 'undefined') {
        module.exports = function () {
            var verb, args = [].slice.call(arguments);
            if (args[0].match(/\.|\//)) // first argument looks like a URL
                verb = (args.length > 2) ? 'post' : 'get';
            else
                verb = args.shift();
            if (verb.match(/get|head/i) && args.length == 2)
                args.splice(1, 0, null); // assume no data if head/get with two args (url, options)
            return new Promise(function (resolve, reject) {
                module.exports.request(verb, args[0], args[1], args[2], function (err, resp) {
                    return err ? reject(err) : resolve(resp);
                });
            });
        };
    }
    module.exports.version = version;
    module.exports.defaults = function (obj) {
        for (var key in obj) {
            var target_key = aliased.options[key] || key;
            if (defaults.hasOwnProperty(target_key) && typeof obj[key] != 'undefined') {
                if (target_key != 'parse_response' && target_key != 'proxy' && target_key != 'agent') {
                    // ensure type matches the original, except for proxy/parse_response that can be null/bool or string
                    var valid_type = defaults[target_key].constructor.name;
                    if (obj[key].constructor.name != valid_type)
                        throw new TypeError('Invalid type for ' + key + ', should be ' + valid_type);
                }
                defaults[target_key] = obj[key];
            }
            else {
                throw new Error('Invalid property for defaults:' + target_key);
            }
        }
        return defaults;
    };
    'head get'.split(' ').forEach(function (method) {
        module.exports[method] = function (uri, options, callback) {
            return new Needle(method, uri, null, options, callback).start();
        };
    });
    'post put patch delete'.split(' ').forEach(function (method) {
        module.exports[method] = function (uri, data, options, callback) {
            return new Needle(method, uri, data, options, callback).start();
        };
    });
    module.exports.request = function (method, uri, data, opts, callback) {
        return new Needle(method, uri, data, opts, callback).start();
    };
},
/* debug/src/index.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * Detect Electron renderer / nwjs process, which is node, but we should
     * treat as a browser.
     */
    if (typeof process === 'undefined' || process.type === 'renderer' || process.browser === true || process.__nwjs) {
        module.exports = require(73) /* ./browser.js */;
    }
    else {
        module.exports = require(76) /* ./node.js */;
    }
},
/* debug/src/browser.js */ function _(require, module, exports, __esModule, __esExport) {/* eslint-env browser */
    /**
     * This is the web browser implementation of `debug()`.
     */
    exports.formatArgs = formatArgs;
    exports.save = save;
    exports.load = load;
    exports.useColors = useColors;
    exports.storage = localstorage();
    exports.destroy = (() => {
        let warned = false;
        return () => {
            if (!warned) {
                warned = true;
                console.warn('Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.');
            }
        };
    })();
    /**
     * Colors.
     */
    exports.colors = [
        '#0000CC',
        '#0000FF',
        '#0033CC',
        '#0033FF',
        '#0066CC',
        '#0066FF',
        '#0099CC',
        '#0099FF',
        '#00CC00',
        '#00CC33',
        '#00CC66',
        '#00CC99',
        '#00CCCC',
        '#00CCFF',
        '#3300CC',
        '#3300FF',
        '#3333CC',
        '#3333FF',
        '#3366CC',
        '#3366FF',
        '#3399CC',
        '#3399FF',
        '#33CC00',
        '#33CC33',
        '#33CC66',
        '#33CC99',
        '#33CCCC',
        '#33CCFF',
        '#6600CC',
        '#6600FF',
        '#6633CC',
        '#6633FF',
        '#66CC00',
        '#66CC33',
        '#9900CC',
        '#9900FF',
        '#9933CC',
        '#9933FF',
        '#99CC00',
        '#99CC33',
        '#CC0000',
        '#CC0033',
        '#CC0066',
        '#CC0099',
        '#CC00CC',
        '#CC00FF',
        '#CC3300',
        '#CC3333',
        '#CC3366',
        '#CC3399',
        '#CC33CC',
        '#CC33FF',
        '#CC6600',
        '#CC6633',
        '#CC9900',
        '#CC9933',
        '#CCCC00',
        '#CCCC33',
        '#FF0000',
        '#FF0033',
        '#FF0066',
        '#FF0099',
        '#FF00CC',
        '#FF00FF',
        '#FF3300',
        '#FF3333',
        '#FF3366',
        '#FF3399',
        '#FF33CC',
        '#FF33FF',
        '#FF6600',
        '#FF6633',
        '#FF9900',
        '#FF9933',
        '#FFCC00',
        '#FFCC33'
    ];
    /**
     * Currently only WebKit-based Web Inspectors, Firefox >= v31,
     * and the Firebug extension (any Firefox version) are known
     * to support "%c" CSS customizations.
     *
     * TODO: add a `localStorage` variable to explicitly enable/disable colors
     */
    // eslint-disable-next-line complexity
    function useColors() {
        // NB: In an Electron preload script, document will be defined but not fully
        // initialized. Since we know we're in Chrome, we'll just detect this case
        // explicitly
        if (typeof window !== 'undefined' && window.process && (window.process.type === 'renderer' || window.process.__nwjs)) {
            return true;
        }
        // Internet Explorer and Edge do not support colors.
        if (typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/(edge|trident)\/(\d+)/)) {
            return false;
        }
        // Is webkit? http://stackoverflow.com/a/16459606/376773
        // document is undefined in react-native: https://github.com/facebook/react-native/pull/1632
        return (typeof document !== 'undefined' && document.documentElement && document.documentElement.style && document.documentElement.style.WebkitAppearance) ||
            // Is firebug? http://stackoverflow.com/a/398120/376773
            (typeof window !== 'undefined' && window.console && (window.console.firebug || (window.console.exception && window.console.table))) ||
            // Is firefox >= v31?
            // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
            (typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31) ||
            // Double check webkit in userAgent just in case we are in a worker
            (typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/applewebkit\/(\d+)/));
    }
    /**
     * Colorize log arguments if enabled.
     *
     * @api public
     */
    function formatArgs(args) {
        args[0] = (this.useColors ? '%c' : '') +
            this.namespace +
            (this.useColors ? ' %c' : ' ') +
            args[0] +
            (this.useColors ? '%c ' : ' ') +
            '+' + module.exports.humanize(this.diff);
        if (!this.useColors) {
            return;
        }
        const c = 'color: ' + this.color;
        args.splice(1, 0, c, 'color: inherit');
        // The final "%c" is somewhat tricky, because there could be other
        // arguments passed either before or after the %c, so we need to
        // figure out the correct index to insert the CSS into
        let index = 0;
        let lastC = 0;
        args[0].replace(/%[a-zA-Z%]/g, match => {
            if (match === '%%') {
                return;
            }
            index++;
            if (match === '%c') {
                // We only are interested in the *last* %c
                // (the user may have provided their own)
                lastC = index;
            }
        });
        args.splice(lastC, 0, c);
    }
    /**
     * Invokes `console.debug()` when available.
     * No-op when `console.debug` is not a "function".
     * If `console.debug` is not available, falls back
     * to `console.log`.
     *
     * @api public
     */
    exports.log = console.debug || console.log || (() => { });
    /**
     * Save `namespaces`.
     *
     * @param {String} namespaces
     * @api private
     */
    function save(namespaces) {
        try {
            if (namespaces) {
                exports.storage.setItem('debug', namespaces);
            }
            else {
                exports.storage.removeItem('debug');
            }
        }
        catch (error) {
            // Swallow
            // XXX (@Qix-) should we be logging these?
        }
    }
    /**
     * Load `namespaces`.
     *
     * @return {String} returns the previously persisted debug modes
     * @api private
     */
    function load() {
        let r;
        try {
            r = exports.storage.getItem('debug');
        }
        catch (error) {
            // Swallow
            // XXX (@Qix-) should we be logging these?
        }
        // If debug isn't set in LS, and we're in Electron, try to load $DEBUG
        if (!r && typeof process !== 'undefined' && 'env' in process) {
            r = process.env.DEBUG;
        }
        return r;
    }
    /**
     * Localstorage attempts to return the localstorage.
     *
     * This is necessary because safari throws
     * when a user disables cookies/localstorage
     * and you attempt to access it.
     *
     * @return {LocalStorage}
     * @api private
     */
    function localstorage() {
        try {
            // TVMLKit (Apple TV JS Runtime) does not have a window object, just localStorage in the global context
            // The Browser also has localStorage in the global context.
            return localStorage;
        }
        catch (error) {
            // Swallow
            // XXX (@Qix-) should we be logging these?
        }
    }
    module.exports = require(74) /* ./common */(exports);
    const { formatters } = module.exports;
    /**
     * Map %j to `JSON.stringify()`, since no Web Inspectors do that by default.
     */
    formatters.j = function (v) {
        try {
            return JSON.stringify(v);
        }
        catch (error) {
            return '[UnexpectedJSONParseError]: ' + error.message;
        }
    };
},
/* debug/src/common.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * This is the common logic for both the Node.js and web browser
     * implementations of `debug()`.
     */
    function setup(env) {
        createDebug.debug = createDebug;
        createDebug.default = createDebug;
        createDebug.coerce = coerce;
        createDebug.disable = disable;
        createDebug.enable = enable;
        createDebug.enabled = enabled;
        createDebug.humanize = require(75) /* ms */;
        createDebug.destroy = destroy;
        Object.keys(env).forEach(key => {
            createDebug[key] = env[key];
        });
        /**
        * The currently active debug mode names, and names to skip.
        */
        createDebug.names = [];
        createDebug.skips = [];
        /**
        * Map of special "%n" handling functions, for the debug "format" argument.
        *
        * Valid key names are a single, lower or upper-case letter, i.e. "n" and "N".
        */
        createDebug.formatters = {};
        /**
        * Selects a color for a debug namespace
        * @param {String} namespace The namespace string for the debug instance to be colored
        * @return {Number|String} An ANSI color code for the given namespace
        * @api private
        */
        function selectColor(namespace) {
            let hash = 0;
            for (let i = 0; i < namespace.length; i++) {
                hash = ((hash << 5) - hash) + namespace.charCodeAt(i);
                hash |= 0; // Convert to 32bit integer
            }
            return createDebug.colors[Math.abs(hash) % createDebug.colors.length];
        }
        createDebug.selectColor = selectColor;
        /**
        * Create a debugger with the given `namespace`.
        *
        * @param {String} namespace
        * @return {Function}
        * @api public
        */
        function createDebug(namespace) {
            let prevTime;
            let enableOverride = null;
            let namespacesCache;
            let enabledCache;
            function debug(...args) {
                // Disabled?
                if (!debug.enabled) {
                    return;
                }
                const self = debug;
                // Set `diff` timestamp
                const curr = Number(new Date());
                const ms = curr - (prevTime || curr);
                self.diff = ms;
                self.prev = prevTime;
                self.curr = curr;
                prevTime = curr;
                args[0] = createDebug.coerce(args[0]);
                if (typeof args[0] !== 'string') {
                    // Anything else let's inspect with %O
                    args.unshift('%O');
                }
                // Apply any `formatters` transformations
                let index = 0;
                args[0] = args[0].replace(/%([a-zA-Z%])/g, (match, format) => {
                    // If we encounter an escaped % then don't increase the array index
                    if (match === '%%') {
                        return '%';
                    }
                    index++;
                    const formatter = createDebug.formatters[format];
                    if (typeof formatter === 'function') {
                        const val = args[index];
                        match = formatter.call(self, val);
                        // Now we need to remove `args[index]` since it's inlined in the `format`
                        args.splice(index, 1);
                        index--;
                    }
                    return match;
                });
                // Apply env-specific formatting (colors, etc.)
                createDebug.formatArgs.call(self, args);
                const logFn = self.log || createDebug.log;
                logFn.apply(self, args);
            }
            debug.namespace = namespace;
            debug.useColors = createDebug.useColors();
            debug.color = createDebug.selectColor(namespace);
            debug.extend = extend;
            debug.destroy = createDebug.destroy; // XXX Temporary. Will be removed in the next major release.
            Object.defineProperty(debug, 'enabled', {
                enumerable: true,
                configurable: false,
                get: () => {
                    if (enableOverride !== null) {
                        return enableOverride;
                    }
                    if (namespacesCache !== createDebug.namespaces) {
                        namespacesCache = createDebug.namespaces;
                        enabledCache = createDebug.enabled(namespace);
                    }
                    return enabledCache;
                },
                set: v => {
                    enableOverride = v;
                }
            });
            // Env-specific initialization logic for debug instances
            if (typeof createDebug.init === 'function') {
                createDebug.init(debug);
            }
            return debug;
        }
        function extend(namespace, delimiter) {
            const newDebug = createDebug(this.namespace + (typeof delimiter === 'undefined' ? ':' : delimiter) + namespace);
            newDebug.log = this.log;
            return newDebug;
        }
        /**
        * Enables a debug mode by namespaces. This can include modes
        * separated by a colon and wildcards.
        *
        * @param {String} namespaces
        * @api public
        */
        function enable(namespaces) {
            createDebug.save(namespaces);
            createDebug.namespaces = namespaces;
            createDebug.names = [];
            createDebug.skips = [];
            let i;
            const split = (typeof namespaces === 'string' ? namespaces : '').split(/[\s,]+/);
            const len = split.length;
            for (i = 0; i < len; i++) {
                if (!split[i]) {
                    // ignore empty strings
                    continue;
                }
                namespaces = split[i].replace(/\*/g, '.*?');
                if (namespaces[0] === '-') {
                    createDebug.skips.push(new RegExp('^' + namespaces.slice(1) + '$'));
                }
                else {
                    createDebug.names.push(new RegExp('^' + namespaces + '$'));
                }
            }
        }
        /**
        * Disable debug output.
        *
        * @return {String} namespaces
        * @api public
        */
        function disable() {
            const namespaces = [
                ...createDebug.names.map(toNamespace),
                ...createDebug.skips.map(toNamespace).map(namespace => '-' + namespace)
            ].join(',');
            createDebug.enable('');
            return namespaces;
        }
        /**
        * Returns true if the given mode name is enabled, false otherwise.
        *
        * @param {String} name
        * @return {Boolean}
        * @api public
        */
        function enabled(name) {
            if (name[name.length - 1] === '*') {
                return true;
            }
            let i;
            let len;
            for (i = 0, len = createDebug.skips.length; i < len; i++) {
                if (createDebug.skips[i].test(name)) {
                    return false;
                }
            }
            for (i = 0, len = createDebug.names.length; i < len; i++) {
                if (createDebug.names[i].test(name)) {
                    return true;
                }
            }
            return false;
        }
        /**
        * Convert regexp to namespace
        *
        * @param {RegExp} regxep
        * @return {String} namespace
        * @api private
        */
        function toNamespace(regexp) {
            return regexp.toString()
                .substring(2, regexp.toString().length - 2)
                .replace(/\.\*\?$/, '*');
        }
        /**
        * Coerce `val`.
        *
        * @param {Mixed} val
        * @return {Mixed}
        * @api private
        */
        function coerce(val) {
            if (val instanceof Error) {
                return val.stack || val.message;
            }
            return val;
        }
        /**
        * XXX DO NOT USE. This is a temporary stub function.
        * XXX It WILL be removed in the next major release.
        */
        function destroy() {
            console.warn('Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.');
        }
        createDebug.enable(createDebug.load());
        return createDebug;
    }
    module.exports = setup;
},
/* ms/index.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * Helpers.
     */
    var s = 1000;
    var m = s * 60;
    var h = m * 60;
    var d = h * 24;
    var w = d * 7;
    var y = d * 365.25;
    /**
     * Parse or format the given `val`.
     *
     * Options:
     *
     *  - `long` verbose formatting [false]
     *
     * @param {String|Number} val
     * @param {Object} [options]
     * @throws {Error} throw an error if val is not a non-empty string or a number
     * @return {String|Number}
     * @api public
     */
    module.exports = function (val, options) {
        options = options || {};
        var type = typeof val;
        if (type === 'string' && val.length > 0) {
            return parse(val);
        }
        else if (type === 'number' && isFinite(val)) {
            return options.long ? fmtLong(val) : fmtShort(val);
        }
        throw new Error('val is not a non-empty string or a valid number. val=' +
            JSON.stringify(val));
    };
    /**
     * Parse the given `str` and return milliseconds.
     *
     * @param {String} str
     * @return {Number}
     * @api private
     */
    function parse(str) {
        str = String(str);
        if (str.length > 100) {
            return;
        }
        var match = /^(-?(?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|weeks?|w|years?|yrs?|y)?$/i.exec(str);
        if (!match) {
            return;
        }
        var n = parseFloat(match[1]);
        var type = (match[2] || 'ms').toLowerCase();
        switch (type) {
            case 'years':
            case 'year':
            case 'yrs':
            case 'yr':
            case 'y':
                return n * y;
            case 'weeks':
            case 'week':
            case 'w':
                return n * w;
            case 'days':
            case 'day':
            case 'd':
                return n * d;
            case 'hours':
            case 'hour':
            case 'hrs':
            case 'hr':
            case 'h':
                return n * h;
            case 'minutes':
            case 'minute':
            case 'mins':
            case 'min':
            case 'm':
                return n * m;
            case 'seconds':
            case 'second':
            case 'secs':
            case 'sec':
            case 's':
                return n * s;
            case 'milliseconds':
            case 'millisecond':
            case 'msecs':
            case 'msec':
            case 'ms':
                return n;
            default:
                return undefined;
        }
    }
    /**
     * Short format for `ms`.
     *
     * @param {Number} ms
     * @return {String}
     * @api private
     */
    function fmtShort(ms) {
        var msAbs = Math.abs(ms);
        if (msAbs >= d) {
            return Math.round(ms / d) + 'd';
        }
        if (msAbs >= h) {
            return Math.round(ms / h) + 'h';
        }
        if (msAbs >= m) {
            return Math.round(ms / m) + 'm';
        }
        if (msAbs >= s) {
            return Math.round(ms / s) + 's';
        }
        return ms + 'ms';
    }
    /**
     * Long format for `ms`.
     *
     * @param {Number} ms
     * @return {String}
     * @api private
     */
    function fmtLong(ms) {
        var msAbs = Math.abs(ms);
        if (msAbs >= d) {
            return plural(ms, msAbs, d, 'day');
        }
        if (msAbs >= h) {
            return plural(ms, msAbs, h, 'hour');
        }
        if (msAbs >= m) {
            return plural(ms, msAbs, m, 'minute');
        }
        if (msAbs >= s) {
            return plural(ms, msAbs, s, 'second');
        }
        return ms + ' ms';
    }
    /**
     * Pluralization helper.
     */
    function plural(ms, msAbs, n, name) {
        var isPlural = msAbs >= n * 1.5;
        return Math.round(ms / n) + ' ' + name + (isPlural ? 's' : '');
    }
},
/* debug/src/node.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * Module dependencies.
     */
    const tty = require('tty');
    const util = require('util');
    /**
     * This is the Node.js implementation of `debug()`.
     */
    exports.init = init;
    exports.log = log;
    exports.formatArgs = formatArgs;
    exports.save = save;
    exports.load = load;
    exports.useColors = useColors;
    exports.destroy = util.deprecate(() => { }, 'Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.');
    /**
     * Colors.
     */
    exports.colors = [6, 2, 3, 4, 5, 1];
    try {
        // Optional dependency (as in, doesn't need to be installed, NOT like optionalDependencies in package.json)
        // eslint-disable-next-line import/no-extraneous-dependencies
        const supportsColor = require(38) /* supports-color */;
        if (supportsColor && (supportsColor.stderr || supportsColor).level >= 2) {
            exports.colors = [
                20,
                21,
                26,
                27,
                32,
                33,
                38,
                39,
                40,
                41,
                42,
                43,
                44,
                45,
                56,
                57,
                62,
                63,
                68,
                69,
                74,
                75,
                76,
                77,
                78,
                79,
                80,
                81,
                92,
                93,
                98,
                99,
                112,
                113,
                128,
                129,
                134,
                135,
                148,
                149,
                160,
                161,
                162,
                163,
                164,
                165,
                166,
                167,
                168,
                169,
                170,
                171,
                172,
                173,
                178,
                179,
                184,
                185,
                196,
                197,
                198,
                199,
                200,
                201,
                202,
                203,
                204,
                205,
                206,
                207,
                208,
                209,
                214,
                215,
                220,
                221
            ];
        }
    }
    catch (error) {
        // Swallow - we only care if `supports-color` is available; it doesn't have to be.
    }
    /**
     * Build up the default `inspectOpts` object from the environment variables.
     *
     *   $ DEBUG_COLORS=no DEBUG_DEPTH=10 DEBUG_SHOW_HIDDEN=enabled node script.js
     */
    exports.inspectOpts = Object.keys(process.env).filter(key => {
        return /^debug_/i.test(key);
    }).reduce((obj, key) => {
        // Camel-case
        const prop = key
            .substring(6)
            .toLowerCase()
            .replace(/_([a-z])/g, (_, k) => {
            return k.toUpperCase();
        });
        // Coerce string value into JS value
        let val = process.env[key];
        if (/^(yes|on|true|enabled)$/i.test(val)) {
            val = true;
        }
        else if (/^(no|off|false|disabled)$/i.test(val)) {
            val = false;
        }
        else if (val === 'null') {
            val = null;
        }
        else {
            val = Number(val);
        }
        obj[prop] = val;
        return obj;
    }, {});
    /**
     * Is stdout a TTY? Colored output is enabled when `true`.
     */
    function useColors() {
        return 'colors' in exports.inspectOpts ?
            Boolean(exports.inspectOpts.colors) :
            tty.isatty(process.stderr.fd);
    }
    /**
     * Adds ANSI color escape codes if enabled.
     *
     * @api public
     */
    function formatArgs(args) {
        const { namespace: name, useColors } = this;
        if (useColors) {
            const c = this.color;
            const colorCode = '\u001B[3' + (c < 8 ? c : '8;5;' + c);
            const prefix = `  ${colorCode};1m${name} \u001B[0m`;
            args[0] = prefix + args[0].split('\n').join('\n' + prefix);
            args.push(colorCode + 'm+' + module.exports.humanize(this.diff) + '\u001B[0m');
        }
        else {
            args[0] = getDate() + name + ' ' + args[0];
        }
    }
    function getDate() {
        if (exports.inspectOpts.hideDate) {
            return '';
        }
        return new Date().toISOString() + ' ';
    }
    /**
     * Invokes `util.format()` with the specified arguments and writes to stderr.
     */
    function log(...args) {
        return process.stderr.write(util.format(...args) + '\n');
    }
    /**
     * Save `namespaces`.
     *
     * @param {String} namespaces
     * @api private
     */
    function save(namespaces) {
        if (namespaces) {
            process.env.DEBUG = namespaces;
        }
        else {
            // If you set a process.env field to null or undefined, it gets cast to the
            // string 'null' or 'undefined'. Just delete instead.
            delete process.env.DEBUG;
        }
    }
    /**
     * Load `namespaces`.
     *
     * @return {String} returns the previously persisted debug modes
     * @api private
     */
    function load() {
        return process.env.DEBUG;
    }
    /**
     * Init logic for `debug` instances.
     *
     * Create a new `inspectOpts` object in case `useColors` is set
     * differently for a particular `debug` instance.
     */
    function init(debug) {
        debug.inspectOpts = {};
        const keys = Object.keys(exports.inspectOpts);
        for (let i = 0; i < keys.length; i++) {
            debug.inspectOpts[keys[i]] = exports.inspectOpts[keys[i]];
        }
    }
    module.exports = require(74) /* ./common */(exports);
    const { formatters } = module.exports;
    /**
     * Map %o to `util.inspect()`, all on a single line.
     */
    formatters.o = function (v) {
        this.inspectOpts.colors = this.useColors;
        return util.inspect(v, this.inspectOpts)
            .split('\n')
            .map(str => str.trim())
            .join(' ');
    };
    /**
     * Map %O to `util.inspect()`, allowing multiple lines if needed.
     */
    formatters.O = function (v) {
        this.inspectOpts.colors = this.useColors;
        return util.inspect(v, this.inspectOpts);
    };
},
/* needle/lib/querystring.js */ function _(require, module, exports, __esModule, __esExport) {// based on the qs module, but handles null objects as expected
    // fixes by Tomas Pollak.
    var toString = Object.prototype.toString;
    function stringify(obj, prefix) {
        if (prefix && (obj === null || typeof obj == 'undefined')) {
            return prefix + '=';
        }
        else if (toString.call(obj) == '[object Array]') {
            return stringifyArray(obj, prefix);
        }
        else if (toString.call(obj) == '[object Object]') {
            return stringifyObject(obj, prefix);
        }
        else if (toString.call(obj) == '[object Date]') {
            return obj.toISOString();
        }
        else if (prefix) { // string inside array or hash
            return prefix + '=' + encodeURIComponent(String(obj));
        }
        else if (String(obj).indexOf('=') !== -1) { // string with equal sign
            return String(obj);
        }
        else {
            throw new TypeError('Cannot build a querystring out of: ' + obj);
        }
    }
    ;
    function stringifyArray(arr, prefix) {
        var ret = [];
        for (var i = 0, len = arr.length; i < len; i++) {
            if (prefix)
                ret.push(stringify(arr[i], prefix + '[]'));
            else
                ret.push(stringify(arr[i]));
        }
        return ret.join('&');
    }
    function stringifyObject(obj, prefix) {
        var ret = [];
        Object.keys(obj).forEach(function (key) {
            ret.push(stringify(obj[key], prefix
                ? prefix + '[' + encodeURIComponent(key) + ']'
                : encodeURIComponent(key)));
        });
        return ret.join('&');
    }
    exports.build = stringify;
},
/* needle/lib/multipart.js */ function _(require, module, exports, __esModule, __esExport) {
    var readFile = require('fs').readFile, basename = require('path').basename;
    exports.build = function (data, boundary, callback) {
        if (typeof data != 'object' || typeof data.pipe == 'function')
            return callback(new Error('Multipart builder expects data as key/val object.'));
        var body = '', object = flatten(data), count = Object.keys(object).length;
        if (count === 0)
            return callback(new Error('Empty multipart body. Invalid data.'));
        function done(err, section) {
            if (err)
                return callback(err);
            if (section)
                body += section;
            --count || callback(null, body + '--' + boundary + '--');
        }
        ;
        for (var key in object) {
            var value = object[key];
            if (value === null || typeof value == 'undefined') {
                done();
            }
            else if (Buffer.isBuffer(value)) {
                var part = { buffer: value, content_type: 'application/octet-stream' };
                generate_part(key, part, boundary, done);
            }
            else {
                var part = (value.buffer || value.file || value.content_type) ? value : { value: value };
                generate_part(key, part, boundary, done);
            }
        }
    };
    function generate_part(name, part, boundary, callback) {
        var return_part = '--' + boundary + '\r\n';
        return_part += 'Content-Disposition: form-data; name="' + name + '"';
        function append(data, filename) {
            if (data) {
                var binary = part.content_type.indexOf('text') == -1;
                return_part += '; filename="' + encodeURIComponent(filename) + '"\r\n';
                if (binary)
                    return_part += 'Content-Transfer-Encoding: binary\r\n';
                return_part += 'Content-Type: ' + part.content_type + '\r\n\r\n';
                return_part += binary ? data.toString('binary') : data.toString('utf8');
            }
            callback(null, return_part + '\r\n');
        }
        ;
        if ((part.file || part.buffer) && part.content_type) {
            var filename = part.filename ? part.filename : part.file ? basename(part.file) : name;
            if (part.buffer)
                return append(part.buffer, filename);
            readFile(part.file, function (err, data) {
                if (err)
                    return callback(err);
                append(data, filename);
            });
        }
        else {
            if (typeof part.value == 'object')
                return callback(new Error('Object received for ' + name + ', expected string.'));
            if (part.content_type) {
                return_part += '\r\n';
                return_part += 'Content-Type: ' + part.content_type;
            }
            return_part += '\r\n\r\n';
            return_part += Buffer.from(String(part.value), 'utf8').toString('binary');
            append();
        }
    }
    // flattens nested objects for multipart body
    function flatten(object, into, prefix) {
        into = into || {};
        for (var key in object) {
            var prefix_key = prefix ? prefix + '[' + key + ']' : key;
            var prop = object[key];
            if (prop && typeof prop === 'object' && !(prop.buffer || prop.file || prop.content_type))
                flatten(prop, into, prefix_key);
            else
                into[prefix_key] = prop;
        }
        return into;
    }
},
/* needle/lib/auth.js */ function _(require, module, exports, __esModule, __esExport) {
    var createHash = require('crypto').createHash;
    function get_header(header, credentials, opts) {
        var type = header.split(' ')[0], user = credentials[0], pass = credentials[1];
        if (type == 'Digest') {
            return digest.generate(header, user, pass, opts.method, opts.path);
        }
        else if (type == 'Basic') {
            return basic(user, pass);
        }
    }
    ////////////////////
    // basic
    function md5(string) {
        return createHash('md5').update(string).digest('hex');
    }
    function basic(user, pass) {
        var str = typeof pass == 'undefined' ? user : [user, pass].join(':');
        return 'Basic ' + Buffer.from(str).toString('base64');
    }
    ////////////////////
    // digest
    // logic inspired from https://github.com/simme/node-http-digest-client
    var digest = {};
    digest.parse_header = function (header) {
        var challenge = {}, matches = header.match(/([a-z0-9_-]+)="?([a-z0-9_=\/\.@\s-\+:)()]+)"?/gi);
        for (var i = 0, l = matches.length; i < l; i++) {
            var parts = matches[i].split('='), key = parts.shift(), val = parts.join('=').replace(/^"/, '').replace(/"$/, '');
            challenge[key] = val;
        }
        return challenge;
    };
    digest.update_nc = function (nc) {
        var max = 99999999;
        nc++;
        if (nc > max)
            nc = 1;
        var padding = new Array(8).join('0') + '';
        nc = nc + '';
        return padding.substr(0, 8 - nc.length) + nc;
    };
    digest.generate = function (header, user, pass, method, path) {
        var nc = 1, cnonce = null, challenge = digest.parse_header(header);
        var ha1 = md5(user + ':' + challenge.realm + ':' + pass), ha2 = md5(method.toUpperCase() + ':' + path), resp = [ha1, challenge.nonce];
        if (typeof challenge.qop === 'string') {
            cnonce = md5(Math.random().toString(36)).substr(0, 8);
            nc = digest.update_nc(nc);
            resp = resp.concat(nc, cnonce);
            resp = resp.concat(challenge.qop, ha2);
        }
        else {
            resp = resp.concat(ha2);
        }
        var params = {
            uri: path,
            realm: challenge.realm,
            nonce: challenge.nonce,
            username: user,
            response: md5(resp.join(':'))
        };
        if (challenge.qop) {
            params.qop = challenge.qop;
        }
        if (challenge.opaque) {
            params.opaque = challenge.opaque;
        }
        if (cnonce) {
            params.nc = nc;
            params.cnonce = cnonce;
        }
        header = [];
        for (var k in params)
            header.push(k + '="' + params[k] + '"');
        return 'Digest ' + header.join(', ');
    };
    module.exports = {
        header: get_header,
        basic: basic,
        digest: digest.generate
    };
},
/* needle/lib/cookies.js */ function _(require, module, exports, __esModule, __esExport) {
    //  Simple cookie handling implementation based on the standard RFC 6265.
    //
    //  This module just has two functionalities:
    //    - Parse a set-cookie-header as a key value object
    //    - Write a cookie-string from a key value object
    //
    //  All cookie attributes are ignored.
    var unescape = require('querystring').unescape;
    var COOKIE_PAIR = /^([^=\s]+)\s*=\s*("?)\s*(.*)\s*\2\s*$/;
    var EXCLUDED_CHARS = /[\x00-\x1F\x7F\x3B\x3B\s\"\,\\"%]/g;
    var TRAILING_SEMICOLON = /\x3B+$/;
    var SEP_SEMICOLON = /\s*\x3B\s*/;
    // i know these should be 'const', but I'd like to keep
    // supporting earlier node.js versions as long as I can. :)
    var KEY_INDEX = 1; // index of key from COOKIE_PAIR match
    var VALUE_INDEX = 3; // index of value from COOKIE_PAIR match
    // Returns a copy str trimmed and without trainling semicolon.
    function cleanCookieString(str) {
        return str.trim().replace(/\x3B+$/, '');
    }
    function getFirstPair(str) {
        var index = str.indexOf('\x3B');
        return index === -1 ? str : str.substr(0, index);
    }
    // Returns a encoded copy of str based on RFC6265 S4.1.1.
    function encodeCookieComponent(str) {
        return str.toString().replace(EXCLUDED_CHARS, encodeURIComponent);
    }
    // Parses a set-cookie-string based on the standard defined in RFC6265 S4.1.1.
    function parseSetCookieString(str) {
        str = cleanCookieString(str);
        str = getFirstPair(str);
        var res = COOKIE_PAIR.exec(str);
        if (!res || !res[VALUE_INDEX])
            return null;
        return {
            name: unescape(res[KEY_INDEX]),
            value: unescape(res[VALUE_INDEX])
        };
    }
    // Parses a set-cookie-header and returns a key/value object.
    // Each key represents the name of a cookie.
    function parseSetCookieHeader(header) {
        if (!header)
            return {};
        header = Array.isArray(header) ? header : [header];
        return header.reduce(function (res, str) {
            var cookie = parseSetCookieString(str);
            if (cookie)
                res[cookie.name] = cookie.value;
            return res;
        }, {});
    }
    // Writes a set-cookie-string based on the standard definded in RFC6265 S4.1.1.
    function writeCookieString(obj) {
        return Object.keys(obj).reduce(function (str, name) {
            var encodedName = encodeCookieComponent(name);
            var encodedValue = encodeCookieComponent(obj[name]);
            str += (str ? '; ' : '') + encodedName + '=' + encodedValue;
            return str;
        }, '');
    }
    // returns a key/val object from an array of cookie strings
    exports.read = parseSetCookieHeader;
    // writes a cookie string header
    exports.write = writeCookieString;
},
/* needle/lib/parsers.js */ function _(require, module, exports, __esModule, __esExport) {//////////////////////////////////////////
    // Defines mappings between content-type
    // and the appropriate parsers.
    //////////////////////////////////////////
    var Transform = require('stream').Transform;
    var sax = require(82) /* sax */;
    function parseXML(str, cb) {
        var obj, current, parser = sax.parser(true, { trim: true, lowercase: true });
        parser.onerror = parser.onend = done;
        function done(err) {
            parser.onerror = parser.onend = function () { };
            cb(err, obj);
        }
        function newElement(name, attributes) {
            return {
                name: name || '',
                value: '',
                attributes: attributes || {},
                children: []
            };
        }
        parser.oncdata = parser.ontext = function (t) {
            if (current)
                current.value += t;
        };
        parser.onopentag = function (node) {
            var element = newElement(node.name, node.attributes);
            if (current) {
                element.parent = current;
                current.children.push(element);
            }
            else { // root object
                obj = element;
            }
            current = element;
        };
        parser.onclosetag = function () {
            if (typeof current.parent !== 'undefined') {
                var just_closed = current;
                current = current.parent;
                delete just_closed.parent;
            }
        };
        parser.write(str).close();
    }
    function parserFactory(name, fn) {
        function parser() {
            var chunks = [], stream = new Transform({ objectMode: true });
            // Buffer all our data
            stream._transform = function (chunk, encoding, done) {
                chunks.push(chunk);
                done();
            };
            // And call the parser when all is there.
            stream._flush = function (done) {
                var self = this, data = Buffer.concat(chunks);
                try {
                    fn(data, function (err, result) {
                        if (err)
                            throw err;
                        self.push(result);
                    });
                }
                catch (err) {
                    self.push(data); // just pass the original data
                }
                finally {
                    done();
                }
            };
            return stream;
        }
        return { fn: parser, name: name };
    }
    var parsers = {};
    function buildParser(name, types, fn) {
        var parser = parserFactory(name, fn);
        types.forEach(function (type) {
            parsers[type] = parser;
        });
    }
    buildParser('json', [
        'application/json',
        'text/javascript',
        'application/vnd.api+json'
    ], function (buffer, cb) {
        var err, data;
        try {
            data = JSON.parse(buffer);
        }
        catch (e) {
            err = e;
        }
        cb(err, data);
    });
    buildParser('xml', [
        'text/xml',
        'application/xml',
        'application/rdf+xml',
        'application/rss+xml',
        'application/atom+xml'
    ], function (buffer, cb) {
        parseXML(buffer.toString(), function (err, obj) {
            cb(err, obj);
        });
    });
    module.exports = parsers;
    module.exports.use = buildParser;
},
/* sax/lib/sax.js */ function _(require, module, exports, __esModule, __esExport) {
    ;
    (function (sax) {
        sax.parser = function (strict, opt) { return new SAXParser(strict, opt); };
        sax.SAXParser = SAXParser;
        sax.SAXStream = SAXStream;
        sax.createStream = createStream;
        // When we pass the MAX_BUFFER_LENGTH position, start checking for buffer overruns.
        // When we check, schedule the next check for MAX_BUFFER_LENGTH - (max(buffer lengths)),
        // since that's the earliest that a buffer overrun could occur.  This way, checks are
        // as rare as required, but as often as necessary to ensure never crossing this bound.
        // Furthermore, buffers are only tested at most once per write(), so passing a very
        // large string into write() might have undesirable effects, but this is manageable by
        // the caller, so it is assumed to be safe.  Thus, a call to write() may, in the extreme
        // edge case, result in creating at most one complete copy of the string passed in.
        // Set to Infinity to have unlimited buffers.
        sax.MAX_BUFFER_LENGTH = 64 * 1024;
        var buffers = [
            'comment', 'sgmlDecl', 'textNode', 'tagName', 'doctype',
            'procInstName', 'procInstBody', 'entity', 'attribName',
            'attribValue', 'cdata', 'script'
        ];
        sax.EVENTS = [
            'text',
            'processinginstruction',
            'sgmldeclaration',
            'doctype',
            'comment',
            'opentagstart',
            'attribute',
            'opentag',
            'closetag',
            'opencdata',
            'cdata',
            'closecdata',
            'error',
            'end',
            'ready',
            'script',
            'opennamespace',
            'closenamespace'
        ];
        function SAXParser(strict, opt) {
            if (!(this instanceof SAXParser)) {
                return new SAXParser(strict, opt);
            }
            var parser = this;
            clearBuffers(parser);
            parser.q = parser.c = '';
            parser.bufferCheckPosition = sax.MAX_BUFFER_LENGTH;
            parser.opt = opt || {};
            parser.opt.lowercase = parser.opt.lowercase || parser.opt.lowercasetags;
            parser.looseCase = parser.opt.lowercase ? 'toLowerCase' : 'toUpperCase';
            parser.tags = [];
            parser.closed = parser.closedRoot = parser.sawRoot = false;
            parser.tag = parser.error = null;
            parser.strict = !!strict;
            parser.noscript = !!(strict || parser.opt.noscript);
            parser.state = S.BEGIN;
            parser.strictEntities = parser.opt.strictEntities;
            parser.ENTITIES = parser.strictEntities ? Object.create(sax.XML_ENTITIES) : Object.create(sax.ENTITIES);
            parser.attribList = [];
            // namespaces form a prototype chain.
            // it always points at the current tag,
            // which protos to its parent tag.
            if (parser.opt.xmlns) {
                parser.ns = Object.create(rootNS);
            }
            // mostly just for error reporting
            parser.trackPosition = parser.opt.position !== false;
            if (parser.trackPosition) {
                parser.position = parser.line = parser.column = 0;
            }
            emit(parser, 'onready');
        }
        if (!Object.create) {
            Object.create = function (o) {
                function F() { }
                F.prototype = o;
                var newf = new F();
                return newf;
            };
        }
        if (!Object.keys) {
            Object.keys = function (o) {
                var a = [];
                for (var i in o)
                    if (o.hasOwnProperty(i))
                        a.push(i);
                return a;
            };
        }
        function checkBufferLength(parser) {
            var maxAllowed = Math.max(sax.MAX_BUFFER_LENGTH, 10);
            var maxActual = 0;
            for (var i = 0, l = buffers.length; i < l; i++) {
                var len = parser[buffers[i]].length;
                if (len > maxAllowed) {
                    // Text/cdata nodes can get big, and since they're buffered,
                    // we can get here under normal conditions.
                    // Avoid issues by emitting the text node now,
                    // so at least it won't get any bigger.
                    switch (buffers[i]) {
                        case 'textNode':
                            closeText(parser);
                            break;
                        case 'cdata':
                            emitNode(parser, 'oncdata', parser.cdata);
                            parser.cdata = '';
                            break;
                        case 'script':
                            emitNode(parser, 'onscript', parser.script);
                            parser.script = '';
                            break;
                        default:
                            error(parser, 'Max buffer length exceeded: ' + buffers[i]);
                    }
                }
                maxActual = Math.max(maxActual, len);
            }
            // schedule the next check for the earliest possible buffer overrun.
            var m = sax.MAX_BUFFER_LENGTH - maxActual;
            parser.bufferCheckPosition = m + parser.position;
        }
        function clearBuffers(parser) {
            for (var i = 0, l = buffers.length; i < l; i++) {
                parser[buffers[i]] = '';
            }
        }
        function flushBuffers(parser) {
            closeText(parser);
            if (parser.cdata !== '') {
                emitNode(parser, 'oncdata', parser.cdata);
                parser.cdata = '';
            }
            if (parser.script !== '') {
                emitNode(parser, 'onscript', parser.script);
                parser.script = '';
            }
        }
        SAXParser.prototype = {
            end: function () { end(this); },
            write: write,
            resume: function () { this.error = null; return this; },
            close: function () { return this.write(null); },
            flush: function () { flushBuffers(this); }
        };
        var Stream;
        try {
            Stream = require('stream').Stream;
        }
        catch (ex) {
            Stream = function () { };
        }
        var streamWraps = sax.EVENTS.filter(function (ev) {
            return ev !== 'error' && ev !== 'end';
        });
        function createStream(strict, opt) {
            return new SAXStream(strict, opt);
        }
        function SAXStream(strict, opt) {
            if (!(this instanceof SAXStream)) {
                return new SAXStream(strict, opt);
            }
            Stream.apply(this);
            this._parser = new SAXParser(strict, opt);
            this.writable = true;
            this.readable = true;
            var me = this;
            this._parser.onend = function () {
                me.emit('end');
            };
            this._parser.onerror = function (er) {
                me.emit('error', er);
                // if didn't throw, then means error was handled.
                // go ahead and clear error, so we can write again.
                me._parser.error = null;
            };
            this._decoder = null;
            streamWraps.forEach(function (ev) {
                Object.defineProperty(me, 'on' + ev, {
                    get: function () {
                        return me._parser['on' + ev];
                    },
                    set: function (h) {
                        if (!h) {
                            me.removeAllListeners(ev);
                            me._parser['on' + ev] = h;
                            return h;
                        }
                        me.on(ev, h);
                    },
                    enumerable: true,
                    configurable: false
                });
            });
        }
        SAXStream.prototype = Object.create(Stream.prototype, {
            constructor: {
                value: SAXStream
            }
        });
        SAXStream.prototype.write = function (data) {
            if (typeof Buffer === 'function' &&
                typeof Buffer.isBuffer === 'function' &&
                Buffer.isBuffer(data)) {
                if (!this._decoder) {
                    var SD = require('string_decoder').StringDecoder;
                    this._decoder = new SD('utf8');
                }
                data = this._decoder.write(data);
            }
            this._parser.write(data.toString());
            this.emit('data', data);
            return true;
        };
        SAXStream.prototype.end = function (chunk) {
            if (chunk && chunk.length) {
                this.write(chunk);
            }
            this._parser.end();
            return true;
        };
        SAXStream.prototype.on = function (ev, handler) {
            var me = this;
            if (!me._parser['on' + ev] && streamWraps.indexOf(ev) !== -1) {
                me._parser['on' + ev] = function () {
                    var args = arguments.length === 1 ? [arguments[0]] : Array.apply(null, arguments);
                    args.splice(0, 0, ev);
                    me.emit.apply(me, args);
                };
            }
            return Stream.prototype.on.call(me, ev, handler);
        };
        // this really needs to be replaced with character classes.
        // XML allows all manner of ridiculous numbers and digits.
        var CDATA = '[CDATA[';
        var DOCTYPE = 'DOCTYPE';
        var XML_NAMESPACE = 'http://www.w3.org/XML/1998/namespace';
        var XMLNS_NAMESPACE = 'http://www.w3.org/2000/xmlns/';
        var rootNS = { xml: XML_NAMESPACE, xmlns: XMLNS_NAMESPACE };
        // http://www.w3.org/TR/REC-xml/#NT-NameStartChar
        // This implementation works on strings, a single character at a time
        // as such, it cannot ever support astral-plane characters (10000-EFFFF)
        // without a significant breaking change to either this  parser, or the
        // JavaScript language.  Implementation of an emoji-capable xml parser
        // is left as an exercise for the reader.
        var nameStart = /[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/;
        var nameBody = /[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040.\d-]/;
        var entityStart = /[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/;
        var entityBody = /[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040.\d-]/;
        function isWhitespace(c) {
            return c === ' ' || c === '\n' || c === '\r' || c === '\t';
        }
        function isQuote(c) {
            return c === '"' || c === '\'';
        }
        function isAttribEnd(c) {
            return c === '>' || isWhitespace(c);
        }
        function isMatch(regex, c) {
            return regex.test(c);
        }
        function notMatch(regex, c) {
            return !isMatch(regex, c);
        }
        var S = 0;
        sax.STATE = {
            BEGIN: S++,
            BEGIN_WHITESPACE: S++,
            TEXT: S++,
            TEXT_ENTITY: S++,
            OPEN_WAKA: S++,
            SGML_DECL: S++,
            SGML_DECL_QUOTED: S++,
            DOCTYPE: S++,
            DOCTYPE_QUOTED: S++,
            DOCTYPE_DTD: S++,
            DOCTYPE_DTD_QUOTED: S++,
            COMMENT_STARTING: S++,
            COMMENT: S++,
            COMMENT_ENDING: S++,
            COMMENT_ENDED: S++,
            CDATA: S++,
            CDATA_ENDING: S++,
            CDATA_ENDING_2: S++,
            PROC_INST: S++,
            PROC_INST_BODY: S++,
            PROC_INST_ENDING: S++,
            OPEN_TAG: S++,
            OPEN_TAG_SLASH: S++,
            ATTRIB: S++,
            ATTRIB_NAME: S++,
            ATTRIB_NAME_SAW_WHITE: S++,
            ATTRIB_VALUE: S++,
            ATTRIB_VALUE_QUOTED: S++,
            ATTRIB_VALUE_CLOSED: S++,
            ATTRIB_VALUE_UNQUOTED: S++,
            ATTRIB_VALUE_ENTITY_Q: S++,
            ATTRIB_VALUE_ENTITY_U: S++,
            CLOSE_TAG: S++,
            CLOSE_TAG_SAW_WHITE: S++,
            SCRIPT: S++,
            SCRIPT_ENDING: S++ // <script> ... <
        };
        sax.XML_ENTITIES = {
            'amp': '&',
            'gt': '>',
            'lt': '<',
            'quot': '"',
            'apos': "'"
        };
        sax.ENTITIES = {
            'amp': '&',
            'gt': '>',
            'lt': '<',
            'quot': '"',
            'apos': "'",
            'AElig': 198,
            'Aacute': 193,
            'Acirc': 194,
            'Agrave': 192,
            'Aring': 197,
            'Atilde': 195,
            'Auml': 196,
            'Ccedil': 199,
            'ETH': 208,
            'Eacute': 201,
            'Ecirc': 202,
            'Egrave': 200,
            'Euml': 203,
            'Iacute': 205,
            'Icirc': 206,
            'Igrave': 204,
            'Iuml': 207,
            'Ntilde': 209,
            'Oacute': 211,
            'Ocirc': 212,
            'Ograve': 210,
            'Oslash': 216,
            'Otilde': 213,
            'Ouml': 214,
            'THORN': 222,
            'Uacute': 218,
            'Ucirc': 219,
            'Ugrave': 217,
            'Uuml': 220,
            'Yacute': 221,
            'aacute': 225,
            'acirc': 226,
            'aelig': 230,
            'agrave': 224,
            'aring': 229,
            'atilde': 227,
            'auml': 228,
            'ccedil': 231,
            'eacute': 233,
            'ecirc': 234,
            'egrave': 232,
            'eth': 240,
            'euml': 235,
            'iacute': 237,
            'icirc': 238,
            'igrave': 236,
            'iuml': 239,
            'ntilde': 241,
            'oacute': 243,
            'ocirc': 244,
            'ograve': 242,
            'oslash': 248,
            'otilde': 245,
            'ouml': 246,
            'szlig': 223,
            'thorn': 254,
            'uacute': 250,
            'ucirc': 251,
            'ugrave': 249,
            'uuml': 252,
            'yacute': 253,
            'yuml': 255,
            'copy': 169,
            'reg': 174,
            'nbsp': 160,
            'iexcl': 161,
            'cent': 162,
            'pound': 163,
            'curren': 164,
            'yen': 165,
            'brvbar': 166,
            'sect': 167,
            'uml': 168,
            'ordf': 170,
            'laquo': 171,
            'not': 172,
            'shy': 173,
            'macr': 175,
            'deg': 176,
            'plusmn': 177,
            'sup1': 185,
            'sup2': 178,
            'sup3': 179,
            'acute': 180,
            'micro': 181,
            'para': 182,
            'middot': 183,
            'cedil': 184,
            'ordm': 186,
            'raquo': 187,
            'frac14': 188,
            'frac12': 189,
            'frac34': 190,
            'iquest': 191,
            'times': 215,
            'divide': 247,
            'OElig': 338,
            'oelig': 339,
            'Scaron': 352,
            'scaron': 353,
            'Yuml': 376,
            'fnof': 402,
            'circ': 710,
            'tilde': 732,
            'Alpha': 913,
            'Beta': 914,
            'Gamma': 915,
            'Delta': 916,
            'Epsilon': 917,
            'Zeta': 918,
            'Eta': 919,
            'Theta': 920,
            'Iota': 921,
            'Kappa': 922,
            'Lambda': 923,
            'Mu': 924,
            'Nu': 925,
            'Xi': 926,
            'Omicron': 927,
            'Pi': 928,
            'Rho': 929,
            'Sigma': 931,
            'Tau': 932,
            'Upsilon': 933,
            'Phi': 934,
            'Chi': 935,
            'Psi': 936,
            'Omega': 937,
            'alpha': 945,
            'beta': 946,
            'gamma': 947,
            'delta': 948,
            'epsilon': 949,
            'zeta': 950,
            'eta': 951,
            'theta': 952,
            'iota': 953,
            'kappa': 954,
            'lambda': 955,
            'mu': 956,
            'nu': 957,
            'xi': 958,
            'omicron': 959,
            'pi': 960,
            'rho': 961,
            'sigmaf': 962,
            'sigma': 963,
            'tau': 964,
            'upsilon': 965,
            'phi': 966,
            'chi': 967,
            'psi': 968,
            'omega': 969,
            'thetasym': 977,
            'upsih': 978,
            'piv': 982,
            'ensp': 8194,
            'emsp': 8195,
            'thinsp': 8201,
            'zwnj': 8204,
            'zwj': 8205,
            'lrm': 8206,
            'rlm': 8207,
            'ndash': 8211,
            'mdash': 8212,
            'lsquo': 8216,
            'rsquo': 8217,
            'sbquo': 8218,
            'ldquo': 8220,
            'rdquo': 8221,
            'bdquo': 8222,
            'dagger': 8224,
            'Dagger': 8225,
            'bull': 8226,
            'hellip': 8230,
            'permil': 8240,
            'prime': 8242,
            'Prime': 8243,
            'lsaquo': 8249,
            'rsaquo': 8250,
            'oline': 8254,
            'frasl': 8260,
            'euro': 8364,
            'image': 8465,
            'weierp': 8472,
            'real': 8476,
            'trade': 8482,
            'alefsym': 8501,
            'larr': 8592,
            'uarr': 8593,
            'rarr': 8594,
            'darr': 8595,
            'harr': 8596,
            'crarr': 8629,
            'lArr': 8656,
            'uArr': 8657,
            'rArr': 8658,
            'dArr': 8659,
            'hArr': 8660,
            'forall': 8704,
            'part': 8706,
            'exist': 8707,
            'empty': 8709,
            'nabla': 8711,
            'isin': 8712,
            'notin': 8713,
            'ni': 8715,
            'prod': 8719,
            'sum': 8721,
            'minus': 8722,
            'lowast': 8727,
            'radic': 8730,
            'prop': 8733,
            'infin': 8734,
            'ang': 8736,
            'and': 8743,
            'or': 8744,
            'cap': 8745,
            'cup': 8746,
            'int': 8747,
            'there4': 8756,
            'sim': 8764,
            'cong': 8773,
            'asymp': 8776,
            'ne': 8800,
            'equiv': 8801,
            'le': 8804,
            'ge': 8805,
            'sub': 8834,
            'sup': 8835,
            'nsub': 8836,
            'sube': 8838,
            'supe': 8839,
            'oplus': 8853,
            'otimes': 8855,
            'perp': 8869,
            'sdot': 8901,
            'lceil': 8968,
            'rceil': 8969,
            'lfloor': 8970,
            'rfloor': 8971,
            'lang': 9001,
            'rang': 9002,
            'loz': 9674,
            'spades': 9824,
            'clubs': 9827,
            'hearts': 9829,
            'diams': 9830
        };
        Object.keys(sax.ENTITIES).forEach(function (key) {
            var e = sax.ENTITIES[key];
            var s = typeof e === 'number' ? String.fromCharCode(e) : e;
            sax.ENTITIES[key] = s;
        });
        for (var s in sax.STATE) {
            sax.STATE[sax.STATE[s]] = s;
        }
        // shorthand
        S = sax.STATE;
        function emit(parser, event, data) {
            parser[event] && parser[event](data);
        }
        function emitNode(parser, nodeType, data) {
            if (parser.textNode)
                closeText(parser);
            emit(parser, nodeType, data);
        }
        function closeText(parser) {
            parser.textNode = textopts(parser.opt, parser.textNode);
            if (parser.textNode)
                emit(parser, 'ontext', parser.textNode);
            parser.textNode = '';
        }
        function textopts(opt, text) {
            if (opt.trim)
                text = text.trim();
            if (opt.normalize)
                text = text.replace(/\s+/g, ' ');
            return text;
        }
        function error(parser, er) {
            closeText(parser);
            if (parser.trackPosition) {
                er += '\nLine: ' + parser.line +
                    '\nColumn: ' + parser.column +
                    '\nChar: ' + parser.c;
            }
            er = new Error(er);
            parser.error = er;
            emit(parser, 'onerror', er);
            return parser;
        }
        function end(parser) {
            if (parser.sawRoot && !parser.closedRoot)
                strictFail(parser, 'Unclosed root tag');
            if ((parser.state !== S.BEGIN) &&
                (parser.state !== S.BEGIN_WHITESPACE) &&
                (parser.state !== S.TEXT)) {
                error(parser, 'Unexpected end');
            }
            closeText(parser);
            parser.c = '';
            parser.closed = true;
            emit(parser, 'onend');
            SAXParser.call(parser, parser.strict, parser.opt);
            return parser;
        }
        function strictFail(parser, message) {
            if (typeof parser !== 'object' || !(parser instanceof SAXParser)) {
                throw new Error('bad call to strictFail');
            }
            if (parser.strict) {
                error(parser, message);
            }
        }
        function newTag(parser) {
            if (!parser.strict)
                parser.tagName = parser.tagName[parser.looseCase]();
            var parent = parser.tags[parser.tags.length - 1] || parser;
            var tag = parser.tag = { name: parser.tagName, attributes: {} };
            // will be overridden if tag contails an xmlns="foo" or xmlns:foo="bar"
            if (parser.opt.xmlns) {
                tag.ns = parent.ns;
            }
            parser.attribList.length = 0;
            emitNode(parser, 'onopentagstart', tag);
        }
        function qname(name, attribute) {
            var i = name.indexOf(':');
            var qualName = i < 0 ? ['', name] : name.split(':');
            var prefix = qualName[0];
            var local = qualName[1];
            // <x "xmlns"="http://foo">
            if (attribute && name === 'xmlns') {
                prefix = 'xmlns';
                local = '';
            }
            return { prefix: prefix, local: local };
        }
        function attrib(parser) {
            if (!parser.strict) {
                parser.attribName = parser.attribName[parser.looseCase]();
            }
            if (parser.attribList.indexOf(parser.attribName) !== -1 ||
                parser.tag.attributes.hasOwnProperty(parser.attribName)) {
                parser.attribName = parser.attribValue = '';
                return;
            }
            if (parser.opt.xmlns) {
                var qn = qname(parser.attribName, true);
                var prefix = qn.prefix;
                var local = qn.local;
                if (prefix === 'xmlns') {
                    // namespace binding attribute. push the binding into scope
                    if (local === 'xml' && parser.attribValue !== XML_NAMESPACE) {
                        strictFail(parser, 'xml: prefix must be bound to ' + XML_NAMESPACE + '\n' +
                            'Actual: ' + parser.attribValue);
                    }
                    else if (local === 'xmlns' && parser.attribValue !== XMLNS_NAMESPACE) {
                        strictFail(parser, 'xmlns: prefix must be bound to ' + XMLNS_NAMESPACE + '\n' +
                            'Actual: ' + parser.attribValue);
                    }
                    else {
                        var tag = parser.tag;
                        var parent = parser.tags[parser.tags.length - 1] || parser;
                        if (tag.ns === parent.ns) {
                            tag.ns = Object.create(parent.ns);
                        }
                        tag.ns[local] = parser.attribValue;
                    }
                }
                // defer onattribute events until all attributes have been seen
                // so any new bindings can take effect. preserve attribute order
                // so deferred events can be emitted in document order
                parser.attribList.push([parser.attribName, parser.attribValue]);
            }
            else {
                // in non-xmlns mode, we can emit the event right away
                parser.tag.attributes[parser.attribName] = parser.attribValue;
                emitNode(parser, 'onattribute', {
                    name: parser.attribName,
                    value: parser.attribValue
                });
            }
            parser.attribName = parser.attribValue = '';
        }
        function openTag(parser, selfClosing) {
            if (parser.opt.xmlns) {
                // emit namespace binding events
                var tag = parser.tag;
                // add namespace info to tag
                var qn = qname(parser.tagName);
                tag.prefix = qn.prefix;
                tag.local = qn.local;
                tag.uri = tag.ns[qn.prefix] || '';
                if (tag.prefix && !tag.uri) {
                    strictFail(parser, 'Unbound namespace prefix: ' +
                        JSON.stringify(parser.tagName));
                    tag.uri = qn.prefix;
                }
                var parent = parser.tags[parser.tags.length - 1] || parser;
                if (tag.ns && parent.ns !== tag.ns) {
                    Object.keys(tag.ns).forEach(function (p) {
                        emitNode(parser, 'onopennamespace', {
                            prefix: p,
                            uri: tag.ns[p]
                        });
                    });
                }
                // handle deferred onattribute events
                // Note: do not apply default ns to attributes:
                //   http://www.w3.org/TR/REC-xml-names/#defaulting
                for (var i = 0, l = parser.attribList.length; i < l; i++) {
                    var nv = parser.attribList[i];
                    var name = nv[0];
                    var value = nv[1];
                    var qualName = qname(name, true);
                    var prefix = qualName.prefix;
                    var local = qualName.local;
                    var uri = prefix === '' ? '' : (tag.ns[prefix] || '');
                    var a = {
                        name: name,
                        value: value,
                        prefix: prefix,
                        local: local,
                        uri: uri
                    };
                    // if there's any attributes with an undefined namespace,
                    // then fail on them now.
                    if (prefix && prefix !== 'xmlns' && !uri) {
                        strictFail(parser, 'Unbound namespace prefix: ' +
                            JSON.stringify(prefix));
                        a.uri = prefix;
                    }
                    parser.tag.attributes[name] = a;
                    emitNode(parser, 'onattribute', a);
                }
                parser.attribList.length = 0;
            }
            parser.tag.isSelfClosing = !!selfClosing;
            // process the tag
            parser.sawRoot = true;
            parser.tags.push(parser.tag);
            emitNode(parser, 'onopentag', parser.tag);
            if (!selfClosing) {
                // special case for <script> in non-strict mode.
                if (!parser.noscript && parser.tagName.toLowerCase() === 'script') {
                    parser.state = S.SCRIPT;
                }
                else {
                    parser.state = S.TEXT;
                }
                parser.tag = null;
                parser.tagName = '';
            }
            parser.attribName = parser.attribValue = '';
            parser.attribList.length = 0;
        }
        function closeTag(parser) {
            if (!parser.tagName) {
                strictFail(parser, 'Weird empty close tag.');
                parser.textNode += '</>';
                parser.state = S.TEXT;
                return;
            }
            if (parser.script) {
                if (parser.tagName !== 'script') {
                    parser.script += '</' + parser.tagName + '>';
                    parser.tagName = '';
                    parser.state = S.SCRIPT;
                    return;
                }
                emitNode(parser, 'onscript', parser.script);
                parser.script = '';
            }
            // first make sure that the closing tag actually exists.
            // <a><b></c></b></a> will close everything, otherwise.
            var t = parser.tags.length;
            var tagName = parser.tagName;
            if (!parser.strict) {
                tagName = tagName[parser.looseCase]();
            }
            var closeTo = tagName;
            while (t--) {
                var close = parser.tags[t];
                if (close.name !== closeTo) {
                    // fail the first time in strict mode
                    strictFail(parser, 'Unexpected close tag');
                }
                else {
                    break;
                }
            }
            // didn't find it.  we already failed for strict, so just abort.
            if (t < 0) {
                strictFail(parser, 'Unmatched closing tag: ' + parser.tagName);
                parser.textNode += '</' + parser.tagName + '>';
                parser.state = S.TEXT;
                return;
            }
            parser.tagName = tagName;
            var s = parser.tags.length;
            while (s-- > t) {
                var tag = parser.tag = parser.tags.pop();
                parser.tagName = parser.tag.name;
                emitNode(parser, 'onclosetag', parser.tagName);
                var x = {};
                for (var i in tag.ns) {
                    x[i] = tag.ns[i];
                }
                var parent = parser.tags[parser.tags.length - 1] || parser;
                if (parser.opt.xmlns && tag.ns !== parent.ns) {
                    // remove namespace bindings introduced by tag
                    Object.keys(tag.ns).forEach(function (p) {
                        var n = tag.ns[p];
                        emitNode(parser, 'onclosenamespace', { prefix: p, uri: n });
                    });
                }
            }
            if (t === 0)
                parser.closedRoot = true;
            parser.tagName = parser.attribValue = parser.attribName = '';
            parser.attribList.length = 0;
            parser.state = S.TEXT;
        }
        function parseEntity(parser) {
            var entity = parser.entity;
            var entityLC = entity.toLowerCase();
            var num;
            var numStr = '';
            if (parser.ENTITIES[entity]) {
                return parser.ENTITIES[entity];
            }
            if (parser.ENTITIES[entityLC]) {
                return parser.ENTITIES[entityLC];
            }
            entity = entityLC;
            if (entity.charAt(0) === '#') {
                if (entity.charAt(1) === 'x') {
                    entity = entity.slice(2);
                    num = parseInt(entity, 16);
                    numStr = num.toString(16);
                }
                else {
                    entity = entity.slice(1);
                    num = parseInt(entity, 10);
                    numStr = num.toString(10);
                }
            }
            entity = entity.replace(/^0+/, '');
            if (isNaN(num) || numStr.toLowerCase() !== entity) {
                strictFail(parser, 'Invalid character entity');
                return '&' + parser.entity + ';';
            }
            return String.fromCodePoint(num);
        }
        function beginWhiteSpace(parser, c) {
            if (c === '<') {
                parser.state = S.OPEN_WAKA;
                parser.startTagPosition = parser.position;
            }
            else if (!isWhitespace(c)) {
                // have to process this as a text node.
                // weird, but happens.
                strictFail(parser, 'Non-whitespace before first tag.');
                parser.textNode = c;
                parser.state = S.TEXT;
            }
        }
        function charAt(chunk, i) {
            var result = '';
            if (i < chunk.length) {
                result = chunk.charAt(i);
            }
            return result;
        }
        function write(chunk) {
            var parser = this;
            if (this.error) {
                throw this.error;
            }
            if (parser.closed) {
                return error(parser, 'Cannot write after close. Assign an onready handler.');
            }
            if (chunk === null) {
                return end(parser);
            }
            if (typeof chunk === 'object') {
                chunk = chunk.toString();
            }
            var i = 0;
            var c = '';
            while (true) {
                c = charAt(chunk, i++);
                parser.c = c;
                if (!c) {
                    break;
                }
                if (parser.trackPosition) {
                    parser.position++;
                    if (c === '\n') {
                        parser.line++;
                        parser.column = 0;
                    }
                    else {
                        parser.column++;
                    }
                }
                switch (parser.state) {
                    case S.BEGIN:
                        parser.state = S.BEGIN_WHITESPACE;
                        if (c === '\uFEFF') {
                            continue;
                        }
                        beginWhiteSpace(parser, c);
                        continue;
                    case S.BEGIN_WHITESPACE:
                        beginWhiteSpace(parser, c);
                        continue;
                    case S.TEXT:
                        if (parser.sawRoot && !parser.closedRoot) {
                            var starti = i - 1;
                            while (c && c !== '<' && c !== '&') {
                                c = charAt(chunk, i++);
                                if (c && parser.trackPosition) {
                                    parser.position++;
                                    if (c === '\n') {
                                        parser.line++;
                                        parser.column = 0;
                                    }
                                    else {
                                        parser.column++;
                                    }
                                }
                            }
                            parser.textNode += chunk.substring(starti, i - 1);
                        }
                        if (c === '<' && !(parser.sawRoot && parser.closedRoot && !parser.strict)) {
                            parser.state = S.OPEN_WAKA;
                            parser.startTagPosition = parser.position;
                        }
                        else {
                            if (!isWhitespace(c) && (!parser.sawRoot || parser.closedRoot)) {
                                strictFail(parser, 'Text data outside of root node.');
                            }
                            if (c === '&') {
                                parser.state = S.TEXT_ENTITY;
                            }
                            else {
                                parser.textNode += c;
                            }
                        }
                        continue;
                    case S.SCRIPT:
                        // only non-strict
                        if (c === '<') {
                            parser.state = S.SCRIPT_ENDING;
                        }
                        else {
                            parser.script += c;
                        }
                        continue;
                    case S.SCRIPT_ENDING:
                        if (c === '/') {
                            parser.state = S.CLOSE_TAG;
                        }
                        else {
                            parser.script += '<' + c;
                            parser.state = S.SCRIPT;
                        }
                        continue;
                    case S.OPEN_WAKA:
                        // either a /, ?, !, or text is coming next.
                        if (c === '!') {
                            parser.state = S.SGML_DECL;
                            parser.sgmlDecl = '';
                        }
                        else if (isWhitespace(c)) {
                            // wait for it...
                        }
                        else if (isMatch(nameStart, c)) {
                            parser.state = S.OPEN_TAG;
                            parser.tagName = c;
                        }
                        else if (c === '/') {
                            parser.state = S.CLOSE_TAG;
                            parser.tagName = '';
                        }
                        else if (c === '?') {
                            parser.state = S.PROC_INST;
                            parser.procInstName = parser.procInstBody = '';
                        }
                        else {
                            strictFail(parser, 'Unencoded <');
                            // if there was some whitespace, then add that in.
                            if (parser.startTagPosition + 1 < parser.position) {
                                var pad = parser.position - parser.startTagPosition;
                                c = new Array(pad).join(' ') + c;
                            }
                            parser.textNode += '<' + c;
                            parser.state = S.TEXT;
                        }
                        continue;
                    case S.SGML_DECL:
                        if ((parser.sgmlDecl + c).toUpperCase() === CDATA) {
                            emitNode(parser, 'onopencdata');
                            parser.state = S.CDATA;
                            parser.sgmlDecl = '';
                            parser.cdata = '';
                        }
                        else if (parser.sgmlDecl + c === '--') {
                            parser.state = S.COMMENT;
                            parser.comment = '';
                            parser.sgmlDecl = '';
                        }
                        else if ((parser.sgmlDecl + c).toUpperCase() === DOCTYPE) {
                            parser.state = S.DOCTYPE;
                            if (parser.doctype || parser.sawRoot) {
                                strictFail(parser, 'Inappropriately located doctype declaration');
                            }
                            parser.doctype = '';
                            parser.sgmlDecl = '';
                        }
                        else if (c === '>') {
                            emitNode(parser, 'onsgmldeclaration', parser.sgmlDecl);
                            parser.sgmlDecl = '';
                            parser.state = S.TEXT;
                        }
                        else if (isQuote(c)) {
                            parser.state = S.SGML_DECL_QUOTED;
                            parser.sgmlDecl += c;
                        }
                        else {
                            parser.sgmlDecl += c;
                        }
                        continue;
                    case S.SGML_DECL_QUOTED:
                        if (c === parser.q) {
                            parser.state = S.SGML_DECL;
                            parser.q = '';
                        }
                        parser.sgmlDecl += c;
                        continue;
                    case S.DOCTYPE:
                        if (c === '>') {
                            parser.state = S.TEXT;
                            emitNode(parser, 'ondoctype', parser.doctype);
                            parser.doctype = true; // just remember that we saw it.
                        }
                        else {
                            parser.doctype += c;
                            if (c === '[') {
                                parser.state = S.DOCTYPE_DTD;
                            }
                            else if (isQuote(c)) {
                                parser.state = S.DOCTYPE_QUOTED;
                                parser.q = c;
                            }
                        }
                        continue;
                    case S.DOCTYPE_QUOTED:
                        parser.doctype += c;
                        if (c === parser.q) {
                            parser.q = '';
                            parser.state = S.DOCTYPE;
                        }
                        continue;
                    case S.DOCTYPE_DTD:
                        parser.doctype += c;
                        if (c === ']') {
                            parser.state = S.DOCTYPE;
                        }
                        else if (isQuote(c)) {
                            parser.state = S.DOCTYPE_DTD_QUOTED;
                            parser.q = c;
                        }
                        continue;
                    case S.DOCTYPE_DTD_QUOTED:
                        parser.doctype += c;
                        if (c === parser.q) {
                            parser.state = S.DOCTYPE_DTD;
                            parser.q = '';
                        }
                        continue;
                    case S.COMMENT:
                        if (c === '-') {
                            parser.state = S.COMMENT_ENDING;
                        }
                        else {
                            parser.comment += c;
                        }
                        continue;
                    case S.COMMENT_ENDING:
                        if (c === '-') {
                            parser.state = S.COMMENT_ENDED;
                            parser.comment = textopts(parser.opt, parser.comment);
                            if (parser.comment) {
                                emitNode(parser, 'oncomment', parser.comment);
                            }
                            parser.comment = '';
                        }
                        else {
                            parser.comment += '-' + c;
                            parser.state = S.COMMENT;
                        }
                        continue;
                    case S.COMMENT_ENDED:
                        if (c !== '>') {
                            strictFail(parser, 'Malformed comment');
                            // allow <!-- blah -- bloo --> in non-strict mode,
                            // which is a comment of " blah -- bloo "
                            parser.comment += '--' + c;
                            parser.state = S.COMMENT;
                        }
                        else {
                            parser.state = S.TEXT;
                        }
                        continue;
                    case S.CDATA:
                        if (c === ']') {
                            parser.state = S.CDATA_ENDING;
                        }
                        else {
                            parser.cdata += c;
                        }
                        continue;
                    case S.CDATA_ENDING:
                        if (c === ']') {
                            parser.state = S.CDATA_ENDING_2;
                        }
                        else {
                            parser.cdata += ']' + c;
                            parser.state = S.CDATA;
                        }
                        continue;
                    case S.CDATA_ENDING_2:
                        if (c === '>') {
                            if (parser.cdata) {
                                emitNode(parser, 'oncdata', parser.cdata);
                            }
                            emitNode(parser, 'onclosecdata');
                            parser.cdata = '';
                            parser.state = S.TEXT;
                        }
                        else if (c === ']') {
                            parser.cdata += ']';
                        }
                        else {
                            parser.cdata += ']]' + c;
                            parser.state = S.CDATA;
                        }
                        continue;
                    case S.PROC_INST:
                        if (c === '?') {
                            parser.state = S.PROC_INST_ENDING;
                        }
                        else if (isWhitespace(c)) {
                            parser.state = S.PROC_INST_BODY;
                        }
                        else {
                            parser.procInstName += c;
                        }
                        continue;
                    case S.PROC_INST_BODY:
                        if (!parser.procInstBody && isWhitespace(c)) {
                            continue;
                        }
                        else if (c === '?') {
                            parser.state = S.PROC_INST_ENDING;
                        }
                        else {
                            parser.procInstBody += c;
                        }
                        continue;
                    case S.PROC_INST_ENDING:
                        if (c === '>') {
                            emitNode(parser, 'onprocessinginstruction', {
                                name: parser.procInstName,
                                body: parser.procInstBody
                            });
                            parser.procInstName = parser.procInstBody = '';
                            parser.state = S.TEXT;
                        }
                        else {
                            parser.procInstBody += '?' + c;
                            parser.state = S.PROC_INST_BODY;
                        }
                        continue;
                    case S.OPEN_TAG:
                        if (isMatch(nameBody, c)) {
                            parser.tagName += c;
                        }
                        else {
                            newTag(parser);
                            if (c === '>') {
                                openTag(parser);
                            }
                            else if (c === '/') {
                                parser.state = S.OPEN_TAG_SLASH;
                            }
                            else {
                                if (!isWhitespace(c)) {
                                    strictFail(parser, 'Invalid character in tag name');
                                }
                                parser.state = S.ATTRIB;
                            }
                        }
                        continue;
                    case S.OPEN_TAG_SLASH:
                        if (c === '>') {
                            openTag(parser, true);
                            closeTag(parser);
                        }
                        else {
                            strictFail(parser, 'Forward-slash in opening tag not followed by >');
                            parser.state = S.ATTRIB;
                        }
                        continue;
                    case S.ATTRIB:
                        // haven't read the attribute name yet.
                        if (isWhitespace(c)) {
                            continue;
                        }
                        else if (c === '>') {
                            openTag(parser);
                        }
                        else if (c === '/') {
                            parser.state = S.OPEN_TAG_SLASH;
                        }
                        else if (isMatch(nameStart, c)) {
                            parser.attribName = c;
                            parser.attribValue = '';
                            parser.state = S.ATTRIB_NAME;
                        }
                        else {
                            strictFail(parser, 'Invalid attribute name');
                        }
                        continue;
                    case S.ATTRIB_NAME:
                        if (c === '=') {
                            parser.state = S.ATTRIB_VALUE;
                        }
                        else if (c === '>') {
                            strictFail(parser, 'Attribute without value');
                            parser.attribValue = parser.attribName;
                            attrib(parser);
                            openTag(parser);
                        }
                        else if (isWhitespace(c)) {
                            parser.state = S.ATTRIB_NAME_SAW_WHITE;
                        }
                        else if (isMatch(nameBody, c)) {
                            parser.attribName += c;
                        }
                        else {
                            strictFail(parser, 'Invalid attribute name');
                        }
                        continue;
                    case S.ATTRIB_NAME_SAW_WHITE:
                        if (c === '=') {
                            parser.state = S.ATTRIB_VALUE;
                        }
                        else if (isWhitespace(c)) {
                            continue;
                        }
                        else {
                            strictFail(parser, 'Attribute without value');
                            parser.tag.attributes[parser.attribName] = '';
                            parser.attribValue = '';
                            emitNode(parser, 'onattribute', {
                                name: parser.attribName,
                                value: ''
                            });
                            parser.attribName = '';
                            if (c === '>') {
                                openTag(parser);
                            }
                            else if (isMatch(nameStart, c)) {
                                parser.attribName = c;
                                parser.state = S.ATTRIB_NAME;
                            }
                            else {
                                strictFail(parser, 'Invalid attribute name');
                                parser.state = S.ATTRIB;
                            }
                        }
                        continue;
                    case S.ATTRIB_VALUE:
                        if (isWhitespace(c)) {
                            continue;
                        }
                        else if (isQuote(c)) {
                            parser.q = c;
                            parser.state = S.ATTRIB_VALUE_QUOTED;
                        }
                        else {
                            strictFail(parser, 'Unquoted attribute value');
                            parser.state = S.ATTRIB_VALUE_UNQUOTED;
                            parser.attribValue = c;
                        }
                        continue;
                    case S.ATTRIB_VALUE_QUOTED:
                        if (c !== parser.q) {
                            if (c === '&') {
                                parser.state = S.ATTRIB_VALUE_ENTITY_Q;
                            }
                            else {
                                parser.attribValue += c;
                            }
                            continue;
                        }
                        attrib(parser);
                        parser.q = '';
                        parser.state = S.ATTRIB_VALUE_CLOSED;
                        continue;
                    case S.ATTRIB_VALUE_CLOSED:
                        if (isWhitespace(c)) {
                            parser.state = S.ATTRIB;
                        }
                        else if (c === '>') {
                            openTag(parser);
                        }
                        else if (c === '/') {
                            parser.state = S.OPEN_TAG_SLASH;
                        }
                        else if (isMatch(nameStart, c)) {
                            strictFail(parser, 'No whitespace between attributes');
                            parser.attribName = c;
                            parser.attribValue = '';
                            parser.state = S.ATTRIB_NAME;
                        }
                        else {
                            strictFail(parser, 'Invalid attribute name');
                        }
                        continue;
                    case S.ATTRIB_VALUE_UNQUOTED:
                        if (!isAttribEnd(c)) {
                            if (c === '&') {
                                parser.state = S.ATTRIB_VALUE_ENTITY_U;
                            }
                            else {
                                parser.attribValue += c;
                            }
                            continue;
                        }
                        attrib(parser);
                        if (c === '>') {
                            openTag(parser);
                        }
                        else {
                            parser.state = S.ATTRIB;
                        }
                        continue;
                    case S.CLOSE_TAG:
                        if (!parser.tagName) {
                            if (isWhitespace(c)) {
                                continue;
                            }
                            else if (notMatch(nameStart, c)) {
                                if (parser.script) {
                                    parser.script += '</' + c;
                                    parser.state = S.SCRIPT;
                                }
                                else {
                                    strictFail(parser, 'Invalid tagname in closing tag.');
                                }
                            }
                            else {
                                parser.tagName = c;
                            }
                        }
                        else if (c === '>') {
                            closeTag(parser);
                        }
                        else if (isMatch(nameBody, c)) {
                            parser.tagName += c;
                        }
                        else if (parser.script) {
                            parser.script += '</' + parser.tagName;
                            parser.tagName = '';
                            parser.state = S.SCRIPT;
                        }
                        else {
                            if (!isWhitespace(c)) {
                                strictFail(parser, 'Invalid tagname in closing tag');
                            }
                            parser.state = S.CLOSE_TAG_SAW_WHITE;
                        }
                        continue;
                    case S.CLOSE_TAG_SAW_WHITE:
                        if (isWhitespace(c)) {
                            continue;
                        }
                        if (c === '>') {
                            closeTag(parser);
                        }
                        else {
                            strictFail(parser, 'Invalid characters in closing tag');
                        }
                        continue;
                    case S.TEXT_ENTITY:
                    case S.ATTRIB_VALUE_ENTITY_Q:
                    case S.ATTRIB_VALUE_ENTITY_U:
                        var returnState;
                        var buffer;
                        switch (parser.state) {
                            case S.TEXT_ENTITY:
                                returnState = S.TEXT;
                                buffer = 'textNode';
                                break;
                            case S.ATTRIB_VALUE_ENTITY_Q:
                                returnState = S.ATTRIB_VALUE_QUOTED;
                                buffer = 'attribValue';
                                break;
                            case S.ATTRIB_VALUE_ENTITY_U:
                                returnState = S.ATTRIB_VALUE_UNQUOTED;
                                buffer = 'attribValue';
                                break;
                        }
                        if (c === ';') {
                            parser[buffer] += parseEntity(parser);
                            parser.entity = '';
                            parser.state = returnState;
                        }
                        else if (isMatch(parser.entity.length ? entityBody : entityStart, c)) {
                            parser.entity += c;
                        }
                        else {
                            strictFail(parser, 'Invalid character in entity name');
                            parser[buffer] += '&' + parser.entity + c;
                            parser.entity = '';
                            parser.state = returnState;
                        }
                        continue;
                    default:
                        throw new Error(parser, 'Unknown state: ' + parser.state);
                }
            } // while
            if (parser.position >= parser.bufferCheckPosition) {
                checkBufferLength(parser);
            }
            return parser;
        }
        /*! http://mths.be/fromcodepoint v0.1.0 by @mathias */
        /* istanbul ignore next */
        if (!String.fromCodePoint) {
            (function () {
                var stringFromCharCode = String.fromCharCode;
                var floor = Math.floor;
                var fromCodePoint = function () {
                    var MAX_SIZE = 0x4000;
                    var codeUnits = [];
                    var highSurrogate;
                    var lowSurrogate;
                    var index = -1;
                    var length = arguments.length;
                    if (!length) {
                        return '';
                    }
                    var result = '';
                    while (++index < length) {
                        var codePoint = Number(arguments[index]);
                        if (!isFinite(codePoint) || // `NaN`, `+Infinity`, or `-Infinity`
                            codePoint < 0 || // not a valid Unicode code point
                            codePoint > 0x10FFFF || // not a valid Unicode code point
                            floor(codePoint) !== codePoint // not an integer
                        ) {
                            throw RangeError('Invalid code point: ' + codePoint);
                        }
                        if (codePoint <= 0xFFFF) { // BMP code point
                            codeUnits.push(codePoint);
                        }
                        else { // Astral code point; split in surrogate halves
                            // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
                            codePoint -= 0x10000;
                            highSurrogate = (codePoint >> 10) + 0xD800;
                            lowSurrogate = (codePoint % 0x400) + 0xDC00;
                            codeUnits.push(highSurrogate, lowSurrogate);
                        }
                        if (index + 1 === length || codeUnits.length > MAX_SIZE) {
                            result += stringFromCharCode.apply(null, codeUnits);
                            codeUnits.length = 0;
                        }
                    }
                    return result;
                };
                /* istanbul ignore next */
                if (Object.defineProperty) {
                    Object.defineProperty(String, 'fromCodePoint', {
                        value: fromCodePoint,
                        configurable: true,
                        writable: true
                    });
                }
                else {
                    String.fromCodePoint = fromCodePoint;
                }
            }());
        }
    })(typeof exports === 'undefined' ? this.sax = {} : exports);
},
/* needle/lib/decoder.js */ function _(require, module, exports, __esModule, __esExport) {
    var iconv, inherits = require('util').inherits, stream = require('stream');
    var regex = /(?:charset|encoding)\s*=\s*['"]? *([\w\-]+)/i;
    inherits(StreamDecoder, stream.Transform);
    function StreamDecoder(charset) {
        if (!(this instanceof StreamDecoder))
            return new StreamDecoder(charset);
        stream.Transform.call(this, charset);
        this.charset = charset;
        this.parsed_chunk = false;
    }
    StreamDecoder.prototype._transform = function (chunk, encoding, done) {
        // try to get charset from chunk, but just once
        if (!this.parsed_chunk && (this.charset == 'utf-8' || this.charset == 'utf8')) {
            this.parsed_chunk = true;
            var matches = regex.exec(chunk.toString());
            if (matches) {
                var found = matches[1].toLowerCase().replace('utf8', 'utf-8'); // canonicalize;
                // set charset, but only if iconv can handle it
                if (iconv.encodingExists(found))
                    this.charset = found;
            }
        }
        if (this.charset == 'utf-8') { // no need to decode, just pass through
            this.push(chunk);
            return done();
        }
        // initialize stream decoder if not present
        var self = this;
        if (!this.decoder) {
            this.decoder = iconv.decodeStream(this.charset);
            this.decoder.on('data', function (decoded_chunk) {
                self.push(decoded_chunk);
            });
        }
        ;
        this.decoder.write(chunk);
        done();
    };
    module.exports = function (charset) {
        try {
            if (!iconv)
                iconv = require(84) /* iconv-lite */;
        }
        catch (e) {
            /* iconv not found */
        }
        if (iconv)
            return new StreamDecoder(charset);
        else
            return new stream.PassThrough;
    };
},
/* iconv-lite/lib/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Some environments don't have global Buffer (e.g. React Native).
    // Solution would be installing npm modules "buffer" and "stream" explicitly.
    var Buffer = require(85) /* safer-buffer */.Buffer;
    var bomHandling = require(86) /* ./bom-handling */, iconv = module.exports;
    // All codecs and aliases are kept here, keyed by encoding name/alias.
    // They are lazy loaded in `iconv.getCodec` from `encodings/index.js`.
    iconv.encodings = null;
    // Characters emitted in case of error.
    iconv.defaultCharUnicode = '�';
    iconv.defaultCharSingleByte = '?';
    // Public API.
    iconv.encode = function encode(str, encoding, options) {
        str = "" + (str || ""); // Ensure string.
        var encoder = iconv.getEncoder(encoding, options);
        var res = encoder.write(str);
        var trail = encoder.end();
        return (trail && trail.length > 0) ? Buffer.concat([res, trail]) : res;
    };
    iconv.decode = function decode(buf, encoding, options) {
        if (typeof buf === 'string') {
            if (!iconv.skipDecodeWarning) {
                console.error('Iconv-lite warning: decode()-ing strings is deprecated. Refer to https://github.com/ashtuchkin/iconv-lite/wiki/Use-Buffers-when-decoding');
                iconv.skipDecodeWarning = true;
            }
            buf = Buffer.from("" + (buf || ""), "binary"); // Ensure buffer.
        }
        var decoder = iconv.getDecoder(encoding, options);
        var res = decoder.write(buf);
        var trail = decoder.end();
        return trail ? (res + trail) : res;
    };
    iconv.encodingExists = function encodingExists(enc) {
        try {
            iconv.getCodec(enc);
            return true;
        }
        catch (e) {
            return false;
        }
    };
    // Legacy aliases to convert functions
    iconv.toEncoding = iconv.encode;
    iconv.fromEncoding = iconv.decode;
    // Search for a codec in iconv.encodings. Cache codec data in iconv._codecDataCache.
    iconv._codecDataCache = {};
    iconv.getCodec = function getCodec(encoding) {
        if (!iconv.encodings)
            iconv.encodings = require(87) /* ../encodings */; // Lazy load all encoding definitions.
        // Canonicalize encoding name: strip all non-alphanumeric chars and appended year.
        var enc = iconv._canonicalizeEncoding(encoding);
        // Traverse iconv.encodings to find actual codec.
        var codecOptions = {};
        while (true) {
            var codec = iconv._codecDataCache[enc];
            if (codec)
                return codec;
            var codecDef = iconv.encodings[enc];
            switch (typeof codecDef) {
                case "string": // Direct alias to other encoding.
                    enc = codecDef;
                    break;
                case "object": // Alias with options. Can be layered.
                    for (var key in codecDef)
                        codecOptions[key] = codecDef[key];
                    if (!codecOptions.encodingName)
                        codecOptions.encodingName = enc;
                    enc = codecDef.type;
                    break;
                case "function": // Codec itself.
                    if (!codecOptions.encodingName)
                        codecOptions.encodingName = enc;
                    // The codec function must load all tables and return object with .encoder and .decoder methods.
                    // It'll be called only once (for each different options object).
                    codec = new codecDef(codecOptions, iconv);
                    iconv._codecDataCache[codecOptions.encodingName] = codec; // Save it to be reused later.
                    return codec;
                default:
                    throw new Error("Encoding not recognized: '" + encoding + "' (searched as: '" + enc + "')");
            }
        }
    };
    iconv._canonicalizeEncoding = function (encoding) {
        // Canonicalize encoding name: strip all non-alphanumeric chars and appended year.
        return ('' + encoding).toLowerCase().replace(/:\d{4}$|[^0-9a-z]/g, "");
    };
    iconv.getEncoder = function getEncoder(encoding, options) {
        var codec = iconv.getCodec(encoding), encoder = new codec.encoder(options, codec);
        if (codec.bomAware && options && options.addBOM)
            encoder = new bomHandling.PrependBOM(encoder, options);
        return encoder;
    };
    iconv.getDecoder = function getDecoder(encoding, options) {
        var codec = iconv.getCodec(encoding), decoder = new codec.decoder(options, codec);
        if (codec.bomAware && !(options && options.stripBOM === false))
            decoder = new bomHandling.StripBOM(decoder, options);
        return decoder;
    };
    // Load extensions in Node. All of them are omitted in Browserify build via 'browser' field in package.json.
    var nodeVer = typeof process !== 'undefined' && process.versions && process.versions.node;
    if (nodeVer) {
        // Load streaming support in Node v0.10+
        var nodeVerArr = nodeVer.split(".").map(Number);
        if (nodeVerArr[0] > 0 || nodeVerArr[1] >= 10) {
            require(104) /* ./streams */(iconv);
        }
        // Load Node primitive extensions.
        require(105) /* ./extend-node */(iconv);
    }
    if ("Ā" != "\u0100") {
        console.error("iconv-lite warning: javascript files use encoding different from utf-8. See https://github.com/ashtuchkin/iconv-lite/wiki/Javascript-source-file-encodings for more info.");
    }
},
/* safer-buffer/safer.js */ function _(require, module, exports, __esModule, __esExport) {/* eslint-disable node/no-deprecated-api */
    'use strict';
    var buffer = require('buffer');
    var Buffer = buffer.Buffer;
    var safer = {};
    var key;
    for (key in buffer) {
        if (!buffer.hasOwnProperty(key))
            continue;
        if (key === 'SlowBuffer' || key === 'Buffer')
            continue;
        safer[key] = buffer[key];
    }
    var Safer = safer.Buffer = {};
    for (key in Buffer) {
        if (!Buffer.hasOwnProperty(key))
            continue;
        if (key === 'allocUnsafe' || key === 'allocUnsafeSlow')
            continue;
        Safer[key] = Buffer[key];
    }
    safer.Buffer.prototype = Buffer.prototype;
    if (!Safer.from || Safer.from === Uint8Array.from) {
        Safer.from = function (value, encodingOrOffset, length) {
            if (typeof value === 'number') {
                throw new TypeError('The "value" argument must not be of type number. Received type ' + typeof value);
            }
            if (value && typeof value.length === 'undefined') {
                throw new TypeError('The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type ' + typeof value);
            }
            return Buffer(value, encodingOrOffset, length);
        };
    }
    if (!Safer.alloc) {
        Safer.alloc = function (size, fill, encoding) {
            if (typeof size !== 'number') {
                throw new TypeError('The "size" argument must be of type number. Received type ' + typeof size);
            }
            if (size < 0 || size >= 2 * (1 << 30)) {
                throw new RangeError('The value "' + size + '" is invalid for option "size"');
            }
            var buf = Buffer(size);
            if (!fill || fill.length === 0) {
                buf.fill(0);
            }
            else if (typeof encoding === 'string') {
                buf.fill(fill, encoding);
            }
            else {
                buf.fill(fill);
            }
            return buf;
        };
    }
    if (!safer.kStringMaxLength) {
        try {
            safer.kStringMaxLength = process.binding('buffer').kStringMaxLength;
        }
        catch (e) {
            // we can't determine kStringMaxLength in environments where process.binding
            // is unsupported, so let's not set it
        }
    }
    if (!safer.constants) {
        safer.constants = {
            MAX_LENGTH: safer.kMaxLength
        };
        if (safer.kStringMaxLength) {
            safer.constants.MAX_STRING_LENGTH = safer.kStringMaxLength;
        }
    }
    module.exports = safer;
},
/* iconv-lite/lib/bom-handling.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var BOMChar = '\uFEFF';
    exports.PrependBOM = PrependBOMWrapper;
    function PrependBOMWrapper(encoder, options) {
        this.encoder = encoder;
        this.addBOM = true;
    }
    PrependBOMWrapper.prototype.write = function (str) {
        if (this.addBOM) {
            str = BOMChar + str;
            this.addBOM = false;
        }
        return this.encoder.write(str);
    };
    PrependBOMWrapper.prototype.end = function () {
        return this.encoder.end();
    };
    //------------------------------------------------------------------------------
    exports.StripBOM = StripBOMWrapper;
    function StripBOMWrapper(decoder, options) {
        this.decoder = decoder;
        this.pass = false;
        this.options = options || {};
    }
    StripBOMWrapper.prototype.write = function (buf) {
        var res = this.decoder.write(buf);
        if (this.pass || !res)
            return res;
        if (res[0] === BOMChar) {
            res = res.slice(1);
            if (typeof this.options.stripBOM === 'function')
                this.options.stripBOM();
        }
        this.pass = true;
        return res;
    };
    StripBOMWrapper.prototype.end = function () {
        return this.decoder.end();
    };
},
/* iconv-lite/encodings/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Update this array if you add/rename/remove files in this directory.
    // We support Browserify by skipping automatic module discovery and requiring modules directly.
    var modules = [
        require(88) /* ./internal */,
        require(89) /* ./utf16 */,
        require(90) /* ./utf7 */,
        require(91) /* ./sbcs-codec */,
        require(92) /* ./sbcs-data */,
        require(93) /* ./sbcs-data-generated */,
        require(94) /* ./dbcs-codec */,
        require(95) /* ./dbcs-data */,
    ];
    // Put all encoding/alias/codec definitions to single object and export it. 
    for (var i = 0; i < modules.length; i++) {
        var module = modules[i];
        for (var enc in module)
            if (Object.prototype.hasOwnProperty.call(module, enc))
                exports[enc] = module[enc];
    }
},
/* iconv-lite/encodings/internal.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // Export Node.js internal encodings.
    module.exports = {
        // Encodings
        utf8: { type: "_internal", bomAware: true },
        cesu8: { type: "_internal", bomAware: true },
        unicode11utf8: "utf8",
        ucs2: { type: "_internal", bomAware: true },
        utf16le: "ucs2",
        binary: { type: "_internal" },
        base64: { type: "_internal" },
        hex: { type: "_internal" },
        // Codec.
        _internal: InternalCodec,
    };
    //------------------------------------------------------------------------------
    function InternalCodec(codecOptions, iconv) {
        this.enc = codecOptions.encodingName;
        this.bomAware = codecOptions.bomAware;
        if (this.enc === "base64")
            this.encoder = InternalEncoderBase64;
        else if (this.enc === "cesu8") {
            this.enc = "utf8"; // Use utf8 for decoding.
            this.encoder = InternalEncoderCesu8;
            // Add decoder for versions of Node not supporting CESU-8
            if (Buffer.from('eda0bdedb2a9', 'hex').toString() !== '💩') {
                this.decoder = InternalDecoderCesu8;
                this.defaultCharUnicode = iconv.defaultCharUnicode;
            }
        }
    }
    InternalCodec.prototype.encoder = InternalEncoder;
    InternalCodec.prototype.decoder = InternalDecoder;
    //------------------------------------------------------------------------------
    // We use node.js internal decoder. Its signature is the same as ours.
    var StringDecoder = require('string_decoder').StringDecoder;
    if (!StringDecoder.prototype.end) // Node v0.8 doesn't have this method.
        StringDecoder.prototype.end = function () { };
    function InternalDecoder(options, codec) {
        StringDecoder.call(this, codec.enc);
    }
    InternalDecoder.prototype = StringDecoder.prototype;
    //------------------------------------------------------------------------------
    // Encoder is mostly trivial
    function InternalEncoder(options, codec) {
        this.enc = codec.enc;
    }
    InternalEncoder.prototype.write = function (str) {
        return Buffer.from(str, this.enc);
    };
    InternalEncoder.prototype.end = function () {
    };
    //------------------------------------------------------------------------------
    // Except base64 encoder, which must keep its state.
    function InternalEncoderBase64(options, codec) {
        this.prevStr = '';
    }
    InternalEncoderBase64.prototype.write = function (str) {
        str = this.prevStr + str;
        var completeQuads = str.length - (str.length % 4);
        this.prevStr = str.slice(completeQuads);
        str = str.slice(0, completeQuads);
        return Buffer.from(str, "base64");
    };
    InternalEncoderBase64.prototype.end = function () {
        return Buffer.from(this.prevStr, "base64");
    };
    //------------------------------------------------------------------------------
    // CESU-8 encoder is also special.
    function InternalEncoderCesu8(options, codec) {
    }
    InternalEncoderCesu8.prototype.write = function (str) {
        var buf = Buffer.alloc(str.length * 3), bufIdx = 0;
        for (var i = 0; i < str.length; i++) {
            var charCode = str.charCodeAt(i);
            // Naive implementation, but it works because CESU-8 is especially easy
            // to convert from UTF-16 (which all JS strings are encoded in).
            if (charCode < 0x80)
                buf[bufIdx++] = charCode;
            else if (charCode < 0x800) {
                buf[bufIdx++] = 0xC0 + (charCode >>> 6);
                buf[bufIdx++] = 0x80 + (charCode & 0x3f);
            }
            else { // charCode will always be < 0x10000 in javascript.
                buf[bufIdx++] = 0xE0 + (charCode >>> 12);
                buf[bufIdx++] = 0x80 + ((charCode >>> 6) & 0x3f);
                buf[bufIdx++] = 0x80 + (charCode & 0x3f);
            }
        }
        return buf.slice(0, bufIdx);
    };
    InternalEncoderCesu8.prototype.end = function () {
    };
    //------------------------------------------------------------------------------
    // CESU-8 decoder is not implemented in Node v4.0+
    function InternalDecoderCesu8(options, codec) {
        this.acc = 0;
        this.contBytes = 0;
        this.accBytes = 0;
        this.defaultCharUnicode = codec.defaultCharUnicode;
    }
    InternalDecoderCesu8.prototype.write = function (buf) {
        var acc = this.acc, contBytes = this.contBytes, accBytes = this.accBytes, res = '';
        for (var i = 0; i < buf.length; i++) {
            var curByte = buf[i];
            if ((curByte & 0xC0) !== 0x80) { // Leading byte
                if (contBytes > 0) { // Previous code is invalid
                    res += this.defaultCharUnicode;
                    contBytes = 0;
                }
                if (curByte < 0x80) { // Single-byte code
                    res += String.fromCharCode(curByte);
                }
                else if (curByte < 0xE0) { // Two-byte code
                    acc = curByte & 0x1F;
                    contBytes = 1;
                    accBytes = 1;
                }
                else if (curByte < 0xF0) { // Three-byte code
                    acc = curByte & 0x0F;
                    contBytes = 2;
                    accBytes = 1;
                }
                else { // Four or more are not supported for CESU-8.
                    res += this.defaultCharUnicode;
                }
            }
            else { // Continuation byte
                if (contBytes > 0) { // We're waiting for it.
                    acc = (acc << 6) | (curByte & 0x3f);
                    contBytes--;
                    accBytes++;
                    if (contBytes === 0) {
                        // Check for overlong encoding, but support Modified UTF-8 (encoding NULL as C0 80)
                        if (accBytes === 2 && acc < 0x80 && acc > 0)
                            res += this.defaultCharUnicode;
                        else if (accBytes === 3 && acc < 0x800)
                            res += this.defaultCharUnicode;
                        else
                            // Actually add character.
                            res += String.fromCharCode(acc);
                    }
                }
                else { // Unexpected continuation byte
                    res += this.defaultCharUnicode;
                }
            }
        }
        this.acc = acc;
        this.contBytes = contBytes;
        this.accBytes = accBytes;
        return res;
    };
    InternalDecoderCesu8.prototype.end = function () {
        var res = 0;
        if (this.contBytes > 0)
            res += this.defaultCharUnicode;
        return res;
    };
},
/* iconv-lite/encodings/utf16.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // Note: UTF16-LE (or UCS2) codec is Node.js native. See encodings/internal.js
    // == UTF16-BE codec. ==========================================================
    exports.utf16be = Utf16BECodec;
    function Utf16BECodec() {
    }
    Utf16BECodec.prototype.encoder = Utf16BEEncoder;
    Utf16BECodec.prototype.decoder = Utf16BEDecoder;
    Utf16BECodec.prototype.bomAware = true;
    // -- Encoding
    function Utf16BEEncoder() {
    }
    Utf16BEEncoder.prototype.write = function (str) {
        var buf = Buffer.from(str, 'ucs2');
        for (var i = 0; i < buf.length; i += 2) {
            var tmp = buf[i];
            buf[i] = buf[i + 1];
            buf[i + 1] = tmp;
        }
        return buf;
    };
    Utf16BEEncoder.prototype.end = function () {
    };
    // -- Decoding
    function Utf16BEDecoder() {
        this.overflowByte = -1;
    }
    Utf16BEDecoder.prototype.write = function (buf) {
        if (buf.length == 0)
            return '';
        var buf2 = Buffer.alloc(buf.length + 1), i = 0, j = 0;
        if (this.overflowByte !== -1) {
            buf2[0] = buf[0];
            buf2[1] = this.overflowByte;
            i = 1;
            j = 2;
        }
        for (; i < buf.length - 1; i += 2, j += 2) {
            buf2[j] = buf[i + 1];
            buf2[j + 1] = buf[i];
        }
        this.overflowByte = (i == buf.length - 1) ? buf[buf.length - 1] : -1;
        return buf2.slice(0, j).toString('ucs2');
    };
    Utf16BEDecoder.prototype.end = function () {
    };
    // == UTF-16 codec =============================================================
    // Decoder chooses automatically from UTF-16LE and UTF-16BE using BOM and space-based heuristic.
    // Defaults to UTF-16LE, as it's prevalent and default in Node.
    // http://en.wikipedia.org/wiki/UTF-16 and http://encoding.spec.whatwg.org/#utf-16le
    // Decoder default can be changed: iconv.decode(buf, 'utf16', {defaultEncoding: 'utf-16be'});
    // Encoder uses UTF-16LE and prepends BOM (which can be overridden with addBOM: false).
    exports.utf16 = Utf16Codec;
    function Utf16Codec(codecOptions, iconv) {
        this.iconv = iconv;
    }
    Utf16Codec.prototype.encoder = Utf16Encoder;
    Utf16Codec.prototype.decoder = Utf16Decoder;
    // -- Encoding (pass-through)
    function Utf16Encoder(options, codec) {
        options = options || {};
        if (options.addBOM === undefined)
            options.addBOM = true;
        this.encoder = codec.iconv.getEncoder('utf-16le', options);
    }
    Utf16Encoder.prototype.write = function (str) {
        return this.encoder.write(str);
    };
    Utf16Encoder.prototype.end = function () {
        return this.encoder.end();
    };
    // -- Decoding
    function Utf16Decoder(options, codec) {
        this.decoder = null;
        this.initialBytes = [];
        this.initialBytesLen = 0;
        this.options = options || {};
        this.iconv = codec.iconv;
    }
    Utf16Decoder.prototype.write = function (buf) {
        if (!this.decoder) {
            // Codec is not chosen yet. Accumulate initial bytes.
            this.initialBytes.push(buf);
            this.initialBytesLen += buf.length;
            if (this.initialBytesLen < 16) // We need more bytes to use space heuristic (see below)
                return '';
            // We have enough bytes -> detect endianness.
            var buf = Buffer.concat(this.initialBytes), encoding = detectEncoding(buf, this.options.defaultEncoding);
            this.decoder = this.iconv.getDecoder(encoding, this.options);
            this.initialBytes.length = this.initialBytesLen = 0;
        }
        return this.decoder.write(buf);
    };
    Utf16Decoder.prototype.end = function () {
        if (!this.decoder) {
            var buf = Buffer.concat(this.initialBytes), encoding = detectEncoding(buf, this.options.defaultEncoding);
            this.decoder = this.iconv.getDecoder(encoding, this.options);
            var res = this.decoder.write(buf), trail = this.decoder.end();
            return trail ? (res + trail) : res;
        }
        return this.decoder.end();
    };
    function detectEncoding(buf, defaultEncoding) {
        var enc = defaultEncoding || 'utf-16le';
        if (buf.length >= 2) {
            // Check BOM.
            if (buf[0] == 0xFE && buf[1] == 0xFF) // UTF-16BE BOM
                enc = 'utf-16be';
            else if (buf[0] == 0xFF && buf[1] == 0xFE) // UTF-16LE BOM
                enc = 'utf-16le';
            else {
                // No BOM found. Try to deduce encoding from initial content.
                // Most of the time, the content has ASCII chars (U+00**), but the opposite (U+**00) is uncommon.
                // So, we count ASCII as if it was LE or BE, and decide from that.
                var asciiCharsLE = 0, asciiCharsBE = 0, // Counts of chars in both positions
                _len = Math.min(buf.length - (buf.length % 2), 64); // Len is always even.
                for (var i = 0; i < _len; i += 2) {
                    if (buf[i] === 0 && buf[i + 1] !== 0)
                        asciiCharsBE++;
                    if (buf[i] !== 0 && buf[i + 1] === 0)
                        asciiCharsLE++;
                }
                if (asciiCharsBE > asciiCharsLE)
                    enc = 'utf-16be';
                else if (asciiCharsBE < asciiCharsLE)
                    enc = 'utf-16le';
            }
        }
        return enc;
    }
},
/* iconv-lite/encodings/utf7.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // UTF-7 codec, according to https://tools.ietf.org/html/rfc2152
    // See also below a UTF-7-IMAP codec, according to http://tools.ietf.org/html/rfc3501#section-5.1.3
    exports.utf7 = Utf7Codec;
    exports.unicode11utf7 = 'utf7'; // Alias UNICODE-1-1-UTF-7
    function Utf7Codec(codecOptions, iconv) {
        this.iconv = iconv;
    }
    ;
    Utf7Codec.prototype.encoder = Utf7Encoder;
    Utf7Codec.prototype.decoder = Utf7Decoder;
    Utf7Codec.prototype.bomAware = true;
    // -- Encoding
    var nonDirectChars = /[^A-Za-z0-9'\(\),-\.\/:\? \n\r\t]+/g;
    function Utf7Encoder(options, codec) {
        this.iconv = codec.iconv;
    }
    Utf7Encoder.prototype.write = function (str) {
        // Naive implementation.
        // Non-direct chars are encoded as "+<base64>-"; single "+" char is encoded as "+-".
        return Buffer.from(str.replace(nonDirectChars, function (chunk) {
            return "+" + (chunk === '+' ? '' :
                this.iconv.encode(chunk, 'utf16-be').toString('base64').replace(/=+$/, ''))
                + "-";
        }.bind(this)));
    };
    Utf7Encoder.prototype.end = function () {
    };
    // -- Decoding
    function Utf7Decoder(options, codec) {
        this.iconv = codec.iconv;
        this.inBase64 = false;
        this.base64Accum = '';
    }
    var base64Regex = /[A-Za-z0-9\/+]/;
    var base64Chars = [];
    for (var i = 0; i < 256; i++)
        base64Chars[i] = base64Regex.test(String.fromCharCode(i));
    var plusChar = '+'.charCodeAt(0), minusChar = '-'.charCodeAt(0), andChar = '&'.charCodeAt(0);
    Utf7Decoder.prototype.write = function (buf) {
        var res = "", lastI = 0, inBase64 = this.inBase64, base64Accum = this.base64Accum;
        // The decoder is more involved as we must handle chunks in stream.
        for (var i = 0; i < buf.length; i++) {
            if (!inBase64) { // We're in direct mode.
                // Write direct chars until '+'
                if (buf[i] == plusChar) {
                    res += this.iconv.decode(buf.slice(lastI, i), "ascii"); // Write direct chars.
                    lastI = i + 1;
                    inBase64 = true;
                }
            }
            else { // We decode base64.
                if (!base64Chars[buf[i]]) { // Base64 ended.
                    if (i == lastI && buf[i] == minusChar) { // "+-" -> "+"
                        res += "+";
                    }
                    else {
                        var b64str = base64Accum + buf.slice(lastI, i).toString();
                        res += this.iconv.decode(Buffer.from(b64str, 'base64'), "utf16-be");
                    }
                    if (buf[i] != minusChar) // Minus is absorbed after base64.
                        i--;
                    lastI = i + 1;
                    inBase64 = false;
                    base64Accum = '';
                }
            }
        }
        if (!inBase64) {
            res += this.iconv.decode(buf.slice(lastI), "ascii"); // Write direct chars.
        }
        else {
            var b64str = base64Accum + buf.slice(lastI).toString();
            var canBeDecoded = b64str.length - (b64str.length % 8); // Minimal chunk: 2 quads -> 2x3 bytes -> 3 chars.
            base64Accum = b64str.slice(canBeDecoded); // The rest will be decoded in future.
            b64str = b64str.slice(0, canBeDecoded);
            res += this.iconv.decode(Buffer.from(b64str, 'base64'), "utf16-be");
        }
        this.inBase64 = inBase64;
        this.base64Accum = base64Accum;
        return res;
    };
    Utf7Decoder.prototype.end = function () {
        var res = "";
        if (this.inBase64 && this.base64Accum.length > 0)
            res = this.iconv.decode(Buffer.from(this.base64Accum, 'base64'), "utf16-be");
        this.inBase64 = false;
        this.base64Accum = '';
        return res;
    };
    // UTF-7-IMAP codec.
    // RFC3501 Sec. 5.1.3 Modified UTF-7 (http://tools.ietf.org/html/rfc3501#section-5.1.3)
    // Differences:
    //  * Base64 part is started by "&" instead of "+"
    //  * Direct characters are 0x20-0x7E, except "&" (0x26)
    //  * In Base64, "," is used instead of "/"
    //  * Base64 must not be used to represent direct characters.
    //  * No implicit shift back from Base64 (should always end with '-')
    //  * String must end in non-shifted position.
    //  * "-&" while in base64 is not allowed.
    exports.utf7imap = Utf7IMAPCodec;
    function Utf7IMAPCodec(codecOptions, iconv) {
        this.iconv = iconv;
    }
    ;
    Utf7IMAPCodec.prototype.encoder = Utf7IMAPEncoder;
    Utf7IMAPCodec.prototype.decoder = Utf7IMAPDecoder;
    Utf7IMAPCodec.prototype.bomAware = true;
    // -- Encoding
    function Utf7IMAPEncoder(options, codec) {
        this.iconv = codec.iconv;
        this.inBase64 = false;
        this.base64Accum = Buffer.alloc(6);
        this.base64AccumIdx = 0;
    }
    Utf7IMAPEncoder.prototype.write = function (str) {
        var inBase64 = this.inBase64, base64Accum = this.base64Accum, base64AccumIdx = this.base64AccumIdx, buf = Buffer.alloc(str.length * 5 + 10), bufIdx = 0;
        for (var i = 0; i < str.length; i++) {
            var uChar = str.charCodeAt(i);
            if (0x20 <= uChar && uChar <= 0x7E) { // Direct character or '&'.
                if (inBase64) {
                    if (base64AccumIdx > 0) {
                        bufIdx += buf.write(base64Accum.slice(0, base64AccumIdx).toString('base64').replace(/\//g, ',').replace(/=+$/, ''), bufIdx);
                        base64AccumIdx = 0;
                    }
                    buf[bufIdx++] = minusChar; // Write '-', then go to direct mode.
                    inBase64 = false;
                }
                if (!inBase64) {
                    buf[bufIdx++] = uChar; // Write direct character
                    if (uChar === andChar) // Ampersand -> '&-'
                        buf[bufIdx++] = minusChar;
                }
            }
            else { // Non-direct character
                if (!inBase64) {
                    buf[bufIdx++] = andChar; // Write '&', then go to base64 mode.
                    inBase64 = true;
                }
                if (inBase64) {
                    base64Accum[base64AccumIdx++] = uChar >> 8;
                    base64Accum[base64AccumIdx++] = uChar & 0xFF;
                    if (base64AccumIdx == base64Accum.length) {
                        bufIdx += buf.write(base64Accum.toString('base64').replace(/\//g, ','), bufIdx);
                        base64AccumIdx = 0;
                    }
                }
            }
        }
        this.inBase64 = inBase64;
        this.base64AccumIdx = base64AccumIdx;
        return buf.slice(0, bufIdx);
    };
    Utf7IMAPEncoder.prototype.end = function () {
        var buf = Buffer.alloc(10), bufIdx = 0;
        if (this.inBase64) {
            if (this.base64AccumIdx > 0) {
                bufIdx += buf.write(this.base64Accum.slice(0, this.base64AccumIdx).toString('base64').replace(/\//g, ',').replace(/=+$/, ''), bufIdx);
                this.base64AccumIdx = 0;
            }
            buf[bufIdx++] = minusChar; // Write '-', then go to direct mode.
            this.inBase64 = false;
        }
        return buf.slice(0, bufIdx);
    };
    // -- Decoding
    function Utf7IMAPDecoder(options, codec) {
        this.iconv = codec.iconv;
        this.inBase64 = false;
        this.base64Accum = '';
    }
    var base64IMAPChars = base64Chars.slice();
    base64IMAPChars[','.charCodeAt(0)] = true;
    Utf7IMAPDecoder.prototype.write = function (buf) {
        var res = "", lastI = 0, inBase64 = this.inBase64, base64Accum = this.base64Accum;
        // The decoder is more involved as we must handle chunks in stream.
        // It is forgiving, closer to standard UTF-7 (for example, '-' is optional at the end).
        for (var i = 0; i < buf.length; i++) {
            if (!inBase64) { // We're in direct mode.
                // Write direct chars until '&'
                if (buf[i] == andChar) {
                    res += this.iconv.decode(buf.slice(lastI, i), "ascii"); // Write direct chars.
                    lastI = i + 1;
                    inBase64 = true;
                }
            }
            else { // We decode base64.
                if (!base64IMAPChars[buf[i]]) { // Base64 ended.
                    if (i == lastI && buf[i] == minusChar) { // "&-" -> "&"
                        res += "&";
                    }
                    else {
                        var b64str = base64Accum + buf.slice(lastI, i).toString().replace(/,/g, '/');
                        res += this.iconv.decode(Buffer.from(b64str, 'base64'), "utf16-be");
                    }
                    if (buf[i] != minusChar) // Minus may be absorbed after base64.
                        i--;
                    lastI = i + 1;
                    inBase64 = false;
                    base64Accum = '';
                }
            }
        }
        if (!inBase64) {
            res += this.iconv.decode(buf.slice(lastI), "ascii"); // Write direct chars.
        }
        else {
            var b64str = base64Accum + buf.slice(lastI).toString().replace(/,/g, '/');
            var canBeDecoded = b64str.length - (b64str.length % 8); // Minimal chunk: 2 quads -> 2x3 bytes -> 3 chars.
            base64Accum = b64str.slice(canBeDecoded); // The rest will be decoded in future.
            b64str = b64str.slice(0, canBeDecoded);
            res += this.iconv.decode(Buffer.from(b64str, 'base64'), "utf16-be");
        }
        this.inBase64 = inBase64;
        this.base64Accum = base64Accum;
        return res;
    };
    Utf7IMAPDecoder.prototype.end = function () {
        var res = "";
        if (this.inBase64 && this.base64Accum.length > 0)
            res = this.iconv.decode(Buffer.from(this.base64Accum, 'base64'), "utf16-be");
        this.inBase64 = false;
        this.base64Accum = '';
        return res;
    };
},
/* iconv-lite/encodings/sbcs-codec.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // Single-byte codec. Needs a 'chars' string parameter that contains 256 or 128 chars that
    // correspond to encoded bytes (if 128 - then lower half is ASCII). 
    exports._sbcs = SBCSCodec;
    function SBCSCodec(codecOptions, iconv) {
        if (!codecOptions)
            throw new Error("SBCS codec is called without the data.");
        // Prepare char buffer for decoding.
        if (!codecOptions.chars || (codecOptions.chars.length !== 128 && codecOptions.chars.length !== 256))
            throw new Error("Encoding '" + codecOptions.type + "' has incorrect 'chars' (must be of len 128 or 256)");
        if (codecOptions.chars.length === 128) {
            var asciiString = "";
            for (var i = 0; i < 128; i++)
                asciiString += String.fromCharCode(i);
            codecOptions.chars = asciiString + codecOptions.chars;
        }
        this.decodeBuf = Buffer.from(codecOptions.chars, 'ucs2');
        // Encoding buffer.
        var encodeBuf = Buffer.alloc(65536, iconv.defaultCharSingleByte.charCodeAt(0));
        for (var i = 0; i < codecOptions.chars.length; i++)
            encodeBuf[codecOptions.chars.charCodeAt(i)] = i;
        this.encodeBuf = encodeBuf;
    }
    SBCSCodec.prototype.encoder = SBCSEncoder;
    SBCSCodec.prototype.decoder = SBCSDecoder;
    function SBCSEncoder(options, codec) {
        this.encodeBuf = codec.encodeBuf;
    }
    SBCSEncoder.prototype.write = function (str) {
        var buf = Buffer.alloc(str.length);
        for (var i = 0; i < str.length; i++)
            buf[i] = this.encodeBuf[str.charCodeAt(i)];
        return buf;
    };
    SBCSEncoder.prototype.end = function () {
    };
    function SBCSDecoder(options, codec) {
        this.decodeBuf = codec.decodeBuf;
    }
    SBCSDecoder.prototype.write = function (buf) {
        // Strings are immutable in JS -> we use ucs2 buffer to speed up computations.
        var decodeBuf = this.decodeBuf;
        var newBuf = Buffer.alloc(buf.length * 2);
        var idx1 = 0, idx2 = 0;
        for (var i = 0; i < buf.length; i++) {
            idx1 = buf[i] * 2;
            idx2 = i * 2;
            newBuf[idx2] = decodeBuf[idx1];
            newBuf[idx2 + 1] = decodeBuf[idx1 + 1];
        }
        return newBuf.toString('ucs2');
    };
    SBCSDecoder.prototype.end = function () {
    };
},
/* iconv-lite/encodings/sbcs-data.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Manually added data to be used by sbcs codec in addition to generated one.
    module.exports = {
        // Not supported by iconv, not sure why.
        "10029": "maccenteuro",
        "maccenteuro": {
            "type": "_sbcs",
            "chars": "ÄĀāÉĄÖÜáąČäčĆćéŹźĎíďĒēĖóėôöõúĚěü†°Ę£§•¶ß®©™ę¨≠ģĮįĪ≤≥īĶ∂∑łĻļĽľĹĺŅņŃ¬√ńŇ∆«»… ňŐÕőŌ–—“”‘’÷◊ōŔŕŘ‹›řŖŗŠ‚„šŚśÁŤťÍŽžŪÓÔūŮÚůŰűŲųÝýķŻŁżĢˇ"
        },
        "808": "cp808",
        "ibm808": "cp808",
        "cp808": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёЄєЇїЎў°∙·√№€■ "
        },
        "mik": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя└┴┬├─┼╣║╚╔╩╦╠═╬┐░▒▓│┤№§╗╝┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        // Aliases of generated encodings.
        "ascii8bit": "ascii",
        "usascii": "ascii",
        "ansix34": "ascii",
        "ansix341968": "ascii",
        "ansix341986": "ascii",
        "csascii": "ascii",
        "cp367": "ascii",
        "ibm367": "ascii",
        "isoir6": "ascii",
        "iso646us": "ascii",
        "iso646irv": "ascii",
        "us": "ascii",
        "latin1": "iso88591",
        "latin2": "iso88592",
        "latin3": "iso88593",
        "latin4": "iso88594",
        "latin5": "iso88599",
        "latin6": "iso885910",
        "latin7": "iso885913",
        "latin8": "iso885914",
        "latin9": "iso885915",
        "latin10": "iso885916",
        "csisolatin1": "iso88591",
        "csisolatin2": "iso88592",
        "csisolatin3": "iso88593",
        "csisolatin4": "iso88594",
        "csisolatincyrillic": "iso88595",
        "csisolatinarabic": "iso88596",
        "csisolatingreek": "iso88597",
        "csisolatinhebrew": "iso88598",
        "csisolatin5": "iso88599",
        "csisolatin6": "iso885910",
        "l1": "iso88591",
        "l2": "iso88592",
        "l3": "iso88593",
        "l4": "iso88594",
        "l5": "iso88599",
        "l6": "iso885910",
        "l7": "iso885913",
        "l8": "iso885914",
        "l9": "iso885915",
        "l10": "iso885916",
        "isoir14": "iso646jp",
        "isoir57": "iso646cn",
        "isoir100": "iso88591",
        "isoir101": "iso88592",
        "isoir109": "iso88593",
        "isoir110": "iso88594",
        "isoir144": "iso88595",
        "isoir127": "iso88596",
        "isoir126": "iso88597",
        "isoir138": "iso88598",
        "isoir148": "iso88599",
        "isoir157": "iso885910",
        "isoir166": "tis620",
        "isoir179": "iso885913",
        "isoir199": "iso885914",
        "isoir203": "iso885915",
        "isoir226": "iso885916",
        "cp819": "iso88591",
        "ibm819": "iso88591",
        "cyrillic": "iso88595",
        "arabic": "iso88596",
        "arabic8": "iso88596",
        "ecma114": "iso88596",
        "asmo708": "iso88596",
        "greek": "iso88597",
        "greek8": "iso88597",
        "ecma118": "iso88597",
        "elot928": "iso88597",
        "hebrew": "iso88598",
        "hebrew8": "iso88598",
        "turkish": "iso88599",
        "turkish8": "iso88599",
        "thai": "iso885911",
        "thai8": "iso885911",
        "celtic": "iso885914",
        "celtic8": "iso885914",
        "isoceltic": "iso885914",
        "tis6200": "tis620",
        "tis62025291": "tis620",
        "tis62025330": "tis620",
        "10000": "macroman",
        "10006": "macgreek",
        "10007": "maccyrillic",
        "10079": "maciceland",
        "10081": "macturkish",
        "cspc8codepage437": "cp437",
        "cspc775baltic": "cp775",
        "cspc850multilingual": "cp850",
        "cspcp852": "cp852",
        "cspc862latinhebrew": "cp862",
        "cpgr": "cp869",
        "msee": "cp1250",
        "mscyrl": "cp1251",
        "msansi": "cp1252",
        "msgreek": "cp1253",
        "msturk": "cp1254",
        "mshebr": "cp1255",
        "msarab": "cp1256",
        "winbaltrim": "cp1257",
        "cp20866": "koi8r",
        "20866": "koi8r",
        "ibm878": "koi8r",
        "cskoi8r": "koi8r",
        "cp21866": "koi8u",
        "21866": "koi8u",
        "ibm1168": "koi8u",
        "strk10482002": "rk1048",
        "tcvn5712": "tcvn",
        "tcvn57121": "tcvn",
        "gb198880": "iso646cn",
        "cn": "iso646cn",
        "csiso14jisc6220ro": "iso646jp",
        "jisc62201969ro": "iso646jp",
        "jp": "iso646jp",
        "cshproman8": "hproman8",
        "r8": "hproman8",
        "roman8": "hproman8",
        "xroman8": "hproman8",
        "ibm1051": "hproman8",
        "mac": "macintosh",
        "csmacintosh": "macintosh",
    };
},
/* iconv-lite/encodings/sbcs-data-generated.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Generated data for sbcs codec. Don't edit manually. Regenerate using generation/gen-sbcs.js script.
    module.exports = {
        "437": "cp437",
        "737": "cp737",
        "775": "cp775",
        "850": "cp850",
        "852": "cp852",
        "855": "cp855",
        "856": "cp856",
        "857": "cp857",
        "858": "cp858",
        "860": "cp860",
        "861": "cp861",
        "862": "cp862",
        "863": "cp863",
        "864": "cp864",
        "865": "cp865",
        "866": "cp866",
        "869": "cp869",
        "874": "windows874",
        "922": "cp922",
        "1046": "cp1046",
        "1124": "cp1124",
        "1125": "cp1125",
        "1129": "cp1129",
        "1133": "cp1133",
        "1161": "cp1161",
        "1162": "cp1162",
        "1163": "cp1163",
        "1250": "windows1250",
        "1251": "windows1251",
        "1252": "windows1252",
        "1253": "windows1253",
        "1254": "windows1254",
        "1255": "windows1255",
        "1256": "windows1256",
        "1257": "windows1257",
        "1258": "windows1258",
        "28591": "iso88591",
        "28592": "iso88592",
        "28593": "iso88593",
        "28594": "iso88594",
        "28595": "iso88595",
        "28596": "iso88596",
        "28597": "iso88597",
        "28598": "iso88598",
        "28599": "iso88599",
        "28600": "iso885910",
        "28601": "iso885911",
        "28603": "iso885913",
        "28604": "iso885914",
        "28605": "iso885915",
        "28606": "iso885916",
        "windows874": {
            "type": "_sbcs",
            "chars": "€����…�����������‘’“”•–—�������� กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"
        },
        "win874": "windows874",
        "cp874": "windows874",
        "windows1250": {
            "type": "_sbcs",
            "chars": "€�‚�„…†‡�‰Š‹ŚŤŽŹ�‘’“”•–—�™š›śťžź ˇ˘Ł¤Ą¦§¨©Ş«¬­®Ż°±˛ł´µ¶·¸ąş»Ľ˝ľżŔÁÂĂÄĹĆÇČÉĘËĚÍÎĎĐŃŇÓÔŐÖ×ŘŮÚŰÜÝŢßŕáâăäĺćçčéęëěíîďđńňóôőö÷řůúűüýţ˙"
        },
        "win1250": "windows1250",
        "cp1250": "windows1250",
        "windows1251": {
            "type": "_sbcs",
            "chars": "ЂЃ‚ѓ„…†‡€‰Љ‹ЊЌЋЏђ‘’“”•–—�™љ›њќћџ ЎўЈ¤Ґ¦§Ё©Є«¬­®Ї°±Ііґµ¶·ё№є»јЅѕїАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"
        },
        "win1251": "windows1251",
        "cp1251": "windows1251",
        "windows1252": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡ˆ‰Š‹Œ�Ž��‘’“”•–—˜™š›œ�žŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "win1252": "windows1252",
        "cp1252": "windows1252",
        "windows1253": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡�‰�‹�����‘’“”•–—�™�›���� ΅Ά£¤¥¦§¨©�«¬­®―°±²³΄µ¶·ΈΉΊ»Ό½ΎΏΐΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡ�ΣΤΥΦΧΨΩΪΫάέήίΰαβγδεζηθικλμνξοπρςστυφχψωϊϋόύώ�"
        },
        "win1253": "windows1253",
        "cp1253": "windows1253",
        "windows1254": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡ˆ‰Š‹Œ����‘’“”•–—˜™š›œ��Ÿ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏĞÑÒÓÔÕÖ×ØÙÚÛÜİŞßàáâãäåæçèéêëìíîïğñòóôõö÷øùúûüışÿ"
        },
        "win1254": "windows1254",
        "cp1254": "windows1254",
        "windows1255": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡ˆ‰�‹�����‘’“”•–—˜™�›���� ¡¢£₪¥¦§¨©×«¬­®¯°±²³´µ¶·¸¹÷»¼½¾¿ְֱֲֳִֵֶַָֹֺֻּֽ־ֿ׀ׁׂ׃װױײ׳״�������אבגדהוזחטיךכלםמןנסעףפץצקרשת��‎‏�"
        },
        "win1255": "windows1255",
        "cp1255": "windows1255",
        "windows1256": {
            "type": "_sbcs",
            "chars": "€پ‚ƒ„…†‡ˆ‰ٹ‹Œچژڈگ‘’“”•–—ک™ڑ›œ‌‍ں ،¢£¤¥¦§¨©ھ«¬­®¯°±²³´µ¶·¸¹؛»¼½¾؟ہءآأؤإئابةتثجحخدذرزسشصض×طظعغـفقكàلâمنهوçèéêëىيîïًٌٍَôُِ÷ّùْûü‎‏ے"
        },
        "win1256": "windows1256",
        "cp1256": "windows1256",
        "windows1257": {
            "type": "_sbcs",
            "chars": "€�‚�„…†‡�‰�‹�¨ˇ¸�‘’“”•–—�™�›�¯˛� �¢£¤�¦§Ø©Ŗ«¬­®Æ°±²³´µ¶·ø¹ŗ»¼½¾æĄĮĀĆÄÅĘĒČÉŹĖĢĶĪĻŠŃŅÓŌÕÖ×ŲŁŚŪÜŻŽßąįāćäåęēčéźėģķīļšńņóōõö÷ųłśūüżž˙"
        },
        "win1257": "windows1257",
        "cp1257": "windows1257",
        "windows1258": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡ˆ‰�‹Œ����‘’“”•–—˜™�›œ��Ÿ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"
        },
        "win1258": "windows1258",
        "cp1258": "windows1258",
        "iso88591": {
            "type": "_sbcs",
            "chars": " ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "cp28591": "iso88591",
        "iso88592": {
            "type": "_sbcs",
            "chars": " Ą˘Ł¤ĽŚ§¨ŠŞŤŹ­ŽŻ°ą˛ł´ľśˇ¸šşťź˝žżŔÁÂĂÄĹĆÇČÉĘËĚÍÎĎĐŃŇÓÔŐÖ×ŘŮÚŰÜÝŢßŕáâăäĺćçčéęëěíîďđńňóôőö÷řůúűüýţ˙"
        },
        "cp28592": "iso88592",
        "iso88593": {
            "type": "_sbcs",
            "chars": " Ħ˘£¤�Ĥ§¨İŞĞĴ­�Ż°ħ²³´µĥ·¸ışğĵ½�żÀÁÂ�ÄĊĈÇÈÉÊËÌÍÎÏ�ÑÒÓÔĠÖ×ĜÙÚÛÜŬŜßàáâ�äċĉçèéêëìíîï�ñòóôġö÷ĝùúûüŭŝ˙"
        },
        "cp28593": "iso88593",
        "iso88594": {
            "type": "_sbcs",
            "chars": " ĄĸŖ¤ĨĻ§¨ŠĒĢŦ­Ž¯°ą˛ŗ´ĩļˇ¸šēģŧŊžŋĀÁÂÃÄÅÆĮČÉĘËĖÍÎĪĐŅŌĶÔÕÖ×ØŲÚÛÜŨŪßāáâãäåæįčéęëėíîīđņōķôõö÷øųúûüũū˙"
        },
        "cp28594": "iso88594",
        "iso88595": {
            "type": "_sbcs",
            "chars": " ЁЂЃЄЅІЇЈЉЊЋЌ­ЎЏАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя№ёђѓєѕіїјљњћќ§ўџ"
        },
        "cp28595": "iso88595",
        "iso88596": {
            "type": "_sbcs",
            "chars": " ���¤�������،­�������������؛���؟�ءآأؤإئابةتثجحخدذرزسشصضطظعغ�����ـفقكلمنهوىيًٌٍَُِّْ�������������"
        },
        "cp28596": "iso88596",
        "iso88597": {
            "type": "_sbcs",
            "chars": " ‘’£€₯¦§¨©ͺ«¬­�―°±²³΄΅Ά·ΈΉΊ»Ό½ΎΏΐΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡ�ΣΤΥΦΧΨΩΪΫάέήίΰαβγδεζηθικλμνξοπρςστυφχψωϊϋόύώ�"
        },
        "cp28597": "iso88597",
        "iso88598": {
            "type": "_sbcs",
            "chars": " �¢£¤¥¦§¨©×«¬­®¯°±²³´µ¶·¸¹÷»¼½¾��������������������������������‗אבגדהוזחטיךכלםמןנסעףפץצקרשת��‎‏�"
        },
        "cp28598": "iso88598",
        "iso88599": {
            "type": "_sbcs",
            "chars": " ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏĞÑÒÓÔÕÖ×ØÙÚÛÜİŞßàáâãäåæçèéêëìíîïğñòóôõö÷øùúûüışÿ"
        },
        "cp28599": "iso88599",
        "iso885910": {
            "type": "_sbcs",
            "chars": " ĄĒĢĪĨĶ§ĻĐŠŦŽ­ŪŊ°ąēģīĩķ·ļđšŧž―ūŋĀÁÂÃÄÅÆĮČÉĘËĖÍÎÏÐŅŌÓÔÕÖŨØŲÚÛÜÝÞßāáâãäåæįčéęëėíîïðņōóôõöũøųúûüýþĸ"
        },
        "cp28600": "iso885910",
        "iso885911": {
            "type": "_sbcs",
            "chars": " กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"
        },
        "cp28601": "iso885911",
        "iso885913": {
            "type": "_sbcs",
            "chars": " ”¢£¤„¦§Ø©Ŗ«¬­®Æ°±²³“µ¶·ø¹ŗ»¼½¾æĄĮĀĆÄÅĘĒČÉŹĖĢĶĪĻŠŃŅÓŌÕÖ×ŲŁŚŪÜŻŽßąįāćäåęēčéźėģķīļšńņóōõö÷ųłśūüżž’"
        },
        "cp28603": "iso885913",
        "iso885914": {
            "type": "_sbcs",
            "chars": " Ḃḃ£ĊċḊ§Ẁ©ẂḋỲ­®ŸḞḟĠġṀṁ¶ṖẁṗẃṠỳẄẅṡÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏŴÑÒÓÔÕÖṪØÙÚÛÜÝŶßàáâãäåæçèéêëìíîïŵñòóôõöṫøùúûüýŷÿ"
        },
        "cp28604": "iso885914",
        "iso885915": {
            "type": "_sbcs",
            "chars": " ¡¢£€¥Š§š©ª«¬­®¯°±²³Žµ¶·ž¹º»ŒœŸ¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "cp28605": "iso885915",
        "iso885916": {
            "type": "_sbcs",
            "chars": " ĄąŁ€„Š§š©Ș«Ź­źŻ°±ČłŽ”¶·žčș»ŒœŸżÀÁÂĂÄĆÆÇÈÉÊËÌÍÎÏĐŃÒÓÔŐÖŚŰÙÚÛÜĘȚßàáâăäćæçèéêëìíîïđńòóôőöśűùúûüęțÿ"
        },
        "cp28606": "iso885916",
        "cp437": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜ¢£¥₧ƒáíóúñÑªº¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm437": "cp437",
        "csibm437": "cp437",
        "cp737": {
            "type": "_sbcs",
            "chars": "ΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡΣΤΥΦΧΨΩαβγδεζηθικλμνξοπρσςτυφχψ░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀ωάέήϊίόύϋώΆΈΉΊΌΎΏ±≥≤ΪΫ÷≈°∙·√ⁿ²■ "
        },
        "ibm737": "cp737",
        "csibm737": "cp737",
        "cp775": {
            "type": "_sbcs",
            "chars": "ĆüéāäģåćłēŖŗīŹÄÅÉæÆōöĢ¢ŚśÖÜø£Ø×¤ĀĪóŻżź”¦©®¬½¼Ł«»░▒▓│┤ĄČĘĖ╣║╗╝ĮŠ┐└┴┬├─┼ŲŪ╚╔╩╦╠═╬Žąčęėįšųūž┘┌█▄▌▐▀ÓßŌŃõÕµńĶķĻļņĒŅ’­±“¾¶§÷„°∙·¹³²■ "
        },
        "ibm775": "cp775",
        "csibm775": "cp775",
        "cp850": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø×ƒáíóúñÑªº¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ðÐÊËÈıÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµþÞÚÛÙýÝ¯´­±‗¾¶§÷¸°¨·¹³²■ "
        },
        "ibm850": "cp850",
        "csibm850": "cp850",
        "cp852": {
            "type": "_sbcs",
            "chars": "ÇüéâäůćçłëŐőîŹÄĆÉĹĺôöĽľŚśÖÜŤťŁ×čáíóúĄąŽžĘę¬źČş«»░▒▓│┤ÁÂĚŞ╣║╗╝Żż┐└┴┬├─┼Ăă╚╔╩╦╠═╬¤đĐĎËďŇÍÎě┘┌█▄ŢŮ▀ÓßÔŃńňŠšŔÚŕŰýÝţ´­˝˛ˇ˘§÷¸°¨˙űŘř■ "
        },
        "ibm852": "cp852",
        "csibm852": "cp852",
        "cp855": {
            "type": "_sbcs",
            "chars": "ђЂѓЃёЁєЄѕЅіІїЇјЈљЉњЊћЋќЌўЎџЏюЮъЪаАбБцЦдДеЕфФгГ«»░▒▓│┤хХиИ╣║╗╝йЙ┐└┴┬├─┼кК╚╔╩╦╠═╬¤лЛмМнНоОп┘┌█▄Пя▀ЯрРсСтТуУжЖвВьЬ№­ыЫзЗшШэЭщЩчЧ§■ "
        },
        "ibm855": "cp855",
        "csibm855": "cp855",
        "cp856": {
            "type": "_sbcs",
            "chars": "אבגדהוזחטיךכלםמןנסעףפץצקרשת�£�×����������®¬½¼�«»░▒▓│┤���©╣║╗╝¢¥┐└┴┬├─┼��╚╔╩╦╠═╬¤���������┘┌█▄¦�▀������µ�������¯´­±‗¾¶§÷¸°¨·¹³²■ "
        },
        "ibm856": "cp856",
        "csibm856": "cp856",
        "cp857": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîıÄÅÉæÆôöòûùİÖÜø£ØŞşáíóúñÑĞğ¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ºªÊËÈ�ÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµ�×ÚÛÙìÿ¯´­±�¾¶§÷¸°¨·¹³²■ "
        },
        "ibm857": "cp857",
        "csibm857": "cp857",
        "cp858": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø×ƒáíóúñÑªº¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ðÐÊËÈ€ÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµþÞÚÛÙýÝ¯´­±‗¾¶§÷¸°¨·¹³²■ "
        },
        "ibm858": "cp858",
        "csibm858": "cp858",
        "cp860": {
            "type": "_sbcs",
            "chars": "ÇüéâãàÁçêÊèÍÔìÃÂÉÀÈôõòÚùÌÕÜ¢£Ù₧ÓáíóúñÑªº¿Ò¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm860": "cp860",
        "csibm860": "cp860",
        "cp861": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèÐðÞÄÅÉæÆôöþûÝýÖÜø£Ø₧ƒáíóúÁÍÓÚ¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm861": "cp861",
        "csibm861": "cp861",
        "cp862": {
            "type": "_sbcs",
            "chars": "אבגדהוזחטיךכלםמןנסעףפץצקרשת¢£¥₧ƒáíóúñÑªº¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm862": "cp862",
        "csibm862": "cp862",
        "cp863": {
            "type": "_sbcs",
            "chars": "ÇüéâÂà¶çêëèïî‗À§ÉÈÊôËÏûù¤ÔÜ¢£ÙÛƒ¦´óú¨¸³¯Î⌐¬½¼¾«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm863": "cp863",
        "csibm863": "cp863",
        "cp864": {
            "type": "_sbcs",
            "chars": "\u0000\u0001\u0002\u0003\u0004\u0005\u0006\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010\u0011\u0012\u0013\u0014\u0015\u0016\u0017\u0018\u0019\u001a\u001b\u001c\u001d\u001e\u001f !\"#$٪&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~°·∙√▒─│┼┤┬├┴┐┌└┘β∞φ±½¼≈«»ﻷﻸ��ﻻﻼ� ­ﺂ£¤ﺄ��ﺎﺏﺕﺙ،ﺝﺡﺥ٠١٢٣٤٥٦٧٨٩ﻑ؛ﺱﺵﺹ؟¢ﺀﺁﺃﺅﻊﺋﺍﺑﺓﺗﺛﺟﺣﺧﺩﺫﺭﺯﺳﺷﺻﺿﻁﻅﻋﻏ¦¬÷×ﻉـﻓﻗﻛﻟﻣﻧﻫﻭﻯﻳﺽﻌﻎﻍﻡﹽّﻥﻩﻬﻰﻲﻐﻕﻵﻶﻝﻙﻱ■�"
        },
        "ibm864": "cp864",
        "csibm864": "cp864",
        "cp865": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø₧ƒáíóúñÑªº¿⌐¬½¼¡«¤░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm865": "cp865",
        "csibm865": "cp865",
        "cp866": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёЄєЇїЎў°∙·√№¤■ "
        },
        "ibm866": "cp866",
        "csibm866": "cp866",
        "cp869": {
            "type": "_sbcs",
            "chars": "������Ά�·¬¦‘’Έ―ΉΊΪΌ��ΎΫ©Ώ²³ά£έήίϊΐόύΑΒΓΔΕΖΗ½ΘΙ«»░▒▓│┤ΚΛΜΝ╣║╗╝ΞΟ┐└┴┬├─┼ΠΡ╚╔╩╦╠═╬ΣΤΥΦΧΨΩαβγ┘┌█▄δε▀ζηθικλμνξοπρσςτ΄­±υφχ§ψ΅°¨ωϋΰώ■ "
        },
        "ibm869": "cp869",
        "csibm869": "cp869",
        "cp922": {
            "type": "_sbcs",
            "chars": " ¡¢£¤¥¦§¨©ª«¬­®‾°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏŠÑÒÓÔÕÖ×ØÙÚÛÜÝŽßàáâãäåæçèéêëìíîïšñòóôõö÷øùúûüýžÿ"
        },
        "ibm922": "cp922",
        "csibm922": "cp922",
        "cp1046": {
            "type": "_sbcs",
            "chars": "ﺈ×÷ﹱ■│─┐┌└┘ﹹﹻﹽﹿﹷﺊﻰﻳﻲﻎﻏﻐﻶﻸﻺﻼ ¤ﺋﺑﺗﺛﺟﺣ،­ﺧﺳ٠١٢٣٤٥٦٧٨٩ﺷ؛ﺻﺿﻊ؟ﻋءآأؤإئابةتثجحخدذرزسشصضطﻇعغﻌﺂﺄﺎﻓـفقكلمنهوىيًٌٍَُِّْﻗﻛﻟﻵﻷﻹﻻﻣﻧﻬﻩ�"
        },
        "ibm1046": "cp1046",
        "csibm1046": "cp1046",
        "cp1124": {
            "type": "_sbcs",
            "chars": " ЁЂҐЄЅІЇЈЉЊЋЌ­ЎЏАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя№ёђґєѕіїјљњћќ§ўџ"
        },
        "ibm1124": "cp1124",
        "csibm1124": "cp1124",
        "cp1125": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёҐґЄєІіЇї·√№¤■ "
        },
        "ibm1125": "cp1125",
        "csibm1125": "cp1125",
        "cp1129": {
            "type": "_sbcs",
            "chars": " ¡¢£¤¥¦§œ©ª«¬­®¯°±²³Ÿµ¶·Œ¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"
        },
        "ibm1129": "cp1129",
        "csibm1129": "cp1129",
        "cp1133": {
            "type": "_sbcs",
            "chars": " ກຂຄງຈສຊຍດຕຖທນບປຜຝພຟມຢຣລວຫອຮ���ຯະາຳິີຶືຸູຼັົຽ���ເແໂໃໄ່້໊໋໌ໍໆ�ໜໝ₭����������������໐໑໒໓໔໕໖໗໘໙��¢¬¦�"
        },
        "ibm1133": "cp1133",
        "csibm1133": "cp1133",
        "cp1161": {
            "type": "_sbcs",
            "chars": "��������������������������������่กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู้๊๋€฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛¢¬¦ "
        },
        "ibm1161": "cp1161",
        "csibm1161": "cp1161",
        "cp1162": {
            "type": "_sbcs",
            "chars": "€…‘’“”•–— กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"
        },
        "ibm1162": "cp1162",
        "csibm1162": "cp1162",
        "cp1163": {
            "type": "_sbcs",
            "chars": " ¡¢£€¥¦§œ©ª«¬­®¯°±²³Ÿµ¶·Œ¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"
        },
        "ibm1163": "cp1163",
        "csibm1163": "cp1163",
        "maccroatian": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®Š™´¨≠ŽØ∞±≤≥∆µ∂∑∏š∫ªºΩžø¿¡¬√ƒ≈Ć«Č… ÀÃÕŒœĐ—“”‘’÷◊�©⁄¤‹›Æ»–·‚„‰ÂćÁčÈÍÎÏÌÓÔđÒÚÛÙıˆ˜¯πË˚¸Êæˇ"
        },
        "maccyrillic": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ†°¢£§•¶І®©™Ђђ≠Ѓѓ∞±≤≥іµ∂ЈЄєЇїЉљЊњјЅ¬√ƒ≈∆«»… ЋћЌќѕ–—“”‘’÷„ЎўЏџ№Ёёяабвгдежзийклмнопрстуфхцчшщъыьэю¤"
        },
        "macgreek": {
            "type": "_sbcs",
            "chars": "Ä¹²É³ÖÜ΅àâä΄¨çéèêë£™îï•½‰ôö¦­ùûü†ΓΔΘΛΞΠß®©ΣΪ§≠°·Α±≤≥¥ΒΕΖΗΙΚΜΦΫΨΩάΝ¬ΟΡ≈Τ«»… ΥΧΆΈœ–―“”‘’÷ΉΊΌΎέήίόΏύαβψδεφγηιξκλμνοπώρστθωςχυζϊϋΐΰ�"
        },
        "maciceland": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûüÝ°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤ÐðÞþý·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "macroman": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›ﬁﬂ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "macromania": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ĂŞ∞±≤≥¥µ∂∑∏π∫ªºΩăş¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›Ţţ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "macthai": {
            "type": "_sbcs",
            "chars": "«»…“”�•‘’� กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู﻿​–—฿เแโใไๅๆ็่้๊๋์ํ™๏๐๑๒๓๔๕๖๗๘๙®©����"
        },
        "macturkish": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸĞğİıŞş‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙ�ˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "macukraine": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ†°Ґ£§•¶І®©™Ђђ≠Ѓѓ∞±≤≥іµґЈЄєЇїЉљЊњјЅ¬√ƒ≈∆«»… ЋћЌќѕ–—“”‘’÷„ЎўЏџ№Ёёяабвгдежзийклмнопрстуфхцчшщъыьэю¤"
        },
        "koi8r": {
            "type": "_sbcs",
            "chars": "─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ё╓╔╕╖╗╘╙╚╛╜╝╞╟╠╡Ё╢╣╤╥╦╧╨╩╪╫╬©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"
        },
        "koi8u": {
            "type": "_sbcs",
            "chars": "─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ёє╔ії╗╘╙╚╛ґ╝╞╟╠╡ЁЄ╣ІЇ╦╧╨╩╪Ґ╬©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"
        },
        "koi8ru": {
            "type": "_sbcs",
            "chars": "─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ёє╔ії╗╘╙╚╛ґў╞╟╠╡ЁЄ╣ІЇ╦╧╨╩╪ҐЎ©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"
        },
        "koi8t": {
            "type": "_sbcs",
            "chars": "қғ‚Ғ„…†‡�‰ҳ‹ҲҷҶ�Қ‘’“”•–—�™�›�����ӯӮё¤ӣ¦§���«¬­®�°±²Ё�Ӣ¶·�№�»���©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"
        },
        "armscii8": {
            "type": "_sbcs",
            "chars": " �և։)(»«—.՝,-֊…՜՛՞ԱաԲբԳգԴդԵեԶզԷէԸըԹթԺժԻիԼլԽխԾծԿկՀհՁձՂղՃճՄմՅյՆնՇշՈոՉչՊպՋջՌռՍսՎվՏտՐրՑցՒւՓփՔքՕօՖֆ՚�"
        },
        "rk1048": {
            "type": "_sbcs",
            "chars": "ЂЃ‚ѓ„…†‡€‰Љ‹ЊҚҺЏђ‘’“”•–—�™љ›њқһџ ҰұӘ¤Ө¦§Ё©Ғ«¬­®Ү°±Ііөµ¶·ё№ғ»әҢңүАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"
        },
        "tcvn": {
            "type": "_sbcs",
            "chars": "\u0000ÚỤ\u0003ỪỬỮ\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010ỨỰỲỶỸÝỴ\u0018\u0019\u001a\u001b\u001c\u001d\u001e\u001f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~ÀẢÃÁẠẶẬÈẺẼÉẸỆÌỈĨÍỊÒỎÕÓỌỘỜỞỠỚỢÙỦŨ ĂÂÊÔƠƯĐăâêôơưđẶ̀̀̉̃́àảãáạẲằẳẵắẴẮẦẨẪẤỀặầẩẫấậèỂẻẽéẹềểễếệìỉỄẾỒĩíịòỔỏõóọồổỗốộờởỡớợùỖủũúụừửữứựỳỷỹýỵỐ"
        },
        "georgianacademy": {
            "type": "_sbcs",
            "chars": "‚ƒ„…†‡ˆ‰Š‹Œ‘’“”•–—˜™š›œŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿აბგდევზთიკლმნოპჟრსტუფქღყშჩცძწჭხჯჰჱჲჳჴჵჶçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "georgianps": {
            "type": "_sbcs",
            "chars": "‚ƒ„…†‡ˆ‰Š‹Œ‘’“”•–—˜™š›œŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿აბგდევზჱთიკლმნჲოპჟრსტჳუფქღყშჩცძწჭხჴჯჰჵæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "pt154": {
            "type": "_sbcs",
            "chars": "ҖҒӮғ„…ҶҮҲүҠӢҢҚҺҸҗ‘’“”•–—ҳҷҡӣңқһҹ ЎўЈӨҘҰ§Ё©Ә«¬ӯ®Ҝ°ұІіҙө¶·ё№ә»јҪҫҝАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"
        },
        "viscii": {
            "type": "_sbcs",
            "chars": "\u0000\u0001Ẳ\u0003\u0004ẴẪ\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010\u0011\u0012\u0013Ỷ\u0015\u0016\u0017\u0018Ỹ\u001a\u001b\u001c\u001dỴ\u001f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~ẠẮẰẶẤẦẨẬẼẸẾỀỂỄỆỐỒỔỖỘỢỚỜỞỊỎỌỈỦŨỤỲÕắằặấầẩậẽẹếềểễệốồổỗỠƠộờởịỰỨỪỬơớƯÀÁÂÃẢĂẳẵÈÉÊẺÌÍĨỳĐứÒÓÔạỷừửÙÚỹỵÝỡưàáâãảăữẫèéêẻìíĩỉđựòóôõỏọụùúũủýợỮ"
        },
        "iso646cn": {
            "type": "_sbcs",
            "chars": "\u0000\u0001\u0002\u0003\u0004\u0005\u0006\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010\u0011\u0012\u0013\u0014\u0015\u0016\u0017\u0018\u0019\u001a\u001b\u001c\u001d\u001e\u001f !\"#¥%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}‾��������������������������������������������������������������������������������������������������������������������������������"
        },
        "iso646jp": {
            "type": "_sbcs",
            "chars": "\u0000\u0001\u0002\u0003\u0004\u0005\u0006\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010\u0011\u0012\u0013\u0014\u0015\u0016\u0017\u0018\u0019\u001a\u001b\u001c\u001d\u001e\u001f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[¥]^_`abcdefghijklmnopqrstuvwxyz{|}‾��������������������������������������������������������������������������������������������������������������������������������"
        },
        "hproman8": {
            "type": "_sbcs",
            "chars": " ÀÂÈÊËÎÏ´ˋˆ¨˜ÙÛ₤¯Ýý°ÇçÑñ¡¿¤£¥§ƒ¢âêôûáéóúàèòùäëöüÅîØÆåíøæÄìÖÜÉïßÔÁÃãÐðÍÌÓÒÕõŠšÚŸÿÞþ·µ¶¾—¼½ªº«■»±�"
        },
        "macintosh": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›ﬁﬂ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "ascii": {
            "type": "_sbcs",
            "chars": "��������������������������������������������������������������������������������������������������������������������������������"
        },
        "tis620": {
            "type": "_sbcs",
            "chars": "���������������������������������กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"
        }
    };
},
/* iconv-lite/encodings/dbcs-codec.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // Multibyte codec. In this scheme, a character is represented by 1 or more bytes.
    // Our codec supports UTF-16 surrogates, extensions for GB18030 and unicode sequences.
    // To save memory and loading time, we read table files only when requested.
    exports._dbcs = DBCSCodec;
    var UNASSIGNED = -1, GB18030_CODE = -2, SEQ_START = -10, NODE_START = -1000, UNASSIGNED_NODE = new Array(0x100), DEF_CHAR = -1;
    for (var i = 0; i < 0x100; i++)
        UNASSIGNED_NODE[i] = UNASSIGNED;
    // Class DBCSCodec reads and initializes mapping tables.
    function DBCSCodec(codecOptions, iconv) {
        this.encodingName = codecOptions.encodingName;
        if (!codecOptions)
            throw new Error("DBCS codec is called without the data.");
        if (!codecOptions.table)
            throw new Error("Encoding '" + this.encodingName + "' has no data.");
        // Load tables.
        var mappingTable = codecOptions.table();
        // Decode tables: MBCS -> Unicode.
        // decodeTables is a trie, encoded as an array of arrays of integers. Internal arrays are trie nodes and all have len = 256.
        // Trie root is decodeTables[0].
        // Values: >=  0 -> unicode character code. can be > 0xFFFF
        //         == UNASSIGNED -> unknown/unassigned sequence.
        //         == GB18030_CODE -> this is the end of a GB18030 4-byte sequence.
        //         <= NODE_START -> index of the next node in our trie to process next byte.
        //         <= SEQ_START  -> index of the start of a character code sequence, in decodeTableSeq.
        this.decodeTables = [];
        this.decodeTables[0] = UNASSIGNED_NODE.slice(0); // Create root node.
        // Sometimes a MBCS char corresponds to a sequence of unicode chars. We store them as arrays of integers here. 
        this.decodeTableSeq = [];
        // Actual mapping tables consist of chunks. Use them to fill up decode tables.
        for (var i = 0; i < mappingTable.length; i++)
            this._addDecodeChunk(mappingTable[i]);
        this.defaultCharUnicode = iconv.defaultCharUnicode;
        // Encode tables: Unicode -> DBCS.
        // `encodeTable` is array mapping from unicode char to encoded char. All its values are integers for performance.
        // Because it can be sparse, it is represented as array of buckets by 256 chars each. Bucket can be null.
        // Values: >=  0 -> it is a normal char. Write the value (if <=256 then 1 byte, if <=65536 then 2 bytes, etc.).
        //         == UNASSIGNED -> no conversion found. Output a default char.
        //         <= SEQ_START  -> it's an index in encodeTableSeq, see below. The character starts a sequence.
        this.encodeTable = [];
        // `encodeTableSeq` is used when a sequence of unicode characters is encoded as a single code. We use a tree of
        // objects where keys correspond to characters in sequence and leafs are the encoded dbcs values. A special DEF_CHAR key
        // means end of sequence (needed when one sequence is a strict subsequence of another).
        // Objects are kept separately from encodeTable to increase performance.
        this.encodeTableSeq = [];
        // Some chars can be decoded, but need not be encoded.
        var skipEncodeChars = {};
        if (codecOptions.encodeSkipVals)
            for (var i = 0; i < codecOptions.encodeSkipVals.length; i++) {
                var val = codecOptions.encodeSkipVals[i];
                if (typeof val === 'number')
                    skipEncodeChars[val] = true;
                else
                    for (var j = val.from; j <= val.to; j++)
                        skipEncodeChars[j] = true;
            }
        // Use decode trie to recursively fill out encode tables.
        this._fillEncodeTable(0, 0, skipEncodeChars);
        // Add more encoding pairs when needed.
        if (codecOptions.encodeAdd) {
            for (var uChar in codecOptions.encodeAdd)
                if (Object.prototype.hasOwnProperty.call(codecOptions.encodeAdd, uChar))
                    this._setEncodeChar(uChar.charCodeAt(0), codecOptions.encodeAdd[uChar]);
        }
        this.defCharSB = this.encodeTable[0][iconv.defaultCharSingleByte.charCodeAt(0)];
        if (this.defCharSB === UNASSIGNED)
            this.defCharSB = this.encodeTable[0]['?'];
        if (this.defCharSB === UNASSIGNED)
            this.defCharSB = "?".charCodeAt(0);
        // Load & create GB18030 tables when needed.
        if (typeof codecOptions.gb18030 === 'function') {
            this.gb18030 = codecOptions.gb18030(); // Load GB18030 ranges.
            // Add GB18030 decode tables.
            var thirdByteNodeIdx = this.decodeTables.length;
            var thirdByteNode = this.decodeTables[thirdByteNodeIdx] = UNASSIGNED_NODE.slice(0);
            var fourthByteNodeIdx = this.decodeTables.length;
            var fourthByteNode = this.decodeTables[fourthByteNodeIdx] = UNASSIGNED_NODE.slice(0);
            for (var i = 0x81; i <= 0xFE; i++) {
                var secondByteNodeIdx = NODE_START - this.decodeTables[0][i];
                var secondByteNode = this.decodeTables[secondByteNodeIdx];
                for (var j = 0x30; j <= 0x39; j++)
                    secondByteNode[j] = NODE_START - thirdByteNodeIdx;
            }
            for (var i = 0x81; i <= 0xFE; i++)
                thirdByteNode[i] = NODE_START - fourthByteNodeIdx;
            for (var i = 0x30; i <= 0x39; i++)
                fourthByteNode[i] = GB18030_CODE;
        }
    }
    DBCSCodec.prototype.encoder = DBCSEncoder;
    DBCSCodec.prototype.decoder = DBCSDecoder;
    // Decoder helpers
    DBCSCodec.prototype._getDecodeTrieNode = function (addr) {
        var bytes = [];
        for (; addr > 0; addr >>= 8)
            bytes.push(addr & 0xFF);
        if (bytes.length == 0)
            bytes.push(0);
        var node = this.decodeTables[0];
        for (var i = bytes.length - 1; i > 0; i--) { // Traverse nodes deeper into the trie.
            var val = node[bytes[i]];
            if (val == UNASSIGNED) { // Create new node.
                node[bytes[i]] = NODE_START - this.decodeTables.length;
                this.decodeTables.push(node = UNASSIGNED_NODE.slice(0));
            }
            else if (val <= NODE_START) { // Existing node.
                node = this.decodeTables[NODE_START - val];
            }
            else
                throw new Error("Overwrite byte in " + this.encodingName + ", addr: " + addr.toString(16));
        }
        return node;
    };
    DBCSCodec.prototype._addDecodeChunk = function (chunk) {
        // First element of chunk is the hex mbcs code where we start.
        var curAddr = parseInt(chunk[0], 16);
        // Choose the decoding node where we'll write our chars.
        var writeTable = this._getDecodeTrieNode(curAddr);
        curAddr = curAddr & 0xFF;
        // Write all other elements of the chunk to the table.
        for (var k = 1; k < chunk.length; k++) {
            var part = chunk[k];
            if (typeof part === "string") { // String, write as-is.
                for (var l = 0; l < part.length;) {
                    var code = part.charCodeAt(l++);
                    if (0xD800 <= code && code < 0xDC00) { // Decode surrogate
                        var codeTrail = part.charCodeAt(l++);
                        if (0xDC00 <= codeTrail && codeTrail < 0xE000)
                            writeTable[curAddr++] = 0x10000 + (code - 0xD800) * 0x400 + (codeTrail - 0xDC00);
                        else
                            throw new Error("Incorrect surrogate pair in " + this.encodingName + " at chunk " + chunk[0]);
                    }
                    else if (0x0FF0 < code && code <= 0x0FFF) { // Character sequence (our own encoding used)
                        var len = 0xFFF - code + 2;
                        var seq = [];
                        for (var m = 0; m < len; m++)
                            seq.push(part.charCodeAt(l++)); // Simple variation: don't support surrogates or subsequences in seq.
                        writeTable[curAddr++] = SEQ_START - this.decodeTableSeq.length;
                        this.decodeTableSeq.push(seq);
                    }
                    else
                        writeTable[curAddr++] = code; // Basic char
                }
            }
            else if (typeof part === "number") { // Integer, meaning increasing sequence starting with prev character.
                var charCode = writeTable[curAddr - 1] + 1;
                for (var l = 0; l < part; l++)
                    writeTable[curAddr++] = charCode++;
            }
            else
                throw new Error("Incorrect type '" + typeof part + "' given in " + this.encodingName + " at chunk " + chunk[0]);
        }
        if (curAddr > 0xFF)
            throw new Error("Incorrect chunk in " + this.encodingName + " at addr " + chunk[0] + ": too long" + curAddr);
    };
    // Encoder helpers
    DBCSCodec.prototype._getEncodeBucket = function (uCode) {
        var high = uCode >> 8; // This could be > 0xFF because of astral characters.
        if (this.encodeTable[high] === undefined)
            this.encodeTable[high] = UNASSIGNED_NODE.slice(0); // Create bucket on demand.
        return this.encodeTable[high];
    };
    DBCSCodec.prototype._setEncodeChar = function (uCode, dbcsCode) {
        var bucket = this._getEncodeBucket(uCode);
        var low = uCode & 0xFF;
        if (bucket[low] <= SEQ_START)
            this.encodeTableSeq[SEQ_START - bucket[low]][DEF_CHAR] = dbcsCode; // There's already a sequence, set a single-char subsequence of it.
        else if (bucket[low] == UNASSIGNED)
            bucket[low] = dbcsCode;
    };
    DBCSCodec.prototype._setEncodeSequence = function (seq, dbcsCode) {
        // Get the root of character tree according to first character of the sequence.
        var uCode = seq[0];
        var bucket = this._getEncodeBucket(uCode);
        var low = uCode & 0xFF;
        var node;
        if (bucket[low] <= SEQ_START) {
            // There's already a sequence with  - use it.
            node = this.encodeTableSeq[SEQ_START - bucket[low]];
        }
        else {
            // There was no sequence object - allocate a new one.
            node = {};
            if (bucket[low] !== UNASSIGNED)
                node[DEF_CHAR] = bucket[low]; // If a char was set before - make it a single-char subsequence.
            bucket[low] = SEQ_START - this.encodeTableSeq.length;
            this.encodeTableSeq.push(node);
        }
        // Traverse the character tree, allocating new nodes as needed.
        for (var j = 1; j < seq.length - 1; j++) {
            var oldVal = node[uCode];
            if (typeof oldVal === 'object')
                node = oldVal;
            else {
                node = node[uCode] = {};
                if (oldVal !== undefined)
                    node[DEF_CHAR] = oldVal;
            }
        }
        // Set the leaf to given dbcsCode.
        uCode = seq[seq.length - 1];
        node[uCode] = dbcsCode;
    };
    DBCSCodec.prototype._fillEncodeTable = function (nodeIdx, prefix, skipEncodeChars) {
        var node = this.decodeTables[nodeIdx];
        for (var i = 0; i < 0x100; i++) {
            var uCode = node[i];
            var mbCode = prefix + i;
            if (skipEncodeChars[mbCode])
                continue;
            if (uCode >= 0)
                this._setEncodeChar(uCode, mbCode);
            else if (uCode <= NODE_START)
                this._fillEncodeTable(NODE_START - uCode, mbCode << 8, skipEncodeChars);
            else if (uCode <= SEQ_START)
                this._setEncodeSequence(this.decodeTableSeq[SEQ_START - uCode], mbCode);
        }
    };
    // == Encoder ==================================================================
    function DBCSEncoder(options, codec) {
        // Encoder state
        this.leadSurrogate = -1;
        this.seqObj = undefined;
        // Static data
        this.encodeTable = codec.encodeTable;
        this.encodeTableSeq = codec.encodeTableSeq;
        this.defaultCharSingleByte = codec.defCharSB;
        this.gb18030 = codec.gb18030;
    }
    DBCSEncoder.prototype.write = function (str) {
        var newBuf = Buffer.alloc(str.length * (this.gb18030 ? 4 : 3)), leadSurrogate = this.leadSurrogate, seqObj = this.seqObj, nextChar = -1, i = 0, j = 0;
        while (true) {
            // 0. Get next character.
            if (nextChar === -1) {
                if (i == str.length)
                    break;
                var uCode = str.charCodeAt(i++);
            }
            else {
                var uCode = nextChar;
                nextChar = -1;
            }
            // 1. Handle surrogates.
            if (0xD800 <= uCode && uCode < 0xE000) { // Char is one of surrogates.
                if (uCode < 0xDC00) { // We've got lead surrogate.
                    if (leadSurrogate === -1) {
                        leadSurrogate = uCode;
                        continue;
                    }
                    else {
                        leadSurrogate = uCode;
                        // Double lead surrogate found.
                        uCode = UNASSIGNED;
                    }
                }
                else { // We've got trail surrogate.
                    if (leadSurrogate !== -1) {
                        uCode = 0x10000 + (leadSurrogate - 0xD800) * 0x400 + (uCode - 0xDC00);
                        leadSurrogate = -1;
                    }
                    else {
                        // Incomplete surrogate pair - only trail surrogate found.
                        uCode = UNASSIGNED;
                    }
                }
            }
            else if (leadSurrogate !== -1) {
                // Incomplete surrogate pair - only lead surrogate found.
                nextChar = uCode;
                uCode = UNASSIGNED; // Write an error, then current char.
                leadSurrogate = -1;
            }
            // 2. Convert uCode character.
            var dbcsCode = UNASSIGNED;
            if (seqObj !== undefined && uCode != UNASSIGNED) { // We are in the middle of the sequence
                var resCode = seqObj[uCode];
                if (typeof resCode === 'object') { // Sequence continues.
                    seqObj = resCode;
                    continue;
                }
                else if (typeof resCode == 'number') { // Sequence finished. Write it.
                    dbcsCode = resCode;
                }
                else if (resCode == undefined) { // Current character is not part of the sequence.
                    // Try default character for this sequence
                    resCode = seqObj[DEF_CHAR];
                    if (resCode !== undefined) {
                        dbcsCode = resCode; // Found. Write it.
                        nextChar = uCode; // Current character will be written too in the next iteration.
                    }
                    else {
                        // TODO: What if we have no default? (resCode == undefined)
                        // Then, we should write first char of the sequence as-is and try the rest recursively.
                        // Didn't do it for now because no encoding has this situation yet.
                        // Currently, just skip the sequence and write current char.
                    }
                }
                seqObj = undefined;
            }
            else if (uCode >= 0) { // Regular character
                var subtable = this.encodeTable[uCode >> 8];
                if (subtable !== undefined)
                    dbcsCode = subtable[uCode & 0xFF];
                if (dbcsCode <= SEQ_START) { // Sequence start
                    seqObj = this.encodeTableSeq[SEQ_START - dbcsCode];
                    continue;
                }
                if (dbcsCode == UNASSIGNED && this.gb18030) {
                    // Use GB18030 algorithm to find character(s) to write.
                    var idx = findIdx(this.gb18030.uChars, uCode);
                    if (idx != -1) {
                        var dbcsCode = this.gb18030.gbChars[idx] + (uCode - this.gb18030.uChars[idx]);
                        newBuf[j++] = 0x81 + Math.floor(dbcsCode / 12600);
                        dbcsCode = dbcsCode % 12600;
                        newBuf[j++] = 0x30 + Math.floor(dbcsCode / 1260);
                        dbcsCode = dbcsCode % 1260;
                        newBuf[j++] = 0x81 + Math.floor(dbcsCode / 10);
                        dbcsCode = dbcsCode % 10;
                        newBuf[j++] = 0x30 + dbcsCode;
                        continue;
                    }
                }
            }
            // 3. Write dbcsCode character.
            if (dbcsCode === UNASSIGNED)
                dbcsCode = this.defaultCharSingleByte;
            if (dbcsCode < 0x100) {
                newBuf[j++] = dbcsCode;
            }
            else if (dbcsCode < 0x10000) {
                newBuf[j++] = dbcsCode >> 8; // high byte
                newBuf[j++] = dbcsCode & 0xFF; // low byte
            }
            else {
                newBuf[j++] = dbcsCode >> 16;
                newBuf[j++] = (dbcsCode >> 8) & 0xFF;
                newBuf[j++] = dbcsCode & 0xFF;
            }
        }
        this.seqObj = seqObj;
        this.leadSurrogate = leadSurrogate;
        return newBuf.slice(0, j);
    };
    DBCSEncoder.prototype.end = function () {
        if (this.leadSurrogate === -1 && this.seqObj === undefined)
            return; // All clean. Most often case.
        var newBuf = Buffer.alloc(10), j = 0;
        if (this.seqObj) { // We're in the sequence.
            var dbcsCode = this.seqObj[DEF_CHAR];
            if (dbcsCode !== undefined) { // Write beginning of the sequence.
                if (dbcsCode < 0x100) {
                    newBuf[j++] = dbcsCode;
                }
                else {
                    newBuf[j++] = dbcsCode >> 8; // high byte
                    newBuf[j++] = dbcsCode & 0xFF; // low byte
                }
            }
            else {
                // See todo above.
            }
            this.seqObj = undefined;
        }
        if (this.leadSurrogate !== -1) {
            // Incomplete surrogate pair - only lead surrogate found.
            newBuf[j++] = this.defaultCharSingleByte;
            this.leadSurrogate = -1;
        }
        return newBuf.slice(0, j);
    };
    // Export for testing
    DBCSEncoder.prototype.findIdx = findIdx;
    // == Decoder ==================================================================
    function DBCSDecoder(options, codec) {
        // Decoder state
        this.nodeIdx = 0;
        this.prevBuf = Buffer.alloc(0);
        // Static data
        this.decodeTables = codec.decodeTables;
        this.decodeTableSeq = codec.decodeTableSeq;
        this.defaultCharUnicode = codec.defaultCharUnicode;
        this.gb18030 = codec.gb18030;
    }
    DBCSDecoder.prototype.write = function (buf) {
        var newBuf = Buffer.alloc(buf.length * 2), nodeIdx = this.nodeIdx, prevBuf = this.prevBuf, prevBufOffset = this.prevBuf.length, seqStart = -this.prevBuf.length, // idx of the start of current parsed sequence.
        uCode;
        if (prevBufOffset > 0) // Make prev buf overlap a little to make it easier to slice later.
            prevBuf = Buffer.concat([prevBuf, buf.slice(0, 10)]);
        for (var i = 0, j = 0; i < buf.length; i++) {
            var curByte = (i >= 0) ? buf[i] : prevBuf[i + prevBufOffset];
            // Lookup in current trie node.
            var uCode = this.decodeTables[nodeIdx][curByte];
            if (uCode >= 0) {
                // Normal character, just use it.
            }
            else if (uCode === UNASSIGNED) { // Unknown char.
                // TODO: Callback with seq.
                //var curSeq = (seqStart >= 0) ? buf.slice(seqStart, i+1) : prevBuf.slice(seqStart + prevBufOffset, i+1 + prevBufOffset);
                i = seqStart; // Try to parse again, after skipping first byte of the sequence ('i' will be incremented by 'for' cycle).
                uCode = this.defaultCharUnicode.charCodeAt(0);
            }
            else if (uCode === GB18030_CODE) {
                var curSeq = (seqStart >= 0) ? buf.slice(seqStart, i + 1) : prevBuf.slice(seqStart + prevBufOffset, i + 1 + prevBufOffset);
                var ptr = (curSeq[0] - 0x81) * 12600 + (curSeq[1] - 0x30) * 1260 + (curSeq[2] - 0x81) * 10 + (curSeq[3] - 0x30);
                var idx = findIdx(this.gb18030.gbChars, ptr);
                uCode = this.gb18030.uChars[idx] + ptr - this.gb18030.gbChars[idx];
            }
            else if (uCode <= NODE_START) { // Go to next trie node.
                nodeIdx = NODE_START - uCode;
                continue;
            }
            else if (uCode <= SEQ_START) { // Output a sequence of chars.
                var seq = this.decodeTableSeq[SEQ_START - uCode];
                for (var k = 0; k < seq.length - 1; k++) {
                    uCode = seq[k];
                    newBuf[j++] = uCode & 0xFF;
                    newBuf[j++] = uCode >> 8;
                }
                uCode = seq[seq.length - 1];
            }
            else
                throw new Error("iconv-lite internal error: invalid decoding table value " + uCode + " at " + nodeIdx + "/" + curByte);
            // Write the character to buffer, handling higher planes using surrogate pair.
            if (uCode > 0xFFFF) {
                uCode -= 0x10000;
                var uCodeLead = 0xD800 + Math.floor(uCode / 0x400);
                newBuf[j++] = uCodeLead & 0xFF;
                newBuf[j++] = uCodeLead >> 8;
                uCode = 0xDC00 + uCode % 0x400;
            }
            newBuf[j++] = uCode & 0xFF;
            newBuf[j++] = uCode >> 8;
            // Reset trie node.
            nodeIdx = 0;
            seqStart = i + 1;
        }
        this.nodeIdx = nodeIdx;
        this.prevBuf = (seqStart >= 0) ? buf.slice(seqStart) : prevBuf.slice(seqStart + prevBufOffset);
        return newBuf.slice(0, j).toString('ucs2');
    };
    DBCSDecoder.prototype.end = function () {
        var ret = '';
        // Try to parse all remaining chars.
        while (this.prevBuf.length > 0) {
            // Skip 1 character in the buffer.
            ret += this.defaultCharUnicode;
            var buf = this.prevBuf.slice(1);
            // Parse remaining as usual.
            this.prevBuf = Buffer.alloc(0);
            this.nodeIdx = 0;
            if (buf.length > 0)
                ret += this.write(buf);
        }
        this.nodeIdx = 0;
        return ret;
    };
    // Binary search for GB18030. Returns largest i such that table[i] <= val.
    function findIdx(table, val) {
        if (table[0] > val)
            return -1;
        var l = 0, r = table.length;
        while (l < r - 1) { // always table[l] <= val < table[r]
            var mid = l + Math.floor((r - l + 1) / 2);
            if (table[mid] <= val)
                l = mid;
            else
                r = mid;
        }
        return l;
    }
},
/* iconv-lite/encodings/dbcs-data.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Description of supported double byte encodings and aliases.
    // Tables are not require()-d until they are needed to speed up library load.
    // require()-s are direct to support Browserify.
    module.exports = {
        // == Japanese/ShiftJIS ====================================================
        // All japanese encodings are based on JIS X set of standards:
        // JIS X 0201 - Single-byte encoding of ASCII + ¥ + Kana chars at 0xA1-0xDF.
        // JIS X 0208 - Main set of 6879 characters, placed in 94x94 plane, to be encoded by 2 bytes. 
        //              Has several variations in 1978, 1983, 1990 and 1997.
        // JIS X 0212 - Supplementary plane of 6067 chars in 94x94 plane. 1990. Effectively dead.
        // JIS X 0213 - Extension and modern replacement of 0208 and 0212. Total chars: 11233.
        //              2 planes, first is superset of 0208, second - revised 0212.
        //              Introduced in 2000, revised 2004. Some characters are in Unicode Plane 2 (0x2xxxx)
        // Byte encodings are:
        //  * Shift_JIS: Compatible with 0201, uses not defined chars in top half as lead bytes for double-byte
        //               encoding of 0208. Lead byte ranges: 0x81-0x9F, 0xE0-0xEF; Trail byte ranges: 0x40-0x7E, 0x80-0x9E, 0x9F-0xFC.
        //               Windows CP932 is a superset of Shift_JIS. Some companies added more chars, notably KDDI.
        //  * EUC-JP:    Up to 3 bytes per character. Used mostly on *nixes.
        //               0x00-0x7F       - lower part of 0201
        //               0x8E, 0xA1-0xDF - upper part of 0201
        //               (0xA1-0xFE)x2   - 0208 plane (94x94).
        //               0x8F, (0xA1-0xFE)x2 - 0212 plane (94x94).
        //  * JIS X 208: 7-bit, direct encoding of 0208. Byte ranges: 0x21-0x7E (94 values). Uncommon.
        //               Used as-is in ISO2022 family.
        //  * ISO2022-JP: Stateful encoding, with escape sequences to switch between ASCII, 
        //                0201-1976 Roman, 0208-1978, 0208-1983.
        //  * ISO2022-JP-1: Adds esc seq for 0212-1990.
        //  * ISO2022-JP-2: Adds esc seq for GB2313-1980, KSX1001-1992, ISO8859-1, ISO8859-7.
        //  * ISO2022-JP-3: Adds esc seq for 0201-1976 Kana set, 0213-2000 Planes 1, 2.
        //  * ISO2022-JP-2004: Adds 0213-2004 Plane 1.
        //
        // After JIS X 0213 appeared, Shift_JIS-2004, EUC-JISX0213 and ISO2022-JP-2004 followed, with just changing the planes.
        //
        // Overall, it seems that it's a mess :( http://www8.plala.or.jp/tkubota1/unicode-symbols-map2.html
        'shiftjis': {
            type: '_dbcs',
            table: function () { return require(96) /* ./tables/shiftjis.json */; },
            encodeAdd: { '\u00a5': 0x5C, '\u203E': 0x7E },
            encodeSkipVals: [{ from: 0xED40, to: 0xF940 }],
        },
        'csshiftjis': 'shiftjis',
        'mskanji': 'shiftjis',
        'sjis': 'shiftjis',
        'windows31j': 'shiftjis',
        'ms31j': 'shiftjis',
        'xsjis': 'shiftjis',
        'windows932': 'shiftjis',
        'ms932': 'shiftjis',
        '932': 'shiftjis',
        'cp932': 'shiftjis',
        'eucjp': {
            type: '_dbcs',
            table: function () { return require(97) /* ./tables/eucjp.json */; },
            encodeAdd: { '\u00a5': 0x5C, '\u203E': 0x7E },
        },
        // TODO: KDDI extension to Shift_JIS
        // TODO: IBM CCSID 942 = CP932, but F0-F9 custom chars and other char changes.
        // TODO: IBM CCSID 943 = Shift_JIS = CP932 with original Shift_JIS lower 128 chars.
        // == Chinese/GBK ==========================================================
        // http://en.wikipedia.org/wiki/GBK
        // We mostly implement W3C recommendation: https://www.w3.org/TR/encoding/#gbk-encoder
        // Oldest GB2312 (1981, ~7600 chars) is a subset of CP936
        'gb2312': 'cp936',
        'gb231280': 'cp936',
        'gb23121980': 'cp936',
        'csgb2312': 'cp936',
        'csiso58gb231280': 'cp936',
        'euccn': 'cp936',
        // Microsoft's CP936 is a subset and approximation of GBK.
        'windows936': 'cp936',
        'ms936': 'cp936',
        '936': 'cp936',
        'cp936': {
            type: '_dbcs',
            table: function () { return require(98) /* ./tables/cp936.json */; },
        },
        // GBK (~22000 chars) is an extension of CP936 that added user-mapped chars and some other.
        'gbk': {
            type: '_dbcs',
            table: function () { return require(98) /* ./tables/cp936.json */.concat(require(99) /* ./tables/gbk-added.json */); },
        },
        'xgbk': 'gbk',
        'isoir58': 'gbk',
        // GB18030 is an algorithmic extension of GBK.
        // Main source: https://www.w3.org/TR/encoding/#gbk-encoder
        // http://icu-project.org/docs/papers/gb18030.html
        // http://source.icu-project.org/repos/icu/data/trunk/charset/data/xml/gb-18030-2000.xml
        // http://www.khngai.com/chinese/charmap/tblgbk.php?page=0
        'gb18030': {
            type: '_dbcs',
            table: function () { return require(98) /* ./tables/cp936.json */.concat(require(99) /* ./tables/gbk-added.json */); },
            gb18030: function () { return require(100) /* ./tables/gb18030-ranges.json */; },
            encodeSkipVals: [0x80],
            encodeAdd: { '€': 0xA2E3 },
        },
        'chinese': 'gb18030',
        // == Korean ===============================================================
        // EUC-KR, KS_C_5601 and KS X 1001 are exactly the same.
        'windows949': 'cp949',
        'ms949': 'cp949',
        '949': 'cp949',
        'cp949': {
            type: '_dbcs',
            table: function () { return require(101) /* ./tables/cp949.json */; },
        },
        'cseuckr': 'cp949',
        'csksc56011987': 'cp949',
        'euckr': 'cp949',
        'isoir149': 'cp949',
        'korean': 'cp949',
        'ksc56011987': 'cp949',
        'ksc56011989': 'cp949',
        'ksc5601': 'cp949',
        // == Big5/Taiwan/Hong Kong ================================================
        // There are lots of tables for Big5 and cp950. Please see the following links for history:
        // http://moztw.org/docs/big5/  http://www.haible.de/bruno/charsets/conversion-tables/Big5.html
        // Variations, in roughly number of defined chars:
        //  * Windows CP 950: Microsoft variant of Big5. Canonical: http://www.unicode.org/Public/MAPPINGS/VENDORS/MICSFT/WINDOWS/CP950.TXT
        //  * Windows CP 951: Microsoft variant of Big5-HKSCS-2001. Seems to be never public. http://me.abelcheung.org/articles/research/what-is-cp951/
        //  * Big5-2003 (Taiwan standard) almost superset of cp950.
        //  * Unicode-at-on (UAO) / Mozilla 1.8. Falling out of use on the Web. Not supported by other browsers.
        //  * Big5-HKSCS (-2001, -2004, -2008). Hong Kong standard. 
        //    many unicode code points moved from PUA to Supplementary plane (U+2XXXX) over the years.
        //    Plus, it has 4 combining sequences.
        //    Seems that Mozilla refused to support it for 10 yrs. https://bugzilla.mozilla.org/show_bug.cgi?id=162431 https://bugzilla.mozilla.org/show_bug.cgi?id=310299
        //    because big5-hkscs is the only encoding to include astral characters in non-algorithmic way.
        //    Implementations are not consistent within browsers; sometimes labeled as just big5.
        //    MS Internet Explorer switches from big5 to big5-hkscs when a patch applied.
        //    Great discussion & recap of what's going on https://bugzilla.mozilla.org/show_bug.cgi?id=912470#c31
        //    In the encoder, it might make sense to support encoding old PUA mappings to Big5 bytes seq-s.
        //    Official spec: http://www.ogcio.gov.hk/en/business/tech_promotion/ccli/terms/doc/2003cmp_2008.txt
        //                   http://www.ogcio.gov.hk/tc/business/tech_promotion/ccli/terms/doc/hkscs-2008-big5-iso.txt
        // 
        // Current understanding of how to deal with Big5(-HKSCS) is in the Encoding Standard, http://encoding.spec.whatwg.org/#big5-encoder
        // Unicode mapping (http://www.unicode.org/Public/MAPPINGS/OBSOLETE/EASTASIA/OTHER/BIG5.TXT) is said to be wrong.
        'windows950': 'cp950',
        'ms950': 'cp950',
        '950': 'cp950',
        'cp950': {
            type: '_dbcs',
            table: function () { return require(102) /* ./tables/cp950.json */; },
        },
        // Big5 has many variations and is an extension of cp950. We use Encoding Standard's as a consensus.
        'big5': 'big5hkscs',
        'big5hkscs': {
            type: '_dbcs',
            table: function () { return require(102) /* ./tables/cp950.json */.concat(require(103) /* ./tables/big5-added.json */); },
            encodeSkipVals: [0xa2cc],
        },
        'cnbig5': 'big5hkscs',
        'csbig5': 'big5hkscs',
        'xxbig5': 'big5hkscs',
    };
},
/* iconv-lite/encodings/tables/shiftjis.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 128],
        ["a1", "｡", 62],
        ["8140", "　、。，．・：；？！゛゜´｀¨＾￣＿ヽヾゝゞ〃仝々〆〇ー―‐／＼～∥｜…‥‘’“”（）〔〕［］｛｝〈", 9, "＋－±×"],
        ["8180", "÷＝≠＜＞≦≧∞∴♂♀°′″℃￥＄￠￡％＃＆＊＠§☆★○●◎◇◆□■△▲▽▼※〒→←↑↓〓"],
        ["81b8", "∈∋⊆⊇⊂⊃∪∩"],
        ["81c8", "∧∨￢⇒⇔∀∃"],
        ["81da", "∠⊥⌒∂∇≡≒≪≫√∽∝∵∫∬"],
        ["81f0", "Å‰♯♭♪†‡¶"],
        ["81fc", "◯"],
        ["824f", "０", 9],
        ["8260", "Ａ", 25],
        ["8281", "ａ", 25],
        ["829f", "ぁ", 82],
        ["8340", "ァ", 62],
        ["8380", "ム", 22],
        ["839f", "Α", 16, "Σ", 6],
        ["83bf", "α", 16, "σ", 6],
        ["8440", "А", 5, "ЁЖ", 25],
        ["8470", "а", 5, "ёж", 7],
        ["8480", "о", 17],
        ["849f", "─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂"],
        ["8740", "①", 19, "Ⅰ", 9],
        ["875f", "㍉㌔㌢㍍㌘㌧㌃㌶㍑㍗㌍㌦㌣㌫㍊㌻㎜㎝㎞㎎㎏㏄㎡"],
        ["877e", "㍻"],
        ["8780", "〝〟№㏍℡㊤", 4, "㈱㈲㈹㍾㍽㍼≒≡∫∮∑√⊥∠∟⊿∵∩∪"],
        ["889f", "亜唖娃阿哀愛挨姶逢葵茜穐悪握渥旭葦芦鯵梓圧斡扱宛姐虻飴絢綾鮎或粟袷安庵按暗案闇鞍杏以伊位依偉囲夷委威尉惟意慰易椅為畏異移維緯胃萎衣謂違遺医井亥域育郁磯一壱溢逸稲茨芋鰯允印咽員因姻引飲淫胤蔭"],
        ["8940", "院陰隠韻吋右宇烏羽迂雨卯鵜窺丑碓臼渦嘘唄欝蔚鰻姥厩浦瓜閏噂云運雲荏餌叡営嬰影映曳栄永泳洩瑛盈穎頴英衛詠鋭液疫益駅悦謁越閲榎厭円"],
        ["8980", "園堰奄宴延怨掩援沿演炎焔煙燕猿縁艶苑薗遠鉛鴛塩於汚甥凹央奥往応押旺横欧殴王翁襖鴬鴎黄岡沖荻億屋憶臆桶牡乙俺卸恩温穏音下化仮何伽価佳加可嘉夏嫁家寡科暇果架歌河火珂禍禾稼箇花苛茄荷華菓蝦課嘩貨迦過霞蚊俄峨我牙画臥芽蛾賀雅餓駕介会解回塊壊廻快怪悔恢懐戒拐改"],
        ["8a40", "魁晦械海灰界皆絵芥蟹開階貝凱劾外咳害崖慨概涯碍蓋街該鎧骸浬馨蛙垣柿蛎鈎劃嚇各廓拡撹格核殻獲確穫覚角赫較郭閣隔革学岳楽額顎掛笠樫"],
        ["8a80", "橿梶鰍潟割喝恰括活渇滑葛褐轄且鰹叶椛樺鞄株兜竃蒲釜鎌噛鴨栢茅萱粥刈苅瓦乾侃冠寒刊勘勧巻喚堪姦完官寛干幹患感慣憾換敢柑桓棺款歓汗漢澗潅環甘監看竿管簡緩缶翰肝艦莞観諌貫還鑑間閑関陥韓館舘丸含岸巌玩癌眼岩翫贋雁頑顔願企伎危喜器基奇嬉寄岐希幾忌揮机旗既期棋棄"],
        ["8b40", "機帰毅気汽畿祈季稀紀徽規記貴起軌輝飢騎鬼亀偽儀妓宜戯技擬欺犠疑祇義蟻誼議掬菊鞠吉吃喫桔橘詰砧杵黍却客脚虐逆丘久仇休及吸宮弓急救"],
        ["8b80", "朽求汲泣灸球究窮笈級糾給旧牛去居巨拒拠挙渠虚許距鋸漁禦魚亨享京供侠僑兇競共凶協匡卿叫喬境峡強彊怯恐恭挟教橋況狂狭矯胸脅興蕎郷鏡響饗驚仰凝尭暁業局曲極玉桐粁僅勤均巾錦斤欣欽琴禁禽筋緊芹菌衿襟謹近金吟銀九倶句区狗玖矩苦躯駆駈駒具愚虞喰空偶寓遇隅串櫛釧屑屈"],
        ["8c40", "掘窟沓靴轡窪熊隈粂栗繰桑鍬勲君薫訓群軍郡卦袈祁係傾刑兄啓圭珪型契形径恵慶慧憩掲携敬景桂渓畦稽系経継繋罫茎荊蛍計詣警軽頚鶏芸迎鯨"],
        ["8c80", "劇戟撃激隙桁傑欠決潔穴結血訣月件倹倦健兼券剣喧圏堅嫌建憲懸拳捲検権牽犬献研硯絹県肩見謙賢軒遣鍵険顕験鹸元原厳幻弦減源玄現絃舷言諺限乎個古呼固姑孤己庫弧戸故枯湖狐糊袴股胡菰虎誇跨鈷雇顧鼓五互伍午呉吾娯後御悟梧檎瑚碁語誤護醐乞鯉交佼侯候倖光公功効勾厚口向"],
        ["8d40", "后喉坑垢好孔孝宏工巧巷幸広庚康弘恒慌抗拘控攻昂晃更杭校梗構江洪浩港溝甲皇硬稿糠紅紘絞綱耕考肯肱腔膏航荒行衡講貢購郊酵鉱砿鋼閤降"],
        ["8d80", "項香高鴻剛劫号合壕拷濠豪轟麹克刻告国穀酷鵠黒獄漉腰甑忽惚骨狛込此頃今困坤墾婚恨懇昏昆根梱混痕紺艮魂些佐叉唆嵯左差査沙瑳砂詐鎖裟坐座挫債催再最哉塞妻宰彩才採栽歳済災采犀砕砦祭斎細菜裁載際剤在材罪財冴坂阪堺榊肴咲崎埼碕鷺作削咋搾昨朔柵窄策索錯桜鮭笹匙冊刷"],
        ["8e40", "察拶撮擦札殺薩雑皐鯖捌錆鮫皿晒三傘参山惨撒散桟燦珊産算纂蚕讃賛酸餐斬暫残仕仔伺使刺司史嗣四士始姉姿子屍市師志思指支孜斯施旨枝止"],
        ["8e80", "死氏獅祉私糸紙紫肢脂至視詞詩試誌諮資賜雌飼歯事似侍児字寺慈持時次滋治爾璽痔磁示而耳自蒔辞汐鹿式識鴫竺軸宍雫七叱執失嫉室悉湿漆疾質実蔀篠偲柴芝屡蕊縞舎写射捨赦斜煮社紗者謝車遮蛇邪借勺尺杓灼爵酌釈錫若寂弱惹主取守手朱殊狩珠種腫趣酒首儒受呪寿授樹綬需囚収周"],
        ["8f40", "宗就州修愁拾洲秀秋終繍習臭舟蒐衆襲讐蹴輯週酋酬集醜什住充十従戎柔汁渋獣縦重銃叔夙宿淑祝縮粛塾熟出術述俊峻春瞬竣舜駿准循旬楯殉淳"],
        ["8f80", "準潤盾純巡遵醇順処初所暑曙渚庶緒署書薯藷諸助叙女序徐恕鋤除傷償勝匠升召哨商唱嘗奨妾娼宵将小少尚庄床廠彰承抄招掌捷昇昌昭晶松梢樟樵沼消渉湘焼焦照症省硝礁祥称章笑粧紹肖菖蒋蕉衝裳訟証詔詳象賞醤鉦鍾鐘障鞘上丈丞乗冗剰城場壌嬢常情擾条杖浄状畳穣蒸譲醸錠嘱埴飾"],
        ["9040", "拭植殖燭織職色触食蝕辱尻伸信侵唇娠寝審心慎振新晋森榛浸深申疹真神秦紳臣芯薪親診身辛進針震人仁刃塵壬尋甚尽腎訊迅陣靭笥諏須酢図厨"],
        ["9080", "逗吹垂帥推水炊睡粋翠衰遂酔錐錘随瑞髄崇嵩数枢趨雛据杉椙菅頗雀裾澄摺寸世瀬畝是凄制勢姓征性成政整星晴棲栖正清牲生盛精聖声製西誠誓請逝醒青静斉税脆隻席惜戚斥昔析石積籍績脊責赤跡蹟碩切拙接摂折設窃節説雪絶舌蝉仙先千占宣専尖川戦扇撰栓栴泉浅洗染潜煎煽旋穿箭線"],
        ["9140", "繊羨腺舛船薦詮賎践選遷銭銑閃鮮前善漸然全禅繕膳糎噌塑岨措曾曽楚狙疏疎礎祖租粗素組蘇訴阻遡鼠僧創双叢倉喪壮奏爽宋層匝惣想捜掃挿掻"],
        ["9180", "操早曹巣槍槽漕燥争痩相窓糟総綜聡草荘葬蒼藻装走送遭鎗霜騒像増憎臓蔵贈造促側則即息捉束測足速俗属賊族続卒袖其揃存孫尊損村遜他多太汰詑唾堕妥惰打柁舵楕陀駄騨体堆対耐岱帯待怠態戴替泰滞胎腿苔袋貸退逮隊黛鯛代台大第醍題鷹滝瀧卓啄宅托択拓沢濯琢託鐸濁諾茸凧蛸只"],
        ["9240", "叩但達辰奪脱巽竪辿棚谷狸鱈樽誰丹単嘆坦担探旦歎淡湛炭短端箪綻耽胆蛋誕鍛団壇弾断暖檀段男談値知地弛恥智池痴稚置致蜘遅馳築畜竹筑蓄"],
        ["9280", "逐秩窒茶嫡着中仲宙忠抽昼柱注虫衷註酎鋳駐樗瀦猪苧著貯丁兆凋喋寵帖帳庁弔張彫徴懲挑暢朝潮牒町眺聴脹腸蝶調諜超跳銚長頂鳥勅捗直朕沈珍賃鎮陳津墜椎槌追鎚痛通塚栂掴槻佃漬柘辻蔦綴鍔椿潰坪壷嬬紬爪吊釣鶴亭低停偵剃貞呈堤定帝底庭廷弟悌抵挺提梯汀碇禎程締艇訂諦蹄逓"],
        ["9340", "邸鄭釘鼎泥摘擢敵滴的笛適鏑溺哲徹撤轍迭鉄典填天展店添纏甜貼転顛点伝殿澱田電兎吐堵塗妬屠徒斗杜渡登菟賭途都鍍砥砺努度土奴怒倒党冬"],
        ["9380", "凍刀唐塔塘套宕島嶋悼投搭東桃梼棟盗淘湯涛灯燈当痘祷等答筒糖統到董蕩藤討謄豆踏逃透鐙陶頭騰闘働動同堂導憧撞洞瞳童胴萄道銅峠鴇匿得徳涜特督禿篤毒独読栃橡凸突椴届鳶苫寅酉瀞噸屯惇敦沌豚遁頓呑曇鈍奈那内乍凪薙謎灘捺鍋楢馴縄畷南楠軟難汝二尼弐迩匂賑肉虹廿日乳入"],
        ["9440", "如尿韮任妊忍認濡禰祢寧葱猫熱年念捻撚燃粘乃廼之埜嚢悩濃納能脳膿農覗蚤巴把播覇杷波派琶破婆罵芭馬俳廃拝排敗杯盃牌背肺輩配倍培媒梅"],
        ["9480", "楳煤狽買売賠陪這蝿秤矧萩伯剥博拍柏泊白箔粕舶薄迫曝漠爆縛莫駁麦函箱硲箸肇筈櫨幡肌畑畠八鉢溌発醗髪伐罰抜筏閥鳩噺塙蛤隼伴判半反叛帆搬斑板氾汎版犯班畔繁般藩販範釆煩頒飯挽晩番盤磐蕃蛮匪卑否妃庇彼悲扉批披斐比泌疲皮碑秘緋罷肥被誹費避非飛樋簸備尾微枇毘琵眉美"],
        ["9540", "鼻柊稗匹疋髭彦膝菱肘弼必畢筆逼桧姫媛紐百謬俵彪標氷漂瓢票表評豹廟描病秒苗錨鋲蒜蛭鰭品彬斌浜瀕貧賓頻敏瓶不付埠夫婦富冨布府怖扶敷"],
        ["9580", "斧普浮父符腐膚芙譜負賦赴阜附侮撫武舞葡蕪部封楓風葺蕗伏副復幅服福腹複覆淵弗払沸仏物鮒分吻噴墳憤扮焚奮粉糞紛雰文聞丙併兵塀幣平弊柄並蔽閉陛米頁僻壁癖碧別瞥蔑箆偏変片篇編辺返遍便勉娩弁鞭保舗鋪圃捕歩甫補輔穂募墓慕戊暮母簿菩倣俸包呆報奉宝峰峯崩庖抱捧放方朋"],
        ["9640", "法泡烹砲縫胞芳萌蓬蜂褒訪豊邦鋒飽鳳鵬乏亡傍剖坊妨帽忘忙房暴望某棒冒紡肪膨謀貌貿鉾防吠頬北僕卜墨撲朴牧睦穆釦勃没殆堀幌奔本翻凡盆"],
        ["9680", "摩磨魔麻埋妹昧枚毎哩槙幕膜枕鮪柾鱒桝亦俣又抹末沫迄侭繭麿万慢満漫蔓味未魅巳箕岬密蜜湊蓑稔脈妙粍民眠務夢無牟矛霧鵡椋婿娘冥名命明盟迷銘鳴姪牝滅免棉綿緬面麺摸模茂妄孟毛猛盲網耗蒙儲木黙目杢勿餅尤戻籾貰問悶紋門匁也冶夜爺耶野弥矢厄役約薬訳躍靖柳薮鑓愉愈油癒"],
        ["9740", "諭輸唯佑優勇友宥幽悠憂揖有柚湧涌猶猷由祐裕誘遊邑郵雄融夕予余与誉輿預傭幼妖容庸揚揺擁曜楊様洋溶熔用窯羊耀葉蓉要謡踊遥陽養慾抑欲"],
        ["9780", "沃浴翌翼淀羅螺裸来莱頼雷洛絡落酪乱卵嵐欄濫藍蘭覧利吏履李梨理璃痢裏裡里離陸律率立葎掠略劉流溜琉留硫粒隆竜龍侶慮旅虜了亮僚両凌寮料梁涼猟療瞭稜糧良諒遼量陵領力緑倫厘林淋燐琳臨輪隣鱗麟瑠塁涙累類令伶例冷励嶺怜玲礼苓鈴隷零霊麗齢暦歴列劣烈裂廉恋憐漣煉簾練聯"],
        ["9840", "蓮連錬呂魯櫓炉賂路露労婁廊弄朗楼榔浪漏牢狼篭老聾蝋郎六麓禄肋録論倭和話歪賄脇惑枠鷲亙亘鰐詫藁蕨椀湾碗腕"],
        ["989f", "弌丐丕个丱丶丼丿乂乖乘亂亅豫亊舒弍于亞亟亠亢亰亳亶从仍仄仆仂仗仞仭仟价伉佚估佛佝佗佇佶侈侏侘佻佩佰侑佯來侖儘俔俟俎俘俛俑俚俐俤俥倚倨倔倪倥倅伜俶倡倩倬俾俯們倆偃假會偕偐偈做偖偬偸傀傚傅傴傲"],
        ["9940", "僉僊傳僂僖僞僥僭僣僮價僵儉儁儂儖儕儔儚儡儺儷儼儻儿兀兒兌兔兢竸兩兪兮冀冂囘册冉冏冑冓冕冖冤冦冢冩冪冫决冱冲冰况冽凅凉凛几處凩凭"],
        ["9980", "凰凵凾刄刋刔刎刧刪刮刳刹剏剄剋剌剞剔剪剴剩剳剿剽劍劔劒剱劈劑辨辧劬劭劼劵勁勍勗勞勣勦飭勠勳勵勸勹匆匈甸匍匐匏匕匚匣匯匱匳匸區卆卅丗卉卍凖卞卩卮夘卻卷厂厖厠厦厥厮厰厶參簒雙叟曼燮叮叨叭叺吁吽呀听吭吼吮吶吩吝呎咏呵咎呟呱呷呰咒呻咀呶咄咐咆哇咢咸咥咬哄哈咨"],
        ["9a40", "咫哂咤咾咼哘哥哦唏唔哽哮哭哺哢唹啀啣啌售啜啅啖啗唸唳啝喙喀咯喊喟啻啾喘喞單啼喃喩喇喨嗚嗅嗟嗄嗜嗤嗔嘔嗷嘖嗾嗽嘛嗹噎噐營嘴嘶嘲嘸"],
        ["9a80", "噫噤嘯噬噪嚆嚀嚊嚠嚔嚏嚥嚮嚶嚴囂嚼囁囃囀囈囎囑囓囗囮囹圀囿圄圉圈國圍圓團圖嗇圜圦圷圸坎圻址坏坩埀垈坡坿垉垓垠垳垤垪垰埃埆埔埒埓堊埖埣堋堙堝塲堡塢塋塰毀塒堽塹墅墹墟墫墺壞墻墸墮壅壓壑壗壙壘壥壜壤壟壯壺壹壻壼壽夂夊夐夛梦夥夬夭夲夸夾竒奕奐奎奚奘奢奠奧奬奩"],
        ["9b40", "奸妁妝佞侫妣妲姆姨姜妍姙姚娥娟娑娜娉娚婀婬婉娵娶婢婪媚媼媾嫋嫂媽嫣嫗嫦嫩嫖嫺嫻嬌嬋嬖嬲嫐嬪嬶嬾孃孅孀孑孕孚孛孥孩孰孳孵學斈孺宀"],
        ["9b80", "它宦宸寃寇寉寔寐寤實寢寞寥寫寰寶寳尅將專對尓尠尢尨尸尹屁屆屎屓屐屏孱屬屮乢屶屹岌岑岔妛岫岻岶岼岷峅岾峇峙峩峽峺峭嶌峪崋崕崗嵜崟崛崑崔崢崚崙崘嵌嵒嵎嵋嵬嵳嵶嶇嶄嶂嶢嶝嶬嶮嶽嶐嶷嶼巉巍巓巒巖巛巫已巵帋帚帙帑帛帶帷幄幃幀幎幗幔幟幢幤幇幵并幺麼广庠廁廂廈廐廏"],
        ["9c40", "廖廣廝廚廛廢廡廨廩廬廱廳廰廴廸廾弃弉彝彜弋弑弖弩弭弸彁彈彌彎弯彑彖彗彙彡彭彳彷徃徂彿徊很徑徇從徙徘徠徨徭徼忖忻忤忸忱忝悳忿怡恠"],
        ["9c80", "怙怐怩怎怱怛怕怫怦怏怺恚恁恪恷恟恊恆恍恣恃恤恂恬恫恙悁悍惧悃悚悄悛悖悗悒悧悋惡悸惠惓悴忰悽惆悵惘慍愕愆惶惷愀惴惺愃愡惻惱愍愎慇愾愨愧慊愿愼愬愴愽慂慄慳慷慘慙慚慫慴慯慥慱慟慝慓慵憙憖憇憬憔憚憊憑憫憮懌懊應懷懈懃懆憺懋罹懍懦懣懶懺懴懿懽懼懾戀戈戉戍戌戔戛"],
        ["9d40", "戞戡截戮戰戲戳扁扎扞扣扛扠扨扼抂抉找抒抓抖拔抃抔拗拑抻拏拿拆擔拈拜拌拊拂拇抛拉挌拮拱挧挂挈拯拵捐挾捍搜捏掖掎掀掫捶掣掏掉掟掵捫"],
        ["9d80", "捩掾揩揀揆揣揉插揶揄搖搴搆搓搦搶攝搗搨搏摧摯摶摎攪撕撓撥撩撈撼據擒擅擇撻擘擂擱擧舉擠擡抬擣擯攬擶擴擲擺攀擽攘攜攅攤攣攫攴攵攷收攸畋效敖敕敍敘敞敝敲數斂斃變斛斟斫斷旃旆旁旄旌旒旛旙无旡旱杲昊昃旻杳昵昶昴昜晏晄晉晁晞晝晤晧晨晟晢晰暃暈暎暉暄暘暝曁暹曉暾暼"],
        ["9e40", "曄暸曖曚曠昿曦曩曰曵曷朏朖朞朦朧霸朮朿朶杁朸朷杆杞杠杙杣杤枉杰枩杼杪枌枋枦枡枅枷柯枴柬枳柩枸柤柞柝柢柮枹柎柆柧檜栞框栩桀桍栲桎"],
        ["9e80", "梳栫桙档桷桿梟梏梭梔條梛梃檮梹桴梵梠梺椏梍桾椁棊椈棘椢椦棡椌棍棔棧棕椶椒椄棗棣椥棹棠棯椨椪椚椣椡棆楹楷楜楸楫楔楾楮椹楴椽楙椰楡楞楝榁楪榲榮槐榿槁槓榾槎寨槊槝榻槃榧樮榑榠榜榕榴槞槨樂樛槿權槹槲槧樅榱樞槭樔槫樊樒櫁樣樓橄樌橲樶橸橇橢橙橦橈樸樢檐檍檠檄檢檣"],
        ["9f40", "檗蘗檻櫃櫂檸檳檬櫞櫑櫟檪櫚櫪櫻欅蘖櫺欒欖鬱欟欸欷盜欹飮歇歃歉歐歙歔歛歟歡歸歹歿殀殄殃殍殘殕殞殤殪殫殯殲殱殳殷殼毆毋毓毟毬毫毳毯"],
        ["9f80", "麾氈氓气氛氤氣汞汕汢汪沂沍沚沁沛汾汨汳沒沐泄泱泓沽泗泅泝沮沱沾沺泛泯泙泪洟衍洶洫洽洸洙洵洳洒洌浣涓浤浚浹浙涎涕濤涅淹渕渊涵淇淦涸淆淬淞淌淨淒淅淺淙淤淕淪淮渭湮渮渙湲湟渾渣湫渫湶湍渟湃渺湎渤滿渝游溂溪溘滉溷滓溽溯滄溲滔滕溏溥滂溟潁漑灌滬滸滾漿滲漱滯漲滌"],
        ["e040", "漾漓滷澆潺潸澁澀潯潛濳潭澂潼潘澎澑濂潦澳澣澡澤澹濆澪濟濕濬濔濘濱濮濛瀉瀋濺瀑瀁瀏濾瀛瀚潴瀝瀘瀟瀰瀾瀲灑灣炙炒炯烱炬炸炳炮烟烋烝"],
        ["e080", "烙焉烽焜焙煥煕熈煦煢煌煖煬熏燻熄熕熨熬燗熹熾燒燉燔燎燠燬燧燵燼燹燿爍爐爛爨爭爬爰爲爻爼爿牀牆牋牘牴牾犂犁犇犒犖犢犧犹犲狃狆狄狎狒狢狠狡狹狷倏猗猊猜猖猝猴猯猩猥猾獎獏默獗獪獨獰獸獵獻獺珈玳珎玻珀珥珮珞璢琅瑯琥珸琲琺瑕琿瑟瑙瑁瑜瑩瑰瑣瑪瑶瑾璋璞璧瓊瓏瓔珱"],
        ["e140", "瓠瓣瓧瓩瓮瓲瓰瓱瓸瓷甄甃甅甌甎甍甕甓甞甦甬甼畄畍畊畉畛畆畚畩畤畧畫畭畸當疆疇畴疊疉疂疔疚疝疥疣痂疳痃疵疽疸疼疱痍痊痒痙痣痞痾痿"],
        ["e180", "痼瘁痰痺痲痳瘋瘍瘉瘟瘧瘠瘡瘢瘤瘴瘰瘻癇癈癆癜癘癡癢癨癩癪癧癬癰癲癶癸發皀皃皈皋皎皖皓皙皚皰皴皸皹皺盂盍盖盒盞盡盥盧盪蘯盻眈眇眄眩眤眞眥眦眛眷眸睇睚睨睫睛睥睿睾睹瞎瞋瞑瞠瞞瞰瞶瞹瞿瞼瞽瞻矇矍矗矚矜矣矮矼砌砒礦砠礪硅碎硴碆硼碚碌碣碵碪碯磑磆磋磔碾碼磅磊磬"],
        ["e240", "磧磚磽磴礇礒礑礙礬礫祀祠祗祟祚祕祓祺祿禊禝禧齋禪禮禳禹禺秉秕秧秬秡秣稈稍稘稙稠稟禀稱稻稾稷穃穗穉穡穢穩龝穰穹穽窈窗窕窘窖窩竈窰"],
        ["e280", "窶竅竄窿邃竇竊竍竏竕竓站竚竝竡竢竦竭竰笂笏笊笆笳笘笙笞笵笨笶筐筺笄筍笋筌筅筵筥筴筧筰筱筬筮箝箘箟箍箜箚箋箒箏筝箙篋篁篌篏箴篆篝篩簑簔篦篥籠簀簇簓篳篷簗簍篶簣簧簪簟簷簫簽籌籃籔籏籀籐籘籟籤籖籥籬籵粃粐粤粭粢粫粡粨粳粲粱粮粹粽糀糅糂糘糒糜糢鬻糯糲糴糶糺紆"],
        ["e340", "紂紜紕紊絅絋紮紲紿紵絆絳絖絎絲絨絮絏絣經綉絛綏絽綛綺綮綣綵緇綽綫總綢綯緜綸綟綰緘緝緤緞緻緲緡縅縊縣縡縒縱縟縉縋縢繆繦縻縵縹繃縷"],
        ["e380", "縲縺繧繝繖繞繙繚繹繪繩繼繻纃緕繽辮繿纈纉續纒纐纓纔纖纎纛纜缸缺罅罌罍罎罐网罕罔罘罟罠罨罩罧罸羂羆羃羈羇羌羔羞羝羚羣羯羲羹羮羶羸譱翅翆翊翕翔翡翦翩翳翹飜耆耄耋耒耘耙耜耡耨耿耻聊聆聒聘聚聟聢聨聳聲聰聶聹聽聿肄肆肅肛肓肚肭冐肬胛胥胙胝胄胚胖脉胯胱脛脩脣脯腋"],
        ["e440", "隋腆脾腓腑胼腱腮腥腦腴膃膈膊膀膂膠膕膤膣腟膓膩膰膵膾膸膽臀臂膺臉臍臑臙臘臈臚臟臠臧臺臻臾舁舂舅與舊舍舐舖舩舫舸舳艀艙艘艝艚艟艤"],
        ["e480", "艢艨艪艫舮艱艷艸艾芍芒芫芟芻芬苡苣苟苒苴苳苺莓范苻苹苞茆苜茉苙茵茴茖茲茱荀茹荐荅茯茫茗茘莅莚莪莟莢莖茣莎莇莊荼莵荳荵莠莉莨菴萓菫菎菽萃菘萋菁菷萇菠菲萍萢萠莽萸蔆菻葭萪萼蕚蒄葷葫蒭葮蒂葩葆萬葯葹萵蓊葢蒹蒿蒟蓙蓍蒻蓚蓐蓁蓆蓖蒡蔡蓿蓴蔗蔘蔬蔟蔕蔔蓼蕀蕣蕘蕈"],
        ["e540", "蕁蘂蕋蕕薀薤薈薑薊薨蕭薔薛藪薇薜蕷蕾薐藉薺藏薹藐藕藝藥藜藹蘊蘓蘋藾藺蘆蘢蘚蘰蘿虍乕虔號虧虱蚓蚣蚩蚪蚋蚌蚶蚯蛄蛆蚰蛉蠣蚫蛔蛞蛩蛬"],
        ["e580", "蛟蛛蛯蜒蜆蜈蜀蜃蛻蜑蜉蜍蛹蜊蜴蜿蜷蜻蜥蜩蜚蝠蝟蝸蝌蝎蝴蝗蝨蝮蝙蝓蝣蝪蠅螢螟螂螯蟋螽蟀蟐雖螫蟄螳蟇蟆螻蟯蟲蟠蠏蠍蟾蟶蟷蠎蟒蠑蠖蠕蠢蠡蠱蠶蠹蠧蠻衄衂衒衙衞衢衫袁衾袞衵衽袵衲袂袗袒袮袙袢袍袤袰袿袱裃裄裔裘裙裝裹褂裼裴裨裲褄褌褊褓襃褞褥褪褫襁襄褻褶褸襌褝襠襞"],
        ["e640", "襦襤襭襪襯襴襷襾覃覈覊覓覘覡覩覦覬覯覲覺覽覿觀觚觜觝觧觴觸訃訖訐訌訛訝訥訶詁詛詒詆詈詼詭詬詢誅誂誄誨誡誑誥誦誚誣諄諍諂諚諫諳諧"],
        ["e680", "諤諱謔諠諢諷諞諛謌謇謚諡謖謐謗謠謳鞫謦謫謾謨譁譌譏譎證譖譛譚譫譟譬譯譴譽讀讌讎讒讓讖讙讚谺豁谿豈豌豎豐豕豢豬豸豺貂貉貅貊貍貎貔豼貘戝貭貪貽貲貳貮貶賈賁賤賣賚賽賺賻贄贅贊贇贏贍贐齎贓賍贔贖赧赭赱赳趁趙跂趾趺跏跚跖跌跛跋跪跫跟跣跼踈踉跿踝踞踐踟蹂踵踰踴蹊"],
        ["e740", "蹇蹉蹌蹐蹈蹙蹤蹠踪蹣蹕蹶蹲蹼躁躇躅躄躋躊躓躑躔躙躪躡躬躰軆躱躾軅軈軋軛軣軼軻軫軾輊輅輕輒輙輓輜輟輛輌輦輳輻輹轅轂輾轌轉轆轎轗轜"],
        ["e780", "轢轣轤辜辟辣辭辯辷迚迥迢迪迯邇迴逅迹迺逑逕逡逍逞逖逋逧逶逵逹迸遏遐遑遒逎遉逾遖遘遞遨遯遶隨遲邂遽邁邀邊邉邏邨邯邱邵郢郤扈郛鄂鄒鄙鄲鄰酊酖酘酣酥酩酳酲醋醉醂醢醫醯醪醵醴醺釀釁釉釋釐釖釟釡釛釼釵釶鈞釿鈔鈬鈕鈑鉞鉗鉅鉉鉤鉈銕鈿鉋鉐銜銖銓銛鉚鋏銹銷鋩錏鋺鍄錮"],
        ["e840", "錙錢錚錣錺錵錻鍜鍠鍼鍮鍖鎰鎬鎭鎔鎹鏖鏗鏨鏥鏘鏃鏝鏐鏈鏤鐚鐔鐓鐃鐇鐐鐶鐫鐵鐡鐺鑁鑒鑄鑛鑠鑢鑞鑪鈩鑰鑵鑷鑽鑚鑼鑾钁鑿閂閇閊閔閖閘閙"],
        ["e880", "閠閨閧閭閼閻閹閾闊濶闃闍闌闕闔闖關闡闥闢阡阨阮阯陂陌陏陋陷陜陞陝陟陦陲陬隍隘隕隗險隧隱隲隰隴隶隸隹雎雋雉雍襍雜霍雕雹霄霆霈霓霎霑霏霖霙霤霪霰霹霽霾靄靆靈靂靉靜靠靤靦靨勒靫靱靹鞅靼鞁靺鞆鞋鞏鞐鞜鞨鞦鞣鞳鞴韃韆韈韋韜韭齏韲竟韶韵頏頌頸頤頡頷頽顆顏顋顫顯顰"],
        ["e940", "顱顴顳颪颯颱颶飄飃飆飩飫餃餉餒餔餘餡餝餞餤餠餬餮餽餾饂饉饅饐饋饑饒饌饕馗馘馥馭馮馼駟駛駝駘駑駭駮駱駲駻駸騁騏騅駢騙騫騷驅驂驀驃"],
        ["e980", "騾驕驍驛驗驟驢驥驤驩驫驪骭骰骼髀髏髑髓體髞髟髢髣髦髯髫髮髴髱髷髻鬆鬘鬚鬟鬢鬣鬥鬧鬨鬩鬪鬮鬯鬲魄魃魏魍魎魑魘魴鮓鮃鮑鮖鮗鮟鮠鮨鮴鯀鯊鮹鯆鯏鯑鯒鯣鯢鯤鯔鯡鰺鯲鯱鯰鰕鰔鰉鰓鰌鰆鰈鰒鰊鰄鰮鰛鰥鰤鰡鰰鱇鰲鱆鰾鱚鱠鱧鱶鱸鳧鳬鳰鴉鴈鳫鴃鴆鴪鴦鶯鴣鴟鵄鴕鴒鵁鴿鴾鵆鵈"],
        ["ea40", "鵝鵞鵤鵑鵐鵙鵲鶉鶇鶫鵯鵺鶚鶤鶩鶲鷄鷁鶻鶸鶺鷆鷏鷂鷙鷓鷸鷦鷭鷯鷽鸚鸛鸞鹵鹹鹽麁麈麋麌麒麕麑麝麥麩麸麪麭靡黌黎黏黐黔黜點黝黠黥黨黯"],
        ["ea80", "黴黶黷黹黻黼黽鼇鼈皷鼕鼡鼬鼾齊齒齔齣齟齠齡齦齧齬齪齷齲齶龕龜龠堯槇遙瑤凜熙"],
        ["ed40", "纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏"],
        ["ed80", "塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱"],
        ["ee40", "犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙"],
        ["ee80", "蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"],
        ["eeef", "ⅰ", 9, "￢￤＇＂"],
        ["f040", "", 62],
        ["f080", "", 124],
        ["f140", "", 62],
        ["f180", "", 124],
        ["f240", "", 62],
        ["f280", "", 124],
        ["f340", "", 62],
        ["f380", "", 124],
        ["f440", "", 62],
        ["f480", "", 124],
        ["f540", "", 62],
        ["f580", "", 124],
        ["f640", "", 62],
        ["f680", "", 124],
        ["f740", "", 62],
        ["f780", "", 124],
        ["f840", "", 62],
        ["f880", "", 124],
        ["f940", ""],
        ["fa40", "ⅰ", 9, "Ⅰ", 9, "￢￤＇＂㈱№℡∵纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊"],
        ["fa80", "兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯"],
        ["fb40", "涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神"],
        ["fb80", "祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙"],
        ["fc40", "髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/eucjp.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 127],
        ["8ea1", "｡", 62],
        ["a1a1", "　、。，．・：；？！゛゜´｀¨＾￣＿ヽヾゝゞ〃仝々〆〇ー―‐／＼～∥｜…‥‘’“”（）〔〕［］｛｝〈", 9, "＋－±×÷＝≠＜＞≦≧∞∴♂♀°′″℃￥＄￠￡％＃＆＊＠§☆★○●◎◇"],
        ["a2a1", "◆□■△▲▽▼※〒→←↑↓〓"],
        ["a2ba", "∈∋⊆⊇⊂⊃∪∩"],
        ["a2ca", "∧∨￢⇒⇔∀∃"],
        ["a2dc", "∠⊥⌒∂∇≡≒≪≫√∽∝∵∫∬"],
        ["a2f2", "Å‰♯♭♪†‡¶"],
        ["a2fe", "◯"],
        ["a3b0", "０", 9],
        ["a3c1", "Ａ", 25],
        ["a3e1", "ａ", 25],
        ["a4a1", "ぁ", 82],
        ["a5a1", "ァ", 85],
        ["a6a1", "Α", 16, "Σ", 6],
        ["a6c1", "α", 16, "σ", 6],
        ["a7a1", "А", 5, "ЁЖ", 25],
        ["a7d1", "а", 5, "ёж", 25],
        ["a8a1", "─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂"],
        ["ada1", "①", 19, "Ⅰ", 9],
        ["adc0", "㍉㌔㌢㍍㌘㌧㌃㌶㍑㍗㌍㌦㌣㌫㍊㌻㎜㎝㎞㎎㎏㏄㎡"],
        ["addf", "㍻〝〟№㏍℡㊤", 4, "㈱㈲㈹㍾㍽㍼≒≡∫∮∑√⊥∠∟⊿∵∩∪"],
        ["b0a1", "亜唖娃阿哀愛挨姶逢葵茜穐悪握渥旭葦芦鯵梓圧斡扱宛姐虻飴絢綾鮎或粟袷安庵按暗案闇鞍杏以伊位依偉囲夷委威尉惟意慰易椅為畏異移維緯胃萎衣謂違遺医井亥域育郁磯一壱溢逸稲茨芋鰯允印咽員因姻引飲淫胤蔭"],
        ["b1a1", "院陰隠韻吋右宇烏羽迂雨卯鵜窺丑碓臼渦嘘唄欝蔚鰻姥厩浦瓜閏噂云運雲荏餌叡営嬰影映曳栄永泳洩瑛盈穎頴英衛詠鋭液疫益駅悦謁越閲榎厭円園堰奄宴延怨掩援沿演炎焔煙燕猿縁艶苑薗遠鉛鴛塩於汚甥凹央奥往応"],
        ["b2a1", "押旺横欧殴王翁襖鴬鴎黄岡沖荻億屋憶臆桶牡乙俺卸恩温穏音下化仮何伽価佳加可嘉夏嫁家寡科暇果架歌河火珂禍禾稼箇花苛茄荷華菓蝦課嘩貨迦過霞蚊俄峨我牙画臥芽蛾賀雅餓駕介会解回塊壊廻快怪悔恢懐戒拐改"],
        ["b3a1", "魁晦械海灰界皆絵芥蟹開階貝凱劾外咳害崖慨概涯碍蓋街該鎧骸浬馨蛙垣柿蛎鈎劃嚇各廓拡撹格核殻獲確穫覚角赫較郭閣隔革学岳楽額顎掛笠樫橿梶鰍潟割喝恰括活渇滑葛褐轄且鰹叶椛樺鞄株兜竃蒲釜鎌噛鴨栢茅萱"],
        ["b4a1", "粥刈苅瓦乾侃冠寒刊勘勧巻喚堪姦完官寛干幹患感慣憾換敢柑桓棺款歓汗漢澗潅環甘監看竿管簡緩缶翰肝艦莞観諌貫還鑑間閑関陥韓館舘丸含岸巌玩癌眼岩翫贋雁頑顔願企伎危喜器基奇嬉寄岐希幾忌揮机旗既期棋棄"],
        ["b5a1", "機帰毅気汽畿祈季稀紀徽規記貴起軌輝飢騎鬼亀偽儀妓宜戯技擬欺犠疑祇義蟻誼議掬菊鞠吉吃喫桔橘詰砧杵黍却客脚虐逆丘久仇休及吸宮弓急救朽求汲泣灸球究窮笈級糾給旧牛去居巨拒拠挙渠虚許距鋸漁禦魚亨享京"],
        ["b6a1", "供侠僑兇競共凶協匡卿叫喬境峡強彊怯恐恭挟教橋況狂狭矯胸脅興蕎郷鏡響饗驚仰凝尭暁業局曲極玉桐粁僅勤均巾錦斤欣欽琴禁禽筋緊芹菌衿襟謹近金吟銀九倶句区狗玖矩苦躯駆駈駒具愚虞喰空偶寓遇隅串櫛釧屑屈"],
        ["b7a1", "掘窟沓靴轡窪熊隈粂栗繰桑鍬勲君薫訓群軍郡卦袈祁係傾刑兄啓圭珪型契形径恵慶慧憩掲携敬景桂渓畦稽系経継繋罫茎荊蛍計詣警軽頚鶏芸迎鯨劇戟撃激隙桁傑欠決潔穴結血訣月件倹倦健兼券剣喧圏堅嫌建憲懸拳捲"],
        ["b8a1", "検権牽犬献研硯絹県肩見謙賢軒遣鍵険顕験鹸元原厳幻弦減源玄現絃舷言諺限乎個古呼固姑孤己庫弧戸故枯湖狐糊袴股胡菰虎誇跨鈷雇顧鼓五互伍午呉吾娯後御悟梧檎瑚碁語誤護醐乞鯉交佼侯候倖光公功効勾厚口向"],
        ["b9a1", "后喉坑垢好孔孝宏工巧巷幸広庚康弘恒慌抗拘控攻昂晃更杭校梗構江洪浩港溝甲皇硬稿糠紅紘絞綱耕考肯肱腔膏航荒行衡講貢購郊酵鉱砿鋼閤降項香高鴻剛劫号合壕拷濠豪轟麹克刻告国穀酷鵠黒獄漉腰甑忽惚骨狛込"],
        ["baa1", "此頃今困坤墾婚恨懇昏昆根梱混痕紺艮魂些佐叉唆嵯左差査沙瑳砂詐鎖裟坐座挫債催再最哉塞妻宰彩才採栽歳済災采犀砕砦祭斎細菜裁載際剤在材罪財冴坂阪堺榊肴咲崎埼碕鷺作削咋搾昨朔柵窄策索錯桜鮭笹匙冊刷"],
        ["bba1", "察拶撮擦札殺薩雑皐鯖捌錆鮫皿晒三傘参山惨撒散桟燦珊産算纂蚕讃賛酸餐斬暫残仕仔伺使刺司史嗣四士始姉姿子屍市師志思指支孜斯施旨枝止死氏獅祉私糸紙紫肢脂至視詞詩試誌諮資賜雌飼歯事似侍児字寺慈持時"],
        ["bca1", "次滋治爾璽痔磁示而耳自蒔辞汐鹿式識鴫竺軸宍雫七叱執失嫉室悉湿漆疾質実蔀篠偲柴芝屡蕊縞舎写射捨赦斜煮社紗者謝車遮蛇邪借勺尺杓灼爵酌釈錫若寂弱惹主取守手朱殊狩珠種腫趣酒首儒受呪寿授樹綬需囚収周"],
        ["bda1", "宗就州修愁拾洲秀秋終繍習臭舟蒐衆襲讐蹴輯週酋酬集醜什住充十従戎柔汁渋獣縦重銃叔夙宿淑祝縮粛塾熟出術述俊峻春瞬竣舜駿准循旬楯殉淳準潤盾純巡遵醇順処初所暑曙渚庶緒署書薯藷諸助叙女序徐恕鋤除傷償"],
        ["bea1", "勝匠升召哨商唱嘗奨妾娼宵将小少尚庄床廠彰承抄招掌捷昇昌昭晶松梢樟樵沼消渉湘焼焦照症省硝礁祥称章笑粧紹肖菖蒋蕉衝裳訟証詔詳象賞醤鉦鍾鐘障鞘上丈丞乗冗剰城場壌嬢常情擾条杖浄状畳穣蒸譲醸錠嘱埴飾"],
        ["bfa1", "拭植殖燭織職色触食蝕辱尻伸信侵唇娠寝審心慎振新晋森榛浸深申疹真神秦紳臣芯薪親診身辛進針震人仁刃塵壬尋甚尽腎訊迅陣靭笥諏須酢図厨逗吹垂帥推水炊睡粋翠衰遂酔錐錘随瑞髄崇嵩数枢趨雛据杉椙菅頗雀裾"],
        ["c0a1", "澄摺寸世瀬畝是凄制勢姓征性成政整星晴棲栖正清牲生盛精聖声製西誠誓請逝醒青静斉税脆隻席惜戚斥昔析石積籍績脊責赤跡蹟碩切拙接摂折設窃節説雪絶舌蝉仙先千占宣専尖川戦扇撰栓栴泉浅洗染潜煎煽旋穿箭線"],
        ["c1a1", "繊羨腺舛船薦詮賎践選遷銭銑閃鮮前善漸然全禅繕膳糎噌塑岨措曾曽楚狙疏疎礎祖租粗素組蘇訴阻遡鼠僧創双叢倉喪壮奏爽宋層匝惣想捜掃挿掻操早曹巣槍槽漕燥争痩相窓糟総綜聡草荘葬蒼藻装走送遭鎗霜騒像増憎"],
        ["c2a1", "臓蔵贈造促側則即息捉束測足速俗属賊族続卒袖其揃存孫尊損村遜他多太汰詑唾堕妥惰打柁舵楕陀駄騨体堆対耐岱帯待怠態戴替泰滞胎腿苔袋貸退逮隊黛鯛代台大第醍題鷹滝瀧卓啄宅托択拓沢濯琢託鐸濁諾茸凧蛸只"],
        ["c3a1", "叩但達辰奪脱巽竪辿棚谷狸鱈樽誰丹単嘆坦担探旦歎淡湛炭短端箪綻耽胆蛋誕鍛団壇弾断暖檀段男談値知地弛恥智池痴稚置致蜘遅馳築畜竹筑蓄逐秩窒茶嫡着中仲宙忠抽昼柱注虫衷註酎鋳駐樗瀦猪苧著貯丁兆凋喋寵"],
        ["c4a1", "帖帳庁弔張彫徴懲挑暢朝潮牒町眺聴脹腸蝶調諜超跳銚長頂鳥勅捗直朕沈珍賃鎮陳津墜椎槌追鎚痛通塚栂掴槻佃漬柘辻蔦綴鍔椿潰坪壷嬬紬爪吊釣鶴亭低停偵剃貞呈堤定帝底庭廷弟悌抵挺提梯汀碇禎程締艇訂諦蹄逓"],
        ["c5a1", "邸鄭釘鼎泥摘擢敵滴的笛適鏑溺哲徹撤轍迭鉄典填天展店添纏甜貼転顛点伝殿澱田電兎吐堵塗妬屠徒斗杜渡登菟賭途都鍍砥砺努度土奴怒倒党冬凍刀唐塔塘套宕島嶋悼投搭東桃梼棟盗淘湯涛灯燈当痘祷等答筒糖統到"],
        ["c6a1", "董蕩藤討謄豆踏逃透鐙陶頭騰闘働動同堂導憧撞洞瞳童胴萄道銅峠鴇匿得徳涜特督禿篤毒独読栃橡凸突椴届鳶苫寅酉瀞噸屯惇敦沌豚遁頓呑曇鈍奈那内乍凪薙謎灘捺鍋楢馴縄畷南楠軟難汝二尼弐迩匂賑肉虹廿日乳入"],
        ["c7a1", "如尿韮任妊忍認濡禰祢寧葱猫熱年念捻撚燃粘乃廼之埜嚢悩濃納能脳膿農覗蚤巴把播覇杷波派琶破婆罵芭馬俳廃拝排敗杯盃牌背肺輩配倍培媒梅楳煤狽買売賠陪這蝿秤矧萩伯剥博拍柏泊白箔粕舶薄迫曝漠爆縛莫駁麦"],
        ["c8a1", "函箱硲箸肇筈櫨幡肌畑畠八鉢溌発醗髪伐罰抜筏閥鳩噺塙蛤隼伴判半反叛帆搬斑板氾汎版犯班畔繁般藩販範釆煩頒飯挽晩番盤磐蕃蛮匪卑否妃庇彼悲扉批披斐比泌疲皮碑秘緋罷肥被誹費避非飛樋簸備尾微枇毘琵眉美"],
        ["c9a1", "鼻柊稗匹疋髭彦膝菱肘弼必畢筆逼桧姫媛紐百謬俵彪標氷漂瓢票表評豹廟描病秒苗錨鋲蒜蛭鰭品彬斌浜瀕貧賓頻敏瓶不付埠夫婦富冨布府怖扶敷斧普浮父符腐膚芙譜負賦赴阜附侮撫武舞葡蕪部封楓風葺蕗伏副復幅服"],
        ["caa1", "福腹複覆淵弗払沸仏物鮒分吻噴墳憤扮焚奮粉糞紛雰文聞丙併兵塀幣平弊柄並蔽閉陛米頁僻壁癖碧別瞥蔑箆偏変片篇編辺返遍便勉娩弁鞭保舗鋪圃捕歩甫補輔穂募墓慕戊暮母簿菩倣俸包呆報奉宝峰峯崩庖抱捧放方朋"],
        ["cba1", "法泡烹砲縫胞芳萌蓬蜂褒訪豊邦鋒飽鳳鵬乏亡傍剖坊妨帽忘忙房暴望某棒冒紡肪膨謀貌貿鉾防吠頬北僕卜墨撲朴牧睦穆釦勃没殆堀幌奔本翻凡盆摩磨魔麻埋妹昧枚毎哩槙幕膜枕鮪柾鱒桝亦俣又抹末沫迄侭繭麿万慢満"],
        ["cca1", "漫蔓味未魅巳箕岬密蜜湊蓑稔脈妙粍民眠務夢無牟矛霧鵡椋婿娘冥名命明盟迷銘鳴姪牝滅免棉綿緬面麺摸模茂妄孟毛猛盲網耗蒙儲木黙目杢勿餅尤戻籾貰問悶紋門匁也冶夜爺耶野弥矢厄役約薬訳躍靖柳薮鑓愉愈油癒"],
        ["cda1", "諭輸唯佑優勇友宥幽悠憂揖有柚湧涌猶猷由祐裕誘遊邑郵雄融夕予余与誉輿預傭幼妖容庸揚揺擁曜楊様洋溶熔用窯羊耀葉蓉要謡踊遥陽養慾抑欲沃浴翌翼淀羅螺裸来莱頼雷洛絡落酪乱卵嵐欄濫藍蘭覧利吏履李梨理璃"],
        ["cea1", "痢裏裡里離陸律率立葎掠略劉流溜琉留硫粒隆竜龍侶慮旅虜了亮僚両凌寮料梁涼猟療瞭稜糧良諒遼量陵領力緑倫厘林淋燐琳臨輪隣鱗麟瑠塁涙累類令伶例冷励嶺怜玲礼苓鈴隷零霊麗齢暦歴列劣烈裂廉恋憐漣煉簾練聯"],
        ["cfa1", "蓮連錬呂魯櫓炉賂路露労婁廊弄朗楼榔浪漏牢狼篭老聾蝋郎六麓禄肋録論倭和話歪賄脇惑枠鷲亙亘鰐詫藁蕨椀湾碗腕"],
        ["d0a1", "弌丐丕个丱丶丼丿乂乖乘亂亅豫亊舒弍于亞亟亠亢亰亳亶从仍仄仆仂仗仞仭仟价伉佚估佛佝佗佇佶侈侏侘佻佩佰侑佯來侖儘俔俟俎俘俛俑俚俐俤俥倚倨倔倪倥倅伜俶倡倩倬俾俯們倆偃假會偕偐偈做偖偬偸傀傚傅傴傲"],
        ["d1a1", "僉僊傳僂僖僞僥僭僣僮價僵儉儁儂儖儕儔儚儡儺儷儼儻儿兀兒兌兔兢竸兩兪兮冀冂囘册冉冏冑冓冕冖冤冦冢冩冪冫决冱冲冰况冽凅凉凛几處凩凭凰凵凾刄刋刔刎刧刪刮刳刹剏剄剋剌剞剔剪剴剩剳剿剽劍劔劒剱劈劑辨"],
        ["d2a1", "辧劬劭劼劵勁勍勗勞勣勦飭勠勳勵勸勹匆匈甸匍匐匏匕匚匣匯匱匳匸區卆卅丗卉卍凖卞卩卮夘卻卷厂厖厠厦厥厮厰厶參簒雙叟曼燮叮叨叭叺吁吽呀听吭吼吮吶吩吝呎咏呵咎呟呱呷呰咒呻咀呶咄咐咆哇咢咸咥咬哄哈咨"],
        ["d3a1", "咫哂咤咾咼哘哥哦唏唔哽哮哭哺哢唹啀啣啌售啜啅啖啗唸唳啝喙喀咯喊喟啻啾喘喞單啼喃喩喇喨嗚嗅嗟嗄嗜嗤嗔嘔嗷嘖嗾嗽嘛嗹噎噐營嘴嘶嘲嘸噫噤嘯噬噪嚆嚀嚊嚠嚔嚏嚥嚮嚶嚴囂嚼囁囃囀囈囎囑囓囗囮囹圀囿圄圉"],
        ["d4a1", "圈國圍圓團圖嗇圜圦圷圸坎圻址坏坩埀垈坡坿垉垓垠垳垤垪垰埃埆埔埒埓堊埖埣堋堙堝塲堡塢塋塰毀塒堽塹墅墹墟墫墺壞墻墸墮壅壓壑壗壙壘壥壜壤壟壯壺壹壻壼壽夂夊夐夛梦夥夬夭夲夸夾竒奕奐奎奚奘奢奠奧奬奩"],
        ["d5a1", "奸妁妝佞侫妣妲姆姨姜妍姙姚娥娟娑娜娉娚婀婬婉娵娶婢婪媚媼媾嫋嫂媽嫣嫗嫦嫩嫖嫺嫻嬌嬋嬖嬲嫐嬪嬶嬾孃孅孀孑孕孚孛孥孩孰孳孵學斈孺宀它宦宸寃寇寉寔寐寤實寢寞寥寫寰寶寳尅將專對尓尠尢尨尸尹屁屆屎屓"],
        ["d6a1", "屐屏孱屬屮乢屶屹岌岑岔妛岫岻岶岼岷峅岾峇峙峩峽峺峭嶌峪崋崕崗嵜崟崛崑崔崢崚崙崘嵌嵒嵎嵋嵬嵳嵶嶇嶄嶂嶢嶝嶬嶮嶽嶐嶷嶼巉巍巓巒巖巛巫已巵帋帚帙帑帛帶帷幄幃幀幎幗幔幟幢幤幇幵并幺麼广庠廁廂廈廐廏"],
        ["d7a1", "廖廣廝廚廛廢廡廨廩廬廱廳廰廴廸廾弃弉彝彜弋弑弖弩弭弸彁彈彌彎弯彑彖彗彙彡彭彳彷徃徂彿徊很徑徇從徙徘徠徨徭徼忖忻忤忸忱忝悳忿怡恠怙怐怩怎怱怛怕怫怦怏怺恚恁恪恷恟恊恆恍恣恃恤恂恬恫恙悁悍惧悃悚"],
        ["d8a1", "悄悛悖悗悒悧悋惡悸惠惓悴忰悽惆悵惘慍愕愆惶惷愀惴惺愃愡惻惱愍愎慇愾愨愧慊愿愼愬愴愽慂慄慳慷慘慙慚慫慴慯慥慱慟慝慓慵憙憖憇憬憔憚憊憑憫憮懌懊應懷懈懃懆憺懋罹懍懦懣懶懺懴懿懽懼懾戀戈戉戍戌戔戛"],
        ["d9a1", "戞戡截戮戰戲戳扁扎扞扣扛扠扨扼抂抉找抒抓抖拔抃抔拗拑抻拏拿拆擔拈拜拌拊拂拇抛拉挌拮拱挧挂挈拯拵捐挾捍搜捏掖掎掀掫捶掣掏掉掟掵捫捩掾揩揀揆揣揉插揶揄搖搴搆搓搦搶攝搗搨搏摧摯摶摎攪撕撓撥撩撈撼"],
        ["daa1", "據擒擅擇撻擘擂擱擧舉擠擡抬擣擯攬擶擴擲擺攀擽攘攜攅攤攣攫攴攵攷收攸畋效敖敕敍敘敞敝敲數斂斃變斛斟斫斷旃旆旁旄旌旒旛旙无旡旱杲昊昃旻杳昵昶昴昜晏晄晉晁晞晝晤晧晨晟晢晰暃暈暎暉暄暘暝曁暹曉暾暼"],
        ["dba1", "曄暸曖曚曠昿曦曩曰曵曷朏朖朞朦朧霸朮朿朶杁朸朷杆杞杠杙杣杤枉杰枩杼杪枌枋枦枡枅枷柯枴柬枳柩枸柤柞柝柢柮枹柎柆柧檜栞框栩桀桍栲桎梳栫桙档桷桿梟梏梭梔條梛梃檮梹桴梵梠梺椏梍桾椁棊椈棘椢椦棡椌棍"],
        ["dca1", "棔棧棕椶椒椄棗棣椥棹棠棯椨椪椚椣椡棆楹楷楜楸楫楔楾楮椹楴椽楙椰楡楞楝榁楪榲榮槐榿槁槓榾槎寨槊槝榻槃榧樮榑榠榜榕榴槞槨樂樛槿權槹槲槧樅榱樞槭樔槫樊樒櫁樣樓橄樌橲樶橸橇橢橙橦橈樸樢檐檍檠檄檢檣"],
        ["dda1", "檗蘗檻櫃櫂檸檳檬櫞櫑櫟檪櫚櫪櫻欅蘖櫺欒欖鬱欟欸欷盜欹飮歇歃歉歐歙歔歛歟歡歸歹歿殀殄殃殍殘殕殞殤殪殫殯殲殱殳殷殼毆毋毓毟毬毫毳毯麾氈氓气氛氤氣汞汕汢汪沂沍沚沁沛汾汨汳沒沐泄泱泓沽泗泅泝沮沱沾"],
        ["dea1", "沺泛泯泙泪洟衍洶洫洽洸洙洵洳洒洌浣涓浤浚浹浙涎涕濤涅淹渕渊涵淇淦涸淆淬淞淌淨淒淅淺淙淤淕淪淮渭湮渮渙湲湟渾渣湫渫湶湍渟湃渺湎渤滿渝游溂溪溘滉溷滓溽溯滄溲滔滕溏溥滂溟潁漑灌滬滸滾漿滲漱滯漲滌"],
        ["dfa1", "漾漓滷澆潺潸澁澀潯潛濳潭澂潼潘澎澑濂潦澳澣澡澤澹濆澪濟濕濬濔濘濱濮濛瀉瀋濺瀑瀁瀏濾瀛瀚潴瀝瀘瀟瀰瀾瀲灑灣炙炒炯烱炬炸炳炮烟烋烝烙焉烽焜焙煥煕熈煦煢煌煖煬熏燻熄熕熨熬燗熹熾燒燉燔燎燠燬燧燵燼"],
        ["e0a1", "燹燿爍爐爛爨爭爬爰爲爻爼爿牀牆牋牘牴牾犂犁犇犒犖犢犧犹犲狃狆狄狎狒狢狠狡狹狷倏猗猊猜猖猝猴猯猩猥猾獎獏默獗獪獨獰獸獵獻獺珈玳珎玻珀珥珮珞璢琅瑯琥珸琲琺瑕琿瑟瑙瑁瑜瑩瑰瑣瑪瑶瑾璋璞璧瓊瓏瓔珱"],
        ["e1a1", "瓠瓣瓧瓩瓮瓲瓰瓱瓸瓷甄甃甅甌甎甍甕甓甞甦甬甼畄畍畊畉畛畆畚畩畤畧畫畭畸當疆疇畴疊疉疂疔疚疝疥疣痂疳痃疵疽疸疼疱痍痊痒痙痣痞痾痿痼瘁痰痺痲痳瘋瘍瘉瘟瘧瘠瘡瘢瘤瘴瘰瘻癇癈癆癜癘癡癢癨癩癪癧癬癰"],
        ["e2a1", "癲癶癸發皀皃皈皋皎皖皓皙皚皰皴皸皹皺盂盍盖盒盞盡盥盧盪蘯盻眈眇眄眩眤眞眥眦眛眷眸睇睚睨睫睛睥睿睾睹瞎瞋瞑瞠瞞瞰瞶瞹瞿瞼瞽瞻矇矍矗矚矜矣矮矼砌砒礦砠礪硅碎硴碆硼碚碌碣碵碪碯磑磆磋磔碾碼磅磊磬"],
        ["e3a1", "磧磚磽磴礇礒礑礙礬礫祀祠祗祟祚祕祓祺祿禊禝禧齋禪禮禳禹禺秉秕秧秬秡秣稈稍稘稙稠稟禀稱稻稾稷穃穗穉穡穢穩龝穰穹穽窈窗窕窘窖窩竈窰窶竅竄窿邃竇竊竍竏竕竓站竚竝竡竢竦竭竰笂笏笊笆笳笘笙笞笵笨笶筐"],
        ["e4a1", "筺笄筍笋筌筅筵筥筴筧筰筱筬筮箝箘箟箍箜箚箋箒箏筝箙篋篁篌篏箴篆篝篩簑簔篦篥籠簀簇簓篳篷簗簍篶簣簧簪簟簷簫簽籌籃籔籏籀籐籘籟籤籖籥籬籵粃粐粤粭粢粫粡粨粳粲粱粮粹粽糀糅糂糘糒糜糢鬻糯糲糴糶糺紆"],
        ["e5a1", "紂紜紕紊絅絋紮紲紿紵絆絳絖絎絲絨絮絏絣經綉絛綏絽綛綺綮綣綵緇綽綫總綢綯緜綸綟綰緘緝緤緞緻緲緡縅縊縣縡縒縱縟縉縋縢繆繦縻縵縹繃縷縲縺繧繝繖繞繙繚繹繪繩繼繻纃緕繽辮繿纈纉續纒纐纓纔纖纎纛纜缸缺"],
        ["e6a1", "罅罌罍罎罐网罕罔罘罟罠罨罩罧罸羂羆羃羈羇羌羔羞羝羚羣羯羲羹羮羶羸譱翅翆翊翕翔翡翦翩翳翹飜耆耄耋耒耘耙耜耡耨耿耻聊聆聒聘聚聟聢聨聳聲聰聶聹聽聿肄肆肅肛肓肚肭冐肬胛胥胙胝胄胚胖脉胯胱脛脩脣脯腋"],
        ["e7a1", "隋腆脾腓腑胼腱腮腥腦腴膃膈膊膀膂膠膕膤膣腟膓膩膰膵膾膸膽臀臂膺臉臍臑臙臘臈臚臟臠臧臺臻臾舁舂舅與舊舍舐舖舩舫舸舳艀艙艘艝艚艟艤艢艨艪艫舮艱艷艸艾芍芒芫芟芻芬苡苣苟苒苴苳苺莓范苻苹苞茆苜茉苙"],
        ["e8a1", "茵茴茖茲茱荀茹荐荅茯茫茗茘莅莚莪莟莢莖茣莎莇莊荼莵荳荵莠莉莨菴萓菫菎菽萃菘萋菁菷萇菠菲萍萢萠莽萸蔆菻葭萪萼蕚蒄葷葫蒭葮蒂葩葆萬葯葹萵蓊葢蒹蒿蒟蓙蓍蒻蓚蓐蓁蓆蓖蒡蔡蓿蓴蔗蔘蔬蔟蔕蔔蓼蕀蕣蕘蕈"],
        ["e9a1", "蕁蘂蕋蕕薀薤薈薑薊薨蕭薔薛藪薇薜蕷蕾薐藉薺藏薹藐藕藝藥藜藹蘊蘓蘋藾藺蘆蘢蘚蘰蘿虍乕虔號虧虱蚓蚣蚩蚪蚋蚌蚶蚯蛄蛆蚰蛉蠣蚫蛔蛞蛩蛬蛟蛛蛯蜒蜆蜈蜀蜃蛻蜑蜉蜍蛹蜊蜴蜿蜷蜻蜥蜩蜚蝠蝟蝸蝌蝎蝴蝗蝨蝮蝙"],
        ["eaa1", "蝓蝣蝪蠅螢螟螂螯蟋螽蟀蟐雖螫蟄螳蟇蟆螻蟯蟲蟠蠏蠍蟾蟶蟷蠎蟒蠑蠖蠕蠢蠡蠱蠶蠹蠧蠻衄衂衒衙衞衢衫袁衾袞衵衽袵衲袂袗袒袮袙袢袍袤袰袿袱裃裄裔裘裙裝裹褂裼裴裨裲褄褌褊褓襃褞褥褪褫襁襄褻褶褸襌褝襠襞"],
        ["eba1", "襦襤襭襪襯襴襷襾覃覈覊覓覘覡覩覦覬覯覲覺覽覿觀觚觜觝觧觴觸訃訖訐訌訛訝訥訶詁詛詒詆詈詼詭詬詢誅誂誄誨誡誑誥誦誚誣諄諍諂諚諫諳諧諤諱謔諠諢諷諞諛謌謇謚諡謖謐謗謠謳鞫謦謫謾謨譁譌譏譎證譖譛譚譫"],
        ["eca1", "譟譬譯譴譽讀讌讎讒讓讖讙讚谺豁谿豈豌豎豐豕豢豬豸豺貂貉貅貊貍貎貔豼貘戝貭貪貽貲貳貮貶賈賁賤賣賚賽賺賻贄贅贊贇贏贍贐齎贓賍贔贖赧赭赱赳趁趙跂趾趺跏跚跖跌跛跋跪跫跟跣跼踈踉跿踝踞踐踟蹂踵踰踴蹊"],
        ["eda1", "蹇蹉蹌蹐蹈蹙蹤蹠踪蹣蹕蹶蹲蹼躁躇躅躄躋躊躓躑躔躙躪躡躬躰軆躱躾軅軈軋軛軣軼軻軫軾輊輅輕輒輙輓輜輟輛輌輦輳輻輹轅轂輾轌轉轆轎轗轜轢轣轤辜辟辣辭辯辷迚迥迢迪迯邇迴逅迹迺逑逕逡逍逞逖逋逧逶逵逹迸"],
        ["eea1", "遏遐遑遒逎遉逾遖遘遞遨遯遶隨遲邂遽邁邀邊邉邏邨邯邱邵郢郤扈郛鄂鄒鄙鄲鄰酊酖酘酣酥酩酳酲醋醉醂醢醫醯醪醵醴醺釀釁釉釋釐釖釟釡釛釼釵釶鈞釿鈔鈬鈕鈑鉞鉗鉅鉉鉤鉈銕鈿鉋鉐銜銖銓銛鉚鋏銹銷鋩錏鋺鍄錮"],
        ["efa1", "錙錢錚錣錺錵錻鍜鍠鍼鍮鍖鎰鎬鎭鎔鎹鏖鏗鏨鏥鏘鏃鏝鏐鏈鏤鐚鐔鐓鐃鐇鐐鐶鐫鐵鐡鐺鑁鑒鑄鑛鑠鑢鑞鑪鈩鑰鑵鑷鑽鑚鑼鑾钁鑿閂閇閊閔閖閘閙閠閨閧閭閼閻閹閾闊濶闃闍闌闕闔闖關闡闥闢阡阨阮阯陂陌陏陋陷陜陞"],
        ["f0a1", "陝陟陦陲陬隍隘隕隗險隧隱隲隰隴隶隸隹雎雋雉雍襍雜霍雕雹霄霆霈霓霎霑霏霖霙霤霪霰霹霽霾靄靆靈靂靉靜靠靤靦靨勒靫靱靹鞅靼鞁靺鞆鞋鞏鞐鞜鞨鞦鞣鞳鞴韃韆韈韋韜韭齏韲竟韶韵頏頌頸頤頡頷頽顆顏顋顫顯顰"],
        ["f1a1", "顱顴顳颪颯颱颶飄飃飆飩飫餃餉餒餔餘餡餝餞餤餠餬餮餽餾饂饉饅饐饋饑饒饌饕馗馘馥馭馮馼駟駛駝駘駑駭駮駱駲駻駸騁騏騅駢騙騫騷驅驂驀驃騾驕驍驛驗驟驢驥驤驩驫驪骭骰骼髀髏髑髓體髞髟髢髣髦髯髫髮髴髱髷"],
        ["f2a1", "髻鬆鬘鬚鬟鬢鬣鬥鬧鬨鬩鬪鬮鬯鬲魄魃魏魍魎魑魘魴鮓鮃鮑鮖鮗鮟鮠鮨鮴鯀鯊鮹鯆鯏鯑鯒鯣鯢鯤鯔鯡鰺鯲鯱鯰鰕鰔鰉鰓鰌鰆鰈鰒鰊鰄鰮鰛鰥鰤鰡鰰鱇鰲鱆鰾鱚鱠鱧鱶鱸鳧鳬鳰鴉鴈鳫鴃鴆鴪鴦鶯鴣鴟鵄鴕鴒鵁鴿鴾鵆鵈"],
        ["f3a1", "鵝鵞鵤鵑鵐鵙鵲鶉鶇鶫鵯鵺鶚鶤鶩鶲鷄鷁鶻鶸鶺鷆鷏鷂鷙鷓鷸鷦鷭鷯鷽鸚鸛鸞鹵鹹鹽麁麈麋麌麒麕麑麝麥麩麸麪麭靡黌黎黏黐黔黜點黝黠黥黨黯黴黶黷黹黻黼黽鼇鼈皷鼕鼡鼬鼾齊齒齔齣齟齠齡齦齧齬齪齷齲齶龕龜龠"],
        ["f4a1", "堯槇遙瑤凜熙"],
        ["f9a1", "纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德"],
        ["faa1", "忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱"],
        ["fba1", "犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚"],
        ["fca1", "釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"],
        ["fcf1", "ⅰ", 9, "￢￤＇＂"],
        ["8fa2af", "˘ˇ¸˙˝¯˛˚～΄΅"],
        ["8fa2c2", "¡¦¿"],
        ["8fa2eb", "ºª©®™¤№"],
        ["8fa6e1", "ΆΈΉΊΪ"],
        ["8fa6e7", "Ό"],
        ["8fa6e9", "ΎΫ"],
        ["8fa6ec", "Ώ"],
        ["8fa6f1", "άέήίϊΐόςύϋΰώ"],
        ["8fa7c2", "Ђ", 10, "ЎЏ"],
        ["8fa7f2", "ђ", 10, "ўџ"],
        ["8fa9a1", "ÆĐ"],
        ["8fa9a4", "Ħ"],
        ["8fa9a6", "Ĳ"],
        ["8fa9a8", "ŁĿ"],
        ["8fa9ab", "ŊØŒ"],
        ["8fa9af", "ŦÞ"],
        ["8fa9c1", "æđðħıĳĸłŀŉŋøœßŧþ"],
        ["8faaa1", "ÁÀÄÂĂǍĀĄÅÃĆĈČÇĊĎÉÈËÊĚĖĒĘ"],
        ["8faaba", "ĜĞĢĠĤÍÌÏÎǏİĪĮĨĴĶĹĽĻŃŇŅÑÓÒÖÔǑŐŌÕŔŘŖŚŜŠŞŤŢÚÙÜÛŬǓŰŪŲŮŨǗǛǙǕŴÝŸŶŹŽŻ"],
        ["8faba1", "áàäâăǎāąåãćĉčçċďéèëêěėēęǵĝğ"],
        ["8fabbd", "ġĥíìïîǐ"],
        ["8fabc5", "īįĩĵķĺľļńňņñóòöôǒőōõŕřŗśŝšşťţúùüûŭǔűūųůũǘǜǚǖŵýÿŷźžż"],
        ["8fb0a1", "丂丄丅丌丒丟丣两丨丫丮丯丰丵乀乁乄乇乑乚乜乣乨乩乴乵乹乿亍亖亗亝亯亹仃仐仚仛仠仡仢仨仯仱仳仵份仾仿伀伂伃伈伋伌伒伕伖众伙伮伱你伳伵伷伹伻伾佀佂佈佉佋佌佒佔佖佘佟佣佪佬佮佱佷佸佹佺佽佾侁侂侄"],
        ["8fb1a1", "侅侉侊侌侎侐侒侓侔侗侙侚侞侟侲侷侹侻侼侽侾俀俁俅俆俈俉俋俌俍俏俒俜俠俢俰俲俼俽俿倀倁倄倇倊倌倎倐倓倗倘倛倜倝倞倢倧倮倰倲倳倵偀偁偂偅偆偊偌偎偑偒偓偗偙偟偠偢偣偦偧偪偭偰偱倻傁傃傄傆傊傎傏傐"],
        ["8fb2a1", "傒傓傔傖傛傜傞", 4, "傪傯傰傹傺傽僀僃僄僇僌僎僐僓僔僘僜僝僟僢僤僦僨僩僯僱僶僺僾儃儆儇儈儋儌儍儎僲儐儗儙儛儜儝儞儣儧儨儬儭儯儱儳儴儵儸儹兂兊兏兓兕兗兘兟兤兦兾冃冄冋冎冘冝冡冣冭冸冺冼冾冿凂"],
        ["8fb3a1", "凈减凑凒凓凕凘凞凢凥凮凲凳凴凷刁刂刅划刓刕刖刘刢刨刱刲刵刼剅剉剕剗剘剚剜剟剠剡剦剮剷剸剹劀劂劅劊劌劓劕劖劗劘劚劜劤劥劦劧劯劰劶劷劸劺劻劽勀勄勆勈勌勏勑勔勖勛勜勡勥勨勩勪勬勰勱勴勶勷匀匃匊匋"],
        ["8fb4a1", "匌匑匓匘匛匜匞匟匥匧匨匩匫匬匭匰匲匵匼匽匾卂卌卋卙卛卡卣卥卬卭卲卹卾厃厇厈厎厓厔厙厝厡厤厪厫厯厲厴厵厷厸厺厽叀叅叏叒叓叕叚叝叞叠另叧叵吂吓吚吡吧吨吪启吱吴吵呃呄呇呍呏呞呢呤呦呧呩呫呭呮呴呿"],
        ["8fb5a1", "咁咃咅咈咉咍咑咕咖咜咟咡咦咧咩咪咭咮咱咷咹咺咻咿哆哊响哎哠哪哬哯哶哼哾哿唀唁唅唈唉唌唍唎唕唪唫唲唵唶唻唼唽啁啇啉啊啍啐啑啘啚啛啞啠啡啤啦啿喁喂喆喈喎喏喑喒喓喔喗喣喤喭喲喿嗁嗃嗆嗉嗋嗌嗎嗑嗒"],
        ["8fb6a1", "嗓嗗嗘嗛嗞嗢嗩嗶嗿嘅嘈嘊嘍", 5, "嘙嘬嘰嘳嘵嘷嘹嘻嘼嘽嘿噀噁噃噄噆噉噋噍噏噔噞噠噡噢噣噦噩噭噯噱噲噵嚄嚅嚈嚋嚌嚕嚙嚚嚝嚞嚟嚦嚧嚨嚩嚫嚬嚭嚱嚳嚷嚾囅囉囊囋囏囐囌囍囙囜囝囟囡囤", 4, "囱囫园"],
        ["8fb7a1", "囶囷圁圂圇圊圌圑圕圚圛圝圠圢圣圤圥圩圪圬圮圯圳圴圽圾圿坅坆坌坍坒坢坥坧坨坫坭", 4, "坳坴坵坷坹坺坻坼坾垁垃垌垔垗垙垚垜垝垞垟垡垕垧垨垩垬垸垽埇埈埌埏埕埝埞埤埦埧埩埭埰埵埶埸埽埾埿堃堄堈堉埡"],
        ["8fb8a1", "堌堍堛堞堟堠堦堧堭堲堹堿塉塌塍塏塐塕塟塡塤塧塨塸塼塿墀墁墇墈墉墊墌墍墏墐墔墖墝墠墡墢墦墩墱墲壄墼壂壈壍壎壐壒壔壖壚壝壡壢壩壳夅夆夋夌夒夓夔虁夝夡夣夤夨夯夰夳夵夶夿奃奆奒奓奙奛奝奞奟奡奣奫奭"],
        ["8fb9a1", "奯奲奵奶她奻奼妋妌妎妒妕妗妟妤妧妭妮妯妰妳妷妺妼姁姃姄姈姊姍姒姝姞姟姣姤姧姮姯姱姲姴姷娀娄娌娍娎娒娓娞娣娤娧娨娪娭娰婄婅婇婈婌婐婕婞婣婥婧婭婷婺婻婾媋媐媓媖媙媜媞媟媠媢媧媬媱媲媳媵媸媺媻媿"],
        ["8fbaa1", "嫄嫆嫈嫏嫚嫜嫠嫥嫪嫮嫵嫶嫽嬀嬁嬈嬗嬴嬙嬛嬝嬡嬥嬭嬸孁孋孌孒孖孞孨孮孯孼孽孾孿宁宄宆宊宎宐宑宓宔宖宨宩宬宭宯宱宲宷宺宼寀寁寍寏寖", 4, "寠寯寱寴寽尌尗尞尟尣尦尩尫尬尮尰尲尵尶屙屚屜屢屣屧屨屩"],
        ["8fbba1", "屭屰屴屵屺屻屼屽岇岈岊岏岒岝岟岠岢岣岦岪岲岴岵岺峉峋峒峝峗峮峱峲峴崁崆崍崒崫崣崤崦崧崱崴崹崽崿嵂嵃嵆嵈嵕嵑嵙嵊嵟嵠嵡嵢嵤嵪嵭嵰嵹嵺嵾嵿嶁嶃嶈嶊嶒嶓嶔嶕嶙嶛嶟嶠嶧嶫嶰嶴嶸嶹巃巇巋巐巎巘巙巠巤"],
        ["8fbca1", "巩巸巹帀帇帍帒帔帕帘帟帠帮帨帲帵帾幋幐幉幑幖幘幛幜幞幨幪", 4, "幰庀庋庎庢庤庥庨庪庬庱庳庽庾庿廆廌廋廎廑廒廔廕廜廞廥廫异弆弇弈弎弙弜弝弡弢弣弤弨弫弬弮弰弴弶弻弽弿彀彄彅彇彍彐彔彘彛彠彣彤彧"],
        ["8fbda1", "彯彲彴彵彸彺彽彾徉徍徏徖徜徝徢徧徫徤徬徯徰徱徸忄忇忈忉忋忐", 4, "忞忡忢忨忩忪忬忭忮忯忲忳忶忺忼怇怊怍怓怔怗怘怚怟怤怭怳怵恀恇恈恉恌恑恔恖恗恝恡恧恱恾恿悂悆悈悊悎悑悓悕悘悝悞悢悤悥您悰悱悷"],
        ["8fbea1", "悻悾惂惄惈惉惊惋惎惏惔惕惙惛惝惞惢惥惲惵惸惼惽愂愇愊愌愐", 4, "愖愗愙愜愞愢愪愫愰愱愵愶愷愹慁慅慆慉慞慠慬慲慸慻慼慿憀憁憃憄憋憍憒憓憗憘憜憝憟憠憥憨憪憭憸憹憼懀懁懂懎懏懕懜懝懞懟懡懢懧懩懥"],
        ["8fbfa1", "懬懭懯戁戃戄戇戓戕戜戠戢戣戧戩戫戹戽扂扃扄扆扌扐扑扒扔扖扚扜扤扭扯扳扺扽抍抎抏抐抦抨抳抶抷抺抾抿拄拎拕拖拚拪拲拴拼拽挃挄挊挋挍挐挓挖挘挩挪挭挵挶挹挼捁捂捃捄捆捊捋捎捒捓捔捘捛捥捦捬捭捱捴捵"],
        ["8fc0a1", "捸捼捽捿掂掄掇掊掐掔掕掙掚掞掤掦掭掮掯掽揁揅揈揎揑揓揔揕揜揠揥揪揬揲揳揵揸揹搉搊搐搒搔搘搞搠搢搤搥搩搪搯搰搵搽搿摋摏摑摒摓摔摚摛摜摝摟摠摡摣摭摳摴摻摽撅撇撏撐撑撘撙撛撝撟撡撣撦撨撬撳撽撾撿"],
        ["8fc1a1", "擄擉擊擋擌擎擐擑擕擗擤擥擩擪擭擰擵擷擻擿攁攄攈攉攊攏攓攔攖攙攛攞攟攢攦攩攮攱攺攼攽敃敇敉敐敒敔敟敠敧敫敺敽斁斅斊斒斕斘斝斠斣斦斮斲斳斴斿旂旈旉旎旐旔旖旘旟旰旲旴旵旹旾旿昀昄昈昉昍昑昒昕昖昝"],
        ["8fc2a1", "昞昡昢昣昤昦昩昪昫昬昮昰昱昳昹昷晀晅晆晊晌晑晎晗晘晙晛晜晠晡曻晪晫晬晾晳晵晿晷晸晹晻暀晼暋暌暍暐暒暙暚暛暜暟暠暤暭暱暲暵暻暿曀曂曃曈曌曎曏曔曛曟曨曫曬曮曺朅朇朎朓朙朜朠朢朳朾杅杇杈杌杔杕杝"],
        ["8fc3a1", "杦杬杮杴杶杻极构枎枏枑枓枖枘枙枛枰枱枲枵枻枼枽柹柀柂柃柅柈柉柒柗柙柜柡柦柰柲柶柷桒栔栙栝栟栨栧栬栭栯栰栱栳栻栿桄桅桊桌桕桗桘桛桫桮", 4, "桵桹桺桻桼梂梄梆梈梖梘梚梜梡梣梥梩梪梮梲梻棅棈棌棏"],
        ["8fc4a1", "棐棑棓棖棙棜棝棥棨棪棫棬棭棰棱棵棶棻棼棽椆椉椊椐椑椓椖椗椱椳椵椸椻楂楅楉楎楗楛楣楤楥楦楨楩楬楰楱楲楺楻楿榀榍榒榖榘榡榥榦榨榫榭榯榷榸榺榼槅槈槑槖槗槢槥槮槯槱槳槵槾樀樁樃樏樑樕樚樝樠樤樨樰樲"],
        ["8fc5a1", "樴樷樻樾樿橅橆橉橊橎橐橑橒橕橖橛橤橧橪橱橳橾檁檃檆檇檉檋檑檛檝檞檟檥檫檯檰檱檴檽檾檿櫆櫉櫈櫌櫐櫔櫕櫖櫜櫝櫤櫧櫬櫰櫱櫲櫼櫽欂欃欆欇欉欏欐欑欗欛欞欤欨欫欬欯欵欶欻欿歆歊歍歒歖歘歝歠歧歫歮歰歵歽"],
        ["8fc6a1", "歾殂殅殗殛殟殠殢殣殨殩殬殭殮殰殸殹殽殾毃毄毉毌毖毚毡毣毦毧毮毱毷毹毿氂氄氅氉氍氎氐氒氙氟氦氧氨氬氮氳氵氶氺氻氿汊汋汍汏汒汔汙汛汜汫汭汯汴汶汸汹汻沅沆沇沉沔沕沗沘沜沟沰沲沴泂泆泍泏泐泑泒泔泖"],
        ["8fc7a1", "泚泜泠泧泩泫泬泮泲泴洄洇洊洎洏洑洓洚洦洧洨汧洮洯洱洹洼洿浗浞浟浡浥浧浯浰浼涂涇涑涒涔涖涗涘涪涬涴涷涹涽涿淄淈淊淎淏淖淛淝淟淠淢淥淩淯淰淴淶淼渀渄渞渢渧渲渶渹渻渼湄湅湈湉湋湏湑湒湓湔湗湜湝湞"],
        ["8fc8a1", "湢湣湨湳湻湽溍溓溙溠溧溭溮溱溳溻溿滀滁滃滇滈滊滍滎滏滫滭滮滹滻滽漄漈漊漌漍漖漘漚漛漦漩漪漯漰漳漶漻漼漭潏潑潒潓潗潙潚潝潞潡潢潨潬潽潾澃澇澈澋澌澍澐澒澓澔澖澚澟澠澥澦澧澨澮澯澰澵澶澼濅濇濈濊"],
        ["8fc9a1", "濚濞濨濩濰濵濹濼濽瀀瀅瀆瀇瀍瀗瀠瀣瀯瀴瀷瀹瀼灃灄灈灉灊灋灔灕灝灞灎灤灥灬灮灵灶灾炁炅炆炔", 4, "炛炤炫炰炱炴炷烊烑烓烔烕烖烘烜烤烺焃", 4, "焋焌焏焞焠焫焭焯焰焱焸煁煅煆煇煊煋煐煒煗煚煜煞煠"],
        ["8fcaa1", "煨煹熀熅熇熌熒熚熛熠熢熯熰熲熳熺熿燀燁燄燋燌燓燖燙燚燜燸燾爀爇爈爉爓爗爚爝爟爤爫爯爴爸爹牁牂牃牅牎牏牐牓牕牖牚牜牞牠牣牨牫牮牯牱牷牸牻牼牿犄犉犍犎犓犛犨犭犮犱犴犾狁狇狉狌狕狖狘狟狥狳狴狺狻"],
        ["8fcba1", "狾猂猄猅猇猋猍猒猓猘猙猞猢猤猧猨猬猱猲猵猺猻猽獃獍獐獒獖獘獝獞獟獠獦獧獩獫獬獮獯獱獷獹獼玀玁玃玅玆玎玐玓玕玗玘玜玞玟玠玢玥玦玪玫玭玵玷玹玼玽玿珅珆珉珋珌珏珒珓珖珙珝珡珣珦珧珩珴珵珷珹珺珻珽"],
        ["8fcca1", "珿琀琁琄琇琊琑琚琛琤琦琨", 9, "琹瑀瑃瑄瑆瑇瑋瑍瑑瑒瑗瑝瑢瑦瑧瑨瑫瑭瑮瑱瑲璀璁璅璆璇璉璏璐璑璒璘璙璚璜璟璠璡璣璦璨璩璪璫璮璯璱璲璵璹璻璿瓈瓉瓌瓐瓓瓘瓚瓛瓞瓟瓤瓨瓪瓫瓯瓴瓺瓻瓼瓿甆"],
        ["8fcda1", "甒甖甗甠甡甤甧甩甪甯甶甹甽甾甿畀畃畇畈畎畐畒畗畞畟畡畯畱畹", 5, "疁疅疐疒疓疕疙疜疢疤疴疺疿痀痁痄痆痌痎痏痗痜痟痠痡痤痧痬痮痯痱痹瘀瘂瘃瘄瘇瘈瘊瘌瘏瘒瘓瘕瘖瘙瘛瘜瘝瘞瘣瘥瘦瘩瘭瘲瘳瘵瘸瘹"],
        ["8fcea1", "瘺瘼癊癀癁癃癄癅癉癋癕癙癟癤癥癭癮癯癱癴皁皅皌皍皕皛皜皝皟皠皢", 6, "皪皭皽盁盅盉盋盌盎盔盙盠盦盨盬盰盱盶盹盼眀眆眊眎眒眔眕眗眙眚眜眢眨眭眮眯眴眵眶眹眽眾睂睅睆睊睍睎睏睒睖睗睜睞睟睠睢"],
        ["8fcfa1", "睤睧睪睬睰睲睳睴睺睽瞀瞄瞌瞍瞔瞕瞖瞚瞟瞢瞧瞪瞮瞯瞱瞵瞾矃矉矑矒矕矙矞矟矠矤矦矪矬矰矱矴矸矻砅砆砉砍砎砑砝砡砢砣砭砮砰砵砷硃硄硇硈硌硎硒硜硞硠硡硣硤硨硪确硺硾碊碏碔碘碡碝碞碟碤碨碬碭碰碱碲碳"],
        ["8fd0a1", "碻碽碿磇磈磉磌磎磒磓磕磖磤磛磟磠磡磦磪磲磳礀磶磷磺磻磿礆礌礐礚礜礞礟礠礥礧礩礭礱礴礵礻礽礿祄祅祆祊祋祏祑祔祘祛祜祧祩祫祲祹祻祼祾禋禌禑禓禔禕禖禘禛禜禡禨禩禫禯禱禴禸离秂秄秇秈秊秏秔秖秚秝秞"],
        ["8fd1a1", "秠秢秥秪秫秭秱秸秼稂稃稇稉稊稌稑稕稛稞稡稧稫稭稯稰稴稵稸稹稺穄穅穇穈穌穕穖穙穜穝穟穠穥穧穪穭穵穸穾窀窂窅窆窊窋窐窑窔窞窠窣窬窳窵窹窻窼竆竉竌竎竑竛竨竩竫竬竱竴竻竽竾笇笔笟笣笧笩笪笫笭笮笯笰"],
        ["8fd2a1", "笱笴笽笿筀筁筇筎筕筠筤筦筩筪筭筯筲筳筷箄箉箎箐箑箖箛箞箠箥箬箯箰箲箵箶箺箻箼箽篂篅篈篊篔篖篗篙篚篛篨篪篲篴篵篸篹篺篼篾簁簂簃簄簆簉簋簌簎簏簙簛簠簥簦簨簬簱簳簴簶簹簺籆籊籕籑籒籓籙", 5],
        ["8fd3a1", "籡籣籧籩籭籮籰籲籹籼籽粆粇粏粔粞粠粦粰粶粷粺粻粼粿糄糇糈糉糍糏糓糔糕糗糙糚糝糦糩糫糵紃紇紈紉紏紑紒紓紖紝紞紣紦紪紭紱紼紽紾絀絁絇絈絍絑絓絗絙絚絜絝絥絧絪絰絸絺絻絿綁綂綃綅綆綈綋綌綍綑綖綗綝"],
        ["8fd4a1", "綞綦綧綪綳綶綷綹緂", 4, "緌緍緎緗緙縀緢緥緦緪緫緭緱緵緶緹緺縈縐縑縕縗縜縝縠縧縨縬縭縯縳縶縿繄繅繇繎繐繒繘繟繡繢繥繫繮繯繳繸繾纁纆纇纊纍纑纕纘纚纝纞缼缻缽缾缿罃罄罇罏罒罓罛罜罝罡罣罤罥罦罭"],
        ["8fd5a1", "罱罽罾罿羀羋羍羏羐羑羖羗羜羡羢羦羪羭羴羼羿翀翃翈翎翏翛翟翣翥翨翬翮翯翲翺翽翾翿耇耈耊耍耎耏耑耓耔耖耝耞耟耠耤耦耬耮耰耴耵耷耹耺耼耾聀聄聠聤聦聭聱聵肁肈肎肜肞肦肧肫肸肹胈胍胏胒胔胕胗胘胠胭胮"],
        ["8fd6a1", "胰胲胳胶胹胺胾脃脋脖脗脘脜脞脠脤脧脬脰脵脺脼腅腇腊腌腒腗腠腡腧腨腩腭腯腷膁膐膄膅膆膋膎膖膘膛膞膢膮膲膴膻臋臃臅臊臎臏臕臗臛臝臞臡臤臫臬臰臱臲臵臶臸臹臽臿舀舃舏舓舔舙舚舝舡舢舨舲舴舺艃艄艅艆"],
        ["8fd7a1", "艋艎艏艑艖艜艠艣艧艭艴艻艽艿芀芁芃芄芇芉芊芎芑芔芖芘芚芛芠芡芣芤芧芨芩芪芮芰芲芴芷芺芼芾芿苆苐苕苚苠苢苤苨苪苭苯苶苷苽苾茀茁茇茈茊茋荔茛茝茞茟茡茢茬茭茮茰茳茷茺茼茽荂荃荄荇荍荎荑荕荖荗荰荸"],
        ["8fd8a1", "荽荿莀莂莄莆莍莒莔莕莘莙莛莜莝莦莧莩莬莾莿菀菇菉菏菐菑菔菝荓菨菪菶菸菹菼萁萆萊萏萑萕萙莭萯萹葅葇葈葊葍葏葑葒葖葘葙葚葜葠葤葥葧葪葰葳葴葶葸葼葽蒁蒅蒒蒓蒕蒞蒦蒨蒩蒪蒯蒱蒴蒺蒽蒾蓀蓂蓇蓈蓌蓏蓓"],
        ["8fd9a1", "蓜蓧蓪蓯蓰蓱蓲蓷蔲蓺蓻蓽蔂蔃蔇蔌蔎蔐蔜蔞蔢蔣蔤蔥蔧蔪蔫蔯蔳蔴蔶蔿蕆蕏", 4, "蕖蕙蕜", 6, "蕤蕫蕯蕹蕺蕻蕽蕿薁薅薆薉薋薌薏薓薘薝薟薠薢薥薧薴薶薷薸薼薽薾薿藂藇藊藋藎薭藘藚藟藠藦藨藭藳藶藼"],
        ["8fdaa1", "藿蘀蘄蘅蘍蘎蘐蘑蘒蘘蘙蘛蘞蘡蘧蘩蘶蘸蘺蘼蘽虀虂虆虒虓虖虗虘虙虝虠", 4, "虩虬虯虵虶虷虺蚍蚑蚖蚘蚚蚜蚡蚦蚧蚨蚭蚱蚳蚴蚵蚷蚸蚹蚿蛀蛁蛃蛅蛑蛒蛕蛗蛚蛜蛠蛣蛥蛧蚈蛺蛼蛽蜄蜅蜇蜋蜎蜏蜐蜓蜔蜙蜞蜟蜡蜣"],
        ["8fdba1", "蜨蜮蜯蜱蜲蜹蜺蜼蜽蜾蝀蝃蝅蝍蝘蝝蝡蝤蝥蝯蝱蝲蝻螃", 6, "螋螌螐螓螕螗螘螙螞螠螣螧螬螭螮螱螵螾螿蟁蟈蟉蟊蟎蟕蟖蟙蟚蟜蟟蟢蟣蟤蟪蟫蟭蟱蟳蟸蟺蟿蠁蠃蠆蠉蠊蠋蠐蠙蠒蠓蠔蠘蠚蠛蠜蠞蠟蠨蠭蠮蠰蠲蠵"],
        ["8fdca1", "蠺蠼衁衃衅衈衉衊衋衎衑衕衖衘衚衜衟衠衤衩衱衹衻袀袘袚袛袜袟袠袨袪袺袽袾裀裊", 4, "裑裒裓裛裞裧裯裰裱裵裷褁褆褍褎褏褕褖褘褙褚褜褠褦褧褨褰褱褲褵褹褺褾襀襂襅襆襉襏襒襗襚襛襜襡襢襣襫襮襰襳襵襺"],
        ["8fdda1", "襻襼襽覉覍覐覔覕覛覜覟覠覥覰覴覵覶覷覼觔", 4, "觥觩觫觭觱觳觶觹觽觿訄訅訇訏訑訒訔訕訞訠訢訤訦訫訬訯訵訷訽訾詀詃詅詇詉詍詎詓詖詗詘詜詝詡詥詧詵詶詷詹詺詻詾詿誀誃誆誋誏誐誒誖誗誙誟誧誩誮誯誳"],
        ["8fdea1", "誶誷誻誾諃諆諈諉諊諑諓諔諕諗諝諟諬諰諴諵諶諼諿謅謆謋謑謜謞謟謊謭謰謷謼譂", 4, "譈譒譓譔譙譍譞譣譭譶譸譹譼譾讁讄讅讋讍讏讔讕讜讞讟谸谹谽谾豅豇豉豋豏豑豓豔豗豘豛豝豙豣豤豦豨豩豭豳豵豶豻豾貆"],
        ["8fdfa1", "貇貋貐貒貓貙貛貜貤貹貺賅賆賉賋賏賖賕賙賝賡賨賬賯賰賲賵賷賸賾賿贁贃贉贒贗贛赥赩赬赮赿趂趄趈趍趐趑趕趞趟趠趦趫趬趯趲趵趷趹趻跀跅跆跇跈跊跎跑跔跕跗跙跤跥跧跬跰趼跱跲跴跽踁踄踅踆踋踑踔踖踠踡踢"],
        ["8fe0a1", "踣踦踧踱踳踶踷踸踹踽蹀蹁蹋蹍蹎蹏蹔蹛蹜蹝蹞蹡蹢蹩蹬蹭蹯蹰蹱蹹蹺蹻躂躃躉躐躒躕躚躛躝躞躢躧躩躭躮躳躵躺躻軀軁軃軄軇軏軑軔軜軨軮軰軱軷軹軺軭輀輂輇輈輏輐輖輗輘輞輠輡輣輥輧輨輬輭輮輴輵輶輷輺轀轁"],
        ["8fe1a1", "轃轇轏轑", 4, "轘轝轞轥辝辠辡辤辥辦辵辶辸达迀迁迆迊迋迍运迒迓迕迠迣迤迨迮迱迵迶迻迾适逄逈逌逘逛逨逩逯逪逬逭逳逴逷逿遃遄遌遛遝遢遦遧遬遰遴遹邅邈邋邌邎邐邕邗邘邙邛邠邡邢邥邰邲邳邴邶邽郌邾郃"],
        ["8fe2a1", "郄郅郇郈郕郗郘郙郜郝郟郥郒郶郫郯郰郴郾郿鄀鄄鄅鄆鄈鄍鄐鄔鄖鄗鄘鄚鄜鄞鄠鄥鄢鄣鄧鄩鄮鄯鄱鄴鄶鄷鄹鄺鄼鄽酃酇酈酏酓酗酙酚酛酡酤酧酭酴酹酺酻醁醃醅醆醊醎醑醓醔醕醘醞醡醦醨醬醭醮醰醱醲醳醶醻醼醽醿"],
        ["8fe3a1", "釂釃釅釓釔釗釙釚釞釤釥釩釪釬", 5, "釷釹釻釽鈀鈁鈄鈅鈆鈇鈉鈊鈌鈐鈒鈓鈖鈘鈜鈝鈣鈤鈥鈦鈨鈮鈯鈰鈳鈵鈶鈸鈹鈺鈼鈾鉀鉂鉃鉆鉇鉊鉍鉎鉏鉑鉘鉙鉜鉝鉠鉡鉥鉧鉨鉩鉮鉯鉰鉵", 4, "鉻鉼鉽鉿銈銉銊銍銎銒銗"],
        ["8fe4a1", "銙銟銠銤銥銧銨銫銯銲銶銸銺銻銼銽銿", 4, "鋅鋆鋇鋈鋋鋌鋍鋎鋐鋓鋕鋗鋘鋙鋜鋝鋟鋠鋡鋣鋥鋧鋨鋬鋮鋰鋹鋻鋿錀錂錈錍錑錔錕錜錝錞錟錡錤錥錧錩錪錳錴錶錷鍇鍈鍉鍐鍑鍒鍕鍗鍘鍚鍞鍤鍥鍧鍩鍪鍭鍯鍰鍱鍳鍴鍶"],
        ["8fe5a1", "鍺鍽鍿鎀鎁鎂鎈鎊鎋鎍鎏鎒鎕鎘鎛鎞鎡鎣鎤鎦鎨鎫鎴鎵鎶鎺鎩鏁鏄鏅鏆鏇鏉", 4, "鏓鏙鏜鏞鏟鏢鏦鏧鏹鏷鏸鏺鏻鏽鐁鐂鐄鐈鐉鐍鐎鐏鐕鐖鐗鐟鐮鐯鐱鐲鐳鐴鐻鐿鐽鑃鑅鑈鑊鑌鑕鑙鑜鑟鑡鑣鑨鑫鑭鑮鑯鑱鑲钄钃镸镹"],
        ["8fe6a1", "镾閄閈閌閍閎閝閞閟閡閦閩閫閬閴閶閺閽閿闆闈闉闋闐闑闒闓闙闚闝闞闟闠闤闦阝阞阢阤阥阦阬阱阳阷阸阹阺阼阽陁陒陔陖陗陘陡陮陴陻陼陾陿隁隂隃隄隉隑隖隚隝隟隤隥隦隩隮隯隳隺雊雒嶲雘雚雝雞雟雩雯雱雺霂"],
        ["8fe7a1", "霃霅霉霚霛霝霡霢霣霨霱霳靁靃靊靎靏靕靗靘靚靛靣靧靪靮靳靶靷靸靻靽靿鞀鞉鞕鞖鞗鞙鞚鞞鞟鞢鞬鞮鞱鞲鞵鞶鞸鞹鞺鞼鞾鞿韁韄韅韇韉韊韌韍韎韐韑韔韗韘韙韝韞韠韛韡韤韯韱韴韷韸韺頇頊頙頍頎頔頖頜頞頠頣頦"],
        ["8fe8a1", "頫頮頯頰頲頳頵頥頾顄顇顊顑顒顓顖顗顙顚顢顣顥顦顪顬颫颭颮颰颴颷颸颺颻颿飂飅飈飌飡飣飥飦飧飪飳飶餂餇餈餑餕餖餗餚餛餜餟餢餦餧餫餱", 4, "餹餺餻餼饀饁饆饇饈饍饎饔饘饙饛饜饞饟饠馛馝馟馦馰馱馲馵"],
        ["8fe9a1", "馹馺馽馿駃駉駓駔駙駚駜駞駧駪駫駬駰駴駵駹駽駾騂騃騄騋騌騐騑騖騞騠騢騣騤騧騭騮騳騵騶騸驇驁驄驊驋驌驎驑驔驖驝骪骬骮骯骲骴骵骶骹骻骾骿髁髃髆髈髎髐髒髕髖髗髛髜髠髤髥髧髩髬髲髳髵髹髺髽髿", 4],
        ["8feaa1", "鬄鬅鬈鬉鬋鬌鬍鬎鬐鬒鬖鬙鬛鬜鬠鬦鬫鬭鬳鬴鬵鬷鬹鬺鬽魈魋魌魕魖魗魛魞魡魣魥魦魨魪", 4, "魳魵魷魸魹魿鮀鮄鮅鮆鮇鮉鮊鮋鮍鮏鮐鮔鮚鮝鮞鮦鮧鮩鮬鮰鮱鮲鮷鮸鮻鮼鮾鮿鯁鯇鯈鯎鯐鯗鯘鯝鯟鯥鯧鯪鯫鯯鯳鯷鯸"],
        ["8feba1", "鯹鯺鯽鯿鰀鰂鰋鰏鰑鰖鰘鰙鰚鰜鰞鰢鰣鰦", 4, "鰱鰵鰶鰷鰽鱁鱃鱄鱅鱉鱊鱎鱏鱐鱓鱔鱖鱘鱛鱝鱞鱟鱣鱩鱪鱜鱫鱨鱮鱰鱲鱵鱷鱻鳦鳲鳷鳹鴋鴂鴑鴗鴘鴜鴝鴞鴯鴰鴲鴳鴴鴺鴼鵅鴽鵂鵃鵇鵊鵓鵔鵟鵣鵢鵥鵩鵪鵫鵰鵶鵷鵻"],
        ["8feca1", "鵼鵾鶃鶄鶆鶊鶍鶎鶒鶓鶕鶖鶗鶘鶡鶪鶬鶮鶱鶵鶹鶼鶿鷃鷇鷉鷊鷔鷕鷖鷗鷚鷞鷟鷠鷥鷧鷩鷫鷮鷰鷳鷴鷾鸊鸂鸇鸎鸐鸑鸒鸕鸖鸙鸜鸝鹺鹻鹼麀麂麃麄麅麇麎麏麖麘麛麞麤麨麬麮麯麰麳麴麵黆黈黋黕黟黤黧黬黭黮黰黱黲黵"],
        ["8feda1", "黸黿鼂鼃鼉鼏鼐鼑鼒鼔鼖鼗鼙鼚鼛鼟鼢鼦鼪鼫鼯鼱鼲鼴鼷鼹鼺鼼鼽鼿齁齃", 4, "齓齕齖齗齘齚齝齞齨齩齭", 4, "齳齵齺齽龏龐龑龒龔龖龗龞龡龢龣龥"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/cp936.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 127, "€"],
        ["8140", "丂丄丅丆丏丒丗丟丠両丣並丩丮丯丱丳丵丷丼乀乁乂乄乆乊乑乕乗乚乛乢乣乤乥乧乨乪", 5, "乲乴", 9, "乿", 6, "亇亊"],
        ["8180", "亐亖亗亙亜亝亞亣亪亯亰亱亴亶亷亸亹亼亽亾仈仌仏仐仒仚仛仜仠仢仦仧仩仭仮仯仱仴仸仹仺仼仾伀伂", 6, "伋伌伒", 4, "伜伝伡伣伨伩伬伭伮伱伳伵伷伹伻伾", 4, "佄佅佇", 5, "佒佔佖佡佢佦佨佪佫佭佮佱佲併佷佸佹佺佽侀侁侂侅來侇侊侌侎侐侒侓侕侖侘侙侚侜侞侟価侢"],
        ["8240", "侤侫侭侰", 4, "侶", 8, "俀俁係俆俇俈俉俋俌俍俒", 4, "俙俛俠俢俤俥俧俫俬俰俲俴俵俶俷俹俻俼俽俿", 11],
        ["8280", "個倎倐們倓倕倖倗倛倝倞倠倢倣値倧倫倯", 10, "倻倽倿偀偁偂偄偅偆偉偊偋偍偐", 4, "偖偗偘偙偛偝", 7, "偦", 5, "偭", 8, "偸偹偺偼偽傁傂傃傄傆傇傉傊傋傌傎", 20, "傤傦傪傫傭", 4, "傳", 6, "傼"],
        ["8340", "傽", 17, "僐", 5, "僗僘僙僛", 10, "僨僩僪僫僯僰僱僲僴僶", 4, "僼", 9, "儈"],
        ["8380", "儉儊儌", 5, "儓", 13, "儢", 28, "兂兇兊兌兎兏児兒兓兗兘兙兛兝", 4, "兣兤兦內兩兪兯兲兺兾兿冃冄円冇冊冋冎冏冐冑冓冔冘冚冝冞冟冡冣冦", 4, "冭冮冴冸冹冺冾冿凁凂凃凅凈凊凍凎凐凒", 5],
        ["8440", "凘凙凚凜凞凟凢凣凥", 5, "凬凮凱凲凴凷凾刄刅刉刋刌刏刐刓刔刕刜刞刟刡刢刣別刦刧刪刬刯刱刲刴刵刼刾剄", 5, "剋剎剏剒剓剕剗剘"],
        ["8480", "剙剚剛剝剟剠剢剣剤剦剨剫剬剭剮剰剱剳", 9, "剾劀劃", 4, "劉", 6, "劑劒劔", 6, "劜劤劥劦劧劮劯劰労", 9, "勀勁勂勄勅勆勈勊勌勍勎勏勑勓勔動勗務", 5, "勠勡勢勣勥", 10, "勱", 7, "勻勼勽匁匂匃匄匇匉匊匋匌匎"],
        ["8540", "匑匒匓匔匘匛匜匞匟匢匤匥匧匨匩匫匬匭匯", 9, "匼匽區卂卄卆卋卌卍卐協単卙卛卝卥卨卪卬卭卲卶卹卻卼卽卾厀厁厃厇厈厊厎厏"],
        ["8580", "厐", 4, "厖厗厙厛厜厞厠厡厤厧厪厫厬厭厯", 6, "厷厸厹厺厼厽厾叀參", 4, "収叏叐叒叓叕叚叜叝叞叡叢叧叴叺叾叿吀吂吅吇吋吔吘吙吚吜吢吤吥吪吰吳吶吷吺吽吿呁呂呄呅呇呉呌呍呎呏呑呚呝", 4, "呣呥呧呩", 7, "呴呹呺呾呿咁咃咅咇咈咉咊咍咑咓咗咘咜咞咟咠咡"],
        ["8640", "咢咥咮咰咲咵咶咷咹咺咼咾哃哅哊哋哖哘哛哠", 4, "哫哬哯哰哱哴", 5, "哻哾唀唂唃唄唅唈唊", 4, "唒唓唕", 5, "唜唝唞唟唡唥唦"],
        ["8680", "唨唩唫唭唲唴唵唶唸唹唺唻唽啀啂啅啇啈啋", 4, "啑啒啓啔啗", 4, "啝啞啟啠啢啣啨啩啫啯", 5, "啹啺啽啿喅喆喌喍喎喐喒喓喕喖喗喚喛喞喠", 6, "喨", 8, "喲喴営喸喺喼喿", 4, "嗆嗇嗈嗊嗋嗎嗏嗐嗕嗗", 4, "嗞嗠嗢嗧嗩嗭嗮嗰嗱嗴嗶嗸", 4, "嗿嘂嘃嘄嘅"],
        ["8740", "嘆嘇嘊嘋嘍嘐", 7, "嘙嘚嘜嘝嘠嘡嘢嘥嘦嘨嘩嘪嘫嘮嘯嘰嘳嘵嘷嘸嘺嘼嘽嘾噀", 11, "噏", 4, "噕噖噚噛噝", 4],
        ["8780", "噣噥噦噧噭噮噯噰噲噳噴噵噷噸噹噺噽", 7, "嚇", 6, "嚐嚑嚒嚔", 14, "嚤", 10, "嚰", 6, "嚸嚹嚺嚻嚽", 12, "囋", 8, "囕囖囘囙囜団囥", 5, "囬囮囯囲図囶囷囸囻囼圀圁圂圅圇國", 6],
        ["8840", "園", 9, "圝圞圠圡圢圤圥圦圧圫圱圲圴", 4, "圼圽圿坁坃坄坅坆坈坉坋坒", 4, "坘坙坢坣坥坧坬坮坰坱坲坴坵坸坹坺坽坾坿垀"],
        ["8880", "垁垇垈垉垊垍", 4, "垔", 6, "垜垝垞垟垥垨垪垬垯垰垱垳垵垶垷垹", 8, "埄", 6, "埌埍埐埑埓埖埗埛埜埞埡埢埣埥", 7, "埮埰埱埲埳埵埶執埻埼埾埿堁堃堄堅堈堉堊堌堎堏堐堒堓堔堖堗堘堚堛堜堝堟堢堣堥", 4, "堫", 4, "報堲堳場堶", 7],
        ["8940", "堾", 5, "塅", 6, "塎塏塐塒塓塕塖塗塙", 4, "塟", 5, "塦", 4, "塭", 16, "塿墂墄墆墇墈墊墋墌"],
        ["8980", "墍", 4, "墔", 4, "墛墜墝墠", 7, "墪", 17, "墽墾墿壀壂壃壄壆", 10, "壒壓壔壖", 13, "壥", 5, "壭壯壱売壴壵壷壸壺", 7, "夃夅夆夈", 4, "夎夐夑夒夓夗夘夛夝夞夠夡夢夣夦夨夬夰夲夳夵夶夻"],
        ["8a40", "夽夾夿奀奃奅奆奊奌奍奐奒奓奙奛", 4, "奡奣奤奦", 12, "奵奷奺奻奼奾奿妀妅妉妋妌妎妏妐妑妔妕妘妚妛妜妝妟妠妡妢妦"],
        ["8a80", "妧妬妭妰妱妳", 5, "妺妼妽妿", 6, "姇姈姉姌姍姎姏姕姖姙姛姞", 4, "姤姦姧姩姪姫姭", 11, "姺姼姽姾娀娂娊娋娍娎娏娐娒娔娕娖娗娙娚娛娝娞娡娢娤娦娧娨娪", 6, "娳娵娷", 4, "娽娾娿婁", 4, "婇婈婋", 9, "婖婗婘婙婛", 5],
        ["8b40", "婡婣婤婥婦婨婩婫", 8, "婸婹婻婼婽婾媀", 17, "媓", 6, "媜", 13, "媫媬"],
        ["8b80", "媭", 4, "媴媶媷媹", 4, "媿嫀嫃", 5, "嫊嫋嫍", 4, "嫓嫕嫗嫙嫚嫛嫝嫞嫟嫢嫤嫥嫧嫨嫪嫬", 4, "嫲", 22, "嬊", 11, "嬘", 25, "嬳嬵嬶嬸", 7, "孁", 6],
        ["8c40", "孈", 7, "孒孖孞孠孡孧孨孫孭孮孯孲孴孶孷學孹孻孼孾孿宂宆宊宍宎宐宑宒宔宖実宧宨宩宬宭宮宯宱宲宷宺宻宼寀寁寃寈寉寊寋寍寎寏"],
        ["8c80", "寑寔", 8, "寠寢寣實寧審", 4, "寯寱", 6, "寽対尀専尃尅將專尋尌對導尐尒尓尗尙尛尞尟尠尡尣尦尨尩尪尫尭尮尯尰尲尳尵尶尷屃屄屆屇屌屍屒屓屔屖屗屘屚屛屜屝屟屢層屧", 6, "屰屲", 6, "屻屼屽屾岀岃", 4, "岉岊岋岎岏岒岓岕岝", 4, "岤", 4],
        ["8d40", "岪岮岯岰岲岴岶岹岺岻岼岾峀峂峃峅", 5, "峌", 5, "峓", 5, "峚", 6, "峢峣峧峩峫峬峮峯峱", 9, "峼", 4],
        ["8d80", "崁崄崅崈", 5, "崏", 4, "崕崗崘崙崚崜崝崟", 4, "崥崨崪崫崬崯", 4, "崵", 7, "崿", 7, "嵈嵉嵍", 10, "嵙嵚嵜嵞", 10, "嵪嵭嵮嵰嵱嵲嵳嵵", 12, "嶃", 21, "嶚嶛嶜嶞嶟嶠"],
        ["8e40", "嶡", 21, "嶸", 12, "巆", 6, "巎", 12, "巜巟巠巣巤巪巬巭"],
        ["8e80", "巰巵巶巸", 4, "巿帀帄帇帉帊帋帍帎帒帓帗帞", 7, "帨", 4, "帯帰帲", 4, "帹帺帾帿幀幁幃幆", 5, "幍", 6, "幖", 4, "幜幝幟幠幣", 14, "幵幷幹幾庁庂広庅庈庉庌庍庎庒庘庛庝庡庢庣庤庨", 4, "庮", 4, "庴庺庻庼庽庿", 6],
        ["8f40", "廆廇廈廋", 5, "廔廕廗廘廙廚廜", 11, "廩廫", 8, "廵廸廹廻廼廽弅弆弇弉弌弍弎弐弒弔弖弙弚弜弝弞弡弢弣弤"],
        ["8f80", "弨弫弬弮弰弲", 6, "弻弽弾弿彁", 14, "彑彔彙彚彛彜彞彟彠彣彥彧彨彫彮彯彲彴彵彶彸彺彽彾彿徃徆徍徎徏徑従徔徖徚徛徝從徟徠徢", 5, "復徫徬徯", 5, "徶徸徹徺徻徾", 4, "忇忈忊忋忎忓忔忕忚忛応忞忟忢忣忥忦忨忩忬忯忰忲忳忴忶忷忹忺忼怇"],
        ["9040", "怈怉怋怌怐怑怓怗怘怚怞怟怢怣怤怬怭怮怰", 4, "怶", 4, "怽怾恀恄", 6, "恌恎恏恑恓恔恖恗恘恛恜恞恟恠恡恥恦恮恱恲恴恵恷恾悀"],
        ["9080", "悁悂悅悆悇悈悊悋悎悏悐悑悓悕悗悘悙悜悞悡悢悤悥悧悩悪悮悰悳悵悶悷悹悺悽", 7, "惇惈惉惌", 4, "惒惓惔惖惗惙惛惞惡", 4, "惪惱惲惵惷惸惻", 4, "愂愃愄愅愇愊愋愌愐", 4, "愖愗愘愙愛愜愝愞愡愢愥愨愩愪愬", 18, "慀", 6],
        ["9140", "慇慉態慍慏慐慒慓慔慖", 6, "慞慟慠慡慣慤慥慦慩", 6, "慱慲慳慴慶慸", 18, "憌憍憏", 4, "憕"],
        ["9180", "憖", 6, "憞", 8, "憪憫憭", 9, "憸", 5, "憿懀懁懃", 4, "應懌", 4, "懓懕", 16, "懧", 13, "懶", 8, "戀", 5, "戇戉戓戔戙戜戝戞戠戣戦戧戨戩戫戭戯戰戱戲戵戶戸", 4, "扂扄扅扆扊"],
        ["9240", "扏扐払扖扗扙扚扜", 6, "扤扥扨扱扲扴扵扷扸扺扻扽抁抂抃抅抆抇抈抋", 5, "抔抙抜抝択抣抦抧抩抪抭抮抯抰抲抳抴抶抷抸抺抾拀拁"],
        ["9280", "拃拋拏拑拕拝拞拠拡拤拪拫拰拲拵拸拹拺拻挀挃挄挅挆挊挋挌挍挏挐挒挓挔挕挗挘挙挜挦挧挩挬挭挮挰挱挳", 5, "挻挼挾挿捀捁捄捇捈捊捑捒捓捔捖", 7, "捠捤捥捦捨捪捫捬捯捰捲捳捴捵捸捹捼捽捾捿掁掃掄掅掆掋掍掑掓掔掕掗掙", 6, "採掤掦掫掯掱掲掵掶掹掻掽掿揀"],
        ["9340", "揁揂揃揅揇揈揊揋揌揑揓揔揕揗", 6, "揟揢揤", 4, "揫揬揮揯揰揱揳揵揷揹揺揻揼揾搃搄搆", 4, "損搎搑搒搕", 5, "搝搟搢搣搤"],
        ["9380", "搥搧搨搩搫搮", 5, "搵", 4, "搻搼搾摀摂摃摉摋", 6, "摓摕摖摗摙", 4, "摟", 7, "摨摪摫摬摮", 9, "摻", 6, "撃撆撈", 8, "撓撔撗撘撚撛撜撝撟", 4, "撥撦撧撨撪撫撯撱撲撳撴撶撹撻撽撾撿擁擃擄擆", 6, "擏擑擓擔擕擖擙據"],
        ["9440", "擛擜擝擟擠擡擣擥擧", 24, "攁", 7, "攊", 7, "攓", 4, "攙", 8],
        ["9480", "攢攣攤攦", 4, "攬攭攰攱攲攳攷攺攼攽敀", 4, "敆敇敊敋敍敎敐敒敓敔敗敘敚敜敟敠敡敤敥敧敨敩敪敭敮敯敱敳敵敶數", 14, "斈斉斊斍斎斏斒斔斕斖斘斚斝斞斠斢斣斦斨斪斬斮斱", 7, "斺斻斾斿旀旂旇旈旉旊旍旐旑旓旔旕旘", 7, "旡旣旤旪旫"],
        ["9540", "旲旳旴旵旸旹旻", 4, "昁昄昅昇昈昉昋昍昐昑昒昖昗昘昚昛昜昞昡昢昣昤昦昩昪昫昬昮昰昲昳昷", 4, "昽昿晀時晄", 6, "晍晎晐晑晘"],
        ["9580", "晙晛晜晝晞晠晢晣晥晧晩", 4, "晱晲晳晵晸晹晻晼晽晿暀暁暃暅暆暈暉暊暋暍暎暏暐暒暓暔暕暘", 4, "暞", 8, "暩", 4, "暯", 4, "暵暶暷暸暺暻暼暽暿", 25, "曚曞", 7, "曧曨曪", 5, "曱曵曶書曺曻曽朁朂會"],
        ["9640", "朄朅朆朇朌朎朏朑朒朓朖朘朙朚朜朞朠", 5, "朧朩朮朰朲朳朶朷朸朹朻朼朾朿杁杄杅杇杊杋杍杒杔杕杗", 4, "杝杢杣杤杦杧杫杬杮東杴杶"],
        ["9680", "杸杹杺杻杽枀枂枃枅枆枈枊枌枍枎枏枑枒枓枔枖枙枛枟枠枡枤枦枩枬枮枱枲枴枹", 7, "柂柅", 9, "柕柖柗柛柟柡柣柤柦柧柨柪柫柭柮柲柵", 7, "柾栁栂栃栄栆栍栐栒栔栕栘", 4, "栞栟栠栢", 6, "栫", 6, "栴栵栶栺栻栿桇桋桍桏桒桖", 5],
        ["9740", "桜桝桞桟桪桬", 7, "桵桸", 8, "梂梄梇", 7, "梐梑梒梔梕梖梘", 9, "梣梤梥梩梪梫梬梮梱梲梴梶梷梸"],
        ["9780", "梹", 6, "棁棃", 5, "棊棌棎棏棐棑棓棔棖棗棙棛", 4, "棡棢棤", 9, "棯棲棳棴棶棷棸棻棽棾棿椀椂椃椄椆", 4, "椌椏椑椓", 11, "椡椢椣椥", 7, "椮椯椱椲椳椵椶椷椸椺椻椼椾楀楁楃", 16, "楕楖楘楙楛楜楟"],
        ["9840", "楡楢楤楥楧楨楩楪楬業楯楰楲", 4, "楺楻楽楾楿榁榃榅榊榋榌榎", 5, "榖榗榙榚榝", 9, "榩榪榬榮榯榰榲榳榵榶榸榹榺榼榽"],
        ["9880", "榾榿槀槂", 7, "構槍槏槑槒槓槕", 5, "槜槝槞槡", 11, "槮槯槰槱槳", 9, "槾樀", 9, "樋", 11, "標", 5, "樠樢", 5, "権樫樬樭樮樰樲樳樴樶", 6, "樿", 4, "橅橆橈", 7, "橑", 6, "橚"],
        ["9940", "橜", 4, "橢橣橤橦", 10, "橲", 6, "橺橻橽橾橿檁檂檃檅", 8, "檏檒", 4, "檘", 7, "檡", 5],
        ["9980", "檧檨檪檭", 114, "欥欦欨", 6],
        ["9a40", "欯欰欱欳欴欵欶欸欻欼欽欿歀歁歂歄歅歈歊歋歍", 11, "歚", 7, "歨歩歫", 13, "歺歽歾歿殀殅殈"],
        ["9a80", "殌殎殏殐殑殔殕殗殘殙殜", 4, "殢", 7, "殫", 7, "殶殸", 6, "毀毃毄毆", 4, "毌毎毐毑毘毚毜", 4, "毢", 7, "毬毭毮毰毱毲毴毶毷毸毺毻毼毾", 6, "氈", 4, "氎氒気氜氝氞氠氣氥氫氬氭氱氳氶氷氹氺氻氼氾氿汃汄汅汈汋", 4, "汑汒汓汖汘"],
        ["9b40", "汙汚汢汣汥汦汧汫", 4, "汱汳汵汷汸決汻汼汿沀沄沇沊沋沍沎沑沒沕沖沗沘沚沜沝沞沠沢沨沬沯沰沴沵沶沷沺泀況泂泃泆泇泈泋泍泎泏泑泒泘"],
        ["9b80", "泙泚泜泝泟泤泦泧泩泬泭泲泴泹泿洀洂洃洅洆洈洉洊洍洏洐洑洓洔洕洖洘洜洝洟", 5, "洦洨洩洬洭洯洰洴洶洷洸洺洿浀浂浄浉浌浐浕浖浗浘浛浝浟浡浢浤浥浧浨浫浬浭浰浱浲浳浵浶浹浺浻浽", 4, "涃涄涆涇涊涋涍涏涐涒涖", 4, "涜涢涥涬涭涰涱涳涴涶涷涹", 5, "淁淂淃淈淉淊"],
        ["9c40", "淍淎淏淐淒淓淔淕淗淚淛淜淟淢淣淥淧淨淩淪淭淯淰淲淴淵淶淸淺淽", 7, "渆渇済渉渋渏渒渓渕渘渙減渜渞渟渢渦渧渨渪測渮渰渱渳渵"],
        ["9c80", "渶渷渹渻", 7, "湅", 7, "湏湐湑湒湕湗湙湚湜湝湞湠", 10, "湬湭湯", 14, "満溁溂溄溇溈溊", 4, "溑", 6, "溙溚溛溝溞溠溡溣溤溦溨溩溫溬溭溮溰溳溵溸溹溼溾溿滀滃滄滅滆滈滉滊滌滍滎滐滒滖滘滙滛滜滝滣滧滪", 5],
        ["9d40", "滰滱滲滳滵滶滷滸滺", 7, "漃漄漅漇漈漊", 4, "漐漑漒漖", 9, "漡漢漣漥漦漧漨漬漮漰漲漴漵漷", 6, "漿潀潁潂"],
        ["9d80", "潃潄潅潈潉潊潌潎", 9, "潙潚潛潝潟潠潡潣潤潥潧", 5, "潯潰潱潳潵潶潷潹潻潽", 6, "澅澆澇澊澋澏", 12, "澝澞澟澠澢", 4, "澨", 10, "澴澵澷澸澺", 5, "濁濃", 5, "濊", 6, "濓", 10, "濟濢濣濤濥"],
        ["9e40", "濦", 7, "濰", 32, "瀒", 7, "瀜", 6, "瀤", 6],
        ["9e80", "瀫", 9, "瀶瀷瀸瀺", 17, "灍灎灐", 13, "灟", 11, "灮灱灲灳灴灷灹灺灻災炁炂炃炄炆炇炈炋炌炍炏炐炑炓炗炘炚炛炞", 12, "炰炲炴炵炶為炾炿烄烅烆烇烉烋", 12, "烚"],
        ["9f40", "烜烝烞烠烡烢烣烥烪烮烰", 6, "烸烺烻烼烾", 10, "焋", 4, "焑焒焔焗焛", 10, "焧", 7, "焲焳焴"],
        ["9f80", "焵焷", 13, "煆煇煈煉煋煍煏", 12, "煝煟", 4, "煥煩", 4, "煯煰煱煴煵煶煷煹煻煼煾", 5, "熅", 4, "熋熌熍熎熐熑熒熓熕熖熗熚", 4, "熡", 6, "熩熪熫熭", 5, "熴熶熷熸熺", 8, "燄", 9, "燏", 4],
        ["a040", "燖", 9, "燡燢燣燤燦燨", 5, "燯", 9, "燺", 11, "爇", 19],
        ["a080", "爛爜爞", 9, "爩爫爭爮爯爲爳爴爺爼爾牀", 6, "牉牊牋牎牏牐牑牓牔牕牗牘牚牜牞牠牣牤牥牨牪牫牬牭牰牱牳牴牶牷牸牻牼牽犂犃犅", 4, "犌犎犐犑犓", 11, "犠", 11, "犮犱犲犳犵犺", 6, "狅狆狇狉狊狋狌狏狑狓狔狕狖狘狚狛"],
        ["a1a1", "　、。·ˉˇ¨〃々—～‖…‘’“”〔〕〈", 7, "〖〗【】±×÷∶∧∨∑∏∪∩∈∷√⊥∥∠⌒⊙∫∮≡≌≈∽∝≠≮≯≤≥∞∵∴♂♀°′″℃＄¤￠￡‰§№☆★○●◎◇◆□■△▲※→←↑↓〓"],
        ["a2a1", "ⅰ", 9],
        ["a2b1", "⒈", 19, "⑴", 19, "①", 9],
        ["a2e5", "㈠", 9],
        ["a2f1", "Ⅰ", 11],
        ["a3a1", "！＂＃￥％", 88, "￣"],
        ["a4a1", "ぁ", 82],
        ["a5a1", "ァ", 85],
        ["a6a1", "Α", 16, "Σ", 6],
        ["a6c1", "α", 16, "σ", 6],
        ["a6e0", "︵︶︹︺︿﹀︽︾﹁﹂﹃﹄"],
        ["a6ee", "︻︼︷︸︱"],
        ["a6f4", "︳︴"],
        ["a7a1", "А", 5, "ЁЖ", 25],
        ["a7d1", "а", 5, "ёж", 25],
        ["a840", "ˊˋ˙–―‥‵℅℉↖↗↘↙∕∟∣≒≦≧⊿═", 35, "▁", 6],
        ["a880", "█", 7, "▓▔▕▼▽◢◣◤◥☉⊕〒〝〞"],
        ["a8a1", "āáǎàēéěèīíǐìōóǒòūúǔùǖǘǚǜüêɑ"],
        ["a8bd", "ńň"],
        ["a8c0", "ɡ"],
        ["a8c5", "ㄅ", 36],
        ["a940", "〡", 8, "㊣㎎㎏㎜㎝㎞㎡㏄㏎㏑㏒㏕︰￢￤"],
        ["a959", "℡㈱"],
        ["a95c", "‐"],
        ["a960", "ー゛゜ヽヾ〆ゝゞ﹉", 9, "﹔﹕﹖﹗﹙", 8],
        ["a980", "﹢", 4, "﹨﹩﹪﹫"],
        ["a996", "〇"],
        ["a9a4", "─", 75],
        ["aa40", "狜狝狟狢", 5, "狪狫狵狶狹狽狾狿猀猂猄", 5, "猋猌猍猏猐猑猒猔猘猙猚猟猠猣猤猦猧猨猭猯猰猲猳猵猶猺猻猼猽獀", 8],
        ["aa80", "獉獊獋獌獎獏獑獓獔獕獖獘", 7, "獡", 10, "獮獰獱"],
        ["ab40", "獲", 11, "獿", 4, "玅玆玈玊玌玍玏玐玒玓玔玕玗玘玙玚玜玝玞玠玡玣", 5, "玪玬玭玱玴玵玶玸玹玼玽玾玿珁珃", 4],
        ["ab80", "珋珌珎珒", 6, "珚珛珜珝珟珡珢珣珤珦珨珪珫珬珮珯珰珱珳", 4],
        ["ac40", "珸", 10, "琄琇琈琋琌琍琎琑", 8, "琜", 5, "琣琤琧琩琫琭琯琱琲琷", 4, "琽琾琿瑀瑂", 11],
        ["ac80", "瑎", 6, "瑖瑘瑝瑠", 12, "瑮瑯瑱", 4, "瑸瑹瑺"],
        ["ad40", "瑻瑼瑽瑿璂璄璅璆璈璉璊璌璍璏璑", 10, "璝璟", 7, "璪", 15, "璻", 12],
        ["ad80", "瓈", 9, "瓓", 8, "瓝瓟瓡瓥瓧", 6, "瓰瓱瓲"],
        ["ae40", "瓳瓵瓸", 6, "甀甁甂甃甅", 7, "甎甐甒甔甕甖甗甛甝甞甠", 4, "甦甧甪甮甴甶甹甼甽甿畁畂畃畄畆畇畉畊畍畐畑畒畓畕畖畗畘"],
        ["ae80", "畝", 7, "畧畨畩畫", 6, "畳畵當畷畺", 4, "疀疁疂疄疅疇"],
        ["af40", "疈疉疊疌疍疎疐疓疕疘疛疜疞疢疦", 4, "疭疶疷疺疻疿痀痁痆痋痌痎痏痐痑痓痗痙痚痜痝痟痠痡痥痩痬痭痮痯痲痳痵痶痷痸痺痻痽痾瘂瘄瘆瘇"],
        ["af80", "瘈瘉瘋瘍瘎瘏瘑瘒瘓瘔瘖瘚瘜瘝瘞瘡瘣瘧瘨瘬瘮瘯瘱瘲瘶瘷瘹瘺瘻瘽癁療癄"],
        ["b040", "癅", 6, "癎", 5, "癕癗", 4, "癝癟癠癡癢癤", 6, "癬癭癮癰", 7, "癹発發癿皀皁皃皅皉皊皌皍皏皐皒皔皕皗皘皚皛"],
        ["b080", "皜", 7, "皥", 8, "皯皰皳皵", 9, "盀盁盃啊阿埃挨哎唉哀皑癌蔼矮艾碍爱隘鞍氨安俺按暗岸胺案肮昂盎凹敖熬翱袄傲奥懊澳芭捌扒叭吧笆八疤巴拔跋靶把耙坝霸罢爸白柏百摆佰败拜稗斑班搬扳般颁板版扮拌伴瓣半办绊邦帮梆榜膀绑棒磅蚌镑傍谤苞胞包褒剥"],
        ["b140", "盄盇盉盋盌盓盕盙盚盜盝盞盠", 4, "盦", 7, "盰盳盵盶盷盺盻盽盿眀眂眃眅眆眊県眎", 10, "眛眜眝眞眡眣眤眥眧眪眫"],
        ["b180", "眬眮眰", 4, "眹眻眽眾眿睂睄睅睆睈", 7, "睒", 7, "睜薄雹保堡饱宝抱报暴豹鲍爆杯碑悲卑北辈背贝钡倍狈备惫焙被奔苯本笨崩绷甭泵蹦迸逼鼻比鄙笔彼碧蓖蔽毕毙毖币庇痹闭敝弊必辟壁臂避陛鞭边编贬扁便变卞辨辩辫遍标彪膘表鳖憋别瘪彬斌濒滨宾摈兵冰柄丙秉饼炳"],
        ["b240", "睝睞睟睠睤睧睩睪睭", 11, "睺睻睼瞁瞂瞃瞆", 5, "瞏瞐瞓", 11, "瞡瞣瞤瞦瞨瞫瞭瞮瞯瞱瞲瞴瞶", 4],
        ["b280", "瞼瞾矀", 12, "矎", 8, "矘矙矚矝", 4, "矤病并玻菠播拨钵波博勃搏铂箔伯帛舶脖膊渤泊驳捕卜哺补埠不布步簿部怖擦猜裁材才财睬踩采彩菜蔡餐参蚕残惭惨灿苍舱仓沧藏操糙槽曹草厕策侧册测层蹭插叉茬茶查碴搽察岔差诧拆柴豺搀掺蝉馋谗缠铲产阐颤昌猖"],
        ["b340", "矦矨矪矯矰矱矲矴矵矷矹矺矻矼砃", 5, "砊砋砎砏砐砓砕砙砛砞砠砡砢砤砨砪砫砮砯砱砲砳砵砶砽砿硁硂硃硄硆硈硉硊硋硍硏硑硓硔硘硙硚"],
        ["b380", "硛硜硞", 11, "硯", 7, "硸硹硺硻硽", 6, "场尝常长偿肠厂敞畅唱倡超抄钞朝嘲潮巢吵炒车扯撤掣彻澈郴臣辰尘晨忱沉陈趁衬撑称城橙成呈乘程惩澄诚承逞骋秤吃痴持匙池迟弛驰耻齿侈尺赤翅斥炽充冲虫崇宠抽酬畴踌稠愁筹仇绸瞅丑臭初出橱厨躇锄雏滁除楚"],
        ["b440", "碄碅碆碈碊碋碏碐碒碔碕碖碙碝碞碠碢碤碦碨", 7, "碵碶碷碸確碻碼碽碿磀磂磃磄磆磇磈磌磍磎磏磑磒磓磖磗磘磚", 9],
        ["b480", "磤磥磦磧磩磪磫磭", 4, "磳磵磶磸磹磻", 5, "礂礃礄礆", 6, "础储矗搐触处揣川穿椽传船喘串疮窗幢床闯创吹炊捶锤垂春椿醇唇淳纯蠢戳绰疵茨磁雌辞慈瓷词此刺赐次聪葱囱匆从丛凑粗醋簇促蹿篡窜摧崔催脆瘁粹淬翠村存寸磋撮搓措挫错搭达答瘩打大呆歹傣戴带殆代贷袋待逮"],
        ["b540", "礍", 5, "礔", 9, "礟", 4, "礥", 14, "礵", 4, "礽礿祂祃祄祅祇祊", 8, "祔祕祘祙祡祣"],
        ["b580", "祤祦祩祪祫祬祮祰", 6, "祹祻", 4, "禂禃禆禇禈禉禋禌禍禎禐禑禒怠耽担丹单郸掸胆旦氮但惮淡诞弹蛋当挡党荡档刀捣蹈倒岛祷导到稻悼道盗德得的蹬灯登等瞪凳邓堤低滴迪敌笛狄涤翟嫡抵底地蒂第帝弟递缔颠掂滇碘点典靛垫电佃甸店惦奠淀殿碉叼雕凋刁掉吊钓调跌爹碟蝶迭谍叠"],
        ["b640", "禓", 6, "禛", 11, "禨", 10, "禴", 4, "禼禿秂秄秅秇秈秊秌秎秏秐秓秔秖秗秙", 5, "秠秡秢秥秨秪"],
        ["b680", "秬秮秱", 6, "秹秺秼秾秿稁稄稅稇稈稉稊稌稏", 4, "稕稖稘稙稛稜丁盯叮钉顶鼎锭定订丢东冬董懂动栋侗恫冻洞兜抖斗陡豆逗痘都督毒犊独读堵睹赌杜镀肚度渡妒端短锻段断缎堆兑队对墩吨蹲敦顿囤钝盾遁掇哆多夺垛躲朵跺舵剁惰堕蛾峨鹅俄额讹娥恶厄扼遏鄂饿恩而儿耳尔饵洱二"],
        ["b740", "稝稟稡稢稤", 14, "稴稵稶稸稺稾穀", 5, "穇", 9, "穒", 4, "穘", 16],
        ["b780", "穩", 6, "穱穲穳穵穻穼穽穾窂窅窇窉窊窋窌窎窏窐窓窔窙窚窛窞窡窢贰发罚筏伐乏阀法珐藩帆番翻樊矾钒繁凡烦反返范贩犯饭泛坊芳方肪房防妨仿访纺放菲非啡飞肥匪诽吠肺废沸费芬酚吩氛分纷坟焚汾粉奋份忿愤粪丰封枫蜂峰锋风疯烽逢冯缝讽奉凤佛否夫敷肤孵扶拂辐幅氟符伏俘服"],
        ["b840", "窣窤窧窩窪窫窮", 4, "窴", 10, "竀", 10, "竌", 9, "竗竘竚竛竜竝竡竢竤竧", 5, "竮竰竱竲竳"],
        ["b880", "竴", 4, "竻竼竾笀笁笂笅笇笉笌笍笎笐笒笓笖笗笘笚笜笝笟笡笢笣笧笩笭浮涪福袱弗甫抚辅俯釜斧脯腑府腐赴副覆赋复傅付阜父腹负富讣附妇缚咐噶嘎该改概钙盖溉干甘杆柑竿肝赶感秆敢赣冈刚钢缸肛纲岗港杠篙皋高膏羔糕搞镐稿告哥歌搁戈鸽胳疙割革葛格蛤阁隔铬个各给根跟耕更庚羹"],
        ["b940", "笯笰笲笴笵笶笷笹笻笽笿", 5, "筆筈筊筍筎筓筕筗筙筜筞筟筡筣", 10, "筯筰筳筴筶筸筺筼筽筿箁箂箃箄箆", 6, "箎箏"],
        ["b980", "箑箒箓箖箘箙箚箛箞箟箠箣箤箥箮箯箰箲箳箵箶箷箹", 7, "篂篃範埂耿梗工攻功恭龚供躬公宫弓巩汞拱贡共钩勾沟苟狗垢构购够辜菇咕箍估沽孤姑鼓古蛊骨谷股故顾固雇刮瓜剐寡挂褂乖拐怪棺关官冠观管馆罐惯灌贯光广逛瑰规圭硅归龟闺轨鬼诡癸桂柜跪贵刽辊滚棍锅郭国果裹过哈"],
        ["ba40", "篅篈築篊篋篍篎篏篐篒篔", 4, "篛篜篞篟篠篢篣篤篧篨篩篫篬篭篯篰篲", 4, "篸篹篺篻篽篿", 7, "簈簉簊簍簎簐", 5, "簗簘簙"],
        ["ba80", "簚", 4, "簠", 5, "簨簩簫", 12, "簹", 5, "籂骸孩海氦亥害骇酣憨邯韩含涵寒函喊罕翰撼捍旱憾悍焊汗汉夯杭航壕嚎豪毫郝好耗号浩呵喝荷菏核禾和何合盒貉阂河涸赫褐鹤贺嘿黑痕很狠恨哼亨横衡恒轰哄烘虹鸿洪宏弘红喉侯猴吼厚候后呼乎忽瑚壶葫胡蝴狐糊湖"],
        ["bb40", "籃", 9, "籎", 36, "籵", 5, "籾", 9],
        ["bb80", "粈粊", 6, "粓粔粖粙粚粛粠粡粣粦粧粨粩粫粬粭粯粰粴", 4, "粺粻弧虎唬护互沪户花哗华猾滑画划化话槐徊怀淮坏欢环桓还缓换患唤痪豢焕涣宦幻荒慌黄磺蝗簧皇凰惶煌晃幌恍谎灰挥辉徽恢蛔回毁悔慧卉惠晦贿秽会烩汇讳诲绘荤昏婚魂浑混豁活伙火获或惑霍货祸击圾基机畸稽积箕"],
        ["bc40", "粿糀糂糃糄糆糉糋糎", 6, "糘糚糛糝糞糡", 6, "糩", 5, "糰", 7, "糹糺糼", 13, "紋", 5],
        ["bc80", "紑", 14, "紡紣紤紥紦紨紩紪紬紭紮細", 6, "肌饥迹激讥鸡姬绩缉吉极棘辑籍集及急疾汲即嫉级挤几脊己蓟技冀季伎祭剂悸济寄寂计记既忌际妓继纪嘉枷夹佳家加荚颊贾甲钾假稼价架驾嫁歼监坚尖笺间煎兼肩艰奸缄茧检柬碱硷拣捡简俭剪减荐槛鉴践贱见键箭件"],
        ["bd40", "紷", 54, "絯", 7],
        ["bd80", "絸", 32, "健舰剑饯渐溅涧建僵姜将浆江疆蒋桨奖讲匠酱降蕉椒礁焦胶交郊浇骄娇嚼搅铰矫侥脚狡角饺缴绞剿教酵轿较叫窖揭接皆秸街阶截劫节桔杰捷睫竭洁结解姐戒藉芥界借介疥诫届巾筋斤金今津襟紧锦仅谨进靳晋禁近烬浸"],
        ["be40", "継", 12, "綧", 6, "綯", 42],
        ["be80", "線", 32, "尽劲荆兢茎睛晶鲸京惊精粳经井警景颈静境敬镜径痉靖竟竞净炯窘揪究纠玖韭久灸九酒厩救旧臼舅咎就疚鞠拘狙疽居驹菊局咀矩举沮聚拒据巨具距踞锯俱句惧炬剧捐鹃娟倦眷卷绢撅攫抉掘倔爵觉决诀绝均菌钧军君峻"],
        ["bf40", "緻", 62],
        ["bf80", "縺縼", 4, "繂", 4, "繈", 21, "俊竣浚郡骏喀咖卡咯开揩楷凯慨刊堪勘坎砍看康慷糠扛抗亢炕考拷烤靠坷苛柯棵磕颗科壳咳可渴克刻客课肯啃垦恳坑吭空恐孔控抠口扣寇枯哭窟苦酷库裤夸垮挎跨胯块筷侩快宽款匡筐狂框矿眶旷况亏盔岿窥葵奎魁傀"],
        ["c040", "繞", 35, "纃", 23, "纜纝纞"],
        ["c080", "纮纴纻纼绖绤绬绹缊缐缞缷缹缻", 6, "罃罆", 9, "罒罓馈愧溃坤昆捆困括扩廓阔垃拉喇蜡腊辣啦莱来赖蓝婪栏拦篮阑兰澜谰揽览懒缆烂滥琅榔狼廊郎朗浪捞劳牢老佬姥酪烙涝勒乐雷镭蕾磊累儡垒擂肋类泪棱楞冷厘梨犁黎篱狸离漓理李里鲤礼莉荔吏栗丽厉励砾历利傈例俐"],
        ["c140", "罖罙罛罜罝罞罠罣", 4, "罫罬罭罯罰罳罵罶罷罸罺罻罼罽罿羀羂", 7, "羋羍羏", 4, "羕", 4, "羛羜羠羢羣羥羦羨", 6, "羱"],
        ["c180", "羳", 4, "羺羻羾翀翂翃翄翆翇翈翉翋翍翏", 4, "翖翗翙", 5, "翢翣痢立粒沥隶力璃哩俩联莲连镰廉怜涟帘敛脸链恋炼练粮凉梁粱良两辆量晾亮谅撩聊僚疗燎寥辽潦了撂镣廖料列裂烈劣猎琳林磷霖临邻鳞淋凛赁吝拎玲菱零龄铃伶羚凌灵陵岭领另令溜琉榴硫馏留刘瘤流柳六龙聋咙笼窿"],
        ["c240", "翤翧翨翪翫翬翭翯翲翴", 6, "翽翾翿耂耇耈耉耊耎耏耑耓耚耛耝耞耟耡耣耤耫", 5, "耲耴耹耺耼耾聀聁聄聅聇聈聉聎聏聐聑聓聕聖聗"],
        ["c280", "聙聛", 13, "聫", 5, "聲", 11, "隆垄拢陇楼娄搂篓漏陋芦卢颅庐炉掳卤虏鲁麓碌露路赂鹿潞禄录陆戮驴吕铝侣旅履屡缕虑氯律率滤绿峦挛孪滦卵乱掠略抡轮伦仑沦纶论萝螺罗逻锣箩骡裸落洛骆络妈麻玛码蚂马骂嘛吗埋买麦卖迈脉瞒馒蛮满蔓曼慢漫"],
        ["c340", "聾肁肂肅肈肊肍", 5, "肔肕肗肙肞肣肦肧肨肬肰肳肵肶肸肹肻胅胇", 4, "胏", 6, "胘胟胠胢胣胦胮胵胷胹胻胾胿脀脁脃脄脅脇脈脋"],
        ["c380", "脌脕脗脙脛脜脝脟", 12, "脭脮脰脳脴脵脷脹", 4, "脿谩芒茫盲氓忙莽猫茅锚毛矛铆卯茂冒帽貌贸么玫枚梅酶霉煤没眉媒镁每美昧寐妹媚门闷们萌蒙檬盟锰猛梦孟眯醚靡糜迷谜弥米秘觅泌蜜密幂棉眠绵冕免勉娩缅面苗描瞄藐秒渺庙妙蔑灭民抿皿敏悯闽明螟鸣铭名命谬摸"],
        ["c440", "腀", 5, "腇腉腍腎腏腒腖腗腘腛", 4, "腡腢腣腤腦腨腪腫腬腯腲腳腵腶腷腸膁膃", 4, "膉膋膌膍膎膐膒", 5, "膙膚膞", 4, "膤膥"],
        ["c480", "膧膩膫", 7, "膴", 5, "膼膽膾膿臄臅臇臈臉臋臍", 6, "摹蘑模膜磨摩魔抹末莫墨默沫漠寞陌谋牟某拇牡亩姆母墓暮幕募慕木目睦牧穆拿哪呐钠那娜纳氖乃奶耐奈南男难囊挠脑恼闹淖呢馁内嫩能妮霓倪泥尼拟你匿腻逆溺蔫拈年碾撵捻念娘酿鸟尿捏聂孽啮镊镍涅您柠狞凝宁"],
        ["c540", "臔", 14, "臤臥臦臨臩臫臮", 4, "臵", 5, "臽臿舃與", 4, "舎舏舑舓舕", 5, "舝舠舤舥舦舧舩舮舲舺舼舽舿"],
        ["c580", "艀艁艂艃艅艆艈艊艌艍艎艐", 7, "艙艛艜艝艞艠", 7, "艩拧泞牛扭钮纽脓浓农弄奴努怒女暖虐疟挪懦糯诺哦欧鸥殴藕呕偶沤啪趴爬帕怕琶拍排牌徘湃派攀潘盘磐盼畔判叛乓庞旁耪胖抛咆刨炮袍跑泡呸胚培裴赔陪配佩沛喷盆砰抨烹澎彭蓬棚硼篷膨朋鹏捧碰坯砒霹批披劈琵毗"],
        ["c640", "艪艫艬艭艱艵艶艷艸艻艼芀芁芃芅芆芇芉芌芐芓芔芕芖芚芛芞芠芢芣芧芲芵芶芺芻芼芿苀苂苃苅苆苉苐苖苙苚苝苢苧苨苩苪苬苭苮苰苲苳苵苶苸"],
        ["c680", "苺苼", 4, "茊茋茍茐茒茓茖茘茙茝", 9, "茩茪茮茰茲茷茻茽啤脾疲皮匹痞僻屁譬篇偏片骗飘漂瓢票撇瞥拼频贫品聘乒坪苹萍平凭瓶评屏坡泼颇婆破魄迫粕剖扑铺仆莆葡菩蒲埔朴圃普浦谱曝瀑期欺栖戚妻七凄漆柒沏其棋奇歧畦崎脐齐旗祈祁骑起岂乞企启契砌器气迄弃汽泣讫掐"],
        ["c740", "茾茿荁荂荄荅荈荊", 4, "荓荕", 4, "荝荢荰", 6, "荹荺荾", 6, "莇莈莊莋莌莍莏莐莑莔莕莖莗莙莚莝莟莡", 6, "莬莭莮"],
        ["c780", "莯莵莻莾莿菂菃菄菆菈菉菋菍菎菐菑菒菓菕菗菙菚菛菞菢菣菤菦菧菨菫菬菭恰洽牵扦钎铅千迁签仟谦乾黔钱钳前潜遣浅谴堑嵌欠歉枪呛腔羌墙蔷强抢橇锹敲悄桥瞧乔侨巧鞘撬翘峭俏窍切茄且怯窃钦侵亲秦琴勤芹擒禽寝沁青轻氢倾卿清擎晴氰情顷请庆琼穷秋丘邱球求囚酋泅趋区蛆曲躯屈驱渠"],
        ["c840", "菮華菳", 4, "菺菻菼菾菿萀萂萅萇萈萉萊萐萒", 5, "萙萚萛萞", 5, "萩", 7, "萲", 5, "萹萺萻萾", 7, "葇葈葉"],
        ["c880", "葊", 6, "葒", 4, "葘葝葞葟葠葢葤", 4, "葪葮葯葰葲葴葷葹葻葼取娶龋趣去圈颧权醛泉全痊拳犬券劝缺炔瘸却鹊榷确雀裙群然燃冉染瓤壤攘嚷让饶扰绕惹热壬仁人忍韧任认刃妊纫扔仍日戎茸蓉荣融熔溶容绒冗揉柔肉茹蠕儒孺如辱乳汝入褥软阮蕊瑞锐闰润若弱撒洒萨腮鳃塞赛三叁"],
        ["c940", "葽", 4, "蒃蒄蒅蒆蒊蒍蒏", 7, "蒘蒚蒛蒝蒞蒟蒠蒢", 12, "蒰蒱蒳蒵蒶蒷蒻蒼蒾蓀蓂蓃蓅蓆蓇蓈蓋蓌蓎蓏蓒蓔蓕蓗"],
        ["c980", "蓘", 4, "蓞蓡蓢蓤蓧", 4, "蓭蓮蓯蓱", 10, "蓽蓾蔀蔁蔂伞散桑嗓丧搔骚扫嫂瑟色涩森僧莎砂杀刹沙纱傻啥煞筛晒珊苫杉山删煽衫闪陕擅赡膳善汕扇缮墒伤商赏晌上尚裳梢捎稍烧芍勺韶少哨邵绍奢赊蛇舌舍赦摄射慑涉社设砷申呻伸身深娠绅神沈审婶甚肾慎渗声生甥牲升绳"],
        ["ca40", "蔃", 8, "蔍蔎蔏蔐蔒蔔蔕蔖蔘蔙蔛蔜蔝蔞蔠蔢", 8, "蔭", 9, "蔾", 4, "蕄蕅蕆蕇蕋", 10],
        ["ca80", "蕗蕘蕚蕛蕜蕝蕟", 4, "蕥蕦蕧蕩", 8, "蕳蕵蕶蕷蕸蕼蕽蕿薀薁省盛剩胜圣师失狮施湿诗尸虱十石拾时什食蚀实识史矢使屎驶始式示士世柿事拭誓逝势是嗜噬适仕侍释饰氏市恃室视试收手首守寿授售受瘦兽蔬枢梳殊抒输叔舒淑疏书赎孰熟薯暑曙署蜀黍鼠属术述树束戍竖墅庶数漱"],
        ["cb40", "薂薃薆薈", 6, "薐", 10, "薝", 6, "薥薦薧薩薫薬薭薱", 5, "薸薺", 6, "藂", 6, "藊", 4, "藑藒"],
        ["cb80", "藔藖", 5, "藝", 6, "藥藦藧藨藪", 14, "恕刷耍摔衰甩帅栓拴霜双爽谁水睡税吮瞬顺舜说硕朔烁斯撕嘶思私司丝死肆寺嗣四伺似饲巳松耸怂颂送宋讼诵搜艘擞嗽苏酥俗素速粟僳塑溯宿诉肃酸蒜算虽隋随绥髓碎岁穗遂隧祟孙损笋蓑梭唆缩琐索锁所塌他它她塔"],
        ["cc40", "藹藺藼藽藾蘀", 4, "蘆", 10, "蘒蘓蘔蘕蘗", 15, "蘨蘪", 13, "蘹蘺蘻蘽蘾蘿虀"],
        ["cc80", "虁", 11, "虒虓處", 4, "虛虜虝號虠虡虣", 7, "獭挞蹋踏胎苔抬台泰酞太态汰坍摊贪瘫滩坛檀痰潭谭谈坦毯袒碳探叹炭汤塘搪堂棠膛唐糖倘躺淌趟烫掏涛滔绦萄桃逃淘陶讨套特藤腾疼誊梯剔踢锑提题蹄啼体替嚏惕涕剃屉天添填田甜恬舔腆挑条迢眺跳贴铁帖厅听烃"],
        ["cd40", "虭虯虰虲", 6, "蚃", 6, "蚎", 4, "蚔蚖", 5, "蚞", 4, "蚥蚦蚫蚭蚮蚲蚳蚷蚸蚹蚻", 4, "蛁蛂蛃蛅蛈蛌蛍蛒蛓蛕蛖蛗蛚蛜"],
        ["cd80", "蛝蛠蛡蛢蛣蛥蛦蛧蛨蛪蛫蛬蛯蛵蛶蛷蛺蛻蛼蛽蛿蜁蜄蜅蜆蜋蜌蜎蜏蜐蜑蜔蜖汀廷停亭庭挺艇通桐酮瞳同铜彤童桶捅筒统痛偷投头透凸秃突图徒途涂屠土吐兔湍团推颓腿蜕褪退吞屯臀拖托脱鸵陀驮驼椭妥拓唾挖哇蛙洼娃瓦袜歪外豌弯湾玩顽丸烷完碗挽晚皖惋宛婉万腕汪王亡枉网往旺望忘妄威"],
        ["ce40", "蜙蜛蜝蜟蜠蜤蜦蜧蜨蜪蜫蜬蜭蜯蜰蜲蜳蜵蜶蜸蜹蜺蜼蜽蝀", 6, "蝊蝋蝍蝏蝐蝑蝒蝔蝕蝖蝘蝚", 5, "蝡蝢蝦", 7, "蝯蝱蝲蝳蝵"],
        ["ce80", "蝷蝸蝹蝺蝿螀螁螄螆螇螉螊螌螎", 4, "螔螕螖螘", 6, "螠", 4, "巍微危韦违桅围唯惟为潍维苇萎委伟伪尾纬未蔚味畏胃喂魏位渭谓尉慰卫瘟温蚊文闻纹吻稳紊问嗡翁瓮挝蜗涡窝我斡卧握沃巫呜钨乌污诬屋无芜梧吾吴毋武五捂午舞伍侮坞戊雾晤物勿务悟误昔熙析西硒矽晰嘻吸锡牺"],
        ["cf40", "螥螦螧螩螪螮螰螱螲螴螶螷螸螹螻螼螾螿蟁", 4, "蟇蟈蟉蟌", 4, "蟔", 6, "蟜蟝蟞蟟蟡蟢蟣蟤蟦蟧蟨蟩蟫蟬蟭蟯", 9],
        ["cf80", "蟺蟻蟼蟽蟿蠀蠁蠂蠄", 5, "蠋", 7, "蠔蠗蠘蠙蠚蠜", 4, "蠣稀息希悉膝夕惜熄烯溪汐犀檄袭席习媳喜铣洗系隙戏细瞎虾匣霞辖暇峡侠狭下厦夏吓掀锨先仙鲜纤咸贤衔舷闲涎弦嫌显险现献县腺馅羡宪陷限线相厢镶香箱襄湘乡翔祥详想响享项巷橡像向象萧硝霄削哮嚣销消宵淆晓"],
        ["d040", "蠤", 13, "蠳", 5, "蠺蠻蠽蠾蠿衁衂衃衆", 5, "衎", 5, "衕衖衘衚", 6, "衦衧衪衭衯衱衳衴衵衶衸衹衺"],
        ["d080", "衻衼袀袃袆袇袉袊袌袎袏袐袑袓袔袕袗", 4, "袝", 4, "袣袥", 5, "小孝校肖啸笑效楔些歇蝎鞋协挟携邪斜胁谐写械卸蟹懈泄泻谢屑薪芯锌欣辛新忻心信衅星腥猩惺兴刑型形邢行醒幸杏性姓兄凶胸匈汹雄熊休修羞朽嗅锈秀袖绣墟戌需虚嘘须徐许蓄酗叙旭序畜恤絮婿绪续轩喧宣悬旋玄"],
        ["d140", "袬袮袯袰袲", 4, "袸袹袺袻袽袾袿裀裃裄裇裈裊裋裌裍裏裐裑裓裖裗裚", 4, "裠裡裦裧裩", 6, "裲裵裶裷裺裻製裿褀褁褃", 5],
        ["d180", "褉褋", 4, "褑褔", 4, "褜", 4, "褢褣褤褦褧褨褩褬褭褮褯褱褲褳褵褷选癣眩绚靴薛学穴雪血勋熏循旬询寻驯巡殉汛训讯逊迅压押鸦鸭呀丫芽牙蚜崖衙涯雅哑亚讶焉咽阉烟淹盐严研蜒岩延言颜阎炎沿奄掩眼衍演艳堰燕厌砚雁唁彦焰宴谚验殃央鸯秧杨扬佯疡羊洋阳氧仰痒养样漾邀腰妖瑶"],
        ["d240", "褸", 8, "襂襃襅", 24, "襠", 5, "襧", 19, "襼"],
        ["d280", "襽襾覀覂覄覅覇", 26, "摇尧遥窑谣姚咬舀药要耀椰噎耶爷野冶也页掖业叶曳腋夜液一壹医揖铱依伊衣颐夷遗移仪胰疑沂宜姨彝椅蚁倚已乙矣以艺抑易邑屹亿役臆逸肄疫亦裔意毅忆义益溢诣议谊译异翼翌绎茵荫因殷音阴姻吟银淫寅饮尹引隐"],
        ["d340", "覢", 30, "觃觍觓觔觕觗觘觙觛觝觟觠觡觢觤觧觨觩觪觬觭觮觰觱觲觴", 6],
        ["d380", "觻", 4, "訁", 5, "計", 21, "印英樱婴鹰应缨莹萤营荧蝇迎赢盈影颖硬映哟拥佣臃痈庸雍踊蛹咏泳涌永恿勇用幽优悠忧尤由邮铀犹油游酉有友右佑釉诱又幼迂淤于盂榆虞愚舆余俞逾鱼愉渝渔隅予娱雨与屿禹宇语羽玉域芋郁吁遇喻峪御愈欲狱育誉"],
        ["d440", "訞", 31, "訿", 8, "詉", 21],
        ["d480", "詟", 25, "詺", 6, "浴寓裕预豫驭鸳渊冤元垣袁原援辕园员圆猿源缘远苑愿怨院曰约越跃钥岳粤月悦阅耘云郧匀陨允运蕴酝晕韵孕匝砸杂栽哉灾宰载再在咱攒暂赞赃脏葬遭糟凿藻枣早澡蚤躁噪造皂灶燥责择则泽贼怎增憎曾赠扎喳渣札轧"],
        ["d540", "誁", 7, "誋", 7, "誔", 46],
        ["d580", "諃", 32, "铡闸眨栅榨咋乍炸诈摘斋宅窄债寨瞻毡詹粘沾盏斩辗崭展蘸栈占战站湛绽樟章彰漳张掌涨杖丈帐账仗胀瘴障招昭找沼赵照罩兆肇召遮折哲蛰辙者锗蔗这浙珍斟真甄砧臻贞针侦枕疹诊震振镇阵蒸挣睁征狰争怔整拯正政"],
        ["d640", "諤", 34, "謈", 27],
        ["d680", "謤謥謧", 30, "帧症郑证芝枝支吱蜘知肢脂汁之织职直植殖执值侄址指止趾只旨纸志挚掷至致置帜峙制智秩稚质炙痔滞治窒中盅忠钟衷终种肿重仲众舟周州洲诌粥轴肘帚咒皱宙昼骤珠株蛛朱猪诸诛逐竹烛煮拄瞩嘱主著柱助蛀贮铸筑"],
        ["d740", "譆", 31, "譧", 4, "譭", 25],
        ["d780", "讇", 24, "讬讱讻诇诐诪谉谞住注祝驻抓爪拽专砖转撰赚篆桩庄装妆撞壮状椎锥追赘坠缀谆准捉拙卓桌琢茁酌啄着灼浊兹咨资姿滋淄孜紫仔籽滓子自渍字鬃棕踪宗综总纵邹走奏揍租足卒族祖诅阻组钻纂嘴醉最罪尊遵昨左佐柞做作坐座"],
        ["d840", "谸", 8, "豂豃豄豅豈豊豋豍", 7, "豖豗豘豙豛", 5, "豣", 6, "豬", 6, "豴豵豶豷豻", 6, "貃貄貆貇"],
        ["d880", "貈貋貍", 6, "貕貖貗貙", 20, "亍丌兀丐廿卅丕亘丞鬲孬噩丨禺丿匕乇夭爻卮氐囟胤馗毓睾鼗丶亟鼐乜乩亓芈孛啬嘏仄厍厝厣厥厮靥赝匚叵匦匮匾赜卦卣刂刈刎刭刳刿剀剌剞剡剜蒯剽劂劁劐劓冂罔亻仃仉仂仨仡仫仞伛仳伢佤仵伥伧伉伫佞佧攸佚佝"],
        ["d940", "貮", 62],
        ["d980", "賭", 32, "佟佗伲伽佶佴侑侉侃侏佾佻侪佼侬侔俦俨俪俅俚俣俜俑俟俸倩偌俳倬倏倮倭俾倜倌倥倨偾偃偕偈偎偬偻傥傧傩傺僖儆僭僬僦僮儇儋仝氽佘佥俎龠汆籴兮巽黉馘冁夔勹匍訇匐凫夙兕亠兖亳衮袤亵脔裒禀嬴蠃羸冫冱冽冼"],
        ["da40", "贎", 14, "贠赑赒赗赟赥赨赩赪赬赮赯赱赲赸", 8, "趂趃趆趇趈趉趌", 4, "趒趓趕", 9, "趠趡"],
        ["da80", "趢趤", 12, "趲趶趷趹趻趽跀跁跂跅跇跈跉跊跍跐跒跓跔凇冖冢冥讠讦讧讪讴讵讷诂诃诋诏诎诒诓诔诖诘诙诜诟诠诤诨诩诮诰诳诶诹诼诿谀谂谄谇谌谏谑谒谔谕谖谙谛谘谝谟谠谡谥谧谪谫谮谯谲谳谵谶卩卺阝阢阡阱阪阽阼陂陉陔陟陧陬陲陴隈隍隗隰邗邛邝邙邬邡邴邳邶邺"],
        ["db40", "跕跘跙跜跠跡跢跥跦跧跩跭跮跰跱跲跴跶跼跾", 6, "踆踇踈踋踍踎踐踑踒踓踕", 7, "踠踡踤", 4, "踫踭踰踲踳踴踶踷踸踻踼踾"],
        ["db80", "踿蹃蹅蹆蹌", 4, "蹓", 5, "蹚", 11, "蹧蹨蹪蹫蹮蹱邸邰郏郅邾郐郄郇郓郦郢郜郗郛郫郯郾鄄鄢鄞鄣鄱鄯鄹酃酆刍奂劢劬劭劾哿勐勖勰叟燮矍廴凵凼鬯厶弁畚巯坌垩垡塾墼壅壑圩圬圪圳圹圮圯坜圻坂坩垅坫垆坼坻坨坭坶坳垭垤垌垲埏垧垴垓垠埕埘埚埙埒垸埴埯埸埤埝"],
        ["dc40", "蹳蹵蹷", 4, "蹽蹾躀躂躃躄躆躈", 6, "躑躒躓躕", 6, "躝躟", 11, "躭躮躰躱躳", 6, "躻", 7],
        ["dc80", "軃", 10, "軏", 21, "堋堍埽埭堀堞堙塄堠塥塬墁墉墚墀馨鼙懿艹艽艿芏芊芨芄芎芑芗芙芫芸芾芰苈苊苣芘芷芮苋苌苁芩芴芡芪芟苄苎芤苡茉苷苤茏茇苜苴苒苘茌苻苓茑茚茆茔茕苠苕茜荑荛荜茈莒茼茴茱莛荞茯荏荇荃荟荀茗荠茭茺茳荦荥"],
        ["dd40", "軥", 62],
        ["dd80", "輤", 32, "荨茛荩荬荪荭荮莰荸莳莴莠莪莓莜莅荼莶莩荽莸荻莘莞莨莺莼菁萁菥菘堇萘萋菝菽菖萜萸萑萆菔菟萏萃菸菹菪菅菀萦菰菡葜葑葚葙葳蒇蒈葺蒉葸萼葆葩葶蒌蒎萱葭蓁蓍蓐蓦蒽蓓蓊蒿蒺蓠蒡蒹蒴蒗蓥蓣蔌甍蔸蓰蔹蔟蔺"],
        ["de40", "轅", 32, "轪辀辌辒辝辠辡辢辤辥辦辧辪辬辭辮辯農辳辴辵辷辸辺辻込辿迀迃迆"],
        ["de80", "迉", 4, "迏迒迖迗迚迠迡迣迧迬迯迱迲迴迵迶迺迻迼迾迿逇逈逌逎逓逕逘蕖蔻蓿蓼蕙蕈蕨蕤蕞蕺瞢蕃蕲蕻薤薨薇薏蕹薮薜薅薹薷薰藓藁藜藿蘧蘅蘩蘖蘼廾弈夼奁耷奕奚奘匏尢尥尬尴扌扪抟抻拊拚拗拮挢拶挹捋捃掭揶捱捺掎掴捭掬掊捩掮掼揲揸揠揿揄揞揎摒揆掾摅摁搋搛搠搌搦搡摞撄摭撖"],
        ["df40", "這逜連逤逥逧", 5, "逰", 4, "逷逹逺逽逿遀遃遅遆遈", 4, "過達違遖遙遚遜", 5, "遤遦遧適遪遫遬遯", 4, "遶", 6, "遾邁"],
        ["df80", "還邅邆邇邉邊邌", 4, "邒邔邖邘邚邜邞邟邠邤邥邧邨邩邫邭邲邷邼邽邿郀摺撷撸撙撺擀擐擗擤擢攉攥攮弋忒甙弑卟叱叽叩叨叻吒吖吆呋呒呓呔呖呃吡呗呙吣吲咂咔呷呱呤咚咛咄呶呦咝哐咭哂咴哒咧咦哓哔呲咣哕咻咿哌哙哚哜咩咪咤哝哏哞唛哧唠哽唔哳唢唣唏唑唧唪啧喏喵啉啭啁啕唿啐唼"],
        ["e040", "郂郃郆郈郉郋郌郍郒郔郕郖郘郙郚郞郟郠郣郤郥郩郪郬郮郰郱郲郳郵郶郷郹郺郻郼郿鄀鄁鄃鄅", 19, "鄚鄛鄜"],
        ["e080", "鄝鄟鄠鄡鄤", 10, "鄰鄲", 6, "鄺", 8, "酄唷啖啵啶啷唳唰啜喋嗒喃喱喹喈喁喟啾嗖喑啻嗟喽喾喔喙嗪嗷嗉嘟嗑嗫嗬嗔嗦嗝嗄嗯嗥嗲嗳嗌嗍嗨嗵嗤辔嘞嘈嘌嘁嘤嘣嗾嘀嘧嘭噘嘹噗嘬噍噢噙噜噌噔嚆噤噱噫噻噼嚅嚓嚯囔囗囝囡囵囫囹囿圄圊圉圜帏帙帔帑帱帻帼"],
        ["e140", "酅酇酈酑酓酔酕酖酘酙酛酜酟酠酦酧酨酫酭酳酺酻酼醀", 4, "醆醈醊醎醏醓", 6, "醜", 5, "醤", 5, "醫醬醰醱醲醳醶醷醸醹醻"],
        ["e180", "醼", 10, "釈釋釐釒", 9, "針", 8, "帷幄幔幛幞幡岌屺岍岐岖岈岘岙岑岚岜岵岢岽岬岫岱岣峁岷峄峒峤峋峥崂崃崧崦崮崤崞崆崛嵘崾崴崽嵬嵛嵯嵝嵫嵋嵊嵩嵴嶂嶙嶝豳嶷巅彳彷徂徇徉後徕徙徜徨徭徵徼衢彡犭犰犴犷犸狃狁狎狍狒狨狯狩狲狴狷猁狳猃狺"],
        ["e240", "釦", 62],
        ["e280", "鈥", 32, "狻猗猓猡猊猞猝猕猢猹猥猬猸猱獐獍獗獠獬獯獾舛夥飧夤夂饣饧", 5, "饴饷饽馀馄馇馊馍馐馑馓馔馕庀庑庋庖庥庠庹庵庾庳赓廒廑廛廨廪膺忄忉忖忏怃忮怄忡忤忾怅怆忪忭忸怙怵怦怛怏怍怩怫怊怿怡恸恹恻恺恂"],
        ["e340", "鉆", 45, "鉵", 16],
        ["e380", "銆", 7, "銏", 24, "恪恽悖悚悭悝悃悒悌悛惬悻悱惝惘惆惚悴愠愦愕愣惴愀愎愫慊慵憬憔憧憷懔懵忝隳闩闫闱闳闵闶闼闾阃阄阆阈阊阋阌阍阏阒阕阖阗阙阚丬爿戕氵汔汜汊沣沅沐沔沌汨汩汴汶沆沩泐泔沭泷泸泱泗沲泠泖泺泫泮沱泓泯泾"],
        ["e440", "銨", 5, "銯", 24, "鋉", 31],
        ["e480", "鋩", 32, "洹洧洌浃浈洇洄洙洎洫浍洮洵洚浏浒浔洳涑浯涞涠浞涓涔浜浠浼浣渚淇淅淞渎涿淠渑淦淝淙渖涫渌涮渫湮湎湫溲湟溆湓湔渲渥湄滟溱溘滠漭滢溥溧溽溻溷滗溴滏溏滂溟潢潆潇漤漕滹漯漶潋潴漪漉漩澉澍澌潸潲潼潺濑"],
        ["e540", "錊", 51, "錿", 10],
        ["e580", "鍊", 31, "鍫濉澧澹澶濂濡濮濞濠濯瀚瀣瀛瀹瀵灏灞宀宄宕宓宥宸甯骞搴寤寮褰寰蹇謇辶迓迕迥迮迤迩迦迳迨逅逄逋逦逑逍逖逡逵逶逭逯遄遑遒遐遨遘遢遛暹遴遽邂邈邃邋彐彗彖彘尻咫屐屙孱屣屦羼弪弩弭艴弼鬻屮妁妃妍妩妪妣"],
        ["e640", "鍬", 34, "鎐", 27],
        ["e680", "鎬", 29, "鏋鏌鏍妗姊妫妞妤姒妲妯姗妾娅娆姝娈姣姘姹娌娉娲娴娑娣娓婀婧婊婕娼婢婵胬媪媛婷婺媾嫫媲嫒嫔媸嫠嫣嫱嫖嫦嫘嫜嬉嬗嬖嬲嬷孀尕尜孚孥孳孑孓孢驵驷驸驺驿驽骀骁骅骈骊骐骒骓骖骘骛骜骝骟骠骢骣骥骧纟纡纣纥纨纩"],
        ["e740", "鏎", 7, "鏗", 54],
        ["e780", "鐎", 32, "纭纰纾绀绁绂绉绋绌绐绔绗绛绠绡绨绫绮绯绱绲缍绶绺绻绾缁缂缃缇缈缋缌缏缑缒缗缙缜缛缟缡", 6, "缪缫缬缭缯", 4, "缵幺畿巛甾邕玎玑玮玢玟珏珂珑玷玳珀珉珈珥珙顼琊珩珧珞玺珲琏琪瑛琦琥琨琰琮琬"],
        ["e840", "鐯", 14, "鐿", 43, "鑬鑭鑮鑯"],
        ["e880", "鑰", 20, "钑钖钘铇铏铓铔铚铦铻锜锠琛琚瑁瑜瑗瑕瑙瑷瑭瑾璜璎璀璁璇璋璞璨璩璐璧瓒璺韪韫韬杌杓杞杈杩枥枇杪杳枘枧杵枨枞枭枋杷杼柰栉柘栊柩枰栌柙枵柚枳柝栀柃枸柢栎柁柽栲栳桠桡桎桢桄桤梃栝桕桦桁桧桀栾桊桉栩梵梏桴桷梓桫棂楮棼椟椠棹"],
        ["e940", "锧锳锽镃镈镋镕镚镠镮镴镵長", 7, "門", 42],
        ["e980", "閫", 32, "椤棰椋椁楗棣椐楱椹楠楂楝榄楫榀榘楸椴槌榇榈槎榉楦楣楹榛榧榻榫榭槔榱槁槊槟榕槠榍槿樯槭樗樘橥槲橄樾檠橐橛樵檎橹樽樨橘橼檑檐檩檗檫猷獒殁殂殇殄殒殓殍殚殛殡殪轫轭轱轲轳轵轶轸轷轹轺轼轾辁辂辄辇辋"],
        ["ea40", "闌", 27, "闬闿阇阓阘阛阞阠阣", 6, "阫阬阭阯阰阷阸阹阺阾陁陃陊陎陏陑陒陓陖陗"],
        ["ea80", "陘陙陚陜陝陞陠陣陥陦陫陭", 4, "陳陸", 12, "隇隉隊辍辎辏辘辚軎戋戗戛戟戢戡戥戤戬臧瓯瓴瓿甏甑甓攴旮旯旰昊昙杲昃昕昀炅曷昝昴昱昶昵耆晟晔晁晏晖晡晗晷暄暌暧暝暾曛曜曦曩贲贳贶贻贽赀赅赆赈赉赇赍赕赙觇觊觋觌觎觏觐觑牮犟牝牦牯牾牿犄犋犍犏犒挈挲掰"],
        ["eb40", "隌階隑隒隓隕隖隚際隝", 9, "隨", 7, "隱隲隴隵隷隸隺隻隿雂雃雈雊雋雐雑雓雔雖", 9, "雡", 6, "雫"],
        ["eb80", "雬雭雮雰雱雲雴雵雸雺電雼雽雿霂霃霅霊霋霌霐霑霒霔霕霗", 4, "霝霟霠搿擘耄毪毳毽毵毹氅氇氆氍氕氘氙氚氡氩氤氪氲攵敕敫牍牒牖爰虢刖肟肜肓肼朊肽肱肫肭肴肷胧胨胩胪胛胂胄胙胍胗朐胝胫胱胴胭脍脎胲胼朕脒豚脶脞脬脘脲腈腌腓腴腙腚腱腠腩腼腽腭腧塍媵膈膂膑滕膣膪臌朦臊膻"],
        ["ec40", "霡", 8, "霫霬霮霯霱霳", 4, "霺霻霼霽霿", 18, "靔靕靗靘靚靜靝靟靣靤靦靧靨靪", 7],
        ["ec80", "靲靵靷", 4, "靽", 7, "鞆", 4, "鞌鞎鞏鞐鞓鞕鞖鞗鞙", 4, "臁膦欤欷欹歃歆歙飑飒飓飕飙飚殳彀毂觳斐齑斓於旆旄旃旌旎旒旖炀炜炖炝炻烀炷炫炱烨烊焐焓焖焯焱煳煜煨煅煲煊煸煺熘熳熵熨熠燠燔燧燹爝爨灬焘煦熹戾戽扃扈扉礻祀祆祉祛祜祓祚祢祗祠祯祧祺禅禊禚禧禳忑忐"],
        ["ed40", "鞞鞟鞡鞢鞤", 6, "鞬鞮鞰鞱鞳鞵", 46],
        ["ed80", "韤韥韨韮", 4, "韴韷", 23, "怼恝恚恧恁恙恣悫愆愍慝憩憝懋懑戆肀聿沓泶淼矶矸砀砉砗砘砑斫砭砜砝砹砺砻砟砼砥砬砣砩硎硭硖硗砦硐硇硌硪碛碓碚碇碜碡碣碲碹碥磔磙磉磬磲礅磴礓礤礞礴龛黹黻黼盱眄眍盹眇眈眚眢眙眭眦眵眸睐睑睇睃睚睨"],
        ["ee40", "頏", 62],
        ["ee80", "顎", 32, "睢睥睿瞍睽瞀瞌瞑瞟瞠瞰瞵瞽町畀畎畋畈畛畲畹疃罘罡罟詈罨罴罱罹羁罾盍盥蠲钅钆钇钋钊钌钍钏钐钔钗钕钚钛钜钣钤钫钪钭钬钯钰钲钴钶", 4, "钼钽钿铄铈", 6, "铐铑铒铕铖铗铙铘铛铞铟铠铢铤铥铧铨铪"],
        ["ef40", "顯", 5, "颋颎颒颕颙颣風", 37, "飏飐飔飖飗飛飜飝飠", 4],
        ["ef80", "飥飦飩", 30, "铩铫铮铯铳铴铵铷铹铼铽铿锃锂锆锇锉锊锍锎锏锒", 4, "锘锛锝锞锟锢锪锫锩锬锱锲锴锶锷锸锼锾锿镂锵镄镅镆镉镌镎镏镒镓镔镖镗镘镙镛镞镟镝镡镢镤", 8, "镯镱镲镳锺矧矬雉秕秭秣秫稆嵇稃稂稞稔"],
        ["f040", "餈", 4, "餎餏餑", 28, "餯", 26],
        ["f080", "饊", 9, "饖", 12, "饤饦饳饸饹饻饾馂馃馉稹稷穑黏馥穰皈皎皓皙皤瓞瓠甬鸠鸢鸨", 4, "鸲鸱鸶鸸鸷鸹鸺鸾鹁鹂鹄鹆鹇鹈鹉鹋鹌鹎鹑鹕鹗鹚鹛鹜鹞鹣鹦", 6, "鹱鹭鹳疒疔疖疠疝疬疣疳疴疸痄疱疰痃痂痖痍痣痨痦痤痫痧瘃痱痼痿瘐瘀瘅瘌瘗瘊瘥瘘瘕瘙"],
        ["f140", "馌馎馚", 10, "馦馧馩", 47],
        ["f180", "駙", 32, "瘛瘼瘢瘠癀瘭瘰瘿瘵癃瘾瘳癍癞癔癜癖癫癯翊竦穸穹窀窆窈窕窦窠窬窨窭窳衤衩衲衽衿袂袢裆袷袼裉裢裎裣裥裱褚裼裨裾裰褡褙褓褛褊褴褫褶襁襦襻疋胥皲皴矜耒耔耖耜耠耢耥耦耧耩耨耱耋耵聃聆聍聒聩聱覃顸颀颃"],
        ["f240", "駺", 62],
        ["f280", "騹", 32, "颉颌颍颏颔颚颛颞颟颡颢颥颦虍虔虬虮虿虺虼虻蚨蚍蚋蚬蚝蚧蚣蚪蚓蚩蚶蛄蚵蛎蚰蚺蚱蚯蛉蛏蚴蛩蛱蛲蛭蛳蛐蜓蛞蛴蛟蛘蛑蜃蜇蛸蜈蜊蜍蜉蜣蜻蜞蜥蜮蜚蜾蝈蜴蜱蜩蜷蜿螂蜢蝽蝾蝻蝠蝰蝌蝮螋蝓蝣蝼蝤蝙蝥螓螯螨蟒"],
        ["f340", "驚", 17, "驲骃骉骍骎骔骕骙骦骩", 6, "骲骳骴骵骹骻骽骾骿髃髄髆", 4, "髍髎髏髐髒體髕髖髗髙髚髛髜"],
        ["f380", "髝髞髠髢髣髤髥髧髨髩髪髬髮髰", 8, "髺髼", 6, "鬄鬅鬆蟆螈螅螭螗螃螫蟥螬螵螳蟋蟓螽蟑蟀蟊蟛蟪蟠蟮蠖蠓蟾蠊蠛蠡蠹蠼缶罂罄罅舐竺竽笈笃笄笕笊笫笏筇笸笪笙笮笱笠笥笤笳笾笞筘筚筅筵筌筝筠筮筻筢筲筱箐箦箧箸箬箝箨箅箪箜箢箫箴篑篁篌篝篚篥篦篪簌篾篼簏簖簋"],
        ["f440", "鬇鬉", 5, "鬐鬑鬒鬔", 10, "鬠鬡鬢鬤", 10, "鬰鬱鬳", 7, "鬽鬾鬿魀魆魊魋魌魎魐魒魓魕", 5],
        ["f480", "魛", 32, "簟簪簦簸籁籀臾舁舂舄臬衄舡舢舣舭舯舨舫舸舻舳舴舾艄艉艋艏艚艟艨衾袅袈裘裟襞羝羟羧羯羰羲籼敉粑粝粜粞粢粲粼粽糁糇糌糍糈糅糗糨艮暨羿翎翕翥翡翦翩翮翳糸絷綦綮繇纛麸麴赳趄趔趑趱赧赭豇豉酊酐酎酏酤"],
        ["f540", "魼", 62],
        ["f580", "鮻", 32, "酢酡酰酩酯酽酾酲酴酹醌醅醐醍醑醢醣醪醭醮醯醵醴醺豕鹾趸跫踅蹙蹩趵趿趼趺跄跖跗跚跞跎跏跛跆跬跷跸跣跹跻跤踉跽踔踝踟踬踮踣踯踺蹀踹踵踽踱蹉蹁蹂蹑蹒蹊蹰蹶蹼蹯蹴躅躏躔躐躜躞豸貂貊貅貘貔斛觖觞觚觜"],
        ["f640", "鯜", 62],
        ["f680", "鰛", 32, "觥觫觯訾謦靓雩雳雯霆霁霈霏霎霪霭霰霾龀龃龅", 5, "龌黾鼋鼍隹隼隽雎雒瞿雠銎銮鋈錾鍪鏊鎏鐾鑫鱿鲂鲅鲆鲇鲈稣鲋鲎鲐鲑鲒鲔鲕鲚鲛鲞", 5, "鲥", 4, "鲫鲭鲮鲰", 7, "鲺鲻鲼鲽鳄鳅鳆鳇鳊鳋"],
        ["f740", "鰼", 62],
        ["f780", "鱻鱽鱾鲀鲃鲄鲉鲊鲌鲏鲓鲖鲗鲘鲙鲝鲪鲬鲯鲹鲾", 4, "鳈鳉鳑鳒鳚鳛鳠鳡鳌", 4, "鳓鳔鳕鳗鳘鳙鳜鳝鳟鳢靼鞅鞑鞒鞔鞯鞫鞣鞲鞴骱骰骷鹘骶骺骼髁髀髅髂髋髌髑魅魃魇魉魈魍魑飨餍餮饕饔髟髡髦髯髫髻髭髹鬈鬏鬓鬟鬣麽麾縻麂麇麈麋麒鏖麝麟黛黜黝黠黟黢黩黧黥黪黯鼢鼬鼯鼹鼷鼽鼾齄"],
        ["f840", "鳣", 62],
        ["f880", "鴢", 32],
        ["f940", "鵃", 62],
        ["f980", "鶂", 32],
        ["fa40", "鶣", 62],
        ["fa80", "鷢", 32],
        ["fb40", "鸃", 27, "鸤鸧鸮鸰鸴鸻鸼鹀鹍鹐鹒鹓鹔鹖鹙鹝鹟鹠鹡鹢鹥鹮鹯鹲鹴", 9, "麀"],
        ["fb80", "麁麃麄麅麆麉麊麌", 5, "麔", 8, "麞麠", 5, "麧麨麩麪"],
        ["fc40", "麫", 8, "麵麶麷麹麺麼麿", 4, "黅黆黇黈黊黋黌黐黒黓黕黖黗黙黚點黡黣黤黦黨黫黬黭黮黰", 8, "黺黽黿", 6],
        ["fc80", "鼆", 4, "鼌鼏鼑鼒鼔鼕鼖鼘鼚", 5, "鼡鼣", 8, "鼭鼮鼰鼱"],
        ["fd40", "鼲", 4, "鼸鼺鼼鼿", 4, "齅", 10, "齒", 38],
        ["fd80", "齹", 5, "龁龂龍", 11, "龜龝龞龡", 4, "郎凉秊裏隣"],
        ["fe40", "兀嗀﨎﨏﨑﨓﨔礼﨟蘒﨡﨣﨤﨧﨨﨩"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/gbk-added.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["a140", "", 62],
        ["a180", "", 32],
        ["a240", "", 62],
        ["a280", "", 32],
        ["a2ab", "", 5],
        ["a2e3", "€"],
        ["a2ef", ""],
        ["a2fd", ""],
        ["a340", "", 62],
        ["a380", "", 31, "　"],
        ["a440", "", 62],
        ["a480", "", 32],
        ["a4f4", "", 10],
        ["a540", "", 62],
        ["a580", "", 32],
        ["a5f7", "", 7],
        ["a640", "", 62],
        ["a680", "", 32],
        ["a6b9", "", 7],
        ["a6d9", "", 6],
        ["a6ec", ""],
        ["a6f3", ""],
        ["a6f6", "", 8],
        ["a740", "", 62],
        ["a780", "", 32],
        ["a7c2", "", 14],
        ["a7f2", "", 12],
        ["a896", "", 10],
        ["a8bc", ""],
        ["a8bf", "ǹ"],
        ["a8c1", ""],
        ["a8ea", "", 20],
        ["a958", ""],
        ["a95b", ""],
        ["a95d", ""],
        ["a989", "〾⿰", 11],
        ["a997", "", 12],
        ["a9f0", "", 14],
        ["aaa1", "", 93],
        ["aba1", "", 93],
        ["aca1", "", 93],
        ["ada1", "", 93],
        ["aea1", "", 93],
        ["afa1", "", 93],
        ["d7fa", "", 4],
        ["f8a1", "", 93],
        ["f9a1", "", 93],
        ["faa1", "", 93],
        ["fba1", "", 93],
        ["fca1", "", 93],
        ["fda1", "", 93],
        ["fe50", "⺁⺄㑳㑇⺈⺋㖞㘚㘎⺌⺗㥮㤘㧏㧟㩳㧐㭎㱮㳠⺧⺪䁖䅟⺮䌷⺳⺶⺷䎱䎬⺻䏝䓖䙡䙌"],
        ["fe80", "䜣䜩䝼䞍⻊䥇䥺䥽䦂䦃䦅䦆䦟䦛䦷䦶䲣䲟䲠䲡䱷䲢䴓", 6, "䶮", 93]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/gb18030-ranges.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = { "uChars": [128, 165, 169, 178, 184, 216, 226, 235, 238, 244, 248, 251, 253, 258, 276, 284, 300, 325, 329, 334, 364, 463, 465, 467, 469, 471, 473, 475, 477, 506, 594, 610, 712, 716, 730, 930, 938, 962, 970, 1026, 1104, 1106, 8209, 8215, 8218, 8222, 8231, 8241, 8244, 8246, 8252, 8365, 8452, 8454, 8458, 8471, 8482, 8556, 8570, 8596, 8602, 8713, 8720, 8722, 8726, 8731, 8737, 8740, 8742, 8748, 8751, 8760, 8766, 8777, 8781, 8787, 8802, 8808, 8816, 8854, 8858, 8870, 8896, 8979, 9322, 9372, 9548, 9588, 9616, 9622, 9634, 9652, 9662, 9672, 9676, 9680, 9702, 9735, 9738, 9793, 9795, 11906, 11909, 11913, 11917, 11928, 11944, 11947, 11951, 11956, 11960, 11964, 11979, 12284, 12292, 12312, 12319, 12330, 12351, 12436, 12447, 12535, 12543, 12586, 12842, 12850, 12964, 13200, 13215, 13218, 13253, 13263, 13267, 13270, 13384, 13428, 13727, 13839, 13851, 14617, 14703, 14801, 14816, 14964, 15183, 15471, 15585, 16471, 16736, 17208, 17325, 17330, 17374, 17623, 17997, 18018, 18212, 18218, 18301, 18318, 18760, 18811, 18814, 18820, 18823, 18844, 18848, 18872, 19576, 19620, 19738, 19887, 40870, 59244, 59336, 59367, 59413, 59417, 59423, 59431, 59437, 59443, 59452, 59460, 59478, 59493, 63789, 63866, 63894, 63976, 63986, 64016, 64018, 64021, 64025, 64034, 64037, 64042, 65074, 65093, 65107, 65112, 65127, 65132, 65375, 65510, 65536], "gbChars": [0, 36, 38, 45, 50, 81, 89, 95, 96, 100, 103, 104, 105, 109, 126, 133, 148, 172, 175, 179, 208, 306, 307, 308, 309, 310, 311, 312, 313, 341, 428, 443, 544, 545, 558, 741, 742, 749, 750, 805, 819, 820, 7922, 7924, 7925, 7927, 7934, 7943, 7944, 7945, 7950, 8062, 8148, 8149, 8152, 8164, 8174, 8236, 8240, 8262, 8264, 8374, 8380, 8381, 8384, 8388, 8390, 8392, 8393, 8394, 8396, 8401, 8406, 8416, 8419, 8424, 8437, 8439, 8445, 8482, 8485, 8496, 8521, 8603, 8936, 8946, 9046, 9050, 9063, 9066, 9076, 9092, 9100, 9108, 9111, 9113, 9131, 9162, 9164, 9218, 9219, 11329, 11331, 11334, 11336, 11346, 11361, 11363, 11366, 11370, 11372, 11375, 11389, 11682, 11686, 11687, 11692, 11694, 11714, 11716, 11723, 11725, 11730, 11736, 11982, 11989, 12102, 12336, 12348, 12350, 12384, 12393, 12395, 12397, 12510, 12553, 12851, 12962, 12973, 13738, 13823, 13919, 13933, 14080, 14298, 14585, 14698, 15583, 15847, 16318, 16434, 16438, 16481, 16729, 17102, 17122, 17315, 17320, 17402, 17418, 17859, 17909, 17911, 17915, 17916, 17936, 17939, 17961, 18664, 18703, 18814, 18962, 19043, 33469, 33470, 33471, 33484, 33485, 33490, 33497, 33501, 33505, 33513, 33520, 33536, 33550, 37845, 37921, 37948, 38029, 38038, 38064, 38065, 38066, 38069, 38075, 38076, 38078, 39108, 39109, 39113, 39114, 39115, 39116, 39265, 39394, 189000] };
    module.exports = json;
},
/* iconv-lite/encodings/tables/cp949.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 127],
        ["8141", "갂갃갅갆갋", 4, "갘갞갟갡갢갣갥", 6, "갮갲갳갴"],
        ["8161", "갵갶갷갺갻갽갾갿걁", 9, "걌걎", 5, "걕"],
        ["8181", "걖걗걙걚걛걝", 18, "걲걳걵걶걹걻", 4, "겂겇겈겍겎겏겑겒겓겕", 6, "겞겢", 5, "겫겭겮겱", 6, "겺겾겿곀곂곃곅곆곇곉곊곋곍", 7, "곖곘", 7, "곢곣곥곦곩곫곭곮곲곴곷", 4, "곾곿괁괂괃괅괇", 4, "괎괐괒괓"],
        ["8241", "괔괕괖괗괙괚괛괝괞괟괡", 7, "괪괫괮", 5],
        ["8261", "괶괷괹괺괻괽", 6, "굆굈굊", 5, "굑굒굓굕굖굗"],
        ["8281", "굙", 7, "굢굤", 7, "굮굯굱굲굷굸굹굺굾궀궃", 4, "궊궋궍궎궏궑", 10, "궞", 5, "궥", 17, "궸", 7, "귂귃귅귆귇귉", 6, "귒귔", 7, "귝귞귟귡귢귣귥", 18],
        ["8341", "귺귻귽귾긂", 5, "긊긌긎", 5, "긕", 7],
        ["8361", "긝", 18, "긲긳긵긶긹긻긼"],
        ["8381", "긽긾긿깂깄깇깈깉깋깏깑깒깓깕깗", 4, "깞깢깣깤깦깧깪깫깭깮깯깱", 6, "깺깾", 5, "꺆", 5, "꺍", 46, "꺿껁껂껃껅", 6, "껎껒", 5, "껚껛껝", 8],
        ["8441", "껦껧껩껪껬껮", 5, "껵껶껷껹껺껻껽", 8],
        ["8461", "꼆꼉꼊꼋꼌꼎꼏꼑", 18],
        ["8481", "꼤", 7, "꼮꼯꼱꼳꼵", 6, "꼾꽀꽄꽅꽆꽇꽊", 5, "꽑", 10, "꽞", 5, "꽦", 18, "꽺", 5, "꾁꾂꾃꾅꾆꾇꾉", 6, "꾒꾓꾔꾖", 5, "꾝", 26, "꾺꾻꾽꾾"],
        ["8541", "꾿꿁", 5, "꿊꿌꿏", 4, "꿕", 6, "꿝", 4],
        ["8561", "꿢", 5, "꿪", 5, "꿲꿳꿵꿶꿷꿹", 6, "뀂뀃"],
        ["8581", "뀅", 6, "뀍뀎뀏뀑뀒뀓뀕", 6, "뀞", 9, "뀩", 26, "끆끇끉끋끍끏끐끑끒끖끘끚끛끜끞", 29, "끾끿낁낂낃낅", 6, "낎낐낒", 5, "낛낝낞낣낤"],
        ["8641", "낥낦낧낪낰낲낶낷낹낺낻낽", 6, "냆냊", 5, "냒"],
        ["8661", "냓냕냖냗냙", 6, "냡냢냣냤냦", 10],
        ["8681", "냱", 22, "넊넍넎넏넑넔넕넖넗넚넞", 4, "넦넧넩넪넫넭", 6, "넶넺", 5, "녂녃녅녆녇녉", 6, "녒녓녖녗녙녚녛녝녞녟녡", 22, "녺녻녽녾녿놁놃", 4, "놊놌놎놏놐놑놕놖놗놙놚놛놝"],
        ["8741", "놞", 9, "놩", 15],
        ["8761", "놹", 18, "뇍뇎뇏뇑뇒뇓뇕"],
        ["8781", "뇖", 5, "뇞뇠", 7, "뇪뇫뇭뇮뇯뇱", 7, "뇺뇼뇾", 5, "눆눇눉눊눍", 6, "눖눘눚", 5, "눡", 18, "눵", 6, "눽", 26, "뉙뉚뉛뉝뉞뉟뉡", 6, "뉪", 4],
        ["8841", "뉯", 4, "뉶", 5, "뉽", 6, "늆늇늈늊", 4],
        ["8861", "늏늒늓늕늖늗늛", 4, "늢늤늧늨늩늫늭늮늯늱늲늳늵늶늷"],
        ["8881", "늸", 15, "닊닋닍닎닏닑닓", 4, "닚닜닞닟닠닡닣닧닩닪닰닱닲닶닼닽닾댂댃댅댆댇댉", 6, "댒댖", 5, "댝", 54, "덗덙덚덝덠덡덢덣"],
        ["8941", "덦덨덪덬덭덯덲덳덵덶덷덹", 6, "뎂뎆", 5, "뎍"],
        ["8961", "뎎뎏뎑뎒뎓뎕", 10, "뎢", 5, "뎩뎪뎫뎭"],
        ["8981", "뎮", 21, "돆돇돉돊돍돏돑돒돓돖돘돚돜돞돟돡돢돣돥돦돧돩", 18, "돽", 18, "됑", 6, "됙됚됛됝됞됟됡", 6, "됪됬", 7, "됵", 15],
        ["8a41", "둅", 10, "둒둓둕둖둗둙", 6, "둢둤둦"],
        ["8a61", "둧", 4, "둭", 18, "뒁뒂"],
        ["8a81", "뒃", 4, "뒉", 19, "뒞", 5, "뒥뒦뒧뒩뒪뒫뒭", 7, "뒶뒸뒺", 5, "듁듂듃듅듆듇듉", 6, "듑듒듓듔듖", 5, "듞듟듡듢듥듧", 4, "듮듰듲", 5, "듹", 26, "딖딗딙딚딝"],
        ["8b41", "딞", 5, "딦딫", 4, "딲딳딵딶딷딹", 6, "땂땆"],
        ["8b61", "땇땈땉땊땎땏땑땒땓땕", 6, "땞땢", 8],
        ["8b81", "땫", 52, "떢떣떥떦떧떩떬떭떮떯떲떶", 4, "떾떿뗁뗂뗃뗅", 6, "뗎뗒", 5, "뗙", 18, "뗭", 18],
        ["8c41", "똀", 15, "똒똓똕똖똗똙", 4],
        ["8c61", "똞", 6, "똦", 5, "똭", 6, "똵", 5],
        ["8c81", "똻", 12, "뙉", 26, "뙥뙦뙧뙩", 50, "뚞뚟뚡뚢뚣뚥", 5, "뚭뚮뚯뚰뚲", 16],
        ["8d41", "뛃", 16, "뛕", 8],
        ["8d61", "뛞", 17, "뛱뛲뛳뛵뛶뛷뛹뛺"],
        ["8d81", "뛻", 4, "뜂뜃뜄뜆", 33, "뜪뜫뜭뜮뜱", 6, "뜺뜼", 7, "띅띆띇띉띊띋띍", 6, "띖", 9, "띡띢띣띥띦띧띩", 6, "띲띴띶", 5, "띾띿랁랂랃랅", 6, "랎랓랔랕랚랛랝랞"],
        ["8e41", "랟랡", 6, "랪랮", 5, "랶랷랹", 8],
        ["8e61", "럂", 4, "럈럊", 19],
        ["8e81", "럞", 13, "럮럯럱럲럳럵", 6, "럾렂", 4, "렊렋렍렎렏렑", 6, "렚렜렞", 5, "렦렧렩렪렫렭", 6, "렶렺", 5, "롁롂롃롅", 11, "롒롔", 7, "롞롟롡롢롣롥", 6, "롮롰롲", 5, "롹롺롻롽", 7],
        ["8f41", "뢅", 7, "뢎", 17],
        ["8f61", "뢠", 7, "뢩", 6, "뢱뢲뢳뢵뢶뢷뢹", 4],
        ["8f81", "뢾뢿룂룄룆", 5, "룍룎룏룑룒룓룕", 7, "룞룠룢", 5, "룪룫룭룮룯룱", 6, "룺룼룾", 5, "뤅", 18, "뤙", 6, "뤡", 26, "뤾뤿륁륂륃륅", 6, "륍륎륐륒", 5],
        ["9041", "륚륛륝륞륟륡", 6, "륪륬륮", 5, "륶륷륹륺륻륽"],
        ["9061", "륾", 5, "릆릈릋릌릏", 15],
        ["9081", "릟", 12, "릮릯릱릲릳릵", 6, "릾맀맂", 5, "맊맋맍맓", 4, "맚맜맟맠맢맦맧맩맪맫맭", 6, "맶맻", 4, "먂", 5, "먉", 11, "먖", 33, "먺먻먽먾먿멁멃멄멅멆"],
        ["9141", "멇멊멌멏멐멑멒멖멗멙멚멛멝", 6, "멦멪", 5],
        ["9161", "멲멳멵멶멷멹", 9, "몆몈몉몊몋몍", 5],
        ["9181", "몓", 20, "몪몭몮몯몱몳", 4, "몺몼몾", 5, "뫅뫆뫇뫉", 14, "뫚", 33, "뫽뫾뫿묁묂묃묅", 7, "묎묐묒", 5, "묙묚묛묝묞묟묡", 6],
        ["9241", "묨묪묬", 7, "묷묹묺묿", 4, "뭆뭈뭊뭋뭌뭎뭑뭒"],
        ["9261", "뭓뭕뭖뭗뭙", 7, "뭢뭤", 7, "뭭", 4],
        ["9281", "뭲", 21, "뮉뮊뮋뮍뮎뮏뮑", 18, "뮥뮦뮧뮩뮪뮫뮭", 6, "뮵뮶뮸", 7, "믁믂믃믅믆믇믉", 6, "믑믒믔", 35, "믺믻믽믾밁"],
        ["9341", "밃", 4, "밊밎밐밒밓밙밚밠밡밢밣밦밨밪밫밬밮밯밲밳밵"],
        ["9361", "밶밷밹", 6, "뱂뱆뱇뱈뱊뱋뱎뱏뱑", 8],
        ["9381", "뱚뱛뱜뱞", 37, "벆벇벉벊벍벏", 4, "벖벘벛", 4, "벢벣벥벦벩", 6, "벲벶", 5, "벾벿볁볂볃볅", 7, "볎볒볓볔볖볗볙볚볛볝", 22, "볷볹볺볻볽"],
        ["9441", "볾", 5, "봆봈봊", 5, "봑봒봓봕", 8],
        ["9461", "봞", 5, "봥", 6, "봭", 12],
        ["9481", "봺", 5, "뵁", 6, "뵊뵋뵍뵎뵏뵑", 6, "뵚", 9, "뵥뵦뵧뵩", 22, "붂붃붅붆붋", 4, "붒붔붖붗붘붛붝", 6, "붥", 10, "붱", 6, "붹", 24],
        ["9541", "뷒뷓뷖뷗뷙뷚뷛뷝", 11, "뷪", 5, "뷱"],
        ["9561", "뷲뷳뷵뷶뷷뷹", 6, "븁븂븄븆", 5, "븎븏븑븒븓"],
        ["9581", "븕", 6, "븞븠", 35, "빆빇빉빊빋빍빏", 4, "빖빘빜빝빞빟빢빣빥빦빧빩빫", 4, "빲빶", 4, "빾빿뺁뺂뺃뺅", 6, "뺎뺒", 5, "뺚", 13, "뺩", 14],
        ["9641", "뺸", 23, "뻒뻓"],
        ["9661", "뻕뻖뻙", 6, "뻡뻢뻦", 5, "뻭", 8],
        ["9681", "뻶", 10, "뼂", 5, "뼊", 13, "뼚뼞", 33, "뽂뽃뽅뽆뽇뽉", 6, "뽒뽓뽔뽖", 44],
        ["9741", "뾃", 16, "뾕", 8],
        ["9761", "뾞", 17, "뾱", 7],
        ["9781", "뾹", 11, "뿆", 5, "뿎뿏뿑뿒뿓뿕", 6, "뿝뿞뿠뿢", 89, "쀽쀾쀿"],
        ["9841", "쁀", 16, "쁒", 5, "쁙쁚쁛"],
        ["9861", "쁝쁞쁟쁡", 6, "쁪", 15],
        ["9881", "쁺", 21, "삒삓삕삖삗삙", 6, "삢삤삦", 5, "삮삱삲삷", 4, "삾샂샃샄샆샇샊샋샍샎샏샑", 6, "샚샞", 5, "샦샧샩샪샫샭", 6, "샶샸샺", 5, "섁섂섃섅섆섇섉", 6, "섑섒섓섔섖", 5, "섡섢섥섨섩섪섫섮"],
        ["9941", "섲섳섴섵섷섺섻섽섾섿셁", 6, "셊셎", 5, "셖셗"],
        ["9961", "셙셚셛셝", 6, "셦셪", 5, "셱셲셳셵셶셷셹셺셻"],
        ["9981", "셼", 8, "솆", 5, "솏솑솒솓솕솗", 4, "솞솠솢솣솤솦솧솪솫솭솮솯솱", 11, "솾", 5, "쇅쇆쇇쇉쇊쇋쇍", 6, "쇕쇖쇙", 6, "쇡쇢쇣쇥쇦쇧쇩", 6, "쇲쇴", 7, "쇾쇿숁숂숃숅", 6, "숎숐숒", 5, "숚숛숝숞숡숢숣"],
        ["9a41", "숤숥숦숧숪숬숮숰숳숵", 16],
        ["9a61", "쉆쉇쉉", 6, "쉒쉓쉕쉖쉗쉙", 6, "쉡쉢쉣쉤쉦"],
        ["9a81", "쉧", 4, "쉮쉯쉱쉲쉳쉵", 6, "쉾슀슂", 5, "슊", 5, "슑", 6, "슙슚슜슞", 5, "슦슧슩슪슫슮", 5, "슶슸슺", 33, "싞싟싡싢싥", 5, "싮싰싲싳싴싵싷싺싽싾싿쌁", 6, "쌊쌋쌎쌏"],
        ["9b41", "쌐쌑쌒쌖쌗쌙쌚쌛쌝", 6, "쌦쌧쌪", 8],
        ["9b61", "쌳", 17, "썆", 7],
        ["9b81", "썎", 25, "썪썫썭썮썯썱썳", 4, "썺썻썾", 5, "쎅쎆쎇쎉쎊쎋쎍", 50, "쏁", 22, "쏚"],
        ["9c41", "쏛쏝쏞쏡쏣", 4, "쏪쏫쏬쏮", 5, "쏶쏷쏹", 5],
        ["9c61", "쏿", 8, "쐉", 6, "쐑", 9],
        ["9c81", "쐛", 8, "쐥", 6, "쐭쐮쐯쐱쐲쐳쐵", 6, "쐾", 9, "쑉", 26, "쑦쑧쑩쑪쑫쑭", 6, "쑶쑷쑸쑺", 5, "쒁", 18, "쒕", 6, "쒝", 12],
        ["9d41", "쒪", 13, "쒹쒺쒻쒽", 8],
        ["9d61", "쓆", 25],
        ["9d81", "쓠", 8, "쓪", 5, "쓲쓳쓵쓶쓷쓹쓻쓼쓽쓾씂", 9, "씍씎씏씑씒씓씕", 6, "씝", 10, "씪씫씭씮씯씱", 6, "씺씼씾", 5, "앆앇앋앏앐앑앒앖앚앛앜앟앢앣앥앦앧앩", 6, "앲앶", 5, "앾앿얁얂얃얅얆얈얉얊얋얎얐얒얓얔"],
        ["9e41", "얖얙얚얛얝얞얟얡", 7, "얪", 9, "얶"],
        ["9e61", "얷얺얿", 4, "엋엍엏엒엓엕엖엗엙", 6, "엢엤엦엧"],
        ["9e81", "엨엩엪엫엯엱엲엳엵엸엹엺엻옂옃옄옉옊옋옍옎옏옑", 6, "옚옝", 6, "옦옧옩옪옫옯옱옲옶옸옺옼옽옾옿왂왃왅왆왇왉", 6, "왒왖", 5, "왞왟왡", 10, "왭왮왰왲", 5, "왺왻왽왾왿욁", 6, "욊욌욎", 5, "욖욗욙욚욛욝", 6, "욦"],
        ["9f41", "욨욪", 5, "욲욳욵욶욷욻", 4, "웂웄웆", 5, "웎"],
        ["9f61", "웏웑웒웓웕", 6, "웞웟웢", 5, "웪웫웭웮웯웱웲"],
        ["9f81", "웳", 4, "웺웻웼웾", 5, "윆윇윉윊윋윍", 6, "윖윘윚", 5, "윢윣윥윦윧윩", 6, "윲윴윶윸윹윺윻윾윿읁읂읃읅", 4, "읋읎읐읙읚읛읝읞읟읡", 6, "읩읪읬", 7, "읶읷읹읺읻읿잀잁잂잆잋잌잍잏잒잓잕잙잛", 4, "잢잧", 4, "잮잯잱잲잳잵잶잷"],
        ["a041", "잸잹잺잻잾쟂", 5, "쟊쟋쟍쟏쟑", 6, "쟙쟚쟛쟜"],
        ["a061", "쟞", 5, "쟥쟦쟧쟩쟪쟫쟭", 13],
        ["a081", "쟻", 4, "젂젃젅젆젇젉젋", 4, "젒젔젗", 4, "젞젟젡젢젣젥", 6, "젮젰젲", 5, "젹젺젻젽젾젿졁", 6, "졊졋졎", 5, "졕", 26, "졲졳졵졶졷졹졻", 4, "좂좄좈좉좊좎", 5, "좕", 7, "좞좠좢좣좤"],
        ["a141", "좥좦좧좩", 18, "좾좿죀죁"],
        ["a161", "죂죃죅죆죇죉죊죋죍", 6, "죖죘죚", 5, "죢죣죥"],
        ["a181", "죦", 14, "죶", 5, "죾죿줁줂줃줇", 4, "줎　、。·‥…¨〃­―∥＼∼‘’“”〔〕〈", 9, "±×÷≠≤≥∞∴°′″℃Å￠￡￥♂♀∠⊥⌒∂∇≡≒§※☆★○●◎◇◆□■△▲▽▼→←↑↓↔〓≪≫√∽∝∵∫∬∈∋⊆⊇⊂⊃∪∩∧∨￢"],
        ["a241", "줐줒", 5, "줙", 18],
        ["a261", "줭", 6, "줵", 18],
        ["a281", "쥈", 7, "쥒쥓쥕쥖쥗쥙", 6, "쥢쥤", 7, "쥭쥮쥯⇒⇔∀∃´～ˇ˘˝˚˙¸˛¡¿ː∮∑∏¤℉‰◁◀▷▶♤♠♡♥♧♣⊙◈▣◐◑▒▤▥▨▧▦▩♨☏☎☜☞¶†‡↕↗↙↖↘♭♩♪♬㉿㈜№㏇™㏂㏘℡€®"],
        ["a341", "쥱쥲쥳쥵", 6, "쥽", 10, "즊즋즍즎즏"],
        ["a361", "즑", 6, "즚즜즞", 16],
        ["a381", "즯", 16, "짂짃짅짆짉짋", 4, "짒짔짗짘짛！", 58, "￦］", 32, "￣"],
        ["a441", "짞짟짡짣짥짦짨짩짪짫짮짲", 5, "짺짻짽짾짿쨁쨂쨃쨄"],
        ["a461", "쨅쨆쨇쨊쨎", 5, "쨕쨖쨗쨙", 12],
        ["a481", "쨦쨧쨨쨪", 28, "ㄱ", 93],
        ["a541", "쩇", 4, "쩎쩏쩑쩒쩓쩕", 6, "쩞쩢", 5, "쩩쩪"],
        ["a561", "쩫", 17, "쩾", 5, "쪅쪆"],
        ["a581", "쪇", 16, "쪙", 14, "ⅰ", 9],
        ["a5b0", "Ⅰ", 9],
        ["a5c1", "Α", 16, "Σ", 6],
        ["a5e1", "α", 16, "σ", 6],
        ["a641", "쪨", 19, "쪾쪿쫁쫂쫃쫅"],
        ["a661", "쫆", 5, "쫎쫐쫒쫔쫕쫖쫗쫚", 5, "쫡", 6],
        ["a681", "쫨쫩쫪쫫쫭", 6, "쫵", 18, "쬉쬊─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂┒┑┚┙┖┕┎┍┞┟┡┢┦┧┩┪┭┮┱┲┵┶┹┺┽┾╀╁╃", 7],
        ["a741", "쬋", 4, "쬑쬒쬓쬕쬖쬗쬙", 6, "쬢", 7],
        ["a761", "쬪", 22, "쭂쭃쭄"],
        ["a781", "쭅쭆쭇쭊쭋쭍쭎쭏쭑", 6, "쭚쭛쭜쭞", 5, "쭥", 7, "㎕㎖㎗ℓ㎘㏄㎣㎤㎥㎦㎙", 9, "㏊㎍㎎㎏㏏㎈㎉㏈㎧㎨㎰", 9, "㎀", 4, "㎺", 5, "㎐", 4, "Ω㏀㏁㎊㎋㎌㏖㏅㎭㎮㎯㏛㎩㎪㎫㎬㏝㏐㏓㏃㏉㏜㏆"],
        ["a841", "쭭", 10, "쭺", 14],
        ["a861", "쮉", 18, "쮝", 6],
        ["a881", "쮤", 19, "쮹", 11, "ÆÐªĦ"],
        ["a8a6", "Ĳ"],
        ["a8a8", "ĿŁØŒºÞŦŊ"],
        ["a8b1", "㉠", 27, "ⓐ", 25, "①", 14, "½⅓⅔¼¾⅛⅜⅝⅞"],
        ["a941", "쯅", 14, "쯕", 10],
        ["a961", "쯠쯡쯢쯣쯥쯦쯨쯪", 18],
        ["a981", "쯽", 14, "찎찏찑찒찓찕", 6, "찞찟찠찣찤æđðħıĳĸŀłøœßþŧŋŉ㈀", 27, "⒜", 25, "⑴", 14, "¹²³⁴ⁿ₁₂₃₄"],
        ["aa41", "찥찦찪찫찭찯찱", 6, "찺찿", 4, "챆챇챉챊챋챍챎"],
        ["aa61", "챏", 4, "챖챚", 5, "챡챢챣챥챧챩", 6, "챱챲"],
        ["aa81", "챳챴챶", 29, "ぁ", 82],
        ["ab41", "첔첕첖첗첚첛첝첞첟첡", 6, "첪첮", 5, "첶첷첹"],
        ["ab61", "첺첻첽", 6, "쳆쳈쳊", 5, "쳑쳒쳓쳕", 5],
        ["ab81", "쳛", 8, "쳥", 6, "쳭쳮쳯쳱", 12, "ァ", 85],
        ["ac41", "쳾쳿촀촂", 5, "촊촋촍촎촏촑", 6, "촚촜촞촟촠"],
        ["ac61", "촡촢촣촥촦촧촩촪촫촭", 11, "촺", 4],
        ["ac81", "촿", 28, "쵝쵞쵟А", 5, "ЁЖ", 25],
        ["acd1", "а", 5, "ёж", 25],
        ["ad41", "쵡쵢쵣쵥", 6, "쵮쵰쵲", 5, "쵹", 7],
        ["ad61", "춁", 6, "춉", 10, "춖춗춙춚춛춝춞춟"],
        ["ad81", "춠춡춢춣춦춨춪", 5, "춱", 18, "췅"],
        ["ae41", "췆", 5, "췍췎췏췑", 16],
        ["ae61", "췢", 5, "췩췪췫췭췮췯췱", 6, "췺췼췾", 4],
        ["ae81", "츃츅츆츇츉츊츋츍", 6, "츕츖츗츘츚", 5, "츢츣츥츦츧츩츪츫"],
        ["af41", "츬츭츮츯츲츴츶", 19],
        ["af61", "칊", 13, "칚칛칝칞칢", 5, "칪칬"],
        ["af81", "칮", 5, "칶칷칹칺칻칽", 6, "캆캈캊", 5, "캒캓캕캖캗캙"],
        ["b041", "캚", 5, "캢캦", 5, "캮", 12],
        ["b061", "캻", 5, "컂", 19],
        ["b081", "컖", 13, "컦컧컩컪컭", 6, "컶컺", 5, "가각간갇갈갉갊감", 7, "같", 4, "갠갤갬갭갯갰갱갸갹갼걀걋걍걔걘걜거걱건걷걸걺검겁것겄겅겆겉겊겋게겐겔겜겝겟겠겡겨격겪견겯결겸겹겻겼경곁계곈곌곕곗고곡곤곧골곪곬곯곰곱곳공곶과곽관괄괆"],
        ["b141", "켂켃켅켆켇켉", 6, "켒켔켖", 5, "켝켞켟켡켢켣"],
        ["b161", "켥", 6, "켮켲", 5, "켹", 11],
        ["b181", "콅", 14, "콖콗콙콚콛콝", 6, "콦콨콪콫콬괌괍괏광괘괜괠괩괬괭괴괵괸괼굄굅굇굉교굔굘굡굣구국군굳굴굵굶굻굼굽굿궁궂궈궉권궐궜궝궤궷귀귁귄귈귐귑귓규균귤그극근귿글긁금급긋긍긔기긱긴긷길긺김깁깃깅깆깊까깍깎깐깔깖깜깝깟깠깡깥깨깩깬깰깸"],
        ["b241", "콭콮콯콲콳콵콶콷콹", 6, "쾁쾂쾃쾄쾆", 5, "쾍"],
        ["b261", "쾎", 18, "쾢", 5, "쾩"],
        ["b281", "쾪", 5, "쾱", 18, "쿅", 6, "깹깻깼깽꺄꺅꺌꺼꺽꺾껀껄껌껍껏껐껑께껙껜껨껫껭껴껸껼꼇꼈꼍꼐꼬꼭꼰꼲꼴꼼꼽꼿꽁꽂꽃꽈꽉꽐꽜꽝꽤꽥꽹꾀꾄꾈꾐꾑꾕꾜꾸꾹꾼꿀꿇꿈꿉꿋꿍꿎꿔꿜꿨꿩꿰꿱꿴꿸뀀뀁뀄뀌뀐뀔뀜뀝뀨끄끅끈끊끌끎끓끔끕끗끙"],
        ["b341", "쿌", 19, "쿢쿣쿥쿦쿧쿩"],
        ["b361", "쿪", 5, "쿲쿴쿶", 5, "쿽쿾쿿퀁퀂퀃퀅", 5],
        ["b381", "퀋", 5, "퀒", 5, "퀙", 19, "끝끼끽낀낄낌낍낏낑나낙낚난낟날낡낢남납낫", 4, "낱낳내낵낸낼냄냅냇냈냉냐냑냔냘냠냥너넉넋넌널넒넓넘넙넛넜넝넣네넥넨넬넴넵넷넸넹녀녁년녈념녑녔녕녘녜녠노녹논놀놂놈놉놋농높놓놔놘놜놨뇌뇐뇔뇜뇝"],
        ["b441", "퀮", 5, "퀶퀷퀹퀺퀻퀽", 6, "큆큈큊", 5],
        ["b461", "큑큒큓큕큖큗큙", 6, "큡", 10, "큮큯"],
        ["b481", "큱큲큳큵", 6, "큾큿킀킂", 18, "뇟뇨뇩뇬뇰뇹뇻뇽누눅눈눋눌눔눕눗눙눠눴눼뉘뉜뉠뉨뉩뉴뉵뉼늄늅늉느늑는늘늙늚늠늡늣능늦늪늬늰늴니닉닌닐닒님닙닛닝닢다닥닦단닫", 4, "닳담답닷", 4, "닿대댁댄댈댐댑댓댔댕댜더덕덖던덛덜덞덟덤덥"],
        ["b541", "킕", 14, "킦킧킩킪킫킭", 5],
        ["b561", "킳킶킸킺", 5, "탂탃탅탆탇탊", 5, "탒탖", 4],
        ["b581", "탛탞탟탡탢탣탥", 6, "탮탲", 5, "탹", 11, "덧덩덫덮데덱덴델뎀뎁뎃뎄뎅뎌뎐뎔뎠뎡뎨뎬도독돈돋돌돎돐돔돕돗동돛돝돠돤돨돼됐되된될됨됩됫됴두둑둔둘둠둡둣둥둬뒀뒈뒝뒤뒨뒬뒵뒷뒹듀듄듈듐듕드득든듣들듦듬듭듯등듸디딕딘딛딜딤딥딧딨딩딪따딱딴딸"],
        ["b641", "턅", 7, "턎", 17],
        ["b661", "턠", 15, "턲턳턵턶턷턹턻턼턽턾"],
        ["b681", "턿텂텆", 5, "텎텏텑텒텓텕", 6, "텞텠텢", 5, "텩텪텫텭땀땁땃땄땅땋때땍땐땔땜땝땟땠땡떠떡떤떨떪떫떰떱떳떴떵떻떼떽뗀뗄뗌뗍뗏뗐뗑뗘뗬또똑똔똘똥똬똴뙈뙤뙨뚜뚝뚠뚤뚫뚬뚱뛔뛰뛴뛸뜀뜁뜅뜨뜩뜬뜯뜰뜸뜹뜻띄띈띌띔띕띠띤띨띰띱띳띵라락란랄람랍랏랐랑랒랖랗"],
        ["b741", "텮", 13, "텽", 6, "톅톆톇톉톊"],
        ["b761", "톋", 20, "톢톣톥톦톧"],
        ["b781", "톩", 6, "톲톴톶톷톸톹톻톽톾톿퇁", 14, "래랙랜랠램랩랫랬랭랴략랸럇량러럭런럴럼럽럿렀렁렇레렉렌렐렘렙렛렝려력련렬렴렵렷렸령례롄롑롓로록론롤롬롭롯롱롸롼뢍뢨뢰뢴뢸룀룁룃룅료룐룔룝룟룡루룩룬룰룸룹룻룽뤄뤘뤠뤼뤽륀륄륌륏륑류륙륜률륨륩"],
        ["b841", "퇐", 7, "퇙", 17],
        ["b861", "퇫", 8, "퇵퇶퇷퇹", 13],
        ["b881", "툈툊", 5, "툑", 24, "륫륭르륵른를름릅릇릉릊릍릎리릭린릴림립릿링마막만많", 4, "맘맙맛망맞맡맣매맥맨맬맴맵맷맸맹맺먀먁먈먕머먹먼멀멂멈멉멋멍멎멓메멕멘멜멤멥멧멨멩며멱면멸몃몄명몇몌모목몫몬몰몲몸몹못몽뫄뫈뫘뫙뫼"],
        ["b941", "툪툫툮툯툱툲툳툵", 6, "툾퉀퉂", 5, "퉉퉊퉋퉌"],
        ["b961", "퉍", 14, "퉝", 6, "퉥퉦퉧퉨"],
        ["b981", "퉩", 22, "튂튃튅튆튇튉튊튋튌묀묄묍묏묑묘묜묠묩묫무묵묶문묻물묽묾뭄뭅뭇뭉뭍뭏뭐뭔뭘뭡뭣뭬뮈뮌뮐뮤뮨뮬뮴뮷므믄믈믐믓미믹민믿밀밂밈밉밋밌밍및밑바", 4, "받", 4, "밤밥밧방밭배백밴밸뱀뱁뱃뱄뱅뱉뱌뱍뱐뱝버벅번벋벌벎범법벗"],
        ["ba41", "튍튎튏튒튓튔튖", 5, "튝튞튟튡튢튣튥", 6, "튭"],
        ["ba61", "튮튯튰튲", 5, "튺튻튽튾틁틃", 4, "틊틌", 5],
        ["ba81", "틒틓틕틖틗틙틚틛틝", 6, "틦", 9, "틲틳틵틶틷틹틺벙벚베벡벤벧벨벰벱벳벴벵벼벽변별볍볏볐병볕볘볜보복볶본볼봄봅봇봉봐봔봤봬뵀뵈뵉뵌뵐뵘뵙뵤뵨부북분붇불붉붊붐붑붓붕붙붚붜붤붰붸뷔뷕뷘뷜뷩뷰뷴뷸븀븃븅브븍븐블븜븝븟비빅빈빌빎빔빕빗빙빚빛빠빡빤"],
        ["bb41", "틻", 4, "팂팄팆", 5, "팏팑팒팓팕팗", 4, "팞팢팣"],
        ["bb61", "팤팦팧팪팫팭팮팯팱", 6, "팺팾", 5, "퍆퍇퍈퍉"],
        ["bb81", "퍊", 31, "빨빪빰빱빳빴빵빻빼빽뺀뺄뺌뺍뺏뺐뺑뺘뺙뺨뻐뻑뻔뻗뻘뻠뻣뻤뻥뻬뼁뼈뼉뼘뼙뼛뼜뼝뽀뽁뽄뽈뽐뽑뽕뾔뾰뿅뿌뿍뿐뿔뿜뿟뿡쀼쁑쁘쁜쁠쁨쁩삐삑삔삘삠삡삣삥사삭삯산삳살삵삶삼삽삿샀상샅새색샌샐샘샙샛샜생샤"],
        ["bc41", "퍪", 17, "퍾퍿펁펂펃펅펆펇"],
        ["bc61", "펈펉펊펋펎펒", 5, "펚펛펝펞펟펡", 6, "펪펬펮"],
        ["bc81", "펯", 4, "펵펶펷펹펺펻펽", 6, "폆폇폊", 5, "폑", 5, "샥샨샬샴샵샷샹섀섄섈섐섕서", 4, "섣설섦섧섬섭섯섰성섶세섹센셀셈셉셋셌셍셔셕션셜셤셥셧셨셩셰셴셸솅소속솎손솔솖솜솝솟송솥솨솩솬솰솽쇄쇈쇌쇔쇗쇘쇠쇤쇨쇰쇱쇳쇼쇽숀숄숌숍숏숑수숙순숟술숨숩숫숭"],
        ["bd41", "폗폙", 7, "폢폤", 7, "폮폯폱폲폳폵폶폷"],
        ["bd61", "폸폹폺폻폾퐀퐂", 5, "퐉", 13],
        ["bd81", "퐗", 5, "퐞", 25, "숯숱숲숴쉈쉐쉑쉔쉘쉠쉥쉬쉭쉰쉴쉼쉽쉿슁슈슉슐슘슛슝스슥슨슬슭슴습슷승시식신싣실싫심십싯싱싶싸싹싻싼쌀쌈쌉쌌쌍쌓쌔쌕쌘쌜쌤쌥쌨쌩썅써썩썬썰썲썸썹썼썽쎄쎈쎌쏀쏘쏙쏜쏟쏠쏢쏨쏩쏭쏴쏵쏸쐈쐐쐤쐬쐰"],
        ["be41", "퐸", 7, "푁푂푃푅", 14],
        ["be61", "푔", 7, "푝푞푟푡푢푣푥", 7, "푮푰푱푲"],
        ["be81", "푳", 4, "푺푻푽푾풁풃", 4, "풊풌풎", 5, "풕", 8, "쐴쐼쐽쑈쑤쑥쑨쑬쑴쑵쑹쒀쒔쒜쒸쒼쓩쓰쓱쓴쓸쓺쓿씀씁씌씐씔씜씨씩씬씰씸씹씻씽아악안앉않알앍앎앓암압앗았앙앝앞애액앤앨앰앱앳앴앵야약얀얄얇얌얍얏양얕얗얘얜얠얩어억언얹얻얼얽얾엄", 6, "엌엎"],
        ["bf41", "풞", 10, "풪", 14],
        ["bf61", "풹", 18, "퓍퓎퓏퓑퓒퓓퓕"],
        ["bf81", "퓖", 5, "퓝퓞퓠", 7, "퓩퓪퓫퓭퓮퓯퓱", 6, "퓹퓺퓼에엑엔엘엠엡엣엥여역엮연열엶엷염", 5, "옅옆옇예옌옐옘옙옛옜오옥온올옭옮옰옳옴옵옷옹옻와왁완왈왐왑왓왔왕왜왝왠왬왯왱외왹왼욀욈욉욋욍요욕욘욜욤욥욧용우욱운울욹욺움웁웃웅워웍원월웜웝웠웡웨"],
        ["c041", "퓾", 5, "픅픆픇픉픊픋픍", 6, "픖픘", 5],
        ["c061", "픞", 25],
        ["c081", "픸픹픺픻픾픿핁핂핃핅", 6, "핎핐핒", 5, "핚핛핝핞핟핡핢핣웩웬웰웸웹웽위윅윈윌윔윕윗윙유육윤율윰윱윳융윷으윽은을읊음읍읏응", 7, "읜읠읨읫이익인일읽읾잃임입잇있잉잊잎자작잔잖잗잘잚잠잡잣잤장잦재잭잰잴잼잽잿쟀쟁쟈쟉쟌쟎쟐쟘쟝쟤쟨쟬저적전절젊"],
        ["c141", "핤핦핧핪핬핮", 5, "핶핷핹핺핻핽", 6, "햆햊햋"],
        ["c161", "햌햍햎햏햑", 19, "햦햧"],
        ["c181", "햨", 31, "점접젓정젖제젝젠젤젬젭젯젱져젼졀졈졉졌졍졔조족존졸졺좀좁좃종좆좇좋좌좍좔좝좟좡좨좼좽죄죈죌죔죕죗죙죠죡죤죵주죽준줄줅줆줌줍줏중줘줬줴쥐쥑쥔쥘쥠쥡쥣쥬쥰쥴쥼즈즉즌즐즘즙즛증지직진짇질짊짐집짓"],
        ["c241", "헊헋헍헎헏헑헓", 4, "헚헜헞", 5, "헦헧헩헪헫헭헮"],
        ["c261", "헯", 4, "헶헸헺", 5, "혂혃혅혆혇혉", 6, "혒"],
        ["c281", "혖", 5, "혝혞혟혡혢혣혥", 7, "혮", 9, "혺혻징짖짙짚짜짝짠짢짤짧짬짭짯짰짱째짹짼쨀쨈쨉쨋쨌쨍쨔쨘쨩쩌쩍쩐쩔쩜쩝쩟쩠쩡쩨쩽쪄쪘쪼쪽쫀쫄쫌쫍쫏쫑쫓쫘쫙쫠쫬쫴쬈쬐쬔쬘쬠쬡쭁쭈쭉쭌쭐쭘쭙쭝쭤쭸쭹쮜쮸쯔쯤쯧쯩찌찍찐찔찜찝찡찢찧차착찬찮찰참찹찻"],
        ["c341", "혽혾혿홁홂홃홄홆홇홊홌홎홏홐홒홓홖홗홙홚홛홝", 4],
        ["c361", "홢", 4, "홨홪", 5, "홲홳홵", 11],
        ["c381", "횁횂횄횆", 5, "횎횏횑횒횓횕", 7, "횞횠횢", 5, "횩횪찼창찾채책챈챌챔챕챗챘챙챠챤챦챨챰챵처척천철첨첩첫첬청체첵첸첼쳄쳅쳇쳉쳐쳔쳤쳬쳰촁초촉촌촐촘촙촛총촤촨촬촹최쵠쵤쵬쵭쵯쵱쵸춈추축춘출춤춥춧충춰췄췌췐취췬췰췸췹췻췽츄츈츌츔츙츠측츤츨츰츱츳층"],
        ["c441", "횫횭횮횯횱", 7, "횺횼", 7, "훆훇훉훊훋"],
        ["c461", "훍훎훏훐훒훓훕훖훘훚", 5, "훡훢훣훥훦훧훩", 4],
        ["c481", "훮훯훱훲훳훴훶", 5, "훾훿휁휂휃휅", 11, "휒휓휔치칙친칟칠칡침칩칫칭카칵칸칼캄캅캇캉캐캑캔캘캠캡캣캤캥캬캭컁커컥컨컫컬컴컵컷컸컹케켁켄켈켐켑켓켕켜켠켤켬켭켯켰켱켸코콕콘콜콤콥콧콩콰콱콴콸쾀쾅쾌쾡쾨쾰쿄쿠쿡쿤쿨쿰쿱쿳쿵쿼퀀퀄퀑퀘퀭퀴퀵퀸퀼"],
        ["c541", "휕휖휗휚휛휝휞휟휡", 6, "휪휬휮", 5, "휶휷휹"],
        ["c561", "휺휻휽", 6, "흅흆흈흊", 5, "흒흓흕흚", 4],
        ["c581", "흟흢흤흦흧흨흪흫흭흮흯흱흲흳흵", 6, "흾흿힀힂", 5, "힊힋큄큅큇큉큐큔큘큠크큭큰클큼큽킁키킥킨킬킴킵킷킹타탁탄탈탉탐탑탓탔탕태택탠탤탬탭탯탰탱탸턍터턱턴털턺텀텁텃텄텅테텍텐텔템텝텟텡텨텬텼톄톈토톡톤톨톰톱톳통톺톼퇀퇘퇴퇸툇툉툐투툭툰툴툼툽툿퉁퉈퉜"],
        ["c641", "힍힎힏힑", 6, "힚힜힞", 5],
        ["c6a1", "퉤튀튁튄튈튐튑튕튜튠튤튬튱트특튼튿틀틂틈틉틋틔틘틜틤틥티틱틴틸팀팁팃팅파팍팎판팔팖팜팝팟팠팡팥패팩팬팰팸팹팻팼팽퍄퍅퍼퍽펀펄펌펍펏펐펑페펙펜펠펨펩펫펭펴편펼폄폅폈평폐폘폡폣포폭폰폴폼폽폿퐁"],
        ["c7a1", "퐈퐝푀푄표푠푤푭푯푸푹푼푿풀풂품풉풋풍풔풩퓌퓐퓔퓜퓟퓨퓬퓰퓸퓻퓽프픈플픔픕픗피픽핀필핌핍핏핑하학한할핥함합핫항해핵핸핼햄햅햇했행햐향허헉헌헐헒험헙헛헝헤헥헨헬헴헵헷헹혀혁현혈혐협혓혔형혜혠"],
        ["c8a1", "혤혭호혹혼홀홅홈홉홋홍홑화확환활홧황홰홱홴횃횅회획횐횔횝횟횡효횬횰횹횻후훅훈훌훑훔훗훙훠훤훨훰훵훼훽휀휄휑휘휙휜휠휨휩휫휭휴휵휸휼흄흇흉흐흑흔흖흗흘흙흠흡흣흥흩희흰흴흼흽힁히힉힌힐힘힙힛힝"],
        ["caa1", "伽佳假價加可呵哥嘉嫁家暇架枷柯歌珂痂稼苛茄街袈訶賈跏軻迦駕刻却各恪慤殼珏脚覺角閣侃刊墾奸姦干幹懇揀杆柬桿澗癎看磵稈竿簡肝艮艱諫間乫喝曷渴碣竭葛褐蝎鞨勘坎堪嵌感憾戡敢柑橄減甘疳監瞰紺邯鑑鑒龕"],
        ["cba1", "匣岬甲胛鉀閘剛堈姜岡崗康强彊慷江畺疆糠絳綱羌腔舡薑襁講鋼降鱇介价個凱塏愷愾慨改槪漑疥皆盖箇芥蓋豈鎧開喀客坑更粳羹醵倨去居巨拒据據擧渠炬祛距踞車遽鉅鋸乾件健巾建愆楗腱虔蹇鍵騫乞傑杰桀儉劍劒檢"],
        ["cca1", "瞼鈐黔劫怯迲偈憩揭擊格檄激膈覡隔堅牽犬甄絹繭肩見譴遣鵑抉決潔結缺訣兼慊箝謙鉗鎌京俓倞傾儆勁勍卿坰境庚徑慶憬擎敬景暻更梗涇炅烱璟璥瓊痙硬磬竟競絅經耕耿脛莖警輕逕鏡頃頸驚鯨係啓堺契季屆悸戒桂械"],
        ["cda1", "棨溪界癸磎稽系繫繼計誡谿階鷄古叩告呱固姑孤尻庫拷攷故敲暠枯槁沽痼皐睾稿羔考股膏苦苽菰藁蠱袴誥賈辜錮雇顧高鼓哭斛曲梏穀谷鵠困坤崑昆梱棍滾琨袞鯤汨滑骨供公共功孔工恐恭拱控攻珙空蚣貢鞏串寡戈果瓜"],
        ["cea1", "科菓誇課跨過鍋顆廓槨藿郭串冠官寬慣棺款灌琯瓘管罐菅觀貫關館刮恝括适侊光匡壙廣曠洸炚狂珖筐胱鑛卦掛罫乖傀塊壞怪愧拐槐魁宏紘肱轟交僑咬喬嬌嶠巧攪敎校橋狡皎矯絞翹膠蕎蛟較轎郊餃驕鮫丘久九仇俱具勾"],
        ["cfa1", "區口句咎嘔坵垢寇嶇廐懼拘救枸柩構歐毆毬求溝灸狗玖球瞿矩究絿耉臼舅舊苟衢謳購軀逑邱鉤銶駒驅鳩鷗龜國局菊鞠鞫麴君窘群裙軍郡堀屈掘窟宮弓穹窮芎躬倦券勸卷圈拳捲權淃眷厥獗蕨蹶闕机櫃潰詭軌饋句晷歸貴"],
        ["d0a1", "鬼龜叫圭奎揆槻珪硅窺竅糾葵規赳逵閨勻均畇筠菌鈞龜橘克剋劇戟棘極隙僅劤勤懃斤根槿瑾筋芹菫覲謹近饉契今妗擒昑檎琴禁禽芩衾衿襟金錦伋及急扱汲級給亘兢矜肯企伎其冀嗜器圻基埼夔奇妓寄岐崎己幾忌技旗旣"],
        ["d1a1", "朞期杞棋棄機欺氣汽沂淇玘琦琪璂璣畸畿碁磯祁祇祈祺箕紀綺羈耆耭肌記譏豈起錡錤飢饑騎騏驥麒緊佶吉拮桔金喫儺喇奈娜懦懶拏拿癩", 5, "那樂", 4, "諾酪駱亂卵暖欄煖爛蘭難鸞捏捺南嵐枏楠湳濫男藍襤拉"],
        ["d2a1", "納臘蠟衲囊娘廊", 4, "乃來內奈柰耐冷女年撚秊念恬拈捻寧寗努勞奴弩怒擄櫓爐瑙盧", 5, "駑魯", 10, "濃籠聾膿農惱牢磊腦賂雷尿壘", 7, "嫩訥杻紐勒", 5, "能菱陵尼泥匿溺多茶"],
        ["d3a1", "丹亶但單團壇彖斷旦檀段湍短端簞緞蛋袒鄲鍛撻澾獺疸達啖坍憺擔曇淡湛潭澹痰聃膽蕁覃談譚錟沓畓答踏遝唐堂塘幢戇撞棠當糖螳黨代垈坮大對岱帶待戴擡玳臺袋貸隊黛宅德悳倒刀到圖堵塗導屠島嶋度徒悼挑掉搗桃"],
        ["d4a1", "棹櫂淘渡滔濤燾盜睹禱稻萄覩賭跳蹈逃途道都鍍陶韜毒瀆牘犢獨督禿篤纛讀墩惇敦旽暾沌焞燉豚頓乭突仝冬凍動同憧東桐棟洞潼疼瞳童胴董銅兜斗杜枓痘竇荳讀豆逗頭屯臀芚遁遯鈍得嶝橙燈登等藤謄鄧騰喇懶拏癩羅"],
        ["d5a1", "蘿螺裸邏樂洛烙珞絡落諾酪駱丹亂卵欄欒瀾爛蘭鸞剌辣嵐擥攬欖濫籃纜藍襤覽拉臘蠟廊朗浪狼琅瑯螂郞來崍徠萊冷掠略亮倆兩凉梁樑粮粱糧良諒輛量侶儷勵呂廬慮戾旅櫚濾礪藜蠣閭驢驪麗黎力曆歷瀝礫轢靂憐戀攣漣"],
        ["d6a1", "煉璉練聯蓮輦連鍊冽列劣洌烈裂廉斂殮濂簾獵令伶囹寧岺嶺怜玲笭羚翎聆逞鈴零靈領齡例澧禮醴隷勞怒撈擄櫓潞瀘爐盧老蘆虜路輅露魯鷺鹵碌祿綠菉錄鹿麓論壟弄朧瀧瓏籠聾儡瀨牢磊賂賚賴雷了僚寮廖料燎療瞭聊蓼"],
        ["d7a1", "遼鬧龍壘婁屢樓淚漏瘻累縷蔞褸鏤陋劉旒柳榴流溜瀏琉瑠留瘤硫謬類六戮陸侖倫崙淪綸輪律慄栗率隆勒肋凜凌楞稜綾菱陵俚利厘吏唎履悧李梨浬犁狸理璃異痢籬罹羸莉裏裡里釐離鯉吝潾燐璘藺躪隣鱗麟林淋琳臨霖砬"],
        ["d8a1", "立笠粒摩瑪痲碼磨馬魔麻寞幕漠膜莫邈万卍娩巒彎慢挽晩曼滿漫灣瞞萬蔓蠻輓饅鰻唜抹末沫茉襪靺亡妄忘忙望網罔芒茫莽輞邙埋妹媒寐昧枚梅每煤罵買賣邁魅脈貊陌驀麥孟氓猛盲盟萌冪覓免冕勉棉沔眄眠綿緬面麵滅"],
        ["d9a1", "蔑冥名命明暝椧溟皿瞑茗蓂螟酩銘鳴袂侮冒募姆帽慕摸摹暮某模母毛牟牡瑁眸矛耗芼茅謀謨貌木沐牧目睦穆鶩歿沒夢朦蒙卯墓妙廟描昴杳渺猫竗苗錨務巫憮懋戊拇撫无楙武毋無珷畝繆舞茂蕪誣貿霧鵡墨默們刎吻問文"],
        ["daa1", "汶紊紋聞蚊門雯勿沕物味媚尾嵋彌微未梶楣渼湄眉米美薇謎迷靡黴岷悶愍憫敏旻旼民泯玟珉緡閔密蜜謐剝博拍搏撲朴樸泊珀璞箔粕縛膊舶薄迫雹駁伴半反叛拌搬攀斑槃泮潘班畔瘢盤盼磐磻礬絆般蟠返頒飯勃拔撥渤潑"],
        ["dba1", "發跋醱鉢髮魃倣傍坊妨尨幇彷房放方旁昉枋榜滂磅紡肪膀舫芳蒡蚌訪謗邦防龐倍俳北培徘拜排杯湃焙盃背胚裴裵褙賠輩配陪伯佰帛柏栢白百魄幡樊煩燔番磻繁蕃藩飜伐筏罰閥凡帆梵氾汎泛犯範范法琺僻劈壁擘檗璧癖"],
        ["dca1", "碧蘗闢霹便卞弁變辨辯邊別瞥鱉鼈丙倂兵屛幷昞昺柄棅炳甁病秉竝輧餠騈保堡報寶普步洑湺潽珤甫菩補褓譜輔伏僕匐卜宓復服福腹茯蔔複覆輹輻馥鰒本乶俸奉封峯峰捧棒烽熢琫縫蓬蜂逢鋒鳳不付俯傅剖副否咐埠夫婦"],
        ["dda1", "孚孵富府復扶敷斧浮溥父符簿缶腐腑膚艀芙莩訃負賦賻赴趺部釜阜附駙鳧北分吩噴墳奔奮忿憤扮昐汾焚盆粉糞紛芬賁雰不佛弗彿拂崩朋棚硼繃鵬丕備匕匪卑妃婢庇悲憊扉批斐枇榧比毖毗毘沸泌琵痺砒碑秕秘粃緋翡肥"],
        ["dea1", "脾臂菲蜚裨誹譬費鄙非飛鼻嚬嬪彬斌檳殯浜濱瀕牝玭貧賓頻憑氷聘騁乍事些仕伺似使俟僿史司唆嗣四士奢娑寫寺射巳師徙思捨斜斯柶査梭死沙泗渣瀉獅砂社祀祠私篩紗絲肆舍莎蓑蛇裟詐詞謝賜赦辭邪飼駟麝削數朔索"],
        ["dfa1", "傘刪山散汕珊産疝算蒜酸霰乷撒殺煞薩三參杉森渗芟蔘衫揷澁鈒颯上傷像償商喪嘗孀尙峠常床庠廂想桑橡湘爽牀狀相祥箱翔裳觴詳象賞霜塞璽賽嗇塞穡索色牲生甥省笙墅壻嶼序庶徐恕抒捿敍暑曙書栖棲犀瑞筮絮緖署"],
        ["e0a1", "胥舒薯西誓逝鋤黍鼠夕奭席惜昔晳析汐淅潟石碩蓆釋錫仙僊先善嬋宣扇敾旋渲煽琁瑄璇璿癬禪線繕羨腺膳船蘚蟬詵跣選銑鐥饍鮮卨屑楔泄洩渫舌薛褻設說雪齧剡暹殲纖蟾贍閃陝攝涉燮葉城姓宬性惺成星晟猩珹盛省筬"],
        ["e1a1", "聖聲腥誠醒世勢歲洗稅笹細說貰召嘯塑宵小少巢所掃搔昭梳沼消溯瀟炤燒甦疏疎瘙笑篠簫素紹蔬蕭蘇訴逍遡邵銷韶騷俗屬束涑粟續謖贖速孫巽損蓀遜飡率宋悚松淞訟誦送頌刷殺灑碎鎖衰釗修受嗽囚垂壽嫂守岫峀帥愁"],
        ["e2a1", "戍手授搜收數樹殊水洙漱燧狩獸琇璲瘦睡秀穗竪粹綏綬繡羞脩茱蒐蓚藪袖誰讐輸遂邃酬銖銹隋隧隨雖需須首髓鬚叔塾夙孰宿淑潚熟琡璹肅菽巡徇循恂旬栒楯橓殉洵淳珣盾瞬筍純脣舜荀蓴蕣詢諄醇錞順馴戌術述鉥崇崧"],
        ["e3a1", "嵩瑟膝蝨濕拾習褶襲丞乘僧勝升承昇繩蠅陞侍匙嘶始媤尸屎屍市弑恃施是時枾柴猜矢示翅蒔蓍視試詩諡豕豺埴寔式息拭植殖湜熄篒蝕識軾食飾伸侁信呻娠宸愼新晨燼申神紳腎臣莘薪藎蜃訊身辛辰迅失室實悉審尋心沁"],
        ["e4a1", "沈深瀋甚芯諶什十拾雙氏亞俄兒啞娥峨我牙芽莪蛾衙訝阿雅餓鴉鵝堊岳嶽幄惡愕握樂渥鄂鍔顎鰐齷安岸按晏案眼雁鞍顔鮟斡謁軋閼唵岩巖庵暗癌菴闇壓押狎鴨仰央怏昻殃秧鴦厓哀埃崖愛曖涯碍艾隘靄厄扼掖液縊腋額"],
        ["e5a1", "櫻罌鶯鸚也倻冶夜惹揶椰爺耶若野弱掠略約若葯蒻藥躍亮佯兩凉壤孃恙揚攘敭暘梁楊樣洋瀁煬痒瘍禳穰糧羊良襄諒讓釀陽量養圄御於漁瘀禦語馭魚齬億憶抑檍臆偃堰彦焉言諺孼蘖俺儼嚴奄掩淹嶪業円予余勵呂女如廬"],
        ["e6a1", "旅歟汝濾璵礖礪與艅茹輿轝閭餘驪麗黎亦力域役易曆歷疫繹譯轢逆驛嚥堧姸娟宴年延憐戀捐挻撚椽沇沿涎涓淵演漣烟然煙煉燃燕璉硏硯秊筵緣練縯聯衍軟輦蓮連鉛鍊鳶列劣咽悅涅烈熱裂說閱厭廉念捻染殮炎焰琰艶苒"],
        ["e7a1", "簾閻髥鹽曄獵燁葉令囹塋寧嶺嶸影怜映暎楹榮永泳渶潁濚瀛瀯煐營獰玲瑛瑩瓔盈穎纓羚聆英詠迎鈴鍈零霙靈領乂倪例刈叡曳汭濊猊睿穢芮藝蘂禮裔詣譽豫醴銳隸霓預五伍俉傲午吾吳嗚塢墺奧娛寤悟惡懊敖旿晤梧汚澳"],
        ["e8a1", "烏熬獒筽蜈誤鰲鼇屋沃獄玉鈺溫瑥瘟穩縕蘊兀壅擁瓮甕癰翁邕雍饔渦瓦窩窪臥蛙蝸訛婉完宛梡椀浣玩琓琬碗緩翫脘腕莞豌阮頑曰往旺枉汪王倭娃歪矮外嵬巍猥畏了僚僥凹堯夭妖姚寥寮尿嶢拗搖撓擾料曜樂橈燎燿瑤療"],
        ["e9a1", "窈窯繇繞耀腰蓼蟯要謠遙遼邀饒慾欲浴縟褥辱俑傭冗勇埇墉容庸慂榕涌湧溶熔瑢用甬聳茸蓉踊鎔鏞龍于佑偶優又友右宇寓尤愚憂旴牛玗瑀盂祐禑禹紆羽芋藕虞迂遇郵釪隅雨雩勖彧旭昱栯煜稶郁頊云暈橒殞澐熉耘芸蕓"],
        ["eaa1", "運隕雲韻蔚鬱亐熊雄元原員圓園垣媛嫄寃怨愿援沅洹湲源爰猿瑗苑袁轅遠阮院願鴛月越鉞位偉僞危圍委威尉慰暐渭爲瑋緯胃萎葦蔿蝟衛褘謂違韋魏乳侑儒兪劉唯喩孺宥幼幽庾悠惟愈愉揄攸有杻柔柚柳楡楢油洧流游溜"],
        ["eba1", "濡猶猷琉瑜由留癒硫紐維臾萸裕誘諛諭踰蹂遊逾遺酉釉鍮類六堉戮毓肉育陸倫允奫尹崙淪潤玧胤贇輪鈗閏律慄栗率聿戎瀜絨融隆垠恩慇殷誾銀隱乙吟淫蔭陰音飮揖泣邑凝應膺鷹依倚儀宜意懿擬椅毅疑矣義艤薏蟻衣誼"],
        ["eca1", "議醫二以伊利吏夷姨履已弛彛怡易李梨泥爾珥理異痍痢移罹而耳肄苡荑裏裡貽貳邇里離飴餌匿溺瀷益翊翌翼謚人仁刃印吝咽因姻寅引忍湮燐璘絪茵藺蚓認隣靭靷鱗麟一佚佾壹日溢逸鎰馹任壬妊姙恁林淋稔臨荏賃入卄"],
        ["eda1", "立笠粒仍剩孕芿仔刺咨姉姿子字孜恣慈滋炙煮玆瓷疵磁紫者自茨蔗藉諮資雌作勺嚼斫昨灼炸爵綽芍酌雀鵲孱棧殘潺盞岑暫潛箴簪蠶雜丈仗匠場墻壯奬將帳庄張掌暲杖樟檣欌漿牆狀獐璋章粧腸臟臧莊葬蔣薔藏裝贓醬長"],
        ["eea1", "障再哉在宰才材栽梓渽滓災縡裁財載齋齎爭箏諍錚佇低儲咀姐底抵杵楮樗沮渚狙猪疽箸紵苧菹著藷詛貯躇這邸雎齟勣吊嫡寂摘敵滴狄炙的積笛籍績翟荻謫賊赤跡蹟迪迹適鏑佃佺傳全典前剪塡塼奠專展廛悛戰栓殿氈澱"],
        ["efa1", "煎琠田甸畑癲筌箋箭篆纏詮輾轉鈿銓錢鐫電顚顫餞切截折浙癤竊節絶占岾店漸点粘霑鮎點接摺蝶丁井亭停偵呈姃定幀庭廷征情挺政整旌晶晸柾楨檉正汀淀淨渟湞瀞炡玎珽町睛碇禎程穽精綎艇訂諪貞鄭酊釘鉦鋌錠霆靖"],
        ["f0a1", "靜頂鼎制劑啼堤帝弟悌提梯濟祭第臍薺製諸蹄醍除際霽題齊俎兆凋助嘲弔彫措操早晁曺曹朝條棗槽漕潮照燥爪璪眺祖祚租稠窕粗糟組繰肇藻蚤詔調趙躁造遭釣阻雕鳥族簇足鏃存尊卒拙猝倧宗從悰慫棕淙琮種終綜縱腫"],
        ["f1a1", "踪踵鍾鐘佐坐左座挫罪主住侏做姝胄呪周嗾奏宙州廚晝朱柱株注洲湊澍炷珠疇籌紂紬綢舟蛛註誅走躊輳週酎酒鑄駐竹粥俊儁准埈寯峻晙樽浚準濬焌畯竣蠢逡遵雋駿茁中仲衆重卽櫛楫汁葺增憎曾拯烝甑症繒蒸證贈之只"],
        ["f2a1", "咫地址志持指摯支旨智枝枳止池沚漬知砥祉祗紙肢脂至芝芷蜘誌識贄趾遲直稙稷織職唇嗔塵振搢晉晋桭榛殄津溱珍瑨璡畛疹盡眞瞋秦縉縝臻蔯袗診賑軫辰進鎭陣陳震侄叱姪嫉帙桎瓆疾秩窒膣蛭質跌迭斟朕什執潗緝輯"],
        ["f3a1", "鏶集徵懲澄且侘借叉嗟嵯差次此磋箚茶蹉車遮捉搾着窄錯鑿齪撰澯燦璨瓚竄簒纂粲纘讚贊鑽餐饌刹察擦札紮僭參塹慘慙懺斬站讒讖倉倡創唱娼廠彰愴敞昌昶暢槍滄漲猖瘡窓脹艙菖蒼債埰寀寨彩採砦綵菜蔡采釵冊柵策"],
        ["f4a1", "責凄妻悽處倜刺剔尺慽戚拓擲斥滌瘠脊蹠陟隻仟千喘天川擅泉淺玔穿舛薦賤踐遷釧闡阡韆凸哲喆徹撤澈綴輟轍鐵僉尖沾添甛瞻簽籤詹諂堞妾帖捷牒疊睫諜貼輒廳晴淸聽菁請靑鯖切剃替涕滯締諦逮遞體初剿哨憔抄招梢"],
        ["f5a1", "椒楚樵炒焦硝礁礎秒稍肖艸苕草蕉貂超酢醋醮促囑燭矗蜀觸寸忖村邨叢塚寵悤憁摠總聰蔥銃撮催崔最墜抽推椎楸樞湫皺秋芻萩諏趨追鄒酋醜錐錘鎚雛騶鰍丑畜祝竺筑築縮蓄蹙蹴軸逐春椿瑃出朮黜充忠沖蟲衝衷悴膵萃"],
        ["f6a1", "贅取吹嘴娶就炊翠聚脆臭趣醉驟鷲側仄厠惻測層侈値嗤峙幟恥梔治淄熾痔痴癡稚穉緇緻置致蚩輜雉馳齒則勅飭親七柒漆侵寢枕沈浸琛砧針鍼蟄秤稱快他咤唾墮妥惰打拖朶楕舵陀馱駝倬卓啄坼度托拓擢晫柝濁濯琢琸託"],
        ["f7a1", "鐸呑嘆坦彈憚歎灘炭綻誕奪脫探眈耽貪塔搭榻宕帑湯糖蕩兌台太怠態殆汰泰笞胎苔跆邰颱宅擇澤撑攄兎吐土討慟桶洞痛筒統通堆槌腿褪退頹偸套妬投透鬪慝特闖坡婆巴把播擺杷波派爬琶破罷芭跛頗判坂板版瓣販辦鈑"],
        ["f8a1", "阪八叭捌佩唄悖敗沛浿牌狽稗覇貝彭澎烹膨愎便偏扁片篇編翩遍鞭騙貶坪平枰萍評吠嬖幣廢弊斃肺蔽閉陛佈包匍匏咆哺圃布怖抛抱捕暴泡浦疱砲胞脯苞葡蒲袍褒逋鋪飽鮑幅暴曝瀑爆輻俵剽彪慓杓標漂瓢票表豹飇飄驃"],
        ["f9a1", "品稟楓諷豊風馮彼披疲皮被避陂匹弼必泌珌畢疋筆苾馝乏逼下何厦夏廈昰河瑕荷蝦賀遐霞鰕壑學虐謔鶴寒恨悍旱汗漢澣瀚罕翰閑閒限韓割轄函含咸啣喊檻涵緘艦銜陷鹹合哈盒蛤閤闔陜亢伉姮嫦巷恒抗杭桁沆港缸肛航"],
        ["faa1", "行降項亥偕咳垓奚孩害懈楷海瀣蟹解該諧邂駭骸劾核倖幸杏荇行享向嚮珦鄕響餉饗香噓墟虛許憲櫶獻軒歇險驗奕爀赫革俔峴弦懸晛泫炫玄玹現眩睍絃絢縣舷衒見賢鉉顯孑穴血頁嫌俠協夾峽挾浹狹脅脇莢鋏頰亨兄刑型"],
        ["fba1", "形泂滎瀅灐炯熒珩瑩荊螢衡逈邢鎣馨兮彗惠慧暳蕙蹊醯鞋乎互呼壕壺好岵弧戶扈昊晧毫浩淏湖滸澔濠濩灝狐琥瑚瓠皓祜糊縞胡芦葫蒿虎號蝴護豪鎬頀顥惑或酷婚昏混渾琿魂忽惚笏哄弘汞泓洪烘紅虹訌鴻化和嬅樺火畵"],
        ["fca1", "禍禾花華話譁貨靴廓擴攫確碻穫丸喚奐宦幻患換歡晥桓渙煥環紈還驩鰥活滑猾豁闊凰幌徨恍惶愰慌晃晄榥況湟滉潢煌璜皇篁簧荒蝗遑隍黃匯回廻徊恢悔懷晦會檜淮澮灰獪繪膾茴蛔誨賄劃獲宖橫鐄哮嚆孝效斅曉梟涍淆"],
        ["fda1", "爻肴酵驍侯候厚后吼喉嗅帿後朽煦珝逅勛勳塤壎焄熏燻薰訓暈薨喧暄煊萱卉喙毁彙徽揮暉煇諱輝麾休携烋畦虧恤譎鷸兇凶匈洶胸黑昕欣炘痕吃屹紇訖欠欽歆吸恰洽翕興僖凞喜噫囍姬嬉希憙憘戱晞曦熙熹熺犧禧稀羲詰"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/cp950.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 127],
        ["a140", "　，、。．‧；：？！︰…‥﹐﹑﹒·﹔﹕﹖﹗｜–︱—︳╴︴﹏（）︵︶｛｝︷︸〔〕︹︺【】︻︼《》︽︾〈〉︿﹀「」﹁﹂『』﹃﹄﹙﹚"],
        ["a1a1", "﹛﹜﹝﹞‘’“”〝〞‵′＃＆＊※§〃○●△▲◎☆★◇◆□■▽▼㊣℅¯￣＿ˍ﹉﹊﹍﹎﹋﹌﹟﹠﹡＋－×÷±√＜＞＝≦≧≠∞≒≡﹢", 4, "～∩∪⊥∠∟⊿㏒㏑∫∮∵∴♀♂⊕⊙↑↓←→↖↗↙↘∥∣／"],
        ["a240", "＼∕﹨＄￥〒￠￡％＠℃℉﹩﹪﹫㏕㎜㎝㎞㏎㎡㎎㎏㏄°兙兛兞兝兡兣嗧瓩糎▁", 7, "▏▎▍▌▋▊▉┼┴┬┤├▔─│▕┌┐└┘╭"],
        ["a2a1", "╮╰╯═╞╪╡◢◣◥◤╱╲╳０", 9, "Ⅰ", 9, "〡", 8, "十卄卅Ａ", 25, "ａ", 21],
        ["a340", "ｗｘｙｚΑ", 16, "Σ", 6, "α", 16, "σ", 6, "ㄅ", 10],
        ["a3a1", "ㄐ", 25, "˙ˉˊˇˋ"],
        ["a3e1", "€"],
        ["a440", "一乙丁七乃九了二人儿入八几刀刁力匕十卜又三下丈上丫丸凡久么也乞于亡兀刃勺千叉口土士夕大女子孑孓寸小尢尸山川工己已巳巾干廾弋弓才"],
        ["a4a1", "丑丐不中丰丹之尹予云井互五亢仁什仃仆仇仍今介仄元允內六兮公冗凶分切刈勻勾勿化匹午升卅卞厄友及反壬天夫太夭孔少尤尺屯巴幻廿弔引心戈戶手扎支文斗斤方日曰月木欠止歹毋比毛氏水火爪父爻片牙牛犬王丙"],
        ["a540", "世丕且丘主乍乏乎以付仔仕他仗代令仙仞充兄冉冊冬凹出凸刊加功包匆北匝仟半卉卡占卯卮去可古右召叮叩叨叼司叵叫另只史叱台句叭叻四囚外"],
        ["a5a1", "央失奴奶孕它尼巨巧左市布平幼弁弘弗必戊打扔扒扑斥旦朮本未末札正母民氐永汁汀氾犯玄玉瓜瓦甘生用甩田由甲申疋白皮皿目矛矢石示禾穴立丞丟乒乓乩亙交亦亥仿伉伙伊伕伍伐休伏仲件任仰仳份企伋光兇兆先全"],
        ["a640", "共再冰列刑划刎刖劣匈匡匠印危吉吏同吊吐吁吋各向名合吃后吆吒因回囝圳地在圭圬圯圩夙多夷夸妄奸妃好她如妁字存宇守宅安寺尖屹州帆并年"],
        ["a6a1", "式弛忙忖戎戌戍成扣扛托收早旨旬旭曲曳有朽朴朱朵次此死氖汝汗汙江池汐汕污汛汍汎灰牟牝百竹米糸缶羊羽老考而耒耳聿肉肋肌臣自至臼舌舛舟艮色艾虫血行衣西阡串亨位住佇佗佞伴佛何估佐佑伽伺伸佃佔似但佣"],
        ["a740", "作你伯低伶余佝佈佚兌克免兵冶冷別判利刪刨劫助努劬匣即卵吝吭吞吾否呎吧呆呃吳呈呂君吩告吹吻吸吮吵吶吠吼呀吱含吟听囪困囤囫坊坑址坍"],
        ["a7a1", "均坎圾坐坏圻壯夾妝妒妨妞妣妙妖妍妤妓妊妥孝孜孚孛完宋宏尬局屁尿尾岐岑岔岌巫希序庇床廷弄弟彤形彷役忘忌志忍忱快忸忪戒我抄抗抖技扶抉扭把扼找批扳抒扯折扮投抓抑抆改攻攸旱更束李杏材村杜杖杞杉杆杠"],
        ["a840", "杓杗步每求汞沙沁沈沉沅沛汪決沐汰沌汨沖沒汽沃汲汾汴沆汶沍沔沘沂灶灼災灸牢牡牠狄狂玖甬甫男甸皂盯矣私秀禿究系罕肖肓肝肘肛肚育良芒"],
        ["a8a1", "芋芍見角言谷豆豕貝赤走足身車辛辰迂迆迅迄巡邑邢邪邦那酉釆里防阮阱阪阬並乖乳事些亞享京佯依侍佳使佬供例來侃佰併侈佩佻侖佾侏侑佺兔兒兕兩具其典冽函刻券刷刺到刮制剁劾劻卒協卓卑卦卷卸卹取叔受味呵"],
        ["a940", "咖呸咕咀呻呷咄咒咆呼咐呱呶和咚呢周咋命咎固垃坷坪坩坡坦坤坼夜奉奇奈奄奔妾妻委妹妮姑姆姐姍始姓姊妯妳姒姅孟孤季宗定官宜宙宛尚屈居"],
        ["a9a1", "屆岷岡岸岩岫岱岳帘帚帖帕帛帑幸庚店府底庖延弦弧弩往征彿彼忝忠忽念忿怏怔怯怵怖怪怕怡性怩怫怛或戕房戾所承拉拌拄抿拂抹拒招披拓拔拋拈抨抽押拐拙拇拍抵拚抱拘拖拗拆抬拎放斧於旺昔易昌昆昂明昀昏昕昊"],
        ["aa40", "昇服朋杭枋枕東果杳杷枇枝林杯杰板枉松析杵枚枓杼杪杲欣武歧歿氓氛泣注泳沱泌泥河沽沾沼波沫法泓沸泄油況沮泗泅泱沿治泡泛泊沬泯泜泖泠"],
        ["aaa1", "炕炎炒炊炙爬爭爸版牧物狀狎狙狗狐玩玨玟玫玥甽疝疙疚的盂盲直知矽社祀祁秉秈空穹竺糾罔羌羋者肺肥肢肱股肫肩肴肪肯臥臾舍芳芝芙芭芽芟芹花芬芥芯芸芣芰芾芷虎虱初表軋迎返近邵邸邱邶采金長門阜陀阿阻附"],
        ["ab40", "陂隹雨青非亟亭亮信侵侯便俠俑俏保促侶俘俟俊俗侮俐俄係俚俎俞侷兗冒冑冠剎剃削前剌剋則勇勉勃勁匍南卻厚叛咬哀咨哎哉咸咦咳哇哂咽咪品"],
        ["aba1", "哄哈咯咫咱咻咩咧咿囿垂型垠垣垢城垮垓奕契奏奎奐姜姘姿姣姨娃姥姪姚姦威姻孩宣宦室客宥封屎屏屍屋峙峒巷帝帥帟幽庠度建弈弭彥很待徊律徇後徉怒思怠急怎怨恍恰恨恢恆恃恬恫恪恤扁拜挖按拼拭持拮拽指拱拷"],
        ["ac40", "拯括拾拴挑挂政故斫施既春昭映昧是星昨昱昤曷柿染柱柔某柬架枯柵柩柯柄柑枴柚查枸柏柞柳枰柙柢柝柒歪殃殆段毒毗氟泉洋洲洪流津洌洱洞洗"],
        ["aca1", "活洽派洶洛泵洹洧洸洩洮洵洎洫炫為炳炬炯炭炸炮炤爰牲牯牴狩狠狡玷珊玻玲珍珀玳甚甭畏界畎畋疫疤疥疢疣癸皆皇皈盈盆盃盅省盹相眉看盾盼眇矜砂研砌砍祆祉祈祇禹禺科秒秋穿突竿竽籽紂紅紀紉紇約紆缸美羿耄"],
        ["ad40", "耐耍耑耶胖胥胚胃胄背胡胛胎胞胤胝致舢苧范茅苣苛苦茄若茂茉苒苗英茁苜苔苑苞苓苟苯茆虐虹虻虺衍衫要觔計訂訃貞負赴赳趴軍軌述迦迢迪迥"],
        ["ada1", "迭迫迤迨郊郎郁郃酋酊重閂限陋陌降面革韋韭音頁風飛食首香乘亳倌倍倣俯倦倥俸倩倖倆值借倚倒們俺倀倔倨俱倡個候倘俳修倭倪俾倫倉兼冤冥冢凍凌准凋剖剜剔剛剝匪卿原厝叟哨唐唁唷哼哥哲唆哺唔哩哭員唉哮哪"],
        ["ae40", "哦唧唇哽唏圃圄埂埔埋埃堉夏套奘奚娑娘娜娟娛娓姬娠娣娩娥娌娉孫屘宰害家宴宮宵容宸射屑展屐峭峽峻峪峨峰島崁峴差席師庫庭座弱徒徑徐恙"],
        ["aea1", "恣恥恐恕恭恩息悄悟悚悍悔悌悅悖扇拳挈拿捎挾振捕捂捆捏捉挺捐挽挪挫挨捍捌效敉料旁旅時晉晏晃晒晌晅晁書朔朕朗校核案框桓根桂桔栩梳栗桌桑栽柴桐桀格桃株桅栓栘桁殊殉殷氣氧氨氦氤泰浪涕消涇浦浸海浙涓"],
        ["af40", "浬涉浮浚浴浩涌涊浹涅浥涔烊烘烤烙烈烏爹特狼狹狽狸狷玆班琉珮珠珪珞畔畝畜畚留疾病症疲疳疽疼疹痂疸皋皰益盍盎眩真眠眨矩砰砧砸砝破砷"],
        ["afa1", "砥砭砠砟砲祕祐祠祟祖神祝祗祚秤秣秧租秦秩秘窄窈站笆笑粉紡紗紋紊素索純紐紕級紜納紙紛缺罟羔翅翁耆耘耕耙耗耽耿胱脂胰脅胭胴脆胸胳脈能脊胼胯臭臬舀舐航舫舨般芻茫荒荔荊茸荐草茵茴荏茲茹茶茗荀茱茨荃"],
        ["b040", "虔蚊蚪蚓蚤蚩蚌蚣蚜衰衷袁袂衽衹記訐討訌訕訊託訓訖訏訑豈豺豹財貢起躬軒軔軏辱送逆迷退迺迴逃追逅迸邕郡郝郢酒配酌釘針釗釜釙閃院陣陡"],
        ["b0a1", "陛陝除陘陞隻飢馬骨高鬥鬲鬼乾偺偽停假偃偌做偉健偶偎偕偵側偷偏倏偯偭兜冕凰剪副勒務勘動匐匏匙匿區匾參曼商啪啦啄啞啡啃啊唱啖問啕唯啤唸售啜唬啣唳啁啗圈國圉域堅堊堆埠埤基堂堵執培夠奢娶婁婉婦婪婀"],
        ["b140", "娼婢婚婆婊孰寇寅寄寂宿密尉專將屠屜屝崇崆崎崛崖崢崑崩崔崙崤崧崗巢常帶帳帷康庸庶庵庾張強彗彬彩彫得徙從徘御徠徜恿患悉悠您惋悴惦悽"],
        ["b1a1", "情悻悵惜悼惘惕惆惟悸惚惇戚戛扈掠控捲掖探接捷捧掘措捱掩掉掃掛捫推掄授掙採掬排掏掀捻捩捨捺敝敖救教敗啟敏敘敕敔斜斛斬族旋旌旎晝晚晤晨晦晞曹勗望梁梯梢梓梵桿桶梱梧梗械梃棄梭梆梅梔條梨梟梡梂欲殺"],
        ["b240", "毫毬氫涎涼淳淙液淡淌淤添淺清淇淋涯淑涮淞淹涸混淵淅淒渚涵淚淫淘淪深淮淨淆淄涪淬涿淦烹焉焊烽烯爽牽犁猜猛猖猓猙率琅琊球理現琍瓠瓶"],
        ["b2a1", "瓷甜產略畦畢異疏痔痕疵痊痍皎盔盒盛眷眾眼眶眸眺硫硃硎祥票祭移窒窕笠笨笛第符笙笞笮粒粗粕絆絃統紮紹紼絀細紳組累終紲紱缽羞羚翌翎習耜聊聆脯脖脣脫脩脰脤舂舵舷舶船莎莞莘荸莢莖莽莫莒莊莓莉莠荷荻荼"],
        ["b340", "莆莧處彪蛇蛀蚶蛄蚵蛆蛋蚱蚯蛉術袞袈被袒袖袍袋覓規訪訝訣訥許設訟訛訢豉豚販責貫貨貪貧赧赦趾趺軛軟這逍通逗連速逝逐逕逞造透逢逖逛途"],
        ["b3a1", "部郭都酗野釵釦釣釧釭釩閉陪陵陳陸陰陴陶陷陬雀雪雩章竟頂頃魚鳥鹵鹿麥麻傢傍傅備傑傀傖傘傚最凱割剴創剩勞勝勛博厥啻喀喧啼喊喝喘喂喜喪喔喇喋喃喳單喟唾喲喚喻喬喱啾喉喫喙圍堯堪場堤堰報堡堝堠壹壺奠"],
        ["b440", "婷媚婿媒媛媧孳孱寒富寓寐尊尋就嵌嵐崴嵇巽幅帽幀幃幾廊廁廂廄弼彭復循徨惑惡悲悶惠愜愣惺愕惰惻惴慨惱愎惶愉愀愒戟扉掣掌描揀揩揉揆揍"],
        ["b4a1", "插揣提握揖揭揮捶援揪換摒揚揹敞敦敢散斑斐斯普晰晴晶景暑智晾晷曾替期朝棺棕棠棘棗椅棟棵森棧棹棒棲棣棋棍植椒椎棉棚楮棻款欺欽殘殖殼毯氮氯氬港游湔渡渲湧湊渠渥渣減湛湘渤湖湮渭渦湯渴湍渺測湃渝渾滋"],
        ["b540", "溉渙湎湣湄湲湩湟焙焚焦焰無然煮焜牌犄犀猶猥猴猩琺琪琳琢琥琵琶琴琯琛琦琨甥甦畫番痢痛痣痙痘痞痠登發皖皓皴盜睏短硝硬硯稍稈程稅稀窘"],
        ["b5a1", "窗窖童竣等策筆筐筒答筍筋筏筑粟粥絞結絨絕紫絮絲絡給絢絰絳善翔翕耋聒肅腕腔腋腑腎脹腆脾腌腓腴舒舜菩萃菸萍菠菅萋菁華菱菴著萊菰萌菌菽菲菊萸萎萄菜萇菔菟虛蛟蛙蛭蛔蛛蛤蛐蛞街裁裂袱覃視註詠評詞証詁"],
        ["b640", "詔詛詐詆訴診訶詖象貂貯貼貳貽賁費賀貴買貶貿貸越超趁跎距跋跚跑跌跛跆軻軸軼辜逮逵週逸進逶鄂郵鄉郾酣酥量鈔鈕鈣鈉鈞鈍鈐鈇鈑閔閏開閑"],
        ["b6a1", "間閒閎隊階隋陽隅隆隍陲隄雁雅雄集雇雯雲韌項順須飧飪飯飩飲飭馮馭黃黍黑亂傭債傲傳僅傾催傷傻傯僇剿剷剽募勦勤勢勣匯嗟嗨嗓嗦嗎嗜嗇嗑嗣嗤嗯嗚嗡嗅嗆嗥嗉園圓塞塑塘塗塚塔填塌塭塊塢塒塋奧嫁嫉嫌媾媽媼"],
        ["b740", "媳嫂媲嵩嵯幌幹廉廈弒彙徬微愚意慈感想愛惹愁愈慎慌慄慍愾愴愧愍愆愷戡戢搓搾搞搪搭搽搬搏搜搔損搶搖搗搆敬斟新暗暉暇暈暖暄暘暍會榔業"],
        ["b7a1", "楚楷楠楔極椰概楊楨楫楞楓楹榆楝楣楛歇歲毀殿毓毽溢溯滓溶滂源溝滇滅溥溘溼溺溫滑準溜滄滔溪溧溴煎煙煩煤煉照煜煬煦煌煥煞煆煨煖爺牒猷獅猿猾瑯瑚瑕瑟瑞瑁琿瑙瑛瑜當畸瘀痰瘁痲痱痺痿痴痳盞盟睛睫睦睞督"],
        ["b840", "睹睪睬睜睥睨睢矮碎碰碗碘碌碉硼碑碓硿祺祿禁萬禽稜稚稠稔稟稞窟窠筷節筠筮筧粱粳粵經絹綑綁綏絛置罩罪署義羨群聖聘肆肄腱腰腸腥腮腳腫"],
        ["b8a1", "腹腺腦舅艇蒂葷落萱葵葦葫葉葬葛萼萵葡董葩葭葆虞虜號蛹蜓蜈蜇蜀蛾蛻蜂蜃蜆蜊衙裟裔裙補裘裝裡裊裕裒覜解詫該詳試詩詰誇詼詣誠話誅詭詢詮詬詹詻訾詨豢貊貉賊資賈賄貲賃賂賅跡跟跨路跳跺跪跤跦躲較載軾輊"],
        ["b940", "辟農運遊道遂達逼違遐遇遏過遍遑逾遁鄒鄗酬酪酩釉鈷鉗鈸鈽鉀鈾鉛鉋鉤鉑鈴鉉鉍鉅鈹鈿鉚閘隘隔隕雍雋雉雊雷電雹零靖靴靶預頑頓頊頒頌飼飴"],
        ["b9a1", "飽飾馳馱馴髡鳩麂鼎鼓鼠僧僮僥僖僭僚僕像僑僱僎僩兢凳劃劂匱厭嗾嘀嘛嘗嗽嘔嘆嘉嘍嘎嗷嘖嘟嘈嘐嗶團圖塵塾境墓墊塹墅塽壽夥夢夤奪奩嫡嫦嫩嫗嫖嫘嫣孵寞寧寡寥實寨寢寤察對屢嶄嶇幛幣幕幗幔廓廖弊彆彰徹慇"],
        ["ba40", "愿態慷慢慣慟慚慘慵截撇摘摔撤摸摟摺摑摧搴摭摻敲斡旗旖暢暨暝榜榨榕槁榮槓構榛榷榻榫榴槐槍榭槌榦槃榣歉歌氳漳演滾漓滴漩漾漠漬漏漂漢"],
        ["baa1", "滿滯漆漱漸漲漣漕漫漯澈漪滬漁滲滌滷熔熙煽熊熄熒爾犒犖獄獐瑤瑣瑪瑰瑭甄疑瘧瘍瘋瘉瘓盡監瞄睽睿睡磁碟碧碳碩碣禎福禍種稱窪窩竭端管箕箋筵算箝箔箏箸箇箄粹粽精綻綰綜綽綾綠緊綴網綱綺綢綿綵綸維緒緇綬"],
        ["bb40", "罰翠翡翟聞聚肇腐膀膏膈膊腿膂臧臺與舔舞艋蓉蒿蓆蓄蒙蒞蒲蒜蓋蒸蓀蓓蒐蒼蓑蓊蜿蜜蜻蜢蜥蜴蜘蝕蜷蜩裳褂裴裹裸製裨褚裯誦誌語誣認誡誓誤"],
        ["bba1", "說誥誨誘誑誚誧豪貍貌賓賑賒赫趙趕跼輔輒輕輓辣遠遘遜遣遙遞遢遝遛鄙鄘鄞酵酸酷酴鉸銀銅銘銖鉻銓銜銨鉼銑閡閨閩閣閥閤隙障際雌雒需靼鞅韶頗領颯颱餃餅餌餉駁骯骰髦魁魂鳴鳶鳳麼鼻齊億儀僻僵價儂儈儉儅凜"],
        ["bc40", "劇劈劉劍劊勰厲嘮嘻嘹嘲嘿嘴嘩噓噎噗噴嘶嘯嘰墀墟增墳墜墮墩墦奭嬉嫻嬋嫵嬌嬈寮寬審寫層履嶝嶔幢幟幡廢廚廟廝廣廠彈影德徵慶慧慮慝慕憂"],
        ["bca1", "慼慰慫慾憧憐憫憎憬憚憤憔憮戮摩摯摹撞撲撈撐撰撥撓撕撩撒撮播撫撚撬撙撢撳敵敷數暮暫暴暱樣樟槨樁樞標槽模樓樊槳樂樅槭樑歐歎殤毅毆漿潼澄潑潦潔澆潭潛潸潮澎潺潰潤澗潘滕潯潠潟熟熬熱熨牖犛獎獗瑩璋璃"],
        ["bd40", "瑾璀畿瘠瘩瘟瘤瘦瘡瘢皚皺盤瞎瞇瞌瞑瞋磋磅確磊碾磕碼磐稿稼穀稽稷稻窯窮箭箱範箴篆篇篁箠篌糊締練緯緻緘緬緝編緣線緞緩綞緙緲緹罵罷羯"],
        ["bda1", "翩耦膛膜膝膠膚膘蔗蔽蔚蓮蔬蔭蔓蔑蔣蔡蔔蓬蔥蓿蔆螂蝴蝶蝠蝦蝸蝨蝙蝗蝌蝓衛衝褐複褒褓褕褊誼諒談諄誕請諸課諉諂調誰論諍誶誹諛豌豎豬賠賞賦賤賬賭賢賣賜質賡赭趟趣踫踐踝踢踏踩踟踡踞躺輝輛輟輩輦輪輜輞"],
        ["be40", "輥適遮遨遭遷鄰鄭鄧鄱醇醉醋醃鋅銻銷鋪銬鋤鋁銳銼鋒鋇鋰銲閭閱霄霆震霉靠鞍鞋鞏頡頫頜颳養餓餒餘駝駐駟駛駑駕駒駙骷髮髯鬧魅魄魷魯鴆鴉"],
        ["bea1", "鴃麩麾黎墨齒儒儘儔儐儕冀冪凝劑劓勳噙噫噹噩噤噸噪器噥噱噯噬噢噶壁墾壇壅奮嬝嬴學寰導彊憲憑憩憊懍憶憾懊懈戰擅擁擋撻撼據擄擇擂操撿擒擔撾整曆曉暹曄曇暸樽樸樺橙橫橘樹橄橢橡橋橇樵機橈歙歷氅濂澱澡"],
        ["bf40", "濃澤濁澧澳激澹澶澦澠澴熾燉燐燒燈燕熹燎燙燜燃燄獨璜璣璘璟璞瓢甌甍瘴瘸瘺盧盥瞠瞞瞟瞥磨磚磬磧禦積穎穆穌穋窺篙簑築篤篛篡篩篦糕糖縊"],
        ["bfa1", "縑縈縛縣縞縝縉縐罹羲翰翱翮耨膳膩膨臻興艘艙蕊蕙蕈蕨蕩蕃蕉蕭蕪蕞螃螟螞螢融衡褪褲褥褫褡親覦諦諺諫諱謀諜諧諮諾謁謂諷諭諳諶諼豫豭貓賴蹄踱踴蹂踹踵輻輯輸輳辨辦遵遴選遲遼遺鄴醒錠錶鋸錳錯錢鋼錫錄錚"],
        ["c040", "錐錦錡錕錮錙閻隧隨險雕霎霑霖霍霓霏靛靜靦鞘頰頸頻頷頭頹頤餐館餞餛餡餚駭駢駱骸骼髻髭鬨鮑鴕鴣鴦鴨鴒鴛默黔龍龜優償儡儲勵嚎嚀嚐嚅嚇"],
        ["c0a1", "嚏壕壓壑壎嬰嬪嬤孺尷屨嶼嶺嶽嶸幫彌徽應懂懇懦懋戲戴擎擊擘擠擰擦擬擱擢擭斂斃曙曖檀檔檄檢檜櫛檣橾檗檐檠歜殮毚氈濘濱濟濠濛濤濫濯澀濬濡濩濕濮濰燧營燮燦燥燭燬燴燠爵牆獰獲璩環璦璨癆療癌盪瞳瞪瞰瞬"],
        ["c140", "瞧瞭矯磷磺磴磯礁禧禪穗窿簇簍篾篷簌篠糠糜糞糢糟糙糝縮績繆縷縲繃縫總縱繅繁縴縹繈縵縿縯罄翳翼聱聲聰聯聳臆臃膺臂臀膿膽臉膾臨舉艱薪"],
        ["c1a1", "薄蕾薜薑薔薯薛薇薨薊虧蟀蟑螳蟒蟆螫螻螺蟈蟋褻褶襄褸褽覬謎謗謙講謊謠謝謄謐豁谿豳賺賽購賸賻趨蹉蹋蹈蹊轄輾轂轅輿避遽還邁邂邀鄹醣醞醜鍍鎂錨鍵鍊鍥鍋錘鍾鍬鍛鍰鍚鍔闊闋闌闈闆隱隸雖霜霞鞠韓顆颶餵騁"],
        ["c240", "駿鮮鮫鮪鮭鴻鴿麋黏點黜黝黛鼾齋叢嚕嚮壙壘嬸彝懣戳擴擲擾攆擺擻擷斷曜朦檳檬櫃檻檸櫂檮檯歟歸殯瀉瀋濾瀆濺瀑瀏燻燼燾燸獷獵璧璿甕癖癘"],
        ["c2a1", "癒瞽瞿瞻瞼礎禮穡穢穠竄竅簫簧簪簞簣簡糧織繕繞繚繡繒繙罈翹翻職聶臍臏舊藏薩藍藐藉薰薺薹薦蟯蟬蟲蟠覆覲觴謨謹謬謫豐贅蹙蹣蹦蹤蹟蹕軀轉轍邇邃邈醫醬釐鎔鎊鎖鎢鎳鎮鎬鎰鎘鎚鎗闔闖闐闕離雜雙雛雞霤鞣鞦"],
        ["c340", "鞭韹額顏題顎顓颺餾餿餽餮馥騎髁鬃鬆魏魎魍鯊鯉鯽鯈鯀鵑鵝鵠黠鼕鼬儳嚥壞壟壢寵龐廬懲懷懶懵攀攏曠曝櫥櫝櫚櫓瀛瀟瀨瀚瀝瀕瀘爆爍牘犢獸"],
        ["c3a1", "獺璽瓊瓣疇疆癟癡矇礙禱穫穩簾簿簸簽簷籀繫繭繹繩繪羅繳羶羹羸臘藩藝藪藕藤藥藷蟻蠅蠍蟹蟾襠襟襖襞譁譜識證譚譎譏譆譙贈贊蹼蹲躇蹶蹬蹺蹴轔轎辭邊邋醱醮鏡鏑鏟鏃鏈鏜鏝鏖鏢鏍鏘鏤鏗鏨關隴難霪霧靡韜韻類"],
        ["c440", "願顛颼饅饉騖騙鬍鯨鯧鯖鯛鶉鵡鵲鵪鵬麒麗麓麴勸嚨嚷嚶嚴嚼壤孀孃孽寶巉懸懺攘攔攙曦朧櫬瀾瀰瀲爐獻瓏癢癥礦礪礬礫竇競籌籃籍糯糰辮繽繼"],
        ["c4a1", "纂罌耀臚艦藻藹蘑藺蘆蘋蘇蘊蠔蠕襤覺觸議譬警譯譟譫贏贍躉躁躅躂醴釋鐘鐃鏽闡霰飄饒饑馨騫騰騷騵鰓鰍鹹麵黨鼯齟齣齡儷儸囁囀囂夔屬巍懼懾攝攜斕曩櫻欄櫺殲灌爛犧瓖瓔癩矓籐纏續羼蘗蘭蘚蠣蠢蠡蠟襪襬覽譴"],
        ["c540", "護譽贓躊躍躋轟辯醺鐮鐳鐵鐺鐸鐲鐫闢霸霹露響顧顥饗驅驃驀騾髏魔魑鰭鰥鶯鶴鷂鶸麝黯鼙齜齦齧儼儻囈囊囉孿巔巒彎懿攤權歡灑灘玀瓤疊癮癬"],
        ["c5a1", "禳籠籟聾聽臟襲襯觼讀贖贗躑躓轡酈鑄鑑鑒霽霾韃韁顫饕驕驍髒鬚鱉鰱鰾鰻鷓鷗鼴齬齪龔囌巖戀攣攫攪曬欐瓚竊籤籣籥纓纖纔臢蘸蘿蠱變邐邏鑣鑠鑤靨顯饜驚驛驗髓體髑鱔鱗鱖鷥麟黴囑壩攬灞癱癲矗罐羈蠶蠹衢讓讒"],
        ["c640", "讖艷贛釀鑪靂靈靄韆顰驟鬢魘鱟鷹鷺鹼鹽鼇齷齲廳欖灣籬籮蠻觀躡釁鑲鑰顱饞髖鬣黌灤矚讚鑷韉驢驥纜讜躪釅鑽鑾鑼鱷鱸黷豔鑿鸚爨驪鬱鸛鸞籲"],
        ["c940", "乂乜凵匚厂万丌乇亍囗兀屮彳丏冇与丮亓仂仉仈冘勼卬厹圠夃夬尐巿旡殳毌气爿丱丼仨仜仩仡仝仚刌匜卌圢圣夗夯宁宄尒尻屴屳帄庀庂忉戉扐氕"],
        ["c9a1", "氶汃氿氻犮犰玊禸肊阞伎优伬仵伔仱伀价伈伝伂伅伢伓伄仴伒冱刓刉刐劦匢匟卍厊吇囡囟圮圪圴夼妀奼妅奻奾奷奿孖尕尥屼屺屻屾巟幵庄异弚彴忕忔忏扜扞扤扡扦扢扙扠扚扥旯旮朾朹朸朻机朿朼朳氘汆汒汜汏汊汔汋"],
        ["ca40", "汌灱牞犴犵玎甪癿穵网艸艼芀艽艿虍襾邙邗邘邛邔阢阤阠阣佖伻佢佉体佤伾佧佒佟佁佘伭伳伿佡冏冹刜刞刡劭劮匉卣卲厎厏吰吷吪呔呅吙吜吥吘"],
        ["caa1", "吽呏呁吨吤呇囮囧囥坁坅坌坉坋坒夆奀妦妘妠妗妎妢妐妏妧妡宎宒尨尪岍岏岈岋岉岒岊岆岓岕巠帊帎庋庉庌庈庍弅弝彸彶忒忑忐忭忨忮忳忡忤忣忺忯忷忻怀忴戺抃抌抎抏抔抇扱扻扺扰抁抈扷扽扲扴攷旰旴旳旲旵杅杇"],
        ["cb40", "杙杕杌杈杝杍杚杋毐氙氚汸汧汫沄沋沏汱汯汩沚汭沇沕沜汦汳汥汻沎灴灺牣犿犽狃狆狁犺狅玕玗玓玔玒町甹疔疕皁礽耴肕肙肐肒肜芐芏芅芎芑芓"],
        ["cba1", "芊芃芄豸迉辿邟邡邥邞邧邠阰阨阯阭丳侘佼侅佽侀侇佶佴侉侄佷佌侗佪侚佹侁佸侐侜侔侞侒侂侕佫佮冞冼冾刵刲刳剆刱劼匊匋匼厒厔咇呿咁咑咂咈呫呺呾呥呬呴呦咍呯呡呠咘呣呧呤囷囹坯坲坭坫坱坰坶垀坵坻坳坴坢"],
        ["cc40", "坨坽夌奅妵妺姏姎妲姌姁妶妼姃姖妱妽姀姈妴姇孢孥宓宕屄屇岮岤岠岵岯岨岬岟岣岭岢岪岧岝岥岶岰岦帗帔帙弨弢弣弤彔徂彾彽忞忥怭怦怙怲怋"],
        ["cca1", "怴怊怗怳怚怞怬怢怍怐怮怓怑怌怉怜戔戽抭抴拑抾抪抶拊抮抳抯抻抩抰抸攽斨斻昉旼昄昒昈旻昃昋昍昅旽昑昐曶朊枅杬枎枒杶杻枘枆构杴枍枌杺枟枑枙枃杽极杸杹枔欥殀歾毞氝沓泬泫泮泙沶泔沭泧沷泐泂沺泃泆泭泲"],
        ["cd40", "泒泝沴沊沝沀泞泀洰泍泇沰泹泏泩泑炔炘炅炓炆炄炑炖炂炚炃牪狖狋狘狉狜狒狔狚狌狑玤玡玭玦玢玠玬玝瓝瓨甿畀甾疌疘皯盳盱盰盵矸矼矹矻矺"],
        ["cda1", "矷祂礿秅穸穻竻籵糽耵肏肮肣肸肵肭舠芠苀芫芚芘芛芵芧芮芼芞芺芴芨芡芩苂芤苃芶芢虰虯虭虮豖迒迋迓迍迖迕迗邲邴邯邳邰阹阽阼阺陃俍俅俓侲俉俋俁俔俜俙侻侳俛俇俖侺俀侹俬剄剉勀勂匽卼厗厖厙厘咺咡咭咥哏"],
        ["ce40", "哃茍咷咮哖咶哅哆咠呰咼咢咾呲哞咰垵垞垟垤垌垗垝垛垔垘垏垙垥垚垕壴复奓姡姞姮娀姱姝姺姽姼姶姤姲姷姛姩姳姵姠姾姴姭宨屌峐峘峌峗峋峛"],
        ["cea1", "峞峚峉峇峊峖峓峔峏峈峆峎峟峸巹帡帢帣帠帤庰庤庢庛庣庥弇弮彖徆怷怹恔恲恞恅恓恇恉恛恌恀恂恟怤恄恘恦恮扂扃拏挍挋拵挎挃拫拹挏挌拸拶挀挓挔拺挕拻拰敁敃斪斿昶昡昲昵昜昦昢昳昫昺昝昴昹昮朏朐柁柲柈枺"],
        ["cf40", "柜枻柸柘柀枷柅柫柤柟枵柍枳柷柶柮柣柂枹柎柧柰枲柼柆柭柌枮柦柛柺柉柊柃柪柋欨殂殄殶毖毘毠氠氡洨洴洭洟洼洿洒洊泚洳洄洙洺洚洑洀洝浂"],
        ["cfa1", "洁洘洷洃洏浀洇洠洬洈洢洉洐炷炟炾炱炰炡炴炵炩牁牉牊牬牰牳牮狊狤狨狫狟狪狦狣玅珌珂珈珅玹玶玵玴珫玿珇玾珃珆玸珋瓬瓮甮畇畈疧疪癹盄眈眃眄眅眊盷盻盺矧矨砆砑砒砅砐砏砎砉砃砓祊祌祋祅祄秕种秏秖秎窀"],
        ["d040", "穾竑笀笁籺籸籹籿粀粁紃紈紁罘羑羍羾耇耎耏耔耷胘胇胠胑胈胂胐胅胣胙胜胊胕胉胏胗胦胍臿舡芔苙苾苹茇苨茀苕茺苫苖苴苬苡苲苵茌苻苶苰苪"],
        ["d0a1", "苤苠苺苳苭虷虴虼虳衁衎衧衪衩觓訄訇赲迣迡迮迠郱邽邿郕郅邾郇郋郈釔釓陔陏陑陓陊陎倞倅倇倓倢倰倛俵俴倳倷倬俶俷倗倜倠倧倵倯倱倎党冔冓凊凄凅凈凎剡剚剒剞剟剕剢勍匎厞唦哢唗唒哧哳哤唚哿唄唈哫唑唅哱"],
        ["d140", "唊哻哷哸哠唎唃唋圁圂埌堲埕埒垺埆垽垼垸垶垿埇埐垹埁夎奊娙娖娭娮娕娏娗娊娞娳孬宧宭宬尃屖屔峬峿峮峱峷崀峹帩帨庨庮庪庬弳弰彧恝恚恧"],
        ["d1a1", "恁悢悈悀悒悁悝悃悕悛悗悇悜悎戙扆拲挐捖挬捄捅挶捃揤挹捋捊挼挩捁挴捘捔捙挭捇挳捚捑挸捗捀捈敊敆旆旃旄旂晊晟晇晑朒朓栟栚桉栲栳栻桋桏栖栱栜栵栫栭栯桎桄栴栝栒栔栦栨栮桍栺栥栠欬欯欭欱欴歭肂殈毦毤"],
        ["d240", "毨毣毢毧氥浺浣浤浶洍浡涒浘浢浭浯涑涍淯浿涆浞浧浠涗浰浼浟涂涘洯浨涋浾涀涄洖涃浻浽浵涐烜烓烑烝烋缹烢烗烒烞烠烔烍烅烆烇烚烎烡牂牸"],
        ["d2a1", "牷牶猀狺狴狾狶狳狻猁珓珙珥珖玼珧珣珩珜珒珛珔珝珚珗珘珨瓞瓟瓴瓵甡畛畟疰痁疻痄痀疿疶疺皊盉眝眛眐眓眒眣眑眕眙眚眢眧砣砬砢砵砯砨砮砫砡砩砳砪砱祔祛祏祜祓祒祑秫秬秠秮秭秪秜秞秝窆窉窅窋窌窊窇竘笐"],
        ["d340", "笄笓笅笏笈笊笎笉笒粄粑粊粌粈粍粅紞紝紑紎紘紖紓紟紒紏紌罜罡罞罠罝罛羖羒翃翂翀耖耾耹胺胲胹胵脁胻脀舁舯舥茳茭荄茙荑茥荖茿荁茦茜茢"],
        ["d3a1", "荂荎茛茪茈茼荍茖茤茠茷茯茩荇荅荌荓茞茬荋茧荈虓虒蚢蚨蚖蚍蚑蚞蚇蚗蚆蚋蚚蚅蚥蚙蚡蚧蚕蚘蚎蚝蚐蚔衃衄衭衵衶衲袀衱衿衯袃衾衴衼訒豇豗豻貤貣赶赸趵趷趶軑軓迾迵适迿迻逄迼迶郖郠郙郚郣郟郥郘郛郗郜郤酐"],
        ["d440", "酎酏釕釢釚陜陟隼飣髟鬯乿偰偪偡偞偠偓偋偝偲偈偍偁偛偊偢倕偅偟偩偫偣偤偆偀偮偳偗偑凐剫剭剬剮勖勓匭厜啵啶唼啍啐唴唪啑啢唶唵唰啒啅"],
        ["d4a1", "唌唲啥啎唹啈唭唻啀啋圊圇埻堔埢埶埜埴堀埭埽堈埸堋埳埏堇埮埣埲埥埬埡堎埼堐埧堁堌埱埩埰堍堄奜婠婘婕婧婞娸娵婭婐婟婥婬婓婤婗婃婝婒婄婛婈媎娾婍娹婌婰婩婇婑婖婂婜孲孮寁寀屙崞崋崝崚崠崌崨崍崦崥崏"],
        ["d540", "崰崒崣崟崮帾帴庱庴庹庲庳弶弸徛徖徟悊悐悆悾悰悺惓惔惏惤惙惝惈悱惛悷惊悿惃惍惀挲捥掊掂捽掽掞掭掝掗掫掎捯掇掐据掯捵掜捭掮捼掤挻掟"],
        ["d5a1", "捸掅掁掑掍捰敓旍晥晡晛晙晜晢朘桹梇梐梜桭桮梮梫楖桯梣梬梩桵桴梲梏桷梒桼桫桲梪梀桱桾梛梖梋梠梉梤桸桻梑梌梊桽欶欳欷欸殑殏殍殎殌氪淀涫涴涳湴涬淩淢涷淶淔渀淈淠淟淖涾淥淜淝淛淴淊涽淭淰涺淕淂淏淉"],
        ["d640", "淐淲淓淽淗淍淣涻烺焍烷焗烴焌烰焄烳焐烼烿焆焓焀烸烶焋焂焎牾牻牼牿猝猗猇猑猘猊猈狿猏猞玈珶珸珵琄琁珽琇琀珺珼珿琌琋珴琈畤畣痎痒痏"],
        ["d6a1", "痋痌痑痐皏皉盓眹眯眭眱眲眴眳眽眥眻眵硈硒硉硍硊硌砦硅硐祤祧祩祪祣祫祡离秺秸秶秷窏窔窐笵筇笴笥笰笢笤笳笘笪笝笱笫笭笯笲笸笚笣粔粘粖粣紵紽紸紶紺絅紬紩絁絇紾紿絊紻紨罣羕羜羝羛翊翋翍翐翑翇翏翉耟"],
        ["d740", "耞耛聇聃聈脘脥脙脛脭脟脬脞脡脕脧脝脢舑舸舳舺舴舲艴莐莣莨莍荺荳莤荴莏莁莕莙荵莔莩荽莃莌莝莛莪莋荾莥莯莈莗莰荿莦莇莮荶莚虙虖蚿蚷"],
        ["d7a1", "蛂蛁蛅蚺蚰蛈蚹蚳蚸蛌蚴蚻蚼蛃蚽蚾衒袉袕袨袢袪袚袑袡袟袘袧袙袛袗袤袬袌袓袎覂觖觙觕訰訧訬訞谹谻豜豝豽貥赽赻赹趼跂趹趿跁軘軞軝軜軗軠軡逤逋逑逜逌逡郯郪郰郴郲郳郔郫郬郩酖酘酚酓酕釬釴釱釳釸釤釹釪"],
        ["d840", "釫釷釨釮镺閆閈陼陭陫陱陯隿靪頄飥馗傛傕傔傞傋傣傃傌傎傝偨傜傒傂傇兟凔匒匑厤厧喑喨喥喭啷噅喢喓喈喏喵喁喣喒喤啽喌喦啿喕喡喎圌堩堷"],
        ["d8a1", "堙堞堧堣堨埵塈堥堜堛堳堿堶堮堹堸堭堬堻奡媯媔媟婺媢媞婸媦婼媥媬媕媮娷媄媊媗媃媋媩婻婽媌媜媏媓媝寪寍寋寔寑寊寎尌尰崷嵃嵫嵁嵋崿崵嵑嵎嵕崳崺嵒崽崱嵙嵂崹嵉崸崼崲崶嵀嵅幄幁彘徦徥徫惉悹惌惢惎惄愔"],
        ["d940", "惲愊愖愅惵愓惸惼惾惁愃愘愝愐惿愄愋扊掔掱掰揎揥揨揯揃撝揳揊揠揶揕揲揵摡揟掾揝揜揄揘揓揂揇揌揋揈揰揗揙攲敧敪敤敜敨敥斌斝斞斮旐旒"],
        ["d9a1", "晼晬晻暀晱晹晪晲朁椌棓椄棜椪棬棪棱椏棖棷棫棤棶椓椐棳棡椇棌椈楰梴椑棯棆椔棸棐棽棼棨椋椊椗棎棈棝棞棦棴棑椆棔棩椕椥棇欹欻欿欼殔殗殙殕殽毰毲毳氰淼湆湇渟湉溈渼渽湅湢渫渿湁湝湳渜渳湋湀湑渻渃渮湞"],
        ["da40", "湨湜湡渱渨湠湱湫渹渢渰湓湥渧湸湤湷湕湹湒湦渵渶湚焠焞焯烻焮焱焣焥焢焲焟焨焺焛牋牚犈犉犆犅犋猒猋猰猢猱猳猧猲猭猦猣猵猌琮琬琰琫琖"],
        ["daa1", "琚琡琭琱琤琣琝琩琠琲瓻甯畯畬痧痚痡痦痝痟痤痗皕皒盚睆睇睄睍睅睊睎睋睌矞矬硠硤硥硜硭硱硪确硰硩硨硞硢祴祳祲祰稂稊稃稌稄窙竦竤筊笻筄筈筌筎筀筘筅粢粞粨粡絘絯絣絓絖絧絪絏絭絜絫絒絔絩絑絟絎缾缿罥"],
        ["db40", "罦羢羠羡翗聑聏聐胾胔腃腊腒腏腇脽腍脺臦臮臷臸臹舄舼舽舿艵茻菏菹萣菀菨萒菧菤菼菶萐菆菈菫菣莿萁菝菥菘菿菡菋菎菖菵菉萉萏菞萑萆菂菳"],
        ["dba1", "菕菺菇菑菪萓菃菬菮菄菻菗菢萛菛菾蛘蛢蛦蛓蛣蛚蛪蛝蛫蛜蛬蛩蛗蛨蛑衈衖衕袺裗袹袸裀袾袶袼袷袽袲褁裉覕覘覗觝觚觛詎詍訹詙詀詗詘詄詅詒詈詑詊詌詏豟貁貀貺貾貰貹貵趄趀趉跘跓跍跇跖跜跏跕跙跈跗跅軯軷軺"],
        ["dc40", "軹軦軮軥軵軧軨軶軫軱軬軴軩逭逴逯鄆鄬鄄郿郼鄈郹郻鄁鄀鄇鄅鄃酡酤酟酢酠鈁鈊鈥鈃鈚鈦鈏鈌鈀鈒釿釽鈆鈄鈧鈂鈜鈤鈙鈗鈅鈖镻閍閌閐隇陾隈"],
        ["dca1", "隉隃隀雂雈雃雱雰靬靰靮頇颩飫鳦黹亃亄亶傽傿僆傮僄僊傴僈僂傰僁傺傱僋僉傶傸凗剺剸剻剼嗃嗛嗌嗐嗋嗊嗝嗀嗔嗄嗩喿嗒喍嗏嗕嗢嗖嗈嗲嗍嗙嗂圔塓塨塤塏塍塉塯塕塎塝塙塥塛堽塣塱壼嫇嫄嫋媺媸媱媵媰媿嫈媻嫆"],
        ["dd40", "媷嫀嫊媴媶嫍媹媐寖寘寙尟尳嵱嵣嵊嵥嵲嵬嵞嵨嵧嵢巰幏幎幊幍幋廅廌廆廋廇彀徯徭惷慉慊愫慅愶愲愮慆愯慏愩慀戠酨戣戥戤揅揱揫搐搒搉搠搤"],
        ["dda1", "搳摃搟搕搘搹搷搢搣搌搦搰搨摁搵搯搊搚摀搥搧搋揧搛搮搡搎敯斒旓暆暌暕暐暋暊暙暔晸朠楦楟椸楎楢楱椿楅楪椹楂楗楙楺楈楉椵楬椳椽楥棰楸椴楩楀楯楄楶楘楁楴楌椻楋椷楜楏楑椲楒椯楻椼歆歅歃歂歈歁殛嗀毻毼"],
        ["de40", "毹毷毸溛滖滈溏滀溟溓溔溠溱溹滆滒溽滁溞滉溷溰滍溦滏溲溾滃滜滘溙溒溎溍溤溡溿溳滐滊溗溮溣煇煔煒煣煠煁煝煢煲煸煪煡煂煘煃煋煰煟煐煓"],
        ["dea1", "煄煍煚牏犍犌犑犐犎猼獂猻猺獀獊獉瑄瑊瑋瑒瑑瑗瑀瑏瑐瑎瑂瑆瑍瑔瓡瓿瓾瓽甝畹畷榃痯瘏瘃痷痾痼痹痸瘐痻痶痭痵痽皙皵盝睕睟睠睒睖睚睩睧睔睙睭矠碇碚碔碏碄碕碅碆碡碃硹碙碀碖硻祼禂祽祹稑稘稙稒稗稕稢稓"],
        ["df40", "稛稐窣窢窞竫筦筤筭筴筩筲筥筳筱筰筡筸筶筣粲粴粯綈綆綀綍絿綅絺綎絻綃絼綌綔綄絽綒罭罫罧罨罬羦羥羧翛翜耡腤腠腷腜腩腛腢腲朡腞腶腧腯"],
        ["dfa1", "腄腡舝艉艄艀艂艅蓱萿葖葶葹蒏蒍葥葑葀蒆葧萰葍葽葚葙葴葳葝蔇葞萷萺萴葺葃葸萲葅萩菙葋萯葂萭葟葰萹葎葌葒葯蓅蒎萻葇萶萳葨葾葄萫葠葔葮葐蜋蜄蛷蜌蛺蛖蛵蝍蛸蜎蜉蜁蛶蜍蜅裖裋裍裎裞裛裚裌裐覅覛觟觥觤"],
        ["e040", "觡觠觢觜触詶誆詿詡訿詷誂誄詵誃誁詴詺谼豋豊豥豤豦貆貄貅賌赨赩趑趌趎趏趍趓趔趐趒跰跠跬跱跮跐跩跣跢跧跲跫跴輆軿輁輀輅輇輈輂輋遒逿"],
        ["e0a1", "遄遉逽鄐鄍鄏鄑鄖鄔鄋鄎酮酯鉈鉒鈰鈺鉦鈳鉥鉞銃鈮鉊鉆鉭鉬鉏鉠鉧鉯鈶鉡鉰鈱鉔鉣鉐鉲鉎鉓鉌鉖鈲閟閜閞閛隒隓隑隗雎雺雽雸雵靳靷靸靲頏頍頎颬飶飹馯馲馰馵骭骫魛鳪鳭鳧麀黽僦僔僗僨僳僛僪僝僤僓僬僰僯僣僠"],
        ["e140", "凘劀劁勩勫匰厬嘧嘕嘌嘒嗼嘏嘜嘁嘓嘂嗺嘝嘄嗿嗹墉塼墐墘墆墁塿塴墋塺墇墑墎塶墂墈塻墔墏壾奫嫜嫮嫥嫕嫪嫚嫭嫫嫳嫢嫠嫛嫬嫞嫝嫙嫨嫟孷寠"],
        ["e1a1", "寣屣嶂嶀嵽嶆嵺嶁嵷嶊嶉嶈嵾嵼嶍嵹嵿幘幙幓廘廑廗廎廜廕廙廒廔彄彃彯徶愬愨慁慞慱慳慒慓慲慬憀慴慔慺慛慥愻慪慡慖戩戧戫搫摍摛摝摴摶摲摳摽摵摦撦摎撂摞摜摋摓摠摐摿搿摬摫摙摥摷敳斠暡暠暟朅朄朢榱榶槉"],
        ["e240", "榠槎榖榰榬榼榑榙榎榧榍榩榾榯榿槄榽榤槔榹槊榚槏榳榓榪榡榞槙榗榐槂榵榥槆歊歍歋殞殟殠毃毄毾滎滵滱漃漥滸漷滻漮漉潎漙漚漧漘漻漒滭漊"],
        ["e2a1", "漶潳滹滮漭潀漰漼漵滫漇漎潃漅滽滶漹漜滼漺漟漍漞漈漡熇熐熉熀熅熂熏煻熆熁熗牄牓犗犕犓獃獍獑獌瑢瑳瑱瑵瑲瑧瑮甀甂甃畽疐瘖瘈瘌瘕瘑瘊瘔皸瞁睼瞅瞂睮瞀睯睾瞃碲碪碴碭碨硾碫碞碥碠碬碢碤禘禊禋禖禕禔禓"],
        ["e340", "禗禈禒禐稫穊稰稯稨稦窨窫窬竮箈箜箊箑箐箖箍箌箛箎箅箘劄箙箤箂粻粿粼粺綧綷緂綣綪緁緀緅綝緎緄緆緋緌綯綹綖綼綟綦綮綩綡緉罳翢翣翥翞"],
        ["e3a1", "耤聝聜膉膆膃膇膍膌膋舕蒗蒤蒡蒟蒺蓎蓂蒬蒮蒫蒹蒴蓁蓍蒪蒚蒱蓐蒝蒧蒻蒢蒔蓇蓌蒛蒩蒯蒨蓖蒘蒶蓏蒠蓗蓔蓒蓛蒰蒑虡蜳蜣蜨蝫蝀蜮蜞蜡蜙蜛蝃蜬蝁蜾蝆蜠蜲蜪蜭蜼蜒蜺蜱蜵蝂蜦蜧蜸蜤蜚蜰蜑裷裧裱裲裺裾裮裼裶裻"],
        ["e440", "裰裬裫覝覡覟覞觩觫觨誫誙誋誒誏誖谽豨豩賕賏賗趖踉踂跿踍跽踊踃踇踆踅跾踀踄輐輑輎輍鄣鄜鄠鄢鄟鄝鄚鄤鄡鄛酺酲酹酳銥銤鉶銛鉺銠銔銪銍"],
        ["e4a1", "銦銚銫鉹銗鉿銣鋮銎銂銕銢鉽銈銡銊銆銌銙銧鉾銇銩銝銋鈭隞隡雿靘靽靺靾鞃鞀鞂靻鞄鞁靿韎韍頖颭颮餂餀餇馝馜駃馹馻馺駂馽駇骱髣髧鬾鬿魠魡魟鳱鳲鳵麧僿儃儰僸儆儇僶僾儋儌僽儊劋劌勱勯噈噂噌嘵噁噊噉噆噘"],
        ["e540", "噚噀嘳嘽嘬嘾嘸嘪嘺圚墫墝墱墠墣墯墬墥墡壿嫿嫴嫽嫷嫶嬃嫸嬂嫹嬁嬇嬅嬏屧嶙嶗嶟嶒嶢嶓嶕嶠嶜嶡嶚嶞幩幝幠幜緳廛廞廡彉徲憋憃慹憱憰憢憉"],
        ["e5a1", "憛憓憯憭憟憒憪憡憍慦憳戭摮摰撖撠撅撗撜撏撋撊撌撣撟摨撱撘敶敺敹敻斲斳暵暰暩暲暷暪暯樀樆樗槥槸樕槱槤樠槿槬槢樛樝槾樧槲槮樔槷槧橀樈槦槻樍槼槫樉樄樘樥樏槶樦樇槴樖歑殥殣殢殦氁氀毿氂潁漦潾澇濆澒"],
        ["e640", "澍澉澌潢潏澅潚澖潶潬澂潕潲潒潐潗澔澓潝漀潡潫潽潧澐潓澋潩潿澕潣潷潪潻熲熯熛熰熠熚熩熵熝熥熞熤熡熪熜熧熳犘犚獘獒獞獟獠獝獛獡獚獙"],
        ["e6a1", "獢璇璉璊璆璁瑽璅璈瑼瑹甈甇畾瘥瘞瘙瘝瘜瘣瘚瘨瘛皜皝皞皛瞍瞏瞉瞈磍碻磏磌磑磎磔磈磃磄磉禚禡禠禜禢禛歶稹窲窴窳箷篋箾箬篎箯箹篊箵糅糈糌糋緷緛緪緧緗緡縃緺緦緶緱緰緮緟罶羬羰羭翭翫翪翬翦翨聤聧膣膟"],
        ["e740", "膞膕膢膙膗舖艏艓艒艐艎艑蔤蔻蔏蔀蔩蔎蔉蔍蔟蔊蔧蔜蓻蔫蓺蔈蔌蓴蔪蓲蔕蓷蓫蓳蓼蔒蓪蓩蔖蓾蔨蔝蔮蔂蓽蔞蓶蔱蔦蓧蓨蓰蓯蓹蔘蔠蔰蔋蔙蔯虢"],
        ["e7a1", "蝖蝣蝤蝷蟡蝳蝘蝔蝛蝒蝡蝚蝑蝞蝭蝪蝐蝎蝟蝝蝯蝬蝺蝮蝜蝥蝏蝻蝵蝢蝧蝩衚褅褌褔褋褗褘褙褆褖褑褎褉覢覤覣觭觰觬諏諆誸諓諑諔諕誻諗誾諀諅諘諃誺誽諙谾豍貏賥賟賙賨賚賝賧趠趜趡趛踠踣踥踤踮踕踛踖踑踙踦踧"],
        ["e840", "踔踒踘踓踜踗踚輬輤輘輚輠輣輖輗遳遰遯遧遫鄯鄫鄩鄪鄲鄦鄮醅醆醊醁醂醄醀鋐鋃鋄鋀鋙銶鋏鋱鋟鋘鋩鋗鋝鋌鋯鋂鋨鋊鋈鋎鋦鋍鋕鋉鋠鋞鋧鋑鋓"],
        ["e8a1", "銵鋡鋆銴镼閬閫閮閰隤隢雓霅霈霂靚鞊鞎鞈韐韏頞頝頦頩頨頠頛頧颲餈飺餑餔餖餗餕駜駍駏駓駔駎駉駖駘駋駗駌骳髬髫髳髲髱魆魃魧魴魱魦魶魵魰魨魤魬鳼鳺鳽鳿鳷鴇鴀鳹鳻鴈鴅鴄麃黓鼏鼐儜儓儗儚儑凞匴叡噰噠噮"],
        ["e940", "噳噦噣噭噲噞噷圜圛壈墽壉墿墺壂墼壆嬗嬙嬛嬡嬔嬓嬐嬖嬨嬚嬠嬞寯嶬嶱嶩嶧嶵嶰嶮嶪嶨嶲嶭嶯嶴幧幨幦幯廩廧廦廨廥彋徼憝憨憖懅憴懆懁懌憺"],
        ["e9a1", "憿憸憌擗擖擐擏擉撽撉擃擛擳擙攳敿敼斢曈暾曀曊曋曏暽暻暺曌朣樴橦橉橧樲橨樾橝橭橶橛橑樨橚樻樿橁橪橤橐橏橔橯橩橠樼橞橖橕橍橎橆歕歔歖殧殪殫毈毇氄氃氆澭濋澣濇澼濎濈潞濄澽澞濊澨瀄澥澮澺澬澪濏澿澸"],
        ["ea40", "澢濉澫濍澯澲澰燅燂熿熸燖燀燁燋燔燊燇燏熽燘熼燆燚燛犝犞獩獦獧獬獥獫獪瑿璚璠璔璒璕璡甋疀瘯瘭瘱瘽瘳瘼瘵瘲瘰皻盦瞚瞝瞡瞜瞛瞢瞣瞕瞙"],
        ["eaa1", "瞗磝磩磥磪磞磣磛磡磢磭磟磠禤穄穈穇窶窸窵窱窷篞篣篧篝篕篥篚篨篹篔篪篢篜篫篘篟糒糔糗糐糑縒縡縗縌縟縠縓縎縜縕縚縢縋縏縖縍縔縥縤罃罻罼罺羱翯耪耩聬膱膦膮膹膵膫膰膬膴膲膷膧臲艕艖艗蕖蕅蕫蕍蕓蕡蕘"],
        ["eb40", "蕀蕆蕤蕁蕢蕄蕑蕇蕣蔾蕛蕱蕎蕮蕵蕕蕧蕠薌蕦蕝蕔蕥蕬虣虥虤螛螏螗螓螒螈螁螖螘蝹螇螣螅螐螑螝螄螔螜螚螉褞褦褰褭褮褧褱褢褩褣褯褬褟觱諠"],
        ["eba1", "諢諲諴諵諝謔諤諟諰諈諞諡諨諿諯諻貑貒貐賵賮賱賰賳赬赮趥趧踳踾踸蹀蹅踶踼踽蹁踰踿躽輶輮輵輲輹輷輴遶遹遻邆郺鄳鄵鄶醓醐醑醍醏錧錞錈錟錆錏鍺錸錼錛錣錒錁鍆錭錎錍鋋錝鋺錥錓鋹鋷錴錂錤鋿錩錹錵錪錔錌"],
        ["ec40", "錋鋾錉錀鋻錖閼闍閾閹閺閶閿閵閽隩雔霋霒霐鞙鞗鞔韰韸頵頯頲餤餟餧餩馞駮駬駥駤駰駣駪駩駧骹骿骴骻髶髺髹髷鬳鮀鮅鮇魼魾魻鮂鮓鮒鮐魺鮕"],
        ["eca1", "魽鮈鴥鴗鴠鴞鴔鴩鴝鴘鴢鴐鴙鴟麈麆麇麮麭黕黖黺鼒鼽儦儥儢儤儠儩勴嚓嚌嚍嚆嚄嚃噾嚂噿嚁壖壔壏壒嬭嬥嬲嬣嬬嬧嬦嬯嬮孻寱寲嶷幬幪徾徻懃憵憼懧懠懥懤懨懞擯擩擣擫擤擨斁斀斶旚曒檍檖檁檥檉檟檛檡檞檇檓檎"],
        ["ed40", "檕檃檨檤檑橿檦檚檅檌檒歛殭氉濌澩濴濔濣濜濭濧濦濞濲濝濢濨燡燱燨燲燤燰燢獳獮獯璗璲璫璐璪璭璱璥璯甐甑甒甏疄癃癈癉癇皤盩瞵瞫瞲瞷瞶"],
        ["eda1", "瞴瞱瞨矰磳磽礂磻磼磲礅磹磾礄禫禨穜穛穖穘穔穚窾竀竁簅簏篲簀篿篻簎篴簋篳簂簉簃簁篸篽簆篰篱簐簊糨縭縼繂縳顈縸縪繉繀繇縩繌縰縻縶繄縺罅罿罾罽翴翲耬膻臄臌臊臅臇膼臩艛艚艜薃薀薏薧薕薠薋薣蕻薤薚薞"],
        ["ee40", "蕷蕼薉薡蕺蕸蕗薎薖薆薍薙薝薁薢薂薈薅蕹蕶薘薐薟虨螾螪螭蟅螰螬螹螵螼螮蟉蟃蟂蟌螷螯蟄蟊螴螶螿螸螽蟞螲褵褳褼褾襁襒褷襂覭覯覮觲觳謞"],
        ["eea1", "謘謖謑謅謋謢謏謒謕謇謍謈謆謜謓謚豏豰豲豱豯貕貔賹赯蹎蹍蹓蹐蹌蹇轃轀邅遾鄸醚醢醛醙醟醡醝醠鎡鎃鎯鍤鍖鍇鍼鍘鍜鍶鍉鍐鍑鍠鍭鎏鍌鍪鍹鍗鍕鍒鍏鍱鍷鍻鍡鍞鍣鍧鎀鍎鍙闇闀闉闃闅閷隮隰隬霠霟霘霝霙鞚鞡鞜"],
        ["ef40", "鞞鞝韕韔韱顁顄顊顉顅顃餥餫餬餪餳餲餯餭餱餰馘馣馡騂駺駴駷駹駸駶駻駽駾駼騃骾髾髽鬁髼魈鮚鮨鮞鮛鮦鮡鮥鮤鮆鮢鮠鮯鴳鵁鵧鴶鴮鴯鴱鴸鴰"],
        ["efa1", "鵅鵂鵃鴾鴷鵀鴽翵鴭麊麉麍麰黈黚黻黿鼤鼣鼢齔龠儱儭儮嚘嚜嚗嚚嚝嚙奰嬼屩屪巀幭幮懘懟懭懮懱懪懰懫懖懩擿攄擽擸攁攃擼斔旛曚曛曘櫅檹檽櫡櫆檺檶檷櫇檴檭歞毉氋瀇瀌瀍瀁瀅瀔瀎濿瀀濻瀦濼濷瀊爁燿燹爃燽獶"],
        ["f040", "璸瓀璵瓁璾璶璻瓂甔甓癜癤癙癐癓癗癚皦皽盬矂瞺磿礌礓礔礉礐礒礑禭禬穟簜簩簙簠簟簭簝簦簨簢簥簰繜繐繖繣繘繢繟繑繠繗繓羵羳翷翸聵臑臒"],
        ["f0a1", "臐艟艞薴藆藀藃藂薳薵薽藇藄薿藋藎藈藅薱薶藒蘤薸薷薾虩蟧蟦蟢蟛蟫蟪蟥蟟蟳蟤蟔蟜蟓蟭蟘蟣螤蟗蟙蠁蟴蟨蟝襓襋襏襌襆襐襑襉謪謧謣謳謰謵譇謯謼謾謱謥謷謦謶謮謤謻謽謺豂豵貙貘貗賾贄贂贀蹜蹢蹠蹗蹖蹞蹥蹧"],
        ["f140", "蹛蹚蹡蹝蹩蹔轆轇轈轋鄨鄺鄻鄾醨醥醧醯醪鎵鎌鎒鎷鎛鎝鎉鎧鎎鎪鎞鎦鎕鎈鎙鎟鎍鎱鎑鎲鎤鎨鎴鎣鎥闒闓闑隳雗雚巂雟雘雝霣霢霥鞬鞮鞨鞫鞤鞪"],
        ["f1a1", "鞢鞥韗韙韖韘韺顐顑顒颸饁餼餺騏騋騉騍騄騑騊騅騇騆髀髜鬈鬄鬅鬩鬵魊魌魋鯇鯆鯃鮿鯁鮵鮸鯓鮶鯄鮹鮽鵜鵓鵏鵊鵛鵋鵙鵖鵌鵗鵒鵔鵟鵘鵚麎麌黟鼁鼀鼖鼥鼫鼪鼩鼨齌齕儴儵劖勷厴嚫嚭嚦嚧嚪嚬壚壝壛夒嬽嬾嬿巃幰"],
        ["f240", "徿懻攇攐攍攉攌攎斄旞旝曞櫧櫠櫌櫑櫙櫋櫟櫜櫐櫫櫏櫍櫞歠殰氌瀙瀧瀠瀖瀫瀡瀢瀣瀩瀗瀤瀜瀪爌爊爇爂爅犥犦犤犣犡瓋瓅璷瓃甖癠矉矊矄矱礝礛"],
        ["f2a1", "礡礜礗礞禰穧穨簳簼簹簬簻糬糪繶繵繸繰繷繯繺繲繴繨罋罊羃羆羷翽翾聸臗臕艤艡艣藫藱藭藙藡藨藚藗藬藲藸藘藟藣藜藑藰藦藯藞藢蠀蟺蠃蟶蟷蠉蠌蠋蠆蟼蠈蟿蠊蠂襢襚襛襗襡襜襘襝襙覈覷覶觶譐譈譊譀譓譖譔譋譕"],
        ["f340", "譑譂譒譗豃豷豶貚贆贇贉趬趪趭趫蹭蹸蹳蹪蹯蹻軂轒轑轏轐轓辴酀鄿醰醭鏞鏇鏏鏂鏚鏐鏹鏬鏌鏙鎩鏦鏊鏔鏮鏣鏕鏄鏎鏀鏒鏧镽闚闛雡霩霫霬霨霦"],
        ["f3a1", "鞳鞷鞶韝韞韟顜顙顝顗颿颽颻颾饈饇饃馦馧騚騕騥騝騤騛騢騠騧騣騞騜騔髂鬋鬊鬎鬌鬷鯪鯫鯠鯞鯤鯦鯢鯰鯔鯗鯬鯜鯙鯥鯕鯡鯚鵷鶁鶊鶄鶈鵱鶀鵸鶆鶋鶌鵽鵫鵴鵵鵰鵩鶅鵳鵻鶂鵯鵹鵿鶇鵨麔麑黀黼鼭齀齁齍齖齗齘匷嚲"],
        ["f440", "嚵嚳壣孅巆巇廮廯忀忁懹攗攖攕攓旟曨曣曤櫳櫰櫪櫨櫹櫱櫮櫯瀼瀵瀯瀷瀴瀱灂瀸瀿瀺瀹灀瀻瀳灁爓爔犨獽獼璺皫皪皾盭矌矎矏矍矲礥礣礧礨礤礩"],
        ["f4a1", "禲穮穬穭竷籉籈籊籇籅糮繻繾纁纀羺翿聹臛臙舋艨艩蘢藿蘁藾蘛蘀藶蘄蘉蘅蘌藽蠙蠐蠑蠗蠓蠖襣襦覹觷譠譪譝譨譣譥譧譭趮躆躈躄轙轖轗轕轘轚邍酃酁醷醵醲醳鐋鐓鏻鐠鐏鐔鏾鐕鐐鐨鐙鐍鏵鐀鏷鐇鐎鐖鐒鏺鐉鏸鐊鏿"],
        ["f540", "鏼鐌鏶鐑鐆闞闠闟霮霯鞹鞻韽韾顠顢顣顟飁飂饐饎饙饌饋饓騲騴騱騬騪騶騩騮騸騭髇髊髆鬐鬒鬑鰋鰈鯷鰅鰒鯸鱀鰇鰎鰆鰗鰔鰉鶟鶙鶤鶝鶒鶘鶐鶛"],
        ["f5a1", "鶠鶔鶜鶪鶗鶡鶚鶢鶨鶞鶣鶿鶩鶖鶦鶧麙麛麚黥黤黧黦鼰鼮齛齠齞齝齙龑儺儹劘劗囃嚽嚾孈孇巋巏廱懽攛欂櫼欃櫸欀灃灄灊灈灉灅灆爝爚爙獾甗癪矐礭礱礯籔籓糲纊纇纈纋纆纍罍羻耰臝蘘蘪蘦蘟蘣蘜蘙蘧蘮蘡蘠蘩蘞蘥"],
        ["f640", "蠩蠝蠛蠠蠤蠜蠫衊襭襩襮襫觺譹譸譅譺譻贐贔趯躎躌轞轛轝酆酄酅醹鐿鐻鐶鐩鐽鐼鐰鐹鐪鐷鐬鑀鐱闥闤闣霵霺鞿韡顤飉飆飀饘饖騹騽驆驄驂驁騺"],
        ["f6a1", "騿髍鬕鬗鬘鬖鬺魒鰫鰝鰜鰬鰣鰨鰩鰤鰡鶷鶶鶼鷁鷇鷊鷏鶾鷅鷃鶻鶵鷎鶹鶺鶬鷈鶱鶭鷌鶳鷍鶲鹺麜黫黮黭鼛鼘鼚鼱齎齥齤龒亹囆囅囋奱孋孌巕巑廲攡攠攦攢欋欈欉氍灕灖灗灒爞爟犩獿瓘瓕瓙瓗癭皭礵禴穰穱籗籜籙籛籚"],
        ["f740", "糴糱纑罏羇臞艫蘴蘵蘳蘬蘲蘶蠬蠨蠦蠪蠥襱覿覾觻譾讄讂讆讅譿贕躕躔躚躒躐躖躗轠轢酇鑌鑐鑊鑋鑏鑇鑅鑈鑉鑆霿韣顪顩飋饔饛驎驓驔驌驏驈驊"],
        ["f7a1", "驉驒驐髐鬙鬫鬻魖魕鱆鱈鰿鱄鰹鰳鱁鰼鰷鰴鰲鰽鰶鷛鷒鷞鷚鷋鷐鷜鷑鷟鷩鷙鷘鷖鷵鷕鷝麶黰鼵鼳鼲齂齫龕龢儽劙壨壧奲孍巘蠯彏戁戃戄攩攥斖曫欑欒欏毊灛灚爢玂玁玃癰矔籧籦纕艬蘺虀蘹蘼蘱蘻蘾蠰蠲蠮蠳襶襴襳觾"],
        ["f840", "讌讎讋讈豅贙躘轤轣醼鑢鑕鑝鑗鑞韄韅頀驖驙鬞鬟鬠鱒鱘鱐鱊鱍鱋鱕鱙鱌鱎鷻鷷鷯鷣鷫鷸鷤鷶鷡鷮鷦鷲鷰鷢鷬鷴鷳鷨鷭黂黐黲黳鼆鼜鼸鼷鼶齃齏"],
        ["f8a1", "齱齰齮齯囓囍孎屭攭曭曮欓灟灡灝灠爣瓛瓥矕礸禷禶籪纗羉艭虃蠸蠷蠵衋讔讕躞躟躠躝醾醽釂鑫鑨鑩雥靆靃靇韇韥驞髕魙鱣鱧鱦鱢鱞鱠鸂鷾鸇鸃鸆鸅鸀鸁鸉鷿鷽鸄麠鼞齆齴齵齶囔攮斸欘欙欗欚灢爦犪矘矙礹籩籫糶纚"],
        ["f940", "纘纛纙臠臡虆虇虈襹襺襼襻觿讘讙躥躤躣鑮鑭鑯鑱鑳靉顲饟鱨鱮鱭鸋鸍鸐鸏鸒鸑麡黵鼉齇齸齻齺齹圞灦籯蠼趲躦釃鑴鑸鑶鑵驠鱴鱳鱱鱵鸔鸓黶鼊"],
        ["f9a1", "龤灨灥糷虪蠾蠽蠿讞貜躩軉靋顳顴飌饡馫驤驦驧鬤鸕鸗齈戇欞爧虌躨钂钀钁驩驨鬮鸙爩虋讟钃鱹麷癵驫鱺鸝灩灪麤齾齉龘碁銹裏墻恒粧嫺╔╦╗╠╬╣╚╩╝╒╤╕╞╪╡╘╧╛╓╥╖╟╫╢╙╨╜║═╭╮╰╯▓"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/big5-added.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["8740", "䏰䰲䘃䖦䕸𧉧䵷䖳𧲱䳢𧳅㮕䜶䝄䱇䱀𤊿𣘗𧍒𦺋𧃒䱗𪍑䝏䗚䲅𧱬䴇䪤䚡𦬣爥𥩔𡩣𣸆𣽡晍囻"],
        ["8767", "綕夝𨮹㷴霴𧯯寛𡵞媤㘥𩺰嫑宷峼杮薓𩥅瑡璝㡵𡵓𣚞𦀡㻬"],
        ["87a1", "𥣞㫵竼龗𤅡𨤍𣇪𠪊𣉞䌊蒄龖鐯䤰蘓墖靊鈘秐稲晠権袝瑌篅枂稬剏遆㓦珄𥶹瓆鿇垳䤯呌䄱𣚎堘穲𧭥讏䚮𦺈䆁𥶙箮𢒼鿈𢓁𢓉𢓌鿉蔄𣖻䂴鿊䓡𪷿拁灮鿋"],
        ["8840", "㇀", 4, "𠄌㇅𠃑𠃍㇆㇇𠃋𡿨㇈𠃊㇉㇊㇋㇌𠄎㇍㇎ĀÁǍÀĒÉĚÈŌÓǑÒ࿿Ê̄Ế࿿Ê̌ỀÊāáǎàɑēéěèīíǐìōóǒòūúǔùǖǘǚ"],
        ["88a1", "ǜü࿿ê̄ế࿿ê̌ềêɡ⏚⏛"],
        ["8940", "𪎩𡅅"],
        ["8943", "攊"],
        ["8946", "丽滝鵎釟"],
        ["894c", "𧜵撑会伨侨兖兴农凤务动医华发变团声处备夲头学实実岚庆总斉柾栄桥济炼电纤纬纺织经统缆缷艺苏药视设询车轧轮"],
        ["89a1", "琑糼緍楆竉刧"],
        ["89ab", "醌碸酞肼"],
        ["89b0", "贋胶𠧧"],
        ["89b5", "肟黇䳍鷉鸌䰾𩷶𧀎鸊𪄳㗁"],
        ["89c1", "溚舾甙"],
        ["89c5", "䤑马骏龙禇𨑬𡷊𠗐𢫦两亁亀亇亿仫伷㑌侽㹈倃傈㑽㒓㒥円夅凛凼刅争剹劐匧㗇厩㕑厰㕓参吣㕭㕲㚁咓咣咴咹哐哯唘唣唨㖘唿㖥㖿嗗㗅"],
        ["8a40", "𧶄唥"],
        ["8a43", "𠱂𠴕𥄫喐𢳆㧬𠍁蹆𤶸𩓥䁓𨂾睺𢰸㨴䟕𨅝𦧲𤷪擝𠵼𠾴𠳕𡃴撍蹾𠺖𠰋𠽤𢲩𨉖𤓓"],
        ["8a64", "𠵆𩩍𨃩䟴𤺧𢳂骲㩧𩗴㿭㔆𥋇𩟔𧣈𢵄鵮頕"],
        ["8a76", "䏙𦂥撴哣𢵌𢯊𡁷㧻𡁯"],
        ["8aa1", "𦛚𦜖𧦠擪𥁒𠱃蹨𢆡𨭌𠜱"],
        ["8aac", "䠋𠆩㿺塳𢶍"],
        ["8ab2", "𤗈𠓼𦂗𠽌𠶖啹䂻䎺"],
        ["8abb", "䪴𢩦𡂝膪飵𠶜捹㧾𢝵跀嚡摼㹃"],
        ["8ac9", "𪘁𠸉𢫏𢳉"],
        ["8ace", "𡃈𣧂㦒㨆𨊛㕸𥹉𢃇噒𠼱𢲲𩜠㒼氽𤸻"],
        ["8adf", "𧕴𢺋𢈈𪙛𨳍𠹺𠰴𦠜羓𡃏𢠃𢤹㗻𥇣𠺌𠾍𠺪㾓𠼰𠵇𡅏𠹌"],
        ["8af6", "𠺫𠮩𠵈𡃀𡄽㿹𢚖搲𠾭"],
        ["8b40", "𣏴𧘹𢯎𠵾𠵿𢱑𢱕㨘𠺘𡃇𠼮𪘲𦭐𨳒𨶙𨳊閪哌苄喹"],
        ["8b55", "𩻃鰦骶𧝞𢷮煀腭胬尜𦕲脴㞗卟𨂽醶𠻺𠸏𠹷𠻻㗝𤷫㘉𠳖嚯𢞵𡃉𠸐𠹸𡁸𡅈𨈇𡑕𠹹𤹐𢶤婔𡀝𡀞𡃵𡃶垜𠸑"],
        ["8ba1", "𧚔𨋍𠾵𠹻𥅾㜃𠾶𡆀𥋘𪊽𤧚𡠺𤅷𨉼墙剨㘚𥜽箲孨䠀䬬鼧䧧鰟鮍𥭴𣄽嗻㗲嚉丨夂𡯁屮靑𠂆乛亻㔾尣彑忄㣺扌攵歺氵氺灬爫丬犭𤣩罒礻糹罓𦉪㓁"],
        ["8bde", "𦍋耂肀𦘒𦥑卝衤见𧢲讠贝钅镸长门𨸏韦页风飞饣𩠐鱼鸟黄歯龜丷𠂇阝户钢"],
        ["8c40", "倻淾𩱳龦㷉袏𤅎灷峵䬠𥇍㕙𥴰愢𨨲辧釶熑朙玺𣊁𪄇㲋𡦀䬐磤琂冮𨜏䀉橣𪊺䈣蘏𠩯稪𩥇𨫪靕灍匤𢁾鏴盙𨧣龧矝亣俰傼丯众龨吴綋墒壐𡶶庒庙忂𢜒斋"],
        ["8ca1", "𣏹椙橃𣱣泿"],
        ["8ca7", "爀𤔅玌㻛𤨓嬕璹讃𥲤𥚕窓篬糃繬苸薗龩袐龪躹龫迏蕟駠鈡龬𨶹𡐿䁱䊢娚"],
        ["8cc9", "顨杫䉶圽"],
        ["8cce", "藖𤥻芿𧄍䲁𦵴嵻𦬕𦾾龭龮宖龯曧繛湗秊㶈䓃𣉖𢞖䎚䔶"],
        ["8ce6", "峕𣬚諹屸㴒𣕑嵸龲煗䕘𤃬𡸣䱷㥸㑊𠆤𦱁諌侴𠈹妿腬顖𩣺弻"],
        ["8d40", "𠮟"],
        ["8d42", "𢇁𨥭䄂䚻𩁹㼇龳𪆵䃸㟖䛷𦱆䅼𨚲𧏿䕭㣔𥒚䕡䔛䶉䱻䵶䗪㿈𤬏㙡䓞䒽䇭崾嵈嵖㷼㠏嶤嶹㠠㠸幂庽弥徃㤈㤔㤿㥍惗愽峥㦉憷憹懏㦸戬抐拥挘㧸嚱"],
        ["8da1", "㨃揢揻搇摚㩋擀崕嘡龟㪗斆㪽旿晓㫲暒㬢朖㭂枤栀㭘桊梄㭲㭱㭻椉楃牜楤榟榅㮼槖㯝橥橴橱檂㯬檙㯲檫檵櫔櫶殁毁毪汵沪㳋洂洆洦涁㳯涤涱渕渘温溆𨧀溻滢滚齿滨滩漤漴㵆𣽁澁澾㵪㵵熷岙㶊瀬㶑灐灔灯灿炉𠌥䏁㗱𠻘"],
        ["8e40", "𣻗垾𦻓焾𥟠㙎榢𨯩孴穉𥣡𩓙穥穽𥦬窻窰竂竃燑𦒍䇊竚竝竪䇯咲𥰁笋筕笩𥌎𥳾箢筯莜𥮴𦱿篐萡箒箸𥴠㶭𥱥蒒篺簆簵𥳁籄粃𤢂粦晽𤕸糉糇糦籴糳糵糎"],
        ["8ea1", "繧䔝𦹄絝𦻖璍綉綫焵綳緒𤁗𦀩緤㴓緵𡟹緥𨍭縝𦄡𦅚繮纒䌫鑬縧罀罁罇礶𦋐駡羗𦍑羣𡙡𠁨䕜𣝦䔃𨌺翺𦒉者耈耝耨耯𪂇𦳃耻耼聡𢜔䦉𦘦𣷣𦛨朥肧𨩈脇脚墰𢛶汿𦒘𤾸擧𡒊舘𡡞橓𤩥𤪕䑺舩𠬍𦩒𣵾俹𡓽蓢荢𦬊𤦧𣔰𡝳𣷸芪椛芳䇛"],
        ["8f40", "蕋苐茚𠸖𡞴㛁𣅽𣕚艻苢茘𣺋𦶣𦬅𦮗𣗎㶿茝嗬莅䔋𦶥莬菁菓㑾𦻔橗蕚㒖𦹂𢻯葘𥯤葱㷓䓤檧葊𣲵祘蒨𦮖𦹷𦹃蓞萏莑䒠蒓蓤𥲑䉀𥳀䕃蔴嫲𦺙䔧蕳䔖枿蘖"],
        ["8fa1", "𨘥𨘻藁𧂈蘂𡖂𧃍䕫䕪蘨㙈𡢢号𧎚虾蝱𪃸蟮𢰧螱蟚蠏噡虬桖䘏衅衆𧗠𣶹𧗤衞袜䙛袴袵揁装睷𧜏覇覊覦覩覧覼𨨥觧𧤤𧪽誜瞓釾誐𧩙竩𧬺𣾏䜓𧬸煼謌謟𥐰𥕥謿譌譍誩𤩺讐讛誯𡛟䘕衏貛𧵔𧶏貫㜥𧵓賖𧶘𧶽贒贃𡤐賛灜贑𤳉㻐起"],
        ["9040", "趩𨀂𡀔𤦊㭼𨆼𧄌竧躭躶軃鋔輙輭𨍥𨐒辥錃𪊟𠩐辳䤪𨧞𨔽𣶻廸𣉢迹𪀔𨚼𨔁𢌥㦀𦻗逷𨔼𧪾遡𨕬𨘋邨𨜓郄𨛦邮都酧㫰醩釄粬𨤳𡺉鈎沟鉁鉢𥖹銹𨫆𣲛𨬌𥗛"],
        ["90a1", "𠴱錬鍫𨫡𨯫炏嫃𨫢𨫥䥥鉄𨯬𨰹𨯿鍳鑛躼閅閦鐦閠濶䊹𢙺𨛘𡉼𣸮䧟氜陻隖䅬隣𦻕懚隶磵𨫠隽双䦡𦲸𠉴𦐐𩂯𩃥𤫑𡤕𣌊霱虂霶䨏䔽䖅𤫩灵孁霛靜𩇕靗孊𩇫靟鐥僐𣂷𣂼鞉鞟鞱鞾韀韒韠𥑬韮琜𩐳響韵𩐝𧥺䫑頴頳顋顦㬎𧅵㵑𠘰𤅜"],
        ["9140", "𥜆飊颷飈飇䫿𦴧𡛓喰飡飦飬鍸餹𤨩䭲𩡗𩤅駵騌騻騐驘𥜥㛄𩂱𩯕髠髢𩬅髴䰎鬔鬭𨘀倴鬴𦦨㣃𣁽魐魀𩴾婅𡡣鮎𤉋鰂鯿鰌𩹨鷔𩾷𪆒𪆫𪃡𪄣𪇟鵾鶃𪄴鸎梈"],
        ["91a1", "鷄𢅛𪆓𪈠𡤻𪈳鴹𪂹𪊴麐麕麞麢䴴麪麯𤍤黁㭠㧥㴝伲㞾𨰫鼂鼈䮖鐤𦶢鼗鼖鼹嚟嚊齅馸𩂋韲葿齢齩竜龎爖䮾𤥵𤦻煷𤧸𤍈𤩑玞𨯚𡣺禟𨥾𨸶鍩鏳𨩄鋬鎁鏋𨥬𤒹爗㻫睲穃烐𤑳𤏸煾𡟯炣𡢾𣖙㻇𡢅𥐯𡟸㜢𡛻𡠹㛡𡝴𡣑𥽋㜣𡛀坛𤨥𡏾𡊨"],
        ["9240", "𡏆𡒶蔃𣚦蔃葕𤦔𧅥𣸱𥕜𣻻𧁒䓴𣛮𩦝𦼦柹㜳㰕㷧塬𡤢栐䁗𣜿𤃡𤂋𤄏𦰡哋嚞𦚱嚒𠿟𠮨𠸍鏆𨬓鎜仸儫㠙𤐶亼𠑥𠍿佋侊𥙑婨𠆫𠏋㦙𠌊𠐔㐵伩𠋀𨺳𠉵諚𠈌亘"],
        ["92a1", "働儍侢伃𤨎𣺊佂倮偬傁俌俥偘僼兙兛兝兞湶𣖕𣸹𣺿浲𡢄𣺉冨凃𠗠䓝𠒣𠒒𠒑赺𨪜𠜎剙劤𠡳勡鍮䙺熌𤎌𠰠𤦬𡃤槑𠸝瑹㻞璙琔瑖玘䮎𤪼𤂍叐㖄爏𤃉喴𠍅响𠯆圝鉝雴鍦埝垍坿㘾壋媙𨩆𡛺𡝯𡜐娬妸銏婾嫏娒𥥆𡧳𡡡𤊕㛵洅瑃娡𥺃"],
        ["9340", "媁𨯗𠐓鏠璌𡌃焅䥲鐈𨧻鎽㞠尞岞幞幈𡦖𡥼𣫮廍孏𡤃𡤄㜁𡢠㛝𡛾㛓脪𨩇𡶺𣑲𨦨弌弎𡤧𡞫婫𡜻孄蘔𧗽衠恾𢡠𢘫忛㺸𢖯𢖾𩂈𦽳懀𠀾𠁆𢘛憙憘恵𢲛𢴇𤛔𩅍"],
        ["93a1", "摱𤙥𢭪㨩𢬢𣑐𩣪𢹸挷𪑛撶挱揑𤧣𢵧护𢲡搻敫楲㯴𣂎𣊭𤦉𣊫唍𣋠𡣙𩐿曎𣊉𣆳㫠䆐𥖄𨬢𥖏𡛼𥕛𥐥磮𣄃𡠪𣈴㑤𣈏𣆂𤋉暎𦴤晫䮓昰𧡰𡷫晣𣋒𣋡昞𥡲㣑𣠺𣞼㮙𣞢𣏾瓐㮖枏𤘪梶栞㯄檾㡣𣟕𤒇樳橒櫉欅𡤒攑梘橌㯗橺歗𣿀𣲚鎠鋲𨯪𨫋"],
        ["9440", "銉𨀞𨧜鑧涥漋𤧬浧𣽿㶏渄𤀼娽渊塇洤硂焻𤌚𤉶烱牐犇犔𤞏𤜥兹𤪤𠗫瑺𣻸𣙟𤩊𤤗𥿡㼆㺱𤫟𨰣𣼵悧㻳瓌琼鎇琷䒟𦷪䕑疃㽣𤳙𤴆㽘畕癳𪗆㬙瑨𨫌𤦫𤦎㫻"],
        ["94a1", "㷍𤩎㻿𤧅𤣳釺圲鍂𨫣𡡤僟𥈡𥇧睸𣈲眎眏睻𤚗𣞁㩞𤣰琸璛㺿𤪺𤫇䃈𤪖𦆮錇𥖁砞碍碈磒珐祙𧝁𥛣䄎禛蒖禥樭𣻺稺秴䅮𡛦䄲鈵秱𠵌𤦌𠊙𣶺𡝮㖗啫㕰㚪𠇔𠰍竢婙𢛵𥪯𥪜娍𠉛磰娪𥯆竾䇹籝籭䈑𥮳𥺼𥺦糍𤧹𡞰粎籼粮檲緜縇緓罎𦉡"],
        ["9540", "𦅜𧭈綗𥺂䉪𦭵𠤖柖𠁎𣗏埄𦐒𦏸𤥢翝笧𠠬𥫩𥵃笌𥸎駦虅驣樜𣐿㧢𤧷𦖭騟𦖠蒀𧄧𦳑䓪脷䐂胆脉腂𦞴飃𦩂艢艥𦩑葓𦶧蘐𧈛媆䅿𡡀嬫𡢡嫤𡣘蚠蜨𣶏蠭𧐢娂"],
        ["95a1", "衮佅袇袿裦襥襍𥚃襔𧞅𧞄𨯵𨯙𨮜𨧹㺭蒣䛵䛏㟲訽訜𩑈彍鈫𤊄旔焩烄𡡅鵭貟賩𧷜妚矃姰䍮㛔踪躧𤰉輰轊䋴汘澻𢌡䢛潹溋𡟚鯩㚵𤤯邻邗啱䤆醻鐄𨩋䁢𨫼鐧𨰝𨰻蓥訫閙閧閗閖𨴴瑅㻂𤣿𤩂𤏪㻧𣈥随𨻧𨹦𨹥㻌𤧭𤩸𣿮琒瑫㻼靁𩂰"],
        ["9640", "桇䨝𩂓𥟟靝鍨𨦉𨰦𨬯𦎾銺嬑譩䤼珹𤈛鞛靱餸𠼦巁𨯅𤪲頟𩓚鋶𩗗釥䓀𨭐𤩧𨭤飜𨩅㼀鈪䤥萔餻饍𧬆㷽馛䭯馪驜𨭥𥣈檏騡嫾騯𩣱䮐𩥈馼䮽䮗鍽塲𡌂堢𤦸"],
        ["96a1", "𡓨硄𢜟𣶸棅㵽鑘㤧慐𢞁𢥫愇鱏鱓鱻鰵鰐魿鯏𩸭鮟𪇵𪃾鴡䲮𤄄鸘䲰鴌𪆴𪃭𪃳𩤯鶥蒽𦸒𦿟𦮂藼䔳𦶤𦺄𦷰萠藮𦸀𣟗𦁤秢𣖜𣙀䤭𤧞㵢鏛銾鍈𠊿碹鉷鑍俤㑀遤𥕝砽硔碶硋𡝗𣇉𤥁㚚佲濚濙瀞瀞吔𤆵垻壳垊鴖埗焴㒯𤆬燫𦱀𤾗嬨𡞵𨩉"],
        ["9740", "愌嫎娋䊼𤒈㜬䭻𨧼鎻鎸𡣖𠼝葲𦳀𡐓𤋺𢰦𤏁妔𣶷𦝁綨𦅛𦂤𤦹𤦋𨧺鋥珢㻩璴𨭣𡢟㻡𤪳櫘珳珻㻖𤨾𤪔𡟙𤩦𠎧𡐤𤧥瑈𤤖炥𤥶銄珦鍟𠓾錱𨫎𨨖鎆𨯧𥗕䤵𨪂煫"],
        ["97a1", "𤥃𠳿嚤𠘚𠯫𠲸唂秄𡟺緾𡛂𤩐𡡒䔮鐁㜊𨫀𤦭妰𡢿𡢃𧒄媡㛢𣵛㚰鉟婹𨪁𡡢鍴㳍𠪴䪖㦊僴㵩㵌𡎜煵䋻𨈘渏𩃤䓫浗𧹏灧沯㳖𣿭𣸭渂漌㵯𠏵畑㚼㓈䚀㻚䡱姄鉮䤾轁𨰜𦯀堒埈㛖𡑒烾𤍢𤩱𢿣𡊰𢎽梹楧𡎘𣓥𧯴𣛟𨪃𣟖𣏺𤲟樚𣚭𦲷萾䓟䓎"],
        ["9840", "𦴦𦵑𦲂𦿞漗𧄉茽𡜺菭𦲀𧁓𡟛妉媂𡞳婡婱𡤅𤇼㜭姯𡜼㛇熎鎐暚𤊥婮娫𤊓樫𣻹𧜶𤑛𤋊焝𤉙𨧡侰𦴨峂𤓎𧹍𤎽樌𤉖𡌄炦焳𤏩㶥泟勇𤩏繥姫崯㷳彜𤩝𡟟綤萦"],
        ["98a1", "咅𣫺𣌀𠈔坾𠣕𠘙㿥𡾞𪊶瀃𩅛嵰玏糓𨩙𩐠俈翧狍猐𧫴猸猹𥛶獁獈㺩𧬘遬燵𤣲珡臶㻊県㻑沢国琙琞琟㻢㻰㻴㻺瓓㼎㽓畂畭畲疍㽼痈痜㿀癍㿗癴㿜発𤽜熈嘣覀塩䀝睃䀹条䁅㗛瞘䁪䁯属瞾矋売砘点砜䂨砹硇硑硦葈𥔵礳栃礲䄃"],
        ["9940", "䄉禑禙辻稆込䅧窑䆲窼艹䇄竏竛䇏両筢筬筻簒簛䉠䉺类粜䊌粸䊔糭输烀𠳏総緔緐緽羮羴犟䎗耠耥笹耮耱联㷌垴炠肷胩䏭脌猪脎脒畠脔䐁㬹腖腙腚"],
        ["99a1", "䐓堺腼膄䐥膓䐭膥埯臁臤艔䒏芦艶苊苘苿䒰荗险榊萅烵葤惣蒈䔄蒾蓡蓸蔐蔸蕒䔻蕯蕰藠䕷虲蚒蚲蛯际螋䘆䘗袮裿褤襇覑𧥧訩訸誔誴豑賔賲贜䞘塟跃䟭仮踺嗘坔蹱嗵躰䠷軎転軤軭軲辷迁迊迌逳駄䢭飠鈓䤞鈨鉘鉫銱銮銿"],
        ["9a40", "鋣鋫鋳鋴鋽鍃鎄鎭䥅䥑麿鐗匁鐝鐭鐾䥪鑔鑹锭関䦧间阳䧥枠䨤靀䨵鞲韂噔䫤惨颹䬙飱塄餎餙冴餜餷饂饝饢䭰駅䮝騼鬏窃魩鮁鯝鯱鯴䱭鰠㝯𡯂鵉鰺"],
        ["9aa1", "黾噐鶓鶽鷀鷼银辶鹻麬麱麽黆铜黢黱黸竈齄𠂔𠊷𠎠椚铃妬𠓗塀铁㞹𠗕𠘕𠙶𡚺块煳𠫂𠫍𠮿呪吆𠯋咞𠯻𠰻𠱓𠱥𠱼惧𠲍噺𠲵𠳝𠳭𠵯𠶲𠷈楕鰯螥𠸄𠸎𠻗𠾐𠼭𠹳尠𠾼帋𡁜𡁏𡁶朞𡁻𡂈𡂖㙇𡂿𡃓𡄯𡄻卤蒭𡋣𡍵𡌶讁𡕷𡘙𡟃𡟇乸炻𡠭𡥪"],
        ["9b40", "𡨭𡩅𡰪𡱰𡲬𡻈拃𡻕𡼕熘桕𢁅槩㛈𢉼𢏗𢏺𢜪𢡱𢥏苽𢥧𢦓𢫕覥𢫨辠𢬎鞸𢬿顇骽𢱌"],
        ["9b62", "𢲈𢲷𥯨𢴈𢴒𢶷𢶕𢹂𢽴𢿌𣀳𣁦𣌟𣏞徱晈暿𧩹𣕧𣗳爁𤦺矗𣘚𣜖纇𠍆墵朎"],
        ["9ba1", "椘𣪧𧙗𥿢𣸑𣺹𧗾𢂚䣐䪸𤄙𨪚𤋮𤌍𤀻𤌴𤎖𤩅𠗊凒𠘑妟𡺨㮾𣳿𤐄𤓖垈𤙴㦛𤜯𨗨𩧉㝢𢇃譞𨭎駖𤠒𤣻𤨕爉𤫀𠱸奥𤺥𤾆𠝹軚𥀬劏圿煱𥊙𥐙𣽊𤪧喼𥑆𥑮𦭒釔㑳𥔿𧘲𥕞䜘𥕢𥕦𥟇𤤿𥡝偦㓻𣏌惞𥤃䝼𨥈𥪮𥮉𥰆𡶐垡煑澶𦄂𧰒遖𦆲𤾚譢𦐂𦑊"],
        ["9c40", "嵛𦯷輶𦒄𡤜諪𤧶𦒈𣿯𦔒䯀𦖿𦚵𢜛鑥𥟡憕娧晉侻嚹𤔡𦛼乪𤤴陖涏𦲽㘘襷𦞙𦡮𦐑𦡞營𦣇筂𩃀𠨑𦤦鄄𦤹穅鷰𦧺騦𦨭㙟𦑩𠀡禃𦨴𦭛崬𣔙菏𦮝䛐𦲤画补𦶮墶"],
        ["9ca1", "㜜𢖍𧁋𧇍㱔𧊀𧊅銁𢅺𧊋錰𧋦𤧐氹钟𧑐𠻸蠧裵𢤦𨑳𡞱溸𤨪𡠠㦤㚹尐秣䔿暶𩲭𩢤襃𧟌𧡘囖䃟𡘊㦡𣜯𨃨𡏅熭荦𧧝𩆨婧䲷𧂯𨦫𧧽𧨊𧬋𧵦𤅺筃祾𨀉澵𪋟樃𨌘厢𦸇鎿栶靝𨅯𨀣𦦵𡏭𣈯𨁈嶅𨰰𨂃圕頣𨥉嶫𤦈斾槕叒𤪥𣾁㰑朶𨂐𨃴𨄮𡾡𨅏"],
        ["9d40", "𨆉𨆯𨈚𨌆𨌯𨎊㗊𨑨𨚪䣺揦𨥖砈鉕𨦸䏲𨧧䏟𨧨𨭆𨯔姸𨰉輋𨿅𩃬筑𩄐𩄼㷷𩅞𤫊运犏嚋𩓧𩗩𩖰𩖸𩜲𩣑𩥉𩥪𩧃𩨨𩬎𩵚𩶛纟𩻸𩼣䲤镇𪊓熢𪋿䶑递𪗋䶜𠲜达嗁"],
        ["9da1", "辺𢒰边𤪓䔉繿潖檱仪㓤𨬬𧢝㜺躀𡟵𨀤𨭬𨮙𧨾𦚯㷫𧙕𣲷𥘵𥥖亚𥺁𦉘嚿𠹭踎孭𣺈𤲞揞拐𡟶𡡻攰嘭𥱊吚𥌑㷆𩶘䱽嘢嘞罉𥻘奵𣵀蝰东𠿪𠵉𣚺脗鵞贘瘻鱅癎瞹鍅吲腈苷嘥脲萘肽嗪祢噃吖𠺝㗎嘅嗱曱𨋢㘭甴嗰喺咗啲𠱁𠲖廐𥅈𠹶𢱢"],
        ["9e40", "𠺢麫絚嗞𡁵抝靭咔賍燶酶揼掹揾啩𢭃鱲𢺳冚㓟𠶧冧呍唞唓癦踭𦢊疱肶蠄螆裇膶萜𡃁䓬猄𤜆宐茋𦢓噻𢛴𧴯𤆣𧵳𦻐𧊶酰𡇙鈈𣳼𪚩𠺬𠻹牦𡲢䝎𤿂𧿹𠿫䃺"],
        ["9ea1", "鱝攟𢶠䣳𤟠𩵼𠿬𠸊恢𧖣𠿭"],
        ["9ead", "𦁈𡆇熣纎鵐业丄㕷嬍沲卧㚬㧜卽㚥𤘘墚𤭮舭呋垪𥪕𠥹"],
        ["9ec5", "㩒𢑥獴𩺬䴉鯭𣳾𩼰䱛𤾩𩖞𩿞葜𣶶𧊲𦞳𣜠挮紥𣻷𣸬㨪逈勌㹴㙺䗩𠒎癀嫰𠺶硺𧼮墧䂿噼鮋嵴癔𪐴麅䳡痹㟻愙𣃚𤏲"],
        ["9ef5", "噝𡊩垧𤥣𩸆刴𧂮㖭汊鵼"],
        ["9f40", "籖鬹埞𡝬屓擓𩓐𦌵𧅤蚭𠴨𦴢𤫢𠵱"],
        ["9f4f", "凾𡼏嶎霃𡷑麁遌笟鬂峑箣扨挵髿篏鬪籾鬮籂粆鰕篼鬉鼗鰛𤤾齚啳寃俽麘俲剠㸆勑坧偖妷帒韈鶫轜呩鞴饀鞺匬愰"],
        ["9fa1", "椬叚鰊鴂䰻陁榀傦畆𡝭駚剳"],
        ["9fae", "酙隁酜"],
        ["9fb2", "酑𨺗捿𦴣櫊嘑醎畺抅𠏼獏籰𥰡𣳽"],
        ["9fc1", "𤤙盖鮝个𠳔莾衂"],
        ["9fc9", "届槀僭坺刟巵从氱𠇲伹咜哚劚趂㗾弌㗳"],
        ["9fdb", "歒酼龥鮗頮颴骺麨麄煺笔"],
        ["9fe7", "毺蠘罸"],
        ["9feb", "嘠𪙊蹷齓"],
        ["9ff0", "跔蹏鸜踁抂𨍽踨蹵竓𤩷稾磘泪詧瘇"],
        ["a040", "𨩚鼦泎蟖痃𪊲硓咢贌狢獱謭猂瓱賫𤪻蘯徺袠䒷"],
        ["a055", "𡠻𦸅"],
        ["a058", "詾𢔛"],
        ["a05b", "惽癧髗鵄鍮鮏蟵"],
        ["a063", "蠏賷猬霡鮰㗖犲䰇籑饊𦅙慙䰄麖慽"],
        ["a073", "坟慯抦戹拎㩜懢厪𣏵捤栂㗒"],
        ["a0a1", "嵗𨯂迚𨸹"],
        ["a0a6", "僙𡵆礆匲阸𠼻䁥"],
        ["a0ae", "矾"],
        ["a0b0", "糂𥼚糚稭聦聣絍甅瓲覔舚朌聢𧒆聛瓰脃眤覉𦟌畓𦻑螩蟎臈螌詉貭譃眫瓸蓚㘵榲趦"],
        ["a0d4", "覩瑨涹蟁𤀑瓧㷛煶悤憜㳑煢恷"],
        ["a0e2", "罱𨬭牐惩䭾删㰘𣳇𥻗𧙖𥔱𡥄𡋾𩤃𦷜𧂭峁𦆭𨨏𣙷𠃮𦡆𤼎䕢嬟𦍌齐麦𦉫"],
        ["a3c0", "␀", 31, "␡"],
        ["c6a1", "①", 9, "⑴", 9, "ⅰ", 9, "丶丿亅亠冂冖冫勹匸卩厶夊宀巛⼳广廴彐彡攴无疒癶辵隶¨ˆヽヾゝゞ〃仝々〆〇ー［］✽ぁ", 23],
        ["c740", "す", 58, "ァアィイ"],
        ["c7a1", "ゥ", 81, "А", 5, "ЁЖ", 4],
        ["c840", "Л", 26, "ёж", 25, "⇧↸↹㇏𠃌乚𠂊刂䒑"],
        ["c8a1", "龰冈龱𧘇"],
        ["c8cd", "￢￤＇＂㈱№℡゛゜⺀⺄⺆⺇⺈⺊⺌⺍⺕⺜⺝⺥⺧⺪⺬⺮⺶⺼⺾⻆⻊⻌⻍⻏⻖⻗⻞⻣"],
        ["c8f5", "ʃɐɛɔɵœøŋʊɪ"],
        ["f9fe", "￭"],
        ["fa40", "𠕇鋛𠗟𣿅蕌䊵珯况㙉𤥂𨧤鍄𡧛苮𣳈砼杄拟𤤳𨦪𠊠𦮳𡌅侫𢓭倈𦴩𧪄𣘀𤪱𢔓倩𠍾徤𠎀𠍇滛𠐟偽儁㑺儎顬㝃萖𤦤𠒇兠𣎴兪𠯿𢃼𠋥𢔰𠖎𣈳𡦃宂蝽𠖳𣲙冲冸"],
        ["faa1", "鴴凉减凑㳜凓𤪦决凢卂凭菍椾𣜭彻刋刦刼劵剗劔効勅簕蕂勠蘍𦬓包𨫞啉滙𣾀𠥔𣿬匳卄𠯢泋𡜦栛珕恊㺪㣌𡛨燝䒢卭却𨚫卾卿𡖖𡘓矦厓𨪛厠厫厮玧𥝲㽙玜叁叅汉义埾叙㪫𠮏叠𣿫𢶣叶𠱷吓灹唫晗浛呭𦭓𠵴啝咏咤䞦𡜍𠻝㶴𠵍"],
        ["fb40", "𨦼𢚘啇䳭启琗喆喩嘅𡣗𤀺䕒𤐵暳𡂴嘷曍𣊊暤暭噍噏磱囱鞇叾圀囯园𨭦㘣𡉏坆𤆥汮炋坂㚱𦱾埦𡐖堃𡑔𤍣堦𤯵塜墪㕡壠壜𡈼壻寿坃𪅐𤉸鏓㖡够梦㛃湙"],
        ["fba1", "𡘾娤啓𡚒蔅姉𠵎𦲁𦴪𡟜姙𡟻𡞲𦶦浱𡠨𡛕姹𦹅媫婣㛦𤦩婷㜈媖瑥嫓𦾡𢕔㶅𡤑㜲𡚸広勐孶斈孼𧨎䀄䡝𠈄寕慠𡨴𥧌𠖥寳宝䴐尅𡭄尓珎尔𡲥𦬨屉䣝岅峩峯嶋𡷹𡸷崐崘嵆𡺤岺巗苼㠭𤤁𢁉𢅳芇㠶㯂帮檊幵幺𤒼𠳓厦亷廐厨𡝱帉廴𨒂"],
        ["fc40", "廹廻㢠廼栾鐛弍𠇁弢㫞䢮𡌺强𦢈𢏐彘𢑱彣鞽𦹮彲鍀𨨶徧嶶㵟𥉐𡽪𧃸𢙨釖𠊞𨨩怱暅𡡷㥣㷇㘹垐𢞴祱㹀悞悤悳𤦂𤦏𧩓璤僡媠慤萤慂慈𦻒憁凴𠙖憇宪𣾷"],
        ["fca1", "𢡟懓𨮝𩥝懐㤲𢦀𢣁怣慜攞掋𠄘担𡝰拕𢸍捬𤧟㨗搸揸𡎎𡟼撐澊𢸶頔𤂌𥜝擡擥鑻㩦携㩗敍漖𤨨𤨣斅敭敟𣁾斵𤥀䬷旑䃘𡠩无旣忟𣐀昘𣇷𣇸晄𣆤𣆥晋𠹵晧𥇦晳晴𡸽𣈱𨗴𣇈𥌓矅𢣷馤朂𤎜𤨡㬫槺𣟂杞杧杢𤇍𩃭柗䓩栢湐鈼栁𣏦𦶠桝"],
        ["fd40", "𣑯槡樋𨫟楳棃𣗍椁椀㴲㨁𣘼㮀枬楡𨩊䋼椶榘㮡𠏉荣傐槹𣙙𢄪橅𣜃檝㯳枱櫈𩆜㰍欝𠤣惞欵歴𢟍溵𣫛𠎵𡥘㝀吡𣭚毡𣻼毜氷𢒋𤣱𦭑汚舦汹𣶼䓅𣶽𤆤𤤌𤤀"],
        ["fda1", "𣳉㛥㳫𠴲鮃𣇹𢒑羏样𦴥𦶡𦷫涖浜湼漄𤥿𤂅𦹲蔳𦽴凇沜渝萮𨬡港𣸯瑓𣾂秌湏媑𣁋濸㜍澝𣸰滺𡒗𤀽䕕鏰潄潜㵎潴𩅰㴻澟𤅄濓𤂑𤅕𤀹𣿰𣾴𤄿凟𤅖𤅗𤅀𦇝灋灾炧炁烌烕烖烟䄄㷨熴熖𤉷焫煅媈煊煮岜𤍥煏鍢𤋁焬𤑚𤨧𤨢熺𨯨炽爎"],
        ["fe40", "鑂爕夑鑃爤鍁𥘅爮牀𤥴梽牕牗㹕𣁄栍漽犂猪猫𤠣𨠫䣭𨠄猨献珏玪𠰺𦨮珉瑉𤇢𡛧𤨤昣㛅𤦷𤦍𤧻珷琕椃𤨦琹𠗃㻗瑜𢢭瑠𨺲瑇珤瑶莹瑬㜰瑴鏱樬璂䥓𤪌"],
        ["fea1", "𤅟𤩹𨮏孆𨰃𡢞瓈𡦈甎瓩甞𨻙𡩋寗𨺬鎅畍畊畧畮𤾂㼄𤴓疎瑝疞疴瘂瘬癑癏癯癶𦏵皐臯㟸𦤑𦤎皡皥皷盌𦾟葢𥂝𥅽𡸜眞眦着撯𥈠睘𣊬瞯𨥤𨥨𡛁矴砉𡍶𤨒棊碯磇磓隥礮𥗠磗礴碱𧘌辸袄𨬫𦂃𢘜禆褀椂禀𥡗禝𧬹礼禩渪𧄦㺨秆𩄍秔"]
    ];
    module.exports = json;
},
/* iconv-lite/lib/streams.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require("buffer").Buffer, Transform = require("stream").Transform;
    // == Exports ==================================================================
    module.exports = function (iconv) {
        // Additional Public API.
        iconv.encodeStream = function encodeStream(encoding, options) {
            return new IconvLiteEncoderStream(iconv.getEncoder(encoding, options), options);
        };
        iconv.decodeStream = function decodeStream(encoding, options) {
            return new IconvLiteDecoderStream(iconv.getDecoder(encoding, options), options);
        };
        iconv.supportsStreams = true;
        // Not published yet.
        iconv.IconvLiteEncoderStream = IconvLiteEncoderStream;
        iconv.IconvLiteDecoderStream = IconvLiteDecoderStream;
        iconv._collect = IconvLiteDecoderStream.prototype.collect;
    };
    // == Encoder stream =======================================================
    function IconvLiteEncoderStream(conv, options) {
        this.conv = conv;
        options = options || {};
        options.decodeStrings = false; // We accept only strings, so we don't need to decode them.
        Transform.call(this, options);
    }
    IconvLiteEncoderStream.prototype = Object.create(Transform.prototype, {
        constructor: { value: IconvLiteEncoderStream }
    });
    IconvLiteEncoderStream.prototype._transform = function (chunk, encoding, done) {
        if (typeof chunk != 'string')
            return done(new Error("Iconv encoding stream needs strings as its input."));
        try {
            var res = this.conv.write(chunk);
            if (res && res.length)
                this.push(res);
            done();
        }
        catch (e) {
            done(e);
        }
    };
    IconvLiteEncoderStream.prototype._flush = function (done) {
        try {
            var res = this.conv.end();
            if (res && res.length)
                this.push(res);
            done();
        }
        catch (e) {
            done(e);
        }
    };
    IconvLiteEncoderStream.prototype.collect = function (cb) {
        var chunks = [];
        this.on('error', cb);
        this.on('data', function (chunk) { chunks.push(chunk); });
        this.on('end', function () {
            cb(null, Buffer.concat(chunks));
        });
        return this;
    };
    // == Decoder stream =======================================================
    function IconvLiteDecoderStream(conv, options) {
        this.conv = conv;
        options = options || {};
        options.encoding = this.encoding = 'utf8'; // We output strings.
        Transform.call(this, options);
    }
    IconvLiteDecoderStream.prototype = Object.create(Transform.prototype, {
        constructor: { value: IconvLiteDecoderStream }
    });
    IconvLiteDecoderStream.prototype._transform = function (chunk, encoding, done) {
        if (!Buffer.isBuffer(chunk))
            return done(new Error("Iconv decoding stream needs buffers as its input."));
        try {
            var res = this.conv.write(chunk);
            if (res && res.length)
                this.push(res, this.encoding);
            done();
        }
        catch (e) {
            done(e);
        }
    };
    IconvLiteDecoderStream.prototype._flush = function (done) {
        try {
            var res = this.conv.end();
            if (res && res.length)
                this.push(res, this.encoding);
            done();
        }
        catch (e) {
            done(e);
        }
    };
    IconvLiteDecoderStream.prototype.collect = function (cb) {
        var res = '';
        this.on('error', cb);
        this.on('data', function (chunk) { res += chunk; });
        this.on('end', function () {
            cb(null, res);
        });
        return this;
    };
},
/* iconv-lite/lib/extend-node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require("buffer").Buffer;
    // Note: not polyfilled with safer-buffer on a purpose, as overrides Buffer
    // == Extend Node primitives to use iconv-lite =================================
    module.exports = function (iconv) {
        var original = undefined; // Place to keep original methods.
        // Node authors rewrote Buffer internals to make it compatible with
        // Uint8Array and we cannot patch key functions since then.
        // Note: this does use older Buffer API on a purpose
        iconv.supportsNodeEncodingsExtension = !(Buffer.from || new Buffer(0) instanceof Uint8Array);
        iconv.extendNodeEncodings = function extendNodeEncodings() {
            if (original)
                return;
            original = {};
            if (!iconv.supportsNodeEncodingsExtension) {
                console.error("ACTION NEEDED: require('iconv-lite').extendNodeEncodings() is not supported in your version of Node");
                console.error("See more info at https://github.com/ashtuchkin/iconv-lite/wiki/Node-v4-compatibility");
                return;
            }
            var nodeNativeEncodings = {
                'hex': true, 'utf8': true, 'utf-8': true, 'ascii': true, 'binary': true,
                'base64': true, 'ucs2': true, 'ucs-2': true, 'utf16le': true, 'utf-16le': true,
            };
            Buffer.isNativeEncoding = function (enc) {
                return enc && nodeNativeEncodings[enc.toLowerCase()];
            };
            // -- SlowBuffer -----------------------------------------------------------
            var SlowBuffer = require('buffer').SlowBuffer;
            original.SlowBufferToString = SlowBuffer.prototype.toString;
            SlowBuffer.prototype.toString = function (encoding, start, end) {
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.SlowBufferToString.call(this, encoding, start, end);
                // Otherwise, use our decoding method.
                if (typeof start == 'undefined')
                    start = 0;
                if (typeof end == 'undefined')
                    end = this.length;
                return iconv.decode(this.slice(start, end), encoding);
            };
            original.SlowBufferWrite = SlowBuffer.prototype.write;
            SlowBuffer.prototype.write = function (string, offset, length, encoding) {
                // Support both (string, offset, length, encoding)
                // and the legacy (string, encoding, offset, length)
                if (isFinite(offset)) {
                    if (!isFinite(length)) {
                        encoding = length;
                        length = undefined;
                    }
                }
                else { // legacy
                    var swap = encoding;
                    encoding = offset;
                    offset = length;
                    length = swap;
                }
                offset = +offset || 0;
                var remaining = this.length - offset;
                if (!length) {
                    length = remaining;
                }
                else {
                    length = +length;
                    if (length > remaining) {
                        length = remaining;
                    }
                }
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.SlowBufferWrite.call(this, string, offset, length, encoding);
                if (string.length > 0 && (length < 0 || offset < 0))
                    throw new RangeError('attempt to write beyond buffer bounds');
                // Otherwise, use our encoding method.
                var buf = iconv.encode(string, encoding);
                if (buf.length < length)
                    length = buf.length;
                buf.copy(this, offset, 0, length);
                return length;
            };
            // -- Buffer ---------------------------------------------------------------
            original.BufferIsEncoding = Buffer.isEncoding;
            Buffer.isEncoding = function (encoding) {
                return Buffer.isNativeEncoding(encoding) || iconv.encodingExists(encoding);
            };
            original.BufferByteLength = Buffer.byteLength;
            Buffer.byteLength = SlowBuffer.byteLength = function (str, encoding) {
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.BufferByteLength.call(this, str, encoding);
                // Slow, I know, but we don't have a better way yet.
                return iconv.encode(str, encoding).length;
            };
            original.BufferToString = Buffer.prototype.toString;
            Buffer.prototype.toString = function (encoding, start, end) {
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.BufferToString.call(this, encoding, start, end);
                // Otherwise, use our decoding method.
                if (typeof start == 'undefined')
                    start = 0;
                if (typeof end == 'undefined')
                    end = this.length;
                return iconv.decode(this.slice(start, end), encoding);
            };
            original.BufferWrite = Buffer.prototype.write;
            Buffer.prototype.write = function (string, offset, length, encoding) {
                var _offset = offset, _length = length, _encoding = encoding;
                // Support both (string, offset, length, encoding)
                // and the legacy (string, encoding, offset, length)
                if (isFinite(offset)) {
                    if (!isFinite(length)) {
                        encoding = length;
                        length = undefined;
                    }
                }
                else { // legacy
                    var swap = encoding;
                    encoding = offset;
                    offset = length;
                    length = swap;
                }
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.BufferWrite.call(this, string, _offset, _length, _encoding);
                offset = +offset || 0;
                var remaining = this.length - offset;
                if (!length) {
                    length = remaining;
                }
                else {
                    length = +length;
                    if (length > remaining) {
                        length = remaining;
                    }
                }
                if (string.length > 0 && (length < 0 || offset < 0))
                    throw new RangeError('attempt to write beyond buffer bounds');
                // Otherwise, use our encoding method.
                var buf = iconv.encode(string, encoding);
                if (buf.length < length)
                    length = buf.length;
                buf.copy(this, offset, 0, length);
                return length;
                // TODO: Set _charsWritten.
            };
            // -- Readable -------------------------------------------------------------
            if (iconv.supportsStreams) {
                var Readable = require('stream').Readable;
                original.ReadableSetEncoding = Readable.prototype.setEncoding;
                Readable.prototype.setEncoding = function setEncoding(enc, options) {
                    // Use our own decoder, it has the same interface.
                    // We cannot use original function as it doesn't handle BOM-s.
                    this._readableState.decoder = iconv.getDecoder(enc, options);
                    this._readableState.encoding = enc;
                };
                Readable.prototype.collect = iconv._collect;
            }
        };
        // Remove iconv-lite Node primitive extensions.
        iconv.undoExtendNodeEncodings = function undoExtendNodeEncodings() {
            if (!iconv.supportsNodeEncodingsExtension)
                return;
            if (!original)
                throw new Error("require('iconv-lite').undoExtendNodeEncodings(): Nothing to undo; extendNodeEncodings() is not called.");
            delete Buffer.isNativeEncoding;
            var SlowBuffer = require('buffer').SlowBuffer;
            SlowBuffer.prototype.toString = original.SlowBufferToString;
            SlowBuffer.prototype.write = original.SlowBufferWrite;
            Buffer.isEncoding = original.BufferIsEncoding;
            Buffer.byteLength = original.BufferByteLength;
            Buffer.prototype.toString = original.BufferToString;
            Buffer.prototype.write = original.BufferWrite;
            if (iconv.supportsStreams) {
                var Readable = require('stream').Readable;
                Readable.prototype.setEncoding = original.ReadableSetEncoding;
                delete Readable.prototype.collect;
            }
            original = undefined;
        };
    };
},
/* needle/lib/utils.js */ function _(require, module, exports, __esModule, __esExport) {
    var fs = require('fs'), url = require('url'), stream = require('stream');
    function resolve_url(href, base) {
        if (url.URL)
            return new url.URL(href, base);
        // older Node version (< v6.13)
        return base ? url.resolve(base, href) : href;
    }
    function host_and_ports_match(url1, url2) {
        if (url1.indexOf('http') < 0)
            url1 = 'http://' + url1;
        if (url2.indexOf('http') < 0)
            url2 = 'http://' + url2;
        var a = url.parse(url1), b = url.parse(url2);
        return a.host == b.host
            && String(a.port || (a.protocol == 'https:' ? 443 : 80))
                == String(b.port || (b.protocol == 'https:' ? 443 : 80));
    }
    // returns false if a no_proxy host or pattern matches given url
    function should_proxy_to(uri) {
        var no_proxy = get_env_var(['NO_PROXY'], true);
        if (!no_proxy)
            return true;
        // previous (naive, simple) strategy
        // var host, hosts = no_proxy.split(',');
        // for (var i in hosts) {
        //   host = hosts[i];
        //   if (host_and_ports_match(host, uri)) {
        //     return false;
        //   }
        // }
        var pattern, pattern_list = no_proxy.split(/[\s,]+/);
        for (var i in pattern_list) {
            pattern = pattern_list[i];
            if (pattern.trim().length == 0)
                continue;
            // replace leading dot by asterisk, escape dots and finally replace asterisk by .*
            var regex = new RegExp(pattern.replace(/^\./, "*").replace(/[.]/g, '\\$&').replace(/\*/g, '.*'));
            if (uri.match(regex))
                return false;
        }
        return true;
    }
    function get_env_var(keys, try_lower) {
        var val, i = -1, env = process.env;
        while (!val && i < keys.length - 1) {
            val = env[keys[++i]];
            if (!val && try_lower) {
                val = env[keys[i].toLowerCase()];
            }
        }
        return val;
    }
    function parse_content_type(header) {
        if (!header || header === '')
            return {};
        var found, charset = 'utf8', arr = header.split(';');
        if (arr.length > 1 && (found = arr[1].match(/charset=(.+)/)))
            charset = found[1];
        return { type: arr[0], charset: charset };
    }
    function is_stream(obj) {
        return typeof obj.pipe === 'function';
    }
    function get_stream_length(stream, given_length, cb) {
        if (given_length > 0)
            return cb(given_length);
        if (stream.end !== void 0 && stream.end !== Infinity && stream.start !== void 0)
            return cb((stream.end + 1) - (stream.start || 0));
        fs.stat(stream.path, function (err, stat) {
            cb(stat ? stat.size - (stream.start || 0) : null);
        });
    }
    function pump_streams(streams, cb) {
        if (stream.pipeline)
            return stream.pipeline.apply(null, streams.concat(cb));
        var tmp = streams.shift();
        while (streams.length) {
            tmp = tmp.pipe(streams.shift());
            tmp.once('error', function (e) {
                cb && cb(e);
                cb = null;
            });
        }
    }
    module.exports = {
        resolve_url: resolve_url,
        get_env_var: get_env_var,
        host_and_ports_match: host_and_ports_match,
        should_proxy_to: should_proxy_to,
        parse_content_type: parse_content_type,
        is_stream: is_stream,
        get_stream_length: get_stream_length,
        pump_streams: pump_streams
    };
},
/* needle/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "needle",
        "version": "3.2.0",
        "description": "The leanest and most handsome HTTP client in the Nodelands.",
        "keywords": [
            "http",
            "https",
            "simple",
            "request",
            "client",
            "multipart",
            "upload",
            "proxy",
            "deflate",
            "timeout",
            "charset",
            "iconv",
            "cookie",
            "redirect"
        ],
        "tags": [
            "http",
            "https",
            "simple",
            "request",
            "client",
            "multipart",
            "upload",
            "proxy",
            "deflate",
            "timeout",
            "charset",
            "iconv",
            "cookie",
            "redirect"
        ],
        "author": "Tomás Pollak <tomas@forkhq.com>",
        "repository": {
            "type": "git",
            "url": "https://github.com/tomas/needle.git"
        },
        "dependencies": {
            "debug": "^3.2.6",
            "iconv-lite": "^0.6.3",
            "sax": "^1.2.4"
        },
        "devDependencies": {
            "JSONStream": "^1.3.5",
            "jschardet": "^1.6.0",
            "mocha": "^5.2.0",
            "pump": "^3.0.0",
            "q": "^1.5.1",
            "should": "^13.2.3",
            "sinon": "^2.3.0",
            "xml2js": "^0.4.19"
        },
        "scripts": {
            "test": "mocha test"
        },
        "directories": {
            "lib": "./lib"
        },
        "main": "./lib/needle",
        "bin": {
            "needle": "./bin/needle"
        },
        "license": "MIT",
        "engines": {
            "node": ">= 4.4.x"
        }
    };
    module.exports = json;
},
/* less/lib/less/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var environment_1 = tslib_1.__importDefault(require(109) /* ./environment/environment */);
    var data_1 = tslib_1.__importDefault(require(110) /* ./data */);
    var tree_1 = tslib_1.__importDefault(require(113) /* ./tree */);
    var abstract_file_manager_1 = tslib_1.__importDefault(require(68) /* ./environment/abstract-file-manager */);
    var abstract_plugin_loader_1 = tslib_1.__importDefault(require(161) /* ./environment/abstract-plugin-loader */);
    var visitors_1 = tslib_1.__importDefault(require(162) /* ./visitors */);
    var parser_1 = tslib_1.__importDefault(require(170) /* ./parser/parser */);
    var functions_1 = tslib_1.__importDefault(require(173) /* ./functions */);
    var contexts_1 = tslib_1.__importDefault(require(133) /* ./contexts */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ./less-error */);
    var transform_tree_1 = tslib_1.__importDefault(require(185) /* ./transform-tree */);
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    var plugin_manager_1 = tslib_1.__importDefault(require(186) /* ./plugin-manager */);
    var logger_1 = tslib_1.__importDefault(require(70) /* ./logger */);
    var source_map_output_1 = tslib_1.__importDefault(require(187) /* ./source-map-output */);
    var source_map_builder_1 = tslib_1.__importDefault(require(188) /* ./source-map-builder */);
    var parse_tree_1 = tslib_1.__importDefault(require(189) /* ./parse-tree */);
    var import_manager_1 = tslib_1.__importDefault(require(190) /* ./import-manager */);
    var parse_1 = tslib_1.__importDefault(require(191) /* ./parse */);
    var render_1 = tslib_1.__importDefault(require(192) /* ./render */);
    var package_json_1 = require(193) /* ../../package.json */;
    var parse_node_version_1 = tslib_1.__importDefault(require(194) /* parse-node-version */);
    function default_1(environment, fileManagers) {
        var sourceMapOutput, sourceMapBuilder, parseTree, importManager;
        environment = new environment_1.default(environment, fileManagers);
        sourceMapOutput = source_map_output_1.default(environment);
        sourceMapBuilder = source_map_builder_1.default(sourceMapOutput, environment);
        parseTree = parse_tree_1.default(sourceMapBuilder);
        importManager = import_manager_1.default(environment);
        var render = render_1.default(environment, parseTree, importManager);
        var parse = parse_1.default(environment, parseTree, importManager);
        var v = parse_node_version_1.default("v" + package_json_1.version);
        var initial = {
            version: [v.major, v.minor, v.patch],
            data: data_1.default,
            tree: tree_1.default,
            Environment: environment_1.default,
            AbstractFileManager: abstract_file_manager_1.default,
            AbstractPluginLoader: abstract_plugin_loader_1.default,
            environment: environment,
            visitors: visitors_1.default,
            Parser: parser_1.default,
            functions: functions_1.default(environment),
            contexts: contexts_1.default,
            SourceMapOutput: sourceMapOutput,
            SourceMapBuilder: sourceMapBuilder,
            ParseTree: parseTree,
            ImportManager: importManager,
            render: render,
            parse: parse,
            LessError: less_error_1.default,
            transformTree: transform_tree_1.default,
            utils: utils,
            PluginManager: plugin_manager_1.default,
            logger: logger_1.default
        };
        // Create a public API
        var ctor = function (t) {
            return function () {
                var obj = Object.create(t.prototype);
                t.apply(obj, Array.prototype.slice.call(arguments, 0));
                return obj;
            };
        };
        var t;
        var api = Object.create(initial);
        for (var n in initial.tree) {
            /* eslint guard-for-in: 0 */
            t = initial.tree[n];
            if (typeof t === 'function') {
                api[n.toLowerCase()] = ctor(t);
            }
            else {
                api[n] = Object.create(null);
                for (var o in t) {
                    /* eslint guard-for-in: 0 */
                    api[n][o.toLowerCase()] = ctor(t[o]);
                }
            }
        }
        /**
         * Some of the functions assume a `this` context of the API object,
         * which causes it to fail when wrapped for ES6 imports.
         *
         * An assumed `this` should be removed in the future.
         */
        initial.parse = initial.parse.bind(api);
        initial.render = initial.render.bind(api);
        return api;
    }
    exports.default = default_1;
    ;
    
},
/* less/lib/less/environment/environment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /**
     * @todo Document why this abstraction exists, and the relationship between
     *       environment, file managers, and plugin manager
     */
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var logger_1 = tslib_1.__importDefault(require(70) /* ../logger */);
    var Environment = /** @class */ (function () {
        function Environment(externalEnvironment, fileManagers) {
            this.fileManagers = fileManagers || [];
            externalEnvironment = externalEnvironment || {};
            var optionalFunctions = ['encodeBase64', 'mimeLookup', 'charsetLookup', 'getSourceMapGenerator'];
            var requiredFunctions = [];
            var functions = requiredFunctions.concat(optionalFunctions);
            for (var i = 0; i < functions.length; i++) {
                var propName = functions[i];
                var environmentFunc = externalEnvironment[propName];
                if (environmentFunc) {
                    this[propName] = environmentFunc.bind(externalEnvironment);
                }
                else if (i < requiredFunctions.length) {
                    this.warn("missing required function in environment - " + propName);
                }
            }
        }
        Environment.prototype.getFileManager = function (filename, currentDirectory, options, environment, isSync) {
            if (!filename) {
                logger_1.default.warn('getFileManager called with no filename.. Please report this issue. continuing.');
            }
            if (currentDirectory == null) {
                logger_1.default.warn('getFileManager called with null directory.. Please report this issue. continuing.');
            }
            var fileManagers = this.fileManagers;
            if (options.pluginManager) {
                fileManagers = [].concat(fileManagers).concat(options.pluginManager.getFileManagers());
            }
            for (var i = fileManagers.length - 1; i >= 0; i--) {
                var fileManager = fileManagers[i];
                if (fileManager[isSync ? 'supportsSync' : 'supports'](filename, currentDirectory, options, environment)) {
                    return fileManager;
                }
            }
            return null;
        };
        Environment.prototype.addFileManager = function (fileManager) {
            this.fileManagers.push(fileManager);
        };
        Environment.prototype.clearFileManagers = function () {
            this.fileManagers = [];
        };
        return Environment;
    }());
    exports.default = Environment;
    
},
/* less/lib/less/data/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var colors_1 = tslib_1.__importDefault(require(111) /* ./colors */);
    var unit_conversions_1 = tslib_1.__importDefault(require(112) /* ./unit-conversions */);
    exports.default = { colors: colors_1.default, unitConversions: unit_conversions_1.default };
    
},
/* less/lib/less/data/colors.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = {
        'aliceblue': '#f0f8ff',
        'antiquewhite': '#faebd7',
        'aqua': '#00ffff',
        'aquamarine': '#7fffd4',
        'azure': '#f0ffff',
        'beige': '#f5f5dc',
        'bisque': '#ffe4c4',
        'black': '#000000',
        'blanchedalmond': '#ffebcd',
        'blue': '#0000ff',
        'blueviolet': '#8a2be2',
        'brown': '#a52a2a',
        'burlywood': '#deb887',
        'cadetblue': '#5f9ea0',
        'chartreuse': '#7fff00',
        'chocolate': '#d2691e',
        'coral': '#ff7f50',
        'cornflowerblue': '#6495ed',
        'cornsilk': '#fff8dc',
        'crimson': '#dc143c',
        'cyan': '#00ffff',
        'darkblue': '#00008b',
        'darkcyan': '#008b8b',
        'darkgoldenrod': '#b8860b',
        'darkgray': '#a9a9a9',
        'darkgrey': '#a9a9a9',
        'darkgreen': '#006400',
        'darkkhaki': '#bdb76b',
        'darkmagenta': '#8b008b',
        'darkolivegreen': '#556b2f',
        'darkorange': '#ff8c00',
        'darkorchid': '#9932cc',
        'darkred': '#8b0000',
        'darksalmon': '#e9967a',
        'darkseagreen': '#8fbc8f',
        'darkslateblue': '#483d8b',
        'darkslategray': '#2f4f4f',
        'darkslategrey': '#2f4f4f',
        'darkturquoise': '#00ced1',
        'darkviolet': '#9400d3',
        'deeppink': '#ff1493',
        'deepskyblue': '#00bfff',
        'dimgray': '#696969',
        'dimgrey': '#696969',
        'dodgerblue': '#1e90ff',
        'firebrick': '#b22222',
        'floralwhite': '#fffaf0',
        'forestgreen': '#228b22',
        'fuchsia': '#ff00ff',
        'gainsboro': '#dcdcdc',
        'ghostwhite': '#f8f8ff',
        'gold': '#ffd700',
        'goldenrod': '#daa520',
        'gray': '#808080',
        'grey': '#808080',
        'green': '#008000',
        'greenyellow': '#adff2f',
        'honeydew': '#f0fff0',
        'hotpink': '#ff69b4',
        'indianred': '#cd5c5c',
        'indigo': '#4b0082',
        'ivory': '#fffff0',
        'khaki': '#f0e68c',
        'lavender': '#e6e6fa',
        'lavenderblush': '#fff0f5',
        'lawngreen': '#7cfc00',
        'lemonchiffon': '#fffacd',
        'lightblue': '#add8e6',
        'lightcoral': '#f08080',
        'lightcyan': '#e0ffff',
        'lightgoldenrodyellow': '#fafad2',
        'lightgray': '#d3d3d3',
        'lightgrey': '#d3d3d3',
        'lightgreen': '#90ee90',
        'lightpink': '#ffb6c1',
        'lightsalmon': '#ffa07a',
        'lightseagreen': '#20b2aa',
        'lightskyblue': '#87cefa',
        'lightslategray': '#778899',
        'lightslategrey': '#778899',
        'lightsteelblue': '#b0c4de',
        'lightyellow': '#ffffe0',
        'lime': '#00ff00',
        'limegreen': '#32cd32',
        'linen': '#faf0e6',
        'magenta': '#ff00ff',
        'maroon': '#800000',
        'mediumaquamarine': '#66cdaa',
        'mediumblue': '#0000cd',
        'mediumorchid': '#ba55d3',
        'mediumpurple': '#9370d8',
        'mediumseagreen': '#3cb371',
        'mediumslateblue': '#7b68ee',
        'mediumspringgreen': '#00fa9a',
        'mediumturquoise': '#48d1cc',
        'mediumvioletred': '#c71585',
        'midnightblue': '#191970',
        'mintcream': '#f5fffa',
        'mistyrose': '#ffe4e1',
        'moccasin': '#ffe4b5',
        'navajowhite': '#ffdead',
        'navy': '#000080',
        'oldlace': '#fdf5e6',
        'olive': '#808000',
        'olivedrab': '#6b8e23',
        'orange': '#ffa500',
        'orangered': '#ff4500',
        'orchid': '#da70d6',
        'palegoldenrod': '#eee8aa',
        'palegreen': '#98fb98',
        'paleturquoise': '#afeeee',
        'palevioletred': '#d87093',
        'papayawhip': '#ffefd5',
        'peachpuff': '#ffdab9',
        'peru': '#cd853f',
        'pink': '#ffc0cb',
        'plum': '#dda0dd',
        'powderblue': '#b0e0e6',
        'purple': '#800080',
        'rebeccapurple': '#663399',
        'red': '#ff0000',
        'rosybrown': '#bc8f8f',
        'royalblue': '#4169e1',
        'saddlebrown': '#8b4513',
        'salmon': '#fa8072',
        'sandybrown': '#f4a460',
        'seagreen': '#2e8b57',
        'seashell': '#fff5ee',
        'sienna': '#a0522d',
        'silver': '#c0c0c0',
        'skyblue': '#87ceeb',
        'slateblue': '#6a5acd',
        'slategray': '#708090',
        'slategrey': '#708090',
        'snow': '#fffafa',
        'springgreen': '#00ff7f',
        'steelblue': '#4682b4',
        'tan': '#d2b48c',
        'teal': '#008080',
        'thistle': '#d8bfd8',
        'tomato': '#ff6347',
        'turquoise': '#40e0d0',
        'violet': '#ee82ee',
        'wheat': '#f5deb3',
        'white': '#ffffff',
        'whitesmoke': '#f5f5f5',
        'yellow': '#ffff00',
        'yellowgreen': '#9acd32'
    };
    
},
/* less/lib/less/data/unit-conversions.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = {
        length: {
            'm': 1,
            'cm': 0.01,
            'mm': 0.001,
            'in': 0.0254,
            'px': 0.0254 / 96,
            'pt': 0.0254 / 72,
            'pc': 0.0254 / 72 * 12
        },
        duration: {
            's': 1,
            'ms': 0.001
        },
        angle: {
            'rad': 1 / (2 * Math.PI),
            'deg': 1 / 360,
            'grad': 1 / 400,
            'turn': 1
        }
    };
    
},
/* less/lib/less/tree/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var color_1 = tslib_1.__importDefault(require(115) /* ./color */);
    var atrule_1 = tslib_1.__importDefault(require(116) /* ./atrule */);
    var detached_ruleset_1 = tslib_1.__importDefault(require(136) /* ./detached-ruleset */);
    var operation_1 = tslib_1.__importDefault(require(137) /* ./operation */);
    var dimension_1 = tslib_1.__importDefault(require(138) /* ./dimension */);
    var unit_1 = tslib_1.__importDefault(require(139) /* ./unit */);
    var keyword_1 = tslib_1.__importDefault(require(129) /* ./keyword */);
    var variable_1 = tslib_1.__importDefault(require(140) /* ./variable */);
    var property_1 = tslib_1.__importDefault(require(144) /* ./property */);
    var ruleset_1 = tslib_1.__importDefault(require(126) /* ./ruleset */);
    var element_1 = tslib_1.__importDefault(require(118) /* ./element */);
    var attribute_1 = tslib_1.__importDefault(require(145) /* ./attribute */);
    var combinator_1 = tslib_1.__importDefault(require(120) /* ./combinator */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var quoted_1 = tslib_1.__importDefault(require(146) /* ./quoted */);
    var expression_1 = tslib_1.__importDefault(require(143) /* ./expression */);
    var declaration_1 = tslib_1.__importDefault(require(127) /* ./declaration */);
    var call_1 = tslib_1.__importDefault(require(141) /* ./call */);
    var url_1 = tslib_1.__importDefault(require(147) /* ./url */);
    var import_1 = tslib_1.__importDefault(require(148) /* ./import */);
    var comment_1 = tslib_1.__importDefault(require(131) /* ./comment */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ./anonymous */);
    var value_1 = tslib_1.__importDefault(require(128) /* ./value */);
    var javascript_1 = tslib_1.__importDefault(require(150) /* ./javascript */);
    var assignment_1 = tslib_1.__importDefault(require(152) /* ./assignment */);
    var condition_1 = tslib_1.__importDefault(require(153) /* ./condition */);
    var paren_1 = tslib_1.__importDefault(require(119) /* ./paren */);
    var media_1 = tslib_1.__importDefault(require(149) /* ./media */);
    var unicode_descriptor_1 = tslib_1.__importDefault(require(154) /* ./unicode-descriptor */);
    var negative_1 = tslib_1.__importDefault(require(155) /* ./negative */);
    var extend_1 = tslib_1.__importDefault(require(156) /* ./extend */);
    var variable_call_1 = tslib_1.__importDefault(require(157) /* ./variable-call */);
    var namespace_value_1 = tslib_1.__importDefault(require(158) /* ./namespace-value */);
    // mixins
    var mixin_call_1 = tslib_1.__importDefault(require(159) /* ./mixin-call */);
    var mixin_definition_1 = tslib_1.__importDefault(require(160) /* ./mixin-definition */);
    exports.default = {
        Node: node_1.default,
        Color: color_1.default,
        AtRule: atrule_1.default,
        DetachedRuleset: detached_ruleset_1.default,
        Operation: operation_1.default,
        Dimension: dimension_1.default,
        Unit: unit_1.default,
        Keyword: keyword_1.default,
        Variable: variable_1.default,
        Property: property_1.default,
        Ruleset: ruleset_1.default,
        Element: element_1.default,
        Attribute: attribute_1.default,
        Combinator: combinator_1.default,
        Selector: selector_1.default,
        Quoted: quoted_1.default,
        Expression: expression_1.default,
        Declaration: declaration_1.default,
        Call: call_1.default,
        URL: url_1.default,
        Import: import_1.default,
        Comment: comment_1.default,
        Anonymous: anonymous_1.default,
        Value: value_1.default,
        JavaScript: javascript_1.default,
        Assignment: assignment_1.default,
        Condition: condition_1.default,
        Paren: paren_1.default,
        Media: media_1.default,
        UnicodeDescriptor: unicode_descriptor_1.default,
        Negative: negative_1.default,
        Extend: extend_1.default,
        VariableCall: variable_call_1.default,
        NamespaceValue: namespace_value_1.default,
        mixin: {
            Call: mixin_call_1.default,
            Definition: mixin_definition_1.default
        }
    };
    
},
/* less/lib/less/tree/node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * The reason why Node is a class and other nodes simply do not extend
     * from Node (since we're transpiling) is due to this issue:
     *
     * https://github.com/less/less.js/issues/3434
     */
    var Node = /** @class */ (function () {
        function Node() {
            this.parent = null;
            this.visibilityBlocks = undefined;
            this.nodeVisible = undefined;
            this.rootNode = null;
            this.parsed = null;
        }
        Object.defineProperty(Node.prototype, "currentFileInfo", {
            get: function () {
                return this.fileInfo();
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Node.prototype, "index", {
            get: function () {
                return this.getIndex();
            },
            enumerable: false,
            configurable: true
        });
        Node.prototype.setParent = function (nodes, parent) {
            function set(node) {
                if (node && node instanceof Node) {
                    node.parent = parent;
                }
            }
            if (Array.isArray(nodes)) {
                nodes.forEach(set);
            }
            else {
                set(nodes);
            }
        };
        Node.prototype.getIndex = function () {
            return this._index || (this.parent && this.parent.getIndex()) || 0;
        };
        Node.prototype.fileInfo = function () {
            return this._fileInfo || (this.parent && this.parent.fileInfo()) || {};
        };
        Node.prototype.isRulesetLike = function () { return false; };
        Node.prototype.toCSS = function (context) {
            var strs = [];
            this.genCSS(context, {
                add: function (chunk, fileInfo, index) {
                    strs.push(chunk);
                },
                isEmpty: function () {
                    return strs.length === 0;
                }
            });
            return strs.join('');
        };
        Node.prototype.genCSS = function (context, output) {
            output.add(this.value);
        };
        Node.prototype.accept = function (visitor) {
            this.value = visitor.visit(this.value);
        };
        Node.prototype.eval = function () { return this; };
        Node.prototype._operate = function (context, op, a, b) {
            switch (op) {
                case '+': return a + b;
                case '-': return a - b;
                case '*': return a * b;
                case '/': return a / b;
            }
        };
        Node.prototype.fround = function (context, value) {
            var precision = context && context.numPrecision;
            // add "epsilon" to ensure numbers like 1.000000005 (represented as 1.000000004999...) are properly rounded:
            return (precision) ? Number((value + 2e-16).toFixed(precision)) : value;
        };
        Node.compare = function (a, b) {
            /* returns:
             -1: a < b
             0: a = b
             1: a > b
             and *any* other value for a != b (e.g. undefined, NaN, -2 etc.) */
            if ((a.compare) &&
                // for "symmetric results" force toCSS-based comparison
                // of Quoted or Anonymous if either value is one of those
                !(b.type === 'Quoted' || b.type === 'Anonymous')) {
                return a.compare(b);
            }
            else if (b.compare) {
                return -b.compare(a);
            }
            else if (a.type !== b.type) {
                return undefined;
            }
            a = a.value;
            b = b.value;
            if (!Array.isArray(a)) {
                return a === b ? 0 : undefined;
            }
            if (a.length !== b.length) {
                return undefined;
            }
            for (var i = 0; i < a.length; i++) {
                if (Node.compare(a[i], b[i]) !== 0) {
                    return undefined;
                }
            }
            return 0;
        };
        Node.numericCompare = function (a, b) {
            return a < b ? -1
                : a === b ? 0
                    : a > b ? 1 : undefined;
        };
        // Returns true if this node represents root of ast imported by reference
        Node.prototype.blocksVisibility = function () {
            if (this.visibilityBlocks == null) {
                this.visibilityBlocks = 0;
            }
            return this.visibilityBlocks !== 0;
        };
        Node.prototype.addVisibilityBlock = function () {
            if (this.visibilityBlocks == null) {
                this.visibilityBlocks = 0;
            }
            this.visibilityBlocks = this.visibilityBlocks + 1;
        };
        Node.prototype.removeVisibilityBlock = function () {
            if (this.visibilityBlocks == null) {
                this.visibilityBlocks = 0;
            }
            this.visibilityBlocks = this.visibilityBlocks - 1;
        };
        // Turns on node visibility - if called node will be shown in output regardless
        // of whether it comes from import by reference or not
        Node.prototype.ensureVisibility = function () {
            this.nodeVisible = true;
        };
        // Turns off node visibility - if called node will NOT be shown in output regardless
        // of whether it comes from import by reference or not
        Node.prototype.ensureInvisibility = function () {
            this.nodeVisible = false;
        };
        // return values:
        // false - the node must not be visible
        // true - the node must be visible
        // undefined or null - the node has the same visibility as its parent
        Node.prototype.isVisible = function () {
            return this.nodeVisible;
        };
        Node.prototype.visibilityInfo = function () {
            return {
                visibilityBlocks: this.visibilityBlocks,
                nodeVisible: this.nodeVisible
            };
        };
        Node.prototype.copyVisibilityInfo = function (info) {
            if (!info) {
                return;
            }
            this.visibilityBlocks = info.visibilityBlocks;
            this.nodeVisible = info.nodeVisible;
        };
        return Node;
    }());
    exports.default = Node;
    
},
/* less/lib/less/tree/color.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var colors_1 = tslib_1.__importDefault(require(111) /* ../data/colors */);
    //
    // RGB Colors - #ff0014, #eee
    //
    var Color = function (rgb, a, originalForm) {
        var self = this;
        //
        // The end goal here, is to parse the arguments
        // into an integer triplet, such as `128, 255, 0`
        //
        // This facilitates operations and conversions.
        //
        if (Array.isArray(rgb)) {
            this.rgb = rgb;
        }
        else if (rgb.length >= 6) {
            this.rgb = [];
            rgb.match(/.{2}/g).map(function (c, i) {
                if (i < 3) {
                    self.rgb.push(parseInt(c, 16));
                }
                else {
                    self.alpha = (parseInt(c, 16)) / 255;
                }
            });
        }
        else {
            this.rgb = [];
            rgb.split('').map(function (c, i) {
                if (i < 3) {
                    self.rgb.push(parseInt(c + c, 16));
                }
                else {
                    self.alpha = (parseInt(c + c, 16)) / 255;
                }
            });
        }
        this.alpha = this.alpha || (typeof a === 'number' ? a : 1);
        if (typeof originalForm !== 'undefined') {
            this.value = originalForm;
        }
    };
    Color.prototype = Object.assign(new node_1.default(), {
        type: 'Color',
        luma: function () {
            var r = this.rgb[0] / 255, g = this.rgb[1] / 255, b = this.rgb[2] / 255;
            r = (r <= 0.03928) ? r / 12.92 : Math.pow(((r + 0.055) / 1.055), 2.4);
            g = (g <= 0.03928) ? g / 12.92 : Math.pow(((g + 0.055) / 1.055), 2.4);
            b = (b <= 0.03928) ? b / 12.92 : Math.pow(((b + 0.055) / 1.055), 2.4);
            return 0.2126 * r + 0.7152 * g + 0.0722 * b;
        },
        genCSS: function (context, output) {
            output.add(this.toCSS(context));
        },
        toCSS: function (context, doNotCompress) {
            var compress = context && context.compress && !doNotCompress;
            var color;
            var alpha;
            var colorFunction;
            var args = [];
            // `value` is set if this color was originally
            // converted from a named color string so we need
            // to respect this and try to output named color too.
            alpha = this.fround(context, this.alpha);
            if (this.value) {
                if (this.value.indexOf('rgb') === 0) {
                    if (alpha < 1) {
                        colorFunction = 'rgba';
                    }
                }
                else if (this.value.indexOf('hsl') === 0) {
                    if (alpha < 1) {
                        colorFunction = 'hsla';
                    }
                    else {
                        colorFunction = 'hsl';
                    }
                }
                else {
                    return this.value;
                }
            }
            else {
                if (alpha < 1) {
                    colorFunction = 'rgba';
                }
            }
            switch (colorFunction) {
                case 'rgba':
                    args = this.rgb.map(function (c) {
                        return clamp(Math.round(c), 255);
                    }).concat(clamp(alpha, 1));
                    break;
                case 'hsla':
                    args.push(clamp(alpha, 1));
                case 'hsl':
                    color = this.toHSL();
                    args = [
                        this.fround(context, color.h),
                        this.fround(context, color.s * 100) + "%",
                        this.fround(context, color.l * 100) + "%"
                    ].concat(args);
            }
            if (colorFunction) {
                // Values are capped between `0` and `255`, rounded and zero-padded.
                return colorFunction + "(" + args.join("," + (compress ? '' : ' ')) + ")";
            }
            color = this.toRGB();
            if (compress) {
                var splitcolor = color.split('');
                // Convert color to short format
                if (splitcolor[1] === splitcolor[2] && splitcolor[3] === splitcolor[4] && splitcolor[5] === splitcolor[6]) {
                    color = "#" + splitcolor[1] + splitcolor[3] + splitcolor[5];
                }
            }
            return color;
        },
        //
        // Operations have to be done per-channel, if not,
        // channels will spill onto each other. Once we have
        // our result, in the form of an integer triplet,
        // we create a new Color node to hold the result.
        //
        operate: function (context, op, other) {
            var rgb = new Array(3);
            var alpha = this.alpha * (1 - other.alpha) + other.alpha;
            for (var c = 0; c < 3; c++) {
                rgb[c] = this._operate(context, op, this.rgb[c], other.rgb[c]);
            }
            return new Color(rgb, alpha);
        },
        toRGB: function () {
            return toHex(this.rgb);
        },
        toHSL: function () {
            var r = this.rgb[0] / 255, g = this.rgb[1] / 255, b = this.rgb[2] / 255, a = this.alpha;
            var max = Math.max(r, g, b), min = Math.min(r, g, b);
            var h;
            var s;
            var l = (max + min) / 2;
            var d = max - min;
            if (max === min) {
                h = s = 0;
            }
            else {
                s = l > 0.5 ? d / (2 - max - min) : d / (max + min);
                switch (max) {
                    case r:
                        h = (g - b) / d + (g < b ? 6 : 0);
                        break;
                    case g:
                        h = (b - r) / d + 2;
                        break;
                    case b:
                        h = (r - g) / d + 4;
                        break;
                }
                h /= 6;
            }
            return { h: h * 360, s: s, l: l, a: a };
        },
        // Adapted from http://mjijackson.com/2008/02/rgb-to-hsl-and-rgb-to-hsv-color-model-conversion-algorithms-in-javascript
        toHSV: function () {
            var r = this.rgb[0] / 255, g = this.rgb[1] / 255, b = this.rgb[2] / 255, a = this.alpha;
            var max = Math.max(r, g, b), min = Math.min(r, g, b);
            var h;
            var s;
            var v = max;
            var d = max - min;
            if (max === 0) {
                s = 0;
            }
            else {
                s = d / max;
            }
            if (max === min) {
                h = 0;
            }
            else {
                switch (max) {
                    case r:
                        h = (g - b) / d + (g < b ? 6 : 0);
                        break;
                    case g:
                        h = (b - r) / d + 2;
                        break;
                    case b:
                        h = (r - g) / d + 4;
                        break;
                }
                h /= 6;
            }
            return { h: h * 360, s: s, v: v, a: a };
        },
        toARGB: function () {
            return toHex([this.alpha * 255].concat(this.rgb));
        },
        compare: function (x) {
            return (x.rgb &&
                x.rgb[0] === this.rgb[0] &&
                x.rgb[1] === this.rgb[1] &&
                x.rgb[2] === this.rgb[2] &&
                x.alpha === this.alpha) ? 0 : undefined;
        }
    });
    Color.fromKeyword = function (keyword) {
        var c;
        var key = keyword.toLowerCase();
        if (colors_1.default.hasOwnProperty(key)) {
            c = new Color(colors_1.default[key].slice(1));
        }
        else if (key === 'transparent') {
            c = new Color([0, 0, 0], 0);
        }
        if (c) {
            c.value = keyword;
            return c;
        }
    };
    function clamp(v, max) {
        return Math.min(Math.max(v, 0), max);
    }
    function toHex(v) {
        return "#" + v.map(function (c) {
            c = clamp(Math.round(c), 255);
            return (c < 16 ? '0' : '') + c.toString(16);
        }).join('');
    }
    exports.default = Color;
    
},
/* less/lib/less/tree/atrule.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var ruleset_1 = tslib_1.__importDefault(require(126) /* ./ruleset */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ./anonymous */);
    var AtRule = function (name, value, rules, index, currentFileInfo, debugInfo, isRooted, visibilityInfo) {
        var i;
        this.name = name;
        this.value = (value instanceof node_1.default) ? value : (value ? new anonymous_1.default(value) : value);
        if (rules) {
            if (Array.isArray(rules)) {
                this.rules = rules;
            }
            else {
                this.rules = [rules];
                this.rules[0].selectors = (new selector_1.default([], null, null, index, currentFileInfo)).createEmptySelectors();
            }
            for (i = 0; i < this.rules.length; i++) {
                this.rules[i].allowImports = true;
            }
            this.setParent(this.rules, this);
        }
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.debugInfo = debugInfo;
        this.isRooted = isRooted || false;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
    };
    AtRule.prototype = Object.assign(new node_1.default(), {
        type: 'AtRule',
        accept: function (visitor) {
            var value = this.value, rules = this.rules;
            if (rules) {
                this.rules = visitor.visitArray(rules);
            }
            if (value) {
                this.value = visitor.visit(value);
            }
        },
        isRulesetLike: function () {
            return this.rules || !this.isCharset();
        },
        isCharset: function () {
            return '@charset' === this.name;
        },
        genCSS: function (context, output) {
            var value = this.value, rules = this.rules;
            output.add(this.name, this.fileInfo(), this.getIndex());
            if (value) {
                output.add(' ');
                value.genCSS(context, output);
            }
            if (rules) {
                this.outputRuleset(context, output, rules);
            }
            else {
                output.add(';');
            }
        },
        eval: function (context) {
            var mediaPathBackup, mediaBlocksBackup, value = this.value, rules = this.rules;
            // media stored inside other atrule should not bubble over it
            // backpup media bubbling information
            mediaPathBackup = context.mediaPath;
            mediaBlocksBackup = context.mediaBlocks;
            // deleted media bubbling information
            context.mediaPath = [];
            context.mediaBlocks = [];
            if (value) {
                value = value.eval(context);
            }
            if (rules) {
                // assuming that there is only one rule at this point - that is how parser constructs the rule
                rules = [rules[0].eval(context)];
                rules[0].root = true;
            }
            // restore media bubbling information
            context.mediaPath = mediaPathBackup;
            context.mediaBlocks = mediaBlocksBackup;
            return new AtRule(this.name, value, rules, this.getIndex(), this.fileInfo(), this.debugInfo, this.isRooted, this.visibilityInfo());
        },
        variable: function (name) {
            if (this.rules) {
                // assuming that there is only one rule at this point - that is how parser constructs the rule
                return ruleset_1.default.prototype.variable.call(this.rules[0], name);
            }
        },
        find: function () {
            if (this.rules) {
                // assuming that there is only one rule at this point - that is how parser constructs the rule
                return ruleset_1.default.prototype.find.apply(this.rules[0], arguments);
            }
        },
        rulesets: function () {
            if (this.rules) {
                // assuming that there is only one rule at this point - that is how parser constructs the rule
                return ruleset_1.default.prototype.rulesets.apply(this.rules[0]);
            }
        },
        outputRuleset: function (context, output, rules) {
            var ruleCnt = rules.length;
            var i;
            context.tabLevel = (context.tabLevel | 0) + 1;
            // Compressed
            if (context.compress) {
                output.add('{');
                for (i = 0; i < ruleCnt; i++) {
                    rules[i].genCSS(context, output);
                }
                output.add('}');
                context.tabLevel--;
                return;
            }
            // Non-compressed
            var tabSetStr = "\n" + Array(context.tabLevel).join('  '), tabRuleStr = tabSetStr + "  ";
            if (!ruleCnt) {
                output.add(" {" + tabSetStr + "}");
            }
            else {
                output.add(" {" + tabRuleStr);
                rules[0].genCSS(context, output);
                for (i = 1; i < ruleCnt; i++) {
                    output.add(tabRuleStr);
                    rules[i].genCSS(context, output);
                }
                output.add(tabSetStr + "}");
            }
            context.tabLevel--;
        }
    });
    exports.default = AtRule;
    
},
/* less/lib/less/tree/selector.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var element_1 = tslib_1.__importDefault(require(118) /* ./element */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    var Selector = function (elements, extendList, condition, index, currentFileInfo, visibilityInfo) {
        this.extendList = extendList;
        this.condition = condition;
        this.evaldCondition = !condition;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.elements = this.getElements(elements);
        this.mixinElements_ = undefined;
        this.copyVisibilityInfo(visibilityInfo);
        this.setParent(this.elements, this);
    };
    Selector.prototype = Object.assign(new node_1.default(), {
        type: 'Selector',
        accept: function (visitor) {
            if (this.elements) {
                this.elements = visitor.visitArray(this.elements);
            }
            if (this.extendList) {
                this.extendList = visitor.visitArray(this.extendList);
            }
            if (this.condition) {
                this.condition = visitor.visit(this.condition);
            }
        },
        createDerived: function (elements, extendList, evaldCondition) {
            elements = this.getElements(elements);
            var newSelector = new Selector(elements, extendList || this.extendList, null, this.getIndex(), this.fileInfo(), this.visibilityInfo());
            newSelector.evaldCondition = (evaldCondition != null) ? evaldCondition : this.evaldCondition;
            newSelector.mediaEmpty = this.mediaEmpty;
            return newSelector;
        },
        getElements: function (els) {
            if (!els) {
                return [new element_1.default('', '&', false, this._index, this._fileInfo)];
            }
            if (typeof els === 'string') {
                this.parse.parseNode(els, ['selector'], this._index, this._fileInfo, function (err, result) {
                    if (err) {
                        throw new less_error_1.default({
                            index: err.index,
                            message: err.message
                        }, this.parse.imports, this._fileInfo.filename);
                    }
                    els = result[0].elements;
                });
            }
            return els;
        },
        createEmptySelectors: function () {
            var el = new element_1.default('', '&', false, this._index, this._fileInfo), sels = [new Selector([el], null, null, this._index, this._fileInfo)];
            sels[0].mediaEmpty = true;
            return sels;
        },
        match: function (other) {
            var elements = this.elements;
            var len = elements.length;
            var olen;
            var i;
            other = other.mixinElements();
            olen = other.length;
            if (olen === 0 || len < olen) {
                return 0;
            }
            else {
                for (i = 0; i < olen; i++) {
                    if (elements[i].value !== other[i]) {
                        return 0;
                    }
                }
            }
            return olen; // return number of matched elements
        },
        mixinElements: function () {
            if (this.mixinElements_) {
                return this.mixinElements_;
            }
            var elements = this.elements.map(function (v) {
                return v.combinator.value + (v.value.value || v.value);
            }).join('').match(/[,&#\*\.\w-]([\w-]|(\\.))*/g);
            if (elements) {
                if (elements[0] === '&') {
                    elements.shift();
                }
            }
            else {
                elements = [];
            }
            return (this.mixinElements_ = elements);
        },
        isJustParentSelector: function () {
            return !this.mediaEmpty &&
                this.elements.length === 1 &&
                this.elements[0].value === '&' &&
                (this.elements[0].combinator.value === ' ' || this.elements[0].combinator.value === '');
        },
        eval: function (context) {
            var evaldCondition = this.condition && this.condition.eval(context);
            var elements = this.elements;
            var extendList = this.extendList;
            elements = elements && elements.map(function (e) { return e.eval(context); });
            extendList = extendList && extendList.map(function (extend) { return extend.eval(context); });
            return this.createDerived(elements, extendList, evaldCondition);
        },
        genCSS: function (context, output) {
            var i, element;
            if ((!context || !context.firstSelector) && this.elements[0].combinator.value === '') {
                output.add(' ', this.fileInfo(), this.getIndex());
            }
            for (i = 0; i < this.elements.length; i++) {
                element = this.elements[i];
                element.genCSS(context, output);
            }
        },
        getIsOutput: function () {
            return this.evaldCondition;
        }
    });
    exports.default = Selector;
    
},
/* less/lib/less/tree/element.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var paren_1 = tslib_1.__importDefault(require(119) /* ./paren */);
    var combinator_1 = tslib_1.__importDefault(require(120) /* ./combinator */);
    var Element = function (combinator, value, isVariable, index, currentFileInfo, visibilityInfo) {
        this.combinator = combinator instanceof combinator_1.default ?
            combinator : new combinator_1.default(combinator);
        if (typeof value === 'string') {
            this.value = value.trim();
        }
        else if (value) {
            this.value = value;
        }
        else {
            this.value = '';
        }
        this.isVariable = isVariable;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.copyVisibilityInfo(visibilityInfo);
        this.setParent(this.combinator, this);
    };
    Element.prototype = Object.assign(new node_1.default(), {
        type: 'Element',
        accept: function (visitor) {
            var value = this.value;
            this.combinator = visitor.visit(this.combinator);
            if (typeof value === 'object') {
                this.value = visitor.visit(value);
            }
        },
        eval: function (context) {
            return new Element(this.combinator, this.value.eval ? this.value.eval(context) : this.value, this.isVariable, this.getIndex(), this.fileInfo(), this.visibilityInfo());
        },
        clone: function () {
            return new Element(this.combinator, this.value, this.isVariable, this.getIndex(), this.fileInfo(), this.visibilityInfo());
        },
        genCSS: function (context, output) {
            output.add(this.toCSS(context), this.fileInfo(), this.getIndex());
        },
        toCSS: function (context) {
            context = context || {};
            var value = this.value;
            var firstSelector = context.firstSelector;
            if (value instanceof paren_1.default) {
                // selector in parens should not be affected by outer selector
                // flags (breaks only interpolated selectors - see #1973)
                context.firstSelector = true;
            }
            value = value.toCSS ? value.toCSS(context) : value;
            context.firstSelector = firstSelector;
            if (value === '' && this.combinator.value.charAt(0) === '&') {
                return '';
            }
            else {
                return this.combinator.toCSS(context) + value;
            }
        }
    });
    exports.default = Element;
    
},
/* less/lib/less/tree/paren.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Paren = function (node) {
        this.value = node;
    };
    Paren.prototype = Object.assign(new node_1.default(), {
        type: 'Paren',
        genCSS: function (context, output) {
            output.add('(');
            this.value.genCSS(context, output);
            output.add(')');
        },
        eval: function (context) {
            return new Paren(this.value.eval(context));
        }
    });
    exports.default = Paren;
    
},
/* less/lib/less/tree/combinator.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var _noSpaceCombinators = {
        '': true,
        ' ': true,
        '|': true
    };
    var Combinator = function (value) {
        if (value === ' ') {
            this.value = ' ';
            this.emptyOrWhitespace = true;
        }
        else {
            this.value = value ? value.trim() : '';
            this.emptyOrWhitespace = this.value === '';
        }
    };
    Combinator.prototype = Object.assign(new node_1.default(), {
        type: 'Combinator',
        genCSS: function (context, output) {
            var spaceOrEmpty = (context.compress || _noSpaceCombinators[this.value]) ? '' : ' ';
            output.add(spaceOrEmpty + this.value + spaceOrEmpty);
        }
    });
    exports.default = Combinator;
    
},
/* less/lib/less/less-error.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    var anonymousFunc = /(<anonymous>|Function):(\d+):(\d+)/;
    /**
     * This is a centralized class of any error that could be thrown internally (mostly by the parser).
     * Besides standard .message it keeps some additional data like a path to the file where the error
     * occurred along with line and column numbers.
     *
     * @class
     * @extends Error
     * @type {module.LessError}
     *
     * @prop {string} type
     * @prop {string} filename
     * @prop {number} index
     * @prop {number} line
     * @prop {number} column
     * @prop {number} callLine
     * @prop {number} callExtract
     * @prop {string[]} extract
     *
     * @param {Object} e              - An error object to wrap around or just a descriptive object
     * @param {Object} fileContentMap - An object with file contents in 'contents' property (like importManager) @todo - move to fileManager?
     * @param {string} [currentFilename]
     */
    var LessError = function (e, fileContentMap, currentFilename) {
        Error.call(this);
        var filename = e.filename || currentFilename;
        this.message = e.message;
        this.stack = e.stack;
        if (fileContentMap && filename) {
            var input = fileContentMap.contents[filename];
            var loc = utils.getLocation(e.index, input);
            var line = loc.line;
            var col = loc.column;
            var callLine = e.call && utils.getLocation(e.call, input).line;
            var lines = input ? input.split('\n') : '';
            this.type = e.type || 'Syntax';
            this.filename = filename;
            this.index = e.index;
            this.line = typeof line === 'number' ? line + 1 : null;
            this.column = col;
            if (!this.line && this.stack) {
                var found = this.stack.match(anonymousFunc);
                /**
                 * We have to figure out how this environment stringifies anonymous functions
                 * so we can correctly map plugin errors.
                 *
                 * Note, in Node 8, the output of anonymous funcs varied based on parameters
                 * being present or not, so we inject dummy params.
                 */
                var func = new Function('a', 'throw new Error()');
                var lineAdjust = 0;
                try {
                    func();
                }
                catch (e) {
                    var match = e.stack.match(anonymousFunc);
                    var line = parseInt(match[2]);
                    lineAdjust = 1 - line;
                }
                if (found) {
                    if (found[2]) {
                        this.line = parseInt(found[2]) + lineAdjust;
                    }
                    if (found[3]) {
                        this.column = parseInt(found[3]);
                    }
                }
            }
            this.callLine = callLine + 1;
            this.callExtract = lines[callLine];
            this.extract = [
                lines[this.line - 2],
                lines[this.line - 1],
                lines[this.line]
            ];
        }
    };
    if (typeof Object.create === 'undefined') {
        var F = function () { };
        F.prototype = Error.prototype;
        LessError.prototype = new F();
    }
    else {
        LessError.prototype = Object.create(Error.prototype);
    }
    LessError.prototype.constructor = LessError;
    /**
     * An overridden version of the default Object.prototype.toString
     * which uses additional information to create a helpful message.
     *
     * @param {Object} options
     * @returns {string}
     */
    LessError.prototype.toString = function (options) {
        options = options || {};
        var message = '';
        var extract = this.extract || [];
        var error = [];
        var stylize = function (str) { return str; };
        if (options.stylize) {
            var type = typeof options.stylize;
            if (type !== 'function') {
                throw Error("options.stylize should be a function, got a " + type + "!");
            }
            stylize = options.stylize;
        }
        if (this.line !== null) {
            if (typeof extract[0] === 'string') {
                error.push(stylize(this.line - 1 + " " + extract[0], 'grey'));
            }
            if (typeof extract[1] === 'string') {
                var errorTxt = this.line + " ";
                if (extract[1]) {
                    errorTxt += extract[1].slice(0, this.column) +
                        stylize(stylize(stylize(extract[1].substr(this.column, 1), 'bold') +
                            extract[1].slice(this.column + 1), 'red'), 'inverse');
                }
                error.push(errorTxt);
            }
            if (typeof extract[2] === 'string') {
                error.push(stylize(this.line + 1 + " " + extract[2], 'grey'));
            }
            error = error.join('\n') + stylize('', 'reset') + "\n";
        }
        message += stylize(this.type + "Error: " + this.message, 'red');
        if (this.filename) {
            message += stylize(' in ', 'red') + this.filename;
        }
        if (this.line) {
            message += stylize(" on line " + this.line + ", column " + (this.column + 1) + ":", 'grey');
        }
        message += "\n" + error;
        if (this.callLine) {
            message += stylize('from ', 'red') + (this.filename || '') + "/n";
            message += stylize(this.callLine, 'grey') + " " + this.callExtract + "/n";
        }
        return message;
    };
    exports.default = LessError;
    
},
/* less/lib/less/utils.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.flattenArray = exports.merge = exports.copyOptions = exports.defaults = exports.clone = exports.copyArray = exports.getLocation = void 0;
    var tslib_1 = require(58) /* tslib */;
    /* jshint proto: true */
    var Constants = tslib_1.__importStar(require(123) /* ./constants */);
    var copy_anything_1 = require(124) /* copy-anything */;
    function getLocation(index, inputStream) {
        var n = index + 1;
        var line = null;
        var column = -1;
        while (--n >= 0 && inputStream.charAt(n) !== '\n') {
            column++;
        }
        if (typeof index === 'number') {
            line = (inputStream.slice(0, index).match(/\n/g) || '').length;
        }
        return {
            line: line,
            column: column
        };
    }
    exports.getLocation = getLocation;
    function copyArray(arr) {
        var i;
        var length = arr.length;
        var copy = new Array(length);
        for (i = 0; i < length; i++) {
            copy[i] = arr[i];
        }
        return copy;
    }
    exports.copyArray = copyArray;
    function clone(obj) {
        var cloned = {};
        for (var prop in obj) {
            if (obj.hasOwnProperty(prop)) {
                cloned[prop] = obj[prop];
            }
        }
        return cloned;
    }
    exports.clone = clone;
    function defaults(obj1, obj2) {
        var newObj = obj2 || {};
        if (!obj2._defaults) {
            newObj = {};
            var defaults_1 = copy_anything_1.copy(obj1);
            newObj._defaults = defaults_1;
            var cloned = obj2 ? copy_anything_1.copy(obj2) : {};
            Object.assign(newObj, defaults_1, cloned);
        }
        return newObj;
    }
    exports.defaults = defaults;
    function copyOptions(obj1, obj2) {
        if (obj2 && obj2._defaults) {
            return obj2;
        }
        var opts = defaults(obj1, obj2);
        if (opts.strictMath) {
            opts.math = Constants.Math.PARENS;
        }
        // Back compat with changed relativeUrls option
        if (opts.relativeUrls) {
            opts.rewriteUrls = Constants.RewriteUrls.ALL;
        }
        if (typeof opts.math === 'string') {
            switch (opts.math.toLowerCase()) {
                case 'always':
                    opts.math = Constants.Math.ALWAYS;
                    break;
                case 'parens-division':
                    opts.math = Constants.Math.PARENS_DIVISION;
                    break;
                case 'strict':
                case 'parens':
                    opts.math = Constants.Math.PARENS;
                    break;
                default:
                    opts.math = Constants.Math.PARENS;
            }
        }
        if (typeof opts.rewriteUrls === 'string') {
            switch (opts.rewriteUrls.toLowerCase()) {
                case 'off':
                    opts.rewriteUrls = Constants.RewriteUrls.OFF;
                    break;
                case 'local':
                    opts.rewriteUrls = Constants.RewriteUrls.LOCAL;
                    break;
                case 'all':
                    opts.rewriteUrls = Constants.RewriteUrls.ALL;
                    break;
            }
        }
        return opts;
    }
    exports.copyOptions = copyOptions;
    function merge(obj1, obj2) {
        for (var prop in obj2) {
            if (obj2.hasOwnProperty(prop)) {
                obj1[prop] = obj2[prop];
            }
        }
        return obj1;
    }
    exports.merge = merge;
    function flattenArray(arr, result) {
        if (result === void 0) {
            result = [];
        }
        for (var i = 0, length_1 = arr.length; i < length_1; i++) {
            var value = arr[i];
            if (Array.isArray(value)) {
                flattenArray(value, result);
            }
            else {
                if (value !== undefined) {
                    result.push(value);
                }
            }
        }
        return result;
    }
    exports.flattenArray = flattenArray;
    
},
/* less/lib/less/constants.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.RewriteUrls = exports.Math = void 0;
    exports.Math = {
        ALWAYS: 0,
        PARENS_DIVISION: 1,
        PARENS: 2
        // removed - STRICT_LEGACY: 3
    };
    exports.RewriteUrls = {
        OFF: 0,
        LOCAL: 1,
        ALL: 2
    };
    
},
/* copy-anything/dist/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    var isWhat = require(125) /* is-what */;
    function assignProp(carry, key, newVal, originalObject, includeNonenumerable) {
        const propType = {}.propertyIsEnumerable.call(originalObject, key)
            ? 'enumerable'
            : 'nonenumerable';
        if (propType === 'enumerable')
            carry[key] = newVal;
        if (includeNonenumerable && propType === 'nonenumerable') {
            Object.defineProperty(carry, key, {
                value: newVal,
                enumerable: false,
                writable: true,
                configurable: true,
            });
        }
    }
    /**
     * Copy (clone) an object and all its props recursively to get rid of any prop referenced of the original object. Arrays are also cloned, however objects inside arrays are still linked.
     *
     * @export
     * @template T
     * @param {T} target Target can be anything
     * @param {Options} [options = {}] Options can be `props` or `nonenumerable`
     * @returns {T} the target with replaced values
     * @export
     */
    function copy(target, options = {}) {
        if (isWhat.isArray(target)) {
            return target.map((item) => copy(item, options));
        }
        if (!isWhat.isPlainObject(target)) {
            return target;
        }
        const props = Object.getOwnPropertyNames(target);
        const symbols = Object.getOwnPropertySymbols(target);
        return [...props, ...symbols].reduce((carry, key) => {
            if (isWhat.isArray(options.props) && !options.props.includes(key)) {
                return carry;
            }
            const val = target[key];
            const newVal = copy(val, options);
            assignProp(carry, key, newVal, target, options.nonenumerable);
            return carry;
        }, {});
    }
    exports.copy = copy;
},
/* is-what/dist/index.cjs.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    /**
     * Returns the object type of the given payload
     *
     * @param {*} payload
     * @returns {string}
     */
    function getType(payload) {
        return Object.prototype.toString.call(payload).slice(8, -1);
    }
    /**
     * Returns whether the payload is undefined
     *
     * @param {*} payload
     * @returns {payload is undefined}
     */
    function isUndefined(payload) {
        return getType(payload) === 'Undefined';
    }
    /**
     * Returns whether the payload is null
     *
     * @param {*} payload
     * @returns {payload is null}
     */
    function isNull(payload) {
        return getType(payload) === 'Null';
    }
    /**
     * Returns whether the payload is a plain JavaScript object (excluding special classes or objects with other prototypes)
     *
     * @param {*} payload
     * @returns {payload is PlainObject}
     */
    function isPlainObject(payload) {
        if (getType(payload) !== 'Object')
            return false;
        return payload.constructor === Object && Object.getPrototypeOf(payload) === Object.prototype;
    }
    /**
     * Returns whether the payload is a plain JavaScript object (excluding special classes or objects with other prototypes)
     *
     * @param {*} payload
     * @returns {payload is PlainObject}
     */
    function isObject(payload) {
        return isPlainObject(payload);
    }
    /**
     * Returns whether the payload is a an empty object (excluding special classes or objects with other prototypes)
     *
     * @param {*} payload
     * @returns {payload is { [K in any]: never }}
     */
    function isEmptyObject(payload) {
        return isPlainObject(payload) && Object.keys(payload).length === 0;
    }
    /**
     * Returns whether the payload is a an empty object (excluding special classes or objects with other prototypes)
     *
     * @param {*} payload
     * @returns {payload is PlainObject}
     */
    function isFullObject(payload) {
        return isPlainObject(payload) && Object.keys(payload).length > 0;
    }
    /**
     * Returns whether the payload is an any kind of object (including special classes or objects with different prototypes)
     *
     * @param {*} payload
     * @returns {payload is PlainObject}
     */
    function isAnyObject(payload) {
        return getType(payload) === 'Object';
    }
    /**
     * Returns whether the payload is an object like a type passed in < >
     *
     * Usage: isObjectLike<{id: any}>(payload) // will make sure it's an object and has an `id` prop.
     *
     * @template T this must be passed in < >
     * @param {*} payload
     * @returns {payload is T}
     */
    function isObjectLike(payload) {
        return isAnyObject(payload);
    }
    /**
     * Returns whether the payload is a function (regular or async)
     *
     * @param {*} payload
     * @returns {payload is AnyFunction}
     */
    function isFunction(payload) {
        return typeof payload === 'function';
    }
    /**
     * Returns whether the payload is an array
     *
     * @param {any} payload
     * @returns {payload is any[]}
     */
    function isArray(payload) {
        return getType(payload) === 'Array';
    }
    /**
     * Returns whether the payload is a an array with at least 1 item
     *
     * @param {*} payload
     * @returns {payload is any[]}
     */
    function isFullArray(payload) {
        return isArray(payload) && payload.length > 0;
    }
    /**
     * Returns whether the payload is a an empty array
     *
     * @param {*} payload
     * @returns {payload is []}
     */
    function isEmptyArray(payload) {
        return isArray(payload) && payload.length === 0;
    }
    /**
     * Returns whether the payload is a string
     *
     * @param {*} payload
     * @returns {payload is string}
     */
    function isString(payload) {
        return getType(payload) === 'String';
    }
    /**
     * Returns whether the payload is a string, BUT returns false for ''
     *
     * @param {*} payload
     * @returns {payload is string}
     */
    function isFullString(payload) {
        return isString(payload) && payload !== '';
    }
    /**
     * Returns whether the payload is ''
     *
     * @param {*} payload
     * @returns {payload is string}
     */
    function isEmptyString(payload) {
        return payload === '';
    }
    /**
     * Returns whether the payload is a number (but not NaN)
     *
     * This will return `false` for `NaN`!!
     *
     * @param {*} payload
     * @returns {payload is number}
     */
    function isNumber(payload) {
        return getType(payload) === 'Number' && !isNaN(payload);
    }
    /**
     * Returns whether the payload is a boolean
     *
     * @param {*} payload
     * @returns {payload is boolean}
     */
    function isBoolean(payload) {
        return getType(payload) === 'Boolean';
    }
    /**
     * Returns whether the payload is a regular expression (RegExp)
     *
     * @param {*} payload
     * @returns {payload is RegExp}
     */
    function isRegExp(payload) {
        return getType(payload) === 'RegExp';
    }
    /**
     * Returns whether the payload is a Map
     *
     * @param {*} payload
     * @returns {payload is Map<any, any>}
     */
    function isMap(payload) {
        return getType(payload) === 'Map';
    }
    /**
     * Returns whether the payload is a WeakMap
     *
     * @param {*} payload
     * @returns {payload is WeakMap<any, any>}
     */
    function isWeakMap(payload) {
        return getType(payload) === 'WeakMap';
    }
    /**
     * Returns whether the payload is a Set
     *
     * @param {*} payload
     * @returns {payload is Set<any>}
     */
    function isSet(payload) {
        return getType(payload) === 'Set';
    }
    /**
     * Returns whether the payload is a WeakSet
     *
     * @param {*} payload
     * @returns {payload is WeakSet<any>}
     */
    function isWeakSet(payload) {
        return getType(payload) === 'WeakSet';
    }
    /**
     * Returns whether the payload is a Symbol
     *
     * @param {*} payload
     * @returns {payload is symbol}
     */
    function isSymbol(payload) {
        return getType(payload) === 'Symbol';
    }
    /**
     * Returns whether the payload is a Date, and that the date is valid
     *
     * @param {*} payload
     * @returns {payload is Date}
     */
    function isDate(payload) {
        return getType(payload) === 'Date' && !isNaN(payload);
    }
    /**
     * Returns whether the payload is a Blob
     *
     * @param {*} payload
     * @returns {payload is Blob}
     */
    function isBlob(payload) {
        return getType(payload) === 'Blob';
    }
    /**
     * Returns whether the payload is a File
     *
     * @param {*} payload
     * @returns {payload is File}
     */
    function isFile(payload) {
        return getType(payload) === 'File';
    }
    /**
     * Returns whether the payload is a Promise
     *
     * @param {*} payload
     * @returns {payload is Promise<any>}
     */
    function isPromise(payload) {
        return getType(payload) === 'Promise';
    }
    /**
     * Returns whether the payload is an Error
     *
     * @param {*} payload
     * @returns {payload is Error}
     */
    function isError(payload) {
        return getType(payload) === 'Error';
    }
    /**
     * Returns whether the payload is literally the value `NaN` (it's `NaN` and also a `number`)
     *
     * @param {*} payload
     * @returns {payload is typeof NaN}
     */
    function isNaNValue(payload) {
        return getType(payload) === 'Number' && isNaN(payload);
    }
    /**
     * Returns whether the payload is a primitive type (eg. Boolean | Null | Undefined | Number | String | Symbol)
     *
     * @param {*} payload
     * @returns {(payload is boolean | null | undefined | number | string | symbol)}
     */
    function isPrimitive(payload) {
        return (isBoolean(payload) ||
            isNull(payload) ||
            isUndefined(payload) ||
            isNumber(payload) ||
            isString(payload) ||
            isSymbol(payload));
    }
    /**
     * Returns true whether the payload is null or undefined
     *
     * @param {*} payload
     * @returns {(payload is null | undefined)}
     */
    var isNullOrUndefined = isOneOf(isNull, isUndefined);
    function isOneOf(a, b, c, d, e) {
        return function (value) {
            return a(value) || b(value) || (!!c && c(value)) || (!!d && d(value)) || (!!e && e(value));
        };
    }
    /**
     * Does a generic check to check that the given payload is of a given type.
     * In cases like Number, it will return true for NaN as NaN is a Number (thanks javascript!);
     * It will, however, differentiate between object and null
     *
     * @template T
     * @param {*} payload
     * @param {T} type
     * @throws {TypeError} Will throw type error if type is an invalid type
     * @returns {payload is T}
     */
    function isType(payload, type) {
        if (!(type instanceof Function)) {
            throw new TypeError('Type must be a function');
        }
        if (!Object.prototype.hasOwnProperty.call(type, 'prototype')) {
            throw new TypeError('Type is not a class');
        }
        // Classes usually have names (as functions usually have names)
        var name = type.name;
        return getType(payload) === name || Boolean(payload && payload.constructor === type);
    }
    exports.getType = getType;
    exports.isAnyObject = isAnyObject;
    exports.isArray = isArray;
    exports.isBlob = isBlob;
    exports.isBoolean = isBoolean;
    exports.isDate = isDate;
    exports.isEmptyArray = isEmptyArray;
    exports.isEmptyObject = isEmptyObject;
    exports.isEmptyString = isEmptyString;
    exports.isError = isError;
    exports.isFile = isFile;
    exports.isFullArray = isFullArray;
    exports.isFullObject = isFullObject;
    exports.isFullString = isFullString;
    exports.isFunction = isFunction;
    exports.isMap = isMap;
    exports.isNaNValue = isNaNValue;
    exports.isNull = isNull;
    exports.isNullOrUndefined = isNullOrUndefined;
    exports.isNumber = isNumber;
    exports.isObject = isObject;
    exports.isObjectLike = isObjectLike;
    exports.isOneOf = isOneOf;
    exports.isPlainObject = isPlainObject;
    exports.isPrimitive = isPrimitive;
    exports.isPromise = isPromise;
    exports.isRegExp = isRegExp;
    exports.isSet = isSet;
    exports.isString = isString;
    exports.isSymbol = isSymbol;
    exports.isType = isType;
    exports.isUndefined = isUndefined;
    exports.isWeakMap = isWeakMap;
    exports.isWeakSet = isWeakSet;
},
/* less/lib/less/tree/ruleset.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var declaration_1 = tslib_1.__importDefault(require(127) /* ./declaration */);
    var keyword_1 = tslib_1.__importDefault(require(129) /* ./keyword */);
    var comment_1 = tslib_1.__importDefault(require(131) /* ./comment */);
    var paren_1 = tslib_1.__importDefault(require(119) /* ./paren */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var element_1 = tslib_1.__importDefault(require(118) /* ./element */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ./anonymous */);
    var contexts_1 = tslib_1.__importDefault(require(133) /* ../contexts */);
    var function_registry_1 = tslib_1.__importDefault(require(134) /* ../functions/function-registry */);
    var default_1 = tslib_1.__importDefault(require(135) /* ../functions/default */);
    var debug_info_1 = tslib_1.__importDefault(require(132) /* ./debug-info */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var Ruleset = function (selectors, rules, strictImports, visibilityInfo) {
        this.selectors = selectors;
        this.rules = rules;
        this._lookups = {};
        this._variables = null;
        this._properties = null;
        this.strictImports = strictImports;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
        this.setParent(this.selectors, this);
        this.setParent(this.rules, this);
    };
    Ruleset.prototype = Object.assign(new node_1.default(), {
        type: 'Ruleset',
        isRuleset: true,
        isRulesetLike: function () { return true; },
        accept: function (visitor) {
            if (this.paths) {
                this.paths = visitor.visitArray(this.paths, true);
            }
            else if (this.selectors) {
                this.selectors = visitor.visitArray(this.selectors);
            }
            if (this.rules && this.rules.length) {
                this.rules = visitor.visitArray(this.rules);
            }
        },
        eval: function (context) {
            var that = this;
            var selectors;
            var selCnt;
            var selector;
            var i;
            var hasVariable;
            var hasOnePassingSelector = false;
            if (this.selectors && (selCnt = this.selectors.length)) {
                selectors = new Array(selCnt);
                default_1.default.error({
                    type: 'Syntax',
                    message: 'it is currently only allowed in parametric mixin guards,'
                });
                for (i = 0; i < selCnt; i++) {
                    selector = this.selectors[i].eval(context);
                    for (var j = 0; j < selector.elements.length; j++) {
                        if (selector.elements[j].isVariable) {
                            hasVariable = true;
                            break;
                        }
                    }
                    selectors[i] = selector;
                    if (selector.evaldCondition) {
                        hasOnePassingSelector = true;
                    }
                }
                if (hasVariable) {
                    var toParseSelectors = new Array(selCnt);
                    for (i = 0; i < selCnt; i++) {
                        selector = selectors[i];
                        toParseSelectors[i] = selector.toCSS(context);
                    }
                    this.parse.parseNode(toParseSelectors.join(','), ["selectors"], selectors[0].getIndex(), selectors[0].fileInfo(), function (err, result) {
                        if (result) {
                            selectors = utils.flattenArray(result);
                        }
                    });
                }
                default_1.default.reset();
            }
            else {
                hasOnePassingSelector = true;
            }
            var rules = this.rules ? utils.copyArray(this.rules) : null;
            var ruleset = new Ruleset(selectors, rules, this.strictImports, this.visibilityInfo());
            var rule;
            var subRule;
            ruleset.originalRuleset = this;
            ruleset.root = this.root;
            ruleset.firstRoot = this.firstRoot;
            ruleset.allowImports = this.allowImports;
            if (this.debugInfo) {
                ruleset.debugInfo = this.debugInfo;
            }
            if (!hasOnePassingSelector) {
                rules.length = 0;
            }
            // inherit a function registry from the frames stack when possible;
            // otherwise from the global registry
            ruleset.functionRegistry = (function (frames) {
                var i = 0;
                var n = frames.length;
                var found;
                for (; i !== n; ++i) {
                    found = frames[i].functionRegistry;
                    if (found) {
                        return found;
                    }
                }
                return function_registry_1.default;
            }(context.frames)).inherit();
            // push the current ruleset to the frames stack
            var ctxFrames = context.frames;
            ctxFrames.unshift(ruleset);
            // currrent selectors
            var ctxSelectors = context.selectors;
            if (!ctxSelectors) {
                context.selectors = ctxSelectors = [];
            }
            ctxSelectors.unshift(this.selectors);
            // Evaluate imports
            if (ruleset.root || ruleset.allowImports || !ruleset.strictImports) {
                ruleset.evalImports(context);
            }
            // Store the frames around mixin definitions,
            // so they can be evaluated like closures when the time comes.
            var rsRules = ruleset.rules;
            for (i = 0; (rule = rsRules[i]); i++) {
                if (rule.evalFirst) {
                    rsRules[i] = rule.eval(context);
                }
            }
            var mediaBlockCount = (context.mediaBlocks && context.mediaBlocks.length) || 0;
            // Evaluate mixin calls.
            for (i = 0; (rule = rsRules[i]); i++) {
                if (rule.type === 'MixinCall') {
                    /* jshint loopfunc:true */
                    rules = rule.eval(context).filter(function (r) {
                        if ((r instanceof declaration_1.default) && r.variable) {
                            // do not pollute the scope if the variable is
                            // already there. consider returning false here
                            // but we need a way to "return" variable from mixins
                            return !(ruleset.variable(r.name));
                        }
                        return true;
                    });
                    rsRules.splice.apply(rsRules, [i, 1].concat(rules));
                    i += rules.length - 1;
                    ruleset.resetCache();
                }
                else if (rule.type === 'VariableCall') {
                    /* jshint loopfunc:true */
                    rules = rule.eval(context).rules.filter(function (r) {
                        if ((r instanceof declaration_1.default) && r.variable) {
                            // do not pollute the scope at all
                            return false;
                        }
                        return true;
                    });
                    rsRules.splice.apply(rsRules, [i, 1].concat(rules));
                    i += rules.length - 1;
                    ruleset.resetCache();
                }
            }
            // Evaluate everything else
            for (i = 0; (rule = rsRules[i]); i++) {
                if (!rule.evalFirst) {
                    rsRules[i] = rule = rule.eval ? rule.eval(context) : rule;
                }
            }
            // Evaluate everything else
            for (i = 0; (rule = rsRules[i]); i++) {
                // for rulesets, check if it is a css guard and can be removed
                if (rule instanceof Ruleset && rule.selectors && rule.selectors.length === 1) {
                    // check if it can be folded in (e.g. & where)
                    if (rule.selectors[0] && rule.selectors[0].isJustParentSelector()) {
                        rsRules.splice(i--, 1);
                        for (var j = 0; (subRule = rule.rules[j]); j++) {
                            if (subRule instanceof node_1.default) {
                                subRule.copyVisibilityInfo(rule.visibilityInfo());
                                if (!(subRule instanceof declaration_1.default) || !subRule.variable) {
                                    rsRules.splice(++i, 0, subRule);
                                }
                            }
                        }
                    }
                }
            }
            // Pop the stack
            ctxFrames.shift();
            ctxSelectors.shift();
            if (context.mediaBlocks) {
                for (i = mediaBlockCount; i < context.mediaBlocks.length; i++) {
                    context.mediaBlocks[i].bubbleSelectors(selectors);
                }
            }
            return ruleset;
        },
        evalImports: function (context) {
            var rules = this.rules;
            var i;
            var importRules;
            if (!rules) {
                return;
            }
            for (i = 0; i < rules.length; i++) {
                if (rules[i].type === 'Import') {
                    importRules = rules[i].eval(context);
                    if (importRules && (importRules.length || importRules.length === 0)) {
                        rules.splice.apply(rules, [i, 1].concat(importRules));
                        i += importRules.length - 1;
                    }
                    else {
                        rules.splice(i, 1, importRules);
                    }
                    this.resetCache();
                }
            }
        },
        makeImportant: function () {
            var result = new Ruleset(this.selectors, this.rules.map(function (r) {
                if (r.makeImportant) {
                    return r.makeImportant();
                }
                else {
                    return r;
                }
            }), this.strictImports, this.visibilityInfo());
            return result;
        },
        matchArgs: function (args) {
            return !args || args.length === 0;
        },
        // lets you call a css selector with a guard
        matchCondition: function (args, context) {
            var lastSelector = this.selectors[this.selectors.length - 1];
            if (!lastSelector.evaldCondition) {
                return false;
            }
            if (lastSelector.condition &&
                !lastSelector.condition.eval(new contexts_1.default.Eval(context, context.frames))) {
                return false;
            }
            return true;
        },
        resetCache: function () {
            this._rulesets = null;
            this._variables = null;
            this._properties = null;
            this._lookups = {};
        },
        variables: function () {
            if (!this._variables) {
                this._variables = !this.rules ? {} : this.rules.reduce(function (hash, r) {
                    if (r instanceof declaration_1.default && r.variable === true) {
                        hash[r.name] = r;
                    }
                    // when evaluating variables in an import statement, imports have not been eval'd
                    // so we need to go inside import statements.
                    // guard against root being a string (in the case of inlined less)
                    if (r.type === 'Import' && r.root && r.root.variables) {
                        var vars = r.root.variables();
                        for (var name_1 in vars) {
                            if (vars.hasOwnProperty(name_1)) {
                                hash[name_1] = r.root.variable(name_1);
                            }
                        }
                    }
                    return hash;
                }, {});
            }
            return this._variables;
        },
        properties: function () {
            if (!this._properties) {
                this._properties = !this.rules ? {} : this.rules.reduce(function (hash, r) {
                    if (r instanceof declaration_1.default && r.variable !== true) {
                        var name_2 = (r.name.length === 1) && (r.name[0] instanceof keyword_1.default) ?
                            r.name[0].value : r.name;
                        // Properties don't overwrite as they can merge
                        if (!hash["$" + name_2]) {
                            hash["$" + name_2] = [r];
                        }
                        else {
                            hash["$" + name_2].push(r);
                        }
                    }
                    return hash;
                }, {});
            }
            return this._properties;
        },
        variable: function (name) {
            var decl = this.variables()[name];
            if (decl) {
                return this.parseValue(decl);
            }
        },
        property: function (name) {
            var decl = this.properties()[name];
            if (decl) {
                return this.parseValue(decl);
            }
        },
        lastDeclaration: function () {
            for (var i = this.rules.length; i > 0; i--) {
                var decl = this.rules[i - 1];
                if (decl instanceof declaration_1.default) {
                    return this.parseValue(decl);
                }
            }
        },
        parseValue: function (toParse) {
            var self = this;
            function transformDeclaration(decl) {
                if (decl.value instanceof anonymous_1.default && !decl.parsed) {
                    if (typeof decl.value.value === 'string') {
                        this.parse.parseNode(decl.value.value, ['value', 'important'], decl.value.getIndex(), decl.fileInfo(), function (err, result) {
                            if (err) {
                                decl.parsed = true;
                            }
                            if (result) {
                                decl.value = result[0];
                                decl.important = result[1] || '';
                                decl.parsed = true;
                            }
                        });
                    }
                    else {
                        decl.parsed = true;
                    }
                    return decl;
                }
                else {
                    return decl;
                }
            }
            if (!Array.isArray(toParse)) {
                return transformDeclaration.call(self, toParse);
            }
            else {
                var nodes_1 = [];
                toParse.forEach(function (n) {
                    nodes_1.push(transformDeclaration.call(self, n));
                });
                return nodes_1;
            }
        },
        rulesets: function () {
            if (!this.rules) {
                return [];
            }
            var filtRules = [];
            var rules = this.rules;
            var i;
            var rule;
            for (i = 0; (rule = rules[i]); i++) {
                if (rule.isRuleset) {
                    filtRules.push(rule);
                }
            }
            return filtRules;
        },
        prependRule: function (rule) {
            var rules = this.rules;
            if (rules) {
                rules.unshift(rule);
            }
            else {
                this.rules = [rule];
            }
            this.setParent(rule, this);
        },
        find: function (selector, self, filter) {
            self = self || this;
            var rules = [];
            var match;
            var foundMixins;
            var key = selector.toCSS();
            if (key in this._lookups) {
                return this._lookups[key];
            }
            this.rulesets().forEach(function (rule) {
                if (rule !== self) {
                    for (var j = 0; j < rule.selectors.length; j++) {
                        match = selector.match(rule.selectors[j]);
                        if (match) {
                            if (selector.elements.length > match) {
                                if (!filter || filter(rule)) {
                                    foundMixins = rule.find(new selector_1.default(selector.elements.slice(match)), self, filter);
                                    for (var i = 0; i < foundMixins.length; ++i) {
                                        foundMixins[i].path.push(rule);
                                    }
                                    Array.prototype.push.apply(rules, foundMixins);
                                }
                            }
                            else {
                                rules.push({ rule: rule, path: [] });
                            }
                            break;
                        }
                    }
                }
            });
            this._lookups[key] = rules;
            return rules;
        },
        genCSS: function (context, output) {
            var i;
            var j;
            var charsetRuleNodes = [];
            var ruleNodes = [];
            var // Line number debugging
            debugInfo;
            var rule;
            var path;
            context.tabLevel = (context.tabLevel || 0);
            if (!this.root) {
                context.tabLevel++;
            }
            var tabRuleStr = context.compress ? '' : Array(context.tabLevel + 1).join('  ');
            var tabSetStr = context.compress ? '' : Array(context.tabLevel).join('  ');
            var sep;
            var charsetNodeIndex = 0;
            var importNodeIndex = 0;
            for (i = 0; (rule = this.rules[i]); i++) {
                if (rule instanceof comment_1.default) {
                    if (importNodeIndex === i) {
                        importNodeIndex++;
                    }
                    ruleNodes.push(rule);
                }
                else if (rule.isCharset && rule.isCharset()) {
                    ruleNodes.splice(charsetNodeIndex, 0, rule);
                    charsetNodeIndex++;
                    importNodeIndex++;
                }
                else if (rule.type === 'Import') {
                    ruleNodes.splice(importNodeIndex, 0, rule);
                    importNodeIndex++;
                }
                else {
                    ruleNodes.push(rule);
                }
            }
            ruleNodes = charsetRuleNodes.concat(ruleNodes);
            // If this is the root node, we don't render
            // a selector, or {}.
            if (!this.root) {
                debugInfo = debug_info_1.default(context, this, tabSetStr);
                if (debugInfo) {
                    output.add(debugInfo);
                    output.add(tabSetStr);
                }
                var paths = this.paths;
                var pathCnt = paths.length;
                var pathSubCnt = void 0;
                sep = context.compress ? ',' : (",\n" + tabSetStr);
                for (i = 0; i < pathCnt; i++) {
                    path = paths[i];
                    if (!(pathSubCnt = path.length)) {
                        continue;
                    }
                    if (i > 0) {
                        output.add(sep);
                    }
                    context.firstSelector = true;
                    path[0].genCSS(context, output);
                    context.firstSelector = false;
                    for (j = 1; j < pathSubCnt; j++) {
                        path[j].genCSS(context, output);
                    }
                }
                output.add((context.compress ? '{' : ' {\n') + tabRuleStr);
            }
            // Compile rules and rulesets
            for (i = 0; (rule = ruleNodes[i]); i++) {
                if (i + 1 === ruleNodes.length) {
                    context.lastRule = true;
                }
                var currentLastRule = context.lastRule;
                if (rule.isRulesetLike(rule)) {
                    context.lastRule = false;
                }
                if (rule.genCSS) {
                    rule.genCSS(context, output);
                }
                else if (rule.value) {
                    output.add(rule.value.toString());
                }
                context.lastRule = currentLastRule;
                if (!context.lastRule && rule.isVisible()) {
                    output.add(context.compress ? '' : ("\n" + tabRuleStr));
                }
                else {
                    context.lastRule = false;
                }
            }
            if (!this.root) {
                output.add((context.compress ? '}' : "\n" + tabSetStr + "}"));
                context.tabLevel--;
            }
            if (!output.isEmpty() && !context.compress && this.firstRoot) {
                output.add('\n');
            }
        },
        joinSelectors: function (paths, context, selectors) {
            for (var s = 0; s < selectors.length; s++) {
                this.joinSelector(paths, context, selectors[s]);
            }
        },
        joinSelector: function (paths, context, selector) {
            function createParenthesis(elementsToPak, originalElement) {
                var replacementParen, j;
                if (elementsToPak.length === 0) {
                    replacementParen = new paren_1.default(elementsToPak[0]);
                }
                else {
                    var insideParent = new Array(elementsToPak.length);
                    for (j = 0; j < elementsToPak.length; j++) {
                        insideParent[j] = new element_1.default(null, elementsToPak[j], originalElement.isVariable, originalElement._index, originalElement._fileInfo);
                    }
                    replacementParen = new paren_1.default(new selector_1.default(insideParent));
                }
                return replacementParen;
            }
            function createSelector(containedElement, originalElement) {
                var element, selector;
                element = new element_1.default(null, containedElement, originalElement.isVariable, originalElement._index, originalElement._fileInfo);
                selector = new selector_1.default([element]);
                return selector;
            }
            // joins selector path from `beginningPath` with selector path in `addPath`
            // `replacedElement` contains element that is being replaced by `addPath`
            // returns concatenated path
            function addReplacementIntoPath(beginningPath, addPath, replacedElement, originalSelector) {
                var newSelectorPath, lastSelector, newJoinedSelector;
                // our new selector path
                newSelectorPath = [];
                // construct the joined selector - if & is the first thing this will be empty,
                // if not newJoinedSelector will be the last set of elements in the selector
                if (beginningPath.length > 0) {
                    newSelectorPath = utils.copyArray(beginningPath);
                    lastSelector = newSelectorPath.pop();
                    newJoinedSelector = originalSelector.createDerived(utils.copyArray(lastSelector.elements));
                }
                else {
                    newJoinedSelector = originalSelector.createDerived([]);
                }
                if (addPath.length > 0) {
                    // /deep/ is a CSS4 selector - (removed, so should deprecate)
                    // that is valid without anything in front of it
                    // so if the & does not have a combinator that is "" or " " then
                    // and there is a combinator on the parent, then grab that.
                    // this also allows + a { & .b { .a & { ... though not sure why you would want to do that
                    var combinator = replacedElement.combinator;
                    var parentEl = addPath[0].elements[0];
                    if (combinator.emptyOrWhitespace && !parentEl.combinator.emptyOrWhitespace) {
                        combinator = parentEl.combinator;
                    }
                    // join the elements so far with the first part of the parent
                    newJoinedSelector.elements.push(new element_1.default(combinator, parentEl.value, replacedElement.isVariable, replacedElement._index, replacedElement._fileInfo));
                    newJoinedSelector.elements = newJoinedSelector.elements.concat(addPath[0].elements.slice(1));
                }
                // now add the joined selector - but only if it is not empty
                if (newJoinedSelector.elements.length !== 0) {
                    newSelectorPath.push(newJoinedSelector);
                }
                // put together the parent selectors after the join (e.g. the rest of the parent)
                if (addPath.length > 1) {
                    var restOfPath = addPath.slice(1);
                    restOfPath = restOfPath.map(function (selector) {
                        return selector.createDerived(selector.elements, []);
                    });
                    newSelectorPath = newSelectorPath.concat(restOfPath);
                }
                return newSelectorPath;
            }
            // joins selector path from `beginningPath` with every selector path in `addPaths` array
            // `replacedElement` contains element that is being replaced by `addPath`
            // returns array with all concatenated paths
            function addAllReplacementsIntoPath(beginningPath, addPaths, replacedElement, originalSelector, result) {
                var j;
                for (j = 0; j < beginningPath.length; j++) {
                    var newSelectorPath = addReplacementIntoPath(beginningPath[j], addPaths, replacedElement, originalSelector);
                    result.push(newSelectorPath);
                }
                return result;
            }
            function mergeElementsOnToSelectors(elements, selectors) {
                var i, sel;
                if (elements.length === 0) {
                    return;
                }
                if (selectors.length === 0) {
                    selectors.push([new selector_1.default(elements)]);
                    return;
                }
                for (i = 0; (sel = selectors[i]); i++) {
                    // if the previous thing in sel is a parent this needs to join on to it
                    if (sel.length > 0) {
                        sel[sel.length - 1] = sel[sel.length - 1].createDerived(sel[sel.length - 1].elements.concat(elements));
                    }
                    else {
                        sel.push(new selector_1.default(elements));
                    }
                }
            }
            // replace all parent selectors inside `inSelector` by content of `context` array
            // resulting selectors are returned inside `paths` array
            // returns true if `inSelector` contained at least one parent selector
            function replaceParentSelector(paths, context, inSelector) {
                // The paths are [[Selector]]
                // The first list is a list of comma separated selectors
                // The inner list is a list of inheritance separated selectors
                // e.g.
                // .a, .b {
                //   .c {
                //   }
                // }
                // == [[.a] [.c]] [[.b] [.c]]
                //
                var i, j, k, currentElements, newSelectors, selectorsMultiplied, sel, el, hadParentSelector = false, length, lastSelector;
                function findNestedSelector(element) {
                    var maybeSelector;
                    if (!(element.value instanceof paren_1.default)) {
                        return null;
                    }
                    maybeSelector = element.value.value;
                    if (!(maybeSelector instanceof selector_1.default)) {
                        return null;
                    }
                    return maybeSelector;
                }
                // the elements from the current selector so far
                currentElements = [];
                // the current list of new selectors to add to the path.
                // We will build it up. We initiate it with one empty selector as we "multiply" the new selectors
                // by the parents
                newSelectors = [
                    []
                ];
                for (i = 0; (el = inSelector.elements[i]); i++) {
                    // non parent reference elements just get added
                    if (el.value !== '&') {
                        var nestedSelector = findNestedSelector(el);
                        if (nestedSelector != null) {
                            // merge the current list of non parent selector elements
                            // on to the current list of selectors to add
                            mergeElementsOnToSelectors(currentElements, newSelectors);
                            var nestedPaths = [];
                            var replaced = void 0;
                            var replacedNewSelectors = [];
                            replaced = replaceParentSelector(nestedPaths, context, nestedSelector);
                            hadParentSelector = hadParentSelector || replaced;
                            // the nestedPaths array should have only one member - replaceParentSelector does not multiply selectors
                            for (k = 0; k < nestedPaths.length; k++) {
                                var replacementSelector = createSelector(createParenthesis(nestedPaths[k], el), el);
                                addAllReplacementsIntoPath(newSelectors, [replacementSelector], el, inSelector, replacedNewSelectors);
                            }
                            newSelectors = replacedNewSelectors;
                            currentElements = [];
                        }
                        else {
                            currentElements.push(el);
                        }
                    }
                    else {
                        hadParentSelector = true;
                        // the new list of selectors to add
                        selectorsMultiplied = [];
                        // merge the current list of non parent selector elements
                        // on to the current list of selectors to add
                        mergeElementsOnToSelectors(currentElements, newSelectors);
                        // loop through our current selectors
                        for (j = 0; j < newSelectors.length; j++) {
                            sel = newSelectors[j];
                            // if we don't have any parent paths, the & might be in a mixin so that it can be used
                            // whether there are parents or not
                            if (context.length === 0) {
                                // the combinator used on el should now be applied to the next element instead so that
                                // it is not lost
                                if (sel.length > 0) {
                                    sel[0].elements.push(new element_1.default(el.combinator, '', el.isVariable, el._index, el._fileInfo));
                                }
                                selectorsMultiplied.push(sel);
                            }
                            else {
                                // and the parent selectors
                                for (k = 0; k < context.length; k++) {
                                    // We need to put the current selectors
                                    // then join the last selector's elements on to the parents selectors
                                    var newSelectorPath = addReplacementIntoPath(sel, context[k], el, inSelector);
                                    // add that to our new set of selectors
                                    selectorsMultiplied.push(newSelectorPath);
                                }
                            }
                        }
                        // our new selectors has been multiplied, so reset the state
                        newSelectors = selectorsMultiplied;
                        currentElements = [];
                    }
                }
                // if we have any elements left over (e.g. .a& .b == .b)
                // add them on to all the current selectors
                mergeElementsOnToSelectors(currentElements, newSelectors);
                for (i = 0; i < newSelectors.length; i++) {
                    length = newSelectors[i].length;
                    if (length > 0) {
                        paths.push(newSelectors[i]);
                        lastSelector = newSelectors[i][length - 1];
                        newSelectors[i][length - 1] = lastSelector.createDerived(lastSelector.elements, inSelector.extendList);
                    }
                }
                return hadParentSelector;
            }
            function deriveSelector(visibilityInfo, deriveFrom) {
                var newSelector = deriveFrom.createDerived(deriveFrom.elements, deriveFrom.extendList, deriveFrom.evaldCondition);
                newSelector.copyVisibilityInfo(visibilityInfo);
                return newSelector;
            }
            // joinSelector code follows
            var i, newPaths, hadParentSelector;
            newPaths = [];
            hadParentSelector = replaceParentSelector(newPaths, context, selector);
            if (!hadParentSelector) {
                if (context.length > 0) {
                    newPaths = [];
                    for (i = 0; i < context.length; i++) {
                        var concatenated = context[i].map(deriveSelector.bind(this, selector.visibilityInfo()));
                        concatenated.push(selector);
                        newPaths.push(concatenated);
                    }
                }
                else {
                    newPaths = [[selector]];
                }
            }
            for (i = 0; i < newPaths.length; i++) {
                paths.push(newPaths[i]);
            }
        }
    });
    exports.default = Ruleset;
    
},
/* less/lib/less/tree/declaration.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var value_1 = tslib_1.__importDefault(require(128) /* ./value */);
    var keyword_1 = tslib_1.__importDefault(require(129) /* ./keyword */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ./anonymous */);
    var Constants = tslib_1.__importStar(require(123) /* ../constants */);
    var MATH = Constants.Math;
    function evalName(context, name) {
        var value = '';
        var i;
        var n = name.length;
        var output = { add: function (s) { value += s; } };
        for (i = 0; i < n; i++) {
            name[i].eval(context).genCSS(context, output);
        }
        return value;
    }
    var Declaration = function (name, value, important, merge, index, currentFileInfo, inline, variable) {
        this.name = name;
        this.value = (value instanceof node_1.default) ? value : new value_1.default([value ? new anonymous_1.default(value) : null]);
        this.important = important ? " " + important.trim() : '';
        this.merge = merge;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.inline = inline || false;
        this.variable = (variable !== undefined) ? variable
            : (name.charAt && (name.charAt(0) === '@'));
        this.allowRoot = true;
        this.setParent(this.value, this);
    };
    Declaration.prototype = Object.assign(new node_1.default(), {
        type: 'Declaration',
        genCSS: function (context, output) {
            output.add(this.name + (context.compress ? ':' : ': '), this.fileInfo(), this.getIndex());
            try {
                this.value.genCSS(context, output);
            }
            catch (e) {
                e.index = this._index;
                e.filename = this._fileInfo.filename;
                throw e;
            }
            output.add(this.important + ((this.inline || (context.lastRule && context.compress)) ? '' : ';'), this._fileInfo, this._index);
        },
        eval: function (context) {
            var mathBypass = false, prevMath, name = this.name, evaldValue, variable = this.variable;
            if (typeof name !== 'string') {
                // expand 'primitive' name directly to get
                // things faster (~10% for benchmark.less):
                name = (name.length === 1) && (name[0] instanceof keyword_1.default) ?
                    name[0].value : evalName(context, name);
                variable = false; // never treat expanded interpolation as new variable name
            }
            // @todo remove when parens-division is default
            if (name === 'font' && context.math === MATH.ALWAYS) {
                mathBypass = true;
                prevMath = context.math;
                context.math = MATH.PARENS_DIVISION;
            }
            try {
                context.importantScope.push({});
                evaldValue = this.value.eval(context);
                if (!this.variable && evaldValue.type === 'DetachedRuleset') {
                    throw { message: 'Rulesets cannot be evaluated on a property.',
                        index: this.getIndex(), filename: this.fileInfo().filename };
                }
                var important = this.important;
                var importantResult = context.importantScope.pop();
                if (!important && importantResult.important) {
                    important = importantResult.important;
                }
                return new Declaration(name, evaldValue, important, this.merge, this.getIndex(), this.fileInfo(), this.inline, variable);
            }
            catch (e) {
                if (typeof e.index !== 'number') {
                    e.index = this.getIndex();
                    e.filename = this.fileInfo().filename;
                }
                throw e;
            }
            finally {
                if (mathBypass) {
                    context.math = prevMath;
                }
            }
        },
        makeImportant: function () {
            return new Declaration(this.name, this.value, '!important', this.merge, this.getIndex(), this.fileInfo(), this.inline);
        }
    });
    exports.default = Declaration;
    
},
/* less/lib/less/tree/value.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Value = function (value) {
        if (!value) {
            throw new Error('Value requires an array argument');
        }
        if (!Array.isArray(value)) {
            this.value = [value];
        }
        else {
            this.value = value;
        }
    };
    Value.prototype = Object.assign(new node_1.default(), {
        type: 'Value',
        accept: function (visitor) {
            if (this.value) {
                this.value = visitor.visitArray(this.value);
            }
        },
        eval: function (context) {
            if (this.value.length === 1) {
                return this.value[0].eval(context);
            }
            else {
                return new Value(this.value.map(function (v) {
                    return v.eval(context);
                }));
            }
        },
        genCSS: function (context, output) {
            var i;
            for (i = 0; i < this.value.length; i++) {
                this.value[i].genCSS(context, output);
                if (i + 1 < this.value.length) {
                    output.add((context && context.compress) ? ',' : ', ');
                }
            }
        }
    });
    exports.default = Value;
    
},
/* less/lib/less/tree/keyword.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Keyword = function (value) {
        this.value = value;
    };
    Keyword.prototype = Object.assign(new node_1.default(), {
        type: 'Keyword',
        genCSS: function (context, output) {
            if (this.value === '%') {
                throw { type: 'Syntax', message: 'Invalid % without number' };
            }
            output.add(this.value);
        }
    });
    Keyword.True = new Keyword('true');
    Keyword.False = new Keyword('false');
    exports.default = Keyword;
    
},
/* less/lib/less/tree/anonymous.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Anonymous = function (value, index, currentFileInfo, mapLines, rulesetLike, visibilityInfo) {
        this.value = value;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.mapLines = mapLines;
        this.rulesetLike = (typeof rulesetLike === 'undefined') ? false : rulesetLike;
        this.allowRoot = true;
        this.copyVisibilityInfo(visibilityInfo);
    };
    Anonymous.prototype = Object.assign(new node_1.default(), {
        type: 'Anonymous',
        eval: function () {
            return new Anonymous(this.value, this._index, this._fileInfo, this.mapLines, this.rulesetLike, this.visibilityInfo());
        },
        compare: function (other) {
            return other.toCSS && this.toCSS() === other.toCSS() ? 0 : undefined;
        },
        isRulesetLike: function () {
            return this.rulesetLike;
        },
        genCSS: function (context, output) {
            this.nodeVisible = Boolean(this.value);
            if (this.nodeVisible) {
                output.add(this.value, this._fileInfo, this._index, this.mapLines);
            }
        }
    });
    exports.default = Anonymous;
    
},
/* less/lib/less/tree/comment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var debug_info_1 = tslib_1.__importDefault(require(132) /* ./debug-info */);
    var Comment = function (value, isLineComment, index, currentFileInfo) {
        this.value = value;
        this.isLineComment = isLineComment;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.allowRoot = true;
    };
    Comment.prototype = Object.assign(new node_1.default(), {
        type: 'Comment',
        genCSS: function (context, output) {
            if (this.debugInfo) {
                output.add(debug_info_1.default(context, this), this.fileInfo(), this.getIndex());
            }
            output.add(this.value);
        },
        isSilent: function (context) {
            var isCompressed = context.compress && this.value[2] !== '!';
            return this.isLineComment || isCompressed;
        }
    });
    exports.default = Comment;
    
},
/* less/lib/less/tree/debug-info.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function asComment(ctx) {
        return "/* line " + ctx.debugInfo.lineNumber + ", " + ctx.debugInfo.fileName + " */\n";
    }
    function asMediaQuery(ctx) {
        var filenameWithProtocol = ctx.debugInfo.fileName;
        if (!/^[a-z]+:\/\//i.test(filenameWithProtocol)) {
            filenameWithProtocol = "file://" + filenameWithProtocol;
        }
        return "@media -sass-debug-info{filename{font-family:" + filenameWithProtocol.replace(/([.:\/\\])/g, function (a) {
            if (a == '\\') {
                a = '\/';
            }
            return "\\" + a;
        }) + "}line{font-family:\\00003" + ctx.debugInfo.lineNumber + "}}\n";
    }
    function debugInfo(context, ctx, lineSeparator) {
        var result = '';
        if (context.dumpLineNumbers && !context.compress) {
            switch (context.dumpLineNumbers) {
                case 'comments':
                    result = asComment(ctx);
                    break;
                case 'mediaquery':
                    result = asMediaQuery(ctx);
                    break;
                case 'all':
                    result = asComment(ctx) + (lineSeparator || '') + asMediaQuery(ctx);
                    break;
            }
        }
        return result;
    }
    exports.default = debugInfo;
    
},
/* less/lib/less/contexts.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var contexts = {};
    exports.default = contexts;
    var Constants = tslib_1.__importStar(require(123) /* ./constants */);
    var copyFromOriginal = function copyFromOriginal(original, destination, propertiesToCopy) {
        if (!original) {
            return;
        }
        for (var i = 0; i < propertiesToCopy.length; i++) {
            if (original.hasOwnProperty(propertiesToCopy[i])) {
                destination[propertiesToCopy[i]] = original[propertiesToCopy[i]];
            }
        }
    };
    /*
     parse is used whilst parsing
     */
    var parseCopyProperties = [
        // options
        'paths',
        'rewriteUrls',
        'rootpath',
        'strictImports',
        'insecure',
        'dumpLineNumbers',
        'compress',
        'syncImport',
        'chunkInput',
        'mime',
        'useFileCache',
        // context
        'processImports',
        // Used by the import manager to stop multiple import visitors being created.
        'pluginManager' // Used as the plugin manager for the session
    ];
    contexts.Parse = function (options) {
        copyFromOriginal(options, this, parseCopyProperties);
        if (typeof this.paths === 'string') {
            this.paths = [this.paths];
        }
    };
    var evalCopyProperties = [
        'paths',
        'compress',
        'math',
        'strictUnits',
        'sourceMap',
        'importMultiple',
        'urlArgs',
        'javascriptEnabled',
        'pluginManager',
        'importantScope',
        'rewriteUrls' // option - whether to adjust URL's to be relative
    ];
    contexts.Eval = function (options, frames) {
        copyFromOriginal(options, this, evalCopyProperties);
        if (typeof this.paths === 'string') {
            this.paths = [this.paths];
        }
        this.frames = frames || [];
        this.importantScope = this.importantScope || [];
    };
    contexts.Eval.prototype.enterCalc = function () {
        if (!this.calcStack) {
            this.calcStack = [];
        }
        this.calcStack.push(true);
        this.inCalc = true;
    };
    contexts.Eval.prototype.exitCalc = function () {
        this.calcStack.pop();
        if (!this.calcStack.length) {
            this.inCalc = false;
        }
    };
    contexts.Eval.prototype.inParenthesis = function () {
        if (!this.parensStack) {
            this.parensStack = [];
        }
        this.parensStack.push(true);
    };
    contexts.Eval.prototype.outOfParenthesis = function () {
        this.parensStack.pop();
    };
    contexts.Eval.prototype.inCalc = false;
    contexts.Eval.prototype.mathOn = true;
    contexts.Eval.prototype.isMathOn = function (op) {
        if (!this.mathOn) {
            return false;
        }
        if (op === '/' && this.math !== Constants.Math.ALWAYS && (!this.parensStack || !this.parensStack.length)) {
            return false;
        }
        if (this.math > Constants.Math.PARENS_DIVISION) {
            return this.parensStack && this.parensStack.length;
        }
        return true;
    };
    contexts.Eval.prototype.pathRequiresRewrite = function (path) {
        var isRelative = this.rewriteUrls === Constants.RewriteUrls.LOCAL ? isPathLocalRelative : isPathRelative;
        return isRelative(path);
    };
    contexts.Eval.prototype.rewritePath = function (path, rootpath) {
        var newPath;
        rootpath = rootpath || '';
        newPath = this.normalizePath(rootpath + path);
        // If a path was explicit relative and the rootpath was not an absolute path
        // we must ensure that the new path is also explicit relative.
        if (isPathLocalRelative(path) &&
            isPathRelative(rootpath) &&
            isPathLocalRelative(newPath) === false) {
            newPath = "./" + newPath;
        }
        return newPath;
    };
    contexts.Eval.prototype.normalizePath = function (path) {
        var segments = path.split('/').reverse();
        var segment;
        path = [];
        while (segments.length !== 0) {
            segment = segments.pop();
            switch (segment) {
                case '.':
                    break;
                case '..':
                    if ((path.length === 0) || (path[path.length - 1] === '..')) {
                        path.push(segment);
                    }
                    else {
                        path.pop();
                    }
                    break;
                default:
                    path.push(segment);
                    break;
            }
        }
        return path.join('/');
    };
    function isPathRelative(path) {
        return !/^(?:[a-z-]+:|\/|#)/i.test(path);
    }
    function isPathLocalRelative(path) {
        return path.charAt(0) === '.';
    }
    // todo - do the same for the toCSS ?
    
},
/* less/lib/less/functions/function-registry.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function makeRegistry(base) {
        return {
            _data: {},
            add: function (name, func) {
                // precautionary case conversion, as later querying of
                // the registry by function-caller uses lower case as well.
                name = name.toLowerCase();
                if (this._data.hasOwnProperty(name)) {
                    // TODO warn
                }
                this._data[name] = func;
            },
            addMultiple: function (functions) {
                var _this = this;
                Object.keys(functions).forEach(function (name) {
                    _this.add(name, functions[name]);
                });
            },
            get: function (name) {
                return this._data[name] || (base && base.get(name));
            },
            getLocalFunctions: function () {
                return this._data;
            },
            inherit: function () {
                return makeRegistry(this);
            },
            create: function (base) {
                return makeRegistry(base);
            }
        };
    }
    exports.default = makeRegistry(null);
    
},
/* less/lib/less/functions/default.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var keyword_1 = tslib_1.__importDefault(require(129) /* ../tree/keyword */);
    var defaultFunc = {
        eval: function () {
            var v = this.value_;
            var e = this.error_;
            if (e) {
                throw e;
            }
            if (v != null) {
                return v ? keyword_1.default.True : keyword_1.default.False;
            }
        },
        value: function (v) {
            this.value_ = v;
        },
        error: function (e) {
            this.error_ = e;
        },
        reset: function () {
            this.value_ = this.error_ = null;
        }
    };
    exports.default = defaultFunc;
    
},
/* less/lib/less/tree/detached-ruleset.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var contexts_1 = tslib_1.__importDefault(require(133) /* ../contexts */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var DetachedRuleset = function (ruleset, frames) {
        this.ruleset = ruleset;
        this.frames = frames;
        this.setParent(this.ruleset, this);
    };
    DetachedRuleset.prototype = Object.assign(new node_1.default(), {
        type: 'DetachedRuleset',
        evalFirst: true,
        accept: function (visitor) {
            this.ruleset = visitor.visit(this.ruleset);
        },
        eval: function (context) {
            var frames = this.frames || utils.copyArray(context.frames);
            return new DetachedRuleset(this.ruleset, frames);
        },
        callEval: function (context) {
            return this.ruleset.eval(this.frames ? new contexts_1.default.Eval(context, this.frames.concat(context.frames)) : context);
        }
    });
    exports.default = DetachedRuleset;
    
},
/* less/lib/less/tree/operation.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var color_1 = tslib_1.__importDefault(require(115) /* ./color */);
    var dimension_1 = tslib_1.__importDefault(require(138) /* ./dimension */);
    var Constants = tslib_1.__importStar(require(123) /* ../constants */);
    var MATH = Constants.Math;
    var Operation = function (op, operands, isSpaced) {
        this.op = op.trim();
        this.operands = operands;
        this.isSpaced = isSpaced;
    };
    Operation.prototype = Object.assign(new node_1.default(), {
        type: 'Operation',
        accept: function (visitor) {
            this.operands = visitor.visitArray(this.operands);
        },
        eval: function (context) {
            var a = this.operands[0].eval(context), b = this.operands[1].eval(context), op;
            if (context.isMathOn(this.op)) {
                op = this.op === './' ? '/' : this.op;
                if (a instanceof dimension_1.default && b instanceof color_1.default) {
                    a = a.toColor();
                }
                if (b instanceof dimension_1.default && a instanceof color_1.default) {
                    b = b.toColor();
                }
                if (!a.operate || !b.operate) {
                    if ((a instanceof Operation || b instanceof Operation)
                        && a.op === '/' && context.math === MATH.PARENS_DIVISION) {
                        return new Operation(this.op, [a, b], this.isSpaced);
                    }
                    throw { type: 'Operation',
                        message: 'Operation on an invalid type' };
                }
                return a.operate(context, op, b);
            }
            else {
                return new Operation(this.op, [a, b], this.isSpaced);
            }
        },
        genCSS: function (context, output) {
            this.operands[0].genCSS(context, output);
            if (this.isSpaced) {
                output.add(' ');
            }
            output.add(this.op);
            if (this.isSpaced) {
                output.add(' ');
            }
            this.operands[1].genCSS(context, output);
        }
    });
    exports.default = Operation;
    
},
/* less/lib/less/tree/dimension.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var unit_conversions_1 = tslib_1.__importDefault(require(112) /* ../data/unit-conversions */);
    var unit_1 = tslib_1.__importDefault(require(139) /* ./unit */);
    var color_1 = tslib_1.__importDefault(require(115) /* ./color */);
    //
    // A number with a unit
    //
    var Dimension = function (value, unit) {
        this.value = parseFloat(value);
        if (isNaN(this.value)) {
            throw new Error('Dimension is not a number.');
        }
        this.unit = (unit && unit instanceof unit_1.default) ? unit :
            new unit_1.default(unit ? [unit] : undefined);
        this.setParent(this.unit, this);
    };
    Dimension.prototype = Object.assign(new node_1.default(), {
        type: 'Dimension',
        accept: function (visitor) {
            this.unit = visitor.visit(this.unit);
        },
        eval: function (context) {
            return this;
        },
        toColor: function () {
            return new color_1.default([this.value, this.value, this.value]);
        },
        genCSS: function (context, output) {
            if ((context && context.strictUnits) && !this.unit.isSingular()) {
                throw new Error("Multiple units in dimension. Correct the units or use the unit function. Bad unit: " + this.unit.toString());
            }
            var value = this.fround(context, this.value);
            var strValue = String(value);
            if (value !== 0 && value < 0.000001 && value > -0.000001) {
                // would be output 1e-6 etc.
                strValue = value.toFixed(20).replace(/0+$/, '');
            }
            if (context && context.compress) {
                // Zero values doesn't need a unit
                if (value === 0 && this.unit.isLength()) {
                    output.add(strValue);
                    return;
                }
                // Float values doesn't need a leading zero
                if (value > 0 && value < 1) {
                    strValue = (strValue).substr(1);
                }
            }
            output.add(strValue);
            this.unit.genCSS(context, output);
        },
        // In an operation between two Dimensions,
        // we default to the first Dimension's unit,
        // so `1px + 2` will yield `3px`.
        operate: function (context, op, other) {
            /* jshint noempty:false */
            var value = this._operate(context, op, this.value, other.value);
            var unit = this.unit.clone();
            if (op === '+' || op === '-') {
                if (unit.numerator.length === 0 && unit.denominator.length === 0) {
                    unit = other.unit.clone();
                    if (this.unit.backupUnit) {
                        unit.backupUnit = this.unit.backupUnit;
                    }
                }
                else if (other.unit.numerator.length === 0 && unit.denominator.length === 0) {
                    // do nothing
                }
                else {
                    other = other.convertTo(this.unit.usedUnits());
                    if (context.strictUnits && other.unit.toString() !== unit.toString()) {
                        throw new Error("Incompatible units. Change the units or use the unit function. "
                            + ("Bad units: '" + unit.toString() + "' and '" + other.unit.toString() + "'."));
                    }
                    value = this._operate(context, op, this.value, other.value);
                }
            }
            else if (op === '*') {
                unit.numerator = unit.numerator.concat(other.unit.numerator).sort();
                unit.denominator = unit.denominator.concat(other.unit.denominator).sort();
                unit.cancel();
            }
            else if (op === '/') {
                unit.numerator = unit.numerator.concat(other.unit.denominator).sort();
                unit.denominator = unit.denominator.concat(other.unit.numerator).sort();
                unit.cancel();
            }
            return new Dimension(value, unit);
        },
        compare: function (other) {
            var a, b;
            if (!(other instanceof Dimension)) {
                return undefined;
            }
            if (this.unit.isEmpty() || other.unit.isEmpty()) {
                a = this;
                b = other;
            }
            else {
                a = this.unify();
                b = other.unify();
                if (a.unit.compare(b.unit) !== 0) {
                    return undefined;
                }
            }
            return node_1.default.numericCompare(a.value, b.value);
        },
        unify: function () {
            return this.convertTo({ length: 'px', duration: 's', angle: 'rad' });
        },
        convertTo: function (conversions) {
            var value = this.value;
            var unit = this.unit.clone();
            var i;
            var groupName;
            var group;
            var targetUnit;
            var derivedConversions = {};
            var applyUnit;
            if (typeof conversions === 'string') {
                for (i in unit_conversions_1.default) {
                    if (unit_conversions_1.default[i].hasOwnProperty(conversions)) {
                        derivedConversions = {};
                        derivedConversions[i] = conversions;
                    }
                }
                conversions = derivedConversions;
            }
            applyUnit = function (atomicUnit, denominator) {
                /* jshint loopfunc:true */
                if (group.hasOwnProperty(atomicUnit)) {
                    if (denominator) {
                        value = value / (group[atomicUnit] / group[targetUnit]);
                    }
                    else {
                        value = value * (group[atomicUnit] / group[targetUnit]);
                    }
                    return targetUnit;
                }
                return atomicUnit;
            };
            for (groupName in conversions) {
                if (conversions.hasOwnProperty(groupName)) {
                    targetUnit = conversions[groupName];
                    group = unit_conversions_1.default[groupName];
                    unit.map(applyUnit);
                }
            }
            unit.cancel();
            return new Dimension(value, unit);
        }
    });
    exports.default = Dimension;
    
},
/* less/lib/less/tree/unit.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var unit_conversions_1 = tslib_1.__importDefault(require(112) /* ../data/unit-conversions */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var Unit = function (numerator, denominator, backupUnit) {
        this.numerator = numerator ? utils.copyArray(numerator).sort() : [];
        this.denominator = denominator ? utils.copyArray(denominator).sort() : [];
        if (backupUnit) {
            this.backupUnit = backupUnit;
        }
        else if (numerator && numerator.length) {
            this.backupUnit = numerator[0];
        }
    };
    Unit.prototype = Object.assign(new node_1.default(), {
        type: 'Unit',
        clone: function () {
            return new Unit(utils.copyArray(this.numerator), utils.copyArray(this.denominator), this.backupUnit);
        },
        genCSS: function (context, output) {
            // Dimension checks the unit is singular and throws an error if in strict math mode.
            var strictUnits = context && context.strictUnits;
            if (this.numerator.length === 1) {
                output.add(this.numerator[0]); // the ideal situation
            }
            else if (!strictUnits && this.backupUnit) {
                output.add(this.backupUnit);
            }
            else if (!strictUnits && this.denominator.length) {
                output.add(this.denominator[0]);
            }
        },
        toString: function () {
            var i, returnStr = this.numerator.join('*');
            for (i = 0; i < this.denominator.length; i++) {
                returnStr += "/" + this.denominator[i];
            }
            return returnStr;
        },
        compare: function (other) {
            return this.is(other.toString()) ? 0 : undefined;
        },
        is: function (unitString) {
            return this.toString().toUpperCase() === unitString.toUpperCase();
        },
        isLength: function () {
            return RegExp('^(px|em|ex|ch|rem|in|cm|mm|pc|pt|ex|vw|vh|vmin|vmax)$', 'gi').test(this.toCSS());
        },
        isEmpty: function () {
            return this.numerator.length === 0 && this.denominator.length === 0;
        },
        isSingular: function () {
            return this.numerator.length <= 1 && this.denominator.length === 0;
        },
        map: function (callback) {
            var i;
            for (i = 0; i < this.numerator.length; i++) {
                this.numerator[i] = callback(this.numerator[i], false);
            }
            for (i = 0; i < this.denominator.length; i++) {
                this.denominator[i] = callback(this.denominator[i], true);
            }
        },
        usedUnits: function () {
            var group;
            var result = {};
            var mapUnit;
            var groupName;
            mapUnit = function (atomicUnit) {
                /* jshint loopfunc:true */
                if (group.hasOwnProperty(atomicUnit) && !result[groupName]) {
                    result[groupName] = atomicUnit;
                }
                return atomicUnit;
            };
            for (groupName in unit_conversions_1.default) {
                if (unit_conversions_1.default.hasOwnProperty(groupName)) {
                    group = unit_conversions_1.default[groupName];
                    this.map(mapUnit);
                }
            }
            return result;
        },
        cancel: function () {
            var counter = {};
            var atomicUnit;
            var i;
            for (i = 0; i < this.numerator.length; i++) {
                atomicUnit = this.numerator[i];
                counter[atomicUnit] = (counter[atomicUnit] || 0) + 1;
            }
            for (i = 0; i < this.denominator.length; i++) {
                atomicUnit = this.denominator[i];
                counter[atomicUnit] = (counter[atomicUnit] || 0) - 1;
            }
            this.numerator = [];
            this.denominator = [];
            for (atomicUnit in counter) {
                if (counter.hasOwnProperty(atomicUnit)) {
                    var count = counter[atomicUnit];
                    if (count > 0) {
                        for (i = 0; i < count; i++) {
                            this.numerator.push(atomicUnit);
                        }
                    }
                    else if (count < 0) {
                        for (i = 0; i < -count; i++) {
                            this.denominator.push(atomicUnit);
                        }
                    }
                }
            }
            this.numerator.sort();
            this.denominator.sort();
        }
    });
    exports.default = Unit;
    
},
/* less/lib/less/tree/variable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var call_1 = tslib_1.__importDefault(require(141) /* ./call */);
    var Variable = function (name, index, currentFileInfo) {
        this.name = name;
        this._index = index;
        this._fileInfo = currentFileInfo;
    };
    Variable.prototype = Object.assign(new node_1.default(), {
        type: 'Variable',
        eval: function (context) {
            var variable, name = this.name;
            if (name.indexOf('@@') === 0) {
                name = "@" + new Variable(name.slice(1), this.getIndex(), this.fileInfo()).eval(context).value;
            }
            if (this.evaluating) {
                throw { type: 'Name',
                    message: "Recursive variable definition for " + name,
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            this.evaluating = true;
            variable = this.find(context.frames, function (frame) {
                var v = frame.variable(name);
                if (v) {
                    if (v.important) {
                        var importantScope = context.importantScope[context.importantScope.length - 1];
                        importantScope.important = v.important;
                    }
                    // If in calc, wrap vars in a function call to cascade evaluate args first
                    if (context.inCalc) {
                        return (new call_1.default('_SELF', [v.value])).eval(context);
                    }
                    else {
                        return v.value.eval(context);
                    }
                }
            });
            if (variable) {
                this.evaluating = false;
                return variable;
            }
            else {
                throw { type: 'Name',
                    message: "variable " + name + " is undefined",
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
        },
        find: function (obj, fun) {
            for (var i = 0, r = void 0; i < obj.length; i++) {
                r = fun.call(obj, obj[i]);
                if (r) {
                    return r;
                }
            }
            return null;
        }
    });
    exports.default = Variable;
    
},
/* less/lib/less/tree/call.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ./anonymous */);
    var function_caller_1 = tslib_1.__importDefault(require(142) /* ../functions/function-caller */);
    //
    // A function call node.
    //
    var Call = function (name, args, index, currentFileInfo) {
        this.name = name;
        this.args = args;
        this.calc = name === 'calc';
        this._index = index;
        this._fileInfo = currentFileInfo;
    };
    Call.prototype = Object.assign(new node_1.default(), {
        type: 'Call',
        accept: function (visitor) {
            if (this.args) {
                this.args = visitor.visitArray(this.args);
            }
        },
        //
        // When evaluating a function call,
        // we either find the function in the functionRegistry,
        // in which case we call it, passing the  evaluated arguments,
        // if this returns null or we cannot find the function, we
        // simply print it out as it appeared originally [2].
        //
        // The reason why we evaluate the arguments, is in the case where
        // we try to pass a variable to a function, like: `saturate(@color)`.
        // The function should receive the value, not the variable.
        //
        eval: function (context) {
            var _this = this;
            /**
             * Turn off math for calc(), and switch back on for evaluating nested functions
             */
            var currentMathContext = context.mathOn;
            context.mathOn = !this.calc;
            if (this.calc || context.inCalc) {
                context.enterCalc();
            }
            var exitCalc = function () {
                if (_this.calc || context.inCalc) {
                    context.exitCalc();
                }
                context.mathOn = currentMathContext;
            };
            var result;
            var funcCaller = new function_caller_1.default(this.name, context, this.getIndex(), this.fileInfo());
            if (funcCaller.isValid()) {
                try {
                    result = funcCaller.call(this.args);
                    exitCalc();
                }
                catch (e) {
                    if (e.hasOwnProperty('line') && e.hasOwnProperty('column')) {
                        throw e;
                    }
                    throw {
                        type: e.type || 'Runtime',
                        message: "Error evaluating function `" + this.name + "`" + (e.message ? ": " + e.message : ''),
                        index: this.getIndex(),
                        filename: this.fileInfo().filename,
                        line: e.lineNumber,
                        column: e.columnNumber
                    };
                }
            }
            if (result !== null && result !== undefined) {
                // Results that that are not nodes are cast as Anonymous nodes
                // Falsy values or booleans are returned as empty nodes
                if (!(result instanceof node_1.default)) {
                    if (!result || result === true) {
                        result = new anonymous_1.default(null);
                    }
                    else {
                        result = new anonymous_1.default(result.toString());
                    }
                }
                result._index = this._index;
                result._fileInfo = this._fileInfo;
                return result;
            }
            var args = this.args.map(function (a) { return a.eval(context); });
            exitCalc();
            return new Call(this.name, args, this.getIndex(), this.fileInfo());
        },
        genCSS: function (context, output) {
            output.add(this.name + "(", this.fileInfo(), this.getIndex());
            for (var i = 0; i < this.args.length; i++) {
                this.args[i].genCSS(context, output);
                if (i + 1 < this.args.length) {
                    output.add(', ');
                }
            }
            output.add(')');
        }
    });
    exports.default = Call;
    
},
/* less/lib/less/functions/function-caller.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var expression_1 = tslib_1.__importDefault(require(143) /* ../tree/expression */);
    var functionCaller = /** @class */ (function () {
        function functionCaller(name, context, index, currentFileInfo) {
            this.name = name.toLowerCase();
            this.index = index;
            this.context = context;
            this.currentFileInfo = currentFileInfo;
            this.func = context.frames[0].functionRegistry.get(this.name);
        }
        functionCaller.prototype.isValid = function () {
            return Boolean(this.func);
        };
        functionCaller.prototype.call = function (args) {
            var _this = this;
            if (!(Array.isArray(args))) {
                args = [args];
            }
            var evalArgs = this.func.evalArgs;
            if (evalArgs !== false) {
                args = args.map(function (a) { return a.eval(_this.context); });
            }
            var commentFilter = function (item) { return !(item.type === 'Comment'); };
            // This code is terrible and should be replaced as per this issue...
            // https://github.com/less/less.js/issues/2477
            args = args
                .filter(commentFilter)
                .map(function (item) {
                if (item.type === 'Expression') {
                    var subNodes = item.value.filter(commentFilter);
                    if (subNodes.length === 1) {
                        // https://github.com/less/less.js/issues/3616
                        if (item.parens && subNodes[0].op === '/') {
                            return item;
                        }
                        return subNodes[0];
                    }
                    else {
                        return new expression_1.default(subNodes);
                    }
                }
                return item;
            });
            if (evalArgs === false) {
                return this.func.apply(this, tslib_1.__spreadArray([this.context], args));
            }
            return this.func.apply(this, args);
        };
        return functionCaller;
    }());
    exports.default = functionCaller;
    
},
/* less/lib/less/tree/expression.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var paren_1 = tslib_1.__importDefault(require(119) /* ./paren */);
    var comment_1 = tslib_1.__importDefault(require(131) /* ./comment */);
    var dimension_1 = tslib_1.__importDefault(require(138) /* ./dimension */);
    var Expression = function (value, noSpacing) {
        this.value = value;
        this.noSpacing = noSpacing;
        if (!value) {
            throw new Error('Expression requires an array parameter');
        }
    };
    Expression.prototype = Object.assign(new node_1.default(), {
        type: 'Expression',
        accept: function (visitor) {
            this.value = visitor.visitArray(this.value);
        },
        eval: function (context) {
            var returnValue;
            var mathOn = context.isMathOn();
            var inParenthesis = this.parens;
            var doubleParen = false;
            if (inParenthesis) {
                context.inParenthesis();
            }
            if (this.value.length > 1) {
                returnValue = new Expression(this.value.map(function (e) {
                    if (!e.eval) {
                        return e;
                    }
                    return e.eval(context);
                }), this.noSpacing);
            }
            else if (this.value.length === 1) {
                if (this.value[0].parens && !this.value[0].parensInOp && !context.inCalc) {
                    doubleParen = true;
                }
                returnValue = this.value[0].eval(context);
            }
            else {
                returnValue = this;
            }
            if (inParenthesis) {
                context.outOfParenthesis();
            }
            if (this.parens && this.parensInOp && !mathOn && !doubleParen
                && (!(returnValue instanceof dimension_1.default))) {
                returnValue = new paren_1.default(returnValue);
            }
            return returnValue;
        },
        genCSS: function (context, output) {
            for (var i = 0; i < this.value.length; i++) {
                this.value[i].genCSS(context, output);
                if (!this.noSpacing && i + 1 < this.value.length) {
                    output.add(' ');
                }
            }
        },
        throwAwayComments: function () {
            this.value = this.value.filter(function (v) {
                return !(v instanceof comment_1.default);
            });
        }
    });
    exports.default = Expression;
    
},
/* less/lib/less/tree/property.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var declaration_1 = tslib_1.__importDefault(require(127) /* ./declaration */);
    var Property = function (name, index, currentFileInfo) {
        this.name = name;
        this._index = index;
        this._fileInfo = currentFileInfo;
    };
    Property.prototype = Object.assign(new node_1.default(), {
        type: 'Property',
        eval: function (context) {
            var property;
            var name = this.name;
            // TODO: shorten this reference
            var mergeRules = context.pluginManager.less.visitors.ToCSSVisitor.prototype._mergeRules;
            if (this.evaluating) {
                throw { type: 'Name',
                    message: "Recursive property reference for " + name,
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            this.evaluating = true;
            property = this.find(context.frames, function (frame) {
                var v;
                var vArr = frame.property(name);
                if (vArr) {
                    for (var i = 0; i < vArr.length; i++) {
                        v = vArr[i];
                        vArr[i] = new declaration_1.default(v.name, v.value, v.important, v.merge, v.index, v.currentFileInfo, v.inline, v.variable);
                    }
                    mergeRules(vArr);
                    v = vArr[vArr.length - 1];
                    if (v.important) {
                        var importantScope = context.importantScope[context.importantScope.length - 1];
                        importantScope.important = v.important;
                    }
                    v = v.value.eval(context);
                    return v;
                }
            });
            if (property) {
                this.evaluating = false;
                return property;
            }
            else {
                throw { type: 'Name',
                    message: "Property '" + name + "' is undefined",
                    filename: this.currentFileInfo.filename,
                    index: this.index };
            }
        },
        find: function (obj, fun) {
            for (var i = 0, r = void 0; i < obj.length; i++) {
                r = fun.call(obj, obj[i]);
                if (r) {
                    return r;
                }
            }
            return null;
        }
    });
    exports.default = Property;
    
},
/* less/lib/less/tree/attribute.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Attribute = function (key, op, value, cif) {
        this.key = key;
        this.op = op;
        this.value = value;
        this.cif = cif;
    };
    Attribute.prototype = Object.assign(new node_1.default(), {
        type: 'Attribute',
        eval: function (context) {
            return new Attribute(this.key.eval ? this.key.eval(context) : this.key, this.op, (this.value && this.value.eval) ? this.value.eval(context) : this.value, this.cif);
        },
        genCSS: function (context, output) {
            output.add(this.toCSS(context));
        },
        toCSS: function (context) {
            var value = this.key.toCSS ? this.key.toCSS(context) : this.key;
            if (this.op) {
                value += this.op;
                value += (this.value.toCSS ? this.value.toCSS(context) : this.value);
            }
            if (this.cif) {
                value = value + " " + this.cif;
            }
            return "[" + value + "]";
        }
    });
    exports.default = Attribute;
    
},
/* less/lib/less/tree/quoted.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var variable_1 = tslib_1.__importDefault(require(140) /* ./variable */);
    var property_1 = tslib_1.__importDefault(require(144) /* ./property */);
    var Quoted = function (str, content, escaped, index, currentFileInfo) {
        this.escaped = (escaped == null) ? true : escaped;
        this.value = content || '';
        this.quote = str.charAt(0);
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.variableRegex = /@\{([\w-]+)\}/g;
        this.propRegex = /\$\{([\w-]+)\}/g;
        this.allowRoot = escaped;
    };
    Quoted.prototype = Object.assign(new node_1.default(), {
        type: 'Quoted',
        genCSS: function (context, output) {
            if (!this.escaped) {
                output.add(this.quote, this.fileInfo(), this.getIndex());
            }
            output.add(this.value);
            if (!this.escaped) {
                output.add(this.quote);
            }
        },
        containsVariables: function () {
            return this.value.match(this.variableRegex);
        },
        eval: function (context) {
            var that = this;
            var value = this.value;
            var variableReplacement = function (_, name) {
                var v = new variable_1.default("@" + name, that.getIndex(), that.fileInfo()).eval(context, true);
                return (v instanceof Quoted) ? v.value : v.toCSS();
            };
            var propertyReplacement = function (_, name) {
                var v = new property_1.default("$" + name, that.getIndex(), that.fileInfo()).eval(context, true);
                return (v instanceof Quoted) ? v.value : v.toCSS();
            };
            function iterativeReplace(value, regexp, replacementFnc) {
                var evaluatedValue = value;
                do {
                    value = evaluatedValue.toString();
                    evaluatedValue = value.replace(regexp, replacementFnc);
                } while (value !== evaluatedValue);
                return evaluatedValue;
            }
            value = iterativeReplace(value, this.variableRegex, variableReplacement);
            value = iterativeReplace(value, this.propRegex, propertyReplacement);
            return new Quoted(this.quote + value + this.quote, value, this.escaped, this.getIndex(), this.fileInfo());
        },
        compare: function (other) {
            // when comparing quoted strings allow the quote to differ
            if (other.type === 'Quoted' && !this.escaped && !other.escaped) {
                return node_1.default.numericCompare(this.value, other.value);
            }
            else {
                return other.toCSS && this.toCSS() === other.toCSS() ? 0 : undefined;
            }
        }
    });
    exports.default = Quoted;
    
},
/* less/lib/less/tree/url.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    function escapePath(path) {
        return path.replace(/[\(\)'"\s]/g, function (match) { return "\\" + match; });
    }
    var URL = function (val, index, currentFileInfo, isEvald) {
        this.value = val;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.isEvald = isEvald;
    };
    URL.prototype = Object.assign(new node_1.default(), {
        type: 'Url',
        accept: function (visitor) {
            this.value = visitor.visit(this.value);
        },
        genCSS: function (context, output) {
            output.add('url(');
            this.value.genCSS(context, output);
            output.add(')');
        },
        eval: function (context) {
            var val = this.value.eval(context);
            var rootpath;
            if (!this.isEvald) {
                // Add the rootpath if the URL requires a rewrite
                rootpath = this.fileInfo() && this.fileInfo().rootpath;
                if (typeof rootpath === 'string' &&
                    typeof val.value === 'string' &&
                    context.pathRequiresRewrite(val.value)) {
                    if (!val.quote) {
                        rootpath = escapePath(rootpath);
                    }
                    val.value = context.rewritePath(val.value, rootpath);
                }
                else {
                    val.value = context.normalizePath(val.value);
                }
                // Add url args if enabled
                if (context.urlArgs) {
                    if (!val.value.match(/^\s*data:/)) {
                        var delimiter = val.value.indexOf('?') === -1 ? '?' : '&';
                        var urlArgs = delimiter + context.urlArgs;
                        if (val.value.indexOf('#') !== -1) {
                            val.value = val.value.replace('#', urlArgs + "#");
                        }
                        else {
                            val.value += urlArgs;
                        }
                    }
                }
            }
            return new URL(val, this.getIndex(), this.fileInfo(), true);
        }
    });
    exports.default = URL;
    
},
/* less/lib/less/tree/import.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var media_1 = tslib_1.__importDefault(require(149) /* ./media */);
    var url_1 = tslib_1.__importDefault(require(147) /* ./url */);
    var quoted_1 = tslib_1.__importDefault(require(146) /* ./quoted */);
    var ruleset_1 = tslib_1.__importDefault(require(126) /* ./ruleset */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ./anonymous */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    //
    // CSS @import node
    //
    // The general strategy here is that we don't want to wait
    // for the parsing to be completed, before we start importing
    // the file. That's because in the context of a browser,
    // most of the time will be spent waiting for the server to respond.
    //
    // On creation, we push the import path to our import queue, though
    // `import,push`, we also pass it a callback, which it'll call once
    // the file has been fetched, and parsed.
    //
    var Import = function (path, features, options, index, currentFileInfo, visibilityInfo) {
        this.options = options;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.path = path;
        this.features = features;
        this.allowRoot = true;
        if (this.options.less !== undefined || this.options.inline) {
            this.css = !this.options.less || this.options.inline;
        }
        else {
            var pathValue = this.getPath();
            if (pathValue && /[#\.\&\?]css([\?;].*)?$/.test(pathValue)) {
                this.css = true;
            }
        }
        this.copyVisibilityInfo(visibilityInfo);
        this.setParent(this.features, this);
        this.setParent(this.path, this);
    };
    Import.prototype = Object.assign(new node_1.default(), {
        type: 'Import',
        accept: function (visitor) {
            if (this.features) {
                this.features = visitor.visit(this.features);
            }
            this.path = visitor.visit(this.path);
            if (!this.options.isPlugin && !this.options.inline && this.root) {
                this.root = visitor.visit(this.root);
            }
        },
        genCSS: function (context, output) {
            if (this.css && this.path._fileInfo.reference === undefined) {
                output.add('@import ', this._fileInfo, this._index);
                this.path.genCSS(context, output);
                if (this.features) {
                    output.add(' ');
                    this.features.genCSS(context, output);
                }
                output.add(';');
            }
        },
        getPath: function () {
            return (this.path instanceof url_1.default) ?
                this.path.value.value : this.path.value;
        },
        isVariableImport: function () {
            var path = this.path;
            if (path instanceof url_1.default) {
                path = path.value;
            }
            if (path instanceof quoted_1.default) {
                return path.containsVariables();
            }
            return true;
        },
        evalForImport: function (context) {
            var path = this.path;
            if (path instanceof url_1.default) {
                path = path.value;
            }
            return new Import(path.eval(context), this.features, this.options, this._index, this._fileInfo, this.visibilityInfo());
        },
        evalPath: function (context) {
            var path = this.path.eval(context);
            var fileInfo = this._fileInfo;
            if (!(path instanceof url_1.default)) {
                // Add the rootpath if the URL requires a rewrite
                var pathValue = path.value;
                if (fileInfo &&
                    pathValue &&
                    context.pathRequiresRewrite(pathValue)) {
                    path.value = context.rewritePath(pathValue, fileInfo.rootpath);
                }
                else {
                    path.value = context.normalizePath(path.value);
                }
            }
            return path;
        },
        eval: function (context) {
            var result = this.doEval(context);
            if (this.options.reference || this.blocksVisibility()) {
                if (result.length || result.length === 0) {
                    result.forEach(function (node) {
                        node.addVisibilityBlock();
                    });
                }
                else {
                    result.addVisibilityBlock();
                }
            }
            return result;
        },
        doEval: function (context) {
            var ruleset;
            var registry;
            var features = this.features && this.features.eval(context);
            if (this.options.isPlugin) {
                if (this.root && this.root.eval) {
                    try {
                        this.root.eval(context);
                    }
                    catch (e) {
                        e.message = 'Plugin error during evaluation';
                        throw new less_error_1.default(e, this.root.imports, this.root.filename);
                    }
                }
                registry = context.frames[0] && context.frames[0].functionRegistry;
                if (registry && this.root && this.root.functions) {
                    registry.addMultiple(this.root.functions);
                }
                return [];
            }
            if (this.skip) {
                if (typeof this.skip === 'function') {
                    this.skip = this.skip();
                }
                if (this.skip) {
                    return [];
                }
            }
            if (this.options.inline) {
                var contents = new anonymous_1.default(this.root, 0, {
                    filename: this.importedFilename,
                    reference: this.path._fileInfo && this.path._fileInfo.reference
                }, true, true);
                return this.features ? new media_1.default([contents], this.features.value) : [contents];
            }
            else if (this.css) {
                var newImport = new Import(this.evalPath(context), features, this.options, this._index);
                if (!newImport.css && this.error) {
                    throw this.error;
                }
                return newImport;
            }
            else if (this.root) {
                ruleset = new ruleset_1.default(null, utils.copyArray(this.root.rules));
                ruleset.evalImports(context);
                return this.features ? new media_1.default(ruleset.rules, this.features.value) : ruleset.rules;
            }
            else {
                return [];
            }
        }
    });
    exports.default = Import;
    
},
/* less/lib/less/tree/media.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var ruleset_1 = tslib_1.__importDefault(require(126) /* ./ruleset */);
    var value_1 = tslib_1.__importDefault(require(128) /* ./value */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ./anonymous */);
    var expression_1 = tslib_1.__importDefault(require(143) /* ./expression */);
    var atrule_1 = tslib_1.__importDefault(require(116) /* ./atrule */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var Media = function (value, features, index, currentFileInfo, visibilityInfo) {
        this._index = index;
        this._fileInfo = currentFileInfo;
        var selectors = (new selector_1.default([], null, null, this._index, this._fileInfo)).createEmptySelectors();
        this.features = new value_1.default(features);
        this.rules = [new ruleset_1.default(selectors, value)];
        this.rules[0].allowImports = true;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
        this.setParent(selectors, this);
        this.setParent(this.features, this);
        this.setParent(this.rules, this);
    };
    Media.prototype = Object.assign(new atrule_1.default(), {
        type: 'Media',
        isRulesetLike: function () {
            return true;
        },
        accept: function (visitor) {
            if (this.features) {
                this.features = visitor.visit(this.features);
            }
            if (this.rules) {
                this.rules = visitor.visitArray(this.rules);
            }
        },
        genCSS: function (context, output) {
            output.add('@media ', this._fileInfo, this._index);
            this.features.genCSS(context, output);
            this.outputRuleset(context, output, this.rules);
        },
        eval: function (context) {
            if (!context.mediaBlocks) {
                context.mediaBlocks = [];
                context.mediaPath = [];
            }
            var media = new Media(null, [], this._index, this._fileInfo, this.visibilityInfo());
            if (this.debugInfo) {
                this.rules[0].debugInfo = this.debugInfo;
                media.debugInfo = this.debugInfo;
            }
            media.features = this.features.eval(context);
            context.mediaPath.push(media);
            context.mediaBlocks.push(media);
            this.rules[0].functionRegistry = context.frames[0].functionRegistry.inherit();
            context.frames.unshift(this.rules[0]);
            media.rules = [this.rules[0].eval(context)];
            context.frames.shift();
            context.mediaPath.pop();
            return context.mediaPath.length === 0 ? media.evalTop(context) :
                media.evalNested(context);
        },
        evalTop: function (context) {
            var result = this;
            // Render all dependent Media blocks.
            if (context.mediaBlocks.length > 1) {
                var selectors = (new selector_1.default([], null, null, this.getIndex(), this.fileInfo())).createEmptySelectors();
                result = new ruleset_1.default(selectors, context.mediaBlocks);
                result.multiMedia = true;
                result.copyVisibilityInfo(this.visibilityInfo());
                this.setParent(result, this);
            }
            delete context.mediaBlocks;
            delete context.mediaPath;
            return result;
        },
        evalNested: function (context) {
            var i;
            var value;
            var path = context.mediaPath.concat([this]);
            // Extract the media-query conditions separated with `,` (OR).
            for (i = 0; i < path.length; i++) {
                value = path[i].features instanceof value_1.default ?
                    path[i].features.value : path[i].features;
                path[i] = Array.isArray(value) ? value : [value];
            }
            // Trace all permutations to generate the resulting media-query.
            //
            // (a, b and c) with nested (d, e) ->
            //    a and d
            //    a and e
            //    b and c and d
            //    b and c and e
            this.features = new value_1.default(this.permute(path).map(function (path) {
                path = path.map(function (fragment) { return fragment.toCSS ? fragment : new anonymous_1.default(fragment); });
                for (i = path.length - 1; i > 0; i--) {
                    path.splice(i, 0, new anonymous_1.default('and'));
                }
                return new expression_1.default(path);
            }));
            this.setParent(this.features, this);
            // Fake a tree-node that doesn't output anything.
            return new ruleset_1.default([], []);
        },
        permute: function (arr) {
            if (arr.length === 0) {
                return [];
            }
            else if (arr.length === 1) {
                return arr[0];
            }
            else {
                var result = [];
                var rest = this.permute(arr.slice(1));
                for (var i = 0; i < rest.length; i++) {
                    for (var j = 0; j < arr[0].length; j++) {
                        result.push([arr[0][j]].concat(rest[i]));
                    }
                }
                return result;
            }
        },
        bubbleSelectors: function (selectors) {
            if (!selectors) {
                return;
            }
            this.rules = [new ruleset_1.default(utils.copyArray(selectors), [this.rules[0]])];
            this.setParent(this.rules, this);
        }
    });
    exports.default = Media;
    
},
/* less/lib/less/tree/javascript.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var js_eval_node_1 = tslib_1.__importDefault(require(151) /* ./js-eval-node */);
    var dimension_1 = tslib_1.__importDefault(require(138) /* ./dimension */);
    var quoted_1 = tslib_1.__importDefault(require(146) /* ./quoted */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ./anonymous */);
    var JavaScript = function (string, escaped, index, currentFileInfo) {
        this.escaped = escaped;
        this.expression = string;
        this._index = index;
        this._fileInfo = currentFileInfo;
    };
    JavaScript.prototype = Object.assign(new js_eval_node_1.default(), {
        type: 'JavaScript',
        eval: function (context) {
            var result = this.evaluateJavaScript(this.expression, context);
            var type = typeof result;
            if (type === 'number' && !isNaN(result)) {
                return new dimension_1.default(result);
            }
            else if (type === 'string') {
                return new quoted_1.default("\"" + result + "\"", result, this.escaped, this._index);
            }
            else if (Array.isArray(result)) {
                return new anonymous_1.default(result.join(', '));
            }
            else {
                return new anonymous_1.default(result);
            }
        }
    });
    exports.default = JavaScript;
    
},
/* less/lib/less/tree/js-eval-node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var variable_1 = tslib_1.__importDefault(require(140) /* ./variable */);
    var JsEvalNode = function () { };
    JsEvalNode.prototype = Object.assign(new node_1.default(), {
        evaluateJavaScript: function (expression, context) {
            var result;
            var that = this;
            var evalContext = {};
            if (!context.javascriptEnabled) {
                throw { message: 'Inline JavaScript is not enabled. Is it set in your options?',
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            expression = expression.replace(/@\{([\w-]+)\}/g, function (_, name) {
                return that.jsify(new variable_1.default("@" + name, that.getIndex(), that.fileInfo()).eval(context));
            });
            try {
                expression = new Function("return (" + expression + ")");
            }
            catch (e) {
                throw { message: "JavaScript evaluation error: " + e.message + " from `" + expression + "`",
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            var variables = context.frames[0].variables();
            for (var k in variables) {
                if (variables.hasOwnProperty(k)) {
                    /* jshint loopfunc:true */
                    evalContext[k.slice(1)] = {
                        value: variables[k].value,
                        toJS: function () {
                            return this.value.eval(context).toCSS();
                        }
                    };
                }
            }
            try {
                result = expression.call(evalContext);
            }
            catch (e) {
                throw { message: "JavaScript evaluation error: '" + e.name + ": " + e.message.replace(/["]/g, '\'') + "'",
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            return result;
        },
        jsify: function (obj) {
            if (Array.isArray(obj.value) && (obj.value.length > 1)) {
                return "[" + obj.value.map(function (v) { return v.toCSS(); }).join(', ') + "]";
            }
            else {
                return obj.toCSS();
            }
        }
    });
    exports.default = JsEvalNode;
    
},
/* less/lib/less/tree/assignment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Assignment = function (key, val) {
        this.key = key;
        this.value = val;
    };
    Assignment.prototype = Object.assign(new node_1.default(), {
        type: 'Assignment',
        accept: function (visitor) {
            this.value = visitor.visit(this.value);
        },
        eval: function (context) {
            if (this.value.eval) {
                return new Assignment(this.key, this.value.eval(context));
            }
            return this;
        },
        genCSS: function (context, output) {
            output.add(this.key + "=");
            if (this.value.genCSS) {
                this.value.genCSS(context, output);
            }
            else {
                output.add(this.value);
            }
        }
    });
    exports.default = Assignment;
    
},
/* less/lib/less/tree/condition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Condition = function (op, l, r, i, negate) {
        this.op = op.trim();
        this.lvalue = l;
        this.rvalue = r;
        this._index = i;
        this.negate = negate;
    };
    Condition.prototype = Object.assign(new node_1.default(), {
        type: 'Condition',
        accept: function (visitor) {
            this.lvalue = visitor.visit(this.lvalue);
            this.rvalue = visitor.visit(this.rvalue);
        },
        eval: function (context) {
            var result = (function (op, a, b) {
                switch (op) {
                    case 'and': return a && b;
                    case 'or': return a || b;
                    default:
                        switch (node_1.default.compare(a, b)) {
                            case -1:
                                return op === '<' || op === '=<' || op === '<=';
                            case 0:
                                return op === '=' || op === '>=' || op === '=<' || op === '<=';
                            case 1:
                                return op === '>' || op === '>=';
                            default:
                                return false;
                        }
                }
            })(this.op, this.lvalue.eval(context), this.rvalue.eval(context));
            return this.negate ? !result : result;
        }
    });
    exports.default = Condition;
    
},
/* less/lib/less/tree/unicode-descriptor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var UnicodeDescriptor = function (value) {
        this.value = value;
    };
    UnicodeDescriptor.prototype = Object.assign(new node_1.default(), {
        type: 'UnicodeDescriptor'
    });
    exports.default = UnicodeDescriptor;
    
},
/* less/lib/less/tree/negative.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var operation_1 = tslib_1.__importDefault(require(137) /* ./operation */);
    var dimension_1 = tslib_1.__importDefault(require(138) /* ./dimension */);
    var Negative = function (node) {
        this.value = node;
    };
    Negative.prototype = Object.assign(new node_1.default(), {
        type: 'Negative',
        genCSS: function (context, output) {
            output.add('-');
            this.value.genCSS(context, output);
        },
        eval: function (context) {
            if (context.isMathOn()) {
                return (new operation_1.default('*', [new dimension_1.default(-1), this.value])).eval(context);
            }
            return new Negative(this.value.eval(context));
        }
    });
    exports.default = Negative;
    
},
/* less/lib/less/tree/extend.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var Extend = function (selector, option, index, currentFileInfo, visibilityInfo) {
        this.selector = selector;
        this.option = option;
        this.object_id = Extend.next_id++;
        this.parent_ids = [this.object_id];
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
        switch (option) {
            case 'all':
                this.allowBefore = true;
                this.allowAfter = true;
                break;
            default:
                this.allowBefore = false;
                this.allowAfter = false;
                break;
        }
        this.setParent(this.selector, this);
    };
    Extend.prototype = Object.assign(new node_1.default(), {
        type: 'Extend',
        accept: function (visitor) {
            this.selector = visitor.visit(this.selector);
        },
        eval: function (context) {
            return new Extend(this.selector.eval(context), this.option, this.getIndex(), this.fileInfo(), this.visibilityInfo());
        },
        clone: function (context) {
            return new Extend(this.selector, this.option, this.getIndex(), this.fileInfo(), this.visibilityInfo());
        },
        // it concatenates (joins) all selectors in selector array
        findSelfSelectors: function (selectors) {
            var selfElements = [], i, selectorElements;
            for (i = 0; i < selectors.length; i++) {
                selectorElements = selectors[i].elements;
                // duplicate the logic in genCSS function inside the selector node.
                // future TODO - move both logics into the selector joiner visitor
                if (i > 0 && selectorElements.length && selectorElements[0].combinator.value === '') {
                    selectorElements[0].combinator.value = ' ';
                }
                selfElements = selfElements.concat(selectors[i].elements);
            }
            this.selfSelectors = [new selector_1.default(selfElements)];
            this.selfSelectors[0].copyVisibilityInfo(this.visibilityInfo());
        }
    });
    Extend.next_id = 0;
    exports.default = Extend;
    
},
/* less/lib/less/tree/variable-call.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var variable_1 = tslib_1.__importDefault(require(140) /* ./variable */);
    var ruleset_1 = tslib_1.__importDefault(require(126) /* ./ruleset */);
    var detached_ruleset_1 = tslib_1.__importDefault(require(136) /* ./detached-ruleset */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    var VariableCall = function (variable, index, currentFileInfo) {
        this.variable = variable;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.allowRoot = true;
    };
    VariableCall.prototype = Object.assign(new node_1.default(), {
        type: 'VariableCall',
        eval: function (context) {
            var rules;
            var detachedRuleset = new variable_1.default(this.variable, this.getIndex(), this.fileInfo()).eval(context);
            var error = new less_error_1.default({ message: "Could not evaluate variable call " + this.variable });
            if (!detachedRuleset.ruleset) {
                if (detachedRuleset.rules) {
                    rules = detachedRuleset;
                }
                else if (Array.isArray(detachedRuleset)) {
                    rules = new ruleset_1.default('', detachedRuleset);
                }
                else if (Array.isArray(detachedRuleset.value)) {
                    rules = new ruleset_1.default('', detachedRuleset.value);
                }
                else {
                    throw error;
                }
                detachedRuleset = new detached_ruleset_1.default(rules);
            }
            if (detachedRuleset.ruleset) {
                return detachedRuleset.callEval(context);
            }
            throw error;
        }
    });
    exports.default = VariableCall;
    
},
/* less/lib/less/tree/namespace-value.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var variable_1 = tslib_1.__importDefault(require(140) /* ./variable */);
    var ruleset_1 = tslib_1.__importDefault(require(126) /* ./ruleset */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var NamespaceValue = function (ruleCall, lookups, index, fileInfo) {
        this.value = ruleCall;
        this.lookups = lookups;
        this._index = index;
        this._fileInfo = fileInfo;
    };
    NamespaceValue.prototype = Object.assign(new node_1.default(), {
        type: 'NamespaceValue',
        eval: function (context) {
            var i, j, name, rules = this.value.eval(context);
            for (i = 0; i < this.lookups.length; i++) {
                name = this.lookups[i];
                /**
                 * Eval'd DRs return rulesets.
                 * Eval'd mixins return rules, so let's make a ruleset if we need it.
                 * We need to do this because of late parsing of values
                 */
                if (Array.isArray(rules)) {
                    rules = new ruleset_1.default([new selector_1.default()], rules);
                }
                if (name === '') {
                    rules = rules.lastDeclaration();
                }
                else if (name.charAt(0) === '@') {
                    if (name.charAt(1) === '@') {
                        name = "@" + new variable_1.default(name.substr(1)).eval(context).value;
                    }
                    if (rules.variables) {
                        rules = rules.variable(name);
                    }
                    if (!rules) {
                        throw { type: 'Name',
                            message: "variable " + name + " not found",
                            filename: this.fileInfo().filename,
                            index: this.getIndex() };
                    }
                }
                else {
                    if (name.substring(0, 2) === '$@') {
                        name = "$" + new variable_1.default(name.substr(1)).eval(context).value;
                    }
                    else {
                        name = name.charAt(0) === '$' ? name : "$" + name;
                    }
                    if (rules.properties) {
                        rules = rules.property(name);
                    }
                    if (!rules) {
                        throw { type: 'Name',
                            message: "property \"" + name.substr(1) + "\" not found",
                            filename: this.fileInfo().filename,
                            index: this.getIndex() };
                    }
                    // Properties are an array of values, since a ruleset can have multiple props.
                    // We pick the last one (the "cascaded" value)
                    rules = rules[rules.length - 1];
                }
                if (rules.value) {
                    rules = rules.eval(context).value;
                }
                if (rules.ruleset) {
                    rules = rules.ruleset.eval(context);
                }
            }
            return rules;
        }
    });
    exports.default = NamespaceValue;
    
},
/* less/lib/less/tree/mixin-call.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var mixin_definition_1 = tslib_1.__importDefault(require(160) /* ./mixin-definition */);
    var default_1 = tslib_1.__importDefault(require(135) /* ../functions/default */);
    var MixinCall = function (elements, args, index, currentFileInfo, important) {
        this.selector = new selector_1.default(elements);
        this.arguments = args || [];
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.important = important;
        this.allowRoot = true;
        this.setParent(this.selector, this);
    };
    MixinCall.prototype = Object.assign(new node_1.default(), {
        type: 'MixinCall',
        accept: function (visitor) {
            if (this.selector) {
                this.selector = visitor.visit(this.selector);
            }
            if (this.arguments.length) {
                this.arguments = visitor.visitArray(this.arguments);
            }
        },
        eval: function (context) {
            var mixins;
            var mixin;
            var mixinPath;
            var args = [];
            var arg;
            var argValue;
            var rules = [];
            var match = false;
            var i;
            var m;
            var f;
            var isRecursive;
            var isOneFound;
            var candidates = [];
            var candidate;
            var conditionResult = [];
            var defaultResult;
            var defFalseEitherCase = -1;
            var defNone = 0;
            var defTrue = 1;
            var defFalse = 2;
            var count;
            var originalRuleset;
            var noArgumentsFilter;
            this.selector = this.selector.eval(context);
            function calcDefGroup(mixin, mixinPath) {
                var f, p, namespace;
                for (f = 0; f < 2; f++) {
                    conditionResult[f] = true;
                    default_1.default.value(f);
                    for (p = 0; p < mixinPath.length && conditionResult[f]; p++) {
                        namespace = mixinPath[p];
                        if (namespace.matchCondition) {
                            conditionResult[f] = conditionResult[f] && namespace.matchCondition(null, context);
                        }
                    }
                    if (mixin.matchCondition) {
                        conditionResult[f] = conditionResult[f] && mixin.matchCondition(args, context);
                    }
                }
                if (conditionResult[0] || conditionResult[1]) {
                    if (conditionResult[0] != conditionResult[1]) {
                        return conditionResult[1] ?
                            defTrue : defFalse;
                    }
                    return defNone;
                }
                return defFalseEitherCase;
            }
            for (i = 0; i < this.arguments.length; i++) {
                arg = this.arguments[i];
                argValue = arg.value.eval(context);
                if (arg.expand && Array.isArray(argValue.value)) {
                    argValue = argValue.value;
                    for (m = 0; m < argValue.length; m++) {
                        args.push({ value: argValue[m] });
                    }
                }
                else {
                    args.push({ name: arg.name, value: argValue });
                }
            }
            noArgumentsFilter = function (rule) { return rule.matchArgs(null, context); };
            for (i = 0; i < context.frames.length; i++) {
                if ((mixins = context.frames[i].find(this.selector, null, noArgumentsFilter)).length > 0) {
                    isOneFound = true;
                    // To make `default()` function independent of definition order we have two "subpasses" here.
                    // At first we evaluate each guard *twice* (with `default() == true` and `default() == false`),
                    // and build candidate list with corresponding flags. Then, when we know all possible matches,
                    // we make a final decision.
                    for (m = 0; m < mixins.length; m++) {
                        mixin = mixins[m].rule;
                        mixinPath = mixins[m].path;
                        isRecursive = false;
                        for (f = 0; f < context.frames.length; f++) {
                            if ((!(mixin instanceof mixin_definition_1.default)) && mixin === (context.frames[f].originalRuleset || context.frames[f])) {
                                isRecursive = true;
                                break;
                            }
                        }
                        if (isRecursive) {
                            continue;
                        }
                        if (mixin.matchArgs(args, context)) {
                            candidate = { mixin: mixin, group: calcDefGroup(mixin, mixinPath) };
                            if (candidate.group !== defFalseEitherCase) {
                                candidates.push(candidate);
                            }
                            match = true;
                        }
                    }
                    default_1.default.reset();
                    count = [0, 0, 0];
                    for (m = 0; m < candidates.length; m++) {
                        count[candidates[m].group]++;
                    }
                    if (count[defNone] > 0) {
                        defaultResult = defFalse;
                    }
                    else {
                        defaultResult = defTrue;
                        if ((count[defTrue] + count[defFalse]) > 1) {
                            throw { type: 'Runtime',
                                message: "Ambiguous use of `default()` found when matching for `" + this.format(args) + "`",
                                index: this.getIndex(), filename: this.fileInfo().filename };
                        }
                    }
                    for (m = 0; m < candidates.length; m++) {
                        candidate = candidates[m].group;
                        if ((candidate === defNone) || (candidate === defaultResult)) {
                            try {
                                mixin = candidates[m].mixin;
                                if (!(mixin instanceof mixin_definition_1.default)) {
                                    originalRuleset = mixin.originalRuleset || mixin;
                                    mixin = new mixin_definition_1.default('', [], mixin.rules, null, false, null, originalRuleset.visibilityInfo());
                                    mixin.originalRuleset = originalRuleset;
                                }
                                var newRules = mixin.evalCall(context, args, this.important).rules;
                                this._setVisibilityToReplacement(newRules);
                                Array.prototype.push.apply(rules, newRules);
                            }
                            catch (e) {
                                throw { message: e.message, index: this.getIndex(), filename: this.fileInfo().filename, stack: e.stack };
                            }
                        }
                    }
                    if (match) {
                        return rules;
                    }
                }
            }
            if (isOneFound) {
                throw { type: 'Runtime',
                    message: "No matching definition was found for `" + this.format(args) + "`",
                    index: this.getIndex(), filename: this.fileInfo().filename };
            }
            else {
                throw { type: 'Name',
                    message: this.selector.toCSS().trim() + " is undefined",
                    index: this.getIndex(), filename: this.fileInfo().filename };
            }
        },
        _setVisibilityToReplacement: function (replacement) {
            var i, rule;
            if (this.blocksVisibility()) {
                for (i = 0; i < replacement.length; i++) {
                    rule = replacement[i];
                    rule.addVisibilityBlock();
                }
            }
        },
        format: function (args) {
            return this.selector.toCSS().trim() + "(" + (args ? args.map(function (a) {
                var argValue = '';
                if (a.name) {
                    argValue += a.name + ":";
                }
                if (a.value.toCSS) {
                    argValue += a.value.toCSS();
                }
                else {
                    argValue += '???';
                }
                return argValue;
            }).join(', ') : '') + ")";
        }
    });
    exports.default = MixinCall;
    
},
/* less/lib/less/tree/mixin-definition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var element_1 = tslib_1.__importDefault(require(118) /* ./element */);
    var ruleset_1 = tslib_1.__importDefault(require(126) /* ./ruleset */);
    var declaration_1 = tslib_1.__importDefault(require(127) /* ./declaration */);
    var detached_ruleset_1 = tslib_1.__importDefault(require(136) /* ./detached-ruleset */);
    var expression_1 = tslib_1.__importDefault(require(143) /* ./expression */);
    var contexts_1 = tslib_1.__importDefault(require(133) /* ../contexts */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var Definition = function (name, params, rules, condition, variadic, frames, visibilityInfo) {
        this.name = name || 'anonymous mixin';
        this.selectors = [new selector_1.default([new element_1.default(null, name, false, this._index, this._fileInfo)])];
        this.params = params;
        this.condition = condition;
        this.variadic = variadic;
        this.arity = params.length;
        this.rules = rules;
        this._lookups = {};
        var optionalParameters = [];
        this.required = params.reduce(function (count, p) {
            if (!p.name || (p.name && !p.value)) {
                return count + 1;
            }
            else {
                optionalParameters.push(p.name);
                return count;
            }
        }, 0);
        this.optionalParameters = optionalParameters;
        this.frames = frames;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
    };
    Definition.prototype = Object.assign(new ruleset_1.default(), {
        type: 'MixinDefinition',
        evalFirst: true,
        accept: function (visitor) {
            if (this.params && this.params.length) {
                this.params = visitor.visitArray(this.params);
            }
            this.rules = visitor.visitArray(this.rules);
            if (this.condition) {
                this.condition = visitor.visit(this.condition);
            }
        },
        evalParams: function (context, mixinEnv, args, evaldArguments) {
            /* jshint boss:true */
            var frame = new ruleset_1.default(null, null);
            var varargs;
            var arg;
            var params = utils.copyArray(this.params);
            var i;
            var j;
            var val;
            var name;
            var isNamedFound;
            var argIndex;
            var argsLength = 0;
            if (mixinEnv.frames && mixinEnv.frames[0] && mixinEnv.frames[0].functionRegistry) {
                frame.functionRegistry = mixinEnv.frames[0].functionRegistry.inherit();
            }
            mixinEnv = new contexts_1.default.Eval(mixinEnv, [frame].concat(mixinEnv.frames));
            if (args) {
                args = utils.copyArray(args);
                argsLength = args.length;
                for (i = 0; i < argsLength; i++) {
                    arg = args[i];
                    if (name = (arg && arg.name)) {
                        isNamedFound = false;
                        for (j = 0; j < params.length; j++) {
                            if (!evaldArguments[j] && name === params[j].name) {
                                evaldArguments[j] = arg.value.eval(context);
                                frame.prependRule(new declaration_1.default(name, arg.value.eval(context)));
                                isNamedFound = true;
                                break;
                            }
                        }
                        if (isNamedFound) {
                            args.splice(i, 1);
                            i--;
                            continue;
                        }
                        else {
                            throw { type: 'Runtime', message: "Named argument for " + this.name + " " + args[i].name + " not found" };
                        }
                    }
                }
            }
            argIndex = 0;
            for (i = 0; i < params.length; i++) {
                if (evaldArguments[i]) {
                    continue;
                }
                arg = args && args[argIndex];
                if (name = params[i].name) {
                    if (params[i].variadic) {
                        varargs = [];
                        for (j = argIndex; j < argsLength; j++) {
                            varargs.push(args[j].value.eval(context));
                        }
                        frame.prependRule(new declaration_1.default(name, new expression_1.default(varargs).eval(context)));
                    }
                    else {
                        val = arg && arg.value;
                        if (val) {
                            // This was a mixin call, pass in a detached ruleset of it's eval'd rules
                            if (Array.isArray(val)) {
                                val = new detached_ruleset_1.default(new ruleset_1.default('', val));
                            }
                            else {
                                val = val.eval(context);
                            }
                        }
                        else if (params[i].value) {
                            val = params[i].value.eval(mixinEnv);
                            frame.resetCache();
                        }
                        else {
                            throw { type: 'Runtime', message: "wrong number of arguments for " + this.name + " (" + argsLength + " for " + this.arity + ")" };
                        }
                        frame.prependRule(new declaration_1.default(name, val));
                        evaldArguments[i] = val;
                    }
                }
                if (params[i].variadic && args) {
                    for (j = argIndex; j < argsLength; j++) {
                        evaldArguments[j] = args[j].value.eval(context);
                    }
                }
                argIndex++;
            }
            return frame;
        },
        makeImportant: function () {
            var rules = !this.rules ? this.rules : this.rules.map(function (r) {
                if (r.makeImportant) {
                    return r.makeImportant(true);
                }
                else {
                    return r;
                }
            });
            var result = new Definition(this.name, this.params, rules, this.condition, this.variadic, this.frames);
            return result;
        },
        eval: function (context) {
            return new Definition(this.name, this.params, this.rules, this.condition, this.variadic, this.frames || utils.copyArray(context.frames));
        },
        evalCall: function (context, args, important) {
            var _arguments = [];
            var mixinFrames = this.frames ? this.frames.concat(context.frames) : context.frames;
            var frame = this.evalParams(context, new contexts_1.default.Eval(context, mixinFrames), args, _arguments);
            var rules;
            var ruleset;
            frame.prependRule(new declaration_1.default('@arguments', new expression_1.default(_arguments).eval(context)));
            rules = utils.copyArray(this.rules);
            ruleset = new ruleset_1.default(null, rules);
            ruleset.originalRuleset = this;
            ruleset = ruleset.eval(new contexts_1.default.Eval(context, [this, frame].concat(mixinFrames)));
            if (important) {
                ruleset = ruleset.makeImportant();
            }
            return ruleset;
        },
        matchCondition: function (args, context) {
            if (this.condition && !this.condition.eval(new contexts_1.default.Eval(context, [this.evalParams(context, /* the parameter variables */ new contexts_1.default.Eval(context, this.frames ? this.frames.concat(context.frames) : context.frames), args, [])]
                .concat(this.frames || []) // the parent namespace/mixin frames
                .concat(context.frames)))) { // the current environment frames
                return false;
            }
            return true;
        },
        matchArgs: function (args, context) {
            var allArgsCnt = (args && args.length) || 0;
            var len;
            var optionalParameters = this.optionalParameters;
            var requiredArgsCnt = !args ? 0 : args.reduce(function (count, p) {
                if (optionalParameters.indexOf(p.name) < 0) {
                    return count + 1;
                }
                else {
                    return count;
                }
            }, 0);
            if (!this.variadic) {
                if (requiredArgsCnt < this.required) {
                    return false;
                }
                if (allArgsCnt > this.params.length) {
                    return false;
                }
            }
            else {
                if (requiredArgsCnt < (this.required - 1)) {
                    return false;
                }
            }
            // check patterns
            len = Math.min(requiredArgsCnt, this.arity);
            for (var i = 0; i < len; i++) {
                if (!this.params[i].name && !this.params[i].variadic) {
                    if (args[i].value.eval(context).toCSS() != this.params[i].value.eval(context).toCSS()) {
                        return false;
                    }
                }
            }
            return true;
        }
    });
    exports.default = Definition;
    
},
/* less/lib/less/environment/abstract-plugin-loader.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var function_registry_1 = tslib_1.__importDefault(require(134) /* ../functions/function-registry */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    var AbstractPluginLoader = /** @class */ (function () {
        function AbstractPluginLoader() {
            // Implemented by Node.js plugin loader
            this.require = function () {
                return null;
            };
        }
        AbstractPluginLoader.prototype.evalPlugin = function (contents, context, imports, pluginOptions, fileInfo) {
            var loader, registry, pluginObj, localModule, pluginManager, filename, result;
            pluginManager = context.pluginManager;
            if (fileInfo) {
                if (typeof fileInfo === 'string') {
                    filename = fileInfo;
                }
                else {
                    filename = fileInfo.filename;
                }
            }
            var shortname = (new this.less.FileManager()).extractUrlParts(filename).filename;
            if (filename) {
                pluginObj = pluginManager.get(filename);
                if (pluginObj) {
                    result = this.trySetOptions(pluginObj, filename, shortname, pluginOptions);
                    if (result) {
                        return result;
                    }
                    try {
                        if (pluginObj.use) {
                            pluginObj.use.call(this.context, pluginObj);
                        }
                    }
                    catch (e) {
                        e.message = e.message || 'Error during @plugin call';
                        return new less_error_1.default(e, imports, filename);
                    }
                    return pluginObj;
                }
            }
            localModule = {
                exports: {},
                pluginManager: pluginManager,
                fileInfo: fileInfo
            };
            registry = function_registry_1.default.create();
            var registerPlugin = function (obj) {
                pluginObj = obj;
            };
            try {
                loader = new Function('module', 'require', 'registerPlugin', 'functions', 'tree', 'less', 'fileInfo', contents);
                loader(localModule, this.require(filename), registerPlugin, registry, this.less.tree, this.less, fileInfo);
            }
            catch (e) {
                return new less_error_1.default(e, imports, filename);
            }
            if (!pluginObj) {
                pluginObj = localModule.exports;
            }
            pluginObj = this.validatePlugin(pluginObj, filename, shortname);
            if (pluginObj instanceof less_error_1.default) {
                return pluginObj;
            }
            if (pluginObj) {
                pluginObj.imports = imports;
                pluginObj.filename = filename;
                // For < 3.x (or unspecified minVersion) - setOptions() before install()
                if (!pluginObj.minVersion || this.compareVersion('3.0.0', pluginObj.minVersion) < 0) {
                    result = this.trySetOptions(pluginObj, filename, shortname, pluginOptions);
                    if (result) {
                        return result;
                    }
                }
                // Run on first load
                pluginManager.addPlugin(pluginObj, fileInfo.filename, registry);
                pluginObj.functions = registry.getLocalFunctions();
                // Need to call setOptions again because the pluginObj might have functions
                result = this.trySetOptions(pluginObj, filename, shortname, pluginOptions);
                if (result) {
                    return result;
                }
                // Run every @plugin call
                try {
                    if (pluginObj.use) {
                        pluginObj.use.call(this.context, pluginObj);
                    }
                }
                catch (e) {
                    e.message = e.message || 'Error during @plugin call';
                    return new less_error_1.default(e, imports, filename);
                }
            }
            else {
                return new less_error_1.default({ message: 'Not a valid plugin' }, imports, filename);
            }
            return pluginObj;
        };
        AbstractPluginLoader.prototype.trySetOptions = function (plugin, filename, name, options) {
            if (options && !plugin.setOptions) {
                return new less_error_1.default({
                    message: "Options have been provided but the plugin " + name + " does not support any options."
                });
            }
            try {
                plugin.setOptions && plugin.setOptions(options);
            }
            catch (e) {
                return new less_error_1.default(e);
            }
        };
        AbstractPluginLoader.prototype.validatePlugin = function (plugin, filename, name) {
            if (plugin) {
                // support plugins being a function
                // so that the plugin can be more usable programmatically
                if (typeof plugin === 'function') {
                    plugin = new plugin();
                }
                if (plugin.minVersion) {
                    if (this.compareVersion(plugin.minVersion, this.less.version) < 0) {
                        return new less_error_1.default({
                            message: "Plugin " + name + " requires version " + this.versionToString(plugin.minVersion)
                        });
                    }
                }
                return plugin;
            }
            return null;
        };
        AbstractPluginLoader.prototype.compareVersion = function (aVersion, bVersion) {
            if (typeof aVersion === 'string') {
                aVersion = aVersion.match(/^(\d+)\.?(\d+)?\.?(\d+)?/);
                aVersion.shift();
            }
            for (var i = 0; i < aVersion.length; i++) {
                if (aVersion[i] !== bVersion[i]) {
                    return parseInt(aVersion[i]) > parseInt(bVersion[i]) ? -1 : 1;
                }
            }
            return 0;
        };
        AbstractPluginLoader.prototype.versionToString = function (version) {
            var versionString = '';
            for (var i = 0; i < version.length; i++) {
                versionString += (versionString ? '.' : '') + version[i];
            }
            return versionString;
        };
        AbstractPluginLoader.prototype.printUsage = function (plugins) {
            for (var i = 0; i < plugins.length; i++) {
                var plugin = plugins[i];
                if (plugin.printUsage) {
                    plugin.printUsage();
                }
            }
        };
        return AbstractPluginLoader;
    }());
    exports.default = AbstractPluginLoader;
    
},
/* less/lib/less/visitors/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var visitor_1 = tslib_1.__importDefault(require(163) /* ./visitor */);
    var import_visitor_1 = tslib_1.__importDefault(require(164) /* ./import-visitor */);
    var set_tree_visibility_visitor_1 = tslib_1.__importDefault(require(166) /* ./set-tree-visibility-visitor */);
    var extend_visitor_1 = tslib_1.__importDefault(require(167) /* ./extend-visitor */);
    var join_selector_visitor_1 = tslib_1.__importDefault(require(168) /* ./join-selector-visitor */);
    var to_css_visitor_1 = tslib_1.__importDefault(require(169) /* ./to-css-visitor */);
    exports.default = {
        Visitor: visitor_1.default,
        ImportVisitor: import_visitor_1.default,
        MarkVisibleSelectorsVisitor: set_tree_visibility_visitor_1.default,
        ExtendVisitor: extend_visitor_1.default,
        JoinSelectorVisitor: join_selector_visitor_1.default,
        ToCSSVisitor: to_css_visitor_1.default
    };
    
},
/* less/lib/less/visitors/visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var tree_1 = tslib_1.__importDefault(require(113) /* ../tree */);
    var _visitArgs = { visitDeeper: true };
    var _hasIndexed = false;
    function _noop(node) {
        return node;
    }
    function indexNodeTypes(parent, ticker) {
        // add .typeIndex to tree node types for lookup table
        var key, child;
        for (key in parent) {
            /* eslint guard-for-in: 0 */
            child = parent[key];
            switch (typeof child) {
                case 'function':
                    // ignore bound functions directly on tree which do not have a prototype
                    // or aren't nodes
                    if (child.prototype && child.prototype.type) {
                        child.prototype.typeIndex = ticker++;
                    }
                    break;
                case 'object':
                    ticker = indexNodeTypes(child, ticker);
                    break;
            }
        }
        return ticker;
    }
    var Visitor = /** @class */ (function () {
        function Visitor(implementation) {
            this._implementation = implementation;
            this._visitInCache = {};
            this._visitOutCache = {};
            if (!_hasIndexed) {
                indexNodeTypes(tree_1.default, 1);
                _hasIndexed = true;
            }
        }
        Visitor.prototype.visit = function (node) {
            if (!node) {
                return node;
            }
            var nodeTypeIndex = node.typeIndex;
            if (!nodeTypeIndex) {
                // MixinCall args aren't a node type?
                if (node.value && node.value.typeIndex) {
                    this.visit(node.value);
                }
                return node;
            }
            var impl = this._implementation;
            var func = this._visitInCache[nodeTypeIndex];
            var funcOut = this._visitOutCache[nodeTypeIndex];
            var visitArgs = _visitArgs;
            var fnName;
            visitArgs.visitDeeper = true;
            if (!func) {
                fnName = "visit" + node.type;
                func = impl[fnName] || _noop;
                funcOut = impl[fnName + "Out"] || _noop;
                this._visitInCache[nodeTypeIndex] = func;
                this._visitOutCache[nodeTypeIndex] = funcOut;
            }
            if (func !== _noop) {
                var newNode = func.call(impl, node, visitArgs);
                if (node && impl.isReplacing) {
                    node = newNode;
                }
            }
            if (visitArgs.visitDeeper && node) {
                if (node.length) {
                    for (var i = 0, cnt = node.length; i < cnt; i++) {
                        if (node[i].accept) {
                            node[i].accept(this);
                        }
                    }
                }
                else if (node.accept) {
                    node.accept(this);
                }
            }
            if (funcOut != _noop) {
                funcOut.call(impl, node);
            }
            return node;
        };
        Visitor.prototype.visitArray = function (nodes, nonReplacing) {
            if (!nodes) {
                return nodes;
            }
            var cnt = nodes.length;
            var i;
            // Non-replacing
            if (nonReplacing || !this._implementation.isReplacing) {
                for (i = 0; i < cnt; i++) {
                    this.visit(nodes[i]);
                }
                return nodes;
            }
            // Replacing
            var out = [];
            for (i = 0; i < cnt; i++) {
                var evald = this.visit(nodes[i]);
                if (evald === undefined) {
                    continue;
                }
                if (!evald.splice) {
                    out.push(evald);
                }
                else if (evald.length) {
                    this.flatten(evald, out);
                }
            }
            return out;
        };
        Visitor.prototype.flatten = function (arr, out) {
            if (!out) {
                out = [];
            }
            var cnt, i, item, nestedCnt, j, nestedItem;
            for (i = 0, cnt = arr.length; i < cnt; i++) {
                item = arr[i];
                if (item === undefined) {
                    continue;
                }
                if (!item.splice) {
                    out.push(item);
                    continue;
                }
                for (j = 0, nestedCnt = item.length; j < nestedCnt; j++) {
                    nestedItem = item[j];
                    if (nestedItem === undefined) {
                        continue;
                    }
                    if (!nestedItem.splice) {
                        out.push(nestedItem);
                    }
                    else if (nestedItem.length) {
                        this.flatten(nestedItem, out);
                    }
                }
            }
            return out;
        };
        return Visitor;
    }());
    exports.default = Visitor;
    
},
/* less/lib/less/visitors/import-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var contexts_1 = tslib_1.__importDefault(require(133) /* ../contexts */);
    var visitor_1 = tslib_1.__importDefault(require(163) /* ./visitor */);
    var import_sequencer_1 = tslib_1.__importDefault(require(165) /* ./import-sequencer */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var ImportVisitor = function (importer, finish) {
        this._visitor = new visitor_1.default(this);
        this._importer = importer;
        this._finish = finish;
        this.context = new contexts_1.default.Eval();
        this.importCount = 0;
        this.onceFileDetectionMap = {};
        this.recursionDetector = {};
        this._sequencer = new import_sequencer_1.default(this._onSequencerEmpty.bind(this));
    };
    ImportVisitor.prototype = {
        isReplacing: false,
        run: function (root) {
            try {
                // process the contents
                this._visitor.visit(root);
            }
            catch (e) {
                this.error = e;
            }
            this.isFinished = true;
            this._sequencer.tryRun();
        },
        _onSequencerEmpty: function () {
            if (!this.isFinished) {
                return;
            }
            this._finish(this.error);
        },
        visitImport: function (importNode, visitArgs) {
            var inlineCSS = importNode.options.inline;
            if (!importNode.css || inlineCSS) {
                var context = new contexts_1.default.Eval(this.context, utils.copyArray(this.context.frames));
                var importParent = context.frames[0];
                this.importCount++;
                if (importNode.isVariableImport()) {
                    this._sequencer.addVariableImport(this.processImportNode.bind(this, importNode, context, importParent));
                }
                else {
                    this.processImportNode(importNode, context, importParent);
                }
            }
            visitArgs.visitDeeper = false;
        },
        processImportNode: function (importNode, context, importParent) {
            var evaldImportNode;
            var inlineCSS = importNode.options.inline;
            try {
                evaldImportNode = importNode.evalForImport(context);
            }
            catch (e) {
                if (!e.filename) {
                    e.index = importNode.getIndex();
                    e.filename = importNode.fileInfo().filename;
                }
                // attempt to eval properly and treat as css
                importNode.css = true;
                // if that fails, this error will be thrown
                importNode.error = e;
            }
            if (evaldImportNode && (!evaldImportNode.css || inlineCSS)) {
                if (evaldImportNode.options.multiple) {
                    context.importMultiple = true;
                }
                // try appending if we haven't determined if it is css or not
                var tryAppendLessExtension = evaldImportNode.css === undefined;
                for (var i = 0; i < importParent.rules.length; i++) {
                    if (importParent.rules[i] === importNode) {
                        importParent.rules[i] = evaldImportNode;
                        break;
                    }
                }
                var onImported = this.onImported.bind(this, evaldImportNode, context), sequencedOnImported = this._sequencer.addImport(onImported);
                this._importer.push(evaldImportNode.getPath(), tryAppendLessExtension, evaldImportNode.fileInfo(), evaldImportNode.options, sequencedOnImported);
            }
            else {
                this.importCount--;
                if (this.isFinished) {
                    this._sequencer.tryRun();
                }
            }
        },
        onImported: function (importNode, context, e, root, importedAtRoot, fullPath) {
            if (e) {
                if (!e.filename) {
                    e.index = importNode.getIndex();
                    e.filename = importNode.fileInfo().filename;
                }
                this.error = e;
            }
            var importVisitor = this, inlineCSS = importNode.options.inline, isPlugin = importNode.options.isPlugin, isOptional = importNode.options.optional, duplicateImport = importedAtRoot || fullPath in importVisitor.recursionDetector;
            if (!context.importMultiple) {
                if (duplicateImport) {
                    importNode.skip = true;
                }
                else {
                    importNode.skip = function () {
                        if (fullPath in importVisitor.onceFileDetectionMap) {
                            return true;
                        }
                        importVisitor.onceFileDetectionMap[fullPath] = true;
                        return false;
                    };
                }
            }
            if (!fullPath && isOptional) {
                importNode.skip = true;
            }
            if (root) {
                importNode.root = root;
                importNode.importedFilename = fullPath;
                if (!inlineCSS && !isPlugin && (context.importMultiple || !duplicateImport)) {
                    importVisitor.recursionDetector[fullPath] = true;
                    var oldContext = this.context;
                    this.context = context;
                    try {
                        this._visitor.visit(root);
                    }
                    catch (e) {
                        this.error = e;
                    }
                    this.context = oldContext;
                }
            }
            importVisitor.importCount--;
            if (importVisitor.isFinished) {
                importVisitor._sequencer.tryRun();
            }
        },
        visitDeclaration: function (declNode, visitArgs) {
            if (declNode.value.type === 'DetachedRuleset') {
                this.context.frames.unshift(declNode);
            }
            else {
                visitArgs.visitDeeper = false;
            }
        },
        visitDeclarationOut: function (declNode) {
            if (declNode.value.type === 'DetachedRuleset') {
                this.context.frames.shift();
            }
        },
        visitAtRule: function (atRuleNode, visitArgs) {
            this.context.frames.unshift(atRuleNode);
        },
        visitAtRuleOut: function (atRuleNode) {
            this.context.frames.shift();
        },
        visitMixinDefinition: function (mixinDefinitionNode, visitArgs) {
            this.context.frames.unshift(mixinDefinitionNode);
        },
        visitMixinDefinitionOut: function (mixinDefinitionNode) {
            this.context.frames.shift();
        },
        visitRuleset: function (rulesetNode, visitArgs) {
            this.context.frames.unshift(rulesetNode);
        },
        visitRulesetOut: function (rulesetNode) {
            this.context.frames.shift();
        },
        visitMedia: function (mediaNode, visitArgs) {
            this.context.frames.unshift(mediaNode.rules[0]);
        },
        visitMediaOut: function (mediaNode) {
            this.context.frames.shift();
        }
    };
    exports.default = ImportVisitor;
    
},
/* less/lib/less/visitors/import-sequencer.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var ImportSequencer = /** @class */ (function () {
        function ImportSequencer(onSequencerEmpty) {
            this.imports = [];
            this.variableImports = [];
            this._onSequencerEmpty = onSequencerEmpty;
            this._currentDepth = 0;
        }
        ImportSequencer.prototype.addImport = function (callback) {
            var importSequencer = this, importItem = {
                callback: callback,
                args: null,
                isReady: false
            };
            this.imports.push(importItem);
            return function () {
                importItem.args = Array.prototype.slice.call(arguments, 0);
                importItem.isReady = true;
                importSequencer.tryRun();
            };
        };
        ImportSequencer.prototype.addVariableImport = function (callback) {
            this.variableImports.push(callback);
        };
        ImportSequencer.prototype.tryRun = function () {
            this._currentDepth++;
            try {
                while (true) {
                    while (this.imports.length > 0) {
                        var importItem = this.imports[0];
                        if (!importItem.isReady) {
                            return;
                        }
                        this.imports = this.imports.slice(1);
                        importItem.callback.apply(null, importItem.args);
                    }
                    if (this.variableImports.length === 0) {
                        break;
                    }
                    var variableImport = this.variableImports[0];
                    this.variableImports = this.variableImports.slice(1);
                    variableImport();
                }
            }
            finally {
                this._currentDepth--;
            }
            if (this._currentDepth === 0 && this._onSequencerEmpty) {
                this._onSequencerEmpty();
            }
        };
        return ImportSequencer;
    }());
    exports.default = ImportSequencer;
    
},
/* less/lib/less/visitors/set-tree-visibility-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var SetTreeVisibilityVisitor = /** @class */ (function () {
        function SetTreeVisibilityVisitor(visible) {
            this.visible = visible;
        }
        SetTreeVisibilityVisitor.prototype.run = function (root) {
            this.visit(root);
        };
        SetTreeVisibilityVisitor.prototype.visitArray = function (nodes) {
            if (!nodes) {
                return nodes;
            }
            var cnt = nodes.length;
            var i;
            for (i = 0; i < cnt; i++) {
                this.visit(nodes[i]);
            }
            return nodes;
        };
        SetTreeVisibilityVisitor.prototype.visit = function (node) {
            if (!node) {
                return node;
            }
            if (node.constructor === Array) {
                return this.visitArray(node);
            }
            if (!node.blocksVisibility || node.blocksVisibility()) {
                return node;
            }
            if (this.visible) {
                node.ensureVisibility();
            }
            else {
                node.ensureInvisibility();
            }
            node.accept(this);
            return node;
        };
        return SetTreeVisibilityVisitor;
    }());
    exports.default = SetTreeVisibilityVisitor;
    
},
/* less/lib/less/visitors/extend-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var tree_1 = tslib_1.__importDefault(require(113) /* ../tree */);
    var visitor_1 = tslib_1.__importDefault(require(163) /* ./visitor */);
    var logger_1 = tslib_1.__importDefault(require(70) /* ../logger */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    /* jshint loopfunc:true */
    var ExtendFinderVisitor = /** @class */ (function () {
        function ExtendFinderVisitor() {
            this._visitor = new visitor_1.default(this);
            this.contexts = [];
            this.allExtendsStack = [[]];
        }
        ExtendFinderVisitor.prototype.run = function (root) {
            root = this._visitor.visit(root);
            root.allExtends = this.allExtendsStack[0];
            return root;
        };
        ExtendFinderVisitor.prototype.visitDeclaration = function (declNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ExtendFinderVisitor.prototype.visitMixinDefinition = function (mixinDefinitionNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ExtendFinderVisitor.prototype.visitRuleset = function (rulesetNode, visitArgs) {
            if (rulesetNode.root) {
                return;
            }
            var i;
            var j;
            var extend;
            var allSelectorsExtendList = [];
            var extendList;
            // get &:extend(.a); rules which apply to all selectors in this ruleset
            var rules = rulesetNode.rules, ruleCnt = rules ? rules.length : 0;
            for (i = 0; i < ruleCnt; i++) {
                if (rulesetNode.rules[i] instanceof tree_1.default.Extend) {
                    allSelectorsExtendList.push(rules[i]);
                    rulesetNode.extendOnEveryPath = true;
                }
            }
            // now find every selector and apply the extends that apply to all extends
            // and the ones which apply to an individual extend
            var paths = rulesetNode.paths;
            for (i = 0; i < paths.length; i++) {
                var selectorPath = paths[i], selector = selectorPath[selectorPath.length - 1], selExtendList = selector.extendList;
                extendList = selExtendList ? utils.copyArray(selExtendList).concat(allSelectorsExtendList)
                    : allSelectorsExtendList;
                if (extendList) {
                    extendList = extendList.map(function (allSelectorsExtend) {
                        return allSelectorsExtend.clone();
                    });
                }
                for (j = 0; j < extendList.length; j++) {
                    this.foundExtends = true;
                    extend = extendList[j];
                    extend.findSelfSelectors(selectorPath);
                    extend.ruleset = rulesetNode;
                    if (j === 0) {
                        extend.firstExtendOnThisSelectorPath = true;
                    }
                    this.allExtendsStack[this.allExtendsStack.length - 1].push(extend);
                }
            }
            this.contexts.push(rulesetNode.selectors);
        };
        ExtendFinderVisitor.prototype.visitRulesetOut = function (rulesetNode) {
            if (!rulesetNode.root) {
                this.contexts.length = this.contexts.length - 1;
            }
        };
        ExtendFinderVisitor.prototype.visitMedia = function (mediaNode, visitArgs) {
            mediaNode.allExtends = [];
            this.allExtendsStack.push(mediaNode.allExtends);
        };
        ExtendFinderVisitor.prototype.visitMediaOut = function (mediaNode) {
            this.allExtendsStack.length = this.allExtendsStack.length - 1;
        };
        ExtendFinderVisitor.prototype.visitAtRule = function (atRuleNode, visitArgs) {
            atRuleNode.allExtends = [];
            this.allExtendsStack.push(atRuleNode.allExtends);
        };
        ExtendFinderVisitor.prototype.visitAtRuleOut = function (atRuleNode) {
            this.allExtendsStack.length = this.allExtendsStack.length - 1;
        };
        return ExtendFinderVisitor;
    }());
    var ProcessExtendsVisitor = /** @class */ (function () {
        function ProcessExtendsVisitor() {
            this._visitor = new visitor_1.default(this);
        }
        ProcessExtendsVisitor.prototype.run = function (root) {
            var extendFinder = new ExtendFinderVisitor();
            this.extendIndices = {};
            extendFinder.run(root);
            if (!extendFinder.foundExtends) {
                return root;
            }
            root.allExtends = root.allExtends.concat(this.doExtendChaining(root.allExtends, root.allExtends));
            this.allExtendsStack = [root.allExtends];
            var newRoot = this._visitor.visit(root);
            this.checkExtendsForNonMatched(root.allExtends);
            return newRoot;
        };
        ProcessExtendsVisitor.prototype.checkExtendsForNonMatched = function (extendList) {
            var indices = this.extendIndices;
            extendList.filter(function (extend) {
                return !extend.hasFoundMatches && extend.parent_ids.length == 1;
            }).forEach(function (extend) {
                var selector = '_unknown_';
                try {
                    selector = extend.selector.toCSS({});
                }
                catch (_) { }
                if (!indices[extend.index + " " + selector]) {
                    indices[extend.index + " " + selector] = true;
                    logger_1.default.warn("extend '" + selector + "' has no matches");
                }
            });
        };
        ProcessExtendsVisitor.prototype.doExtendChaining = function (extendsList, extendsListTarget, iterationCount) {
            //
            // chaining is different from normal extension.. if we extend an extend then we are not just copying, altering
            // and pasting the selector we would do normally, but we are also adding an extend with the same target selector
            // this means this new extend can then go and alter other extends
            //
            // this method deals with all the chaining work - without it, extend is flat and doesn't work on other extend selectors
            // this is also the most expensive.. and a match on one selector can cause an extension of a selector we had already
            // processed if we look at each selector at a time, as is done in visitRuleset
            var extendIndex;
            var targetExtendIndex;
            var matches;
            var extendsToAdd = [];
            var newSelector;
            var extendVisitor = this;
            var selectorPath;
            var extend;
            var targetExtend;
            var newExtend;
            iterationCount = iterationCount || 0;
            // loop through comparing every extend with every target extend.
            // a target extend is the one on the ruleset we are looking at copy/edit/pasting in place
            // e.g.  .a:extend(.b) {}  and .b:extend(.c) {} then the first extend extends the second one
            // and the second is the target.
            // the separation into two lists allows us to process a subset of chains with a bigger set, as is the
            // case when processing media queries
            for (extendIndex = 0; extendIndex < extendsList.length; extendIndex++) {
                for (targetExtendIndex = 0; targetExtendIndex < extendsListTarget.length; targetExtendIndex++) {
                    extend = extendsList[extendIndex];
                    targetExtend = extendsListTarget[targetExtendIndex];
                    // look for circular references
                    if (extend.parent_ids.indexOf(targetExtend.object_id) >= 0) {
                        continue;
                    }
                    // find a match in the target extends self selector (the bit before :extend)
                    selectorPath = [targetExtend.selfSelectors[0]];
                    matches = extendVisitor.findMatch(extend, selectorPath);
                    if (matches.length) {
                        extend.hasFoundMatches = true;
                        // we found a match, so for each self selector..
                        extend.selfSelectors.forEach(function (selfSelector) {
                            var info = targetExtend.visibilityInfo();
                            // process the extend as usual
                            newSelector = extendVisitor.extendSelector(matches, selectorPath, selfSelector, extend.isVisible());
                            // but now we create a new extend from it
                            newExtend = new (tree_1.default.Extend)(targetExtend.selector, targetExtend.option, 0, targetExtend.fileInfo(), info);
                            newExtend.selfSelectors = newSelector;
                            // add the extend onto the list of extends for that selector
                            newSelector[newSelector.length - 1].extendList = [newExtend];
                            // record that we need to add it.
                            extendsToAdd.push(newExtend);
                            newExtend.ruleset = targetExtend.ruleset;
                            // remember its parents for circular references
                            newExtend.parent_ids = newExtend.parent_ids.concat(targetExtend.parent_ids, extend.parent_ids);
                            // only process the selector once.. if we have :extend(.a,.b) then multiple
                            // extends will look at the same selector path, so when extending
                            // we know that any others will be duplicates in terms of what is added to the css
                            if (targetExtend.firstExtendOnThisSelectorPath) {
                                newExtend.firstExtendOnThisSelectorPath = true;
                                targetExtend.ruleset.paths.push(newSelector);
                            }
                        });
                    }
                }
            }
            if (extendsToAdd.length) {
                // try to detect circular references to stop a stack overflow.
                // may no longer be needed.
                this.extendChainCount++;
                if (iterationCount > 100) {
                    var selectorOne = '{unable to calculate}';
                    var selectorTwo = '{unable to calculate}';
                    try {
                        selectorOne = extendsToAdd[0].selfSelectors[0].toCSS();
                        selectorTwo = extendsToAdd[0].selector.toCSS();
                    }
                    catch (e) { }
                    throw { message: "extend circular reference detected. One of the circular extends is currently:" + selectorOne + ":extend(" + selectorTwo + ")" };
                }
                // now process the new extends on the existing rules so that we can handle a extending b extending c extending
                // d extending e...
                return extendsToAdd.concat(extendVisitor.doExtendChaining(extendsToAdd, extendsListTarget, iterationCount + 1));
            }
            else {
                return extendsToAdd;
            }
        };
        ProcessExtendsVisitor.prototype.visitDeclaration = function (ruleNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ProcessExtendsVisitor.prototype.visitMixinDefinition = function (mixinDefinitionNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ProcessExtendsVisitor.prototype.visitSelector = function (selectorNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ProcessExtendsVisitor.prototype.visitRuleset = function (rulesetNode, visitArgs) {
            if (rulesetNode.root) {
                return;
            }
            var matches;
            var pathIndex;
            var extendIndex;
            var allExtends = this.allExtendsStack[this.allExtendsStack.length - 1];
            var selectorsToAdd = [];
            var extendVisitor = this;
            var selectorPath;
            // look at each selector path in the ruleset, find any extend matches and then copy, find and replace
            for (extendIndex = 0; extendIndex < allExtends.length; extendIndex++) {
                for (pathIndex = 0; pathIndex < rulesetNode.paths.length; pathIndex++) {
                    selectorPath = rulesetNode.paths[pathIndex];
                    // extending extends happens initially, before the main pass
                    if (rulesetNode.extendOnEveryPath) {
                        continue;
                    }
                    var extendList = selectorPath[selectorPath.length - 1].extendList;
                    if (extendList && extendList.length) {
                        continue;
                    }
                    matches = this.findMatch(allExtends[extendIndex], selectorPath);
                    if (matches.length) {
                        allExtends[extendIndex].hasFoundMatches = true;
                        allExtends[extendIndex].selfSelectors.forEach(function (selfSelector) {
                            var extendedSelectors;
                            extendedSelectors = extendVisitor.extendSelector(matches, selectorPath, selfSelector, allExtends[extendIndex].isVisible());
                            selectorsToAdd.push(extendedSelectors);
                        });
                    }
                }
            }
            rulesetNode.paths = rulesetNode.paths.concat(selectorsToAdd);
        };
        ProcessExtendsVisitor.prototype.findMatch = function (extend, haystackSelectorPath) {
            //
            // look through the haystack selector path to try and find the needle - extend.selector
            // returns an array of selector matches that can then be replaced
            //
            var haystackSelectorIndex;
            var hackstackSelector;
            var hackstackElementIndex;
            var haystackElement;
            var targetCombinator;
            var i;
            var extendVisitor = this;
            var needleElements = extend.selector.elements;
            var potentialMatches = [];
            var potentialMatch;
            var matches = [];
            // loop through the haystack elements
            for (haystackSelectorIndex = 0; haystackSelectorIndex < haystackSelectorPath.length; haystackSelectorIndex++) {
                hackstackSelector = haystackSelectorPath[haystackSelectorIndex];
                for (hackstackElementIndex = 0; hackstackElementIndex < hackstackSelector.elements.length; hackstackElementIndex++) {
                    haystackElement = hackstackSelector.elements[hackstackElementIndex];
                    // if we allow elements before our match we can add a potential match every time. otherwise only at the first element.
                    if (extend.allowBefore || (haystackSelectorIndex === 0 && hackstackElementIndex === 0)) {
                        potentialMatches.push({ pathIndex: haystackSelectorIndex, index: hackstackElementIndex, matched: 0,
                            initialCombinator: haystackElement.combinator });
                    }
                    for (i = 0; i < potentialMatches.length; i++) {
                        potentialMatch = potentialMatches[i];
                        // selectors add " " onto the first element. When we use & it joins the selectors together, but if we don't
                        // then each selector in haystackSelectorPath has a space before it added in the toCSS phase. so we need to
                        // work out what the resulting combinator will be
                        targetCombinator = haystackElement.combinator.value;
                        if (targetCombinator === '' && hackstackElementIndex === 0) {
                            targetCombinator = ' ';
                        }
                        // if we don't match, null our match to indicate failure
                        if (!extendVisitor.isElementValuesEqual(needleElements[potentialMatch.matched].value, haystackElement.value) ||
                            (potentialMatch.matched > 0 && needleElements[potentialMatch.matched].combinator.value !== targetCombinator)) {
                            potentialMatch = null;
                        }
                        else {
                            potentialMatch.matched++;
                        }
                        // if we are still valid and have finished, test whether we have elements after and whether these are allowed
                        if (potentialMatch) {
                            potentialMatch.finished = potentialMatch.matched === needleElements.length;
                            if (potentialMatch.finished &&
                                (!extend.allowAfter &&
                                    (hackstackElementIndex + 1 < hackstackSelector.elements.length || haystackSelectorIndex + 1 < haystackSelectorPath.length))) {
                                potentialMatch = null;
                            }
                        }
                        // if null we remove, if not, we are still valid, so either push as a valid match or continue
                        if (potentialMatch) {
                            if (potentialMatch.finished) {
                                potentialMatch.length = needleElements.length;
                                potentialMatch.endPathIndex = haystackSelectorIndex;
                                potentialMatch.endPathElementIndex = hackstackElementIndex + 1; // index after end of match
                                potentialMatches.length = 0; // we don't allow matches to overlap, so start matching again
                                matches.push(potentialMatch);
                            }
                        }
                        else {
                            potentialMatches.splice(i, 1);
                            i--;
                        }
                    }
                }
            }
            return matches;
        };
        ProcessExtendsVisitor.prototype.isElementValuesEqual = function (elementValue1, elementValue2) {
            if (typeof elementValue1 === 'string' || typeof elementValue2 === 'string') {
                return elementValue1 === elementValue2;
            }
            if (elementValue1 instanceof tree_1.default.Attribute) {
                if (elementValue1.op !== elementValue2.op || elementValue1.key !== elementValue2.key) {
                    return false;
                }
                if (!elementValue1.value || !elementValue2.value) {
                    if (elementValue1.value || elementValue2.value) {
                        return false;
                    }
                    return true;
                }
                elementValue1 = elementValue1.value.value || elementValue1.value;
                elementValue2 = elementValue2.value.value || elementValue2.value;
                return elementValue1 === elementValue2;
            }
            elementValue1 = elementValue1.value;
            elementValue2 = elementValue2.value;
            if (elementValue1 instanceof tree_1.default.Selector) {
                if (!(elementValue2 instanceof tree_1.default.Selector) || elementValue1.elements.length !== elementValue2.elements.length) {
                    return false;
                }
                for (var i = 0; i < elementValue1.elements.length; i++) {
                    if (elementValue1.elements[i].combinator.value !== elementValue2.elements[i].combinator.value) {
                        if (i !== 0 || (elementValue1.elements[i].combinator.value || ' ') !== (elementValue2.elements[i].combinator.value || ' ')) {
                            return false;
                        }
                    }
                    if (!this.isElementValuesEqual(elementValue1.elements[i].value, elementValue2.elements[i].value)) {
                        return false;
                    }
                }
                return true;
            }
            return false;
        };
        ProcessExtendsVisitor.prototype.extendSelector = function (matches, selectorPath, replacementSelector, isVisible) {
            // for a set of matches, replace each match with the replacement selector
            var currentSelectorPathIndex = 0, currentSelectorPathElementIndex = 0, path = [], matchIndex, selector, firstElement, match, newElements;
            for (matchIndex = 0; matchIndex < matches.length; matchIndex++) {
                match = matches[matchIndex];
                selector = selectorPath[match.pathIndex];
                firstElement = new tree_1.default.Element(match.initialCombinator, replacementSelector.elements[0].value, replacementSelector.elements[0].isVariable, replacementSelector.elements[0].getIndex(), replacementSelector.elements[0].fileInfo());
                if (match.pathIndex > currentSelectorPathIndex && currentSelectorPathElementIndex > 0) {
                    path[path.length - 1].elements = path[path.length - 1]
                        .elements.concat(selectorPath[currentSelectorPathIndex].elements.slice(currentSelectorPathElementIndex));
                    currentSelectorPathElementIndex = 0;
                    currentSelectorPathIndex++;
                }
                newElements = selector.elements
                    .slice(currentSelectorPathElementIndex, match.index)
                    .concat([firstElement])
                    .concat(replacementSelector.elements.slice(1));
                if (currentSelectorPathIndex === match.pathIndex && matchIndex > 0) {
                    path[path.length - 1].elements =
                        path[path.length - 1].elements.concat(newElements);
                }
                else {
                    path = path.concat(selectorPath.slice(currentSelectorPathIndex, match.pathIndex));
                    path.push(new tree_1.default.Selector(newElements));
                }
                currentSelectorPathIndex = match.endPathIndex;
                currentSelectorPathElementIndex = match.endPathElementIndex;
                if (currentSelectorPathElementIndex >= selectorPath[currentSelectorPathIndex].elements.length) {
                    currentSelectorPathElementIndex = 0;
                    currentSelectorPathIndex++;
                }
            }
            if (currentSelectorPathIndex < selectorPath.length && currentSelectorPathElementIndex > 0) {
                path[path.length - 1].elements = path[path.length - 1]
                    .elements.concat(selectorPath[currentSelectorPathIndex].elements.slice(currentSelectorPathElementIndex));
                currentSelectorPathIndex++;
            }
            path = path.concat(selectorPath.slice(currentSelectorPathIndex, selectorPath.length));
            path = path.map(function (currentValue) {
                // we can re-use elements here, because the visibility property matters only for selectors
                var derived = currentValue.createDerived(currentValue.elements);
                if (isVisible) {
                    derived.ensureVisibility();
                }
                else {
                    derived.ensureInvisibility();
                }
                return derived;
            });
            return path;
        };
        ProcessExtendsVisitor.prototype.visitMedia = function (mediaNode, visitArgs) {
            var newAllExtends = mediaNode.allExtends.concat(this.allExtendsStack[this.allExtendsStack.length - 1]);
            newAllExtends = newAllExtends.concat(this.doExtendChaining(newAllExtends, mediaNode.allExtends));
            this.allExtendsStack.push(newAllExtends);
        };
        ProcessExtendsVisitor.prototype.visitMediaOut = function (mediaNode) {
            var lastIndex = this.allExtendsStack.length - 1;
            this.allExtendsStack.length = lastIndex;
        };
        ProcessExtendsVisitor.prototype.visitAtRule = function (atRuleNode, visitArgs) {
            var newAllExtends = atRuleNode.allExtends.concat(this.allExtendsStack[this.allExtendsStack.length - 1]);
            newAllExtends = newAllExtends.concat(this.doExtendChaining(newAllExtends, atRuleNode.allExtends));
            this.allExtendsStack.push(newAllExtends);
        };
        ProcessExtendsVisitor.prototype.visitAtRuleOut = function (atRuleNode) {
            var lastIndex = this.allExtendsStack.length - 1;
            this.allExtendsStack.length = lastIndex;
        };
        return ProcessExtendsVisitor;
    }());
    exports.default = ProcessExtendsVisitor;
    
},
/* less/lib/less/visitors/join-selector-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var visitor_1 = tslib_1.__importDefault(require(163) /* ./visitor */);
    var JoinSelectorVisitor = /** @class */ (function () {
        function JoinSelectorVisitor() {
            this.contexts = [[]];
            this._visitor = new visitor_1.default(this);
        }
        JoinSelectorVisitor.prototype.run = function (root) {
            return this._visitor.visit(root);
        };
        JoinSelectorVisitor.prototype.visitDeclaration = function (declNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        JoinSelectorVisitor.prototype.visitMixinDefinition = function (mixinDefinitionNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        JoinSelectorVisitor.prototype.visitRuleset = function (rulesetNode, visitArgs) {
            var context = this.contexts[this.contexts.length - 1];
            var paths = [];
            var selectors;
            this.contexts.push(paths);
            if (!rulesetNode.root) {
                selectors = rulesetNode.selectors;
                if (selectors) {
                    selectors = selectors.filter(function (selector) { return selector.getIsOutput(); });
                    rulesetNode.selectors = selectors.length ? selectors : (selectors = null);
                    if (selectors) {
                        rulesetNode.joinSelectors(paths, context, selectors);
                    }
                }
                if (!selectors) {
                    rulesetNode.rules = null;
                }
                rulesetNode.paths = paths;
            }
        };
        JoinSelectorVisitor.prototype.visitRulesetOut = function (rulesetNode) {
            this.contexts.length = this.contexts.length - 1;
        };
        JoinSelectorVisitor.prototype.visitMedia = function (mediaNode, visitArgs) {
            var context = this.contexts[this.contexts.length - 1];
            mediaNode.rules[0].root = (context.length === 0 || context[0].multiMedia);
        };
        JoinSelectorVisitor.prototype.visitAtRule = function (atRuleNode, visitArgs) {
            var context = this.contexts[this.contexts.length - 1];
            if (atRuleNode.rules && atRuleNode.rules.length) {
                atRuleNode.rules[0].root = (atRuleNode.isRooted || context.length === 0 || null);
            }
        };
        return JoinSelectorVisitor;
    }());
    exports.default = JoinSelectorVisitor;
    
},
/* less/lib/less/visitors/to-css-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var tree_1 = tslib_1.__importDefault(require(113) /* ../tree */);
    var visitor_1 = tslib_1.__importDefault(require(163) /* ./visitor */);
    var CSSVisitorUtils = /** @class */ (function () {
        function CSSVisitorUtils(context) {
            this._visitor = new visitor_1.default(this);
            this._context = context;
        }
        CSSVisitorUtils.prototype.containsSilentNonBlockedChild = function (bodyRules) {
            var rule;
            if (!bodyRules) {
                return false;
            }
            for (var r = 0; r < bodyRules.length; r++) {
                rule = bodyRules[r];
                if (rule.isSilent && rule.isSilent(this._context) && !rule.blocksVisibility()) {
                    // the atrule contains something that was referenced (likely by extend)
                    // therefore it needs to be shown in output too
                    return true;
                }
            }
            return false;
        };
        CSSVisitorUtils.prototype.keepOnlyVisibleChilds = function (owner) {
            if (owner && owner.rules) {
                owner.rules = owner.rules.filter(function (thing) { return thing.isVisible(); });
            }
        };
        CSSVisitorUtils.prototype.isEmpty = function (owner) {
            return (owner && owner.rules)
                ? (owner.rules.length === 0) : true;
        };
        CSSVisitorUtils.prototype.hasVisibleSelector = function (rulesetNode) {
            return (rulesetNode && rulesetNode.paths)
                ? (rulesetNode.paths.length > 0) : false;
        };
        CSSVisitorUtils.prototype.resolveVisibility = function (node, originalRules) {
            if (!node.blocksVisibility()) {
                if (this.isEmpty(node) && !this.containsSilentNonBlockedChild(originalRules)) {
                    return;
                }
                return node;
            }
            var compiledRulesBody = node.rules[0];
            this.keepOnlyVisibleChilds(compiledRulesBody);
            if (this.isEmpty(compiledRulesBody)) {
                return;
            }
            node.ensureVisibility();
            node.removeVisibilityBlock();
            return node;
        };
        CSSVisitorUtils.prototype.isVisibleRuleset = function (rulesetNode) {
            if (rulesetNode.firstRoot) {
                return true;
            }
            if (this.isEmpty(rulesetNode)) {
                return false;
            }
            if (!rulesetNode.root && !this.hasVisibleSelector(rulesetNode)) {
                return false;
            }
            return true;
        };
        return CSSVisitorUtils;
    }());
    var ToCSSVisitor = function (context) {
        this._visitor = new visitor_1.default(this);
        this._context = context;
        this.utils = new CSSVisitorUtils(context);
    };
    ToCSSVisitor.prototype = {
        isReplacing: true,
        run: function (root) {
            return this._visitor.visit(root);
        },
        visitDeclaration: function (declNode, visitArgs) {
            if (declNode.blocksVisibility() || declNode.variable) {
                return;
            }
            return declNode;
        },
        visitMixinDefinition: function (mixinNode, visitArgs) {
            // mixin definitions do not get eval'd - this means they keep state
            // so we have to clear that state here so it isn't used if toCSS is called twice
            mixinNode.frames = [];
        },
        visitExtend: function (extendNode, visitArgs) {
        },
        visitComment: function (commentNode, visitArgs) {
            if (commentNode.blocksVisibility() || commentNode.isSilent(this._context)) {
                return;
            }
            return commentNode;
        },
        visitMedia: function (mediaNode, visitArgs) {
            var originalRules = mediaNode.rules[0].rules;
            mediaNode.accept(this._visitor);
            visitArgs.visitDeeper = false;
            return this.utils.resolveVisibility(mediaNode, originalRules);
        },
        visitImport: function (importNode, visitArgs) {
            if (importNode.blocksVisibility()) {
                return;
            }
            return importNode;
        },
        visitAtRule: function (atRuleNode, visitArgs) {
            if (atRuleNode.rules && atRuleNode.rules.length) {
                return this.visitAtRuleWithBody(atRuleNode, visitArgs);
            }
            else {
                return this.visitAtRuleWithoutBody(atRuleNode, visitArgs);
            }
        },
        visitAnonymous: function (anonymousNode, visitArgs) {
            if (!anonymousNode.blocksVisibility()) {
                anonymousNode.accept(this._visitor);
                return anonymousNode;
            }
        },
        visitAtRuleWithBody: function (atRuleNode, visitArgs) {
            // if there is only one nested ruleset and that one has no path, then it is
            // just fake ruleset
            function hasFakeRuleset(atRuleNode) {
                var bodyRules = atRuleNode.rules;
                return bodyRules.length === 1 && (!bodyRules[0].paths || bodyRules[0].paths.length === 0);
            }
            function getBodyRules(atRuleNode) {
                var nodeRules = atRuleNode.rules;
                if (hasFakeRuleset(atRuleNode)) {
                    return nodeRules[0].rules;
                }
                return nodeRules;
            }
            // it is still true that it is only one ruleset in array
            // this is last such moment
            // process childs
            var originalRules = getBodyRules(atRuleNode);
            atRuleNode.accept(this._visitor);
            visitArgs.visitDeeper = false;
            if (!this.utils.isEmpty(atRuleNode)) {
                this._mergeRules(atRuleNode.rules[0].rules);
            }
            return this.utils.resolveVisibility(atRuleNode, originalRules);
        },
        visitAtRuleWithoutBody: function (atRuleNode, visitArgs) {
            if (atRuleNode.blocksVisibility()) {
                return;
            }
            if (atRuleNode.name === '@charset') {
                // Only output the debug info together with subsequent @charset definitions
                // a comment (or @media statement) before the actual @charset atrule would
                // be considered illegal css as it has to be on the first line
                if (this.charset) {
                    if (atRuleNode.debugInfo) {
                        var comment = new tree_1.default.Comment("/* " + atRuleNode.toCSS(this._context).replace(/\n/g, '') + " */\n");
                        comment.debugInfo = atRuleNode.debugInfo;
                        return this._visitor.visit(comment);
                    }
                    return;
                }
                this.charset = true;
            }
            return atRuleNode;
        },
        checkValidNodes: function (rules, isRoot) {
            if (!rules) {
                return;
            }
            for (var i = 0; i < rules.length; i++) {
                var ruleNode = rules[i];
                if (isRoot && ruleNode instanceof tree_1.default.Declaration && !ruleNode.variable) {
                    throw { message: 'Properties must be inside selector blocks. They cannot be in the root',
                        index: ruleNode.getIndex(), filename: ruleNode.fileInfo() && ruleNode.fileInfo().filename };
                }
                if (ruleNode instanceof tree_1.default.Call) {
                    throw { message: "Function '" + ruleNode.name + "' did not return a root node",
                        index: ruleNode.getIndex(), filename: ruleNode.fileInfo() && ruleNode.fileInfo().filename };
                }
                if (ruleNode.type && !ruleNode.allowRoot) {
                    throw { message: ruleNode.type + " node returned by a function is not valid here",
                        index: ruleNode.getIndex(), filename: ruleNode.fileInfo() && ruleNode.fileInfo().filename };
                }
            }
        },
        visitRuleset: function (rulesetNode, visitArgs) {
            // at this point rulesets are nested into each other
            var rule;
            var rulesets = [];
            this.checkValidNodes(rulesetNode.rules, rulesetNode.firstRoot);
            if (!rulesetNode.root) {
                // remove invisible paths
                this._compileRulesetPaths(rulesetNode);
                // remove rulesets from this ruleset body and compile them separately
                var nodeRules = rulesetNode.rules;
                var nodeRuleCnt = nodeRules ? nodeRules.length : 0;
                for (var i = 0; i < nodeRuleCnt;) {
                    rule = nodeRules[i];
                    if (rule && rule.rules) {
                        // visit because we are moving them out from being a child
                        rulesets.push(this._visitor.visit(rule));
                        nodeRules.splice(i, 1);
                        nodeRuleCnt--;
                        continue;
                    }
                    i++;
                }
                // accept the visitor to remove rules and refactor itself
                // then we can decide nogw whether we want it or not
                // compile body
                if (nodeRuleCnt > 0) {
                    rulesetNode.accept(this._visitor);
                }
                else {
                    rulesetNode.rules = null;
                }
                visitArgs.visitDeeper = false;
            }
            else { // if (! rulesetNode.root) {
                rulesetNode.accept(this._visitor);
                visitArgs.visitDeeper = false;
            }
            if (rulesetNode.rules) {
                this._mergeRules(rulesetNode.rules);
                this._removeDuplicateRules(rulesetNode.rules);
            }
            // now decide whether we keep the ruleset
            if (this.utils.isVisibleRuleset(rulesetNode)) {
                rulesetNode.ensureVisibility();
                rulesets.splice(0, 0, rulesetNode);
            }
            if (rulesets.length === 1) {
                return rulesets[0];
            }
            return rulesets;
        },
        _compileRulesetPaths: function (rulesetNode) {
            if (rulesetNode.paths) {
                rulesetNode.paths = rulesetNode.paths
                    .filter(function (p) {
                    var i;
                    if (p[0].elements[0].combinator.value === ' ') {
                        p[0].elements[0].combinator = new (tree_1.default.Combinator)('');
                    }
                    for (i = 0; i < p.length; i++) {
                        if (p[i].isVisible() && p[i].getIsOutput()) {
                            return true;
                        }
                    }
                    return false;
                });
            }
        },
        _removeDuplicateRules: function (rules) {
            if (!rules) {
                return;
            }
            // remove duplicates
            var ruleCache = {};
            var ruleList;
            var rule;
            var i;
            for (i = rules.length - 1; i >= 0; i--) {
                rule = rules[i];
                if (rule instanceof tree_1.default.Declaration) {
                    if (!ruleCache[rule.name]) {
                        ruleCache[rule.name] = rule;
                    }
                    else {
                        ruleList = ruleCache[rule.name];
                        if (ruleList instanceof tree_1.default.Declaration) {
                            ruleList = ruleCache[rule.name] = [ruleCache[rule.name].toCSS(this._context)];
                        }
                        var ruleCSS = rule.toCSS(this._context);
                        if (ruleList.indexOf(ruleCSS) !== -1) {
                            rules.splice(i, 1);
                        }
                        else {
                            ruleList.push(ruleCSS);
                        }
                    }
                }
            }
        },
        _mergeRules: function (rules) {
            if (!rules) {
                return;
            }
            var groups = {};
            var groupsArr = [];
            for (var i = 0; i < rules.length; i++) {
                var rule = rules[i];
                if (rule.merge) {
                    var key = rule.name;
                    groups[key] ? rules.splice(i--, 1) :
                        groupsArr.push(groups[key] = []);
                    groups[key].push(rule);
                }
            }
            groupsArr.forEach(function (group) {
                if (group.length > 0) {
                    var result_1 = group[0];
                    var space_1 = [];
                    var comma_1 = [new tree_1.default.Expression(space_1)];
                    group.forEach(function (rule) {
                        if ((rule.merge === '+') && (space_1.length > 0)) {
                            comma_1.push(new tree_1.default.Expression(space_1 = []));
                        }
                        space_1.push(rule.value);
                        result_1.important = result_1.important || rule.important;
                    });
                    result_1.value = new tree_1.default.Value(comma_1);
                }
            });
        }
    };
    exports.default = ToCSSVisitor;
    
},
/* less/lib/less/parser/parser.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    var tree_1 = tslib_1.__importDefault(require(113) /* ../tree */);
    var visitors_1 = tslib_1.__importDefault(require(162) /* ../visitors */);
    var parser_input_1 = tslib_1.__importDefault(require(171) /* ./parser-input */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var function_registry_1 = tslib_1.__importDefault(require(134) /* ../functions/function-registry */);
    //
    // less.js - parser
    //
    //    A relatively straight-forward predictive parser.
    //    There is no tokenization/lexing stage, the input is parsed
    //    in one sweep.
    //
    //    To make the parser fast enough to run in the browser, several
    //    optimization had to be made:
    //
    //    - Matching and slicing on a huge input is often cause of slowdowns.
    //      The solution is to chunkify the input into smaller strings.
    //      The chunks are stored in the `chunks` var,
    //      `j` holds the current chunk index, and `currentPos` holds
    //      the index of the current chunk in relation to `input`.
    //      This gives us an almost 4x speed-up.
    //
    //    - In many cases, we don't need to match individual tokens;
    //      for example, if a value doesn't hold any variables, operations
    //      or dynamic references, the parser can effectively 'skip' it,
    //      treating it as a literal.
    //      An example would be '1px solid #000' - which evaluates to itself,
    //      we don't need to know what the individual components are.
    //      The drawback, of course is that you don't get the benefits of
    //      syntax-checking on the CSS. This gives us a 50% speed-up in the parser,
    //      and a smaller speed-up in the code-gen.
    //
    //
    //    Token matching is done with the `$` function, which either takes
    //    a terminal string or regexp, or a non-terminal function to call.
    //    It also takes care of moving all the indices forwards.
    //
    var Parser = function Parser(context, imports, fileInfo) {
        var parsers;
        var parserInput = parser_input_1.default();
        function error(msg, type) {
            throw new less_error_1.default({
                index: parserInput.i,
                filename: fileInfo.filename,
                type: type || 'Syntax',
                message: msg
            }, imports);
        }
        function expect(arg, msg) {
            // some older browsers return typeof 'function' for RegExp
            var result = (arg instanceof Function) ? arg.call(parsers) : parserInput.$re(arg);
            if (result) {
                return result;
            }
            error(msg || (typeof arg === 'string'
                ? "expected '" + arg + "' got '" + parserInput.currentChar() + "'"
                : 'unexpected token'));
        }
        // Specialization of expect()
        function expectChar(arg, msg) {
            if (parserInput.$char(arg)) {
                return arg;
            }
            error(msg || "expected '" + arg + "' got '" + parserInput.currentChar() + "'");
        }
        function getDebugInfo(index) {
            var filename = fileInfo.filename;
            return {
                lineNumber: utils.getLocation(index, parserInput.getInput()).line + 1,
                fileName: filename
            };
        }
        /**
         *  Used after initial parsing to create nodes on the fly
         *
         *  @param {String} str          - string to parse
         *  @param {Array}  parseList    - array of parsers to run input through e.g. ["value", "important"]
         *  @param {Number} currentIndex - start number to begin indexing
         *  @param {Object} fileInfo     - fileInfo to attach to created nodes
         */
        function parseNode(str, parseList, currentIndex, fileInfo, callback) {
            var result;
            var returnNodes = [];
            var parser = parserInput;
            try {
                parser.start(str, false, function fail(msg, index) {
                    callback({
                        message: msg,
                        index: index + currentIndex
                    });
                });
                for (var x = 0, p = void 0, i = void 0; (p = parseList[x]); x++) {
                    i = parser.i;
                    result = parsers[p]();
                    if (result) {
                        try {
                            result._index = i + currentIndex;
                            result._fileInfo = fileInfo;
                        }
                        catch (e) { }
                        returnNodes.push(result);
                    }
                    else {
                        returnNodes.push(null);
                    }
                }
                var endInfo = parser.end();
                if (endInfo.isFinished) {
                    callback(null, returnNodes);
                }
                else {
                    callback(true, null);
                }
            }
            catch (e) {
                throw new less_error_1.default({
                    index: e.index + currentIndex,
                    message: e.message
                }, imports, fileInfo.filename);
            }
        }
        //
        // The Parser
        //
        return {
            parserInput: parserInput,
            imports: imports,
            fileInfo: fileInfo,
            parseNode: parseNode,
            //
            // Parse an input string into an abstract syntax tree,
            // @param str A string containing 'less' markup
            // @param callback call `callback` when done.
            // @param [additionalData] An optional map which can contains vars - a map (key, value) of variables to apply
            //
            parse: function (str, callback, additionalData) {
                var root;
                var err = null;
                var globalVars;
                var modifyVars;
                var ignored;
                var preText = '';
                // Optionally disable @plugin parsing
                if (additionalData && additionalData.disablePluginRule) {
                    parsers.plugin = function () {
                        var dir = parserInput.$re(/^@plugin?\s+/);
                        if (dir) {
                            error('@plugin statements are not allowed when disablePluginRule is set to true');
                        }
                    };
                }
                ;
                globalVars = (additionalData && additionalData.globalVars) ? Parser.serializeVars(additionalData.globalVars) + "\n" : '';
                modifyVars = (additionalData && additionalData.modifyVars) ? "\n" + Parser.serializeVars(additionalData.modifyVars) : '';
                if (context.pluginManager) {
                    var preProcessors = context.pluginManager.getPreProcessors();
                    for (var i = 0; i < preProcessors.length; i++) {
                        str = preProcessors[i].process(str, { context: context, imports: imports, fileInfo: fileInfo });
                    }
                }
                if (globalVars || (additionalData && additionalData.banner)) {
                    preText = ((additionalData && additionalData.banner) ? additionalData.banner : '') + globalVars;
                    ignored = imports.contentsIgnoredChars;
                    ignored[fileInfo.filename] = ignored[fileInfo.filename] || 0;
                    ignored[fileInfo.filename] += preText.length;
                }
                str = str.replace(/\r\n?/g, '\n');
                // Remove potential UTF Byte Order Mark
                str = preText + str.replace(/^\uFEFF/, '') + modifyVars;
                imports.contents[fileInfo.filename] = str;
                // Start with the primary rule.
                // The whole syntax tree is held under a Ruleset node,
                // with the `root` property set to true, so no `{}` are
                // output. The callback is called when the input is parsed.
                try {
                    parserInput.start(str, context.chunkInput, function fail(msg, index) {
                        throw new less_error_1.default({
                            index: index,
                            type: 'Parse',
                            message: msg,
                            filename: fileInfo.filename
                        }, imports);
                    });
                    tree_1.default.Node.prototype.parse = this;
                    root = new tree_1.default.Ruleset(null, this.parsers.primary());
                    tree_1.default.Node.prototype.rootNode = root;
                    root.root = true;
                    root.firstRoot = true;
                    root.functionRegistry = function_registry_1.default.inherit();
                }
                catch (e) {
                    return callback(new less_error_1.default(e, imports, fileInfo.filename));
                }
                // If `i` is smaller than the `input.length - 1`,
                // it means the parser wasn't able to parse the whole
                // string, so we've got a parsing error.
                //
                // We try to extract a \n delimited string,
                // showing the line where the parse error occurred.
                // We split it up into two parts (the part which parsed,
                // and the part which didn't), so we can color them differently.
                var endInfo = parserInput.end();
                if (!endInfo.isFinished) {
                    var message = endInfo.furthestPossibleErrorMessage;
                    if (!message) {
                        message = 'Unrecognised input';
                        if (endInfo.furthestChar === '}') {
                            message += '. Possibly missing opening \'{\'';
                        }
                        else if (endInfo.furthestChar === ')') {
                            message += '. Possibly missing opening \'(\'';
                        }
                        else if (endInfo.furthestReachedEnd) {
                            message += '. Possibly missing something';
                        }
                    }
                    err = new less_error_1.default({
                        type: 'Parse',
                        message: message,
                        index: endInfo.furthest,
                        filename: fileInfo.filename
                    }, imports);
                }
                var finish = function (e) {
                    e = err || e || imports.error;
                    if (e) {
                        if (!(e instanceof less_error_1.default)) {
                            e = new less_error_1.default(e, imports, fileInfo.filename);
                        }
                        return callback(e);
                    }
                    else {
                        return callback(null, root);
                    }
                };
                if (context.processImports !== false) {
                    new visitors_1.default.ImportVisitor(imports, finish)
                        .run(root);
                }
                else {
                    return finish();
                }
            },
            //
            // Here in, the parsing rules/functions
            //
            // The basic structure of the syntax tree generated is as follows:
            //
            //   Ruleset ->  Declaration -> Value -> Expression -> Entity
            //
            // Here's some Less code:
            //
            //    .class {
            //      color: #fff;
            //      border: 1px solid #000;
            //      width: @w + 4px;
            //      > .child {...}
            //    }
            //
            // And here's what the parse tree might look like:
            //
            //     Ruleset (Selector '.class', [
            //         Declaration ("color",  Value ([Expression [Color #fff]]))
            //         Declaration ("border", Value ([Expression [Dimension 1px][Keyword "solid"][Color #000]]))
            //         Declaration ("width",  Value ([Expression [Operation " + " [Variable "@w"][Dimension 4px]]]))
            //         Ruleset (Selector [Element '>', '.child'], [...])
            //     ])
            //
            //  In general, most rules will try to parse a token with the `$re()` function, and if the return
            //  value is truly, will return a new node, of the relevant type. Sometimes, we need to check
            //  first, before parsing, that's when we use `peek()`.
            //
            parsers: parsers = {
                //
                // The `primary` rule is the *entry* and *exit* point of the parser.
                // The rules here can appear at any level of the parse tree.
                //
                // The recursive nature of the grammar is an interplay between the `block`
                // rule, which represents `{ ... }`, the `ruleset` rule, and this `primary` rule,
                // as represented by this simplified grammar:
                //
                //     primary  →  (ruleset | declaration)+
                //     ruleset  →  selector+ block
                //     block    →  '{' primary '}'
                //
                // Only at one point is the primary rule not called from the
                // block rule: at the root level.
                //
                primary: function () {
                    var mixin = this.mixin;
                    var root = [];
                    var node;
                    while (true) {
                        while (true) {
                            node = this.comment();
                            if (!node) {
                                break;
                            }
                            root.push(node);
                        }
                        // always process comments before deciding if finished
                        if (parserInput.finished) {
                            break;
                        }
                        if (parserInput.peek('}')) {
                            break;
                        }
                        node = this.extendRule();
                        if (node) {
                            root = root.concat(node);
                            continue;
                        }
                        node = mixin.definition() || this.declaration() || mixin.call(false, false) ||
                            this.ruleset() || this.variableCall() || this.entities.call() || this.atrule();
                        if (node) {
                            root.push(node);
                        }
                        else {
                            var foundSemiColon = false;
                            while (parserInput.$char(';')) {
                                foundSemiColon = true;
                            }
                            if (!foundSemiColon) {
                                break;
                            }
                        }
                    }
                    return root;
                },
                // comments are collected by the main parsing mechanism and then assigned to nodes
                // where the current structure allows it
                comment: function () {
                    if (parserInput.commentStore.length) {
                        var comment = parserInput.commentStore.shift();
                        return new (tree_1.default.Comment)(comment.text, comment.isLineComment, comment.index, fileInfo);
                    }
                },
                //
                // Entities are tokens which can be found inside an Expression
                //
                entities: {
                    mixinLookup: function () {
                        return parsers.mixin.call(true, true);
                    },
                    //
                    // A string, which supports escaping " and '
                    //
                    //     "milky way" 'he\'s the one!'
                    //
                    quoted: function (forceEscaped) {
                        var str;
                        var index = parserInput.i;
                        var isEscaped = false;
                        parserInput.save();
                        if (parserInput.$char('~')) {
                            isEscaped = true;
                        }
                        else if (forceEscaped) {
                            parserInput.restore();
                            return;
                        }
                        str = parserInput.$quoted();
                        if (!str) {
                            parserInput.restore();
                            return;
                        }
                        parserInput.forget();
                        return new (tree_1.default.Quoted)(str.charAt(0), str.substr(1, str.length - 2), isEscaped, index, fileInfo);
                    },
                    //
                    // A catch-all word, such as:
                    //
                    //     black border-collapse
                    //
                    keyword: function () {
                        var k = parserInput.$char('%') || parserInput.$re(/^\[?(?:[\w-]|\\(?:[A-Fa-f0-9]{1,6} ?|[^A-Fa-f0-9]))+\]?/);
                        if (k) {
                            return tree_1.default.Color.fromKeyword(k) || new (tree_1.default.Keyword)(k);
                        }
                    },
                    //
                    // A function call
                    //
                    //     rgb(255, 0, 255)
                    //
                    // The arguments are parsed with the `entities.arguments` parser.
                    //
                    call: function () {
                        var name;
                        var args;
                        var func;
                        var index = parserInput.i;
                        // http://jsperf.com/case-insensitive-regex-vs-strtolower-then-regex/18
                        if (parserInput.peek(/^url\(/i)) {
                            return;
                        }
                        parserInput.save();
                        name = parserInput.$re(/^([\w-]+|%|~|progid:[\w\.]+)\(/);
                        if (!name) {
                            parserInput.forget();
                            return;
                        }
                        name = name[1];
                        func = this.customFuncCall(name);
                        if (func) {
                            args = func.parse();
                            if (args && func.stop) {
                                parserInput.forget();
                                return args;
                            }
                        }
                        args = this.arguments(args);
                        if (!parserInput.$char(')')) {
                            parserInput.restore('Could not parse call arguments or missing \')\'');
                            return;
                        }
                        parserInput.forget();
                        return new (tree_1.default.Call)(name, args, index, fileInfo);
                    },
                    //
                    // Parsing rules for functions with non-standard args, e.g.:
                    //
                    //     boolean(not(2 > 1))
                    //
                    //     This is a quick prototype, to be modified/improved when
                    //     more custom-parsed funcs come (e.g. `selector(...)`)
                    //
                    customFuncCall: function (name) {
                        /* Ideally the table is to be moved out of here for faster perf.,
                           but it's quite tricky since it relies on all these `parsers`
                           and `expect` available only here */
                        return {
                            alpha: f(parsers.ieAlpha, true),
                            boolean: f(condition),
                            'if': f(condition)
                        }[name.toLowerCase()];
                        function f(parse, stop) {
                            return {
                                parse: parse,
                                stop: stop // when true - stop after parse() and return its result, 
                                // otherwise continue for plain args
                            };
                        }
                        function condition() {
                            return [expect(parsers.condition, 'expected condition')];
                        }
                    },
                    arguments: function (prevArgs) {
                        var argsComma = prevArgs || [];
                        var argsSemiColon = [];
                        var isSemiColonSeparated;
                        var value;
                        parserInput.save();
                        while (true) {
                            if (prevArgs) {
                                prevArgs = false;
                            }
                            else {
                                value = parsers.detachedRuleset() || this.assignment() || parsers.expression();
                                if (!value) {
                                    break;
                                }
                                if (value.value && value.value.length == 1) {
                                    value = value.value[0];
                                }
                                argsComma.push(value);
                            }
                            if (parserInput.$char(',')) {
                                continue;
                            }
                            if (parserInput.$char(';') || isSemiColonSeparated) {
                                isSemiColonSeparated = true;
                                value = (argsComma.length < 1) ? argsComma[0]
                                    : new tree_1.default.Value(argsComma);
                                argsSemiColon.push(value);
                                argsComma = [];
                            }
                        }
                        parserInput.forget();
                        return isSemiColonSeparated ? argsSemiColon : argsComma;
                    },
                    literal: function () {
                        return this.dimension() ||
                            this.color() ||
                            this.quoted() ||
                            this.unicodeDescriptor();
                    },
                    // Assignments are argument entities for calls.
                    // They are present in ie filter properties as shown below.
                    //
                    //     filter: progid:DXImageTransform.Microsoft.Alpha( *opacity=50* )
                    //
                    assignment: function () {
                        var key;
                        var value;
                        parserInput.save();
                        key = parserInput.$re(/^\w+(?=\s?=)/i);
                        if (!key) {
                            parserInput.restore();
                            return;
                        }
                        if (!parserInput.$char('=')) {
                            parserInput.restore();
                            return;
                        }
                        value = parsers.entity();
                        if (value) {
                            parserInput.forget();
                            return new (tree_1.default.Assignment)(key, value);
                        }
                        else {
                            parserInput.restore();
                        }
                    },
                    //
                    // Parse url() tokens
                    //
                    // We use a specific rule for urls, because they don't really behave like
                    // standard function calls. The difference is that the argument doesn't have
                    // to be enclosed within a string, so it can't be parsed as an Expression.
                    //
                    url: function () {
                        var value;
                        var index = parserInput.i;
                        parserInput.autoCommentAbsorb = false;
                        if (!parserInput.$str('url(')) {
                            parserInput.autoCommentAbsorb = true;
                            return;
                        }
                        value = this.quoted() || this.variable() || this.property() ||
                            parserInput.$re(/^(?:(?:\\[\(\)'"])|[^\(\)'"])+/) || '';
                        parserInput.autoCommentAbsorb = true;
                        expectChar(')');
                        return new (tree_1.default.URL)((value.value != null ||
                            value instanceof tree_1.default.Variable ||
                            value instanceof tree_1.default.Property) ?
                            value : new (tree_1.default.Anonymous)(value, index), index, fileInfo);
                    },
                    //
                    // A Variable entity, such as `@fink`, in
                    //
                    //     width: @fink + 2px
                    //
                    // We use a different parser for variable definitions,
                    // see `parsers.variable`.
                    //
                    variable: function () {
                        var ch;
                        var name;
                        var index = parserInput.i;
                        parserInput.save();
                        if (parserInput.currentChar() === '@' && (name = parserInput.$re(/^@@?[\w-]+/))) {
                            ch = parserInput.currentChar();
                            if (ch === '(' || ch === '[' && !parserInput.prevChar().match(/^\s/)) {
                                // this may be a VariableCall lookup
                                var result = parsers.variableCall(name);
                                if (result) {
                                    parserInput.forget();
                                    return result;
                                }
                            }
                            parserInput.forget();
                            return new (tree_1.default.Variable)(name, index, fileInfo);
                        }
                        parserInput.restore();
                    },
                    // A variable entity using the protective {} e.g. @{var}
                    variableCurly: function () {
                        var curly;
                        var index = parserInput.i;
                        if (parserInput.currentChar() === '@' && (curly = parserInput.$re(/^@\{([\w-]+)\}/))) {
                            return new (tree_1.default.Variable)("@" + curly[1], index, fileInfo);
                        }
                    },
                    //
                    // A Property accessor, such as `$color`, in
                    //
                    //     background-color: $color
                    //
                    property: function () {
                        var name;
                        var index = parserInput.i;
                        if (parserInput.currentChar() === '$' && (name = parserInput.$re(/^\$[\w-]+/))) {
                            return new (tree_1.default.Property)(name, index, fileInfo);
                        }
                    },
                    // A property entity useing the protective {} e.g. ${prop}
                    propertyCurly: function () {
                        var curly;
                        var index = parserInput.i;
                        if (parserInput.currentChar() === '$' && (curly = parserInput.$re(/^\$\{([\w-]+)\}/))) {
                            return new (tree_1.default.Property)("$" + curly[1], index, fileInfo);
                        }
                    },
                    //
                    // A Hexadecimal color
                    //
                    //     #4F3C2F
                    //
                    // `rgb` and `hsl` colors are parsed through the `entities.call` parser.
                    //
                    color: function () {
                        var rgb;
                        parserInput.save();
                        if (parserInput.currentChar() === '#' && (rgb = parserInput.$re(/^#([A-Fa-f0-9]{8}|[A-Fa-f0-9]{6}|[A-Fa-f0-9]{3,4})([\w.#\[])?/))) {
                            if (!rgb[2]) {
                                parserInput.forget();
                                return new (tree_1.default.Color)(rgb[1], undefined, rgb[0]);
                            }
                        }
                        parserInput.restore();
                    },
                    colorKeyword: function () {
                        parserInput.save();
                        var autoCommentAbsorb = parserInput.autoCommentAbsorb;
                        parserInput.autoCommentAbsorb = false;
                        var k = parserInput.$re(/^[_A-Za-z-][_A-Za-z0-9-]+/);
                        parserInput.autoCommentAbsorb = autoCommentAbsorb;
                        if (!k) {
                            parserInput.forget();
                            return;
                        }
                        parserInput.restore();
                        var color = tree_1.default.Color.fromKeyword(k);
                        if (color) {
                            parserInput.$str(k);
                            return color;
                        }
                    },
                    //
                    // A Dimension, that is, a number and a unit
                    //
                    //     0.5em 95%
                    //
                    dimension: function () {
                        if (parserInput.peekNotNumeric()) {
                            return;
                        }
                        var value = parserInput.$re(/^([+-]?\d*\.?\d+)(%|[a-z_]+)?/i);
                        if (value) {
                            return new (tree_1.default.Dimension)(value[1], value[2]);
                        }
                    },
                    //
                    // A unicode descriptor, as is used in unicode-range
                    //
                    // U+0??  or U+00A1-00A9
                    //
                    unicodeDescriptor: function () {
                        var ud;
                        ud = parserInput.$re(/^U\+[0-9a-fA-F?]+(\-[0-9a-fA-F?]+)?/);
                        if (ud) {
                            return new (tree_1.default.UnicodeDescriptor)(ud[0]);
                        }
                    },
                    //
                    // JavaScript code to be evaluated
                    //
                    //     `window.location.href`
                    //
                    javascript: function () {
                        var js;
                        var index = parserInput.i;
                        parserInput.save();
                        var escape = parserInput.$char('~');
                        var jsQuote = parserInput.$char('`');
                        if (!jsQuote) {
                            parserInput.restore();
                            return;
                        }
                        js = parserInput.$re(/^[^`]*`/);
                        if (js) {
                            parserInput.forget();
                            return new (tree_1.default.JavaScript)(js.substr(0, js.length - 1), Boolean(escape), index, fileInfo);
                        }
                        parserInput.restore('invalid javascript definition');
                    }
                },
                //
                // The variable part of a variable definition. Used in the `rule` parser
                //
                //     @fink:
                //
                variable: function () {
                    var name;
                    if (parserInput.currentChar() === '@' && (name = parserInput.$re(/^(@[\w-]+)\s*:/))) {
                        return name[1];
                    }
                },
                //
                // Call a variable value to retrieve a detached ruleset
                // or a value from a detached ruleset's rules.
                //
                //     @fink();
                //     @fink;
                //     color: @fink[@color];
                //
                variableCall: function (parsedName) {
                    var lookups;
                    var i = parserInput.i;
                    var inValue = !!parsedName;
                    var name = parsedName;
                    parserInput.save();
                    if (name || (parserInput.currentChar() === '@'
                        && (name = parserInput.$re(/^(@[\w-]+)(\(\s*\))?/)))) {
                        lookups = this.mixin.ruleLookups();
                        if (!lookups && ((inValue && parserInput.$str('()') !== '()') || (name[2] !== '()'))) {
                            parserInput.restore('Missing \'[...]\' lookup in variable call');
                            return;
                        }
                        if (!inValue) {
                            name = name[1];
                        }
                        var call = new tree_1.default.VariableCall(name, i, fileInfo);
                        if (!inValue && parsers.end()) {
                            parserInput.forget();
                            return call;
                        }
                        else {
                            parserInput.forget();
                            return new tree_1.default.NamespaceValue(call, lookups, i, fileInfo);
                        }
                    }
                    parserInput.restore();
                },
                //
                // extend syntax - used to extend selectors
                //
                extend: function (isRule) {
                    var elements;
                    var e;
                    var index = parserInput.i;
                    var option;
                    var extendList;
                    var extend;
                    if (!parserInput.$str(isRule ? '&:extend(' : ':extend(')) {
                        return;
                    }
                    do {
                        option = null;
                        elements = null;
                        while (!(option = parserInput.$re(/^(all)(?=\s*(\)|,))/))) {
                            e = this.element();
                            if (!e) {
                                break;
                            }
                            if (elements) {
                                elements.push(e);
                            }
                            else {
                                elements = [e];
                            }
                        }
                        option = option && option[1];
                        if (!elements) {
                            error('Missing target selector for :extend().');
                        }
                        extend = new (tree_1.default.Extend)(new (tree_1.default.Selector)(elements), option, index, fileInfo);
                        if (extendList) {
                            extendList.push(extend);
                        }
                        else {
                            extendList = [extend];
                        }
                    } while (parserInput.$char(','));
                    expect(/^\)/);
                    if (isRule) {
                        expect(/^;/);
                    }
                    return extendList;
                },
                //
                // extendRule - used in a rule to extend all the parent selectors
                //
                extendRule: function () {
                    return this.extend(true);
                },
                //
                // Mixins
                //
                mixin: {
                    //
                    // A Mixin call, with an optional argument list
                    //
                    //     #mixins > .square(#fff);
                    //     #mixins.square(#fff);
                    //     .rounded(4px, black);
                    //     .button;
                    //
                    // We can lookup / return a value using the lookup syntax:
                    //
                    //     color: #mixin.square(#fff)[@color];
                    //
                    // The `while` loop is there because mixins can be
                    // namespaced, but we only support the child and descendant
                    // selector for now.
                    //
                    call: function (inValue, getLookup) {
                        var s = parserInput.currentChar();
                        var important = false;
                        var lookups;
                        var index = parserInput.i;
                        var elements;
                        var args;
                        var hasParens;
                        if (s !== '.' && s !== '#') {
                            return;
                        }
                        parserInput.save(); // stop us absorbing part of an invalid selector
                        elements = this.elements();
                        if (elements) {
                            if (parserInput.$char('(')) {
                                args = this.args(true).args;
                                expectChar(')');
                                hasParens = true;
                            }
                            if (getLookup !== false) {
                                lookups = this.ruleLookups();
                            }
                            if (getLookup === true && !lookups) {
                                parserInput.restore();
                                return;
                            }
                            if (inValue && !lookups && !hasParens) {
                                // This isn't a valid in-value mixin call
                                parserInput.restore();
                                return;
                            }
                            if (!inValue && parsers.important()) {
                                important = true;
                            }
                            if (inValue || parsers.end()) {
                                parserInput.forget();
                                var mixin = new (tree_1.default.mixin.Call)(elements, args, index, fileInfo, !lookups && important);
                                if (lookups) {
                                    return new tree_1.default.NamespaceValue(mixin, lookups);
                                }
                                else {
                                    return mixin;
                                }
                            }
                        }
                        parserInput.restore();
                    },
                    /**
                     * Matching elements for mixins
                     * (Start with . or # and can have > )
                     */
                    elements: function () {
                        var elements;
                        var e;
                        var c;
                        var elem;
                        var elemIndex;
                        var re = /^[#.](?:[\w-]|\\(?:[A-Fa-f0-9]{1,6} ?|[^A-Fa-f0-9]))+/;
                        while (true) {
                            elemIndex = parserInput.i;
                            e = parserInput.$re(re);
                            if (!e) {
                                break;
                            }
                            elem = new (tree_1.default.Element)(c, e, false, elemIndex, fileInfo);
                            if (elements) {
                                elements.push(elem);
                            }
                            else {
                                elements = [elem];
                            }
                            c = parserInput.$char('>');
                        }
                        return elements;
                    },
                    args: function (isCall) {
                        var entities = parsers.entities;
                        var returner = { args: null, variadic: false };
                        var expressions = [];
                        var argsSemiColon = [];
                        var argsComma = [];
                        var isSemiColonSeparated;
                        var expressionContainsNamed;
                        var name;
                        var nameLoop;
                        var value;
                        var arg;
                        var expand;
                        var hasSep = true;
                        parserInput.save();
                        while (true) {
                            if (isCall) {
                                arg = parsers.detachedRuleset() || parsers.expression();
                            }
                            else {
                                parserInput.commentStore.length = 0;
                                if (parserInput.$str('...')) {
                                    returner.variadic = true;
                                    if (parserInput.$char(';') && !isSemiColonSeparated) {
                                        isSemiColonSeparated = true;
                                    }
                                    (isSemiColonSeparated ? argsSemiColon : argsComma)
                                        .push({ variadic: true });
                                    break;
                                }
                                arg = entities.variable() || entities.property() || entities.literal() || entities.keyword() || this.call(true);
                            }
                            if (!arg || !hasSep) {
                                break;
                            }
                            nameLoop = null;
                            if (arg.throwAwayComments) {
                                arg.throwAwayComments();
                            }
                            value = arg;
                            var val = null;
                            if (isCall) {
                                // Variable
                                if (arg.value && arg.value.length == 1) {
                                    val = arg.value[0];
                                }
                            }
                            else {
                                val = arg;
                            }
                            if (val && (val instanceof tree_1.default.Variable || val instanceof tree_1.default.Property)) {
                                if (parserInput.$char(':')) {
                                    if (expressions.length > 0) {
                                        if (isSemiColonSeparated) {
                                            error('Cannot mix ; and , as delimiter types');
                                        }
                                        expressionContainsNamed = true;
                                    }
                                    value = parsers.detachedRuleset() || parsers.expression();
                                    if (!value) {
                                        if (isCall) {
                                            error('could not understand value for named argument');
                                        }
                                        else {
                                            parserInput.restore();
                                            returner.args = [];
                                            return returner;
                                        }
                                    }
                                    nameLoop = (name = val.name);
                                }
                                else if (parserInput.$str('...')) {
                                    if (!isCall) {
                                        returner.variadic = true;
                                        if (parserInput.$char(';') && !isSemiColonSeparated) {
                                            isSemiColonSeparated = true;
                                        }
                                        (isSemiColonSeparated ? argsSemiColon : argsComma)
                                            .push({ name: arg.name, variadic: true });
                                        break;
                                    }
                                    else {
                                        expand = true;
                                    }
                                }
                                else if (!isCall) {
                                    name = nameLoop = val.name;
                                    value = null;
                                }
                            }
                            if (value) {
                                expressions.push(value);
                            }
                            argsComma.push({ name: nameLoop, value: value, expand: expand });
                            if (parserInput.$char(',')) {
                                hasSep = true;
                                continue;
                            }
                            hasSep = parserInput.$char(';') === ';';
                            if (hasSep || isSemiColonSeparated) {
                                if (expressionContainsNamed) {
                                    error('Cannot mix ; and , as delimiter types');
                                }
                                isSemiColonSeparated = true;
                                if (expressions.length > 1) {
                                    value = new (tree_1.default.Value)(expressions);
                                }
                                argsSemiColon.push({ name: name, value: value, expand: expand });
                                name = null;
                                expressions = [];
                                expressionContainsNamed = false;
                            }
                        }
                        parserInput.forget();
                        returner.args = isSemiColonSeparated ? argsSemiColon : argsComma;
                        return returner;
                    },
                    //
                    // A Mixin definition, with a list of parameters
                    //
                    //     .rounded (@radius: 2px, @color) {
                    //        ...
                    //     }
                    //
                    // Until we have a finer grained state-machine, we have to
                    // do a look-ahead, to make sure we don't have a mixin call.
                    // See the `rule` function for more information.
                    //
                    // We start by matching `.rounded (`, and then proceed on to
                    // the argument list, which has optional default values.
                    // We store the parameters in `params`, with a `value` key,
                    // if there is a value, such as in the case of `@radius`.
                    //
                    // Once we've got our params list, and a closing `)`, we parse
                    // the `{...}` block.
                    //
                    definition: function () {
                        var name;
                        var params = [];
                        var match;
                        var ruleset;
                        var cond;
                        var variadic = false;
                        if ((parserInput.currentChar() !== '.' && parserInput.currentChar() !== '#') ||
                            parserInput.peek(/^[^{]*\}/)) {
                            return;
                        }
                        parserInput.save();
                        match = parserInput.$re(/^([#.](?:[\w-]|\\(?:[A-Fa-f0-9]{1,6} ?|[^A-Fa-f0-9]))+)\s*\(/);
                        if (match) {
                            name = match[1];
                            var argInfo = this.args(false);
                            params = argInfo.args;
                            variadic = argInfo.variadic;
                            // .mixincall("@{a}");
                            // looks a bit like a mixin definition..
                            // also
                            // .mixincall(@a: {rule: set;});
                            // so we have to be nice and restore
                            if (!parserInput.$char(')')) {
                                parserInput.restore('Missing closing \')\'');
                                return;
                            }
                            parserInput.commentStore.length = 0;
                            if (parserInput.$str('when')) { // Guard
                                cond = expect(parsers.conditions, 'expected condition');
                            }
                            ruleset = parsers.block();
                            if (ruleset) {
                                parserInput.forget();
                                return new (tree_1.default.mixin.Definition)(name, params, ruleset, cond, variadic);
                            }
                            else {
                                parserInput.restore();
                            }
                        }
                        else {
                            parserInput.restore();
                        }
                    },
                    ruleLookups: function () {
                        var rule;
                        var args;
                        var lookups = [];
                        if (parserInput.currentChar() !== '[') {
                            return;
                        }
                        while (true) {
                            parserInput.save();
                            args = null;
                            rule = this.lookupValue();
                            if (!rule && rule !== '') {
                                parserInput.restore();
                                break;
                            }
                            lookups.push(rule);
                            parserInput.forget();
                        }
                        if (lookups.length > 0) {
                            return lookups;
                        }
                    },
                    lookupValue: function () {
                        parserInput.save();
                        if (!parserInput.$char('[')) {
                            parserInput.restore();
                            return;
                        }
                        var name = parserInput.$re(/^(?:[@$]{0,2})[_a-zA-Z0-9-]*/);
                        if (!parserInput.$char(']')) {
                            parserInput.restore();
                            return;
                        }
                        if (name || name === '') {
                            parserInput.forget();
                            return name;
                        }
                        parserInput.restore();
                    }
                },
                //
                // Entities are the smallest recognized token,
                // and can be found inside a rule's value.
                //
                entity: function () {
                    var entities = this.entities;
                    return this.comment() || entities.literal() || entities.variable() || entities.url() ||
                        entities.property() || entities.call() || entities.keyword() || this.mixin.call(true) ||
                        entities.javascript();
                },
                //
                // A Declaration terminator. Note that we use `peek()` to check for '}',
                // because the `block` rule will be expecting it, but we still need to make sure
                // it's there, if ';' was omitted.
                //
                end: function () {
                    return parserInput.$char(';') || parserInput.peek('}');
                },
                //
                // IE's alpha function
                //
                //     alpha(opacity=88)
                //
                ieAlpha: function () {
                    var value;
                    // http://jsperf.com/case-insensitive-regex-vs-strtolower-then-regex/18
                    if (!parserInput.$re(/^opacity=/i)) {
                        return;
                    }
                    value = parserInput.$re(/^\d+/);
                    if (!value) {
                        value = expect(parsers.entities.variable, 'Could not parse alpha');
                        value = "@{" + value.name.slice(1) + "}";
                    }
                    expectChar(')');
                    return new tree_1.default.Quoted('', "alpha(opacity=" + value + ")");
                },
                //
                // A Selector Element
                //
                //     div
                //     + h1
                //     #socks
                //     input[type="text"]
                //
                // Elements are the building blocks for Selectors,
                // they are made out of a `Combinator` (see combinator rule),
                // and an element name, such as a tag a class, or `*`.
                //
                element: function () {
                    var e;
                    var c;
                    var v;
                    var index = parserInput.i;
                    c = this.combinator();
                    e = parserInput.$re(/^(?:\d+\.\d+|\d+)%/) ||
                        parserInput.$re(/^(?:[.#]?|:*)(?:[\w-]|[^\x00-\x9f]|\\(?:[A-Fa-f0-9]{1,6} ?|[^A-Fa-f0-9]))+/) ||
                        parserInput.$char('*') || parserInput.$char('&') || this.attribute() ||
                        parserInput.$re(/^\([^&()@]+\)/) || parserInput.$re(/^[\.#:](?=@)/) ||
                        this.entities.variableCurly();
                    if (!e) {
                        parserInput.save();
                        if (parserInput.$char('(')) {
                            if ((v = this.selector(false)) && parserInput.$char(')')) {
                                e = new (tree_1.default.Paren)(v);
                                parserInput.forget();
                            }
                            else {
                                parserInput.restore('Missing closing \')\'');
                            }
                        }
                        else {
                            parserInput.forget();
                        }
                    }
                    if (e) {
                        return new (tree_1.default.Element)(c, e, e instanceof tree_1.default.Variable, index, fileInfo);
                    }
                },
                //
                // Combinators combine elements together, in a Selector.
                //
                // Because our parser isn't white-space sensitive, special care
                // has to be taken, when parsing the descendant combinator, ` `,
                // as it's an empty space. We have to check the previous character
                // in the input, to see if it's a ` ` character. More info on how
                // we deal with this in *combinator.js*.
                //
                combinator: function () {
                    var c = parserInput.currentChar();
                    if (c === '/') {
                        parserInput.save();
                        var slashedCombinator = parserInput.$re(/^\/[a-z]+\//i);
                        if (slashedCombinator) {
                            parserInput.forget();
                            return new (tree_1.default.Combinator)(slashedCombinator);
                        }
                        parserInput.restore();
                    }
                    if (c === '>' || c === '+' || c === '~' || c === '|' || c === '^') {
                        parserInput.i++;
                        if (c === '^' && parserInput.currentChar() === '^') {
                            c = '^^';
                            parserInput.i++;
                        }
                        while (parserInput.isWhitespace()) {
                            parserInput.i++;
                        }
                        return new (tree_1.default.Combinator)(c);
                    }
                    else if (parserInput.isWhitespace(-1)) {
                        return new (tree_1.default.Combinator)(' ');
                    }
                    else {
                        return new (tree_1.default.Combinator)(null);
                    }
                },
                //
                // A CSS Selector
                // with less extensions e.g. the ability to extend and guard
                //
                //     .class > div + h1
                //     li a:hover
                //
                // Selectors are made out of one or more Elements, see above.
                //
                selector: function (isLess) {
                    var index = parserInput.i;
                    var elements;
                    var extendList;
                    var c;
                    var e;
                    var allExtends;
                    var when;
                    var condition;
                    isLess = isLess !== false;
                    while ((isLess && (extendList = this.extend())) || (isLess && (when = parserInput.$str('when'))) || (e = this.element())) {
                        if (when) {
                            condition = expect(this.conditions, 'expected condition');
                        }
                        else if (condition) {
                            error('CSS guard can only be used at the end of selector');
                        }
                        else if (extendList) {
                            if (allExtends) {
                                allExtends = allExtends.concat(extendList);
                            }
                            else {
                                allExtends = extendList;
                            }
                        }
                        else {
                            if (allExtends) {
                                error('Extend can only be used at the end of selector');
                            }
                            c = parserInput.currentChar();
                            if (elements) {
                                elements.push(e);
                            }
                            else {
                                elements = [e];
                            }
                            e = null;
                        }
                        if (c === '{' || c === '}' || c === ';' || c === ',' || c === ')') {
                            break;
                        }
                    }
                    if (elements) {
                        return new (tree_1.default.Selector)(elements, allExtends, condition, index, fileInfo);
                    }
                    if (allExtends) {
                        error('Extend must be used to extend a selector, it cannot be used on its own');
                    }
                },
                selectors: function () {
                    var s;
                    var selectors;
                    while (true) {
                        s = this.selector();
                        if (!s) {
                            break;
                        }
                        if (selectors) {
                            selectors.push(s);
                        }
                        else {
                            selectors = [s];
                        }
                        parserInput.commentStore.length = 0;
                        if (s.condition && selectors.length > 1) {
                            error("Guards are only currently allowed on a single selector.");
                        }
                        if (!parserInput.$char(',')) {
                            break;
                        }
                        if (s.condition) {
                            error("Guards are only currently allowed on a single selector.");
                        }
                        parserInput.commentStore.length = 0;
                    }
                    return selectors;
                },
                attribute: function () {
                    if (!parserInput.$char('[')) {
                        return;
                    }
                    var entities = this.entities;
                    var key;
                    var val;
                    var op;
                    //
                    // case-insensitive flag
                    // e.g. [attr operator value i]
                    //
                    var cif;
                    if (!(key = entities.variableCurly())) {
                        key = expect(/^(?:[_A-Za-z0-9-\*]*\|)?(?:[_A-Za-z0-9-]|\\.)+/);
                    }
                    op = parserInput.$re(/^[|~*$^]?=/);
                    if (op) {
                        val = entities.quoted() || parserInput.$re(/^[0-9]+%/) || parserInput.$re(/^[\w-]+/) || entities.variableCurly();
                        if (val) {
                            cif = parserInput.$re(/^[iIsS]/);
                        }
                    }
                    expectChar(']');
                    return new (tree_1.default.Attribute)(key, op, val, cif);
                },
                //
                // The `block` rule is used by `ruleset` and `mixin.definition`.
                // It's a wrapper around the `primary` rule, with added `{}`.
                //
                block: function () {
                    var content;
                    if (parserInput.$char('{') && (content = this.primary()) && parserInput.$char('}')) {
                        return content;
                    }
                },
                blockRuleset: function () {
                    var block = this.block();
                    if (block) {
                        block = new tree_1.default.Ruleset(null, block);
                    }
                    return block;
                },
                detachedRuleset: function () {
                    var argInfo;
                    var params;
                    var variadic;
                    parserInput.save();
                    if (parserInput.$re(/^[.#]\(/)) {
                        /**
                         * DR args currently only implemented for each() function, and not
                         * yet settable as `@dr: #(@arg) {}`
                         * This should be done when DRs are merged with mixins.
                         * See: https://github.com/less/less-meta/issues/16
                         */
                        argInfo = this.mixin.args(false);
                        params = argInfo.args;
                        variadic = argInfo.variadic;
                        if (!parserInput.$char(')')) {
                            parserInput.restore();
                            return;
                        }
                    }
                    var blockRuleset = this.blockRuleset();
                    if (blockRuleset) {
                        parserInput.forget();
                        if (params) {
                            return new tree_1.default.mixin.Definition(null, params, blockRuleset, null, variadic);
                        }
                        return new tree_1.default.DetachedRuleset(blockRuleset);
                    }
                    parserInput.restore();
                },
                //
                // div, .class, body > p {...}
                //
                ruleset: function () {
                    var selectors;
                    var rules;
                    var debugInfo;
                    parserInput.save();
                    if (context.dumpLineNumbers) {
                        debugInfo = getDebugInfo(parserInput.i);
                    }
                    selectors = this.selectors();
                    if (selectors && (rules = this.block())) {
                        parserInput.forget();
                        var ruleset = new (tree_1.default.Ruleset)(selectors, rules, context.strictImports);
                        if (context.dumpLineNumbers) {
                            ruleset.debugInfo = debugInfo;
                        }
                        return ruleset;
                    }
                    else {
                        parserInput.restore();
                    }
                },
                declaration: function () {
                    var name;
                    var value;
                    var index = parserInput.i;
                    var hasDR;
                    var c = parserInput.currentChar();
                    var important;
                    var merge;
                    var isVariable;
                    if (c === '.' || c === '#' || c === '&' || c === ':') {
                        return;
                    }
                    parserInput.save();
                    name = this.variable() || this.ruleProperty();
                    if (name) {
                        isVariable = typeof name === 'string';
                        if (isVariable) {
                            value = this.detachedRuleset();
                            if (value) {
                                hasDR = true;
                            }
                        }
                        parserInput.commentStore.length = 0;
                        if (!value) {
                            // a name returned by this.ruleProperty() is always an array of the form:
                            // [string-1, ..., string-n, ""] or [string-1, ..., string-n, "+"]
                            // where each item is a tree.Keyword or tree.Variable
                            merge = !isVariable && name.length > 1 && name.pop().value;
                            // Custom property values get permissive parsing
                            if (name[0].value && name[0].value.slice(0, 2) === '--') {
                                value = this.permissiveValue();
                            }
                            // Try to store values as anonymous
                            // If we need the value later we'll re-parse it in ruleset.parseValue
                            else {
                                value = this.anonymousValue();
                            }
                            if (value) {
                                parserInput.forget();
                                // anonymous values absorb the end ';' which is required for them to work
                                return new (tree_1.default.Declaration)(name, value, false, merge, index, fileInfo);
                            }
                            if (!value) {
                                value = this.value();
                            }
                            if (value) {
                                important = this.important();
                            }
                            else if (isVariable) {
                                // As a last resort, try permissiveValue
                                value = this.permissiveValue();
                            }
                        }
                        if (value && (this.end() || hasDR)) {
                            parserInput.forget();
                            return new (tree_1.default.Declaration)(name, value, important, merge, index, fileInfo);
                        }
                        else {
                            parserInput.restore();
                        }
                    }
                    else {
                        parserInput.restore();
                    }
                },
                anonymousValue: function () {
                    var index = parserInput.i;
                    var match = parserInput.$re(/^([^.#@\$+\/'"*`(;{}-]*);/);
                    if (match) {
                        return new (tree_1.default.Anonymous)(match[1], index);
                    }
                },
                /**
                 * Used for custom properties, at-rules, and variables (as fallback)
                 * Parses almost anything inside of {} [] () "" blocks
                 * until it reaches outer-most tokens.
                 *
                 * First, it will try to parse comments and entities to reach
                 * the end. This is mostly like the Expression parser except no
                 * math is allowed.
                 */
                permissiveValue: function (untilTokens) {
                    var i;
                    var e;
                    var done;
                    var value;
                    var tok = untilTokens || ';';
                    var index = parserInput.i;
                    var result = [];
                    function testCurrentChar() {
                        var char = parserInput.currentChar();
                        if (typeof tok === 'string') {
                            return char === tok;
                        }
                        else {
                            return tok.test(char);
                        }
                    }
                    if (testCurrentChar()) {
                        return;
                    }
                    value = [];
                    do {
                        e = this.comment();
                        if (e) {
                            value.push(e);
                            continue;
                        }
                        e = this.entity();
                        if (e) {
                            value.push(e);
                        }
                    } while (e);
                    done = testCurrentChar();
                    if (value.length > 0) {
                        value = new (tree_1.default.Expression)(value);
                        if (done) {
                            return value;
                        }
                        else {
                            result.push(value);
                        }
                        // Preserve space before $parseUntil as it will not
                        if (parserInput.prevChar() === ' ') {
                            result.push(new tree_1.default.Anonymous(' ', index));
                        }
                    }
                    parserInput.save();
                    value = parserInput.$parseUntil(tok);
                    if (value) {
                        if (typeof value === 'string') {
                            error("Expected '" + value + "'", 'Parse');
                        }
                        if (value.length === 1 && value[0] === ' ') {
                            parserInput.forget();
                            return new tree_1.default.Anonymous('', index);
                        }
                        var item = void 0;
                        for (i = 0; i < value.length; i++) {
                            item = value[i];
                            if (Array.isArray(item)) {
                                // Treat actual quotes as normal quoted values
                                result.push(new tree_1.default.Quoted(item[0], item[1], true, index, fileInfo));
                            }
                            else {
                                if (i === value.length - 1) {
                                    item = item.trim();
                                }
                                // Treat like quoted values, but replace vars like unquoted expressions
                                var quote = new tree_1.default.Quoted('\'', item, true, index, fileInfo);
                                quote.variableRegex = /@([\w-]+)/g;
                                quote.propRegex = /\$([\w-]+)/g;
                                result.push(quote);
                            }
                        }
                        parserInput.forget();
                        return new tree_1.default.Expression(result, true);
                    }
                    parserInput.restore();
                },
                //
                // An @import atrule
                //
                //     @import "lib";
                //
                // Depending on our environment, importing is done differently:
                // In the browser, it's an XHR request, in Node, it would be a
                // file-system operation. The function used for importing is
                // stored in `import`, which we pass to the Import constructor.
                //
                'import': function () {
                    var path;
                    var features;
                    var index = parserInput.i;
                    var dir = parserInput.$re(/^@import\s+/);
                    if (dir) {
                        var options = (dir ? this.importOptions() : null) || {};
                        if ((path = this.entities.quoted() || this.entities.url())) {
                            features = this.mediaFeatures();
                            if (!parserInput.$char(';')) {
                                parserInput.i = index;
                                error('missing semi-colon or unrecognised media features on import');
                            }
                            features = features && new (tree_1.default.Value)(features);
                            return new (tree_1.default.Import)(path, features, options, index, fileInfo);
                        }
                        else {
                            parserInput.i = index;
                            error('malformed import statement');
                        }
                    }
                },
                importOptions: function () {
                    var o;
                    var options = {};
                    var optionName;
                    var value;
                    // list of options, surrounded by parens
                    if (!parserInput.$char('(')) {
                        return null;
                    }
                    do {
                        o = this.importOption();
                        if (o) {
                            optionName = o;
                            value = true;
                            switch (optionName) {
                                case 'css':
                                    optionName = 'less';
                                    value = false;
                                    break;
                                case 'once':
                                    optionName = 'multiple';
                                    value = false;
                                    break;
                            }
                            options[optionName] = value;
                            if (!parserInput.$char(',')) {
                                break;
                            }
                        }
                    } while (o);
                    expectChar(')');
                    return options;
                },
                importOption: function () {
                    var opt = parserInput.$re(/^(less|css|multiple|once|inline|reference|optional)/);
                    if (opt) {
                        return opt[1];
                    }
                },
                mediaFeature: function () {
                    var entities = this.entities;
                    var nodes = [];
                    var e;
                    var p;
                    parserInput.save();
                    do {
                        e = entities.keyword() || entities.variable() || entities.mixinLookup();
                        if (e) {
                            nodes.push(e);
                        }
                        else if (parserInput.$char('(')) {
                            p = this.property();
                            e = this.value();
                            if (parserInput.$char(')')) {
                                if (p && e) {
                                    nodes.push(new (tree_1.default.Paren)(new (tree_1.default.Declaration)(p, e, null, null, parserInput.i, fileInfo, true)));
                                }
                                else if (e) {
                                    nodes.push(new (tree_1.default.Paren)(e));
                                }
                                else {
                                    error('badly formed media feature definition');
                                }
                            }
                            else {
                                error('Missing closing \')\'', 'Parse');
                            }
                        }
                    } while (e);
                    parserInput.forget();
                    if (nodes.length > 0) {
                        return new (tree_1.default.Expression)(nodes);
                    }
                },
                mediaFeatures: function () {
                    var entities = this.entities;
                    var features = [];
                    var e;
                    do {
                        e = this.mediaFeature();
                        if (e) {
                            features.push(e);
                            if (!parserInput.$char(',')) {
                                break;
                            }
                        }
                        else {
                            e = entities.variable() || entities.mixinLookup();
                            if (e) {
                                features.push(e);
                                if (!parserInput.$char(',')) {
                                    break;
                                }
                            }
                        }
                    } while (e);
                    return features.length > 0 ? features : null;
                },
                media: function () {
                    var features;
                    var rules;
                    var media;
                    var debugInfo;
                    var index = parserInput.i;
                    if (context.dumpLineNumbers) {
                        debugInfo = getDebugInfo(index);
                    }
                    parserInput.save();
                    if (parserInput.$str('@media')) {
                        features = this.mediaFeatures();
                        rules = this.block();
                        if (!rules) {
                            error('media definitions require block statements after any features');
                        }
                        parserInput.forget();
                        media = new (tree_1.default.Media)(rules, features, index, fileInfo);
                        if (context.dumpLineNumbers) {
                            media.debugInfo = debugInfo;
                        }
                        return media;
                    }
                    parserInput.restore();
                },
                //
                // A @plugin directive, used to import plugins dynamically.
                //
                //     @plugin (args) "lib";
                //
                plugin: function () {
                    var path;
                    var args;
                    var options;
                    var index = parserInput.i;
                    var dir = parserInput.$re(/^@plugin\s+/);
                    if (dir) {
                        args = this.pluginArgs();
                        if (args) {
                            options = {
                                pluginArgs: args,
                                isPlugin: true
                            };
                        }
                        else {
                            options = { isPlugin: true };
                        }
                        if ((path = this.entities.quoted() || this.entities.url())) {
                            if (!parserInput.$char(';')) {
                                parserInput.i = index;
                                error('missing semi-colon on @plugin');
                            }
                            return new (tree_1.default.Import)(path, null, options, index, fileInfo);
                        }
                        else {
                            parserInput.i = index;
                            error('malformed @plugin statement');
                        }
                    }
                },
                pluginArgs: function () {
                    // list of options, surrounded by parens
                    parserInput.save();
                    if (!parserInput.$char('(')) {
                        parserInput.restore();
                        return null;
                    }
                    var args = parserInput.$re(/^\s*([^\);]+)\)\s*/);
                    if (args[1]) {
                        parserInput.forget();
                        return args[1].trim();
                    }
                    else {
                        parserInput.restore();
                        return null;
                    }
                },
                //
                // A CSS AtRule
                //
                //     @charset "utf-8";
                //
                atrule: function () {
                    var index = parserInput.i;
                    var name;
                    var value;
                    var rules;
                    var nonVendorSpecificName;
                    var hasIdentifier;
                    var hasExpression;
                    var hasUnknown;
                    var hasBlock = true;
                    var isRooted = true;
                    if (parserInput.currentChar() !== '@') {
                        return;
                    }
                    value = this['import']() || this.plugin() || this.media();
                    if (value) {
                        return value;
                    }
                    parserInput.save();
                    name = parserInput.$re(/^@[a-z-]+/);
                    if (!name) {
                        return;
                    }
                    nonVendorSpecificName = name;
                    if (name.charAt(1) == '-' && name.indexOf('-', 2) > 0) {
                        nonVendorSpecificName = "@" + name.slice(name.indexOf('-', 2) + 1);
                    }
                    switch (nonVendorSpecificName) {
                        case '@charset':
                            hasIdentifier = true;
                            hasBlock = false;
                            break;
                        case '@namespace':
                            hasExpression = true;
                            hasBlock = false;
                            break;
                        case '@keyframes':
                        case '@counter-style':
                            hasIdentifier = true;
                            break;
                        case '@document':
                        case '@supports':
                            hasUnknown = true;
                            isRooted = false;
                            break;
                        default:
                            hasUnknown = true;
                            break;
                    }
                    parserInput.commentStore.length = 0;
                    if (hasIdentifier) {
                        value = this.entity();
                        if (!value) {
                            error("expected " + name + " identifier");
                        }
                    }
                    else if (hasExpression) {
                        value = this.expression();
                        if (!value) {
                            error("expected " + name + " expression");
                        }
                    }
                    else if (hasUnknown) {
                        value = this.permissiveValue(/^[{;]/);
                        hasBlock = (parserInput.currentChar() === '{');
                        if (!value) {
                            if (!hasBlock && parserInput.currentChar() !== ';') {
                                error(name + " rule is missing block or ending semi-colon");
                            }
                        }
                        else if (!value.value) {
                            value = null;
                        }
                    }
                    if (hasBlock) {
                        rules = this.blockRuleset();
                    }
                    if (rules || (!hasBlock && value && parserInput.$char(';'))) {
                        parserInput.forget();
                        return new (tree_1.default.AtRule)(name, value, rules, index, fileInfo, context.dumpLineNumbers ? getDebugInfo(index) : null, isRooted);
                    }
                    parserInput.restore('at-rule options not recognised');
                },
                //
                // A Value is a comma-delimited list of Expressions
                //
                //     font-family: Baskerville, Georgia, serif;
                //
                // In a Rule, a Value represents everything after the `:`,
                // and before the `;`.
                //
                value: function () {
                    var e;
                    var expressions = [];
                    var index = parserInput.i;
                    do {
                        e = this.expression();
                        if (e) {
                            expressions.push(e);
                            if (!parserInput.$char(',')) {
                                break;
                            }
                        }
                    } while (e);
                    if (expressions.length > 0) {
                        return new (tree_1.default.Value)(expressions, index);
                    }
                },
                important: function () {
                    if (parserInput.currentChar() === '!') {
                        return parserInput.$re(/^! *important/);
                    }
                },
                sub: function () {
                    var a;
                    var e;
                    parserInput.save();
                    if (parserInput.$char('(')) {
                        a = this.addition();
                        if (a && parserInput.$char(')')) {
                            parserInput.forget();
                            e = new (tree_1.default.Expression)([a]);
                            e.parens = true;
                            return e;
                        }
                        parserInput.restore('Expected \')\'');
                        return;
                    }
                    parserInput.restore();
                },
                multiplication: function () {
                    var m;
                    var a;
                    var op;
                    var operation;
                    var isSpaced;
                    m = this.operand();
                    if (m) {
                        isSpaced = parserInput.isWhitespace(-1);
                        while (true) {
                            if (parserInput.peek(/^\/[*\/]/)) {
                                break;
                            }
                            parserInput.save();
                            op = parserInput.$char('/') || parserInput.$char('*') || parserInput.$str('./');
                            if (!op) {
                                parserInput.forget();
                                break;
                            }
                            a = this.operand();
                            if (!a) {
                                parserInput.restore();
                                break;
                            }
                            parserInput.forget();
                            m.parensInOp = true;
                            a.parensInOp = true;
                            operation = new (tree_1.default.Operation)(op, [operation || m, a], isSpaced);
                            isSpaced = parserInput.isWhitespace(-1);
                        }
                        return operation || m;
                    }
                },
                addition: function () {
                    var m;
                    var a;
                    var op;
                    var operation;
                    var isSpaced;
                    m = this.multiplication();
                    if (m) {
                        isSpaced = parserInput.isWhitespace(-1);
                        while (true) {
                            op = parserInput.$re(/^[-+]\s+/) || (!isSpaced && (parserInput.$char('+') || parserInput.$char('-')));
                            if (!op) {
                                break;
                            }
                            a = this.multiplication();
                            if (!a) {
                                break;
                            }
                            m.parensInOp = true;
                            a.parensInOp = true;
                            operation = new (tree_1.default.Operation)(op, [operation || m, a], isSpaced);
                            isSpaced = parserInput.isWhitespace(-1);
                        }
                        return operation || m;
                    }
                },
                conditions: function () {
                    var a;
                    var b;
                    var index = parserInput.i;
                    var condition;
                    a = this.condition(true);
                    if (a) {
                        while (true) {
                            if (!parserInput.peek(/^,\s*(not\s*)?\(/) || !parserInput.$char(',')) {
                                break;
                            }
                            b = this.condition(true);
                            if (!b) {
                                break;
                            }
                            condition = new (tree_1.default.Condition)('or', condition || a, b, index);
                        }
                        return condition || a;
                    }
                },
                condition: function (needsParens) {
                    var result;
                    var logical;
                    var next;
                    function or() {
                        return parserInput.$str('or');
                    }
                    result = this.conditionAnd(needsParens);
                    if (!result) {
                        return;
                    }
                    logical = or();
                    if (logical) {
                        next = this.condition(needsParens);
                        if (next) {
                            result = new (tree_1.default.Condition)(logical, result, next);
                        }
                        else {
                            return;
                        }
                    }
                    return result;
                },
                conditionAnd: function (needsParens) {
                    var result;
                    var logical;
                    var next;
                    var self = this;
                    function insideCondition() {
                        var cond = self.negatedCondition(needsParens) || self.parenthesisCondition(needsParens);
                        if (!cond && !needsParens) {
                            return self.atomicCondition(needsParens);
                        }
                        return cond;
                    }
                    function and() {
                        return parserInput.$str('and');
                    }
                    result = insideCondition();
                    if (!result) {
                        return;
                    }
                    logical = and();
                    if (logical) {
                        next = this.conditionAnd(needsParens);
                        if (next) {
                            result = new (tree_1.default.Condition)(logical, result, next);
                        }
                        else {
                            return;
                        }
                    }
                    return result;
                },
                negatedCondition: function (needsParens) {
                    if (parserInput.$str('not')) {
                        var result = this.parenthesisCondition(needsParens);
                        if (result) {
                            result.negate = !result.negate;
                        }
                        return result;
                    }
                },
                parenthesisCondition: function (needsParens) {
                    function tryConditionFollowedByParenthesis(me) {
                        var body;
                        parserInput.save();
                        body = me.condition(needsParens);
                        if (!body) {
                            parserInput.restore();
                            return;
                        }
                        if (!parserInput.$char(')')) {
                            parserInput.restore();
                            return;
                        }
                        parserInput.forget();
                        return body;
                    }
                    var body;
                    parserInput.save();
                    if (!parserInput.$str('(')) {
                        parserInput.restore();
                        return;
                    }
                    body = tryConditionFollowedByParenthesis(this);
                    if (body) {
                        parserInput.forget();
                        return body;
                    }
                    body = this.atomicCondition(needsParens);
                    if (!body) {
                        parserInput.restore();
                        return;
                    }
                    if (!parserInput.$char(')')) {
                        parserInput.restore("expected ')' got '" + parserInput.currentChar() + "'");
                        return;
                    }
                    parserInput.forget();
                    return body;
                },
                atomicCondition: function (needsParens) {
                    var entities = this.entities;
                    var index = parserInput.i;
                    var a;
                    var b;
                    var c;
                    var op;
                    function cond() {
                        return this.addition() || entities.keyword() || entities.quoted() || entities.mixinLookup();
                    }
                    cond = cond.bind(this);
                    a = cond();
                    if (a) {
                        if (parserInput.$char('>')) {
                            if (parserInput.$char('=')) {
                                op = '>=';
                            }
                            else {
                                op = '>';
                            }
                        }
                        else if (parserInput.$char('<')) {
                            if (parserInput.$char('=')) {
                                op = '<=';
                            }
                            else {
                                op = '<';
                            }
                        }
                        else if (parserInput.$char('=')) {
                            if (parserInput.$char('>')) {
                                op = '=>';
                            }
                            else if (parserInput.$char('<')) {
                                op = '=<';
                            }
                            else {
                                op = '=';
                            }
                        }
                        if (op) {
                            b = cond();
                            if (b) {
                                c = new (tree_1.default.Condition)(op, a, b, index, false);
                            }
                            else {
                                error('expected expression');
                            }
                        }
                        else {
                            c = new (tree_1.default.Condition)('=', a, new (tree_1.default.Keyword)('true'), index, false);
                        }
                        return c;
                    }
                },
                //
                // An operand is anything that can be part of an operation,
                // such as a Color, or a Variable
                //
                operand: function () {
                    var entities = this.entities;
                    var negate;
                    if (parserInput.peek(/^-[@\$\(]/)) {
                        negate = parserInput.$char('-');
                    }
                    var o = this.sub() || entities.dimension() ||
                        entities.color() || entities.variable() ||
                        entities.property() || entities.call() ||
                        entities.quoted(true) || entities.colorKeyword() ||
                        entities.mixinLookup();
                    if (negate) {
                        o.parensInOp = true;
                        o = new (tree_1.default.Negative)(o);
                    }
                    return o;
                },
                //
                // Expressions either represent mathematical operations,
                // or white-space delimited Entities.
                //
                //     1px solid black
                //     @var * 2
                //
                expression: function () {
                    var entities = [];
                    var e;
                    var delim;
                    var index = parserInput.i;
                    do {
                        e = this.comment();
                        if (e) {
                            entities.push(e);
                            continue;
                        }
                        e = this.addition() || this.entity();
                        if (e instanceof tree_1.default.Comment) {
                            e = null;
                        }
                        if (e) {
                            entities.push(e);
                            // operations do not allow keyword "/" dimension (e.g. small/20px) so we support that here
                            if (!parserInput.peek(/^\/[\/*]/)) {
                                delim = parserInput.$char('/');
                                if (delim) {
                                    entities.push(new (tree_1.default.Anonymous)(delim, index));
                                }
                            }
                        }
                    } while (e);
                    if (entities.length > 0) {
                        return new (tree_1.default.Expression)(entities);
                    }
                },
                property: function () {
                    var name = parserInput.$re(/^(\*?-?[_a-zA-Z0-9-]+)\s*:/);
                    if (name) {
                        return name[1];
                    }
                },
                ruleProperty: function () {
                    var name = [];
                    var index = [];
                    var s;
                    var k;
                    parserInput.save();
                    var simpleProperty = parserInput.$re(/^([_a-zA-Z0-9-]+)\s*:/);
                    if (simpleProperty) {
                        name = [new (tree_1.default.Keyword)(simpleProperty[1])];
                        parserInput.forget();
                        return name;
                    }
                    function match(re) {
                        var i = parserInput.i;
                        var chunk = parserInput.$re(re);
                        if (chunk) {
                            index.push(i);
                            return name.push(chunk[1]);
                        }
                    }
                    match(/^(\*?)/);
                    while (true) {
                        if (!match(/^((?:[\w-]+)|(?:[@\$]\{[\w-]+\}))/)) {
                            break;
                        }
                    }
                    if ((name.length > 1) && match(/^((?:\+_|\+)?)\s*:/)) {
                        parserInput.forget();
                        // at last, we have the complete match now. move forward,
                        // convert name particles to tree objects and return:
                        if (name[0] === '') {
                            name.shift();
                            index.shift();
                        }
                        for (k = 0; k < name.length; k++) {
                            s = name[k];
                            name[k] = (s.charAt(0) !== '@' && s.charAt(0) !== '$') ?
                                new (tree_1.default.Keyword)(s) :
                                (s.charAt(0) === '@' ?
                                    new (tree_1.default.Variable)("@" + s.slice(2, -1), index[k], fileInfo) :
                                    new (tree_1.default.Property)("$" + s.slice(2, -1), index[k], fileInfo));
                        }
                        return name;
                    }
                    parserInput.restore();
                }
            }
        };
    };
    Parser.serializeVars = function (vars) {
        var s = '';
        for (var name_1 in vars) {
            if (Object.hasOwnProperty.call(vars, name_1)) {
                var value = vars[name_1];
                s += ((name_1[0] === '@') ? '' : '@') + name_1 + ": " + value + ((String(value).slice(-1) === ';') ? '' : ';');
            }
        }
        return s;
    };
    exports.default = Parser;
    
},
/* less/lib/less/parser/parser-input.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var chunker_1 = tslib_1.__importDefault(require(172) /* ./chunker */);
    exports.default = (function () {
        var // Less input string
        input;
        var // current chunk
        j;
        var // holds state for backtracking
        saveStack = [];
        var // furthest index the parser has gone to
        furthest;
        var // if this is furthest we got to, this is the probably cause
        furthestPossibleErrorMessage;
        var // chunkified input
        chunks;
        var // current chunk
        current;
        var // index of current chunk, in `input`
        currentPos;
        var parserInput = {};
        var CHARCODE_SPACE = 32;
        var CHARCODE_TAB = 9;
        var CHARCODE_LF = 10;
        var CHARCODE_CR = 13;
        var CHARCODE_PLUS = 43;
        var CHARCODE_COMMA = 44;
        var CHARCODE_FORWARD_SLASH = 47;
        var CHARCODE_9 = 57;
        function skipWhitespace(length) {
            var oldi = parserInput.i;
            var oldj = j;
            var curr = parserInput.i - currentPos;
            var endIndex = parserInput.i + current.length - curr;
            var mem = (parserInput.i += length);
            var inp = input;
            var c;
            var nextChar;
            var comment;
            for (; parserInput.i < endIndex; parserInput.i++) {
                c = inp.charCodeAt(parserInput.i);
                if (parserInput.autoCommentAbsorb && c === CHARCODE_FORWARD_SLASH) {
                    nextChar = inp.charAt(parserInput.i + 1);
                    if (nextChar === '/') {
                        comment = { index: parserInput.i, isLineComment: true };
                        var nextNewLine = inp.indexOf('\n', parserInput.i + 2);
                        if (nextNewLine < 0) {
                            nextNewLine = endIndex;
                        }
                        parserInput.i = nextNewLine;
                        comment.text = inp.substr(comment.index, parserInput.i - comment.index);
                        parserInput.commentStore.push(comment);
                        continue;
                    }
                    else if (nextChar === '*') {
                        var nextStarSlash = inp.indexOf('*/', parserInput.i + 2);
                        if (nextStarSlash >= 0) {
                            comment = {
                                index: parserInput.i,
                                text: inp.substr(parserInput.i, nextStarSlash + 2 - parserInput.i),
                                isLineComment: false
                            };
                            parserInput.i += comment.text.length - 1;
                            parserInput.commentStore.push(comment);
                            continue;
                        }
                    }
                    break;
                }
                if ((c !== CHARCODE_SPACE) && (c !== CHARCODE_LF) && (c !== CHARCODE_TAB) && (c !== CHARCODE_CR)) {
                    break;
                }
            }
            current = current.slice(length + parserInput.i - mem + curr);
            currentPos = parserInput.i;
            if (!current.length) {
                if (j < chunks.length - 1) {
                    current = chunks[++j];
                    skipWhitespace(0); // skip space at the beginning of a chunk
                    return true; // things changed
                }
                parserInput.finished = true;
            }
            return oldi !== parserInput.i || oldj !== j;
        }
        parserInput.save = function () {
            currentPos = parserInput.i;
            saveStack.push({ current: current, i: parserInput.i, j: j });
        };
        parserInput.restore = function (possibleErrorMessage) {
            if (parserInput.i > furthest || (parserInput.i === furthest && possibleErrorMessage && !furthestPossibleErrorMessage)) {
                furthest = parserInput.i;
                furthestPossibleErrorMessage = possibleErrorMessage;
            }
            var state = saveStack.pop();
            current = state.current;
            currentPos = parserInput.i = state.i;
            j = state.j;
        };
        parserInput.forget = function () {
            saveStack.pop();
        };
        parserInput.isWhitespace = function (offset) {
            var pos = parserInput.i + (offset || 0);
            var code = input.charCodeAt(pos);
            return (code === CHARCODE_SPACE || code === CHARCODE_CR || code === CHARCODE_TAB || code === CHARCODE_LF);
        };
        // Specialization of $(tok)
        parserInput.$re = function (tok) {
            if (parserInput.i > currentPos) {
                current = current.slice(parserInput.i - currentPos);
                currentPos = parserInput.i;
            }
            var m = tok.exec(current);
            if (!m) {
                return null;
            }
            skipWhitespace(m[0].length);
            if (typeof m === 'string') {
                return m;
            }
            return m.length === 1 ? m[0] : m;
        };
        parserInput.$char = function (tok) {
            if (input.charAt(parserInput.i) !== tok) {
                return null;
            }
            skipWhitespace(1);
            return tok;
        };
        parserInput.$str = function (tok) {
            var tokLength = tok.length;
            // https://jsperf.com/string-startswith/21
            for (var i = 0; i < tokLength; i++) {
                if (input.charAt(parserInput.i + i) !== tok.charAt(i)) {
                    return null;
                }
            }
            skipWhitespace(tokLength);
            return tok;
        };
        parserInput.$quoted = function (loc) {
            var pos = loc || parserInput.i;
            var startChar = input.charAt(pos);
            if (startChar !== '\'' && startChar !== '"') {
                return;
            }
            var length = input.length;
            var currentPosition = pos;
            for (var i = 1; i + currentPosition < length; i++) {
                var nextChar = input.charAt(i + currentPosition);
                switch (nextChar) {
                    case '\\':
                        i++;
                        continue;
                    case '\r':
                    case '\n':
                        break;
                    case startChar:
                        var str = input.substr(currentPosition, i + 1);
                        if (!loc && loc !== 0) {
                            skipWhitespace(i + 1);
                            return str;
                        }
                        return [startChar, str];
                    default:
                }
            }
            return null;
        };
        /**
         * Permissive parsing. Ignores everything except matching {} [] () and quotes
         * until matching token (outside of blocks)
         */
        parserInput.$parseUntil = function (tok) {
            var quote = '';
            var returnVal = null;
            var inComment = false;
            var blockDepth = 0;
            var blockStack = [];
            var parseGroups = [];
            var length = input.length;
            var startPos = parserInput.i;
            var lastPos = parserInput.i;
            var i = parserInput.i;
            var loop = true;
            var testChar;
            if (typeof tok === 'string') {
                testChar = function (char) { return char === tok; };
            }
            else {
                testChar = function (char) { return tok.test(char); };
            }
            do {
                var prevChar = void 0;
                var nextChar = input.charAt(i);
                if (blockDepth === 0 && testChar(nextChar)) {
                    returnVal = input.substr(lastPos, i - lastPos);
                    if (returnVal) {
                        parseGroups.push(returnVal);
                    }
                    else {
                        parseGroups.push(' ');
                    }
                    returnVal = parseGroups;
                    skipWhitespace(i - startPos);
                    loop = false;
                }
                else {
                    if (inComment) {
                        if (nextChar === '*' &&
                            input.charAt(i + 1) === '/') {
                            i++;
                            blockDepth--;
                            inComment = false;
                        }
                        i++;
                        continue;
                    }
                    switch (nextChar) {
                        case '\\':
                            i++;
                            nextChar = input.charAt(i);
                            parseGroups.push(input.substr(lastPos, i - lastPos + 1));
                            lastPos = i + 1;
                            break;
                        case '/':
                            if (input.charAt(i + 1) === '*') {
                                i++;
                                inComment = true;
                                blockDepth++;
                            }
                            break;
                        case '\'':
                        case '"':
                            quote = parserInput.$quoted(i);
                            if (quote) {
                                parseGroups.push(input.substr(lastPos, i - lastPos), quote);
                                i += quote[1].length - 1;
                                lastPos = i + 1;
                            }
                            else {
                                skipWhitespace(i - startPos);
                                returnVal = nextChar;
                                loop = false;
                            }
                            break;
                        case '{':
                            blockStack.push('}');
                            blockDepth++;
                            break;
                        case '(':
                            blockStack.push(')');
                            blockDepth++;
                            break;
                        case '[':
                            blockStack.push(']');
                            blockDepth++;
                            break;
                        case '}':
                        case ')':
                        case ']':
                            var expected = blockStack.pop();
                            if (nextChar === expected) {
                                blockDepth--;
                            }
                            else {
                                // move the parser to the error and return expected
                                skipWhitespace(i - startPos);
                                returnVal = expected;
                                loop = false;
                            }
                    }
                    i++;
                    if (i > length) {
                        loop = false;
                    }
                }
                prevChar = nextChar;
            } while (loop);
            return returnVal ? returnVal : null;
        };
        parserInput.autoCommentAbsorb = true;
        parserInput.commentStore = [];
        parserInput.finished = false;
        // Same as $(), but don't change the state of the parser,
        // just return the match.
        parserInput.peek = function (tok) {
            if (typeof tok === 'string') {
                // https://jsperf.com/string-startswith/21
                for (var i = 0; i < tok.length; i++) {
                    if (input.charAt(parserInput.i + i) !== tok.charAt(i)) {
                        return false;
                    }
                }
                return true;
            }
            else {
                return tok.test(current);
            }
        };
        // Specialization of peek()
        // TODO remove or change some currentChar calls to peekChar
        parserInput.peekChar = function (tok) { return input.charAt(parserInput.i) === tok; };
        parserInput.currentChar = function () { return input.charAt(parserInput.i); };
        parserInput.prevChar = function () { return input.charAt(parserInput.i - 1); };
        parserInput.getInput = function () { return input; };
        parserInput.peekNotNumeric = function () {
            var c = input.charCodeAt(parserInput.i);
            // Is the first char of the dimension 0-9, '.', '+' or '-'
            return (c > CHARCODE_9 || c < CHARCODE_PLUS) || c === CHARCODE_FORWARD_SLASH || c === CHARCODE_COMMA;
        };
        parserInput.start = function (str, chunkInput, failFunction) {
            input = str;
            parserInput.i = j = currentPos = furthest = 0;
            // chunking apparently makes things quicker (but my tests indicate
            // it might actually make things slower in node at least)
            // and it is a non-perfect parse - it can't recognise
            // unquoted urls, meaning it can't distinguish comments
            // meaning comments with quotes or {}() in them get 'counted'
            // and then lead to parse errors.
            // In addition if the chunking chunks in the wrong place we might
            // not be able to parse a parser statement in one go
            // this is officially deprecated but can be switched on via an option
            // in the case it causes too much performance issues.
            if (chunkInput) {
                chunks = chunker_1.default(str, failFunction);
            }
            else {
                chunks = [str];
            }
            current = chunks[0];
            skipWhitespace(0);
        };
        parserInput.end = function () {
            var message;
            var isFinished = parserInput.i >= input.length;
            if (parserInput.i < furthest) {
                message = furthestPossibleErrorMessage;
                parserInput.i = furthest;
            }
            return {
                isFinished: isFinished,
                furthest: parserInput.i,
                furthestPossibleErrorMessage: message,
                furthestReachedEnd: parserInput.i >= input.length - 1,
                furthestChar: input[parserInput.i]
            };
        };
        return parserInput;
    });
    
},
/* less/lib/less/parser/chunker.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    // Split the input into chunks.
    function default_1(input, fail) {
        var len = input.length;
        var level = 0;
        var parenLevel = 0;
        var lastOpening;
        var lastOpeningParen;
        var lastMultiComment;
        var lastMultiCommentEndBrace;
        var chunks = [];
        var emitFrom = 0;
        var chunkerCurrentIndex;
        var currentChunkStartIndex;
        var cc;
        var cc2;
        var matched;
        function emitChunk(force) {
            var len = chunkerCurrentIndex - emitFrom;
            if (((len < 512) && !force) || !len) {
                return;
            }
            chunks.push(input.slice(emitFrom, chunkerCurrentIndex + 1));
            emitFrom = chunkerCurrentIndex + 1;
        }
        for (chunkerCurrentIndex = 0; chunkerCurrentIndex < len; chunkerCurrentIndex++) {
            cc = input.charCodeAt(chunkerCurrentIndex);
            if (((cc >= 97) && (cc <= 122)) || (cc < 34)) {
                // a-z or whitespace
                continue;
            }
            switch (cc) {
                case 40: // (
                    parenLevel++;
                    lastOpeningParen = chunkerCurrentIndex;
                    continue;
                case 41: // )
                    if (--parenLevel < 0) {
                        return fail('missing opening `(`', chunkerCurrentIndex);
                    }
                    continue;
                case 59: // ;
                    if (!parenLevel) {
                        emitChunk();
                    }
                    continue;
                case 123: // {
                    level++;
                    lastOpening = chunkerCurrentIndex;
                    continue;
                case 125: // }
                    if (--level < 0) {
                        return fail('missing opening `{`', chunkerCurrentIndex);
                    }
                    if (!level && !parenLevel) {
                        emitChunk();
                    }
                    continue;
                case 92: // \
                    if (chunkerCurrentIndex < len - 1) {
                        chunkerCurrentIndex++;
                        continue;
                    }
                    return fail('unescaped `\\`', chunkerCurrentIndex);
                case 34:
                case 39:
                case 96: // ", ' and `
                    matched = 0;
                    currentChunkStartIndex = chunkerCurrentIndex;
                    for (chunkerCurrentIndex = chunkerCurrentIndex + 1; chunkerCurrentIndex < len; chunkerCurrentIndex++) {
                        cc2 = input.charCodeAt(chunkerCurrentIndex);
                        if (cc2 > 96) {
                            continue;
                        }
                        if (cc2 == cc) {
                            matched = 1;
                            break;
                        }
                        if (cc2 == 92) { // \
                            if (chunkerCurrentIndex == len - 1) {
                                return fail('unescaped `\\`', chunkerCurrentIndex);
                            }
                            chunkerCurrentIndex++;
                        }
                    }
                    if (matched) {
                        continue;
                    }
                    return fail("unmatched `" + String.fromCharCode(cc) + "`", currentChunkStartIndex);
                case 47: // /, check for comment
                    if (parenLevel || (chunkerCurrentIndex == len - 1)) {
                        continue;
                    }
                    cc2 = input.charCodeAt(chunkerCurrentIndex + 1);
                    if (cc2 == 47) {
                        // //, find lnfeed
                        for (chunkerCurrentIndex = chunkerCurrentIndex + 2; chunkerCurrentIndex < len; chunkerCurrentIndex++) {
                            cc2 = input.charCodeAt(chunkerCurrentIndex);
                            if ((cc2 <= 13) && ((cc2 == 10) || (cc2 == 13))) {
                                break;
                            }
                        }
                    }
                    else if (cc2 == 42) {
                        // /*, find */
                        lastMultiComment = currentChunkStartIndex = chunkerCurrentIndex;
                        for (chunkerCurrentIndex = chunkerCurrentIndex + 2; chunkerCurrentIndex < len - 1; chunkerCurrentIndex++) {
                            cc2 = input.charCodeAt(chunkerCurrentIndex);
                            if (cc2 == 125) {
                                lastMultiCommentEndBrace = chunkerCurrentIndex;
                            }
                            if (cc2 != 42) {
                                continue;
                            }
                            if (input.charCodeAt(chunkerCurrentIndex + 1) == 47) {
                                break;
                            }
                        }
                        if (chunkerCurrentIndex == len - 1) {
                            return fail('missing closing `*/`', currentChunkStartIndex);
                        }
                        chunkerCurrentIndex++;
                    }
                    continue;
                case 42: // *, check for unmatched */
                    if ((chunkerCurrentIndex < len - 1) && (input.charCodeAt(chunkerCurrentIndex + 1) == 47)) {
                        return fail('unmatched `/*`', chunkerCurrentIndex);
                    }
                    continue;
            }
        }
        if (level !== 0) {
            if ((lastMultiComment > lastOpening) && (lastMultiCommentEndBrace > lastMultiComment)) {
                return fail('missing closing `}` or `*/`', lastOpening);
            }
            else {
                return fail('missing closing `}`', lastOpening);
            }
        }
        else if (parenLevel !== 0) {
            return fail('missing closing `)`', lastOpeningParen);
        }
        emitChunk(true);
        return chunks;
    }
    exports.default = default_1;
    ;
    
},
/* less/lib/less/functions/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var function_registry_1 = tslib_1.__importDefault(require(134) /* ./function-registry */);
    var function_caller_1 = tslib_1.__importDefault(require(142) /* ./function-caller */);
    var boolean_1 = tslib_1.__importDefault(require(174) /* ./boolean */);
    var default_1 = tslib_1.__importDefault(require(135) /* ./default */);
    var color_1 = tslib_1.__importDefault(require(175) /* ./color */);
    var color_blending_1 = tslib_1.__importDefault(require(176) /* ./color-blending */);
    var data_uri_1 = tslib_1.__importDefault(require(177) /* ./data-uri */);
    var list_1 = tslib_1.__importDefault(require(178) /* ./list */);
    var math_1 = tslib_1.__importDefault(require(179) /* ./math */);
    var number_1 = tslib_1.__importDefault(require(181) /* ./number */);
    var string_1 = tslib_1.__importDefault(require(182) /* ./string */);
    var svg_1 = tslib_1.__importDefault(require(183) /* ./svg */);
    var types_1 = tslib_1.__importDefault(require(184) /* ./types */);
    exports.default = (function (environment) {
        var functions = { functionRegistry: function_registry_1.default, functionCaller: function_caller_1.default };
        // register functions
        function_registry_1.default.addMultiple(boolean_1.default);
        function_registry_1.default.add('default', default_1.default.eval.bind(default_1.default));
        function_registry_1.default.addMultiple(color_1.default);
        function_registry_1.default.addMultiple(color_blending_1.default);
        function_registry_1.default.addMultiple(data_uri_1.default(environment));
        function_registry_1.default.addMultiple(list_1.default);
        function_registry_1.default.addMultiple(math_1.default);
        function_registry_1.default.addMultiple(number_1.default);
        function_registry_1.default.addMultiple(string_1.default);
        function_registry_1.default.addMultiple(svg_1.default(environment));
        function_registry_1.default.addMultiple(types_1.default);
        return functions;
    });
    
},
/* less/lib/less/functions/boolean.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ../tree/anonymous */);
    var keyword_1 = tslib_1.__importDefault(require(129) /* ../tree/keyword */);
    function boolean(condition) {
        return condition ? keyword_1.default.True : keyword_1.default.False;
    }
    /**
     * Functions with evalArgs set to false are sent context
     * as the first argument.
     */
    function If(context, condition, trueValue, falseValue) {
        return condition.eval(context) ? trueValue.eval(context)
            : (falseValue ? falseValue.eval(context) : new anonymous_1.default);
    }
    If.evalArgs = false;
    function isdefined(context, variable) {
        try {
            variable.eval(context);
            return keyword_1.default.True;
        }
        catch (e) {
            return keyword_1.default.False;
        }
    }
    isdefined.evalArgs = false;
    exports.default = { isdefined: isdefined, boolean: boolean, 'if': If };
    
},
/* less/lib/less/functions/color.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(138) /* ../tree/dimension */);
    var color_1 = tslib_1.__importDefault(require(115) /* ../tree/color */);
    var quoted_1 = tslib_1.__importDefault(require(146) /* ../tree/quoted */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ../tree/anonymous */);
    var expression_1 = tslib_1.__importDefault(require(143) /* ../tree/expression */);
    var operation_1 = tslib_1.__importDefault(require(137) /* ../tree/operation */);
    var colorFunctions;
    function clamp(val) {
        return Math.min(1, Math.max(0, val));
    }
    function hsla(origColor, hsl) {
        var color = colorFunctions.hsla(hsl.h, hsl.s, hsl.l, hsl.a);
        if (color) {
            if (origColor.value &&
                /^(rgb|hsl)/.test(origColor.value)) {
                color.value = origColor.value;
            }
            else {
                color.value = 'rgb';
            }
            return color;
        }
    }
    function toHSL(color) {
        if (color.toHSL) {
            return color.toHSL();
        }
        else {
            throw new Error('Argument cannot be evaluated to a color');
        }
    }
    function toHSV(color) {
        if (color.toHSV) {
            return color.toHSV();
        }
        else {
            throw new Error('Argument cannot be evaluated to a color');
        }
    }
    function number(n) {
        if (n instanceof dimension_1.default) {
            return parseFloat(n.unit.is('%') ? n.value / 100 : n.value);
        }
        else if (typeof n === 'number') {
            return n;
        }
        else {
            throw {
                type: 'Argument',
                message: 'color functions take numbers as parameters'
            };
        }
    }
    function scaled(n, size) {
        if (n instanceof dimension_1.default && n.unit.is('%')) {
            return parseFloat(n.value * size / 100);
        }
        else {
            return number(n);
        }
    }
    colorFunctions = {
        rgb: function (r, g, b) {
            var a = 1;
            /**
             * Comma-less syntax
             *   e.g. rgb(0 128 255 / 50%)
             */
            if (r instanceof expression_1.default) {
                var val = r.value;
                r = val[0];
                g = val[1];
                b = val[2];
                /**
                 * @todo - should this be normalized in
                 *   function caller? Or parsed differently?
                 */
                if (b instanceof operation_1.default) {
                    var op = b;
                    b = op.operands[0];
                    a = op.operands[1];
                }
            }
            var color = colorFunctions.rgba(r, g, b, a);
            if (color) {
                color.value = 'rgb';
                return color;
            }
        },
        rgba: function (r, g, b, a) {
            try {
                if (r instanceof color_1.default) {
                    if (g) {
                        a = number(g);
                    }
                    else {
                        a = r.alpha;
                    }
                    return new color_1.default(r.rgb, a, 'rgba');
                }
                var rgb = [r, g, b].map(function (c) { return scaled(c, 255); });
                a = number(a);
                return new color_1.default(rgb, a, 'rgba');
            }
            catch (e) { }
        },
        hsl: function (h, s, l) {
            var a = 1;
            if (h instanceof expression_1.default) {
                var val = h.value;
                h = val[0];
                s = val[1];
                l = val[2];
                if (l instanceof operation_1.default) {
                    var op = l;
                    l = op.operands[0];
                    a = op.operands[1];
                }
            }
            var color = colorFunctions.hsla(h, s, l, a);
            if (color) {
                color.value = 'hsl';
                return color;
            }
        },
        hsla: function (h, s, l, a) {
            try {
                if (h instanceof color_1.default) {
                    if (s) {
                        a = number(s);
                    }
                    else {
                        a = h.alpha;
                    }
                    return new color_1.default(h.rgb, a, 'hsla');
                }
                var m1_1;
                var m2_1;
                function hue(h) {
                    h = h < 0 ? h + 1 : (h > 1 ? h - 1 : h);
                    if (h * 6 < 1) {
                        return m1_1 + (m2_1 - m1_1) * h * 6;
                    }
                    else if (h * 2 < 1) {
                        return m2_1;
                    }
                    else if (h * 3 < 2) {
                        return m1_1 + (m2_1 - m1_1) * (2 / 3 - h) * 6;
                    }
                    else {
                        return m1_1;
                    }
                }
                h = (number(h) % 360) / 360;
                s = clamp(number(s));
                l = clamp(number(l));
                a = clamp(number(a));
                m2_1 = l <= 0.5 ? l * (s + 1) : l + s - l * s;
                m1_1 = l * 2 - m2_1;
                var rgb = [
                    hue(h + 1 / 3) * 255,
                    hue(h) * 255,
                    hue(h - 1 / 3) * 255
                ];
                a = number(a);
                return new color_1.default(rgb, a, 'hsla');
            }
            catch (e) { }
        },
        hsv: function (h, s, v) {
            return colorFunctions.hsva(h, s, v, 1.0);
        },
        hsva: function (h, s, v, a) {
            h = ((number(h) % 360) / 360) * 360;
            s = number(s);
            v = number(v);
            a = number(a);
            var i;
            var f;
            i = Math.floor((h / 60) % 6);
            f = (h / 60) - i;
            var vs = [v,
                v * (1 - s),
                v * (1 - f * s),
                v * (1 - (1 - f) * s)];
            var perm = [[0, 3, 1],
                [2, 0, 1],
                [1, 0, 3],
                [1, 2, 0],
                [3, 1, 0],
                [0, 1, 2]];
            return colorFunctions.rgba(vs[perm[i][0]] * 255, vs[perm[i][1]] * 255, vs[perm[i][2]] * 255, a);
        },
        hue: function (color) {
            return new dimension_1.default(toHSL(color).h);
        },
        saturation: function (color) {
            return new dimension_1.default(toHSL(color).s * 100, '%');
        },
        lightness: function (color) {
            return new dimension_1.default(toHSL(color).l * 100, '%');
        },
        hsvhue: function (color) {
            return new dimension_1.default(toHSV(color).h);
        },
        hsvsaturation: function (color) {
            return new dimension_1.default(toHSV(color).s * 100, '%');
        },
        hsvvalue: function (color) {
            return new dimension_1.default(toHSV(color).v * 100, '%');
        },
        red: function (color) {
            return new dimension_1.default(color.rgb[0]);
        },
        green: function (color) {
            return new dimension_1.default(color.rgb[1]);
        },
        blue: function (color) {
            return new dimension_1.default(color.rgb[2]);
        },
        alpha: function (color) {
            return new dimension_1.default(toHSL(color).a);
        },
        luma: function (color) {
            return new dimension_1.default(color.luma() * color.alpha * 100, '%');
        },
        luminance: function (color) {
            var luminance = (0.2126 * color.rgb[0] / 255) +
                (0.7152 * color.rgb[1] / 255) +
                (0.0722 * color.rgb[2] / 255);
            return new dimension_1.default(luminance * color.alpha * 100, '%');
        },
        saturate: function (color, amount, method) {
            // filter: saturate(3.2);
            // should be kept as is, so check for color
            if (!color.rgb) {
                return null;
            }
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.s += hsl.s * amount.value / 100;
            }
            else {
                hsl.s += amount.value / 100;
            }
            hsl.s = clamp(hsl.s);
            return hsla(color, hsl);
        },
        desaturate: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.s -= hsl.s * amount.value / 100;
            }
            else {
                hsl.s -= amount.value / 100;
            }
            hsl.s = clamp(hsl.s);
            return hsla(color, hsl);
        },
        lighten: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.l += hsl.l * amount.value / 100;
            }
            else {
                hsl.l += amount.value / 100;
            }
            hsl.l = clamp(hsl.l);
            return hsla(color, hsl);
        },
        darken: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.l -= hsl.l * amount.value / 100;
            }
            else {
                hsl.l -= amount.value / 100;
            }
            hsl.l = clamp(hsl.l);
            return hsla(color, hsl);
        },
        fadein: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.a += hsl.a * amount.value / 100;
            }
            else {
                hsl.a += amount.value / 100;
            }
            hsl.a = clamp(hsl.a);
            return hsla(color, hsl);
        },
        fadeout: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.a -= hsl.a * amount.value / 100;
            }
            else {
                hsl.a -= amount.value / 100;
            }
            hsl.a = clamp(hsl.a);
            return hsla(color, hsl);
        },
        fade: function (color, amount) {
            var hsl = toHSL(color);
            hsl.a = amount.value / 100;
            hsl.a = clamp(hsl.a);
            return hsla(color, hsl);
        },
        spin: function (color, amount) {
            var hsl = toHSL(color);
            var hue = (hsl.h + amount.value) % 360;
            hsl.h = hue < 0 ? 360 + hue : hue;
            return hsla(color, hsl);
        },
        //
        // Copyright (c) 2006-2009 Hampton Catlin, Natalie Weizenbaum, and Chris Eppstein
        // http://sass-lang.com
        //
        mix: function (color1, color2, weight) {
            if (!weight) {
                weight = new dimension_1.default(50);
            }
            var p = weight.value / 100.0;
            var w = p * 2 - 1;
            var a = toHSL(color1).a - toHSL(color2).a;
            var w1 = (((w * a == -1) ? w : (w + a) / (1 + w * a)) + 1) / 2.0;
            var w2 = 1 - w1;
            var rgb = [color1.rgb[0] * w1 + color2.rgb[0] * w2,
                color1.rgb[1] * w1 + color2.rgb[1] * w2,
                color1.rgb[2] * w1 + color2.rgb[2] * w2];
            var alpha = color1.alpha * p + color2.alpha * (1 - p);
            return new color_1.default(rgb, alpha);
        },
        greyscale: function (color) {
            return colorFunctions.desaturate(color, new dimension_1.default(100));
        },
        contrast: function (color, dark, light, threshold) {
            // filter: contrast(3.2);
            // should be kept as is, so check for color
            if (!color.rgb) {
                return null;
            }
            if (typeof light === 'undefined') {
                light = colorFunctions.rgba(255, 255, 255, 1.0);
            }
            if (typeof dark === 'undefined') {
                dark = colorFunctions.rgba(0, 0, 0, 1.0);
            }
            // Figure out which is actually light and dark:
            if (dark.luma() > light.luma()) {
                var t = light;
                light = dark;
                dark = t;
            }
            if (typeof threshold === 'undefined') {
                threshold = 0.43;
            }
            else {
                threshold = number(threshold);
            }
            if (color.luma() < threshold) {
                return light;
            }
            else {
                return dark;
            }
        },
        // Changes made in 2.7.0 - Reverted in 3.0.0
        // contrast: function (color, color1, color2, threshold) {
        //     // Return which of `color1` and `color2` has the greatest contrast with `color`
        //     // according to the standard WCAG contrast ratio calculation.
        //     // http://www.w3.org/TR/WCAG20/#contrast-ratiodef
        //     // The threshold param is no longer used, in line with SASS.
        //     // filter: contrast(3.2);
        //     // should be kept as is, so check for color
        //     if (!color.rgb) {
        //         return null;
        //     }
        //     if (typeof color1 === 'undefined') {
        //         color1 = colorFunctions.rgba(0, 0, 0, 1.0);
        //     }
        //     if (typeof color2 === 'undefined') {
        //         color2 = colorFunctions.rgba(255, 255, 255, 1.0);
        //     }
        //     var contrast1, contrast2;
        //     var luma = color.luma();
        //     var luma1 = color1.luma();
        //     var luma2 = color2.luma();
        //     // Calculate contrast ratios for each color
        //     if (luma > luma1) {
        //         contrast1 = (luma + 0.05) / (luma1 + 0.05);
        //     } else {
        //         contrast1 = (luma1 + 0.05) / (luma + 0.05);
        //     }
        //     if (luma > luma2) {
        //         contrast2 = (luma + 0.05) / (luma2 + 0.05);
        //     } else {
        //         contrast2 = (luma2 + 0.05) / (luma + 0.05);
        //     }
        //     if (contrast1 > contrast2) {
        //         return color1;
        //     } else {
        //         return color2;
        //     }
        // },
        argb: function (color) {
            return new anonymous_1.default(color.toARGB());
        },
        color: function (c) {
            if ((c instanceof quoted_1.default) &&
                (/^#([A-Fa-f0-9]{8}|[A-Fa-f0-9]{6}|[A-Fa-f0-9]{3,4})$/i.test(c.value))) {
                var val = c.value.slice(1);
                return new color_1.default(val, undefined, "#" + val);
            }
            if ((c instanceof color_1.default) || (c = color_1.default.fromKeyword(c.value))) {
                c.value = undefined;
                return c;
            }
            throw {
                type: 'Argument',
                message: 'argument must be a color keyword or 3|4|6|8 digit hex e.g. #FFF'
            };
        },
        tint: function (color, amount) {
            return colorFunctions.mix(colorFunctions.rgb(255, 255, 255), color, amount);
        },
        shade: function (color, amount) {
            return colorFunctions.mix(colorFunctions.rgb(0, 0, 0), color, amount);
        }
    };
    exports.default = colorFunctions;
    
},
/* less/lib/less/functions/color-blending.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var color_1 = tslib_1.__importDefault(require(115) /* ../tree/color */);
    // Color Blending
    // ref: http://www.w3.org/TR/compositing-1
    function colorBlend(mode, color1, color2) {
        var ab = color1.alpha; // result
        var // backdrop
        cb;
        var as = color2.alpha;
        var // source
        cs;
        var ar;
        var cr;
        var r = [];
        ar = as + ab * (1 - as);
        for (var i = 0; i < 3; i++) {
            cb = color1.rgb[i] / 255;
            cs = color2.rgb[i] / 255;
            cr = mode(cb, cs);
            if (ar) {
                cr = (as * cs + ab * (cb -
                    as * (cb + cs - cr))) / ar;
            }
            r[i] = cr * 255;
        }
        return new color_1.default(r, ar);
    }
    var colorBlendModeFunctions = {
        multiply: function (cb, cs) {
            return cb * cs;
        },
        screen: function (cb, cs) {
            return cb + cs - cb * cs;
        },
        overlay: function (cb, cs) {
            cb *= 2;
            return (cb <= 1) ?
                colorBlendModeFunctions.multiply(cb, cs) :
                colorBlendModeFunctions.screen(cb - 1, cs);
        },
        softlight: function (cb, cs) {
            var d = 1;
            var e = cb;
            if (cs > 0.5) {
                e = 1;
                d = (cb > 0.25) ? Math.sqrt(cb)
                    : ((16 * cb - 12) * cb + 4) * cb;
            }
            return cb - (1 - 2 * cs) * e * (d - cb);
        },
        hardlight: function (cb, cs) {
            return colorBlendModeFunctions.overlay(cs, cb);
        },
        difference: function (cb, cs) {
            return Math.abs(cb - cs);
        },
        exclusion: function (cb, cs) {
            return cb + cs - 2 * cb * cs;
        },
        // non-w3c functions:
        average: function (cb, cs) {
            return (cb + cs) / 2;
        },
        negation: function (cb, cs) {
            return 1 - Math.abs(cb + cs - 1);
        }
    };
    for (var f in colorBlendModeFunctions) {
        if (colorBlendModeFunctions.hasOwnProperty(f)) {
            colorBlend[f] = colorBlend.bind(null, colorBlendModeFunctions[f]);
        }
    }
    exports.default = colorBlend;
    
},
/* less/lib/less/functions/data-uri.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var quoted_1 = tslib_1.__importDefault(require(146) /* ../tree/quoted */);
    var url_1 = tslib_1.__importDefault(require(147) /* ../tree/url */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var logger_1 = tslib_1.__importDefault(require(70) /* ../logger */);
    exports.default = (function (environment) {
        var fallback = function (functionThis, node) { return new url_1.default(node, functionThis.index, functionThis.currentFileInfo).eval(functionThis.context); };
        return { 'data-uri': function (mimetypeNode, filePathNode) {
                if (!filePathNode) {
                    filePathNode = mimetypeNode;
                    mimetypeNode = null;
                }
                var mimetype = mimetypeNode && mimetypeNode.value;
                var filePath = filePathNode.value;
                var currentFileInfo = this.currentFileInfo;
                var currentDirectory = currentFileInfo.rewriteUrls ?
                    currentFileInfo.currentDirectory : currentFileInfo.entryPath;
                var fragmentStart = filePath.indexOf('#');
                var fragment = '';
                if (fragmentStart !== -1) {
                    fragment = filePath.slice(fragmentStart);
                    filePath = filePath.slice(0, fragmentStart);
                }
                var context = utils.clone(this.context);
                context.rawBuffer = true;
                var fileManager = environment.getFileManager(filePath, currentDirectory, context, environment, true);
                if (!fileManager) {
                    return fallback(this, filePathNode);
                }
                var useBase64 = false;
                // detect the mimetype if not given
                if (!mimetypeNode) {
                    mimetype = environment.mimeLookup(filePath);
                    if (mimetype === 'image/svg+xml') {
                        useBase64 = false;
                    }
                    else {
                        // use base 64 unless it's an ASCII or UTF-8 format
                        var charset = environment.charsetLookup(mimetype);
                        useBase64 = ['US-ASCII', 'UTF-8'].indexOf(charset) < 0;
                    }
                    if (useBase64) {
                        mimetype += ';base64';
                    }
                }
                else {
                    useBase64 = /;base64$/.test(mimetype);
                }
                var fileSync = fileManager.loadFileSync(filePath, currentDirectory, context, environment);
                if (!fileSync.contents) {
                    logger_1.default.warn("Skipped data-uri embedding of " + filePath + " because file not found");
                    return fallback(this, filePathNode || mimetypeNode);
                }
                var buf = fileSync.contents;
                if (useBase64 && !environment.encodeBase64) {
                    return fallback(this, filePathNode);
                }
                buf = useBase64 ? environment.encodeBase64(buf) : encodeURIComponent(buf);
                var uri = "data:" + mimetype + "," + buf + fragment;
                return new url_1.default(new quoted_1.default("\"" + uri + "\"", uri, false, this.index, this.currentFileInfo), this.index, this.currentFileInfo);
            } };
    });
    
},
/* less/lib/less/functions/list.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var comment_1 = tslib_1.__importDefault(require(131) /* ../tree/comment */);
    var node_1 = tslib_1.__importDefault(require(114) /* ../tree/node */);
    var dimension_1 = tslib_1.__importDefault(require(138) /* ../tree/dimension */);
    var declaration_1 = tslib_1.__importDefault(require(127) /* ../tree/declaration */);
    var expression_1 = tslib_1.__importDefault(require(143) /* ../tree/expression */);
    var ruleset_1 = tslib_1.__importDefault(require(126) /* ../tree/ruleset */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ../tree/selector */);
    var element_1 = tslib_1.__importDefault(require(118) /* ../tree/element */);
    var quoted_1 = tslib_1.__importDefault(require(146) /* ../tree/quoted */);
    var value_1 = tslib_1.__importDefault(require(128) /* ../tree/value */);
    var getItemsFromNode = function (node) {
        // handle non-array values as an array of length 1
        // return 'undefined' if index is invalid
        var items = Array.isArray(node.value) ?
            node.value : Array(node);
        return items;
    };
    exports.default = {
        _SELF: function (n) {
            return n;
        },
        '~': function () {
            var expr = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                expr[_i] = arguments[_i];
            }
            if (expr.length === 1) {
                return expr[0];
            }
            return new value_1.default(expr);
        },
        extract: function (values, index) {
            // (1-based index)
            index = index.value - 1;
            return getItemsFromNode(values)[index];
        },
        length: function (values) {
            return new dimension_1.default(getItemsFromNode(values).length);
        },
        /**
         * Creates a Less list of incremental values.
         * Modeled after Lodash's range function, also exists natively in PHP
         *
         * @param {Dimension} [start=1]
         * @param {Dimension} end  - e.g. 10 or 10px - unit is added to output
         * @param {Dimension} [step=1]
         */
        range: function (start, end, step) {
            var from;
            var to;
            var stepValue = 1;
            var list = [];
            if (end) {
                to = end;
                from = start.value;
                if (step) {
                    stepValue = step.value;
                }
            }
            else {
                from = 1;
                to = start;
            }
            for (var i = from; i <= to.value; i += stepValue) {
                list.push(new dimension_1.default(i, to.unit));
            }
            return new expression_1.default(list);
        },
        each: function (list, rs) {
            var _this = this;
            var rules = [];
            var newRules;
            var iterator;
            var tryEval = function (val) {
                if (val instanceof node_1.default) {
                    return val.eval(_this.context);
                }
                return val;
            };
            if (list.value && !(list instanceof quoted_1.default)) {
                if (Array.isArray(list.value)) {
                    iterator = list.value.map(tryEval);
                }
                else {
                    iterator = [tryEval(list.value)];
                }
            }
            else if (list.ruleset) {
                iterator = tryEval(list.ruleset).rules;
            }
            else if (list.rules) {
                iterator = list.rules.map(tryEval);
            }
            else if (Array.isArray(list)) {
                iterator = list.map(tryEval);
            }
            else {
                iterator = [tryEval(list)];
            }
            var valueName = '@value';
            var keyName = '@key';
            var indexName = '@index';
            if (rs.params) {
                valueName = rs.params[0] && rs.params[0].name;
                keyName = rs.params[1] && rs.params[1].name;
                indexName = rs.params[2] && rs.params[2].name;
                rs = rs.rules;
            }
            else {
                rs = rs.ruleset;
            }
            for (var i = 0; i < iterator.length; i++) {
                var key = void 0;
                var value = void 0;
                var item = iterator[i];
                if (item instanceof declaration_1.default) {
                    key = typeof item.name === 'string' ? item.name : item.name[0].value;
                    value = item.value;
                }
                else {
                    key = new dimension_1.default(i + 1);
                    value = item;
                }
                if (item instanceof comment_1.default) {
                    continue;
                }
                newRules = rs.rules.slice(0);
                if (valueName) {
                    newRules.push(new declaration_1.default(valueName, value, false, false, this.index, this.currentFileInfo));
                }
                if (indexName) {
                    newRules.push(new declaration_1.default(indexName, new dimension_1.default(i + 1), false, false, this.index, this.currentFileInfo));
                }
                if (keyName) {
                    newRules.push(new declaration_1.default(keyName, key, false, false, this.index, this.currentFileInfo));
                }
                rules.push(new ruleset_1.default([new (selector_1.default)([new element_1.default("", '&')])], newRules, rs.strictImports, rs.visibilityInfo()));
            }
            return new ruleset_1.default([new (selector_1.default)([new element_1.default("", '&')])], rules, rs.strictImports, rs.visibilityInfo()).eval(this.context);
        }
    };
    
},
/* less/lib/less/functions/math.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var math_helper_js_1 = tslib_1.__importDefault(require(180) /* ./math-helper.js */);
    var mathFunctions = {
        // name,  unit
        ceil: null,
        floor: null,
        sqrt: null,
        abs: null,
        tan: '',
        sin: '',
        cos: '',
        atan: 'rad',
        asin: 'rad',
        acos: 'rad'
    };
    for (var f in mathFunctions) {
        if (mathFunctions.hasOwnProperty(f)) {
            mathFunctions[f] = math_helper_js_1.default.bind(null, Math[f], mathFunctions[f]);
        }
    }
    mathFunctions.round = function (n, f) {
        var fraction = typeof f === 'undefined' ? 0 : f.value;
        return math_helper_js_1.default(function (num) { return num.toFixed(fraction); }, null, n);
    };
    exports.default = mathFunctions;
    
},
/* less/lib/less/functions/math-helper.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(138) /* ../tree/dimension */);
    var MathHelper = function (fn, unit, n) {
        if (!(n instanceof dimension_1.default)) {
            throw { type: 'Argument', message: 'argument must be a number' };
        }
        if (unit == null) {
            unit = n.unit;
        }
        else {
            n = n.unify();
        }
        return new dimension_1.default(fn(parseFloat(n.value)), unit);
    };
    exports.default = MathHelper;
    
},
/* less/lib/less/functions/number.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(138) /* ../tree/dimension */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ../tree/anonymous */);
    var math_helper_js_1 = tslib_1.__importDefault(require(180) /* ./math-helper.js */);
    var minMax = function (isMin, args) {
        args = Array.prototype.slice.call(args);
        switch (args.length) {
            case 0: throw { type: 'Argument', message: 'one or more arguments required' };
        }
        var i; // key is the unit.toString() for unified Dimension values,
        var j;
        var current;
        var currentUnified;
        var referenceUnified;
        var unit;
        var unitStatic;
        var unitClone;
        var // elems only contains original argument values.
        order = [];
        var values = {};
        // value is the index into the order array.
        for (i = 0; i < args.length; i++) {
            current = args[i];
            if (!(current instanceof dimension_1.default)) {
                if (Array.isArray(args[i].value)) {
                    Array.prototype.push.apply(args, Array.prototype.slice.call(args[i].value));
                }
                continue;
            }
            currentUnified = current.unit.toString() === '' && unitClone !== undefined ? new dimension_1.default(current.value, unitClone).unify() : current.unify();
            unit = currentUnified.unit.toString() === '' && unitStatic !== undefined ? unitStatic : currentUnified.unit.toString();
            unitStatic = unit !== '' && unitStatic === undefined || unit !== '' && order[0].unify().unit.toString() === '' ? unit : unitStatic;
            unitClone = unit !== '' && unitClone === undefined ? current.unit.toString() : unitClone;
            j = values[''] !== undefined && unit !== '' && unit === unitStatic ? values[''] : values[unit];
            if (j === undefined) {
                if (unitStatic !== undefined && unit !== unitStatic) {
                    throw { type: 'Argument', message: 'incompatible types' };
                }
                values[unit] = order.length;
                order.push(current);
                continue;
            }
            referenceUnified = order[j].unit.toString() === '' && unitClone !== undefined ? new dimension_1.default(order[j].value, unitClone).unify() : order[j].unify();
            if (isMin && currentUnified.value < referenceUnified.value ||
                !isMin && currentUnified.value > referenceUnified.value) {
                order[j] = current;
            }
        }
        if (order.length == 1) {
            return order[0];
        }
        args = order.map(function (a) { return a.toCSS(this.context); }).join(this.context.compress ? ',' : ', ');
        return new anonymous_1.default((isMin ? 'min' : 'max') + "(" + args + ")");
    };
    exports.default = {
        min: function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            try {
                return minMax(true, args);
            }
            catch (e) { }
        },
        max: function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            try {
                return minMax(false, args);
            }
            catch (e) { }
        },
        convert: function (val, unit) {
            return val.convertTo(unit.value);
        },
        pi: function () {
            return new dimension_1.default(Math.PI);
        },
        mod: function (a, b) {
            return new dimension_1.default(a.value % b.value, a.unit);
        },
        pow: function (x, y) {
            if (typeof x === 'number' && typeof y === 'number') {
                x = new dimension_1.default(x);
                y = new dimension_1.default(y);
            }
            else if (!(x instanceof dimension_1.default) || !(y instanceof dimension_1.default)) {
                throw { type: 'Argument', message: 'arguments must be numbers' };
            }
            return new dimension_1.default(Math.pow(x.value, y.value), x.unit);
        },
        percentage: function (n) {
            var result = math_helper_js_1.default(function (num) { return num * 100; }, '%', n);
            return result;
        }
    };
    
},
/* less/lib/less/functions/string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var quoted_1 = tslib_1.__importDefault(require(146) /* ../tree/quoted */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ../tree/anonymous */);
    var javascript_1 = tslib_1.__importDefault(require(150) /* ../tree/javascript */);
    exports.default = {
        e: function (str) {
            return new quoted_1.default('"', str instanceof javascript_1.default ? str.evaluated : str.value, true);
        },
        escape: function (str) {
            return new anonymous_1.default(encodeURI(str.value).replace(/=/g, '%3D').replace(/:/g, '%3A').replace(/#/g, '%23').replace(/;/g, '%3B')
                .replace(/\(/g, '%28').replace(/\)/g, '%29'));
        },
        replace: function (string, pattern, replacement, flags) {
            var result = string.value;
            replacement = (replacement.type === 'Quoted') ?
                replacement.value : replacement.toCSS();
            result = result.replace(new RegExp(pattern.value, flags ? flags.value : ''), replacement);
            return new quoted_1.default(string.quote || '', result, string.escaped);
        },
        '%': function (string /* arg, arg, ... */) {
            var args = Array.prototype.slice.call(arguments, 1);
            var result = string.value;
            var _loop_1 = function (i) {
                /* jshint loopfunc:true */
                result = result.replace(/%[sda]/i, function (token) {
                    var value = ((args[i].type === 'Quoted') &&
                        token.match(/s/i)) ? args[i].value : args[i].toCSS();
                    return token.match(/[A-Z]$/) ? encodeURIComponent(value) : value;
                });
            };
            for (var i = 0; i < args.length; i++) {
                _loop_1(i);
            }
            result = result.replace(/%%/g, '%');
            return new quoted_1.default(string.quote || '', result, string.escaped);
        }
    };
    
},
/* less/lib/less/functions/svg.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(138) /* ../tree/dimension */);
    var color_1 = tslib_1.__importDefault(require(115) /* ../tree/color */);
    var expression_1 = tslib_1.__importDefault(require(143) /* ../tree/expression */);
    var quoted_1 = tslib_1.__importDefault(require(146) /* ../tree/quoted */);
    var url_1 = tslib_1.__importDefault(require(147) /* ../tree/url */);
    exports.default = (function (environment) {
        return { 'svg-gradient': function (direction) {
                var stops;
                var gradientDirectionSvg;
                var gradientType = 'linear';
                var rectangleDimension = 'x="0" y="0" width="1" height="1"';
                var renderEnv = { compress: false };
                var returner;
                var directionValue = direction.toCSS(renderEnv);
                var i;
                var color;
                var position;
                var positionValue;
                var alpha;
                function throwArgumentDescriptor() {
                    throw { type: 'Argument',
                        message: 'svg-gradient expects direction, start_color [start_position], [color position,]...,' +
                            ' end_color [end_position] or direction, color list' };
                }
                if (arguments.length == 2) {
                    if (arguments[1].value.length < 2) {
                        throwArgumentDescriptor();
                    }
                    stops = arguments[1].value;
                }
                else if (arguments.length < 3) {
                    throwArgumentDescriptor();
                }
                else {
                    stops = Array.prototype.slice.call(arguments, 1);
                }
                switch (directionValue) {
                    case 'to bottom':
                        gradientDirectionSvg = 'x1="0%" y1="0%" x2="0%" y2="100%"';
                        break;
                    case 'to right':
                        gradientDirectionSvg = 'x1="0%" y1="0%" x2="100%" y2="0%"';
                        break;
                    case 'to bottom right':
                        gradientDirectionSvg = 'x1="0%" y1="0%" x2="100%" y2="100%"';
                        break;
                    case 'to top right':
                        gradientDirectionSvg = 'x1="0%" y1="100%" x2="100%" y2="0%"';
                        break;
                    case 'ellipse':
                    case 'ellipse at center':
                        gradientType = 'radial';
                        gradientDirectionSvg = 'cx="50%" cy="50%" r="75%"';
                        rectangleDimension = 'x="-50" y="-50" width="101" height="101"';
                        break;
                    default:
                        throw { type: 'Argument', message: 'svg-gradient direction must be \'to bottom\', \'to right\',' +
                                ' \'to bottom right\', \'to top right\' or \'ellipse at center\'' };
                }
                returner = "<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 1 1\"><" + gradientType + "Gradient id=\"g\" " + gradientDirectionSvg + ">";
                for (i = 0; i < stops.length; i += 1) {
                    if (stops[i] instanceof expression_1.default) {
                        color = stops[i].value[0];
                        position = stops[i].value[1];
                    }
                    else {
                        color = stops[i];
                        position = undefined;
                    }
                    if (!(color instanceof color_1.default) || (!((i === 0 || i + 1 === stops.length) && position === undefined) && !(position instanceof dimension_1.default))) {
                        throwArgumentDescriptor();
                    }
                    positionValue = position ? position.toCSS(renderEnv) : i === 0 ? '0%' : '100%';
                    alpha = color.alpha;
                    returner += "<stop offset=\"" + positionValue + "\" stop-color=\"" + color.toRGB() + "\"" + (alpha < 1 ? " stop-opacity=\"" + alpha + "\"" : '') + "/>";
                }
                returner += "</" + gradientType + "Gradient><rect " + rectangleDimension + " fill=\"url(#g)\" /></svg>";
                returner = encodeURIComponent(returner);
                returner = "data:image/svg+xml," + returner;
                return new url_1.default(new quoted_1.default("'" + returner + "'", returner, false, this.index, this.currentFileInfo), this.index, this.currentFileInfo);
            } };
    });
    
},
/* less/lib/less/functions/types.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var keyword_1 = tslib_1.__importDefault(require(129) /* ../tree/keyword */);
    var detached_ruleset_1 = tslib_1.__importDefault(require(136) /* ../tree/detached-ruleset */);
    var dimension_1 = tslib_1.__importDefault(require(138) /* ../tree/dimension */);
    var color_1 = tslib_1.__importDefault(require(115) /* ../tree/color */);
    var quoted_1 = tslib_1.__importDefault(require(146) /* ../tree/quoted */);
    var anonymous_1 = tslib_1.__importDefault(require(130) /* ../tree/anonymous */);
    var url_1 = tslib_1.__importDefault(require(147) /* ../tree/url */);
    var operation_1 = tslib_1.__importDefault(require(137) /* ../tree/operation */);
    var isa = function (n, Type) { return (n instanceof Type) ? keyword_1.default.True : keyword_1.default.False; };
    var isunit = function (n, unit) {
        if (unit === undefined) {
            throw { type: 'Argument', message: 'missing the required second argument to isunit.' };
        }
        unit = typeof unit.value === 'string' ? unit.value : unit;
        if (typeof unit !== 'string') {
            throw { type: 'Argument', message: 'Second argument to isunit should be a unit or a string.' };
        }
        return (n instanceof dimension_1.default) && n.unit.is(unit) ? keyword_1.default.True : keyword_1.default.False;
    };
    exports.default = {
        isruleset: function (n) {
            return isa(n, detached_ruleset_1.default);
        },
        iscolor: function (n) {
            return isa(n, color_1.default);
        },
        isnumber: function (n) {
            return isa(n, dimension_1.default);
        },
        isstring: function (n) {
            return isa(n, quoted_1.default);
        },
        iskeyword: function (n) {
            return isa(n, keyword_1.default);
        },
        isurl: function (n) {
            return isa(n, url_1.default);
        },
        ispixel: function (n) {
            return isunit(n, 'px');
        },
        ispercentage: function (n) {
            return isunit(n, '%');
        },
        isem: function (n) {
            return isunit(n, 'em');
        },
        isunit: isunit,
        unit: function (val, unit) {
            if (!(val instanceof dimension_1.default)) {
                throw { type: 'Argument',
                    message: "the first argument to unit must be a number" + (val instanceof operation_1.default ? '. Have you forgotten parenthesis?' : '') };
            }
            if (unit) {
                if (unit instanceof keyword_1.default) {
                    unit = unit.value;
                }
                else {
                    unit = unit.toCSS();
                }
            }
            else {
                unit = '';
            }
            return new dimension_1.default(val.value, unit);
        },
        'get-unit': function (n) {
            return new anonymous_1.default(n.unit);
        }
    };
    
},
/* less/lib/less/transform-tree.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var contexts_1 = tslib_1.__importDefault(require(133) /* ./contexts */);
    var visitors_1 = tslib_1.__importDefault(require(162) /* ./visitors */);
    var tree_1 = tslib_1.__importDefault(require(113) /* ./tree */);
    function default_1(root, options) {
        options = options || {};
        var evaldRoot;
        var variables = options.variables;
        var evalEnv = new contexts_1.default.Eval(options);
        //
        // Allows setting variables with a hash, so:
        //
        //   `{ color: new tree.Color('#f01') }` will become:
        //
        //   new tree.Declaration('@color',
        //     new tree.Value([
        //       new tree.Expression([
        //         new tree.Color('#f01')
        //       ])
        //     ])
        //   )
        //
        if (typeof variables === 'object' && !Array.isArray(variables)) {
            variables = Object.keys(variables).map(function (k) {
                var value = variables[k];
                if (!(value instanceof tree_1.default.Value)) {
                    if (!(value instanceof tree_1.default.Expression)) {
                        value = new tree_1.default.Expression([value]);
                    }
                    value = new tree_1.default.Value([value]);
                }
                return new tree_1.default.Declaration("@" + k, value, false, null, 0);
            });
            evalEnv.frames = [new tree_1.default.Ruleset(null, variables)];
        }
        var visitors = [
            new visitors_1.default.JoinSelectorVisitor(),
            new visitors_1.default.MarkVisibleSelectorsVisitor(true),
            new visitors_1.default.ExtendVisitor(),
            new visitors_1.default.ToCSSVisitor({ compress: Boolean(options.compress) })
        ];
        var preEvalVisitors = [];
        var v;
        var visitorIterator;
        /**
         * first() / get() allows visitors to be added while visiting
         *
         * @todo Add scoping for visitors just like functions for @plugin; right now they're global
         */
        if (options.pluginManager) {
            visitorIterator = options.pluginManager.visitor();
            for (var i = 0; i < 2; i++) {
                visitorIterator.first();
                while ((v = visitorIterator.get())) {
                    if (v.isPreEvalVisitor) {
                        if (i === 0 || preEvalVisitors.indexOf(v) === -1) {
                            preEvalVisitors.push(v);
                            v.run(root);
                        }
                    }
                    else {
                        if (i === 0 || visitors.indexOf(v) === -1) {
                            if (v.isPreVisitor) {
                                visitors.unshift(v);
                            }
                            else {
                                visitors.push(v);
                            }
                        }
                    }
                }
            }
        }
        evaldRoot = root.eval(evalEnv);
        for (var i = 0; i < visitors.length; i++) {
            visitors[i].run(evaldRoot);
        }
        // Run any remaining visitors added after eval pass
        if (options.pluginManager) {
            visitorIterator.first();
            while ((v = visitorIterator.get())) {
                if (visitors.indexOf(v) === -1 && preEvalVisitors.indexOf(v) === -1) {
                    v.run(evaldRoot);
                }
            }
        }
        return evaldRoot;
    }
    exports.default = default_1;
    ;
    
},
/* less/lib/less/plugin-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * Plugin Manager
     */
    var PluginManager = /** @class */ (function () {
        function PluginManager(less) {
            this.less = less;
            this.visitors = [];
            this.preProcessors = [];
            this.postProcessors = [];
            this.installedPlugins = [];
            this.fileManagers = [];
            this.iterator = -1;
            this.pluginCache = {};
            this.Loader = new less.PluginLoader(less);
        }
        /**
         * Adds all the plugins in the array
         * @param {Array} plugins
         */
        PluginManager.prototype.addPlugins = function (plugins) {
            if (plugins) {
                for (var i = 0; i < plugins.length; i++) {
                    this.addPlugin(plugins[i]);
                }
            }
        };
        /**
         *
         * @param plugin
         * @param {String} filename
         */
        PluginManager.prototype.addPlugin = function (plugin, filename, functionRegistry) {
            this.installedPlugins.push(plugin);
            if (filename) {
                this.pluginCache[filename] = plugin;
            }
            if (plugin.install) {
                plugin.install(this.less, this, functionRegistry || this.less.functions.functionRegistry);
            }
        };
        /**
         *
         * @param filename
         */
        PluginManager.prototype.get = function (filename) {
            return this.pluginCache[filename];
        };
        /**
         * Adds a visitor. The visitor object has options on itself to determine
         * when it should run.
         * @param visitor
         */
        PluginManager.prototype.addVisitor = function (visitor) {
            this.visitors.push(visitor);
        };
        /**
         * Adds a pre processor object
         * @param {object} preProcessor
         * @param {number} priority - guidelines 1 = before import, 1000 = import, 2000 = after import
         */
        PluginManager.prototype.addPreProcessor = function (preProcessor, priority) {
            var indexToInsertAt;
            for (indexToInsertAt = 0; indexToInsertAt < this.preProcessors.length; indexToInsertAt++) {
                if (this.preProcessors[indexToInsertAt].priority >= priority) {
                    break;
                }
            }
            this.preProcessors.splice(indexToInsertAt, 0, { preProcessor: preProcessor, priority: priority });
        };
        /**
         * Adds a post processor object
         * @param {object} postProcessor
         * @param {number} priority - guidelines 1 = before compression, 1000 = compression, 2000 = after compression
         */
        PluginManager.prototype.addPostProcessor = function (postProcessor, priority) {
            var indexToInsertAt;
            for (indexToInsertAt = 0; indexToInsertAt < this.postProcessors.length; indexToInsertAt++) {
                if (this.postProcessors[indexToInsertAt].priority >= priority) {
                    break;
                }
            }
            this.postProcessors.splice(indexToInsertAt, 0, { postProcessor: postProcessor, priority: priority });
        };
        /**
         *
         * @param manager
         */
        PluginManager.prototype.addFileManager = function (manager) {
            this.fileManagers.push(manager);
        };
        /**
         *
         * @returns {Array}
         * @private
         */
        PluginManager.prototype.getPreProcessors = function () {
            var preProcessors = [];
            for (var i = 0; i < this.preProcessors.length; i++) {
                preProcessors.push(this.preProcessors[i].preProcessor);
            }
            return preProcessors;
        };
        /**
         *
         * @returns {Array}
         * @private
         */
        PluginManager.prototype.getPostProcessors = function () {
            var postProcessors = [];
            for (var i = 0; i < this.postProcessors.length; i++) {
                postProcessors.push(this.postProcessors[i].postProcessor);
            }
            return postProcessors;
        };
        /**
         *
         * @returns {Array}
         * @private
         */
        PluginManager.prototype.getVisitors = function () {
            return this.visitors;
        };
        PluginManager.prototype.visitor = function () {
            var self = this;
            return {
                first: function () {
                    self.iterator = -1;
                    return self.visitors[self.iterator];
                },
                get: function () {
                    self.iterator += 1;
                    return self.visitors[self.iterator];
                }
            };
        };
        /**
         *
         * @returns {Array}
         * @private
         */
        PluginManager.prototype.getFileManagers = function () {
            return this.fileManagers;
        };
        return PluginManager;
    }());
    var pm;
    var PluginManagerFactory = function (less, newFactory) {
        if (newFactory || !pm) {
            pm = new PluginManager(less);
        }
        return pm;
    };
    //
    exports.default = PluginManagerFactory;
    
},
/* less/lib/less/source-map-output.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function default_1(environment) {
        var SourceMapOutput = /** @class */ (function () {
            function SourceMapOutput(options) {
                this._css = [];
                this._rootNode = options.rootNode;
                this._contentsMap = options.contentsMap;
                this._contentsIgnoredCharsMap = options.contentsIgnoredCharsMap;
                if (options.sourceMapFilename) {
                    this._sourceMapFilename = options.sourceMapFilename.replace(/\\/g, '/');
                }
                this._outputFilename = options.outputFilename;
                this.sourceMapURL = options.sourceMapURL;
                if (options.sourceMapBasepath) {
                    this._sourceMapBasepath = options.sourceMapBasepath.replace(/\\/g, '/');
                }
                if (options.sourceMapRootpath) {
                    this._sourceMapRootpath = options.sourceMapRootpath.replace(/\\/g, '/');
                    if (this._sourceMapRootpath.charAt(this._sourceMapRootpath.length - 1) !== '/') {
                        this._sourceMapRootpath += '/';
                    }
                }
                else {
                    this._sourceMapRootpath = '';
                }
                this._outputSourceFiles = options.outputSourceFiles;
                this._sourceMapGeneratorConstructor = environment.getSourceMapGenerator();
                this._lineNumber = 0;
                this._column = 0;
            }
            SourceMapOutput.prototype.removeBasepath = function (path) {
                if (this._sourceMapBasepath && path.indexOf(this._sourceMapBasepath) === 0) {
                    path = path.substring(this._sourceMapBasepath.length);
                    if (path.charAt(0) === '\\' || path.charAt(0) === '/') {
                        path = path.substring(1);
                    }
                }
                return path;
            };
            SourceMapOutput.prototype.normalizeFilename = function (filename) {
                filename = filename.replace(/\\/g, '/');
                filename = this.removeBasepath(filename);
                return (this._sourceMapRootpath || '') + filename;
            };
            SourceMapOutput.prototype.add = function (chunk, fileInfo, index, mapLines) {
                // ignore adding empty strings
                if (!chunk) {
                    return;
                }
                var lines, sourceLines, columns, sourceColumns, i;
                if (fileInfo && fileInfo.filename) {
                    var inputSource = this._contentsMap[fileInfo.filename];
                    // remove vars/banner added to the top of the file
                    if (this._contentsIgnoredCharsMap[fileInfo.filename]) {
                        // adjust the index
                        index -= this._contentsIgnoredCharsMap[fileInfo.filename];
                        if (index < 0) {
                            index = 0;
                        }
                        // adjust the source
                        inputSource = inputSource.slice(this._contentsIgnoredCharsMap[fileInfo.filename]);
                    }
                    /**
                     * ignore empty content, or failsafe
                     * if contents map is incorrect
                     */
                    if (inputSource === undefined) {
                        this._css.push(chunk);
                        return;
                    }
                    inputSource = inputSource.substring(0, index);
                    sourceLines = inputSource.split('\n');
                    sourceColumns = sourceLines[sourceLines.length - 1];
                }
                lines = chunk.split('\n');
                columns = lines[lines.length - 1];
                if (fileInfo && fileInfo.filename) {
                    if (!mapLines) {
                        this._sourceMapGenerator.addMapping({ generated: { line: this._lineNumber + 1, column: this._column },
                            original: { line: sourceLines.length, column: sourceColumns.length },
                            source: this.normalizeFilename(fileInfo.filename) });
                    }
                    else {
                        for (i = 0; i < lines.length; i++) {
                            this._sourceMapGenerator.addMapping({ generated: { line: this._lineNumber + i + 1, column: i === 0 ? this._column : 0 },
                                original: { line: sourceLines.length + i, column: i === 0 ? sourceColumns.length : 0 },
                                source: this.normalizeFilename(fileInfo.filename) });
                        }
                    }
                }
                if (lines.length === 1) {
                    this._column += columns.length;
                }
                else {
                    this._lineNumber += lines.length - 1;
                    this._column = columns.length;
                }
                this._css.push(chunk);
            };
            SourceMapOutput.prototype.isEmpty = function () {
                return this._css.length === 0;
            };
            SourceMapOutput.prototype.toCSS = function (context) {
                this._sourceMapGenerator = new this._sourceMapGeneratorConstructor({ file: this._outputFilename, sourceRoot: null });
                if (this._outputSourceFiles) {
                    for (var filename in this._contentsMap) {
                        if (this._contentsMap.hasOwnProperty(filename)) {
                            var source = this._contentsMap[filename];
                            if (this._contentsIgnoredCharsMap[filename]) {
                                source = source.slice(this._contentsIgnoredCharsMap[filename]);
                            }
                            this._sourceMapGenerator.setSourceContent(this.normalizeFilename(filename), source);
                        }
                    }
                }
                this._rootNode.genCSS(context, this);
                if (this._css.length > 0) {
                    var sourceMapURL = void 0;
                    var sourceMapContent = JSON.stringify(this._sourceMapGenerator.toJSON());
                    if (this.sourceMapURL) {
                        sourceMapURL = this.sourceMapURL;
                    }
                    else if (this._sourceMapFilename) {
                        sourceMapURL = this._sourceMapFilename;
                    }
                    this.sourceMapURL = sourceMapURL;
                    this.sourceMap = sourceMapContent;
                }
                return this._css.join('');
            };
            return SourceMapOutput;
        }());
        return SourceMapOutput;
    }
    exports.default = default_1;
    ;
    
},
/* less/lib/less/source-map-builder.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function default_1(SourceMapOutput, environment) {
        var SourceMapBuilder = /** @class */ (function () {
            function SourceMapBuilder(options) {
                this.options = options;
            }
            SourceMapBuilder.prototype.toCSS = function (rootNode, options, imports) {
                var sourceMapOutput = new SourceMapOutput({
                    contentsIgnoredCharsMap: imports.contentsIgnoredChars,
                    rootNode: rootNode,
                    contentsMap: imports.contents,
                    sourceMapFilename: this.options.sourceMapFilename,
                    sourceMapURL: this.options.sourceMapURL,
                    outputFilename: this.options.sourceMapOutputFilename,
                    sourceMapBasepath: this.options.sourceMapBasepath,
                    sourceMapRootpath: this.options.sourceMapRootpath,
                    outputSourceFiles: this.options.outputSourceFiles,
                    sourceMapGenerator: this.options.sourceMapGenerator,
                    sourceMapFileInline: this.options.sourceMapFileInline,
                    disableSourcemapAnnotation: this.options.disableSourcemapAnnotation
                });
                var css = sourceMapOutput.toCSS(options);
                this.sourceMap = sourceMapOutput.sourceMap;
                this.sourceMapURL = sourceMapOutput.sourceMapURL;
                if (this.options.sourceMapInputFilename) {
                    this.sourceMapInputFilename = sourceMapOutput.normalizeFilename(this.options.sourceMapInputFilename);
                }
                if (this.options.sourceMapBasepath !== undefined && this.sourceMapURL !== undefined) {
                    this.sourceMapURL = sourceMapOutput.removeBasepath(this.sourceMapURL);
                }
                return css + this.getCSSAppendage();
            };
            SourceMapBuilder.prototype.getCSSAppendage = function () {
                var sourceMapURL = this.sourceMapURL;
                if (this.options.sourceMapFileInline) {
                    if (this.sourceMap === undefined) {
                        return '';
                    }
                    sourceMapURL = "data:application/json;base64," + environment.encodeBase64(this.sourceMap);
                }
                if (this.options.disableSourcemapAnnotation) {
                    return '';
                }
                if (sourceMapURL) {
                    return "/*# sourceMappingURL=" + sourceMapURL + " */";
                }
                return '';
            };
            SourceMapBuilder.prototype.getExternalSourceMap = function () {
                return this.sourceMap;
            };
            SourceMapBuilder.prototype.setExternalSourceMap = function (sourceMap) {
                this.sourceMap = sourceMap;
            };
            SourceMapBuilder.prototype.isInline = function () {
                return this.options.sourceMapFileInline;
            };
            SourceMapBuilder.prototype.getSourceMapURL = function () {
                return this.sourceMapURL;
            };
            SourceMapBuilder.prototype.getOutputFilename = function () {
                return this.options.sourceMapOutputFilename;
            };
            SourceMapBuilder.prototype.getInputFilename = function () {
                return this.sourceMapInputFilename;
            };
            return SourceMapBuilder;
        }());
        return SourceMapBuilder;
    }
    exports.default = default_1;
    ;
    
},
/* less/lib/less/parse-tree.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var less_error_1 = tslib_1.__importDefault(require(121) /* ./less-error */);
    var transform_tree_1 = tslib_1.__importDefault(require(185) /* ./transform-tree */);
    var logger_1 = tslib_1.__importDefault(require(70) /* ./logger */);
    function default_1(SourceMapBuilder) {
        var ParseTree = /** @class */ (function () {
            function ParseTree(root, imports) {
                this.root = root;
                this.imports = imports;
            }
            ParseTree.prototype.toCSS = function (options) {
                var evaldRoot;
                var result = {};
                var sourceMapBuilder;
                try {
                    evaldRoot = transform_tree_1.default(this.root, options);
                }
                catch (e) {
                    throw new less_error_1.default(e, this.imports);
                }
                try {
                    var compress = Boolean(options.compress);
                    if (compress) {
                        logger_1.default.warn('The compress option has been deprecated. ' +
                            'We recommend you use a dedicated css minifier, for instance see less-plugin-clean-css.');
                    }
                    var toCSSOptions = {
                        compress: compress,
                        dumpLineNumbers: options.dumpLineNumbers,
                        strictUnits: Boolean(options.strictUnits),
                        numPrecision: 8
                    };
                    if (options.sourceMap) {
                        sourceMapBuilder = new SourceMapBuilder(options.sourceMap);
                        result.css = sourceMapBuilder.toCSS(evaldRoot, toCSSOptions, this.imports);
                    }
                    else {
                        result.css = evaldRoot.toCSS(toCSSOptions);
                    }
                }
                catch (e) {
                    throw new less_error_1.default(e, this.imports);
                }
                if (options.pluginManager) {
                    var postProcessors = options.pluginManager.getPostProcessors();
                    for (var i = 0; i < postProcessors.length; i++) {
                        result.css = postProcessors[i].process(result.css, { sourceMap: sourceMapBuilder, options: options, imports: this.imports });
                    }
                }
                if (options.sourceMap) {
                    result.map = sourceMapBuilder.getExternalSourceMap();
                }
                result.imports = [];
                for (var file in this.imports.files) {
                    if (this.imports.files.hasOwnProperty(file) && file !== this.imports.rootFilename) {
                        result.imports.push(file);
                    }
                }
                return result;
            };
            return ParseTree;
        }());
        return ParseTree;
    }
    exports.default = default_1;
    ;
    
},
/* less/lib/less/import-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var contexts_1 = tslib_1.__importDefault(require(133) /* ./contexts */);
    var parser_1 = tslib_1.__importDefault(require(170) /* ./parser/parser */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ./less-error */);
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    var logger_1 = tslib_1.__importDefault(require(70) /* ./logger */);
    function default_1(environment) {
        // FileInfo = {
        //  'rewriteUrls' - option - whether to adjust URL's to be relative
        //  'filename' - full resolved filename of current file
        //  'rootpath' - path to append to normal URLs for this node
        //  'currentDirectory' - path to the current file, absolute
        //  'rootFilename' - filename of the base file
        //  'entryPath' - absolute path to the entry file
        //  'reference' - whether the file should not be output and only output parts that are referenced
        var ImportManager = /** @class */ (function () {
            function ImportManager(less, context, rootFileInfo) {
                this.less = less;
                this.rootFilename = rootFileInfo.filename;
                this.paths = context.paths || []; // Search paths, when importing
                this.contents = {}; // map - filename to contents of all the files
                this.contentsIgnoredChars = {}; // map - filename to lines at the beginning of each file to ignore
                this.mime = context.mime;
                this.error = null;
                this.context = context;
                // Deprecated? Unused outside of here, could be useful.
                this.queue = []; // Files which haven't been imported yet
                this.files = {}; // Holds the imported parse trees.
            }
            /**
             * Add an import to be imported
             * @param path - the raw path
             * @param tryAppendExtension - whether to try appending a file extension (.less or .js if the path has no extension)
             * @param currentFileInfo - the current file info (used for instance to work out relative paths)
             * @param importOptions - import options
             * @param callback - callback for when it is imported
             */
            ImportManager.prototype.push = function (path, tryAppendExtension, currentFileInfo, importOptions, callback) {
                var importManager = this, pluginLoader = this.context.pluginManager.Loader;
                this.queue.push(path);
                var fileParsedFunc = function (e, root, fullPath) {
                    importManager.queue.splice(importManager.queue.indexOf(path), 1); // Remove the path from the queue
                    var importedEqualsRoot = fullPath === importManager.rootFilename;
                    if (importOptions.optional && e) {
                        callback(null, { rules: [] }, false, null);
                        logger_1.default.info("The file " + fullPath + " was skipped because it was not found and the import was marked optional.");
                    }
                    else {
                        // Inline imports aren't cached here.
                        // If we start to cache them, please make sure they won't conflict with non-inline imports of the
                        // same name as they used to do before this comment and the condition below have been added.
                        if (!importManager.files[fullPath] && !importOptions.inline) {
                            importManager.files[fullPath] = { root: root, options: importOptions };
                        }
                        if (e && !importManager.error) {
                            importManager.error = e;
                        }
                        callback(e, root, importedEqualsRoot, fullPath);
                    }
                };
                var newFileInfo = {
                    rewriteUrls: this.context.rewriteUrls,
                    entryPath: currentFileInfo.entryPath,
                    rootpath: currentFileInfo.rootpath,
                    rootFilename: currentFileInfo.rootFilename
                };
                var fileManager = environment.getFileManager(path, currentFileInfo.currentDirectory, this.context, environment);
                if (!fileManager) {
                    fileParsedFunc({ message: "Could not find a file-manager for " + path });
                    return;
                }
                var loadFileCallback = function (loadedFile) {
                    var plugin;
                    var resolvedFilename = loadedFile.filename;
                    var contents = loadedFile.contents.replace(/^\uFEFF/, '');
                    // Pass on an updated rootpath if path of imported file is relative and file
                    // is in a (sub|sup) directory
                    //
                    // Examples:
                    // - If path of imported file is 'module/nav/nav.less' and rootpath is 'less/',
                    //   then rootpath should become 'less/module/nav/'
                    // - If path of imported file is '../mixins.less' and rootpath is 'less/',
                    //   then rootpath should become 'less/../'
                    newFileInfo.currentDirectory = fileManager.getPath(resolvedFilename);
                    if (newFileInfo.rewriteUrls) {
                        newFileInfo.rootpath = fileManager.join((importManager.context.rootpath || ''), fileManager.pathDiff(newFileInfo.currentDirectory, newFileInfo.entryPath));
                        if (!fileManager.isPathAbsolute(newFileInfo.rootpath) && fileManager.alwaysMakePathsAbsolute()) {
                            newFileInfo.rootpath = fileManager.join(newFileInfo.entryPath, newFileInfo.rootpath);
                        }
                    }
                    newFileInfo.filename = resolvedFilename;
                    var newEnv = new contexts_1.default.Parse(importManager.context);
                    newEnv.processImports = false;
                    importManager.contents[resolvedFilename] = contents;
                    if (currentFileInfo.reference || importOptions.reference) {
                        newFileInfo.reference = true;
                    }
                    if (importOptions.isPlugin) {
                        plugin = pluginLoader.evalPlugin(contents, newEnv, importManager, importOptions.pluginArgs, newFileInfo);
                        if (plugin instanceof less_error_1.default) {
                            fileParsedFunc(plugin, null, resolvedFilename);
                        }
                        else {
                            fileParsedFunc(null, plugin, resolvedFilename);
                        }
                    }
                    else if (importOptions.inline) {
                        fileParsedFunc(null, contents, resolvedFilename);
                    }
                    else {
                        // import (multiple) parse trees apparently get altered and can't be cached.
                        // TODO: investigate why this is
                        if (importManager.files[resolvedFilename]
                            && !importManager.files[resolvedFilename].options.multiple
                            && !importOptions.multiple) {
                            fileParsedFunc(null, importManager.files[resolvedFilename].root, resolvedFilename);
                        }
                        else {
                            new parser_1.default(newEnv, importManager, newFileInfo).parse(contents, function (e, root) {
                                fileParsedFunc(e, root, resolvedFilename);
                            });
                        }
                    }
                };
                var loadedFile;
                var promise;
                var context = utils.clone(this.context);
                if (tryAppendExtension) {
                    context.ext = importOptions.isPlugin ? '.js' : '.less';
                }
                if (importOptions.isPlugin) {
                    context.mime = 'application/javascript';
                    if (context.syncImport) {
                        loadedFile = pluginLoader.loadPluginSync(path, currentFileInfo.currentDirectory, context, environment, fileManager);
                    }
                    else {
                        promise = pluginLoader.loadPlugin(path, currentFileInfo.currentDirectory, context, environment, fileManager);
                    }
                }
                else {
                    if (context.syncImport) {
                        loadedFile = fileManager.loadFileSync(path, currentFileInfo.currentDirectory, context, environment);
                    }
                    else {
                        promise = fileManager.loadFile(path, currentFileInfo.currentDirectory, context, environment, function (err, loadedFile) {
                            if (err) {
                                fileParsedFunc(err);
                            }
                            else {
                                loadFileCallback(loadedFile);
                            }
                        });
                    }
                }
                if (loadedFile) {
                    if (!loadedFile.filename) {
                        fileParsedFunc(loadedFile);
                    }
                    else {
                        loadFileCallback(loadedFile);
                    }
                }
                else if (promise) {
                    promise.then(loadFileCallback, fileParsedFunc);
                }
            };
            return ImportManager;
        }());
        return ImportManager;
    }
    exports.default = default_1;
    ;
    
},
/* less/lib/less/parse.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var contexts_1 = tslib_1.__importDefault(require(133) /* ./contexts */);
    var parser_1 = tslib_1.__importDefault(require(170) /* ./parser/parser */);
    var plugin_manager_1 = tslib_1.__importDefault(require(186) /* ./plugin-manager */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ./less-error */);
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    function default_1(environment, ParseTree, ImportManager) {
        var parse = function (input, options, callback) {
            if (typeof options === 'function') {
                callback = options;
                options = utils.copyOptions(this.options, {});
            }
            else {
                options = utils.copyOptions(this.options, options || {});
            }
            if (!callback) {
                var self_1 = this;
                return new Promise(function (resolve, reject) {
                    parse.call(self_1, input, options, function (err, output) {
                        if (err) {
                            reject(err);
                        }
                        else {
                            resolve(output);
                        }
                    });
                });
            }
            else {
                var context_1;
                var rootFileInfo = void 0;
                var pluginManager_1 = new plugin_manager_1.default(this, !options.reUsePluginManager);
                options.pluginManager = pluginManager_1;
                context_1 = new contexts_1.default.Parse(options);
                if (options.rootFileInfo) {
                    rootFileInfo = options.rootFileInfo;
                }
                else {
                    var filename = options.filename || 'input';
                    var entryPath = filename.replace(/[^\/\\]*$/, '');
                    rootFileInfo = {
                        filename: filename,
                        rewriteUrls: context_1.rewriteUrls,
                        rootpath: context_1.rootpath || '',
                        currentDirectory: entryPath,
                        entryPath: entryPath,
                        rootFilename: filename
                    };
                    // add in a missing trailing slash
                    if (rootFileInfo.rootpath && rootFileInfo.rootpath.slice(-1) !== '/') {
                        rootFileInfo.rootpath += '/';
                    }
                }
                var imports_1 = new ImportManager(this, context_1, rootFileInfo);
                this.importManager = imports_1;
                // TODO: allow the plugins to be just a list of paths or names
                // Do an async plugin queue like lessc
                if (options.plugins) {
                    options.plugins.forEach(function (plugin) {
                        var evalResult, contents;
                        if (plugin.fileContent) {
                            contents = plugin.fileContent.replace(/^\uFEFF/, '');
                            evalResult = pluginManager_1.Loader.evalPlugin(contents, context_1, imports_1, plugin.options, plugin.filename);
                            if (evalResult instanceof less_error_1.default) {
                                return callback(evalResult);
                            }
                        }
                        else {
                            pluginManager_1.addPlugin(plugin);
                        }
                    });
                }
                new parser_1.default(context_1, imports_1, rootFileInfo)
                    .parse(input, function (e, root) {
                    if (e) {
                        return callback(e);
                    }
                    callback(null, root, imports_1, options);
                }, options);
            }
        };
        return parse;
    }
    exports.default = default_1;
    ;
    
},
/* less/lib/less/render.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    function default_1(environment, ParseTree, ImportManager) {
        var render = function (input, options, callback) {
            if (typeof options === 'function') {
                callback = options;
                options = utils.copyOptions(this.options, {});
            }
            else {
                options = utils.copyOptions(this.options, options || {});
            }
            if (!callback) {
                var self_1 = this;
                return new Promise(function (resolve, reject) {
                    render.call(self_1, input, options, function (err, output) {
                        if (err) {
                            reject(err);
                        }
                        else {
                            resolve(output);
                        }
                    });
                });
            }
            else {
                this.parse(input, options, function (err, root, imports, options) {
                    if (err) {
                        return callback(err);
                    }
                    var result;
                    try {
                        var parseTree = new ParseTree(root, imports);
                        result = parseTree.toCSS(options);
                    }
                    catch (err) {
                        return callback(err);
                    }
                    callback(null, result);
                });
            }
        };
        return render;
    }
    exports.default = default_1;
    ;
    
},
/* less/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "less",
        "version": "4.1.3",
        "description": "Leaner CSS",
        "homepage": "http://lesscss.org",
        "author": {
            "name": "Alexis Sellier",
            "email": "self@cloudhead.net"
        },
        "contributors": [
            "The Core Less Team"
        ],
        "bugs": {
            "url": "https://github.com/less/less.js/issues"
        },
        "repository": {
            "type": "git",
            "url": "https://github.com/less/less.js.git"
        },
        "master": {
            "url": "https://github.com/less/less.js/blob/master/",
            "raw": "https://raw.githubusercontent.com/less/less.js/master/"
        },
        "license": "Apache-2.0",
        "bin": {
            "lessc": "./bin/lessc"
        },
        "main": "index",
        "module": "./lib/less-node/index",
        "directories": {
            "test": "./test"
        },
        "browser": "./dist/less.js",
        "engines": {
            "node": ">=6"
        },
        "scripts": {
            "test": "grunt test",
            "grunt": "grunt",
            "build": "npm-run-all clean compile",
            "clean": "shx rm -rf ./lib tsconfig.tsbuildinfo",
            "compile": "tsc -p tsconfig.json",
            "copy:root": "shx cp -rf ./dist ../../",
            "dev": "tsc -p tsconfig.json -w",
            "prepublishOnly": "grunt dist"
        },
        "optionalDependencies": {
            "errno": "^0.1.1",
            "graceful-fs": "^4.1.2",
            "image-size": "~0.5.0",
            "make-dir": "^2.1.0",
            "mime": "^1.4.1",
            "needle": "^3.1.0",
            "source-map": "~0.6.0"
        },
        "devDependencies": {
            "@less/test-data": "^4.1.0",
            "@less/test-import-module": "^4.0.0",
            "@rollup/plugin-commonjs": "^17.0.0",
            "@rollup/plugin-json": "^4.1.0",
            "@rollup/plugin-node-resolve": "^11.0.0",
            "@typescript-eslint/eslint-plugin": "^4.28.0",
            "@typescript-eslint/parser": "^4.28.0",
            "benny": "^3.6.12",
            "bootstrap-less-port": "0.3.0",
            "chai": "^4.2.0",
            "cross-env": "^7.0.3",
            "diff": "^3.2.0",
            "eslint": "^7.29.0",
            "fs-extra": "^8.1.0",
            "git-rev": "^0.2.1",
            "globby": "^10.0.1",
            "grunt": "^1.0.4",
            "grunt-cli": "^1.3.2",
            "grunt-contrib-clean": "^1.0.0",
            "grunt-contrib-connect": "^1.0.2",
            "grunt-eslint": "^23.0.0",
            "grunt-saucelabs": "^9.0.1",
            "grunt-shell": "^1.3.0",
            "html-template-tag": "^3.2.0",
            "jit-grunt": "^0.10.0",
            "less-plugin-autoprefix": "^1.5.1",
            "less-plugin-clean-css": "^1.5.1",
            "minimist": "^1.2.0",
            "mocha": "^6.2.1",
            "mocha-headless-chrome": "^2.0.3",
            "mocha-teamcity-reporter": "^3.0.0",
            "nock": "^11.8.2",
            "npm-run-all": "^4.1.5",
            "performance-now": "^0.2.0",
            "phin": "^2.2.3",
            "promise": "^7.1.1",
            "read-glob": "^3.0.0",
            "resolve": "^1.17.0",
            "rollup": "^2.52.2",
            "rollup-plugin-terser": "^5.1.1",
            "rollup-plugin-typescript2": "^0.29.0",
            "semver": "^6.3.0",
            "shx": "^0.3.2",
            "time-grunt": "^1.3.0",
            "ts-node": "^9.1.1",
            "typescript": "^4.3.4",
            "uikit": "2.27.4"
        },
        "keywords": [
            "compile less",
            "css nesting",
            "css variable",
            "css",
            "gradients css",
            "gradients css3",
            "less compiler",
            "less css",
            "less mixins",
            "less",
            "less.js",
            "lesscss",
            "mixins",
            "nested css",
            "parser",
            "preprocessor",
            "bootstrap css",
            "bootstrap less",
            "style",
            "styles",
            "stylesheet",
            "variables in css",
            "css less"
        ],
        "rawcurrent": "https://raw.github.com/less/less.js/v",
        "sourcearchive": "https://github.com/less/less.js/archive/v",
        "dependencies": {
            "copy-anything": "^2.0.1",
            "parse-node-version": "^1.0.1",
            "tslib": "^2.3.0"
        }
    };
    module.exports = json;
},
/* parse-node-version/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    function parseNodeVersion(version) {
        var match = version.match(/^v(\d{1,2})\.(\d{1,2})\.(\d{1,2})(?:-([0-9A-Za-z-.]+))?(?:\+([0-9A-Za-z-.]+))?$/); // eslint-disable-line max-len
        if (!match) {
            throw new Error('Unable to parse: ' + version);
        }
        var res = {
            major: parseInt(match[1], 10),
            minor: parseInt(match[2], 10),
            patch: parseInt(match[3], 10),
            pre: match[4] || '',
            build: match[5] || '',
        };
        return res;
    }
    module.exports = parseNodeVersion;
},
/* less/lib/less-node/lessc-helper.js */ function _(require, module, exports, __esModule, __esExport) {
    // lessc_helper.js
    //
    //      helper functions for lessc
    var lessc_helper = {
        // Stylize a string
        stylize: function (str, style) {
            var styles = {
                'reset': [0, 0],
                'bold': [1, 22],
                'inverse': [7, 27],
                'underline': [4, 24],
                'yellow': [33, 39],
                'green': [32, 39],
                'red': [31, 39],
                'grey': [90, 39]
            };
            return "\u001B[" + styles[style][0] + "m" + str + "\u001B[" + styles[style][1] + "m";
        },
        // Print command line options
        printUsage: function () {
            console.log('usage: lessc [option option=parameter ...] <source> [destination]');
            console.log('');
            console.log('If source is set to `-\' (dash or hyphen-minus), input is read from stdin.');
            console.log('');
            console.log('options:');
            console.log('  -h, --help                   Prints help (this message) and exit.');
            console.log('  --include-path=PATHS         Sets include paths. Separated by `:\'. `;\' also supported on windows.');
            console.log('  -M, --depends                Outputs a makefile import dependency list to stdout.');
            console.log('  --no-color                   Disables colorized output.');
            console.log('  --ie-compat                  Enables IE8 compatibility checks.');
            console.log('  --js                         Enables inline JavaScript in less files');
            console.log('  -l, --lint                   Syntax check only (lint).');
            console.log('  -s, --silent                 Suppresses output of error messages.');
            console.log('  --strict-imports             Forces evaluation of imports.');
            console.log('  --insecure                   Allows imports from insecure https hosts.');
            console.log('  -v, --version                Prints version number and exit.');
            console.log('  --verbose                    Be verbose.');
            console.log('  --source-map[=FILENAME]      Outputs a v3 sourcemap to the filename (or output filename.map).');
            console.log('  --source-map-rootpath=X      Adds this path onto the sourcemap filename and less file paths.');
            console.log('  --source-map-basepath=X      Sets sourcemap base path, defaults to current working directory.');
            console.log('  --source-map-include-source  Puts the less files into the map instead of referencing them.');
            console.log('  --source-map-inline          Puts the map (and any less files) as a base64 data uri into the output css file.');
            console.log('  --source-map-url=URL         Sets a custom URL to map file, for sourceMappingURL comment');
            console.log('                               in generated CSS file.');
            console.log('  --source-map-no-annotation   Excludes the sourceMappingURL comment from the output css file.');
            console.log('  -rp, --rootpath=URL          Sets rootpath for url rewriting in relative imports and urls');
            console.log('                               Works with or without the relative-urls option.');
            console.log('  -ru=, --rewrite-urls=        Rewrites URLs to make them relative to the base less file.');
            console.log('    all|local|off              \'all\' rewrites all URLs, \'local\' just those starting with a \'.\'');
            console.log('');
            console.log('  -m=, --math=');
            console.log('     always                    Less will eagerly perform math operations always.');
            console.log('     parens-division           Math performed except for division (/) operator');
            console.log('     parens | strict           Math only performed inside parentheses');
            console.log('     strict-legacy             Parens required in very strict terms (legacy --strict-math)');
            console.log('');
            console.log('  -su=on|off                   Allows mixed units, e.g. 1px+1em or 1px*1px which have units');
            console.log('  --strict-units=on|off        that cannot be represented.');
            console.log('  --global-var=\'VAR=VALUE\'     Defines a variable that can be referenced by the file.');
            console.log('  --modify-var=\'VAR=VALUE\'     Modifies a variable already declared in the file.');
            console.log('  --url-args=\'QUERYSTRING\'     Adds params into url tokens (e.g. 42, cb=42 or \'a=1&b=2\')');
            console.log('  --plugin=PLUGIN=OPTIONS      Loads a plugin. You can also omit the --plugin= if the plugin begins');
            console.log('                               less-plugin. E.g. the clean css plugin is called less-plugin-clean-css');
            console.log('                               once installed (npm install less-plugin-clean-css), use either with');
            console.log('                               --plugin=less-plugin-clean-css or just --clean-css');
            console.log('                               specify options afterwards e.g. --plugin=less-plugin-clean-css="advanced"');
            console.log('                               or --clean-css="advanced"');
            console.log('  --disable-plugin-rule        Disallow @plugin statements');
            console.log('');
            console.log('-------------------------- Deprecated ----------------');
            console.log('  -sm=on|off               Legacy parens-only math. Use --math');
            console.log('  --strict-math=on|off     ');
            console.log('');
            console.log('  --line-numbers=TYPE      Outputs filename and line numbers.');
            console.log('                           TYPE can be either \'comments\', which will output');
            console.log('                           the debug info within comments, \'mediaquery\'');
            console.log('                           that will output the information within a fake');
            console.log('                           media query which is compatible with the SASS');
            console.log('                           format, and \'all\' which will do both.');
            console.log('  -x, --compress           Compresses output by removing some whitespaces.');
            console.log('                           We recommend you use a dedicated minifer like less-plugin-clean-css');
            console.log('');
            console.log('Report bugs to: http://github.com/less/less.js/issues');
            console.log('Home page: <http://lesscss.org/>');
        }
    };
    // Exports helper functions
    for (var h in lessc_helper) {
        if (lessc_helper.hasOwnProperty(h)) {
            exports[h] = lessc_helper[h];
        }
    }
    
},
/* less/lib/less-node/plugin-loader.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var path_1 = tslib_1.__importDefault(require("path"));
    var abstract_plugin_loader_js_1 = tslib_1.__importDefault(require(161) /* ../less/environment/abstract-plugin-loader.js */);
    /**
     * Node Plugin Loader
     */
    var PluginLoader = function (less) {
        this.less = less;
        this.require = function (prefix) {
            prefix = path_1.default.dirname(prefix);
            return function (id) {
                var str = id.substr(0, 2);
                if (str === '..' || str === './') {
                    return require(path_1.default.join(prefix, id));
                }
                else {
                    return require(id);
                }
            };
        };
    };
    PluginLoader.prototype = Object.assign(new abstract_plugin_loader_js_1.default(), {
        loadPlugin: function (filename, basePath, context, environment, fileManager) {
            var prefix = filename.slice(0, 1);
            var explicit = prefix === '.' || prefix === '/' || filename.slice(-3).toLowerCase() === '.js';
            if (!explicit) {
                context.prefixes = ['less-plugin-', ''];
            }
            if (context.syncImport) {
                return fileManager.loadFileSync(filename, basePath, context, environment);
            }
            return new Promise(function (fulfill, reject) {
                fileManager.loadFile(filename, basePath, context, environment).then(function (data) {
                    try {
                        fulfill(data);
                    }
                    catch (e) {
                        console.log(e);
                        reject(e);
                    }
                }).catch(function (err) {
                    reject(err);
                });
            });
        },
        loadPluginSync: function (filename, basePath, context, environment, fileManager) {
            context.syncImport = true;
            return this.loadPlugin(filename, basePath, context, environment, fileManager);
        }
    });
    exports.default = PluginLoader;
    
},
/* less/lib/less/default-options.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    // Export a new default each time
    function default_1() {
        return {
            /* Inline Javascript - @plugin still allowed */
            javascriptEnabled: false,
            /* Outputs a makefile import dependency list to stdout. */
            depends: false,
            /* (DEPRECATED) Compress using less built-in compression.
             * This does an okay job but does not utilise all the tricks of
             * dedicated css compression. */
            compress: false,
            /* Runs the less parser and just reports errors without any output. */
            lint: false,
            /* Sets available include paths.
             * If the file in an @import rule does not exist at that exact location,
             * less will look for it at the location(s) passed to this option.
             * You might use this for instance to specify a path to a library which
             * you want to be referenced simply and relatively in the less files. */
            paths: [],
            /* color output in the terminal */
            color: true,
            /* The strictImports controls whether the compiler will allow an @import inside of either
             * @media blocks or (a later addition) other selector blocks.
             * See: https://github.com/less/less.js/issues/656 */
            strictImports: false,
            /* Allow Imports from Insecure HTTPS Hosts */
            insecure: false,
            /* Allows you to add a path to every generated import and url in your css.
             * This does not affect less import statements that are processed, just ones
             * that are left in the output css. */
            rootpath: '',
            /* By default URLs are kept as-is, so if you import a file in a sub-directory
             * that references an image, exactly the same URL will be output in the css.
             * This option allows you to re-write URL's in imported files so that the
             * URL is always relative to the base imported file */
            rewriteUrls: false,
            /* How to process math
             *   0 always           - eagerly try to solve all operations
             *   1 parens-division  - require parens for division "/"
             *   2 parens | strict  - require parens for all operations
             *   3 strict-legacy    - legacy strict behavior (super-strict)
             */
            math: 1,
            /* Without this option, less attempts to guess at the output unit when it does maths. */
            strictUnits: false,
            /* Effectively the declaration is put at the top of your base Less file,
             * meaning it can be used but it also can be overridden if this variable
             * is defined in the file. */
            globalVars: null,
            /* As opposed to the global variable option, this puts the declaration at the
             * end of your base file, meaning it will override anything defined in your Less file. */
            modifyVars: null,
            /* This option allows you to specify a argument to go on to every URL.  */
            urlArgs: ''
        };
    }
    exports.default = default_1;
    ;
    
},
/* less/lib/less-node/image-size.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(58) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(138) /* ../less/tree/dimension */);
    var expression_1 = tslib_1.__importDefault(require(143) /* ../less/tree/expression */);
    var function_registry_1 = tslib_1.__importDefault(require(134) /* ./../less/functions/function-registry */);
    exports.default = (function (environment) {
        function imageSize(functionContext, filePathNode) {
            var filePath = filePathNode.value;
            var currentFileInfo = functionContext.currentFileInfo;
            var currentDirectory = currentFileInfo.rewriteUrls ?
                currentFileInfo.currentDirectory : currentFileInfo.entryPath;
            var fragmentStart = filePath.indexOf('#');
            if (fragmentStart !== -1) {
                filePath = filePath.slice(0, fragmentStart);
            }
            var fileManager = environment.getFileManager(filePath, currentDirectory, functionContext.context, environment, true);
            if (!fileManager) {
                throw {
                    type: 'File',
                    message: "Can not set up FileManager for " + filePathNode
                };
            }
            var fileSync = fileManager.loadFileSync(filePath, currentDirectory, functionContext.context, environment);
            if (fileSync.error) {
                throw fileSync.error;
            }
            var sizeOf = require(199) /* image-size */;
            return sizeOf(fileSync.filename);
        }
        var imageFunctions = {
            'image-size': function (filePathNode) {
                var size = imageSize(this, filePathNode);
                return new expression_1.default([
                    new dimension_1.default(size.width, 'px'),
                    new dimension_1.default(size.height, 'px')
                ]);
            },
            'image-width': function (filePathNode) {
                var size = imageSize(this, filePathNode);
                return new dimension_1.default(size.width, 'px');
            },
            'image-height': function (filePathNode) {
                var size = imageSize(this, filePathNode);
                return new dimension_1.default(size.height, 'px');
            }
        };
        function_registry_1.default.addMultiple(imageFunctions);
    });
    
},
/* image-size/lib/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var fs = require('fs');
    var path = require('path');
    var detector = require(200) /* ./detector */;
    var handlers = {};
    var types = require(201) /* ./types */;
    // load all available handlers
    types.forEach(function (type) {
        handlers[type] = require('./types/' + type);
    });
    // Maximum buffer size, with a default of 128 kilobytes.
    // TO-DO: make this adaptive based on the initial signature of the image
    var MaxBufferSize = 128 * 1024;
    function lookup(buffer, filepath) {
        // detect the file type.. don't rely on the extension
        var type = detector(buffer, filepath);
        // find an appropriate handler for this file type
        if (type in handlers) {
            var size = handlers[type].calculate(buffer, filepath);
            if (size !== false) {
                size.type = type;
                return size;
            }
        }
        // throw up, if we don't understand the file
        throw new TypeError('unsupported file type: ' + type + ' (file: ' + filepath + ')');
    }
    function asyncFileToBuffer(filepath, callback) {
        // open the file in read only mode
        fs.open(filepath, 'r', function (err, descriptor) {
            if (err) {
                return callback(err);
            }
            var size = fs.fstatSync(descriptor).size;
            if (size <= 0) {
                return callback(new Error("File size is not greater than 0 —— " + filepath));
            }
            var bufferSize = Math.min(size, MaxBufferSize);
            var buffer = new Buffer(bufferSize);
            // read first buffer block from the file, asynchronously
            fs.read(descriptor, buffer, 0, bufferSize, 0, function (err) {
                if (err) {
                    return callback(err);
                }
                // close the file, we are done
                fs.close(descriptor, function (err) {
                    callback(err, buffer);
                });
            });
        });
    }
    function syncFileToBuffer(filepath) {
        // read from the file, synchronously
        var descriptor = fs.openSync(filepath, 'r');
        var size = fs.fstatSync(descriptor).size;
        var bufferSize = Math.min(size, MaxBufferSize);
        var buffer = new Buffer(bufferSize);
        fs.readSync(descriptor, buffer, 0, bufferSize, 0);
        fs.closeSync(descriptor);
        return buffer;
    }
    /**
     * @params input - buffer or relative/absolute path of the image file
     * @params callback - optional function for async detection
     */
    module.exports = function (input, callback) {
        // Handle buffer input
        if (Buffer.isBuffer(input)) {
            return lookup(input);
        }
        // input should be a string at this point
        if (typeof input !== 'string') {
            throw new TypeError('invalid invocation');
        }
        // resolve the file path
        var filepath = path.resolve(input);
        if (typeof callback === 'function') {
            asyncFileToBuffer(filepath, function (err, buffer) {
                if (err) {
                    return callback(err);
                }
                // return the dimensions
                var dimensions;
                try {
                    dimensions = lookup(buffer, filepath);
                }
                catch (e) {
                    err = e;
                }
                callback(err, dimensions);
            });
        }
        else {
            var buffer = syncFileToBuffer(filepath);
            return lookup(buffer, filepath);
        }
    };
    module.exports.types = types;
},
/* image-size/lib/detector.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var typeMap = {};
    var types = require(201) /* ./types */;
    // load all available handlers
    types.forEach(function (type) {
        typeMap[type] = require('./types/' + type).detect;
    });
    module.exports = function (buffer, filepath) {
        var type, result;
        for (type in typeMap) {
            result = typeMap[type](buffer, filepath);
            if (result) {
                return type;
            }
        }
    };
},
/* image-size/lib/types.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = [
        'bmp',
        'gif',
        'jpg',
        'png',
        'psd',
        'svg',
        'tiff',
        'webp',
        'dds'
    ];
},
/* css/index.js */ function _(require, module, exports, __esModule, __esExport) {
    exports.parse = require(203) /* ./lib/parse */;
    exports.stringify = require(204) /* ./lib/stringify */;
},
/* css/lib/parse/index.js */ function _(require, module, exports, __esModule, __esExport) {
    // http://www.w3.org/TR/CSS21/grammar.html
    // https://github.com/visionmedia/css-parse/pull/49#issuecomment-30088027
    var commentre = /\/\*[^*]*\*+([^/*][^*]*\*+)*\//g;
    module.exports = function (css, options) {
        options = options || {};
        /**
         * Positional.
         */
        var lineno = 1;
        var column = 1;
        /**
         * Update lineno and column based on `str`.
         */
        function updatePosition(str) {
            var lines = str.match(/\n/g);
            if (lines)
                lineno += lines.length;
            var i = str.lastIndexOf('\n');
            column = ~i ? str.length - i : column + str.length;
        }
        /**
         * Mark position and patch `node.position`.
         */
        function position() {
            var start = { line: lineno, column: column };
            return function (node) {
                node.position = new Position(start);
                whitespace();
                return node;
            };
        }
        /**
         * Store position information for a node
         */
        function Position(start) {
            this.start = start;
            this.end = { line: lineno, column: column };
            this.source = options.source;
        }
        /**
         * Non-enumerable source string
         */
        Position.prototype.content = css;
        /**
         * Error `msg`.
         */
        var errorsList = [];
        function error(msg) {
            var err = new Error(options.source + ':' + lineno + ':' + column + ': ' + msg);
            err.reason = msg;
            err.filename = options.source;
            err.line = lineno;
            err.column = column;
            err.source = css;
            if (options.silent) {
                errorsList.push(err);
            }
            else {
                throw err;
            }
        }
        /**
         * Parse stylesheet.
         */
        function stylesheet() {
            var rulesList = rules();
            return {
                type: 'stylesheet',
                stylesheet: {
                    source: options.source,
                    rules: rulesList,
                    parsingErrors: errorsList
                }
            };
        }
        /**
         * Opening brace.
         */
        function open() {
            return match(/^{\s*/);
        }
        /**
         * Closing brace.
         */
        function close() {
            return match(/^}/);
        }
        /**
         * Parse ruleset.
         */
        function rules() {
            var node;
            var rules = [];
            whitespace();
            comments(rules);
            while (css.length && css.charAt(0) != '}' && (node = atrule() || rule())) {
                if (node !== false) {
                    rules.push(node);
                    comments(rules);
                }
            }
            return rules;
        }
        /**
         * Match `re` and return captures.
         */
        function match(re) {
            var m = re.exec(css);
            if (!m)
                return;
            var str = m[0];
            updatePosition(str);
            css = css.slice(str.length);
            return m;
        }
        /**
         * Parse whitespace.
         */
        function whitespace() {
            match(/^\s*/);
        }
        /**
         * Parse comments;
         */
        function comments(rules) {
            var c;
            rules = rules || [];
            while (c = comment()) {
                if (c !== false) {
                    rules.push(c);
                }
            }
            return rules;
        }
        /**
         * Parse comment.
         */
        function comment() {
            var pos = position();
            if ('/' != css.charAt(0) || '*' != css.charAt(1))
                return;
            var i = 2;
            while ("" != css.charAt(i) && ('*' != css.charAt(i) || '/' != css.charAt(i + 1)))
                ++i;
            i += 2;
            if ("" === css.charAt(i - 1)) {
                return error('End of comment missing');
            }
            var str = css.slice(2, i - 2);
            column += 2;
            updatePosition(str);
            css = css.slice(i);
            column += 2;
            return pos({
                type: 'comment',
                comment: str
            });
        }
        /**
         * Parse selector.
         */
        function selector() {
            var m = match(/^([^{]+)/);
            if (!m)
                return;
            /* @fix Remove all comments from selectors
             * http://ostermiller.org/findcomment.html */
            return trim(m[0])
                .replace(/\/\*([^*]|[\r\n]|(\*+([^*/]|[\r\n])))*\*\/+/g, '')
                .replace(/"(?:\\"|[^"])*"|'(?:\\'|[^'])*'/g, function (m) {
                return m.replace(/,/g, '\u200C');
            })
                .split(/\s*(?![^(]*\)),\s*/)
                .map(function (s) {
                return s.replace(/\u200C/g, ',');
            });
        }
        /**
         * Parse declaration.
         */
        function declaration() {
            var pos = position();
            // prop
            var prop = match(/^(\*?[-#\/\*\\\w]+(\[[0-9a-z_-]+\])?)\s*/);
            if (!prop)
                return;
            prop = trim(prop[0]);
            // :
            if (!match(/^:\s*/))
                return error("property missing ':'");
            // val
            var val = match(/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^\)]*?\)|[^};])+)/);
            var ret = pos({
                type: 'declaration',
                property: prop.replace(commentre, ''),
                value: val ? trim(val[0]).replace(commentre, '') : ''
            });
            // ;
            match(/^[;\s]*/);
            return ret;
        }
        /**
         * Parse declarations.
         */
        function declarations() {
            var decls = [];
            if (!open())
                return error("missing '{'");
            comments(decls);
            // declarations
            var decl;
            while (decl = declaration()) {
                if (decl !== false) {
                    decls.push(decl);
                    comments(decls);
                }
            }
            if (!close())
                return error("missing '}'");
            return decls;
        }
        /**
         * Parse keyframe.
         */
        function keyframe() {
            var m;
            var vals = [];
            var pos = position();
            while (m = match(/^((\d+\.\d+|\.\d+|\d+)%?|[a-z]+)\s*/)) {
                vals.push(m[1]);
                match(/^,\s*/);
            }
            if (!vals.length)
                return;
            return pos({
                type: 'keyframe',
                values: vals,
                declarations: declarations()
            });
        }
        /**
         * Parse keyframes.
         */
        function atkeyframes() {
            var pos = position();
            var m = match(/^@([-\w]+)?keyframes\s*/);
            if (!m)
                return;
            var vendor = m[1];
            // identifier
            var m = match(/^([-\w]+)\s*/);
            if (!m)
                return error("@keyframes missing name");
            var name = m[1];
            if (!open())
                return error("@keyframes missing '{'");
            var frame;
            var frames = comments();
            while (frame = keyframe()) {
                frames.push(frame);
                frames = frames.concat(comments());
            }
            if (!close())
                return error("@keyframes missing '}'");
            return pos({
                type: 'keyframes',
                name: name,
                vendor: vendor,
                keyframes: frames
            });
        }
        /**
         * Parse supports.
         */
        function atsupports() {
            var pos = position();
            var m = match(/^@supports *([^{]+)/);
            if (!m)
                return;
            var supports = trim(m[1]);
            if (!open())
                return error("@supports missing '{'");
            var style = comments().concat(rules());
            if (!close())
                return error("@supports missing '}'");
            return pos({
                type: 'supports',
                supports: supports,
                rules: style
            });
        }
        /**
         * Parse host.
         */
        function athost() {
            var pos = position();
            var m = match(/^@host\s*/);
            if (!m)
                return;
            if (!open())
                return error("@host missing '{'");
            var style = comments().concat(rules());
            if (!close())
                return error("@host missing '}'");
            return pos({
                type: 'host',
                rules: style
            });
        }
        /**
         * Parse media.
         */
        function atmedia() {
            var pos = position();
            var m = match(/^@media *([^{]+)/);
            if (!m)
                return;
            var media = trim(m[1]);
            if (!open())
                return error("@media missing '{'");
            var style = comments().concat(rules());
            if (!close())
                return error("@media missing '}'");
            return pos({
                type: 'media',
                media: media,
                rules: style
            });
        }
        /**
         * Parse custom-media.
         */
        function atcustommedia() {
            var pos = position();
            var m = match(/^@custom-media\s+(--[^\s]+)\s*([^{;]+);/);
            if (!m)
                return;
            return pos({
                type: 'custom-media',
                name: trim(m[1]),
                media: trim(m[2])
            });
        }
        /**
         * Parse paged media.
         */
        function atpage() {
            var pos = position();
            var m = match(/^@page */);
            if (!m)
                return;
            var sel = selector() || [];
            if (!open())
                return error("@page missing '{'");
            var decls = comments();
            // declarations
            var decl;
            while (decl = declaration()) {
                decls.push(decl);
                decls = decls.concat(comments());
            }
            if (!close())
                return error("@page missing '}'");
            return pos({
                type: 'page',
                selectors: sel,
                declarations: decls
            });
        }
        /**
         * Parse document.
         */
        function atdocument() {
            var pos = position();
            var m = match(/^@([-\w]+)?document *([^{]+)/);
            if (!m)
                return;
            var vendor = trim(m[1]);
            var doc = trim(m[2]);
            if (!open())
                return error("@document missing '{'");
            var style = comments().concat(rules());
            if (!close())
                return error("@document missing '}'");
            return pos({
                type: 'document',
                document: doc,
                vendor: vendor,
                rules: style
            });
        }
        /**
         * Parse font-face.
         */
        function atfontface() {
            var pos = position();
            var m = match(/^@font-face\s*/);
            if (!m)
                return;
            if (!open())
                return error("@font-face missing '{'");
            var decls = comments();
            // declarations
            var decl;
            while (decl = declaration()) {
                decls.push(decl);
                decls = decls.concat(comments());
            }
            if (!close())
                return error("@font-face missing '}'");
            return pos({
                type: 'font-face',
                declarations: decls
            });
        }
        /**
         * Parse import
         */
        var atimport = _compileAtrule('import');
        /**
         * Parse charset
         */
        var atcharset = _compileAtrule('charset');
        /**
         * Parse namespace
         */
        var atnamespace = _compileAtrule('namespace');
        /**
         * Parse non-block at-rules
         */
        function _compileAtrule(name) {
            var re = new RegExp('^@' + name + '\\s*([^;]+);');
            return function () {
                var pos = position();
                var m = match(re);
                if (!m)
                    return;
                var ret = { type: name };
                ret[name] = m[1].trim();
                return pos(ret);
            };
        }
        /**
         * Parse at rule.
         */
        function atrule() {
            if (css[0] != '@')
                return;
            return atkeyframes()
                || atmedia()
                || atcustommedia()
                || atsupports()
                || atimport()
                || atcharset()
                || atnamespace()
                || atdocument()
                || atpage()
                || athost()
                || atfontface();
        }
        /**
         * Parse rule.
         */
        function rule() {
            var pos = position();
            var sel = selector();
            if (!sel)
                return error('selector missing');
            comments();
            return pos({
                type: 'rule',
                selectors: sel,
                declarations: declarations()
            });
        }
        return addParent(stylesheet());
    };
    /**
     * Trim `str`.
     */
    function trim(str) {
        return str ? str.replace(/^\s+|\s+$/g, '') : '';
    }
    /**
     * Adds non-enumerable parent node reference to each node.
     */
    function addParent(obj, parent) {
        var isNode = obj && typeof obj.type === 'string';
        var childParent = isNode ? obj : parent;
        for (var k in obj) {
            var value = obj[k];
            if (Array.isArray(value)) {
                value.forEach(function (v) { addParent(v, childParent); });
            }
            else if (value && typeof value === 'object') {
                addParent(value, childParent);
            }
        }
        if (isNode) {
            Object.defineProperty(obj, 'parent', {
                configurable: true,
                writable: true,
                enumerable: false,
                value: parent || null
            });
        }
        return obj;
    }
},
/* css/lib/stringify/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Module dependencies.
     */
    var Compressed = require(205) /* ./compress */;
    var Identity = require(209) /* ./identity */;
    /**
     * Stringfy the given AST `node`.
     *
     * Options:
     *
     *  - `compress` space-optimized output
     *  - `sourcemap` return an object with `.code` and `.map`
     *
     * @param {Object} node
     * @param {Object} [options]
     * @return {String}
     * @api public
     */
    module.exports = function (node, options) {
        options = options || {};
        var compiler = options.compress
            ? new Compressed(options)
            : new Identity(options);
        // source maps
        if (options.sourcemap) {
            var sourcemaps = require(210) /* ./source-map-support */;
            sourcemaps(compiler);
            var code = compiler.compile(node);
            compiler.applySourceMaps();
            var map = options.sourcemap === 'generator'
                ? compiler.map
                : compiler.map.toJSON();
            return { code: code, map: map };
        }
        var code = compiler.compile(node);
        return code;
    };
},
/* css/lib/stringify/compress.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Module dependencies.
     */
    var Base = require(206) /* ./compiler */;
    var inherits = require(207) /* inherits */;
    /**
     * Expose compiler.
     */
    module.exports = Compiler;
    /**
     * Initialize a new `Compiler`.
     */
    function Compiler(options) {
        Base.call(this, options);
    }
    /**
     * Inherit from `Base.prototype`.
     */
    inherits(Compiler, Base);
    /**
     * Compile `node`.
     */
    Compiler.prototype.compile = function (node) {
        return node.stylesheet
            .rules.map(this.visit, this)
            .join('');
    };
    /**
     * Visit comment node.
     */
    Compiler.prototype.comment = function (node) {
        return this.emit('', node.position);
    };
    /**
     * Visit import node.
     */
    Compiler.prototype.import = function (node) {
        return this.emit('@import ' + node.import + ';', node.position);
    };
    /**
     * Visit media node.
     */
    Compiler.prototype.media = function (node) {
        return this.emit('@media ' + node.media, node.position)
            + this.emit('{')
            + this.mapVisit(node.rules)
            + this.emit('}');
    };
    /**
     * Visit document node.
     */
    Compiler.prototype.document = function (node) {
        var doc = '@' + (node.vendor || '') + 'document ' + node.document;
        return this.emit(doc, node.position)
            + this.emit('{')
            + this.mapVisit(node.rules)
            + this.emit('}');
    };
    /**
     * Visit charset node.
     */
    Compiler.prototype.charset = function (node) {
        return this.emit('@charset ' + node.charset + ';', node.position);
    };
    /**
     * Visit namespace node.
     */
    Compiler.prototype.namespace = function (node) {
        return this.emit('@namespace ' + node.namespace + ';', node.position);
    };
    /**
     * Visit supports node.
     */
    Compiler.prototype.supports = function (node) {
        return this.emit('@supports ' + node.supports, node.position)
            + this.emit('{')
            + this.mapVisit(node.rules)
            + this.emit('}');
    };
    /**
     * Visit keyframes node.
     */
    Compiler.prototype.keyframes = function (node) {
        return this.emit('@'
            + (node.vendor || '')
            + 'keyframes '
            + node.name, node.position)
            + this.emit('{')
            + this.mapVisit(node.keyframes)
            + this.emit('}');
    };
    /**
     * Visit keyframe node.
     */
    Compiler.prototype.keyframe = function (node) {
        var decls = node.declarations;
        return this.emit(node.values.join(','), node.position)
            + this.emit('{')
            + this.mapVisit(decls)
            + this.emit('}');
    };
    /**
     * Visit page node.
     */
    Compiler.prototype.page = function (node) {
        var sel = node.selectors.length
            ? node.selectors.join(', ')
            : '';
        return this.emit('@page ' + sel, node.position)
            + this.emit('{')
            + this.mapVisit(node.declarations)
            + this.emit('}');
    };
    /**
     * Visit font-face node.
     */
    Compiler.prototype['font-face'] = function (node) {
        return this.emit('@font-face', node.position)
            + this.emit('{')
            + this.mapVisit(node.declarations)
            + this.emit('}');
    };
    /**
     * Visit host node.
     */
    Compiler.prototype.host = function (node) {
        return this.emit('@host', node.position)
            + this.emit('{')
            + this.mapVisit(node.rules)
            + this.emit('}');
    };
    /**
     * Visit custom-media node.
     */
    Compiler.prototype['custom-media'] = function (node) {
        return this.emit('@custom-media ' + node.name + ' ' + node.media + ';', node.position);
    };
    /**
     * Visit rule node.
     */
    Compiler.prototype.rule = function (node) {
        var decls = node.declarations;
        if (!decls.length)
            return '';
        return this.emit(node.selectors.join(','), node.position)
            + this.emit('{')
            + this.mapVisit(decls)
            + this.emit('}');
    };
    /**
     * Visit declaration node.
     */
    Compiler.prototype.declaration = function (node) {
        return this.emit(node.property + ':' + node.value, node.position) + this.emit(';');
    };
},
/* css/lib/stringify/compiler.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Expose `Compiler`.
     */
    module.exports = Compiler;
    /**
     * Initialize a compiler.
     *
     * @param {Type} name
     * @return {Type}
     * @api public
     */
    function Compiler(opts) {
        this.options = opts || {};
    }
    /**
     * Emit `str`
     */
    Compiler.prototype.emit = function (str) {
        return str;
    };
    /**
     * Visit `node`.
     */
    Compiler.prototype.visit = function (node) {
        return this[node.type](node);
    };
    /**
     * Map visit over array of `nodes`, optionally using a `delim`
     */
    Compiler.prototype.mapVisit = function (nodes, delim) {
        var buf = '';
        delim = delim || '';
        for (var i = 0, length = nodes.length; i < length; i++) {
            buf += this.visit(nodes[i]);
            if (delim && i < length - 1)
                buf += this.emit(delim);
        }
        return buf;
    };
},
/* inherits/inherits.js */ function _(require, module, exports, __esModule, __esExport) {
    try {
        var util = require('util');
        /* istanbul ignore next */
        if (typeof util.inherits !== 'function')
            throw '';
        module.exports = util.inherits;
    }
    catch (e) {
        /* istanbul ignore next */
        module.exports = require(208) /* ./inherits_browser.js */;
    }
},
/* inherits/inherits_browser.js */ function _(require, module, exports, __esModule, __esExport) {
    if (typeof Object.create === 'function') {
        // implementation from standard node.js 'util' module
        module.exports = function inherits(ctor, superCtor) {
            if (superCtor) {
                ctor.super_ = superCtor;
                ctor.prototype = Object.create(superCtor.prototype, {
                    constructor: {
                        value: ctor,
                        enumerable: false,
                        writable: true,
                        configurable: true
                    }
                });
            }
        };
    }
    else {
        // old school shim for old browsers
        module.exports = function inherits(ctor, superCtor) {
            if (superCtor) {
                ctor.super_ = superCtor;
                var TempCtor = function () { };
                TempCtor.prototype = superCtor.prototype;
                ctor.prototype = new TempCtor();
                ctor.prototype.constructor = ctor;
            }
        };
    }
},
/* css/lib/stringify/identity.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Module dependencies.
     */
    var Base = require(206) /* ./compiler */;
    var inherits = require(207) /* inherits */;
    /**
     * Expose compiler.
     */
    module.exports = Compiler;
    /**
     * Initialize a new `Compiler`.
     */
    function Compiler(options) {
        options = options || {};
        Base.call(this, options);
        this.indentation = options.indent;
    }
    /**
     * Inherit from `Base.prototype`.
     */
    inherits(Compiler, Base);
    /**
     * Compile `node`.
     */
    Compiler.prototype.compile = function (node) {
        return this.stylesheet(node);
    };
    /**
     * Visit stylesheet node.
     */
    Compiler.prototype.stylesheet = function (node) {
        return this.mapVisit(node.stylesheet.rules, '\n\n');
    };
    /**
     * Visit comment node.
     */
    Compiler.prototype.comment = function (node) {
        return this.emit(this.indent() + '/*' + node.comment + '*/', node.position);
    };
    /**
     * Visit import node.
     */
    Compiler.prototype.import = function (node) {
        return this.emit('@import ' + node.import + ';', node.position);
    };
    /**
     * Visit media node.
     */
    Compiler.prototype.media = function (node) {
        return this.emit('@media ' + node.media, node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(node.rules, '\n\n')
            + this.emit(this.indent(-1)
                + '\n}');
    };
    /**
     * Visit document node.
     */
    Compiler.prototype.document = function (node) {
        var doc = '@' + (node.vendor || '') + 'document ' + node.document;
        return this.emit(doc, node.position)
            + this.emit(' '
                + ' {\n'
                + this.indent(1))
            + this.mapVisit(node.rules, '\n\n')
            + this.emit(this.indent(-1)
                + '\n}');
    };
    /**
     * Visit charset node.
     */
    Compiler.prototype.charset = function (node) {
        return this.emit('@charset ' + node.charset + ';', node.position);
    };
    /**
     * Visit namespace node.
     */
    Compiler.prototype.namespace = function (node) {
        return this.emit('@namespace ' + node.namespace + ';', node.position);
    };
    /**
     * Visit supports node.
     */
    Compiler.prototype.supports = function (node) {
        return this.emit('@supports ' + node.supports, node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(node.rules, '\n\n')
            + this.emit(this.indent(-1)
                + '\n}');
    };
    /**
     * Visit keyframes node.
     */
    Compiler.prototype.keyframes = function (node) {
        return this.emit('@' + (node.vendor || '') + 'keyframes ' + node.name, node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(node.keyframes, '\n')
            + this.emit(this.indent(-1)
                + '}');
    };
    /**
     * Visit keyframe node.
     */
    Compiler.prototype.keyframe = function (node) {
        var decls = node.declarations;
        return this.emit(this.indent())
            + this.emit(node.values.join(', '), node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(decls, '\n')
            + this.emit(this.indent(-1)
                + '\n'
                + this.indent() + '}\n');
    };
    /**
     * Visit page node.
     */
    Compiler.prototype.page = function (node) {
        var sel = node.selectors.length
            ? node.selectors.join(', ') + ' '
            : '';
        return this.emit('@page ' + sel, node.position)
            + this.emit('{\n')
            + this.emit(this.indent(1))
            + this.mapVisit(node.declarations, '\n')
            + this.emit(this.indent(-1))
            + this.emit('\n}');
    };
    /**
     * Visit font-face node.
     */
    Compiler.prototype['font-face'] = function (node) {
        return this.emit('@font-face ', node.position)
            + this.emit('{\n')
            + this.emit(this.indent(1))
            + this.mapVisit(node.declarations, '\n')
            + this.emit(this.indent(-1))
            + this.emit('\n}');
    };
    /**
     * Visit host node.
     */
    Compiler.prototype.host = function (node) {
        return this.emit('@host', node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(node.rules, '\n\n')
            + this.emit(this.indent(-1)
                + '\n}');
    };
    /**
     * Visit custom-media node.
     */
    Compiler.prototype['custom-media'] = function (node) {
        return this.emit('@custom-media ' + node.name + ' ' + node.media + ';', node.position);
    };
    /**
     * Visit rule node.
     */
    Compiler.prototype.rule = function (node) {
        var indent = this.indent();
        var decls = node.declarations;
        if (!decls.length)
            return '';
        return this.emit(node.selectors.map(function (s) { return indent + s; }).join(',\n'), node.position)
            + this.emit(' {\n')
            + this.emit(this.indent(1))
            + this.mapVisit(decls, '\n')
            + this.emit(this.indent(-1))
            + this.emit('\n' + this.indent() + '}');
    };
    /**
     * Visit declaration node.
     */
    Compiler.prototype.declaration = function (node) {
        return this.emit(this.indent())
            + this.emit(node.property + ': ' + node.value, node.position)
            + this.emit(';');
    };
    /**
     * Increase, decrease or return current indentation.
     */
    Compiler.prototype.indent = function (level) {
        this.level = this.level || 1;
        if (null != level) {
            this.level += level;
            return '';
        }
        return Array(this.level).join(this.indentation || '  ');
    };
},
/* css/lib/stringify/source-map-support.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Module dependencies.
     */
    var SourceMap = require(23) /* source-map */.SourceMapGenerator;
    var SourceMapConsumer = require(23) /* source-map */.SourceMapConsumer;
    var sourceMapResolve = require(211) /* source-map-resolve */;
    var fs = require('fs');
    var path = require('path');
    /**
     * Expose `mixin()`.
     */
    module.exports = mixin;
    /**
     * Ensure Windows-style paths are formatted properly
     */
    const makeFriendlyPath = function (aPath) {
        return path.sep === "\\" ? aPath.replace(/\\/g, "/").replace(/^[a-z]:\/?/i, "/") : aPath;
    };
    /**
     * Mixin source map support into `compiler`.
     *
     * @param {Compiler} compiler
     * @api public
     */
    function mixin(compiler) {
        compiler._comment = compiler.comment;
        compiler.map = new SourceMap();
        compiler.position = { line: 1, column: 1 };
        compiler.files = {};
        for (var k in exports)
            compiler[k] = exports[k];
    }
    /**
     * Update position.
     *
     * @param {String} str
     * @api private
     */
    exports.updatePosition = function (str) {
        var lines = str.match(/\n/g);
        if (lines)
            this.position.line += lines.length;
        var i = str.lastIndexOf('\n');
        this.position.column = ~i ? str.length - i : this.position.column + str.length;
    };
    /**
     * Emit `str`.
     *
     * @param {String} str
     * @param {Object} [pos]
     * @return {String}
     * @api private
     */
    exports.emit = function (str, pos) {
        if (pos) {
            var sourceFile = makeFriendlyPath(pos.source || 'source.css');
            this.map.addMapping({
                source: sourceFile,
                generated: {
                    line: this.position.line,
                    column: Math.max(this.position.column - 1, 0)
                },
                original: {
                    line: pos.start.line,
                    column: pos.start.column - 1
                }
            });
            this.addFile(sourceFile, pos);
        }
        this.updatePosition(str);
        return str;
    };
    /**
     * Adds a file to the source map output if it has not already been added
     * @param {String} file
     * @param {Object} pos
     */
    exports.addFile = function (file, pos) {
        if (typeof pos.content !== 'string')
            return;
        if (Object.prototype.hasOwnProperty.call(this.files, file))
            return;
        this.files[file] = pos.content;
    };
    /**
     * Applies any original source maps to the output and embeds the source file
     * contents in the source map.
     */
    exports.applySourceMaps = function () {
        Object.keys(this.files).forEach(function (file) {
            var content = this.files[file];
            this.map.setSourceContent(file, content);
            if (this.options.inputSourcemaps !== false) {
                var originalMap = sourceMapResolve.resolveSync(content, file, fs.readFileSync);
                if (originalMap) {
                    var map = new SourceMapConsumer(originalMap.map);
                    var relativeTo = originalMap.sourcesRelativeTo;
                    this.map.applySourceMap(map, file, makeFriendlyPath(path.dirname(relativeTo)));
                }
            }
        }, this);
    };
    /**
     * Process comments, drops sourceMap comments.
     * @param {Object} node
     */
    exports.comment = function (node) {
        if (/^# sourceMappingURL=/.test(node.comment))
            return this.emit('', node.position);
        else
            return this._comment(node);
    };
},
/* source-map-resolve/index.js */ function _(require, module, exports, __esModule, __esExport) {
    var atob = require(212) /* atob */;
    var urlLib = require("url");
    var pathLib = require("path");
    var decodeUriComponentLib = require(213) /* decode-uri-component */;
    function resolveUrl( /* ...urls */) {
        return Array.prototype.reduce.call(arguments, function (resolved, nextUrl) {
            return urlLib.resolve(resolved, nextUrl);
        });
    }
    function convertWindowsPath(aPath) {
        return pathLib.sep === "\\" ? aPath.replace(/\\/g, "/").replace(/^[a-z]:\/?/i, "/") : aPath;
    }
    function customDecodeUriComponent(string) {
        // `decodeUriComponentLib` turns `+` into ` `, but that's not wanted.
        return decodeUriComponentLib(string.replace(/\+/g, "%2B"));
    }
    function callbackAsync(callback, error, result) {
        setImmediate(function () { callback(error, result); });
    }
    function parseMapToJSON(string, data) {
        try {
            return JSON.parse(string.replace(/^\)\]\}'/, ""));
        }
        catch (error) {
            error.sourceMapData = data;
            throw error;
        }
    }
    function readSync(read, url, data) {
        var readUrl = customDecodeUriComponent(url);
        try {
            return String(read(readUrl));
        }
        catch (error) {
            error.sourceMapData = data;
            throw error;
        }
    }
    var innerRegex = /[#@] sourceMappingURL=([^\s'"]*)/;
    var sourceMappingURLRegex = RegExp("(?:" +
        "/\\*" +
        "(?:\\s*\r?\n(?://)?)?" +
        "(?:" + innerRegex.source + ")" +
        "\\s*" +
        "\\*/" +
        "|" +
        "//(?:" + innerRegex.source + ")" +
        ")" +
        "\\s*");
    function getSourceMappingUrl(code) {
        var match = code.match(sourceMappingURLRegex);
        return match ? match[1] || match[2] || "" : null;
    }
    function resolveSourceMap(code, codeUrl, read, callback) {
        var mapData;
        try {
            mapData = resolveSourceMapHelper(code, codeUrl);
        }
        catch (error) {
            return callbackAsync(callback, error);
        }
        if (!mapData || mapData.map) {
            return callbackAsync(callback, null, mapData);
        }
        var readUrl = customDecodeUriComponent(mapData.url);
        read(readUrl, function (error, result) {
            if (error) {
                error.sourceMapData = mapData;
                return callback(error);
            }
            mapData.map = String(result);
            try {
                mapData.map = parseMapToJSON(mapData.map, mapData);
            }
            catch (error) {
                return callback(error);
            }
            callback(null, mapData);
        });
    }
    function resolveSourceMapSync(code, codeUrl, read) {
        var mapData = resolveSourceMapHelper(code, codeUrl);
        if (!mapData || mapData.map) {
            return mapData;
        }
        mapData.map = readSync(read, mapData.url, mapData);
        mapData.map = parseMapToJSON(mapData.map, mapData);
        return mapData;
    }
    var dataUriRegex = /^data:([^,;]*)(;[^,;]*)*(?:,(.*))?$/;
    /**
     * The media type for JSON text is application/json.
     *
     * {@link https://tools.ietf.org/html/rfc8259#section-11 | IANA Considerations }
     *
     * `text/json` is non-standard media type
     */
    var jsonMimeTypeRegex = /^(?:application|text)\/json$/;
    /**
     * JSON text exchanged between systems that are not part of a closed ecosystem
     * MUST be encoded using UTF-8.
     *
     * {@link https://tools.ietf.org/html/rfc8259#section-8.1 | Character Encoding}
     */
    var jsonCharacterEncoding = "utf-8";
    function base64ToBuf(b64) {
        var binStr = atob(b64);
        var len = binStr.length;
        var arr = new Uint8Array(len);
        for (var i = 0; i < len; i++) {
            arr[i] = binStr.charCodeAt(i);
        }
        return arr;
    }
    function decodeBase64String(b64) {
        if (typeof TextDecoder === "undefined" || typeof Uint8Array === "undefined") {
            return atob(b64);
        }
        var buf = base64ToBuf(b64);
        // Note: `decoder.decode` method will throw a `DOMException` with the
        // `"EncodingError"` value when an coding error is found.
        var decoder = new TextDecoder(jsonCharacterEncoding, { fatal: true });
        return decoder.decode(buf);
    }
    function resolveSourceMapHelper(code, codeUrl) {
        codeUrl = convertWindowsPath(codeUrl);
        var url = getSourceMappingUrl(code);
        if (!url) {
            return null;
        }
        var dataUri = url.match(dataUriRegex);
        if (dataUri) {
            var mimeType = dataUri[1] || "text/plain";
            var lastParameter = dataUri[2] || "";
            var encoded = dataUri[3] || "";
            var data = {
                sourceMappingURL: url,
                url: null,
                sourcesRelativeTo: codeUrl,
                map: encoded
            };
            if (!jsonMimeTypeRegex.test(mimeType)) {
                var error = new Error("Unuseful data uri mime type: " + mimeType);
                error.sourceMapData = data;
                throw error;
            }
            try {
                data.map = parseMapToJSON(lastParameter === ";base64" ? decodeBase64String(encoded) : decodeURIComponent(encoded), data);
            }
            catch (error) {
                error.sourceMapData = data;
                throw error;
            }
            return data;
        }
        var mapUrl = resolveUrl(codeUrl, url);
        return {
            sourceMappingURL: url,
            url: mapUrl,
            sourcesRelativeTo: mapUrl,
            map: null
        };
    }
    function resolveSources(map, mapUrl, read, options, callback) {
        if (typeof options === "function") {
            callback = options;
            options = {};
        }
        var pending = map.sources ? map.sources.length : 0;
        var result = {
            sourcesResolved: [],
            sourcesContent: []
        };
        if (pending === 0) {
            callbackAsync(callback, null, result);
            return;
        }
        var done = function () {
            pending--;
            if (pending === 0) {
                callback(null, result);
            }
        };
        resolveSourcesHelper(map, mapUrl, options, function (fullUrl, sourceContent, index) {
            result.sourcesResolved[index] = fullUrl;
            if (typeof sourceContent === "string") {
                result.sourcesContent[index] = sourceContent;
                callbackAsync(done, null);
            }
            else {
                var readUrl = customDecodeUriComponent(fullUrl);
                read(readUrl, function (error, source) {
                    result.sourcesContent[index] = error ? error : String(source);
                    done();
                });
            }
        });
    }
    function resolveSourcesSync(map, mapUrl, read, options) {
        var result = {
            sourcesResolved: [],
            sourcesContent: []
        };
        if (!map.sources || map.sources.length === 0) {
            return result;
        }
        resolveSourcesHelper(map, mapUrl, options, function (fullUrl, sourceContent, index) {
            result.sourcesResolved[index] = fullUrl;
            if (read !== null) {
                if (typeof sourceContent === "string") {
                    result.sourcesContent[index] = sourceContent;
                }
                else {
                    var readUrl = customDecodeUriComponent(fullUrl);
                    try {
                        result.sourcesContent[index] = String(read(readUrl));
                    }
                    catch (error) {
                        result.sourcesContent[index] = error;
                    }
                }
            }
        });
        return result;
    }
    var endingSlash = /\/?$/;
    function resolveSourcesHelper(map, mapUrl, options, fn) {
        options = options || {};
        mapUrl = convertWindowsPath(mapUrl);
        var fullUrl;
        var sourceContent;
        var sourceRoot;
        for (var index = 0, len = map.sources.length; index < len; index++) {
            sourceRoot = null;
            if (typeof options.sourceRoot === "string") {
                sourceRoot = options.sourceRoot;
            }
            else if (typeof map.sourceRoot === "string" && options.sourceRoot !== false) {
                sourceRoot = map.sourceRoot;
            }
            // If the sourceRoot is the empty string, it is equivalent to not setting
            // the property at all.
            if (sourceRoot === null || sourceRoot === '') {
                fullUrl = resolveUrl(mapUrl, map.sources[index]);
            }
            else {
                // Make sure that the sourceRoot ends with a slash, so that `/scripts/subdir` becomes
                // `/scripts/subdir/<source>`, not `/scripts/<source>`. Pointing to a file as source root
                // does not make sense.
                fullUrl = resolveUrl(mapUrl, sourceRoot.replace(endingSlash, "/"), map.sources[index]);
            }
            sourceContent = (map.sourcesContent || [])[index];
            fn(fullUrl, sourceContent, index);
        }
    }
    function resolve(code, codeUrl, read, options, callback) {
        if (typeof options === "function") {
            callback = options;
            options = {};
        }
        if (code === null) {
            var mapUrl = codeUrl;
            var data = {
                sourceMappingURL: null,
                url: mapUrl,
                sourcesRelativeTo: mapUrl,
                map: null
            };
            var readUrl = customDecodeUriComponent(mapUrl);
            read(readUrl, function (error, result) {
                if (error) {
                    error.sourceMapData = data;
                    return callback(error);
                }
                data.map = String(result);
                try {
                    data.map = parseMapToJSON(data.map, data);
                }
                catch (error) {
                    return callback(error);
                }
                _resolveSources(data);
            });
        }
        else {
            resolveSourceMap(code, codeUrl, read, function (error, mapData) {
                if (error) {
                    return callback(error);
                }
                if (!mapData) {
                    return callback(null, null);
                }
                _resolveSources(mapData);
            });
        }
        function _resolveSources(mapData) {
            resolveSources(mapData.map, mapData.sourcesRelativeTo, read, options, function (error, result) {
                if (error) {
                    return callback(error);
                }
                mapData.sourcesResolved = result.sourcesResolved;
                mapData.sourcesContent = result.sourcesContent;
                callback(null, mapData);
            });
        }
    }
    function resolveSync(code, codeUrl, read, options) {
        var mapData;
        if (code === null) {
            var mapUrl = codeUrl;
            mapData = {
                sourceMappingURL: null,
                url: mapUrl,
                sourcesRelativeTo: mapUrl,
                map: null
            };
            mapData.map = readSync(read, mapUrl, mapData);
            mapData.map = parseMapToJSON(mapData.map, mapData);
        }
        else {
            mapData = resolveSourceMapSync(code, codeUrl, read);
            if (!mapData) {
                return null;
            }
        }
        var result = resolveSourcesSync(mapData.map, mapData.sourcesRelativeTo, read, options);
        mapData.sourcesResolved = result.sourcesResolved;
        mapData.sourcesContent = result.sourcesContent;
        return mapData;
    }
    module.exports = {
        resolveSourceMap: resolveSourceMap,
        resolveSourceMapSync: resolveSourceMapSync,
        resolveSources: resolveSources,
        resolveSourcesSync: resolveSourcesSync,
        resolve: resolve,
        resolveSync: resolveSync,
        parseMapToJSON: parseMapToJSON
    };
},
/* atob/node-atob.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    function atob(str) {
        return Buffer.from(str, 'base64').toString('binary');
    }
    module.exports = atob.atob = atob;
},
/* decode-uri-component/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var token = '%[a-f0-9]{2}';
    var singleMatcher = new RegExp('(' + token + ')|([^%]+?)', 'gi');
    var multiMatcher = new RegExp('(' + token + ')+', 'gi');
    function decodeComponents(components, split) {
        try {
            // Try to decode the entire string first
            return [decodeURIComponent(components.join(''))];
        }
        catch (err) {
            // Do nothing
        }
        if (components.length === 1) {
            return components;
        }
        split = split || 1;
        // Split the array in 2 parts
        var left = components.slice(0, split);
        var right = components.slice(split);
        return Array.prototype.concat.call([], decodeComponents(left), decodeComponents(right));
    }
    function decode(input) {
        try {
            return decodeURIComponent(input);
        }
        catch (err) {
            var tokens = input.match(singleMatcher) || [];
            for (var i = 1; i < tokens.length; i++) {
                input = decodeComponents(tokens, i).join('');
                tokens = input.match(singleMatcher) || [];
            }
            return input;
        }
    }
    function customDecodeURIComponent(input) {
        // Keep track of all the replacements and prefill the map with the `BOM`
        var replaceMap = {
            '%FE%FF': '\uFFFD\uFFFD',
            '%FF%FE': '\uFFFD\uFFFD'
        };
        var match = multiMatcher.exec(input);
        while (match) {
            try {
                // Decode as big chunks as possible
                replaceMap[match[0]] = decodeURIComponent(match[0]);
            }
            catch (err) {
                var result = decode(match[0]);
                if (result !== match[0]) {
                    replaceMap[match[0]] = result;
                }
            }
            match = multiMatcher.exec(input);
        }
        // Add `%C2` at the end of the map to make sure it does not replace the combinator before everything else
        replaceMap['%C2'] = '\uFFFD';
        var entries = Object.keys(replaceMap);
        for (var i = 0; i < entries.length; i++) {
            // Replace all decoded components
            var key = entries[i];
            input = input.replace(new RegExp(key, 'g'), replaceMap[key]);
        }
        return input;
    }
    module.exports = function (encodedURI) {
        if (typeof encodedURI !== 'string') {
            throw new TypeError('Expected `encodedURI` to be of type `string`, got `' + typeof encodedURI + '`');
        }
        try {
            encodedURI = encodedURI.replace(/\+/g, ' ');
            // Try the built in decoder first
            return decodeURIComponent(encodedURI);
        }
        catch (err) {
            // Fallback to a more advanced decoder
            return customDecodeURIComponent(encodedURI);
        }
    };
},
/* prelude.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default_prelude = exports.plugin_prelude = exports.plugin_postlude = exports.postlude = exports.prelude = exports.plugin_postlude_esm = exports.plugin_prelude_esm = exports.postlude_esm = exports.prelude_esm = exports.comment = void 0;
    // TODO import license from "../../../LICENSE.txt"
    const license = `\
Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.

Neither the name of Anaconda nor the names of any contributors
may be used to endorse or promote products derived from this software
without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
THE POSSIBILITY OF SUCH DAMAGE.
`;
    function comment(text) {
        return `/*!${"\n"}${text.trim().split("\n").map((line) => ` * ${line}`).join("\n")}${"\n"} */`;
    }
    exports.comment = comment;
    function str(obj) {
        return JSON.stringify(obj);
    }
    const loader = `\
(function(modules, entry, aliases, externals) {
  if (aliases === undefined) aliases = {};
  if (externals === undefined) externals = {};

  const cache = {};

  const normalize = function(name) {
    if (typeof name === "number")
      return name;

    if (name === "bokehjs")
      return entry;

    if (!externals[name]) {
      const prefix = "@bokehjs/"
      if (name.slice(0, prefix.length) === prefix)
        name = name.slice(prefix.length)
    }

    const alias = aliases[name]
    if (alias != null)
      return alias;

    const trailing = name.length > 0 && name[name.lenght-1] === "/";
    const index = aliases[name + (trailing ? "" : "/") + "index"];
    if (index != null)
      return index;

    return name;
  }

  const require = function(name) {
    let mod = cache[name];
    if (!mod) {
      const id = normalize(name);

      mod = cache[id];
      if (!mod) {
        if (!modules[id]) {
          if (externals[id] === false || (externals[id] == true && parent_require)) {
            try {
              mod = {exports: externals[id] ? parent_require(id) : {}};
              cache[id] = cache[name] = mod;
              return mod.exports;
            } catch (e) {}
          }

          const err = new Error("Cannot find module '" + name + "'");
          err.code = 'MODULE_NOT_FOUND';
          throw err;
        }

        mod = {exports: {}};
        cache[id] = cache[name] = mod;

        function __esModule() {
          Object.defineProperty(mod.exports, "__esModule", {value: true});
        }

        function __esExport(name, value) {
          Object.defineProperty(mod.exports, name, {
            enumerable: true, get: function () { return value; }
          });
        }

        modules[id].call(mod.exports, require, mod, mod.exports, __esModule, __esExport);
      } else {
        cache[name] = mod;
      }
    }

    return mod.exports;
  }
  require.resolve = function(name) {
    return ""
  }

  const main = require(entry);
  main.require = require;

  if (typeof Proxy !== "undefined") {
    // allow Bokeh.loader["@bokehjs/module/name"] syntax
    main.loader = new Proxy({}, {
      get: function(_obj, module) {
        return require(module);
      }
    });
  }

  main.register_plugin = function(plugin_modules, plugin_entry, plugin_aliases, plugin_externals) {
    if (plugin_aliases === undefined) plugin_aliases = {};
    if (plugin_externals === undefined) plugin_externals = {};

    for (let name in plugin_modules) {
      modules[name] = plugin_modules[name];
    }

    for (let name in plugin_aliases) {
      aliases[name] = plugin_aliases[name];
    }

    for (let name in plugin_externals) {
      externals[name] = plugin_externals[name];
    }

    const plugin = require(plugin_entry);

    for (let name in plugin) {
      main[name] = plugin[name];
    }

    return plugin;
  }

  return main;
})
`;
    function prelude_esm() {
        return `\
${comment(license)}
const main = ${loader}\
`;
    }
    exports.prelude_esm = prelude_esm;
    function postlude_esm() {
        return "export default main;";
    }
    exports.postlude_esm = postlude_esm;
    function plugin_prelude_esm() {
        return `\
${comment(license)}
import main from "./bokeh.esm.js";

const plugin = (function(modules, entry, aliases, externals) {
  main.register_plugin(modules, entry, aliases);
})\
`;
    }
    exports.plugin_prelude_esm = plugin_prelude_esm;
    function plugin_postlude_esm() {
        return "export default plugin;";
    }
    exports.plugin_postlude_esm = plugin_postlude_esm;
    function prelude() {
        return `\
${comment(license)}
(function(root, factory) {
  const bokeh = factory();
  bokeh.__bokeh__ = true;
  if (typeof root.Bokeh === "undefined" || typeof root.Bokeh.__bokeh__ === "undefined") {
    root.Bokeh = bokeh;
  }
  const Bokeh = root.Bokeh;
  Bokeh[bokeh.version] = bokeh;
})(this, function() {
  let define;
  const parent_require = typeof require === "function" && require
  return ${loader}\
`;
    }
    exports.prelude = prelude;
    function postlude() {
        return "});";
    }
    exports.postlude = postlude;
    function plugin_postlude() {
        return "});";
    }
    exports.plugin_postlude = plugin_postlude;
    function plugin_prelude(options) {
        return `\
${comment(license)}
(function(root, factory) {
  factory(root["Bokeh"], ${str(options?.version)});
})(this, function(Bokeh, version) {
  let define;
  return (function(modules, entry, aliases, externals) {
    const bokeh = typeof Bokeh !== "undefined" && (version != null ? Bokeh[version] : Bokeh);
    if (bokeh != null) {
      return bokeh.register_plugin(modules, entry, aliases);
    } else {
      throw new Error("Cannot find Bokeh " + version + ". You have to load it prior to loading plugins.");
    }
  })
`;
    }
    exports.plugin_prelude = plugin_prelude;
    function default_prelude(options) {
        return `\
(function(root, factory) {
  ${options?.global != null ? `root[${str(options.global)}] = factory()` : "Object.assign(root, factory())"};
})(this, function() {
  const parent_require = typeof require === "function" && require
  return ${loader}
`;
    }
    exports.default_prelude = default_prelude;
    
},
/* tsconfig.ext.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "compilerOptions": {
            "noImplicitAny": true,
            "noImplicitThis": true,
            "noImplicitReturns": true,
            "noUnusedLocals": true,
            "noUnusedParameters": true,
            "noImplicitOverride": false,
            "strictNullChecks": true,
            "strictBindCallApply": true,
            "strictFunctionTypes": true,
            "strictPropertyInitialization": false,
            "useUnknownInCatchVariables": true,
            "alwaysStrict": true,
            "noErrorTruncation": true,
            "noEmitOnError": false,
            "allowJs": true,
            "declaration": true,
            "sourceMap": true,
            "declarationMap": true,
            "importHelpers": false,
            "experimentalDecorators": true,
            "module": "ES2022",
            "moduleResolution": "node",
            "isolatedModules": true,
            "verbatimModuleSyntax": false,
            "resolveJsonModule": true,
            "skipLibCheck": true,
            "esModuleInterop": true,
            "target": "ES2022",
            "lib": ["es2022", "dom", "dom.iterable"],
            "baseUrl": ".",
            "outDir": "./dist/lib"
        },
        "include": ["./**/*.ts"]
    };
    module.exports = json;
},
/* eslint/lib/api.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Expose out ESLint and CLI to require.
     * @author Ian Christian Myers
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Requirements
    //-----------------------------------------------------------------------------
    const { ESLint } = require(217) /* ./eslint */;
    const { Linter } = require(289) /* ./linter */;
    const { RuleTester } = require(763) /* ./rule-tester */;
    const { SourceCode } = require(314) /* ./source-code */;
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    module.exports = {
        Linter,
        ESLint,
        RuleTester,
        SourceCode
    };
},
/* eslint/lib/eslint/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const { ESLint } = require(218) /* ./eslint */;
    const { FlatESLint } = require(727) /* ./flat-eslint */;
    module.exports = {
        ESLint,
        FlatESLint
    };
},
/* eslint/lib/eslint/eslint.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Main API Class
     * @author Kai Cataldo
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const path = require("path");
    const fs = require("fs");
    const { promisify } = require("util");
    const { CLIEngine, getCLIEngineInternalSlots } = require(219) /* ../cli-engine/cli-engine */;
    const BuiltinRules = require(357) /* ../rules */;
    const { Legacy: { ConfigOps: { getRuleSeverity } } } = require(222) /* @eslint/eslintrc */;
    const { version } = require(221) /* ../../package.json */;
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /** @typedef {import("../cli-engine/cli-engine").LintReport} CLIEngineLintReport */
    /** @typedef {import("../shared/types").DeprecatedRuleInfo} DeprecatedRuleInfo */
    /** @typedef {import("../shared/types").ConfigData} ConfigData */
    /** @typedef {import("../shared/types").LintMessage} LintMessage */
    /** @typedef {import("../shared/types").SuppressedLintMessage} SuppressedLintMessage */
    /** @typedef {import("../shared/types").Plugin} Plugin */
    /** @typedef {import("../shared/types").Rule} Rule */
    /** @typedef {import("../shared/types").LintResult} LintResult */
    /** @typedef {import("../shared/types").ResultsMeta} ResultsMeta */
    /**
     * The main formatter object.
     * @typedef LoadedFormatter
     * @property {(results: LintResult[], resultsMeta: ResultsMeta) => string | Promise<string>} format format function.
     */
    /**
     * The options with which to configure the ESLint instance.
     * @typedef {Object} ESLintOptions
     * @property {boolean} [allowInlineConfig] Enable or disable inline configuration comments.
     * @property {ConfigData} [baseConfig] Base config object, extended by all configs used with this instance
     * @property {boolean} [cache] Enable result caching.
     * @property {string} [cacheLocation] The cache file to use instead of .eslintcache.
     * @property {"metadata" | "content"} [cacheStrategy] The strategy used to detect changed files.
     * @property {string} [cwd] The value to use for the current working directory.
     * @property {boolean} [errorOnUnmatchedPattern] If `false` then `ESLint#lintFiles()` doesn't throw even if no target files found. Defaults to `true`.
     * @property {string[]} [extensions] An array of file extensions to check.
     * @property {boolean|Function} [fix] Execute in autofix mode. If a function, should return a boolean.
     * @property {string[]} [fixTypes] Array of rule types to apply fixes for.
     * @property {boolean} [globInputPaths] Set to false to skip glob resolution of input file paths to lint (default: true). If false, each input file paths is assumed to be a non-glob path to an existing file.
     * @property {boolean} [ignore] False disables use of .eslintignore.
     * @property {string} [ignorePath] The ignore file to use instead of .eslintignore.
     * @property {ConfigData} [overrideConfig] Override config object, overrides all configs used with this instance
     * @property {string} [overrideConfigFile] The configuration file to use.
     * @property {Record<string,Plugin>|null} [plugins] Preloaded plugins. This is a map-like object, keys are plugin IDs and each value is implementation.
     * @property {"error" | "warn" | "off"} [reportUnusedDisableDirectives] the severity to report unused eslint-disable directives.
     * @property {string} [resolvePluginsRelativeTo] The folder where plugins should be resolved from, defaulting to the CWD.
     * @property {string[]} [rulePaths] An array of directories to load custom rules from.
     * @property {boolean} [useEslintrc] False disables looking for .eslintrc.* files.
     */
    /**
     * A rules metadata object.
     * @typedef {Object} RulesMeta
     * @property {string} id The plugin ID.
     * @property {Object} definition The plugin definition.
     */
    /**
     * Private members for the `ESLint` instance.
     * @typedef {Object} ESLintPrivateMembers
     * @property {CLIEngine} cliEngine The wrapped CLIEngine instance.
     * @property {ESLintOptions} options The options used to instantiate the ESLint instance.
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const writeFile = promisify(fs.writeFile);
    /**
     * The map with which to store private class members.
     * @type {WeakMap<ESLint, ESLintPrivateMembers>}
     */
    const privateMembersMap = new WeakMap();
    /**
     * Check if a given value is a non-empty string or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if `x` is a non-empty string.
     */
    function isNonEmptyString(x) {
        return typeof x === "string" && x.trim() !== "";
    }
    /**
     * Check if a given value is an array of non-empty strings or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if `x` is an array of non-empty strings.
     */
    function isArrayOfNonEmptyString(x) {
        return Array.isArray(x) && x.every(isNonEmptyString);
    }
    /**
     * Check if a given value is a valid fix type or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if `x` is valid fix type.
     */
    function isFixType(x) {
        return x === "directive" || x === "problem" || x === "suggestion" || x === "layout";
    }
    /**
     * Check if a given value is an array of fix types or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if `x` is an array of fix types.
     */
    function isFixTypeArray(x) {
        return Array.isArray(x) && x.every(isFixType);
    }
    /**
     * The error for invalid options.
     */
    class ESLintInvalidOptionsError extends Error {
        constructor(messages) {
            super(`Invalid Options:\n- ${messages.join("\n- ")}`);
            this.code = "ESLINT_INVALID_OPTIONS";
            Error.captureStackTrace(this, ESLintInvalidOptionsError);
        }
    }
    /**
     * Validates and normalizes options for the wrapped CLIEngine instance.
     * @param {ESLintOptions} options The options to process.
     * @throws {ESLintInvalidOptionsError} If of any of a variety of type errors.
     * @returns {ESLintOptions} The normalized options.
     */
    function processOptions({ allowInlineConfig = true, // ← we cannot use `overrideConfig.noInlineConfig` instead because `allowInlineConfig` has side-effect that suppress warnings that show inline configs are ignored.
    baseConfig = null, cache = false, cacheLocation = ".eslintcache", cacheStrategy = "metadata", cwd = process.cwd(), errorOnUnmatchedPattern = true, extensions = null, // ← should be null by default because if it's an array then it suppresses RFC20 feature.
    fix = false, fixTypes = null, // ← should be null by default because if it's an array then it suppresses rules that don't have the `meta.type` property.
    globInputPaths = true, ignore = true, ignorePath = null, // ← should be null by default because if it's a string then it may throw ENOENT.
    overrideConfig = null, overrideConfigFile = null, plugins = {}, reportUnusedDisableDirectives = null, // ← should be null by default because if it's a string then it overrides the 'reportUnusedDisableDirectives' setting in config files. And we cannot use `overrideConfig.reportUnusedDisableDirectives` instead because we cannot configure the `error` severity with that.
    resolvePluginsRelativeTo = null, // ← should be null by default because if it's a string then it suppresses RFC47 feature.
    rulePaths = [], useEslintrc = true, ...unknownOptions }) {
        const errors = [];
        const unknownOptionKeys = Object.keys(unknownOptions);
        if (unknownOptionKeys.length >= 1) {
            errors.push(`Unknown options: ${unknownOptionKeys.join(", ")}`);
            if (unknownOptionKeys.includes("cacheFile")) {
                errors.push("'cacheFile' has been removed. Please use the 'cacheLocation' option instead.");
            }
            if (unknownOptionKeys.includes("configFile")) {
                errors.push("'configFile' has been removed. Please use the 'overrideConfigFile' option instead.");
            }
            if (unknownOptionKeys.includes("envs")) {
                errors.push("'envs' has been removed. Please use the 'overrideConfig.env' option instead.");
            }
            if (unknownOptionKeys.includes("globals")) {
                errors.push("'globals' has been removed. Please use the 'overrideConfig.globals' option instead.");
            }
            if (unknownOptionKeys.includes("ignorePattern")) {
                errors.push("'ignorePattern' has been removed. Please use the 'overrideConfig.ignorePatterns' option instead.");
            }
            if (unknownOptionKeys.includes("parser")) {
                errors.push("'parser' has been removed. Please use the 'overrideConfig.parser' option instead.");
            }
            if (unknownOptionKeys.includes("parserOptions")) {
                errors.push("'parserOptions' has been removed. Please use the 'overrideConfig.parserOptions' option instead.");
            }
            if (unknownOptionKeys.includes("rules")) {
                errors.push("'rules' has been removed. Please use the 'overrideConfig.rules' option instead.");
            }
        }
        if (typeof allowInlineConfig !== "boolean") {
            errors.push("'allowInlineConfig' must be a boolean.");
        }
        if (typeof baseConfig !== "object") {
            errors.push("'baseConfig' must be an object or null.");
        }
        if (typeof cache !== "boolean") {
            errors.push("'cache' must be a boolean.");
        }
        if (!isNonEmptyString(cacheLocation)) {
            errors.push("'cacheLocation' must be a non-empty string.");
        }
        if (cacheStrategy !== "metadata" &&
            cacheStrategy !== "content") {
            errors.push("'cacheStrategy' must be any of \"metadata\", \"content\".");
        }
        if (!isNonEmptyString(cwd) || !path.isAbsolute(cwd)) {
            errors.push("'cwd' must be an absolute path.");
        }
        if (typeof errorOnUnmatchedPattern !== "boolean") {
            errors.push("'errorOnUnmatchedPattern' must be a boolean.");
        }
        if (!isArrayOfNonEmptyString(extensions) && extensions !== null) {
            errors.push("'extensions' must be an array of non-empty strings or null.");
        }
        if (typeof fix !== "boolean" && typeof fix !== "function") {
            errors.push("'fix' must be a boolean or a function.");
        }
        if (fixTypes !== null && !isFixTypeArray(fixTypes)) {
            errors.push("'fixTypes' must be an array of any of \"directive\", \"problem\", \"suggestion\", and \"layout\".");
        }
        if (typeof globInputPaths !== "boolean") {
            errors.push("'globInputPaths' must be a boolean.");
        }
        if (typeof ignore !== "boolean") {
            errors.push("'ignore' must be a boolean.");
        }
        if (!isNonEmptyString(ignorePath) && ignorePath !== null) {
            errors.push("'ignorePath' must be a non-empty string or null.");
        }
        if (typeof overrideConfig !== "object") {
            errors.push("'overrideConfig' must be an object or null.");
        }
        if (!isNonEmptyString(overrideConfigFile) && overrideConfigFile !== null) {
            errors.push("'overrideConfigFile' must be a non-empty string or null.");
        }
        if (typeof plugins !== "object") {
            errors.push("'plugins' must be an object or null.");
        }
        else if (plugins !== null && Object.keys(plugins).includes("")) {
            errors.push("'plugins' must not include an empty string.");
        }
        if (Array.isArray(plugins)) {
            errors.push("'plugins' doesn't add plugins to configuration to load. Please use the 'overrideConfig.plugins' option instead.");
        }
        if (reportUnusedDisableDirectives !== "error" &&
            reportUnusedDisableDirectives !== "warn" &&
            reportUnusedDisableDirectives !== "off" &&
            reportUnusedDisableDirectives !== null) {
            errors.push("'reportUnusedDisableDirectives' must be any of \"error\", \"warn\", \"off\", and null.");
        }
        if (!isNonEmptyString(resolvePluginsRelativeTo) &&
            resolvePluginsRelativeTo !== null) {
            errors.push("'resolvePluginsRelativeTo' must be a non-empty string or null.");
        }
        if (!isArrayOfNonEmptyString(rulePaths)) {
            errors.push("'rulePaths' must be an array of non-empty strings.");
        }
        if (typeof useEslintrc !== "boolean") {
            errors.push("'useEslintrc' must be a boolean.");
        }
        if (errors.length > 0) {
            throw new ESLintInvalidOptionsError(errors);
        }
        return {
            allowInlineConfig,
            baseConfig,
            cache,
            cacheLocation,
            cacheStrategy,
            configFile: overrideConfigFile,
            cwd,
            errorOnUnmatchedPattern,
            extensions,
            fix,
            fixTypes,
            globInputPaths,
            ignore,
            ignorePath,
            reportUnusedDisableDirectives,
            resolvePluginsRelativeTo,
            rulePaths,
            useEslintrc
        };
    }
    /**
     * Check if a value has one or more properties and that value is not undefined.
     * @param {any} obj The value to check.
     * @returns {boolean} `true` if `obj` has one or more properties that that value is not undefined.
     */
    function hasDefinedProperty(obj) {
        if (typeof obj === "object" && obj !== null) {
            for (const key in obj) {
                if (typeof obj[key] !== "undefined") {
                    return true;
                }
            }
        }
        return false;
    }
    /**
     * Create rulesMeta object.
     * @param {Map<string,Rule>} rules a map of rules from which to generate the object.
     * @returns {Object} metadata for all enabled rules.
     */
    function createRulesMeta(rules) {
        return Array.from(rules).reduce((retVal, [id, rule]) => {
            retVal[id] = rule.meta;
            return retVal;
        }, {});
    }
    /** @type {WeakMap<ExtractedConfig, DeprecatedRuleInfo[]>} */
    const usedDeprecatedRulesCache = new WeakMap();
    /**
     * Create used deprecated rule list.
     * @param {CLIEngine} cliEngine The CLIEngine instance.
     * @param {string} maybeFilePath The absolute path to a lint target file or `"<text>"`.
     * @returns {DeprecatedRuleInfo[]} The used deprecated rule list.
     */
    function getOrFindUsedDeprecatedRules(cliEngine, maybeFilePath) {
        const { configArrayFactory, options: { cwd } } = getCLIEngineInternalSlots(cliEngine);
        const filePath = path.isAbsolute(maybeFilePath)
            ? maybeFilePath
            : path.join(cwd, "__placeholder__.js");
        const configArray = configArrayFactory.getConfigArrayForFile(filePath);
        const config = configArray.extractConfig(filePath);
        // Most files use the same config, so cache it.
        if (!usedDeprecatedRulesCache.has(config)) {
            const pluginRules = configArray.pluginRules;
            const retv = [];
            for (const [ruleId, ruleConf] of Object.entries(config.rules)) {
                if (getRuleSeverity(ruleConf) === 0) {
                    continue;
                }
                const rule = pluginRules.get(ruleId) || BuiltinRules.get(ruleId);
                const meta = rule && rule.meta;
                if (meta && meta.deprecated) {
                    retv.push({ ruleId, replacedBy: meta.replacedBy || [] });
                }
            }
            usedDeprecatedRulesCache.set(config, Object.freeze(retv));
        }
        return usedDeprecatedRulesCache.get(config);
    }
    /**
     * Processes the linting results generated by a CLIEngine linting report to
     * match the ESLint class's API.
     * @param {CLIEngine} cliEngine The CLIEngine instance.
     * @param {CLIEngineLintReport} report The CLIEngine linting report to process.
     * @returns {LintResult[]} The processed linting results.
     */
    function processCLIEngineLintReport(cliEngine, { results }) {
        const descriptor = {
            configurable: true,
            enumerable: true,
            get() {
                return getOrFindUsedDeprecatedRules(cliEngine, this.filePath);
            }
        };
        for (const result of results) {
            Object.defineProperty(result, "usedDeprecatedRules", descriptor);
        }
        return results;
    }
    /**
     * An Array.prototype.sort() compatible compare function to order results by their file path.
     * @param {LintResult} a The first lint result.
     * @param {LintResult} b The second lint result.
     * @returns {number} An integer representing the order in which the two results should occur.
     */
    function compareResultsByFilePath(a, b) {
        if (a.filePath < b.filePath) {
            return -1;
        }
        if (a.filePath > b.filePath) {
            return 1;
        }
        return 0;
    }
    /**
     * Main API.
     */
    class ESLint {
        /**
         * Creates a new instance of the main ESLint API.
         * @param {ESLintOptions} options The options for this instance.
         */
        constructor(options = {}) {
            const processedOptions = processOptions(options);
            const cliEngine = new CLIEngine(processedOptions, { preloadedPlugins: options.plugins });
            const { configArrayFactory, lastConfigArrays } = getCLIEngineInternalSlots(cliEngine);
            let updated = false;
            /*
             * Address `overrideConfig` to set override config.
             * Operate the `configArrayFactory` internal slot directly because this
             * functionality doesn't exist as the public API of CLIEngine.
             */
            if (hasDefinedProperty(options.overrideConfig)) {
                configArrayFactory.setOverrideConfig(options.overrideConfig);
                updated = true;
            }
            // Update caches.
            if (updated) {
                configArrayFactory.clearCache();
                lastConfigArrays[0] = configArrayFactory.getConfigArrayForFile();
            }
            // Initialize private properties.
            privateMembersMap.set(this, {
                cliEngine,
                options: processedOptions
            });
        }
        /**
         * The version text.
         * @type {string}
         */
        static get version() {
            return version;
        }
        /**
         * Outputs fixes from the given results to files.
         * @param {LintResult[]} results The lint results.
         * @returns {Promise<void>} Returns a promise that is used to track side effects.
         */
        static async outputFixes(results) {
            if (!Array.isArray(results)) {
                throw new Error("'results' must be an array");
            }
            await Promise.all(results
                .filter(result => {
                if (typeof result !== "object" || result === null) {
                    throw new Error("'results' must include only objects");
                }
                return (typeof result.output === "string" &&
                    path.isAbsolute(result.filePath));
            })
                .map(r => writeFile(r.filePath, r.output)));
        }
        /**
         * Returns results that only contains errors.
         * @param {LintResult[]} results The results to filter.
         * @returns {LintResult[]} The filtered results.
         */
        static getErrorResults(results) {
            return CLIEngine.getErrorResults(results);
        }
        /**
         * Returns meta objects for each rule represented in the lint results.
         * @param {LintResult[]} results The results to fetch rules meta for.
         * @returns {Object} A mapping of ruleIds to rule meta objects.
         */
        getRulesMetaForResults(results) {
            const resultRuleIds = new Set();
            // first gather all ruleIds from all results
            for (const result of results) {
                for (const { ruleId } of result.messages) {
                    resultRuleIds.add(ruleId);
                }
                for (const { ruleId } of result.suppressedMessages) {
                    resultRuleIds.add(ruleId);
                }
            }
            // create a map of all rules in the results
            const { cliEngine } = privateMembersMap.get(this);
            const rules = cliEngine.getRules();
            const resultRules = new Map();
            for (const [ruleId, rule] of rules) {
                if (resultRuleIds.has(ruleId)) {
                    resultRules.set(ruleId, rule);
                }
            }
            return createRulesMeta(resultRules);
        }
        /**
         * Executes the current configuration on an array of file and directory names.
         * @param {string[]} patterns An array of file and directory names.
         * @returns {Promise<LintResult[]>} The results of linting the file patterns given.
         */
        async lintFiles(patterns) {
            if (!isNonEmptyString(patterns) && !isArrayOfNonEmptyString(patterns)) {
                throw new Error("'patterns' must be a non-empty string or an array of non-empty strings");
            }
            const { cliEngine } = privateMembersMap.get(this);
            return processCLIEngineLintReport(cliEngine, cliEngine.executeOnFiles(patterns));
        }
        /**
         * Executes the current configuration on text.
         * @param {string} code A string of JavaScript code to lint.
         * @param {Object} [options] The options.
         * @param {string} [options.filePath] The path to the file of the source code.
         * @param {boolean} [options.warnIgnored] When set to true, warn if given filePath is an ignored path.
         * @returns {Promise<LintResult[]>} The results of linting the string of code given.
         */
        async lintText(code, options = {}) {
            if (typeof code !== "string") {
                throw new Error("'code' must be a string");
            }
            if (typeof options !== "object") {
                throw new Error("'options' must be an object, null, or undefined");
            }
            const { filePath, warnIgnored = false, ...unknownOptions } = options || {};
            const unknownOptionKeys = Object.keys(unknownOptions);
            if (unknownOptionKeys.length > 0) {
                throw new Error(`'options' must not include the unknown option(s): ${unknownOptionKeys.join(", ")}`);
            }
            if (filePath !== void 0 && !isNonEmptyString(filePath)) {
                throw new Error("'options.filePath' must be a non-empty string or undefined");
            }
            if (typeof warnIgnored !== "boolean") {
                throw new Error("'options.warnIgnored' must be a boolean or undefined");
            }
            const { cliEngine } = privateMembersMap.get(this);
            return processCLIEngineLintReport(cliEngine, cliEngine.executeOnText(code, filePath, warnIgnored));
        }
        /**
         * Returns the formatter representing the given formatter name.
         * @param {string} [name] The name of the formatter to load.
         * The following values are allowed:
         * - `undefined` ... Load `stylish` builtin formatter.
         * - A builtin formatter name ... Load the builtin formatter.
         * - A third-party formatter name:
         *   - `foo` → `eslint-formatter-foo`
         *   - `@foo` → `@foo/eslint-formatter`
         *   - `@foo/bar` → `@foo/eslint-formatter-bar`
         * - A file path ... Load the file.
         * @returns {Promise<LoadedFormatter>} A promise resolving to the formatter object.
         * This promise will be rejected if the given formatter was not found or not
         * a function.
         */
        async loadFormatter(name = "stylish") {
            if (typeof name !== "string") {
                throw new Error("'name' must be a string");
            }
            const { cliEngine, options } = privateMembersMap.get(this);
            const formatter = cliEngine.getFormatter(name);
            if (typeof formatter !== "function") {
                throw new Error(`Formatter must be a function, but got a ${typeof formatter}.`);
            }
            return {
                /**
                 * The main formatter method.
                 * @param {LintResult[]} results The lint results to format.
                 * @param {ResultsMeta} resultsMeta Warning count and max threshold.
                 * @returns {string | Promise<string>} The formatted lint results.
                 */
                format(results, resultsMeta) {
                    let rulesMeta = null;
                    results.sort(compareResultsByFilePath);
                    return formatter(results, {
                        ...resultsMeta,
                        get cwd() {
                            return options.cwd;
                        },
                        get rulesMeta() {
                            if (!rulesMeta) {
                                rulesMeta = createRulesMeta(cliEngine.getRules());
                            }
                            return rulesMeta;
                        }
                    });
                }
            };
        }
        /**
         * Returns a configuration object for the given file based on the CLI options.
         * This is the same logic used by the ESLint CLI executable to determine
         * configuration for each file it processes.
         * @param {string} filePath The path of the file to retrieve a config object for.
         * @returns {Promise<ConfigData>} A configuration object for the file.
         */
        async calculateConfigForFile(filePath) {
            if (!isNonEmptyString(filePath)) {
                throw new Error("'filePath' must be a non-empty string");
            }
            const { cliEngine } = privateMembersMap.get(this);
            return cliEngine.getConfigForFile(filePath);
        }
        /**
         * Checks if a given path is ignored by ESLint.
         * @param {string} filePath The path of the file to check.
         * @returns {Promise<boolean>} Whether or not the given path is ignored.
         */
        async isPathIgnored(filePath) {
            if (!isNonEmptyString(filePath)) {
                throw new Error("'filePath' must be a non-empty string");
            }
            const { cliEngine } = privateMembersMap.get(this);
            return cliEngine.isPathIgnored(filePath);
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = {
        ESLint,
        /**
         * Get the private class members of a given ESLint instance for tests.
         * @param {ESLint} instance The ESLint instance to get.
         * @returns {ESLintPrivateMembers} The instance's private class members.
         */
        getESLintPrivateMembers(instance) {
            return privateMembersMap.get(instance);
        }
    };
},
/* eslint/lib/cli-engine/cli-engine.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Main CLI object.
     * @author Nicholas C. Zakas
     */
    "use strict";
    /*
     * The CLI object should *not* call process.exit() directly. It should only return
     * exit codes. This allows other programs to use the CLI object and still control
     * when the program exits.
     */
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const fs = require("fs");
    const path = require("path");
    const defaultOptions = require(220) /* ../../conf/default-cli-options */;
    const pkg = require(221) /* ../../package.json */;
    const { Legacy: { ConfigOps, naming, CascadingConfigArrayFactory, IgnorePattern, getUsedExtractedConfigs, ModuleResolver } } = require(222) /* @eslint/eslintrc */;
    const { FileEnumerator } = require(281) /* ./file-enumerator */;
    const { Linter } = require(289) /* ../linter */;
    const builtInRules = require(357) /* ../rules */;
    const loadRules = require(707) /* ./load-rules */;
    const hash = require(708) /* ./hash */;
    const LintResultCache = require(710) /* ./lint-result-cache */;
    const debug = require(72) /* debug */("eslint:cli-engine");
    const validFixTypes = new Set(["directive", "problem", "suggestion", "layout"]);
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    // For VSCode IntelliSense
    /** @typedef {import("../shared/types").ConfigData} ConfigData */
    /** @typedef {import("../shared/types").DeprecatedRuleInfo} DeprecatedRuleInfo */
    /** @typedef {import("../shared/types").LintMessage} LintMessage */
    /** @typedef {import("../shared/types").SuppressedLintMessage} SuppressedLintMessage */
    /** @typedef {import("../shared/types").ParserOptions} ParserOptions */
    /** @typedef {import("../shared/types").Plugin} Plugin */
    /** @typedef {import("../shared/types").RuleConf} RuleConf */
    /** @typedef {import("../shared/types").Rule} Rule */
    /** @typedef {import("../shared/types").FormatterFunction} FormatterFunction */
    /** @typedef {ReturnType<CascadingConfigArrayFactory.getConfigArrayForFile>} ConfigArray */
    /** @typedef {ReturnType<ConfigArray.extractConfig>} ExtractedConfig */
    /**
     * The options to configure a CLI engine with.
     * @typedef {Object} CLIEngineOptions
     * @property {boolean} [allowInlineConfig] Enable or disable inline configuration comments.
     * @property {ConfigData} [baseConfig] Base config object, extended by all configs used with this CLIEngine instance
     * @property {boolean} [cache] Enable result caching.
     * @property {string} [cacheLocation] The cache file to use instead of .eslintcache.
     * @property {string} [configFile] The configuration file to use.
     * @property {string} [cwd] The value to use for the current working directory.
     * @property {string[]} [envs] An array of environments to load.
     * @property {string[]|null} [extensions] An array of file extensions to check.
     * @property {boolean|Function} [fix] Execute in autofix mode. If a function, should return a boolean.
     * @property {string[]} [fixTypes] Array of rule types to apply fixes for.
     * @property {string[]} [globals] An array of global variables to declare.
     * @property {boolean} [ignore] False disables use of .eslintignore.
     * @property {string} [ignorePath] The ignore file to use instead of .eslintignore.
     * @property {string|string[]} [ignorePattern] One or more glob patterns to ignore.
     * @property {boolean} [useEslintrc] False disables looking for .eslintrc
     * @property {string} [parser] The name of the parser to use.
     * @property {ParserOptions} [parserOptions] An object of parserOption settings to use.
     * @property {string[]} [plugins] An array of plugins to load.
     * @property {Record<string,RuleConf>} [rules] An object of rules to use.
     * @property {string[]} [rulePaths] An array of directories to load custom rules from.
     * @property {boolean} [reportUnusedDisableDirectives] `true` adds reports for unused eslint-disable directives
     * @property {boolean} [globInputPaths] Set to false to skip glob resolution of input file paths to lint (default: true). If false, each input file paths is assumed to be a non-glob path to an existing file.
     * @property {string} [resolvePluginsRelativeTo] The folder where plugins should be resolved from, defaulting to the CWD
     */
    /**
     * A linting result.
     * @typedef {Object} LintResult
     * @property {string} filePath The path to the file that was linted.
     * @property {LintMessage[]} messages All of the messages for the result.
     * @property {SuppressedLintMessage[]} suppressedMessages All of the suppressed messages for the result.
     * @property {number} errorCount Number of errors for the result.
     * @property {number} fatalErrorCount Number of fatal errors for the result.
     * @property {number} warningCount Number of warnings for the result.
     * @property {number} fixableErrorCount Number of fixable errors for the result.
     * @property {number} fixableWarningCount Number of fixable warnings for the result.
     * @property {string} [source] The source code of the file that was linted.
     * @property {string} [output] The source code of the file that was linted, with as many fixes applied as possible.
     */
    /**
     * Linting results.
     * @typedef {Object} LintReport
     * @property {LintResult[]} results All of the result.
     * @property {number} errorCount Number of errors for the result.
     * @property {number} fatalErrorCount Number of fatal errors for the result.
     * @property {number} warningCount Number of warnings for the result.
     * @property {number} fixableErrorCount Number of fixable errors for the result.
     * @property {number} fixableWarningCount Number of fixable warnings for the result.
     * @property {DeprecatedRuleInfo[]} usedDeprecatedRules The list of used deprecated rules.
     */
    /**
     * Private data for CLIEngine.
     * @typedef {Object} CLIEngineInternalSlots
     * @property {Map<string, Plugin>} additionalPluginPool The map for additional plugins.
     * @property {string} cacheFilePath The path to the cache of lint results.
     * @property {CascadingConfigArrayFactory} configArrayFactory The factory of configs.
     * @property {(filePath: string) => boolean} defaultIgnores The default predicate function to check if a file ignored or not.
     * @property {FileEnumerator} fileEnumerator The file enumerator.
     * @property {ConfigArray[]} lastConfigArrays The list of config arrays that the last `executeOnFiles` or `executeOnText` used.
     * @property {LintResultCache|null} lintResultCache The cache of lint results.
     * @property {Linter} linter The linter instance which has loaded rules.
     * @property {CLIEngineOptions} options The normalized options of this instance.
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /** @type {WeakMap<CLIEngine, CLIEngineInternalSlots>} */
    const internalSlotsMap = new WeakMap();
    /**
     * Determines if each fix type in an array is supported by ESLint and throws
     * an error if not.
     * @param {string[]} fixTypes An array of fix types to check.
     * @returns {void}
     * @throws {Error} If an invalid fix type is found.
     */
    function validateFixTypes(fixTypes) {
        for (const fixType of fixTypes) {
            if (!validFixTypes.has(fixType)) {
                throw new Error(`Invalid fix type "${fixType}" found.`);
            }
        }
    }
    /**
     * It will calculate the error and warning count for collection of messages per file
     * @param {LintMessage[]} messages Collection of messages
     * @returns {Object} Contains the stats
     * @private
     */
    function calculateStatsPerFile(messages) {
        return messages.reduce((stat, message) => {
            if (message.fatal || message.severity === 2) {
                stat.errorCount++;
                if (message.fatal) {
                    stat.fatalErrorCount++;
                }
                if (message.fix) {
                    stat.fixableErrorCount++;
                }
            }
            else {
                stat.warningCount++;
                if (message.fix) {
                    stat.fixableWarningCount++;
                }
            }
            return stat;
        }, {
            errorCount: 0,
            fatalErrorCount: 0,
            warningCount: 0,
            fixableErrorCount: 0,
            fixableWarningCount: 0
        });
    }
    /**
     * It will calculate the error and warning count for collection of results from all files
     * @param {LintResult[]} results Collection of messages from all the files
     * @returns {Object} Contains the stats
     * @private
     */
    function calculateStatsPerRun(results) {
        return results.reduce((stat, result) => {
            stat.errorCount += result.errorCount;
            stat.fatalErrorCount += result.fatalErrorCount;
            stat.warningCount += result.warningCount;
            stat.fixableErrorCount += result.fixableErrorCount;
            stat.fixableWarningCount += result.fixableWarningCount;
            return stat;
        }, {
            errorCount: 0,
            fatalErrorCount: 0,
            warningCount: 0,
            fixableErrorCount: 0,
            fixableWarningCount: 0
        });
    }
    /**
     * Processes an source code using ESLint.
     * @param {Object} config The config object.
     * @param {string} config.text The source code to verify.
     * @param {string} config.cwd The path to the current working directory.
     * @param {string|undefined} config.filePath The path to the file of `text`. If this is undefined, it uses `<text>`.
     * @param {ConfigArray} config.config The config.
     * @param {boolean} config.fix If `true` then it does fix.
     * @param {boolean} config.allowInlineConfig If `true` then it uses directive comments.
     * @param {boolean} config.reportUnusedDisableDirectives If `true` then it reports unused `eslint-disable` comments.
     * @param {FileEnumerator} config.fileEnumerator The file enumerator to check if a path is a target or not.
     * @param {Linter} config.linter The linter instance to verify.
     * @returns {LintResult} The result of linting.
     * @private
     */
    function verifyText({ text, cwd, filePath: providedFilePath, config, fix, allowInlineConfig, reportUnusedDisableDirectives, fileEnumerator, linter }) {
        const filePath = providedFilePath || "<text>";
        debug(`Lint ${filePath}`);
        /*
         * Verify.
         * `config.extractConfig(filePath)` requires an absolute path, but `linter`
         * doesn't know CWD, so it gives `linter` an absolute path always.
         */
        const filePathToVerify = filePath === "<text>" ? path.join(cwd, filePath) : filePath;
        const { fixed, messages, output } = linter.verifyAndFix(text, config, {
            allowInlineConfig,
            filename: filePathToVerify,
            fix,
            reportUnusedDisableDirectives,
            /**
             * Check if the linter should adopt a given code block or not.
             * @param {string} blockFilename The virtual filename of a code block.
             * @returns {boolean} `true` if the linter should adopt the code block.
             */
            filterCodeBlock(blockFilename) {
                return fileEnumerator.isTargetPath(blockFilename);
            }
        });
        // Tweak and return.
        const result = {
            filePath,
            messages,
            suppressedMessages: linter.getSuppressedMessages(),
            ...calculateStatsPerFile(messages)
        };
        if (fixed) {
            result.output = output;
        }
        if (result.errorCount + result.warningCount > 0 &&
            typeof result.output === "undefined") {
            result.source = text;
        }
        return result;
    }
    /**
     * Returns result with warning by ignore settings
     * @param {string} filePath File path of checked code
     * @param {string} baseDir Absolute path of base directory
     * @returns {LintResult} Result with single warning
     * @private
     */
    function createIgnoreResult(filePath, baseDir) {
        let message;
        const isHidden = filePath.split(path.sep)
            .find(segment => /^\./u.test(segment));
        const isInNodeModules = baseDir && path.relative(baseDir, filePath).startsWith("node_modules");
        if (isHidden) {
            message = "File ignored by default.  Use a negated ignore pattern (like \"--ignore-pattern '!<relative/path/to/filename>'\") to override.";
        }
        else if (isInNodeModules) {
            message = "File ignored by default. Use \"--ignore-pattern '!node_modules/*'\" to override.";
        }
        else {
            message = "File ignored because of a matching ignore pattern. Use \"--no-ignore\" to override.";
        }
        return {
            filePath: path.resolve(filePath),
            messages: [
                {
                    fatal: false,
                    severity: 1,
                    message
                }
            ],
            suppressedMessages: [],
            errorCount: 0,
            fatalErrorCount: 0,
            warningCount: 1,
            fixableErrorCount: 0,
            fixableWarningCount: 0
        };
    }
    /**
     * Get a rule.
     * @param {string} ruleId The rule ID to get.
     * @param {ConfigArray[]} configArrays The config arrays that have plugin rules.
     * @returns {Rule|null} The rule or null.
     */
    function getRule(ruleId, configArrays) {
        for (const configArray of configArrays) {
            const rule = configArray.pluginRules.get(ruleId);
            if (rule) {
                return rule;
            }
        }
        return builtInRules.get(ruleId) || null;
    }
    /**
     * Checks whether a message's rule type should be fixed.
     * @param {LintMessage} message The message to check.
     * @param {ConfigArray[]} lastConfigArrays The list of config arrays that the last `executeOnFiles` or `executeOnText` used.
     * @param {string[]} fixTypes An array of fix types to check.
     * @returns {boolean} Whether the message should be fixed.
     */
    function shouldMessageBeFixed(message, lastConfigArrays, fixTypes) {
        if (!message.ruleId) {
            return fixTypes.has("directive");
        }
        const rule = message.ruleId && getRule(message.ruleId, lastConfigArrays);
        return Boolean(rule && rule.meta && fixTypes.has(rule.meta.type));
    }
    /**
     * Collect used deprecated rules.
     * @param {ConfigArray[]} usedConfigArrays The config arrays which were used.
     * @returns {IterableIterator<DeprecatedRuleInfo>} Used deprecated rules.
     */
    function* iterateRuleDeprecationWarnings(usedConfigArrays) {
        const processedRuleIds = new Set();
        // Flatten used configs.
        /** @type {ExtractedConfig[]} */
        const configs = usedConfigArrays.flatMap(getUsedExtractedConfigs);
        // Traverse rule configs.
        for (const config of configs) {
            for (const [ruleId, ruleConfig] of Object.entries(config.rules)) {
                // Skip if it was processed.
                if (processedRuleIds.has(ruleId)) {
                    continue;
                }
                processedRuleIds.add(ruleId);
                // Skip if it's not used.
                if (!ConfigOps.getRuleSeverity(ruleConfig)) {
                    continue;
                }
                const rule = getRule(ruleId, usedConfigArrays);
                // Skip if it's not deprecated.
                if (!(rule && rule.meta && rule.meta.deprecated)) {
                    continue;
                }
                // This rule was used and deprecated.
                yield {
                    ruleId,
                    replacedBy: rule.meta.replacedBy || []
                };
            }
        }
    }
    /**
     * Checks if the given message is an error message.
     * @param {LintMessage} message The message to check.
     * @returns {boolean} Whether or not the message is an error message.
     * @private
     */
    function isErrorMessage(message) {
        return message.severity === 2;
    }
    /**
     * return the cacheFile to be used by eslint, based on whether the provided parameter is
     * a directory or looks like a directory (ends in `path.sep`), in which case the file
     * name will be the `cacheFile/.cache_hashOfCWD`
     *
     * if cacheFile points to a file or looks like a file then it will just use that file
     * @param {string} cacheFile The name of file to be used to store the cache
     * @param {string} cwd Current working directory
     * @returns {string} the resolved path to the cache file
     */
    function getCacheFile(cacheFile, cwd) {
        /*
         * make sure the path separators are normalized for the environment/os
         * keeping the trailing path separator if present
         */
        const normalizedCacheFile = path.normalize(cacheFile);
        const resolvedCacheFile = path.resolve(cwd, normalizedCacheFile);
        const looksLikeADirectory = normalizedCacheFile.slice(-1) === path.sep;
        /**
         * return the name for the cache file in case the provided parameter is a directory
         * @returns {string} the resolved path to the cacheFile
         */
        function getCacheFileForDirectory() {
            return path.join(resolvedCacheFile, `.cache_${hash(cwd)}`);
        }
        let fileStats;
        try {
            fileStats = fs.lstatSync(resolvedCacheFile);
        }
        catch {
            fileStats = null;
        }
        /*
         * in case the file exists we need to verify if the provided path
         * is a directory or a file. If it is a directory we want to create a file
         * inside that directory
         */
        if (fileStats) {
            /*
             * is a directory or is a file, but the original file the user provided
             * looks like a directory but `path.resolve` removed the `last path.sep`
             * so we need to still treat this like a directory
             */
            if (fileStats.isDirectory() || looksLikeADirectory) {
                return getCacheFileForDirectory();
            }
            // is file so just use that file
            return resolvedCacheFile;
        }
        /*
         * here we known the file or directory doesn't exist,
         * so we will try to infer if its a directory if it looks like a directory
         * for the current operating system.
         */
        // if the last character passed is a path separator we assume is a directory
        if (looksLikeADirectory) {
            return getCacheFileForDirectory();
        }
        return resolvedCacheFile;
    }
    /**
     * Convert a string array to a boolean map.
     * @param {string[]|null} keys The keys to assign true.
     * @param {boolean} defaultValue The default value for each property.
     * @param {string} displayName The property name which is used in error message.
     * @throws {Error} Requires array.
     * @returns {Record<string,boolean>} The boolean map.
     */
    function toBooleanMap(keys, defaultValue, displayName) {
        if (keys && !Array.isArray(keys)) {
            throw new Error(`${displayName} must be an array.`);
        }
        if (keys && keys.length > 0) {
            return keys.reduce((map, def) => {
                const [key, value] = def.split(":");
                if (key !== "__proto__") {
                    map[key] = value === void 0
                        ? defaultValue
                        : value === "true";
                }
                return map;
            }, {});
        }
        return void 0;
    }
    /**
     * Create a config data from CLI options.
     * @param {CLIEngineOptions} options The options
     * @returns {ConfigData|null} The created config data.
     */
    function createConfigDataFromOptions(options) {
        const { ignorePattern, parser, parserOptions, plugins, rules } = options;
        const env = toBooleanMap(options.envs, true, "envs");
        const globals = toBooleanMap(options.globals, false, "globals");
        if (env === void 0 &&
            globals === void 0 &&
            (ignorePattern === void 0 || ignorePattern.length === 0) &&
            parser === void 0 &&
            parserOptions === void 0 &&
            plugins === void 0 &&
            rules === void 0) {
            return null;
        }
        return {
            env,
            globals,
            ignorePatterns: ignorePattern,
            parser,
            parserOptions,
            plugins,
            rules
        };
    }
    /**
     * Checks whether a directory exists at the given location
     * @param {string} resolvedPath A path from the CWD
     * @throws {Error} As thrown by `fs.statSync` or `fs.isDirectory`.
     * @returns {boolean} `true` if a directory exists
     */
    function directoryExists(resolvedPath) {
        try {
            return fs.statSync(resolvedPath).isDirectory();
        }
        catch (error) {
            if (error && (error.code === "ENOENT" || error.code === "ENOTDIR")) {
                return false;
            }
            throw error;
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * Core CLI.
     */
    class CLIEngine {
        /**
         * Creates a new instance of the core CLI engine.
         * @param {CLIEngineOptions} providedOptions The options for this instance.
         * @param {Object} [additionalData] Additional settings that are not CLIEngineOptions.
         * @param {Record<string,Plugin>|null} [additionalData.preloadedPlugins] Preloaded plugins.
         */
        constructor(providedOptions, { preloadedPlugins } = {}) {
            const options = Object.assign(Object.create(null), defaultOptions, { cwd: process.cwd() }, providedOptions);
            if (options.fix === void 0) {
                options.fix = false;
            }
            const additionalPluginPool = new Map();
            if (preloadedPlugins) {
                for (const [id, plugin] of Object.entries(preloadedPlugins)) {
                    additionalPluginPool.set(id, plugin);
                }
            }
            const cacheFilePath = getCacheFile(options.cacheLocation || options.cacheFile, options.cwd);
            const configArrayFactory = new CascadingConfigArrayFactory({
                additionalPluginPool,
                baseConfig: options.baseConfig || null,
                cliConfig: createConfigDataFromOptions(options),
                cwd: options.cwd,
                ignorePath: options.ignorePath,
                resolvePluginsRelativeTo: options.resolvePluginsRelativeTo,
                rulePaths: options.rulePaths,
                specificConfigPath: options.configFile,
                useEslintrc: options.useEslintrc,
                builtInRules,
                loadRules,
                getEslintRecommendedConfig: () => require(286) /* @eslint/js */.configs.recommended,
                getEslintAllConfig: () => require(286) /* @eslint/js */.configs.all
            });
            const fileEnumerator = new FileEnumerator({
                configArrayFactory,
                cwd: options.cwd,
                extensions: options.extensions,
                globInputPaths: options.globInputPaths,
                errorOnUnmatchedPattern: options.errorOnUnmatchedPattern,
                ignore: options.ignore
            });
            const lintResultCache = options.cache ? new LintResultCache(cacheFilePath, options.cacheStrategy) : null;
            const linter = new Linter({ cwd: options.cwd });
            /** @type {ConfigArray[]} */
            const lastConfigArrays = [configArrayFactory.getConfigArrayForFile()];
            // Store private data.
            internalSlotsMap.set(this, {
                additionalPluginPool,
                cacheFilePath,
                configArrayFactory,
                defaultIgnores: IgnorePattern.createDefaultIgnore(options.cwd),
                fileEnumerator,
                lastConfigArrays,
                lintResultCache,
                linter,
                options
            });
            // setup special filter for fixes
            if (options.fix && options.fixTypes && options.fixTypes.length > 0) {
                debug(`Using fix types ${options.fixTypes}`);
                // throw an error if any invalid fix types are found
                validateFixTypes(options.fixTypes);
                // convert to Set for faster lookup
                const fixTypes = new Set(options.fixTypes);
                // save original value of options.fix in case it's a function
                const originalFix = (typeof options.fix === "function")
                    ? options.fix : () => true;
                options.fix = message => shouldMessageBeFixed(message, lastConfigArrays, fixTypes) && originalFix(message);
            }
        }
        getRules() {
            const { lastConfigArrays } = internalSlotsMap.get(this);
            return new Map(function* () {
                yield* builtInRules;
                for (const configArray of lastConfigArrays) {
                    yield* configArray.pluginRules;
                }
            }());
        }
        /**
         * Returns results that only contains errors.
         * @param {LintResult[]} results The results to filter.
         * @returns {LintResult[]} The filtered results.
         */
        static getErrorResults(results) {
            const filtered = [];
            results.forEach(result => {
                const filteredMessages = result.messages.filter(isErrorMessage);
                const filteredSuppressedMessages = result.suppressedMessages.filter(isErrorMessage);
                if (filteredMessages.length > 0) {
                    filtered.push({
                        ...result,
                        messages: filteredMessages,
                        suppressedMessages: filteredSuppressedMessages,
                        errorCount: filteredMessages.length,
                        warningCount: 0,
                        fixableErrorCount: result.fixableErrorCount,
                        fixableWarningCount: 0
                    });
                }
            });
            return filtered;
        }
        /**
         * Outputs fixes from the given results to files.
         * @param {LintReport} report The report object created by CLIEngine.
         * @returns {void}
         */
        static outputFixes(report) {
            report.results.filter(result => Object.prototype.hasOwnProperty.call(result, "output")).forEach(result => {
                fs.writeFileSync(result.filePath, result.output);
            });
        }
        /**
         * Resolves the patterns passed into executeOnFiles() into glob-based patterns
         * for easier handling.
         * @param {string[]} patterns The file patterns passed on the command line.
         * @returns {string[]} The equivalent glob patterns.
         */
        resolveFileGlobPatterns(patterns) {
            const { options } = internalSlotsMap.get(this);
            if (options.globInputPaths === false) {
                return patterns.filter(Boolean);
            }
            const extensions = (options.extensions || [".js"]).map(ext => ext.replace(/^\./u, ""));
            const dirSuffix = `/**/*.{${extensions.join(",")}}`;
            return patterns.filter(Boolean).map(pathname => {
                const resolvedPath = path.resolve(options.cwd, pathname);
                const newPath = directoryExists(resolvedPath)
                    ? pathname.replace(/[/\\]$/u, "") + dirSuffix
                    : pathname;
                return path.normalize(newPath).replace(/\\/gu, "/");
            });
        }
        /**
         * Executes the current configuration on an array of file and directory names.
         * @param {string[]} patterns An array of file and directory names.
         * @throws {Error} As may be thrown by `fs.unlinkSync`.
         * @returns {LintReport} The results for all files that were linted.
         */
        executeOnFiles(patterns) {
            const { cacheFilePath, fileEnumerator, lastConfigArrays, lintResultCache, linter, options: { allowInlineConfig, cache, cwd, fix, reportUnusedDisableDirectives } } = internalSlotsMap.get(this);
            const results = [];
            const startTime = Date.now();
            // Clear the last used config arrays.
            lastConfigArrays.length = 0;
            // Delete cache file; should this do here?
            if (!cache) {
                try {
                    fs.unlinkSync(cacheFilePath);
                }
                catch (error) {
                    const errorCode = error && error.code;
                    // Ignore errors when no such file exists or file system is read only (and cache file does not exist)
                    if (errorCode !== "ENOENT" && !(errorCode === "EROFS" && !fs.existsSync(cacheFilePath))) {
                        throw error;
                    }
                }
            }
            // Iterate source code files.
            for (const { config, filePath, ignored } of fileEnumerator.iterateFiles(patterns)) {
                if (ignored) {
                    results.push(createIgnoreResult(filePath, cwd));
                    continue;
                }
                /*
                 * Store used configs for:
                 * - this method uses to collect used deprecated rules.
                 * - `getRules()` method uses to collect all loaded rules.
                 * - `--fix-type` option uses to get the loaded rule's meta data.
                 */
                if (!lastConfigArrays.includes(config)) {
                    lastConfigArrays.push(config);
                }
                // Skip if there is cached result.
                if (lintResultCache) {
                    const cachedResult = lintResultCache.getCachedLintResults(filePath, config);
                    if (cachedResult) {
                        const hadMessages = cachedResult.messages &&
                            cachedResult.messages.length > 0;
                        if (hadMessages && fix) {
                            debug(`Reprocessing cached file to allow autofix: ${filePath}`);
                        }
                        else {
                            debug(`Skipping file since it hasn't changed: ${filePath}`);
                            results.push(cachedResult);
                            continue;
                        }
                    }
                }
                // Do lint.
                const result = verifyText({
                    text: fs.readFileSync(filePath, "utf8"),
                    filePath,
                    config,
                    cwd,
                    fix,
                    allowInlineConfig,
                    reportUnusedDisableDirectives,
                    fileEnumerator,
                    linter
                });
                results.push(result);
                /*
                 * Store the lint result in the LintResultCache.
                 * NOTE: The LintResultCache will remove the file source and any
                 * other properties that are difficult to serialize, and will
                 * hydrate those properties back in on future lint runs.
                 */
                if (lintResultCache) {
                    lintResultCache.setCachedLintResults(filePath, config, result);
                }
            }
            // Persist the cache to disk.
            if (lintResultCache) {
                lintResultCache.reconcile();
            }
            debug(`Linting complete in: ${Date.now() - startTime}ms`);
            let usedDeprecatedRules;
            return {
                results,
                ...calculateStatsPerRun(results),
                // Initialize it lazily because CLI and `ESLint` API don't use it.
                get usedDeprecatedRules() {
                    if (!usedDeprecatedRules) {
                        usedDeprecatedRules = Array.from(iterateRuleDeprecationWarnings(lastConfigArrays));
                    }
                    return usedDeprecatedRules;
                }
            };
        }
        /**
         * Executes the current configuration on text.
         * @param {string} text A string of JavaScript code to lint.
         * @param {string} [filename] An optional string representing the texts filename.
         * @param {boolean} [warnIgnored] Always warn when a file is ignored
         * @returns {LintReport} The results for the linting.
         */
        executeOnText(text, filename, warnIgnored) {
            const { configArrayFactory, fileEnumerator, lastConfigArrays, linter, options: { allowInlineConfig, cwd, fix, reportUnusedDisableDirectives } } = internalSlotsMap.get(this);
            const results = [];
            const startTime = Date.now();
            const resolvedFilename = filename && path.resolve(cwd, filename);
            // Clear the last used config arrays.
            lastConfigArrays.length = 0;
            if (resolvedFilename && this.isPathIgnored(resolvedFilename)) {
                if (warnIgnored) {
                    results.push(createIgnoreResult(resolvedFilename, cwd));
                }
            }
            else {
                const config = configArrayFactory.getConfigArrayForFile(resolvedFilename || "__placeholder__.js");
                /*
                 * Store used configs for:
                 * - this method uses to collect used deprecated rules.
                 * - `getRules()` method uses to collect all loaded rules.
                 * - `--fix-type` option uses to get the loaded rule's meta data.
                 */
                lastConfigArrays.push(config);
                // Do lint.
                results.push(verifyText({
                    text,
                    filePath: resolvedFilename,
                    config,
                    cwd,
                    fix,
                    allowInlineConfig,
                    reportUnusedDisableDirectives,
                    fileEnumerator,
                    linter
                }));
            }
            debug(`Linting complete in: ${Date.now() - startTime}ms`);
            let usedDeprecatedRules;
            return {
                results,
                ...calculateStatsPerRun(results),
                // Initialize it lazily because CLI and `ESLint` API don't use it.
                get usedDeprecatedRules() {
                    if (!usedDeprecatedRules) {
                        usedDeprecatedRules = Array.from(iterateRuleDeprecationWarnings(lastConfigArrays));
                    }
                    return usedDeprecatedRules;
                }
            };
        }
        /**
         * Returns a configuration object for the given file based on the CLI options.
         * This is the same logic used by the ESLint CLI executable to determine
         * configuration for each file it processes.
         * @param {string} filePath The path of the file to retrieve a config object for.
         * @throws {Error} If filepath a directory path.
         * @returns {ConfigData} A configuration object for the file.
         */
        getConfigForFile(filePath) {
            const { configArrayFactory, options } = internalSlotsMap.get(this);
            const absolutePath = path.resolve(options.cwd, filePath);
            if (directoryExists(absolutePath)) {
                throw Object.assign(new Error("'filePath' should not be a directory path."), { messageTemplate: "print-config-with-directory-path" });
            }
            return configArrayFactory
                .getConfigArrayForFile(absolutePath)
                .extractConfig(absolutePath)
                .toCompatibleObjectAsConfigFileContent();
        }
        /**
         * Checks if a given path is ignored by ESLint.
         * @param {string} filePath The path of the file to check.
         * @returns {boolean} Whether or not the given path is ignored.
         */
        isPathIgnored(filePath) {
            const { configArrayFactory, defaultIgnores, options: { cwd, ignore } } = internalSlotsMap.get(this);
            const absolutePath = path.resolve(cwd, filePath);
            if (ignore) {
                const config = configArrayFactory
                    .getConfigArrayForFile(absolutePath)
                    .extractConfig(absolutePath);
                const ignores = config.ignores || defaultIgnores;
                return ignores(absolutePath);
            }
            return defaultIgnores(absolutePath);
        }
        /**
         * Returns the formatter representing the given format or null if the `format` is not a string.
         * @param {string} [format] The name of the format to load or the path to a
         *      custom formatter.
         * @throws {any} As may be thrown by requiring of formatter
         * @returns {(FormatterFunction|null)} The formatter function or null if the `format` is not a string.
         */
        getFormatter(format) {
            // default is stylish
            const resolvedFormatName = format || "stylish";
            // only strings are valid formatters
            if (typeof resolvedFormatName === "string") {
                // replace \ with / for Windows compatibility
                const normalizedFormatName = resolvedFormatName.replace(/\\/gu, "/");
                const slots = internalSlotsMap.get(this);
                const cwd = slots ? slots.options.cwd : process.cwd();
                const namespace = naming.getNamespaceFromTerm(normalizedFormatName);
                let formatterPath;
                // if there's a slash, then it's a file (TODO: this check seems dubious for scoped npm packages)
                if (!namespace && normalizedFormatName.includes("/")) {
                    formatterPath = path.resolve(cwd, normalizedFormatName);
                }
                else {
                    try {
                        const npmFormat = naming.normalizePackageName(normalizedFormatName, "eslint-formatter");
                        formatterPath = ModuleResolver.resolve(npmFormat, path.join(cwd, "__placeholder__.js"));
                    }
                    catch {
                        formatterPath = path.resolve(__dirname, "formatters", normalizedFormatName);
                    }
                }
                try {
                    return require(formatterPath);
                }
                catch (ex) {
                    if (format === "table" || format === "codeframe") {
                        ex.message = `The ${format} formatter is no longer part of core ESLint. Install it manually with \`npm install -D eslint-formatter-${format}\``;
                    }
                    else {
                        ex.message = `There was a problem loading formatter: ${formatterPath}\nError: ${ex.message}`;
                    }
                    throw ex;
                }
            }
            else {
                return null;
            }
        }
    }
    CLIEngine.version = pkg.version;
    CLIEngine.getFormatter = CLIEngine.prototype.getFormatter;
    module.exports = {
        CLIEngine,
        /**
         * Get the internal slots of a given CLIEngine instance for tests.
         * @param {CLIEngine} instance The CLIEngine instance to get.
         * @returns {CLIEngineInternalSlots} The internal slots.
         */
        getCLIEngineInternalSlots(instance) {
            return internalSlotsMap.get(instance);
        }
    };
},
/* eslint/conf/default-cli-options.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Default CLIEngineOptions.
     * @author Ian VanSchooten
     */
    "use strict";
    module.exports = {
        configFile: null,
        baseConfig: false,
        rulePaths: [],
        useEslintrc: true,
        envs: [],
        globals: [],
        extensions: null,
        ignore: true,
        ignorePath: void 0,
        cache: false,
        /*
         * in order to honor the cacheFile option if specified
         * this option should not have a default value otherwise
         * it will always be used
         */
        cacheLocation: "",
        cacheFile: ".eslintcache",
        cacheStrategy: "metadata",
        fix: false,
        allowInlineConfig: true,
        reportUnusedDisableDirectives: void 0,
        globInputPaths: true
    };
},
/* eslint/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "eslint",
        "version": "8.36.0",
        "author": "Nicholas C. Zakas <nicholas+npm@nczconsulting.com>",
        "description": "An AST-based pattern checker for JavaScript.",
        "bin": {
            "eslint": "./bin/eslint.js"
        },
        "main": "./lib/api.js",
        "exports": {
            "./package.json": "./package.json",
            ".": "./lib/api.js",
            "./use-at-your-own-risk": "./lib/unsupported-api.js"
        },
        "scripts": {
            "build:docs:update-links": "node tools/fetch-docs-links.js",
            "build:site": "node Makefile.js gensite",
            "build:webpack": "node Makefile.js webpack",
            "build:readme": "node tools/update-readme.js",
            "lint": "node Makefile.js lint",
            "lint:docs:js": "node Makefile.js lintDocsJS",
            "lint:fix": "node Makefile.js lint -- fix",
            "lint:fix:docs:js": "node Makefile.js lintDocsJS -- fix",
            "release:generate:alpha": "node Makefile.js generatePrerelease -- alpha",
            "release:generate:beta": "node Makefile.js generatePrerelease -- beta",
            "release:generate:latest": "node Makefile.js generateRelease",
            "release:generate:rc": "node Makefile.js generatePrerelease -- rc",
            "release:publish": "node Makefile.js publishRelease",
            "test": "node Makefile.js test",
            "test:cli": "mocha",
            "test:fuzz": "node Makefile.js fuzz",
            "test:performance": "node Makefile.js perf"
        },
        "gitHooks": {
            "pre-commit": "lint-staged"
        },
        "lint-staged": {
            "*.js": "eslint --fix",
            "*.md": "markdownlint --fix",
            "lib/rules/*.js": [
                "node tools/update-eslint-all.js",
                "git add packages/js/src/configs/eslint-all.js"
            ],
            "docs/src/rules/*.md": [
                "node tools/fetch-docs-links.js",
                "git add docs/src/_data/further_reading_links.json"
            ],
            "docs/**/*.svg": "npx svgo -r --multipass"
        },
        "files": [
            "LICENSE",
            "README.md",
            "bin",
            "conf",
            "lib",
            "messages"
        ],
        "repository": "eslint/eslint",
        "funding": "https://opencollective.com/eslint",
        "homepage": "https://eslint.org",
        "bugs": "https://github.com/eslint/eslint/issues/",
        "dependencies": {
            "@eslint-community/eslint-utils": "^4.2.0",
            "@eslint-community/regexpp": "^4.4.0",
            "@eslint/eslintrc": "^2.0.1",
            "@eslint/js": "8.36.0",
            "@humanwhocodes/config-array": "^0.11.8",
            "@humanwhocodes/module-importer": "^1.0.1",
            "@nodelib/fs.walk": "^1.2.8",
            "ajv": "^6.10.0",
            "chalk": "^4.0.0",
            "cross-spawn": "^7.0.2",
            "debug": "^4.3.2",
            "doctrine": "^3.0.0",
            "escape-string-regexp": "^4.0.0",
            "eslint-scope": "^7.1.1",
            "eslint-visitor-keys": "^3.3.0",
            "espree": "^9.5.0",
            "esquery": "^1.4.2",
            "esutils": "^2.0.2",
            "fast-deep-equal": "^3.1.3",
            "file-entry-cache": "^6.0.1",
            "find-up": "^5.0.0",
            "glob-parent": "^6.0.2",
            "globals": "^13.19.0",
            "grapheme-splitter": "^1.0.4",
            "ignore": "^5.2.0",
            "import-fresh": "^3.0.0",
            "imurmurhash": "^0.1.4",
            "is-glob": "^4.0.0",
            "is-path-inside": "^3.0.3",
            "js-sdsl": "^4.1.4",
            "js-yaml": "^4.1.0",
            "json-stable-stringify-without-jsonify": "^1.0.1",
            "levn": "^0.4.1",
            "lodash.merge": "^4.6.2",
            "minimatch": "^3.1.2",
            "natural-compare": "^1.4.0",
            "optionator": "^0.9.1",
            "strip-ansi": "^6.0.1",
            "strip-json-comments": "^3.1.0",
            "text-table": "^0.2.0"
        },
        "devDependencies": {
            "@babel/core": "^7.4.3",
            "@babel/preset-env": "^7.4.3",
            "babel-loader": "^8.0.5",
            "c8": "^7.12.0",
            "chai": "^4.0.1",
            "cheerio": "^0.22.0",
            "common-tags": "^1.8.0",
            "core-js": "^3.1.3",
            "ejs": "^3.0.2",
            "eslint": "file:.",
            "eslint-config-eslint": "file:packages/eslint-config-eslint",
            "eslint-plugin-eslint-comments": "^3.2.0",
            "eslint-plugin-eslint-plugin": "^4.4.0",
            "eslint-plugin-internal-rules": "file:tools/internal-rules",
            "eslint-plugin-jsdoc": "^38.1.6",
            "eslint-plugin-n": "^15.2.4",
            "eslint-plugin-unicorn": "^42.0.0",
            "eslint-release": "^3.2.0",
            "eslump": "^3.0.0",
            "esprima": "^4.0.1",
            "fast-glob": "^3.2.11",
            "fs-teardown": "^0.1.3",
            "glob": "^7.1.6",
            "got": "^11.8.3",
            "gray-matter": "^4.0.3",
            "karma": "^6.1.1",
            "karma-chrome-launcher": "^3.1.0",
            "karma-mocha": "^2.0.1",
            "karma-mocha-reporter": "^2.2.5",
            "karma-webpack": "^5.0.0",
            "lint-staged": "^11.0.0",
            "load-perf": "^0.2.0",
            "markdownlint": "^0.25.1",
            "markdownlint-cli": "^0.31.1",
            "marked": "^4.0.8",
            "memfs": "^3.0.1",
            "metascraper": "^5.25.7",
            "metascraper-description": "^5.25.7",
            "metascraper-image": "^5.29.3",
            "metascraper-logo": "^5.25.7",
            "metascraper-logo-favicon": "^5.25.7",
            "metascraper-title": "^5.25.7",
            "mocha": "^8.3.2",
            "mocha-junit-reporter": "^2.0.0",
            "node-polyfill-webpack-plugin": "^1.0.3",
            "npm-license": "^0.3.3",
            "pirates": "^4.0.5",
            "progress": "^2.0.3",
            "proxyquire": "^2.0.1",
            "puppeteer": "^13.7.0",
            "recast": "^0.20.4",
            "regenerator-runtime": "^0.13.2",
            "semver": "^7.3.5",
            "shelljs": "^0.8.2",
            "sinon": "^11.0.0",
            "temp": "^0.9.0",
            "webpack": "^5.23.0",
            "webpack-cli": "^4.5.0",
            "yorkie": "^2.0.0"
        },
        "keywords": [
            "ast",
            "lint",
            "javascript",
            "ecmascript",
            "espree"
        ],
        "license": "MIT",
        "engines": {
            "node": "^12.22.0 || ^14.17.0 || >=16.0.0"
        }
    };
    module.exports = json;
},
/* @eslint/eslintrc/dist/eslintrc.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    var debugOrig = require(72) /* debug */;
    var fs = require('fs');
    var importFresh = require(223) /* import-fresh */;
    var Module = require('module');
    var path = require('path');
    var stripComments = require(227) /* strip-json-comments */;
    var assert = require('assert');
    var ignore = require(228) /* ignore */;
    var util = require('util');
    var minimatch = require(229) /* minimatch */;
    var Ajv = require(233) /* ajv */;
    var globals = require(279) /* globals */;
    var os = require('os');
    function _interopDefaultLegacy(e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }
    var debugOrig__default = /*#__PURE__*/ _interopDefaultLegacy(debugOrig);
    var fs__default = /*#__PURE__*/ _interopDefaultLegacy(fs);
    var importFresh__default = /*#__PURE__*/ _interopDefaultLegacy(importFresh);
    var Module__default = /*#__PURE__*/ _interopDefaultLegacy(Module);
    var path__default = /*#__PURE__*/ _interopDefaultLegacy(path);
    var stripComments__default = /*#__PURE__*/ _interopDefaultLegacy(stripComments);
    var assert__default = /*#__PURE__*/ _interopDefaultLegacy(assert);
    var ignore__default = /*#__PURE__*/ _interopDefaultLegacy(ignore);
    var util__default = /*#__PURE__*/ _interopDefaultLegacy(util);
    var minimatch__default = /*#__PURE__*/ _interopDefaultLegacy(minimatch);
    var Ajv__default = /*#__PURE__*/ _interopDefaultLegacy(Ajv);
    var globals__default = /*#__PURE__*/ _interopDefaultLegacy(globals);
    var os__default = /*#__PURE__*/ _interopDefaultLegacy(os);
    /**
     * @fileoverview `IgnorePattern` class.
     *
     * `IgnorePattern` class has the set of glob patterns and the base path.
     *
     * It provides two static methods.
     *
     * - `IgnorePattern.createDefaultIgnore(cwd)`
     *      Create the default predicate function.
     * - `IgnorePattern.createIgnore(ignorePatterns)`
     *      Create the predicate function from multiple `IgnorePattern` objects.
     *
     * It provides two properties and a method.
     *
     * - `patterns`
     *      The glob patterns that ignore to lint.
     * - `basePath`
     *      The base path of the glob patterns. If absolute paths existed in the
     *      glob patterns, those are handled as relative paths to the base path.
     * - `getPatternsRelativeTo(basePath)`
     *      Get `patterns` as modified for a given base path. It modifies the
     *      absolute paths in the patterns as prepending the difference of two base
     *      paths.
     *
     * `ConfigArrayFactory` creates `IgnorePattern` objects when it processes
     * `ignorePatterns` properties.
     *
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    const debug$3 = debugOrig__default["default"]("eslintrc:ignore-pattern");
    /** @typedef {ReturnType<import("ignore").default>} Ignore */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Get the path to the common ancestor directory of given paths.
     * @param {string[]} sourcePaths The paths to calculate the common ancestor.
     * @returns {string} The path to the common ancestor directory.
     */
    function getCommonAncestorPath(sourcePaths) {
        let result = sourcePaths[0];
        for (let i = 1; i < sourcePaths.length; ++i) {
            const a = result;
            const b = sourcePaths[i];
            // Set the shorter one (it's the common ancestor if one includes the other).
            result = a.length < b.length ? a : b;
            // Set the common ancestor.
            for (let j = 0, lastSepPos = 0; j < a.length && j < b.length; ++j) {
                if (a[j] !== b[j]) {
                    result = a.slice(0, lastSepPos);
                    break;
                }
                if (a[j] === path__default["default"].sep) {
                    lastSepPos = j;
                }
            }
        }
        let resolvedResult = result || path__default["default"].sep;
        // if Windows common ancestor is root of drive must have trailing slash to be absolute.
        if (resolvedResult && resolvedResult.endsWith(":") && process.platform === "win32") {
            resolvedResult += path__default["default"].sep;
        }
        return resolvedResult;
    }
    /**
     * Make relative path.
     * @param {string} from The source path to get relative path.
     * @param {string} to The destination path to get relative path.
     * @returns {string} The relative path.
     */
    function relative(from, to) {
        const relPath = path__default["default"].relative(from, to);
        if (path__default["default"].sep === "/") {
            return relPath;
        }
        return relPath.split(path__default["default"].sep).join("/");
    }
    /**
     * Get the trailing slash if existed.
     * @param {string} filePath The path to check.
     * @returns {string} The trailing slash if existed.
     */
    function dirSuffix(filePath) {
        const isDir = (filePath.endsWith(path__default["default"].sep) ||
            (process.platform === "win32" && filePath.endsWith("/")));
        return isDir ? "/" : "";
    }
    const DefaultPatterns = Object.freeze(["/**/node_modules/*"]);
    const DotPatterns = Object.freeze([".*", "!.eslintrc.*", "!../"]);
    //------------------------------------------------------------------------------
    // Public
    //------------------------------------------------------------------------------
    class IgnorePattern {
        /**
         * The default patterns.
         * @type {string[]}
         */
        static get DefaultPatterns() {
            return DefaultPatterns;
        }
        /**
         * Create the default predicate function.
         * @param {string} cwd The current working directory.
         * @returns {((filePath:string, dot:boolean) => boolean) & {basePath:string; patterns:string[]}}
         * The preficate function.
         * The first argument is an absolute path that is checked.
         * The second argument is the flag to not ignore dotfiles.
         * If the predicate function returned `true`, it means the path should be ignored.
         */
        static createDefaultIgnore(cwd) {
            return this.createIgnore([new IgnorePattern(DefaultPatterns, cwd)]);
        }
        /**
         * Create the predicate function from multiple `IgnorePattern` objects.
         * @param {IgnorePattern[]} ignorePatterns The list of ignore patterns.
         * @returns {((filePath:string, dot?:boolean) => boolean) & {basePath:string; patterns:string[]}}
         * The preficate function.
         * The first argument is an absolute path that is checked.
         * The second argument is the flag to not ignore dotfiles.
         * If the predicate function returned `true`, it means the path should be ignored.
         */
        static createIgnore(ignorePatterns) {
            debug$3("Create with: %o", ignorePatterns);
            const basePath = getCommonAncestorPath(ignorePatterns.map(p => p.basePath));
            const patterns = [].concat(...ignorePatterns.map(p => p.getPatternsRelativeTo(basePath)));
            const ig = ignore__default["default"]({ allowRelativePaths: true }).add([...DotPatterns, ...patterns]);
            const dotIg = ignore__default["default"]({ allowRelativePaths: true }).add(patterns);
            debug$3("  processed: %o", { basePath, patterns });
            return Object.assign((filePath, dot = false) => {
                assert__default["default"](path__default["default"].isAbsolute(filePath), "'filePath' should be an absolute path.");
                const relPathRaw = relative(basePath, filePath);
                const relPath = relPathRaw && (relPathRaw + dirSuffix(filePath));
                const adoptedIg = dot ? dotIg : ig;
                const result = relPath !== "" && adoptedIg.ignores(relPath);
                debug$3("Check", { filePath, dot, relativePath: relPath, result });
                return result;
            }, { basePath, patterns });
        }
        /**
         * Initialize a new `IgnorePattern` instance.
         * @param {string[]} patterns The glob patterns that ignore to lint.
         * @param {string} basePath The base path of `patterns`.
         */
        constructor(patterns, basePath) {
            assert__default["default"](path__default["default"].isAbsolute(basePath), "'basePath' should be an absolute path.");
            /**
             * The glob patterns that ignore to lint.
             * @type {string[]}
             */
            this.patterns = patterns;
            /**
             * The base path of `patterns`.
             * @type {string}
             */
            this.basePath = basePath;
            /**
             * If `true` then patterns which don't start with `/` will match the paths to the outside of `basePath`. Defaults to `false`.
             *
             * It's set `true` for `.eslintignore`, `package.json`, and `--ignore-path` for backward compatibility.
             * It's `false` as-is for `ignorePatterns` property in config files.
             * @type {boolean}
             */
            this.loose = false;
        }
        /**
         * Get `patterns` as modified for a given base path. It modifies the
         * absolute paths in the patterns as prepending the difference of two base
         * paths.
         * @param {string} newBasePath The base path.
         * @returns {string[]} Modifired patterns.
         */
        getPatternsRelativeTo(newBasePath) {
            assert__default["default"](path__default["default"].isAbsolute(newBasePath), "'newBasePath' should be an absolute path.");
            const { basePath, loose, patterns } = this;
            if (newBasePath === basePath) {
                return patterns;
            }
            const prefix = `/${relative(newBasePath, basePath)}`;
            return patterns.map(pattern => {
                const negative = pattern.startsWith("!");
                const head = negative ? "!" : "";
                const body = negative ? pattern.slice(1) : pattern;
                if (body.startsWith("/") || body.startsWith("../")) {
                    return `${head}${prefix}${body}`;
                }
                return loose ? pattern : `${head}${prefix}/**/${body}`;
            });
        }
    }
    /**
     * @fileoverview `ExtractedConfig` class.
     *
     * `ExtractedConfig` class expresses a final configuration for a specific file.
     *
     * It provides one method.
     *
     * - `toCompatibleObjectAsConfigFileContent()`
     *      Convert this configuration to the compatible object as the content of
     *      config files. It converts the loaded parser and plugins to strings.
     *      `CLIEngine#getConfigForFile(filePath)` method uses this method.
     *
     * `ConfigArray#extractConfig(filePath)` creates a `ExtractedConfig` instance.
     *
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    // For VSCode intellisense
    /** @typedef {import("../../shared/types").ConfigData} ConfigData */
    /** @typedef {import("../../shared/types").GlobalConf} GlobalConf */
    /** @typedef {import("../../shared/types").SeverityConf} SeverityConf */
    /** @typedef {import("./config-dependency").DependentParser} DependentParser */
    /** @typedef {import("./config-dependency").DependentPlugin} DependentPlugin */
    /**
     * Check if `xs` starts with `ys`.
     * @template T
     * @param {T[]} xs The array to check.
     * @param {T[]} ys The array that may be the first part of `xs`.
     * @returns {boolean} `true` if `xs` starts with `ys`.
     */
    function startsWith(xs, ys) {
        return xs.length >= ys.length && ys.every((y, i) => y === xs[i]);
    }
    /**
     * The class for extracted config data.
     */
    class ExtractedConfig {
        constructor() {
            /**
             * The config name what `noInlineConfig` setting came from.
             * @type {string}
             */
            this.configNameOfNoInlineConfig = "";
            /**
             * Environments.
             * @type {Record<string, boolean>}
             */
            this.env = {};
            /**
             * Global variables.
             * @type {Record<string, GlobalConf>}
             */
            this.globals = {};
            /**
             * The glob patterns that ignore to lint.
             * @type {(((filePath:string, dot?:boolean) => boolean) & { basePath:string; patterns:string[] }) | undefined}
             */
            this.ignores = void 0;
            /**
             * The flag that disables directive comments.
             * @type {boolean|undefined}
             */
            this.noInlineConfig = void 0;
            /**
             * Parser definition.
             * @type {DependentParser|null}
             */
            this.parser = null;
            /**
             * Options for the parser.
             * @type {Object}
             */
            this.parserOptions = {};
            /**
             * Plugin definitions.
             * @type {Record<string, DependentPlugin>}
             */
            this.plugins = {};
            /**
             * Processor ID.
             * @type {string|null}
             */
            this.processor = null;
            /**
             * The flag that reports unused `eslint-disable` directive comments.
             * @type {boolean|undefined}
             */
            this.reportUnusedDisableDirectives = void 0;
            /**
             * Rule settings.
             * @type {Record<string, [SeverityConf, ...any[]]>}
             */
            this.rules = {};
            /**
             * Shared settings.
             * @type {Object}
             */
            this.settings = {};
        }
        /**
         * Convert this config to the compatible object as a config file content.
         * @returns {ConfigData} The converted object.
         */
        toCompatibleObjectAsConfigFileContent() {
            const { 
            /* eslint-disable no-unused-vars */
            configNameOfNoInlineConfig: _ignore1, processor: _ignore2, 
            /* eslint-enable no-unused-vars */
            ignores, ...config } = this;
            config.parser = config.parser && config.parser.filePath;
            config.plugins = Object.keys(config.plugins).filter(Boolean).reverse();
            config.ignorePatterns = ignores ? ignores.patterns : [];
            // Strip the default patterns from `ignorePatterns`.
            if (startsWith(config.ignorePatterns, IgnorePattern.DefaultPatterns)) {
                config.ignorePatterns =
                    config.ignorePatterns.slice(IgnorePattern.DefaultPatterns.length);
            }
            return config;
        }
    }
    /**
     * @fileoverview `ConfigArray` class.
     *
     * `ConfigArray` class expresses the full of a configuration. It has the entry
     * config file, base config files that were extended, loaded parsers, and loaded
     * plugins.
     *
     * `ConfigArray` class provides three properties and two methods.
     *
     * - `pluginEnvironments`
     * - `pluginProcessors`
     * - `pluginRules`
     *      The `Map` objects that contain the members of all plugins that this
     *      config array contains. Those map objects don't have mutation methods.
     *      Those keys are the member ID such as `pluginId/memberName`.
     * - `isRoot()`
     *      If `true` then this configuration has `root:true` property.
     * - `extractConfig(filePath)`
     *      Extract the final configuration for a given file. This means merging
     *      every config array element which that `criteria` property matched. The
     *      `filePath` argument must be an absolute path.
     *
     * `ConfigArrayFactory` provides the loading logic of config files.
     *
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    // Define types for VSCode IntelliSense.
    /** @typedef {import("../../shared/types").Environment} Environment */
    /** @typedef {import("../../shared/types").GlobalConf} GlobalConf */
    /** @typedef {import("../../shared/types").RuleConf} RuleConf */
    /** @typedef {import("../../shared/types").Rule} Rule */
    /** @typedef {import("../../shared/types").Plugin} Plugin */
    /** @typedef {import("../../shared/types").Processor} Processor */
    /** @typedef {import("./config-dependency").DependentParser} DependentParser */
    /** @typedef {import("./config-dependency").DependentPlugin} DependentPlugin */
    /** @typedef {import("./override-tester")["OverrideTester"]} OverrideTester */
    /**
     * @typedef {Object} ConfigArrayElement
     * @property {string} name The name of this config element.
     * @property {string} filePath The path to the source file of this config element.
     * @property {InstanceType<OverrideTester>|null} criteria The tester for the `files` and `excludedFiles` of this config element.
     * @property {Record<string, boolean>|undefined} env The environment settings.
     * @property {Record<string, GlobalConf>|undefined} globals The global variable settings.
     * @property {IgnorePattern|undefined} ignorePattern The ignore patterns.
     * @property {boolean|undefined} noInlineConfig The flag that disables directive comments.
     * @property {DependentParser|undefined} parser The parser loader.
     * @property {Object|undefined} parserOptions The parser options.
     * @property {Record<string, DependentPlugin>|undefined} plugins The plugin loaders.
     * @property {string|undefined} processor The processor name to refer plugin's processor.
     * @property {boolean|undefined} reportUnusedDisableDirectives The flag to report unused `eslint-disable` comments.
     * @property {boolean|undefined} root The flag to express root.
     * @property {Record<string, RuleConf>|undefined} rules The rule settings
     * @property {Object|undefined} settings The shared settings.
     * @property {"config" | "ignore" | "implicit-processor"} type The element type.
     */
    /**
     * @typedef {Object} ConfigArrayInternalSlots
     * @property {Map<string, ExtractedConfig>} cache The cache to extract configs.
     * @property {ReadonlyMap<string, Environment>|null} envMap The map from environment ID to environment definition.
     * @property {ReadonlyMap<string, Processor>|null} processorMap The map from processor ID to environment definition.
     * @property {ReadonlyMap<string, Rule>|null} ruleMap The map from rule ID to rule definition.
     */
    /** @type {WeakMap<ConfigArray, ConfigArrayInternalSlots>} */
    const internalSlotsMap$2 = new class extends WeakMap {
        get(key) {
            let value = super.get(key);
            if (!value) {
                value = {
                    cache: new Map(),
                    envMap: null,
                    processorMap: null,
                    ruleMap: null
                };
                super.set(key, value);
            }
            return value;
        }
    }();
    /**
     * Get the indices which are matched to a given file.
     * @param {ConfigArrayElement[]} elements The elements.
     * @param {string} filePath The path to a target file.
     * @returns {number[]} The indices.
     */
    function getMatchedIndices(elements, filePath) {
        const indices = [];
        for (let i = elements.length - 1; i >= 0; --i) {
            const element = elements[i];
            if (!element.criteria || (filePath && element.criteria.test(filePath))) {
                indices.push(i);
            }
        }
        return indices;
    }
    /**
     * Check if a value is a non-null object.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if the value is a non-null object.
     */
    function isNonNullObject(x) {
        return typeof x === "object" && x !== null;
    }
    /**
     * Merge two objects.
     *
     * Assign every property values of `y` to `x` if `x` doesn't have the property.
     * If `x`'s property value is an object, it does recursive.
     * @param {Object} target The destination to merge
     * @param {Object|undefined} source The source to merge.
     * @returns {void}
     */
    function mergeWithoutOverwrite(target, source) {
        if (!isNonNullObject(source)) {
            return;
        }
        for (const key of Object.keys(source)) {
            if (key === "__proto__") {
                continue;
            }
            if (isNonNullObject(target[key])) {
                mergeWithoutOverwrite(target[key], source[key]);
            }
            else if (target[key] === void 0) {
                if (isNonNullObject(source[key])) {
                    target[key] = Array.isArray(source[key]) ? [] : {};
                    mergeWithoutOverwrite(target[key], source[key]);
                }
                else if (source[key] !== void 0) {
                    target[key] = source[key];
                }
            }
        }
    }
    /**
     * The error for plugin conflicts.
     */
    class PluginConflictError extends Error {
        /**
         * Initialize this error object.
         * @param {string} pluginId The plugin ID.
         * @param {{filePath:string, importerName:string}[]} plugins The resolved plugins.
         */
        constructor(pluginId, plugins) {
            super(`Plugin "${pluginId}" was conflicted between ${plugins.map(p => `"${p.importerName}"`).join(" and ")}.`);
            this.messageTemplate = "plugin-conflict";
            this.messageData = { pluginId, plugins };
        }
    }
    /**
     * Merge plugins.
     * `target`'s definition is prior to `source`'s.
     * @param {Record<string, DependentPlugin>} target The destination to merge
     * @param {Record<string, DependentPlugin>|undefined} source The source to merge.
     * @returns {void}
     */
    function mergePlugins(target, source) {
        if (!isNonNullObject(source)) {
            return;
        }
        for (const key of Object.keys(source)) {
            if (key === "__proto__") {
                continue;
            }
            const targetValue = target[key];
            const sourceValue = source[key];
            // Adopt the plugin which was found at first.
            if (targetValue === void 0) {
                if (sourceValue.error) {
                    throw sourceValue.error;
                }
                target[key] = sourceValue;
            }
            else if (sourceValue.filePath !== targetValue.filePath) {
                throw new PluginConflictError(key, [
                    {
                        filePath: targetValue.filePath,
                        importerName: targetValue.importerName
                    },
                    {
                        filePath: sourceValue.filePath,
                        importerName: sourceValue.importerName
                    }
                ]);
            }
        }
    }
    /**
     * Merge rule configs.
     * `target`'s definition is prior to `source`'s.
     * @param {Record<string, Array>} target The destination to merge
     * @param {Record<string, RuleConf>|undefined} source The source to merge.
     * @returns {void}
     */
    function mergeRuleConfigs(target, source) {
        if (!isNonNullObject(source)) {
            return;
        }
        for (const key of Object.keys(source)) {
            if (key === "__proto__") {
                continue;
            }
            const targetDef = target[key];
            const sourceDef = source[key];
            // Adopt the rule config which was found at first.
            if (targetDef === void 0) {
                if (Array.isArray(sourceDef)) {
                    target[key] = [...sourceDef];
                }
                else {
                    target[key] = [sourceDef];
                }
                /*
                 * If the first found rule config is severity only and the current rule
                 * config has options, merge the severity and the options.
                 */
            }
            else if (targetDef.length === 1 &&
                Array.isArray(sourceDef) &&
                sourceDef.length >= 2) {
                targetDef.push(...sourceDef.slice(1));
            }
        }
    }
    /**
     * Create the extracted config.
     * @param {ConfigArray} instance The config elements.
     * @param {number[]} indices The indices to use.
     * @returns {ExtractedConfig} The extracted config.
     */
    function createConfig(instance, indices) {
        const config = new ExtractedConfig();
        const ignorePatterns = [];
        // Merge elements.
        for (const index of indices) {
            const element = instance[index];
            // Adopt the parser which was found at first.
            if (!config.parser && element.parser) {
                if (element.parser.error) {
                    throw element.parser.error;
                }
                config.parser = element.parser;
            }
            // Adopt the processor which was found at first.
            if (!config.processor && element.processor) {
                config.processor = element.processor;
            }
            // Adopt the noInlineConfig which was found at first.
            if (config.noInlineConfig === void 0 && element.noInlineConfig !== void 0) {
                config.noInlineConfig = element.noInlineConfig;
                config.configNameOfNoInlineConfig = element.name;
            }
            // Adopt the reportUnusedDisableDirectives which was found at first.
            if (config.reportUnusedDisableDirectives === void 0 && element.reportUnusedDisableDirectives !== void 0) {
                config.reportUnusedDisableDirectives = element.reportUnusedDisableDirectives;
            }
            // Collect ignorePatterns
            if (element.ignorePattern) {
                ignorePatterns.push(element.ignorePattern);
            }
            // Merge others.
            mergeWithoutOverwrite(config.env, element.env);
            mergeWithoutOverwrite(config.globals, element.globals);
            mergeWithoutOverwrite(config.parserOptions, element.parserOptions);
            mergeWithoutOverwrite(config.settings, element.settings);
            mergePlugins(config.plugins, element.plugins);
            mergeRuleConfigs(config.rules, element.rules);
        }
        // Create the predicate function for ignore patterns.
        if (ignorePatterns.length > 0) {
            config.ignores = IgnorePattern.createIgnore(ignorePatterns.reverse());
        }
        return config;
    }
    /**
     * Collect definitions.
     * @template T, U
     * @param {string} pluginId The plugin ID for prefix.
     * @param {Record<string,T>} defs The definitions to collect.
     * @param {Map<string, U>} map The map to output.
     * @param {function(T): U} [normalize] The normalize function for each value.
     * @returns {void}
     */
    function collect(pluginId, defs, map, normalize) {
        if (defs) {
            const prefix = pluginId && `${pluginId}/`;
            for (const [key, value] of Object.entries(defs)) {
                map.set(`${prefix}${key}`, normalize ? normalize(value) : value);
            }
        }
    }
    /**
     * Normalize a rule definition.
     * @param {Function|Rule} rule The rule definition to normalize.
     * @returns {Rule} The normalized rule definition.
     */
    function normalizePluginRule(rule) {
        return typeof rule === "function" ? { create: rule } : rule;
    }
    /**
     * Delete the mutation methods from a given map.
     * @param {Map<any, any>} map The map object to delete.
     * @returns {void}
     */
    function deleteMutationMethods(map) {
        Object.defineProperties(map, {
            clear: { configurable: true, value: void 0 },
            delete: { configurable: true, value: void 0 },
            set: { configurable: true, value: void 0 }
        });
    }
    /**
     * Create `envMap`, `processorMap`, `ruleMap` with the plugins in the config array.
     * @param {ConfigArrayElement[]} elements The config elements.
     * @param {ConfigArrayInternalSlots} slots The internal slots.
     * @returns {void}
     */
    function initPluginMemberMaps(elements, slots) {
        const processed = new Set();
        slots.envMap = new Map();
        slots.processorMap = new Map();
        slots.ruleMap = new Map();
        for (const element of elements) {
            if (!element.plugins) {
                continue;
            }
            for (const [pluginId, value] of Object.entries(element.plugins)) {
                const plugin = value.definition;
                if (!plugin || processed.has(pluginId)) {
                    continue;
                }
                processed.add(pluginId);
                collect(pluginId, plugin.environments, slots.envMap);
                collect(pluginId, plugin.processors, slots.processorMap);
                collect(pluginId, plugin.rules, slots.ruleMap, normalizePluginRule);
            }
        }
        deleteMutationMethods(slots.envMap);
        deleteMutationMethods(slots.processorMap);
        deleteMutationMethods(slots.ruleMap);
    }
    /**
     * Create `envMap`, `processorMap`, `ruleMap` with the plugins in the config array.
     * @param {ConfigArray} instance The config elements.
     * @returns {ConfigArrayInternalSlots} The extracted config.
     */
    function ensurePluginMemberMaps(instance) {
        const slots = internalSlotsMap$2.get(instance);
        if (!slots.ruleMap) {
            initPluginMemberMaps(instance, slots);
        }
        return slots;
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * The Config Array.
     *
     * `ConfigArray` instance contains all settings, parsers, and plugins.
     * You need to call `ConfigArray#extractConfig(filePath)` method in order to
     * extract, merge and get only the config data which is related to an arbitrary
     * file.
     * @extends {Array<ConfigArrayElement>}
     */
    class ConfigArray extends Array {
        /**
         * Get the plugin environments.
         * The returned map cannot be mutated.
         * @type {ReadonlyMap<string, Environment>} The plugin environments.
         */
        get pluginEnvironments() {
            return ensurePluginMemberMaps(this).envMap;
        }
        /**
         * Get the plugin processors.
         * The returned map cannot be mutated.
         * @type {ReadonlyMap<string, Processor>} The plugin processors.
         */
        get pluginProcessors() {
            return ensurePluginMemberMaps(this).processorMap;
        }
        /**
         * Get the plugin rules.
         * The returned map cannot be mutated.
         * @returns {ReadonlyMap<string, Rule>} The plugin rules.
         */
        get pluginRules() {
            return ensurePluginMemberMaps(this).ruleMap;
        }
        /**
         * Check if this config has `root` flag.
         * @returns {boolean} `true` if this config array is root.
         */
        isRoot() {
            for (let i = this.length - 1; i >= 0; --i) {
                const root = this[i].root;
                if (typeof root === "boolean") {
                    return root;
                }
            }
            return false;
        }
        /**
         * Extract the config data which is related to a given file.
         * @param {string} filePath The absolute path to the target file.
         * @returns {ExtractedConfig} The extracted config data.
         */
        extractConfig(filePath) {
            const { cache } = internalSlotsMap$2.get(this);
            const indices = getMatchedIndices(this, filePath);
            const cacheKey = indices.join(",");
            if (!cache.has(cacheKey)) {
                cache.set(cacheKey, createConfig(this, indices));
            }
            return cache.get(cacheKey);
        }
        /**
         * Check if a given path is an additional lint target.
         * @param {string} filePath The absolute path to the target file.
         * @returns {boolean} `true` if the file is an additional lint target.
         */
        isAdditionalTargetPath(filePath) {
            for (const { criteria, type } of this) {
                if (type === "config" &&
                    criteria &&
                    !criteria.endsWithWildcard &&
                    criteria.test(filePath)) {
                    return true;
                }
            }
            return false;
        }
    }
    /**
     * Get the used extracted configs.
     * CLIEngine will use this method to collect used deprecated rules.
     * @param {ConfigArray} instance The config array object to get.
     * @returns {ExtractedConfig[]} The used extracted configs.
     * @private
     */
    function getUsedExtractedConfigs(instance) {
        const { cache } = internalSlotsMap$2.get(instance);
        return Array.from(cache.values());
    }
    /**
     * @fileoverview `ConfigDependency` class.
     *
     * `ConfigDependency` class expresses a loaded parser or plugin.
     *
     * If the parser or plugin was loaded successfully, it has `definition` property
     * and `filePath` property. Otherwise, it has `error` property.
     *
     * When `JSON.stringify()` converted a `ConfigDependency` object to a JSON, it
     * omits `definition` property.
     *
     * `ConfigArrayFactory` creates `ConfigDependency` objects when it loads parsers
     * or plugins.
     *
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    /**
     * The class is to store parsers or plugins.
     * This class hides the loaded object from `JSON.stringify()` and `console.log`.
     * @template T
     */
    class ConfigDependency {
        /**
         * Initialize this instance.
         * @param {Object} data The dependency data.
         * @param {T} [data.definition] The dependency if the loading succeeded.
         * @param {Error} [data.error] The error object if the loading failed.
         * @param {string} [data.filePath] The actual path to the dependency if the loading succeeded.
         * @param {string} data.id The ID of this dependency.
         * @param {string} data.importerName The name of the config file which loads this dependency.
         * @param {string} data.importerPath The path to the config file which loads this dependency.
         */
        constructor({ definition = null, error = null, filePath = null, id, importerName, importerPath }) {
            /**
             * The loaded dependency if the loading succeeded.
             * @type {T|null}
             */
            this.definition = definition;
            /**
             * The error object if the loading failed.
             * @type {Error|null}
             */
            this.error = error;
            /**
             * The loaded dependency if the loading succeeded.
             * @type {string|null}
             */
            this.filePath = filePath;
            /**
             * The ID of this dependency.
             * @type {string}
             */
            this.id = id;
            /**
             * The name of the config file which loads this dependency.
             * @type {string}
             */
            this.importerName = importerName;
            /**
             * The path to the config file which loads this dependency.
             * @type {string}
             */
            this.importerPath = importerPath;
        }
        // eslint-disable-next-line jsdoc/require-description
        /**
         * @returns {Object} a JSON compatible object.
         */
        toJSON() {
            const obj = this[util__default["default"].inspect.custom]();
            // Display `error.message` (`Error#message` is unenumerable).
            if (obj.error instanceof Error) {
                obj.error = { ...obj.error, message: obj.error.message };
            }
            return obj;
        }
        // eslint-disable-next-line jsdoc/require-description
        /**
         * @returns {Object} an object to display by `console.log()`.
         */
        [util__default["default"].inspect.custom]() {
            const { definition: _ignore, // eslint-disable-line no-unused-vars
            ...obj } = this;
            return obj;
        }
    }
    /**
     * @fileoverview `OverrideTester` class.
     *
     * `OverrideTester` class handles `files` property and `excludedFiles` property
     * of `overrides` config.
     *
     * It provides one method.
     *
     * - `test(filePath)`
     *      Test if a file path matches the pair of `files` property and
     *      `excludedFiles` property. The `filePath` argument must be an absolute
     *      path.
     *
     * `ConfigArrayFactory` creates `OverrideTester` objects when it processes
     * `overrides` properties.
     *
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    const { Minimatch } = minimatch__default["default"];
    const minimatchOpts = { dot: true, matchBase: true };
    /**
     * @typedef {Object} Pattern
     * @property {InstanceType<Minimatch>[] | null} includes The positive matchers.
     * @property {InstanceType<Minimatch>[] | null} excludes The negative matchers.
     */
    /**
     * Normalize a given pattern to an array.
     * @param {string|string[]|undefined} patterns A glob pattern or an array of glob patterns.
     * @returns {string[]|null} Normalized patterns.
     * @private
     */
    function normalizePatterns(patterns) {
        if (Array.isArray(patterns)) {
            return patterns.filter(Boolean);
        }
        if (typeof patterns === "string" && patterns) {
            return [patterns];
        }
        return [];
    }
    /**
     * Create the matchers of given patterns.
     * @param {string[]} patterns The patterns.
     * @returns {InstanceType<Minimatch>[] | null} The matchers.
     */
    function toMatcher(patterns) {
        if (patterns.length === 0) {
            return null;
        }
        return patterns.map(pattern => {
            if (/^\.[/\\]/u.test(pattern)) {
                return new Minimatch(pattern.slice(2), 
                // `./*.js` should not match with `subdir/foo.js`
                { ...minimatchOpts, matchBase: false });
            }
            return new Minimatch(pattern, minimatchOpts);
        });
    }
    /**
     * Convert a given matcher to string.
     * @param {Pattern} matchers The matchers.
     * @returns {string} The string expression of the matcher.
     */
    function patternToJson({ includes, excludes }) {
        return {
            includes: includes && includes.map(m => m.pattern),
            excludes: excludes && excludes.map(m => m.pattern)
        };
    }
    /**
     * The class to test given paths are matched by the patterns.
     */
    class OverrideTester {
        /**
         * Create a tester with given criteria.
         * If there are no criteria, returns `null`.
         * @param {string|string[]} files The glob patterns for included files.
         * @param {string|string[]} excludedFiles The glob patterns for excluded files.
         * @param {string} basePath The path to the base directory to test paths.
         * @returns {OverrideTester|null} The created instance or `null`.
         */
        static create(files, excludedFiles, basePath) {
            const includePatterns = normalizePatterns(files);
            const excludePatterns = normalizePatterns(excludedFiles);
            let endsWithWildcard = false;
            if (includePatterns.length === 0) {
                return null;
            }
            // Rejects absolute paths or relative paths to parents.
            for (const pattern of includePatterns) {
                if (path__default["default"].isAbsolute(pattern) || pattern.includes("..")) {
                    throw new Error(`Invalid override pattern (expected relative path not containing '..'): ${pattern}`);
                }
                if (pattern.endsWith("*")) {
                    endsWithWildcard = true;
                }
            }
            for (const pattern of excludePatterns) {
                if (path__default["default"].isAbsolute(pattern) || pattern.includes("..")) {
                    throw new Error(`Invalid override pattern (expected relative path not containing '..'): ${pattern}`);
                }
            }
            const includes = toMatcher(includePatterns);
            const excludes = toMatcher(excludePatterns);
            return new OverrideTester([{ includes, excludes }], basePath, endsWithWildcard);
        }
        /**
         * Combine two testers by logical and.
         * If either of the testers was `null`, returns the other tester.
         * The `basePath` property of the two must be the same value.
         * @param {OverrideTester|null} a A tester.
         * @param {OverrideTester|null} b Another tester.
         * @returns {OverrideTester|null} Combined tester.
         */
        static and(a, b) {
            if (!b) {
                return a && new OverrideTester(a.patterns, a.basePath, a.endsWithWildcard);
            }
            if (!a) {
                return new OverrideTester(b.patterns, b.basePath, b.endsWithWildcard);
            }
            assert__default["default"].strictEqual(a.basePath, b.basePath);
            return new OverrideTester(a.patterns.concat(b.patterns), a.basePath, a.endsWithWildcard || b.endsWithWildcard);
        }
        /**
         * Initialize this instance.
         * @param {Pattern[]} patterns The matchers.
         * @param {string} basePath The base path.
         * @param {boolean} endsWithWildcard If `true` then a pattern ends with `*`.
         */
        constructor(patterns, basePath, endsWithWildcard = false) {
            /** @type {Pattern[]} */
            this.patterns = patterns;
            /** @type {string} */
            this.basePath = basePath;
            /** @type {boolean} */
            this.endsWithWildcard = endsWithWildcard;
        }
        /**
         * Test if a given path is matched or not.
         * @param {string} filePath The absolute path to the target file.
         * @returns {boolean} `true` if the path was matched.
         */
        test(filePath) {
            if (typeof filePath !== "string" || !path__default["default"].isAbsolute(filePath)) {
                throw new Error(`'filePath' should be an absolute path, but got ${filePath}.`);
            }
            const relativePath = path__default["default"].relative(this.basePath, filePath);
            return this.patterns.every(({ includes, excludes }) => ((!includes || includes.some(m => m.match(relativePath))) &&
                (!excludes || !excludes.some(m => m.match(relativePath)))));
        }
        // eslint-disable-next-line jsdoc/require-description
        /**
         * @returns {Object} a JSON compatible object.
         */
        toJSON() {
            if (this.patterns.length === 1) {
                return {
                    ...patternToJson(this.patterns[0]),
                    basePath: this.basePath
                };
            }
            return {
                AND: this.patterns.map(patternToJson),
                basePath: this.basePath
            };
        }
        // eslint-disable-next-line jsdoc/require-description
        /**
         * @returns {Object} an object to display by `console.log()`.
         */
        [util__default["default"].inspect.custom]() {
            return this.toJSON();
        }
    }
    /**
     * @fileoverview `ConfigArray` class.
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    /**
     * @fileoverview Config file operations. This file must be usable in the browser,
     * so no Node-specific code can be here.
     * @author Nicholas C. Zakas
     */
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    const RULE_SEVERITY_STRINGS = ["off", "warn", "error"], RULE_SEVERITY = RULE_SEVERITY_STRINGS.reduce((map, value, index) => {
        map[value] = index;
        return map;
    }, {}), VALID_SEVERITIES = [0, 1, 2, "off", "warn", "error"];
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * Normalizes the severity value of a rule's configuration to a number
     * @param {(number|string|[number, ...*]|[string, ...*])} ruleConfig A rule's configuration value, generally
     * received from the user. A valid config value is either 0, 1, 2, the string "off" (treated the same as 0),
     * the string "warn" (treated the same as 1), the string "error" (treated the same as 2), or an array
     * whose first element is one of the above values. Strings are matched case-insensitively.
     * @returns {(0|1|2)} The numeric severity value if the config value was valid, otherwise 0.
     */
    function getRuleSeverity(ruleConfig) {
        const severityValue = Array.isArray(ruleConfig) ? ruleConfig[0] : ruleConfig;
        if (severityValue === 0 || severityValue === 1 || severityValue === 2) {
            return severityValue;
        }
        if (typeof severityValue === "string") {
            return RULE_SEVERITY[severityValue.toLowerCase()] || 0;
        }
        return 0;
    }
    /**
     * Converts old-style severity settings (0, 1, 2) into new-style
     * severity settings (off, warn, error) for all rules. Assumption is that severity
     * values have already been validated as correct.
     * @param {Object} config The config object to normalize.
     * @returns {void}
     */
    function normalizeToStrings(config) {
        if (config.rules) {
            Object.keys(config.rules).forEach(ruleId => {
                const ruleConfig = config.rules[ruleId];
                if (typeof ruleConfig === "number") {
                    config.rules[ruleId] = RULE_SEVERITY_STRINGS[ruleConfig] || RULE_SEVERITY_STRINGS[0];
                }
                else if (Array.isArray(ruleConfig) && typeof ruleConfig[0] === "number") {
                    ruleConfig[0] = RULE_SEVERITY_STRINGS[ruleConfig[0]] || RULE_SEVERITY_STRINGS[0];
                }
            });
        }
    }
    /**
     * Determines if the severity for the given rule configuration represents an error.
     * @param {int|string|Array} ruleConfig The configuration for an individual rule.
     * @returns {boolean} True if the rule represents an error, false if not.
     */
    function isErrorSeverity(ruleConfig) {
        return getRuleSeverity(ruleConfig) === 2;
    }
    /**
     * Checks whether a given config has valid severity or not.
     * @param {number|string|Array} ruleConfig The configuration for an individual rule.
     * @returns {boolean} `true` if the configuration has valid severity.
     */
    function isValidSeverity(ruleConfig) {
        let severity = Array.isArray(ruleConfig) ? ruleConfig[0] : ruleConfig;
        if (typeof severity === "string") {
            severity = severity.toLowerCase();
        }
        return VALID_SEVERITIES.indexOf(severity) !== -1;
    }
    /**
     * Checks whether every rule of a given config has valid severity or not.
     * @param {Object} config The configuration for rules.
     * @returns {boolean} `true` if the configuration has valid severity.
     */
    function isEverySeverityValid(config) {
        return Object.keys(config).every(ruleId => isValidSeverity(config[ruleId]));
    }
    /**
     * Normalizes a value for a global in a config
     * @param {(boolean|string|null)} configuredValue The value given for a global in configuration or in
     * a global directive comment
     * @returns {("readable"|"writeable"|"off")} The value normalized as a string
     * @throws Error if global value is invalid
     */
    function normalizeConfigGlobal(configuredValue) {
        switch (configuredValue) {
            case "off":
                return "off";
            case true:
            case "true":
            case "writeable":
            case "writable":
                return "writable";
            case null:
            case false:
            case "false":
            case "readable":
            case "readonly":
                return "readonly";
            default:
                throw new Error(`'${configuredValue}' is not a valid configuration for a global (use 'readonly', 'writable', or 'off')`);
        }
    }
    var ConfigOps = {
        __proto__: null,
        getRuleSeverity: getRuleSeverity,
        normalizeToStrings: normalizeToStrings,
        isErrorSeverity: isErrorSeverity,
        isValidSeverity: isValidSeverity,
        isEverySeverityValid: isEverySeverityValid,
        normalizeConfigGlobal: normalizeConfigGlobal
    };
    /**
     * @fileoverview Provide the function that emits deprecation warnings.
     * @author Toru Nagashima <http://github.com/mysticatea>
     */
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    // Defitions for deprecation warnings.
    const deprecationWarningMessages = {
        ESLINT_LEGACY_ECMAFEATURES: "The 'ecmaFeatures' config file property is deprecated and has no effect.",
        ESLINT_PERSONAL_CONFIG_LOAD: "'~/.eslintrc.*' config files have been deprecated. " +
            "Please use a config file per project or the '--config' option.",
        ESLINT_PERSONAL_CONFIG_SUPPRESS: "'~/.eslintrc.*' config files have been deprecated. " +
            "Please remove it or add 'root:true' to the config files in your " +
            "projects in order to avoid loading '~/.eslintrc.*' accidentally."
    };
    const sourceFileErrorCache = new Set();
    /**
     * Emits a deprecation warning containing a given filepath. A new deprecation warning is emitted
     * for each unique file path, but repeated invocations with the same file path have no effect.
     * No warnings are emitted if the `--no-deprecation` or `--no-warnings` Node runtime flags are active.
     * @param {string} source The name of the configuration source to report the warning for.
     * @param {string} errorCode The warning message to show.
     * @returns {void}
     */
    function emitDeprecationWarning(source, errorCode) {
        const cacheKey = JSON.stringify({ source, errorCode });
        if (sourceFileErrorCache.has(cacheKey)) {
            return;
        }
        sourceFileErrorCache.add(cacheKey);
        const rel = path__default["default"].relative(process.cwd(), source);
        const message = deprecationWarningMessages[errorCode];
        process.emitWarning(`${message} (found in "${rel}")`, "DeprecationWarning", errorCode);
    }
    /**
     * @fileoverview The instance of Ajv validator.
     * @author Evgeny Poberezkin
     */
    //-----------------------------------------------------------------------------
    // Helpers
    //-----------------------------------------------------------------------------
    /*
     * Copied from ajv/lib/refs/json-schema-draft-04.json
     * The MIT License (MIT)
     * Copyright (c) 2015-2017 Evgeny Poberezkin
     */
    const metaSchema = {
        id: "http://json-schema.org/draft-04/schema#",
        $schema: "http://json-schema.org/draft-04/schema#",
        description: "Core schema meta-schema",
        definitions: {
            schemaArray: {
                type: "array",
                minItems: 1,
                items: { $ref: "#" }
            },
            positiveInteger: {
                type: "integer",
                minimum: 0
            },
            positiveIntegerDefault0: {
                allOf: [{ $ref: "#/definitions/positiveInteger" }, { default: 0 }]
            },
            simpleTypes: {
                enum: ["array", "boolean", "integer", "null", "number", "object", "string"]
            },
            stringArray: {
                type: "array",
                items: { type: "string" },
                minItems: 1,
                uniqueItems: true
            }
        },
        type: "object",
        properties: {
            id: {
                type: "string"
            },
            $schema: {
                type: "string"
            },
            title: {
                type: "string"
            },
            description: {
                type: "string"
            },
            default: {},
            multipleOf: {
                type: "number",
                minimum: 0,
                exclusiveMinimum: true
            },
            maximum: {
                type: "number"
            },
            exclusiveMaximum: {
                type: "boolean",
                default: false
            },
            minimum: {
                type: "number"
            },
            exclusiveMinimum: {
                type: "boolean",
                default: false
            },
            maxLength: { $ref: "#/definitions/positiveInteger" },
            minLength: { $ref: "#/definitions/positiveIntegerDefault0" },
            pattern: {
                type: "string",
                format: "regex"
            },
            additionalItems: {
                anyOf: [
                    { type: "boolean" },
                    { $ref: "#" }
                ],
                default: {}
            },
            items: {
                anyOf: [
                    { $ref: "#" },
                    { $ref: "#/definitions/schemaArray" }
                ],
                default: {}
            },
            maxItems: { $ref: "#/definitions/positiveInteger" },
            minItems: { $ref: "#/definitions/positiveIntegerDefault0" },
            uniqueItems: {
                type: "boolean",
                default: false
            },
            maxProperties: { $ref: "#/definitions/positiveInteger" },
            minProperties: { $ref: "#/definitions/positiveIntegerDefault0" },
            required: { $ref: "#/definitions/stringArray" },
            additionalProperties: {
                anyOf: [
                    { type: "boolean" },
                    { $ref: "#" }
                ],
                default: {}
            },
            definitions: {
                type: "object",
                additionalProperties: { $ref: "#" },
                default: {}
            },
            properties: {
                type: "object",
                additionalProperties: { $ref: "#" },
                default: {}
            },
            patternProperties: {
                type: "object",
                additionalProperties: { $ref: "#" },
                default: {}
            },
            dependencies: {
                type: "object",
                additionalProperties: {
                    anyOf: [
                        { $ref: "#" },
                        { $ref: "#/definitions/stringArray" }
                    ]
                }
            },
            enum: {
                type: "array",
                minItems: 1,
                uniqueItems: true
            },
            type: {
                anyOf: [
                    { $ref: "#/definitions/simpleTypes" },
                    {
                        type: "array",
                        items: { $ref: "#/definitions/simpleTypes" },
                        minItems: 1,
                        uniqueItems: true
                    }
                ]
            },
            format: { type: "string" },
            allOf: { $ref: "#/definitions/schemaArray" },
            anyOf: { $ref: "#/definitions/schemaArray" },
            oneOf: { $ref: "#/definitions/schemaArray" },
            not: { $ref: "#" }
        },
        dependencies: {
            exclusiveMaximum: ["maximum"],
            exclusiveMinimum: ["minimum"]
        },
        default: {}
    };
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    var ajvOrig = (additionalOptions = {}) => {
        const ajv = new Ajv__default["default"]({
            meta: false,
            useDefaults: true,
            validateSchema: false,
            missingRefs: "ignore",
            verbose: true,
            schemaId: "auto",
            ...additionalOptions
        });
        ajv.addMetaSchema(metaSchema);
        // eslint-disable-next-line no-underscore-dangle
        ajv._opts.defaultMeta = metaSchema.id;
        return ajv;
    };
    /**
     * @fileoverview Defines a schema for configs.
     * @author Sylvan Mably
     */
    const baseConfigProperties = {
        $schema: { type: "string" },
        env: { type: "object" },
        extends: { $ref: "#/definitions/stringOrStrings" },
        globals: { type: "object" },
        overrides: {
            type: "array",
            items: { $ref: "#/definitions/overrideConfig" },
            additionalItems: false
        },
        parser: { type: ["string", "null"] },
        parserOptions: { type: "object" },
        plugins: { type: "array" },
        processor: { type: "string" },
        rules: { type: "object" },
        settings: { type: "object" },
        noInlineConfig: { type: "boolean" },
        reportUnusedDisableDirectives: { type: "boolean" },
        ecmaFeatures: { type: "object" } // deprecated; logs a warning when used
    };
    const configSchema = {
        definitions: {
            stringOrStrings: {
                oneOf: [
                    { type: "string" },
                    {
                        type: "array",
                        items: { type: "string" },
                        additionalItems: false
                    }
                ]
            },
            stringOrStringsRequired: {
                oneOf: [
                    { type: "string" },
                    {
                        type: "array",
                        items: { type: "string" },
                        additionalItems: false,
                        minItems: 1
                    }
                ]
            },
            // Config at top-level.
            objectConfig: {
                type: "object",
                properties: {
                    root: { type: "boolean" },
                    ignorePatterns: { $ref: "#/definitions/stringOrStrings" },
                    ...baseConfigProperties
                },
                additionalProperties: false
            },
            // Config in `overrides`.
            overrideConfig: {
                type: "object",
                properties: {
                    excludedFiles: { $ref: "#/definitions/stringOrStrings" },
                    files: { $ref: "#/definitions/stringOrStringsRequired" },
                    ...baseConfigProperties
                },
                required: ["files"],
                additionalProperties: false
            }
        },
        $ref: "#/definitions/objectConfig"
    };
    /**
     * @fileoverview Defines environment settings and globals.
     * @author Elan Shanker
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Get the object that has difference.
     * @param {Record<string,boolean>} current The newer object.
     * @param {Record<string,boolean>} prev The older object.
     * @returns {Record<string,boolean>} The difference object.
     */
    function getDiff(current, prev) {
        const retv = {};
        for (const [key, value] of Object.entries(current)) {
            if (!Object.hasOwnProperty.call(prev, key)) {
                retv[key] = value;
            }
        }
        return retv;
    }
    const newGlobals2015 = getDiff(globals__default["default"].es2015, globals__default["default"].es5); // 19 variables such as Promise, Map, ...
    const newGlobals2017 = {
        Atomics: false,
        SharedArrayBuffer: false
    };
    const newGlobals2020 = {
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        globalThis: false
    };
    const newGlobals2021 = {
        AggregateError: false,
        FinalizationRegistry: false,
        WeakRef: false
    };
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /** @type {Map<string, import("../lib/shared/types").Environment>} */
    var environments = new Map(Object.entries({
        // Language
        builtin: {
            globals: globals__default["default"].es5
        },
        es6: {
            globals: newGlobals2015,
            parserOptions: {
                ecmaVersion: 6
            }
        },
        es2015: {
            globals: newGlobals2015,
            parserOptions: {
                ecmaVersion: 6
            }
        },
        es2016: {
            globals: newGlobals2015,
            parserOptions: {
                ecmaVersion: 7
            }
        },
        es2017: {
            globals: { ...newGlobals2015, ...newGlobals2017 },
            parserOptions: {
                ecmaVersion: 8
            }
        },
        es2018: {
            globals: { ...newGlobals2015, ...newGlobals2017 },
            parserOptions: {
                ecmaVersion: 9
            }
        },
        es2019: {
            globals: { ...newGlobals2015, ...newGlobals2017 },
            parserOptions: {
                ecmaVersion: 10
            }
        },
        es2020: {
            globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020 },
            parserOptions: {
                ecmaVersion: 11
            }
        },
        es2021: {
            globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020, ...newGlobals2021 },
            parserOptions: {
                ecmaVersion: 12
            }
        },
        es2022: {
            globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020, ...newGlobals2021 },
            parserOptions: {
                ecmaVersion: 13
            }
        },
        // Platforms
        browser: {
            globals: globals__default["default"].browser
        },
        node: {
            globals: globals__default["default"].node,
            parserOptions: {
                ecmaFeatures: {
                    globalReturn: true
                }
            }
        },
        "shared-node-browser": {
            globals: globals__default["default"]["shared-node-browser"]
        },
        worker: {
            globals: globals__default["default"].worker
        },
        serviceworker: {
            globals: globals__default["default"].serviceworker
        },
        // Frameworks
        commonjs: {
            globals: globals__default["default"].commonjs,
            parserOptions: {
                ecmaFeatures: {
                    globalReturn: true
                }
            }
        },
        amd: {
            globals: globals__default["default"].amd
        },
        mocha: {
            globals: globals__default["default"].mocha
        },
        jasmine: {
            globals: globals__default["default"].jasmine
        },
        jest: {
            globals: globals__default["default"].jest
        },
        phantomjs: {
            globals: globals__default["default"].phantomjs
        },
        jquery: {
            globals: globals__default["default"].jquery
        },
        qunit: {
            globals: globals__default["default"].qunit
        },
        prototypejs: {
            globals: globals__default["default"].prototypejs
        },
        shelljs: {
            globals: globals__default["default"].shelljs
        },
        meteor: {
            globals: globals__default["default"].meteor
        },
        mongo: {
            globals: globals__default["default"].mongo
        },
        protractor: {
            globals: globals__default["default"].protractor
        },
        applescript: {
            globals: globals__default["default"].applescript
        },
        nashorn: {
            globals: globals__default["default"].nashorn
        },
        atomtest: {
            globals: globals__default["default"].atomtest
        },
        embertest: {
            globals: globals__default["default"].embertest
        },
        webextensions: {
            globals: globals__default["default"].webextensions
        },
        greasemonkey: {
            globals: globals__default["default"].greasemonkey
        }
    }));
    /**
     * @fileoverview Validates configs.
     * @author Brandon Mills
     */
    const ajv = ajvOrig();
    const ruleValidators = new WeakMap();
    const noop = Function.prototype;
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    let validateSchema;
    const severityMap = {
        error: 2,
        warn: 1,
        off: 0
    };
    const validated = new WeakSet();
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    class ConfigValidator {
        constructor({ builtInRules = new Map() } = {}) {
            this.builtInRules = builtInRules;
        }
        /**
         * Gets a complete options schema for a rule.
         * @param {{create: Function, schema: (Array|null)}} rule A new-style rule object
         * @returns {Object} JSON Schema for the rule's options.
         */
        getRuleOptionsSchema(rule) {
            if (!rule) {
                return null;
            }
            const schema = rule.schema || rule.meta && rule.meta.schema;
            // Given a tuple of schemas, insert warning level at the beginning
            if (Array.isArray(schema)) {
                if (schema.length) {
                    return {
                        type: "array",
                        items: schema,
                        minItems: 0,
                        maxItems: schema.length
                    };
                }
                return {
                    type: "array",
                    minItems: 0,
                    maxItems: 0
                };
            }
            // Given a full schema, leave it alone
            return schema || null;
        }
        /**
         * Validates a rule's severity and returns the severity value. Throws an error if the severity is invalid.
         * @param {options} options The given options for the rule.
         * @returns {number|string} The rule's severity value
         */
        validateRuleSeverity(options) {
            const severity = Array.isArray(options) ? options[0] : options;
            const normSeverity = typeof severity === "string" ? severityMap[severity.toLowerCase()] : severity;
            if (normSeverity === 0 || normSeverity === 1 || normSeverity === 2) {
                return normSeverity;
            }
            throw new Error(`\tSeverity should be one of the following: 0 = off, 1 = warn, 2 = error (you passed '${util__default["default"].inspect(severity).replace(/'/gu, "\"").replace(/\n/gu, "")}').\n`);
        }
        /**
         * Validates the non-severity options passed to a rule, based on its schema.
         * @param {{create: Function}} rule The rule to validate
         * @param {Array} localOptions The options for the rule, excluding severity
         * @returns {void}
         */
        validateRuleSchema(rule, localOptions) {
            if (!ruleValidators.has(rule)) {
                const schema = this.getRuleOptionsSchema(rule);
                if (schema) {
                    ruleValidators.set(rule, ajv.compile(schema));
                }
            }
            const validateRule = ruleValidators.get(rule);
            if (validateRule) {
                validateRule(localOptions);
                if (validateRule.errors) {
                    throw new Error(validateRule.errors.map(error => `\tValue ${JSON.stringify(error.data)} ${error.message}.\n`).join(""));
                }
            }
        }
        /**
         * Validates a rule's options against its schema.
         * @param {{create: Function}|null} rule The rule that the config is being validated for
         * @param {string} ruleId The rule's unique name.
         * @param {Array|number} options The given options for the rule.
         * @param {string|null} source The name of the configuration source to report in any errors. If null or undefined,
         * no source is prepended to the message.
         * @returns {void}
         */
        validateRuleOptions(rule, ruleId, options, source = null) {
            try {
                const severity = this.validateRuleSeverity(options);
                if (severity !== 0) {
                    this.validateRuleSchema(rule, Array.isArray(options) ? options.slice(1) : []);
                }
            }
            catch (err) {
                const enhancedMessage = `Configuration for rule "${ruleId}" is invalid:\n${err.message}`;
                if (typeof source === "string") {
                    throw new Error(`${source}:\n\t${enhancedMessage}`);
                }
                else {
                    throw new Error(enhancedMessage);
                }
            }
        }
        /**
         * Validates an environment object
         * @param {Object} environment The environment config object to validate.
         * @param {string} source The name of the configuration source to report in any errors.
         * @param {function(envId:string): Object} [getAdditionalEnv] A map from strings to loaded environments.
         * @returns {void}
         */
        validateEnvironment(environment, source, getAdditionalEnv = noop) {
            // not having an environment is ok
            if (!environment) {
                return;
            }
            Object.keys(environment).forEach(id => {
                const env = getAdditionalEnv(id) || environments.get(id) || null;
                if (!env) {
                    const message = `${source}:\n\tEnvironment key "${id}" is unknown\n`;
                    throw new Error(message);
                }
            });
        }
        /**
         * Validates a rules config object
         * @param {Object} rulesConfig The rules config object to validate.
         * @param {string} source The name of the configuration source to report in any errors.
         * @param {function(ruleId:string): Object} getAdditionalRule A map from strings to loaded rules
         * @returns {void}
         */
        validateRules(rulesConfig, source, getAdditionalRule = noop) {
            if (!rulesConfig) {
                return;
            }
            Object.keys(rulesConfig).forEach(id => {
                const rule = getAdditionalRule(id) || this.builtInRules.get(id) || null;
                this.validateRuleOptions(rule, id, rulesConfig[id], source);
            });
        }
        /**
         * Validates a `globals` section of a config file
         * @param {Object} globalsConfig The `globals` section
         * @param {string|null} source The name of the configuration source to report in the event of an error.
         * @returns {void}
         */
        validateGlobals(globalsConfig, source = null) {
            if (!globalsConfig) {
                return;
            }
            Object.entries(globalsConfig)
                .forEach(([configuredGlobal, configuredValue]) => {
                try {
                    normalizeConfigGlobal(configuredValue);
                }
                catch (err) {
                    throw new Error(`ESLint configuration of global '${configuredGlobal}' in ${source} is invalid:\n${err.message}`);
                }
            });
        }
        /**
         * Validate `processor` configuration.
         * @param {string|undefined} processorName The processor name.
         * @param {string} source The name of config file.
         * @param {function(id:string): Processor} getProcessor The getter of defined processors.
         * @returns {void}
         */
        validateProcessor(processorName, source, getProcessor) {
            if (processorName && !getProcessor(processorName)) {
                throw new Error(`ESLint configuration of processor in '${source}' is invalid: '${processorName}' was not found.`);
            }
        }
        /**
         * Formats an array of schema validation errors.
         * @param {Array} errors An array of error messages to format.
         * @returns {string} Formatted error message
         */
        formatErrors(errors) {
            return errors.map(error => {
                if (error.keyword === "additionalProperties") {
                    const formattedPropertyPath = error.dataPath.length ? `${error.dataPath.slice(1)}.${error.params.additionalProperty}` : error.params.additionalProperty;
                    return `Unexpected top-level property "${formattedPropertyPath}"`;
                }
                if (error.keyword === "type") {
                    const formattedField = error.dataPath.slice(1);
                    const formattedExpectedType = Array.isArray(error.schema) ? error.schema.join("/") : error.schema;
                    const formattedValue = JSON.stringify(error.data);
                    return `Property "${formattedField}" is the wrong type (expected ${formattedExpectedType} but got \`${formattedValue}\`)`;
                }
                const field = error.dataPath[0] === "." ? error.dataPath.slice(1) : error.dataPath;
                return `"${field}" ${error.message}. Value: ${JSON.stringify(error.data)}`;
            }).map(message => `\t- ${message}.\n`).join("");
        }
        /**
         * Validates the top level properties of the config object.
         * @param {Object} config The config object to validate.
         * @param {string} source The name of the configuration source to report in any errors.
         * @returns {void}
         */
        validateConfigSchema(config, source = null) {
            validateSchema = validateSchema || ajv.compile(configSchema);
            if (!validateSchema(config)) {
                throw new Error(`ESLint configuration in ${source} is invalid:\n${this.formatErrors(validateSchema.errors)}`);
            }
            if (Object.hasOwnProperty.call(config, "ecmaFeatures")) {
                emitDeprecationWarning(source, "ESLINT_LEGACY_ECMAFEATURES");
            }
        }
        /**
         * Validates an entire config object.
         * @param {Object} config The config object to validate.
         * @param {string} source The name of the configuration source to report in any errors.
         * @param {function(ruleId:string): Object} [getAdditionalRule] A map from strings to loaded rules.
         * @param {function(envId:string): Object} [getAdditionalEnv] A map from strings to loaded envs.
         * @returns {void}
         */
        validate(config, source, getAdditionalRule, getAdditionalEnv) {
            this.validateConfigSchema(config, source);
            this.validateRules(config.rules, source, getAdditionalRule);
            this.validateEnvironment(config.env, source, getAdditionalEnv);
            this.validateGlobals(config.globals, source);
            for (const override of config.overrides || []) {
                this.validateRules(override.rules, source, getAdditionalRule);
                this.validateEnvironment(override.env, source, getAdditionalEnv);
                this.validateGlobals(config.globals, source);
            }
        }
        /**
         * Validate config array object.
         * @param {ConfigArray} configArray The config array to validate.
         * @returns {void}
         */
        validateConfigArray(configArray) {
            const getPluginEnv = Map.prototype.get.bind(configArray.pluginEnvironments);
            const getPluginProcessor = Map.prototype.get.bind(configArray.pluginProcessors);
            const getPluginRule = Map.prototype.get.bind(configArray.pluginRules);
            // Validate.
            for (const element of configArray) {
                if (validated.has(element)) {
                    continue;
                }
                validated.add(element);
                this.validateEnvironment(element.env, element.name, getPluginEnv);
                this.validateGlobals(element.globals, element.name);
                this.validateProcessor(element.processor, element.name, getPluginProcessor);
                this.validateRules(element.rules, element.name, getPluginRule);
            }
        }
    }
    /**
     * @fileoverview Common helpers for naming of plugins, formatters and configs
     */
    const NAMESPACE_REGEX = /^@.*\//iu;
    /**
     * Brings package name to correct format based on prefix
     * @param {string} name The name of the package.
     * @param {string} prefix Can be either "eslint-plugin", "eslint-config" or "eslint-formatter"
     * @returns {string} Normalized name of the package
     * @private
     */
    function normalizePackageName(name, prefix) {
        let normalizedName = name;
        /**
         * On Windows, name can come in with Windows slashes instead of Unix slashes.
         * Normalize to Unix first to avoid errors later on.
         * https://github.com/eslint/eslint/issues/5644
         */
        if (normalizedName.includes("\\")) {
            normalizedName = normalizedName.replace(/\\/gu, "/");
        }
        if (normalizedName.charAt(0) === "@") {
            /**
             * it's a scoped package
             * package name is the prefix, or just a username
             */
            const scopedPackageShortcutRegex = new RegExp(`^(@[^/]+)(?:/(?:${prefix})?)?$`, "u"), scopedPackageNameRegex = new RegExp(`^${prefix}(-|$)`, "u");
            if (scopedPackageShortcutRegex.test(normalizedName)) {
                normalizedName = normalizedName.replace(scopedPackageShortcutRegex, `$1/${prefix}`);
            }
            else if (!scopedPackageNameRegex.test(normalizedName.split("/")[1])) {
                /**
                 * for scoped packages, insert the prefix after the first / unless
                 * the path is already @scope/eslint or @scope/eslint-xxx-yyy
                 */
                normalizedName = normalizedName.replace(/^@([^/]+)\/(.*)$/u, `@$1/${prefix}-$2`);
            }
        }
        else if (!normalizedName.startsWith(`${prefix}-`)) {
            normalizedName = `${prefix}-${normalizedName}`;
        }
        return normalizedName;
    }
    /**
     * Removes the prefix from a fullname.
     * @param {string} fullname The term which may have the prefix.
     * @param {string} prefix The prefix to remove.
     * @returns {string} The term without prefix.
     */
    function getShorthandName(fullname, prefix) {
        if (fullname[0] === "@") {
            let matchResult = new RegExp(`^(@[^/]+)/${prefix}$`, "u").exec(fullname);
            if (matchResult) {
                return matchResult[1];
            }
            matchResult = new RegExp(`^(@[^/]+)/${prefix}-(.+)$`, "u").exec(fullname);
            if (matchResult) {
                return `${matchResult[1]}/${matchResult[2]}`;
            }
        }
        else if (fullname.startsWith(`${prefix}-`)) {
            return fullname.slice(prefix.length + 1);
        }
        return fullname;
    }
    /**
     * Gets the scope (namespace) of a term.
     * @param {string} term The term which may have the namespace.
     * @returns {string} The namespace of the term if it has one.
     */
    function getNamespaceFromTerm(term) {
        const match = term.match(NAMESPACE_REGEX);
        return match ? match[0] : "";
    }
    var naming = {
        __proto__: null,
        normalizePackageName: normalizePackageName,
        getShorthandName: getShorthandName,
        getNamespaceFromTerm: getNamespaceFromTerm
    };
    /**
     * Utility for resolving a module relative to another module
     * @author Teddy Katz
     */
    /*
     * `Module.createRequire` is added in v12.2.0. It supports URL as well.
     * We only support the case where the argument is a filepath, not a URL.
     */
    const createRequire = Module__default["default"].createRequire;
    /**
     * Resolves a Node module relative to another module
     * @param {string} moduleName The name of a Node module, or a path to a Node module.
     * @param {string} relativeToPath An absolute path indicating the module that `moduleName` should be resolved relative to. This must be
     * a file rather than a directory, but the file need not actually exist.
     * @returns {string} The absolute path that would result from calling `require.resolve(moduleName)` in a file located at `relativeToPath`
     */
    function resolve(moduleName, relativeToPath) {
        try {
            return createRequire(relativeToPath).resolve(moduleName);
        }
        catch (error) {
            // This `if` block is for older Node.js than 12.0.0. We can remove this block in the future.
            if (typeof error === "object" &&
                error !== null &&
                error.code === "MODULE_NOT_FOUND" &&
                !error.requireStack &&
                error.message.includes(moduleName)) {
                error.message += `\nRequire stack:\n- ${relativeToPath}`;
            }
            throw error;
        }
    }
    var ModuleResolver = {
        __proto__: null,
        resolve: resolve
    };
    /**
     * @fileoverview The factory of `ConfigArray` objects.
     *
     * This class provides methods to create `ConfigArray` instance.
     *
     * - `create(configData, options)`
     *     Create a `ConfigArray` instance from a config data. This is to handle CLI
     *     options except `--config`.
     * - `loadFile(filePath, options)`
     *     Create a `ConfigArray` instance from a config file. This is to handle
     *     `--config` option. If the file was not found, throws the following error:
     *      - If the filename was `*.js`, a `MODULE_NOT_FOUND` error.
     *      - If the filename was `package.json`, an IO error or an
     *        `ESLINT_CONFIG_FIELD_NOT_FOUND` error.
     *      - Otherwise, an IO error such as `ENOENT`.
     * - `loadInDirectory(directoryPath, options)`
     *     Create a `ConfigArray` instance from a config file which is on a given
     *     directory. This tries to load `.eslintrc.*` or `package.json`. If not
     *     found, returns an empty `ConfigArray`.
     * - `loadESLintIgnore(filePath)`
     *     Create a `ConfigArray` instance from a config file that is `.eslintignore`
     *     format. This is to handle `--ignore-path` option.
     * - `loadDefaultESLintIgnore()`
     *     Create a `ConfigArray` instance from `.eslintignore` or `package.json` in
     *     the current working directory.
     *
     * `ConfigArrayFactory` class has the responsibility that loads configuration
     * files, including loading `extends`, `parser`, and `plugins`. The created
     * `ConfigArray` instance has the loaded `extends`, `parser`, and `plugins`.
     *
     * But this class doesn't handle cascading. `CascadingConfigArrayFactory` class
     * handles cascading and hierarchy.
     *
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    const require$1 = Module.createRequire(require('url').pathToFileURL(__filename).toString());
    const debug$2 = debugOrig__default["default"]("eslintrc:config-array-factory");
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const configFilenames = [
        ".eslintrc.js",
        ".eslintrc.cjs",
        ".eslintrc.yaml",
        ".eslintrc.yml",
        ".eslintrc.json",
        ".eslintrc",
        "package.json"
    ];
    // Define types for VSCode IntelliSense.
    /** @typedef {import("./shared/types").ConfigData} ConfigData */
    /** @typedef {import("./shared/types").OverrideConfigData} OverrideConfigData */
    /** @typedef {import("./shared/types").Parser} Parser */
    /** @typedef {import("./shared/types").Plugin} Plugin */
    /** @typedef {import("./shared/types").Rule} Rule */
    /** @typedef {import("./config-array/config-dependency").DependentParser} DependentParser */
    /** @typedef {import("./config-array/config-dependency").DependentPlugin} DependentPlugin */
    /** @typedef {ConfigArray[0]} ConfigArrayElement */
    /**
     * @typedef {Object} ConfigArrayFactoryOptions
     * @property {Map<string,Plugin>} [additionalPluginPool] The map for additional plugins.
     * @property {string} [cwd] The path to the current working directory.
     * @property {string} [resolvePluginsRelativeTo] A path to the directory that plugins should be resolved from. Defaults to `cwd`.
     * @property {Map<string,Rule>} builtInRules The rules that are built in to ESLint.
     * @property {Object} [resolver=ModuleResolver] The module resolver object.
     * @property {string} eslintAllPath The path to the definitions for eslint:all.
     * @property {Function} getEslintAllConfig Returns the config data for eslint:all.
     * @property {string} eslintRecommendedPath The path to the definitions for eslint:recommended.
     * @property {Function} getEslintRecommendedConfig Returns the config data for eslint:recommended.
     */
    /**
     * @typedef {Object} ConfigArrayFactoryInternalSlots
     * @property {Map<string,Plugin>} additionalPluginPool The map for additional plugins.
     * @property {string} cwd The path to the current working directory.
     * @property {string | undefined} resolvePluginsRelativeTo An absolute path the the directory that plugins should be resolved from.
     * @property {Map<string,Rule>} builtInRules The rules that are built in to ESLint.
     * @property {Object} [resolver=ModuleResolver] The module resolver object.
     * @property {string} eslintAllPath The path to the definitions for eslint:all.
     * @property {Function} getEslintAllConfig Returns the config data for eslint:all.
     * @property {string} eslintRecommendedPath The path to the definitions for eslint:recommended.
     * @property {Function} getEslintRecommendedConfig Returns the config data for eslint:recommended.
     */
    /**
     * @typedef {Object} ConfigArrayFactoryLoadingContext
     * @property {string} filePath The path to the current configuration.
     * @property {string} matchBasePath The base path to resolve relative paths in `overrides[].files`, `overrides[].excludedFiles`, and `ignorePatterns`.
     * @property {string} name The name of the current configuration.
     * @property {string} pluginBasePath The base path to resolve plugins.
     * @property {"config" | "ignore" | "implicit-processor"} type The type of the current configuration. This is `"config"` in normal. This is `"ignore"` if it came from `.eslintignore`. This is `"implicit-processor"` if it came from legacy file-extension processors.
     */
    /**
     * @typedef {Object} ConfigArrayFactoryLoadingContext
     * @property {string} filePath The path to the current configuration.
     * @property {string} matchBasePath The base path to resolve relative paths in `overrides[].files`, `overrides[].excludedFiles`, and `ignorePatterns`.
     * @property {string} name The name of the current configuration.
     * @property {"config" | "ignore" | "implicit-processor"} type The type of the current configuration. This is `"config"` in normal. This is `"ignore"` if it came from `.eslintignore`. This is `"implicit-processor"` if it came from legacy file-extension processors.
     */
    /** @type {WeakMap<ConfigArrayFactory, ConfigArrayFactoryInternalSlots>} */
    const internalSlotsMap$1 = new WeakMap();
    /** @type {WeakMap<object, Plugin>} */
    const normalizedPlugins = new WeakMap();
    /**
     * Check if a given string is a file path.
     * @param {string} nameOrPath A module name or file path.
     * @returns {boolean} `true` if the `nameOrPath` is a file path.
     */
    function isFilePath(nameOrPath) {
        return (/^\.{1,2}[/\\]/u.test(nameOrPath) ||
            path__default["default"].isAbsolute(nameOrPath));
    }
    /**
     * Convenience wrapper for synchronously reading file contents.
     * @param {string} filePath The filename to read.
     * @returns {string} The file contents, with the BOM removed.
     * @private
     */
    function readFile(filePath) {
        return fs__default["default"].readFileSync(filePath, "utf8").replace(/^\ufeff/u, "");
    }
    /**
     * Loads a YAML configuration from a file.
     * @param {string} filePath The filename to load.
     * @returns {ConfigData} The configuration object from the file.
     * @throws {Error} If the file cannot be read.
     * @private
     */
    function loadYAMLConfigFile(filePath) {
        debug$2(`Loading YAML config file: ${filePath}`);
        // lazy load YAML to improve performance when not used
        const yaml = require$1("js-yaml");
        try {
            // empty YAML file can be null, so always use
            return yaml.load(readFile(filePath)) || {};
        }
        catch (e) {
            debug$2(`Error reading YAML file: ${filePath}`);
            e.message = `Cannot read config file: ${filePath}\nError: ${e.message}`;
            throw e;
        }
    }
    /**
     * Loads a JSON configuration from a file.
     * @param {string} filePath The filename to load.
     * @returns {ConfigData} The configuration object from the file.
     * @throws {Error} If the file cannot be read.
     * @private
     */
    function loadJSONConfigFile(filePath) {
        debug$2(`Loading JSON config file: ${filePath}`);
        try {
            return JSON.parse(stripComments__default["default"](readFile(filePath)));
        }
        catch (e) {
            debug$2(`Error reading JSON file: ${filePath}`);
            e.message = `Cannot read config file: ${filePath}\nError: ${e.message}`;
            e.messageTemplate = "failed-to-read-json";
            e.messageData = {
                path: filePath,
                message: e.message
            };
            throw e;
        }
    }
    /**
     * Loads a legacy (.eslintrc) configuration from a file.
     * @param {string} filePath The filename to load.
     * @returns {ConfigData} The configuration object from the file.
     * @throws {Error} If the file cannot be read.
     * @private
     */
    function loadLegacyConfigFile(filePath) {
        debug$2(`Loading legacy config file: ${filePath}`);
        // lazy load YAML to improve performance when not used
        const yaml = require$1("js-yaml");
        try {
            return yaml.load(stripComments__default["default"](readFile(filePath))) || /* istanbul ignore next */ {};
        }
        catch (e) {
            debug$2("Error reading YAML file: %s\n%o", filePath, e);
            e.message = `Cannot read config file: ${filePath}\nError: ${e.message}`;
            throw e;
        }
    }
    /**
     * Loads a JavaScript configuration from a file.
     * @param {string} filePath The filename to load.
     * @returns {ConfigData} The configuration object from the file.
     * @throws {Error} If the file cannot be read.
     * @private
     */
    function loadJSConfigFile(filePath) {
        debug$2(`Loading JS config file: ${filePath}`);
        try {
            return importFresh__default["default"](filePath);
        }
        catch (e) {
            debug$2(`Error reading JavaScript file: ${filePath}`);
            e.message = `Cannot read config file: ${filePath}\nError: ${e.message}`;
            throw e;
        }
    }
    /**
     * Loads a configuration from a package.json file.
     * @param {string} filePath The filename to load.
     * @returns {ConfigData} The configuration object from the file.
     * @throws {Error} If the file cannot be read.
     * @private
     */
    function loadPackageJSONConfigFile(filePath) {
        debug$2(`Loading package.json config file: ${filePath}`);
        try {
            const packageData = loadJSONConfigFile(filePath);
            if (!Object.hasOwnProperty.call(packageData, "eslintConfig")) {
                throw Object.assign(new Error("package.json file doesn't have 'eslintConfig' field."), { code: "ESLINT_CONFIG_FIELD_NOT_FOUND" });
            }
            return packageData.eslintConfig;
        }
        catch (e) {
            debug$2(`Error reading package.json file: ${filePath}`);
            e.message = `Cannot read config file: ${filePath}\nError: ${e.message}`;
            throw e;
        }
    }
    /**
     * Loads a `.eslintignore` from a file.
     * @param {string} filePath The filename to load.
     * @returns {string[]} The ignore patterns from the file.
     * @private
     */
    function loadESLintIgnoreFile(filePath) {
        debug$2(`Loading .eslintignore file: ${filePath}`);
        try {
            return readFile(filePath)
                .split(/\r?\n/gu)
                .filter(line => line.trim() !== "" && !line.startsWith("#"));
        }
        catch (e) {
            debug$2(`Error reading .eslintignore file: ${filePath}`);
            e.message = `Cannot read .eslintignore file: ${filePath}\nError: ${e.message}`;
            throw e;
        }
    }
    /**
     * Creates an error to notify about a missing config to extend from.
     * @param {string} configName The name of the missing config.
     * @param {string} importerName The name of the config that imported the missing config
     * @param {string} messageTemplate The text template to source error strings from.
     * @returns {Error} The error object to throw
     * @private
     */
    function configInvalidError(configName, importerName, messageTemplate) {
        return Object.assign(new Error(`Failed to load config "${configName}" to extend from.`), {
            messageTemplate,
            messageData: { configName, importerName }
        });
    }
    /**
     * Loads a configuration file regardless of the source. Inspects the file path
     * to determine the correctly way to load the config file.
     * @param {string} filePath The path to the configuration.
     * @returns {ConfigData|null} The configuration information.
     * @private
     */
    function loadConfigFile(filePath) {
        switch (path__default["default"].extname(filePath)) {
            case ".js":
            case ".cjs":
                return loadJSConfigFile(filePath);
            case ".json":
                if (path__default["default"].basename(filePath) === "package.json") {
                    return loadPackageJSONConfigFile(filePath);
                }
                return loadJSONConfigFile(filePath);
            case ".yaml":
            case ".yml":
                return loadYAMLConfigFile(filePath);
            default:
                return loadLegacyConfigFile(filePath);
        }
    }
    /**
     * Write debug log.
     * @param {string} request The requested module name.
     * @param {string} relativeTo The file path to resolve the request relative to.
     * @param {string} filePath The resolved file path.
     * @returns {void}
     */
    function writeDebugLogForLoading(request, relativeTo, filePath) {
        /* istanbul ignore next */
        if (debug$2.enabled) {
            let nameAndVersion = null;
            try {
                const packageJsonPath = resolve(`${request}/package.json`, relativeTo);
                const { version = "unknown" } = require$1(packageJsonPath);
                nameAndVersion = `${request}@${version}`;
            }
            catch (error) {
                debug$2("package.json was not found:", error.message);
                nameAndVersion = request;
            }
            debug$2("Loaded: %s (%s)", nameAndVersion, filePath);
        }
    }
    /**
     * Create a new context with default values.
     * @param {ConfigArrayFactoryInternalSlots} slots The internal slots.
     * @param {"config" | "ignore" | "implicit-processor" | undefined} providedType The type of the current configuration. Default is `"config"`.
     * @param {string | undefined} providedName The name of the current configuration. Default is the relative path from `cwd` to `filePath`.
     * @param {string | undefined} providedFilePath The path to the current configuration. Default is empty string.
     * @param {string | undefined} providedMatchBasePath The type of the current configuration. Default is the directory of `filePath` or `cwd`.
     * @returns {ConfigArrayFactoryLoadingContext} The created context.
     */
    function createContext({ cwd, resolvePluginsRelativeTo }, providedType, providedName, providedFilePath, providedMatchBasePath) {
        const filePath = providedFilePath
            ? path__default["default"].resolve(cwd, providedFilePath)
            : "";
        const matchBasePath = (providedMatchBasePath && path__default["default"].resolve(cwd, providedMatchBasePath)) ||
            (filePath && path__default["default"].dirname(filePath)) ||
            cwd;
        const name = providedName ||
            (filePath && path__default["default"].relative(cwd, filePath)) ||
            "";
        const pluginBasePath = resolvePluginsRelativeTo ||
            (filePath && path__default["default"].dirname(filePath)) ||
            cwd;
        const type = providedType || "config";
        return { filePath, matchBasePath, name, pluginBasePath, type };
    }
    /**
     * Normalize a given plugin.
     * - Ensure the object to have four properties: configs, environments, processors, and rules.
     * - Ensure the object to not have other properties.
     * @param {Plugin} plugin The plugin to normalize.
     * @returns {Plugin} The normalized plugin.
     */
    function normalizePlugin(plugin) {
        // first check the cache
        let normalizedPlugin = normalizedPlugins.get(plugin);
        if (normalizedPlugin) {
            return normalizedPlugin;
        }
        normalizedPlugin = {
            configs: plugin.configs || {},
            environments: plugin.environments || {},
            processors: plugin.processors || {},
            rules: plugin.rules || {}
        };
        // save the reference for later
        normalizedPlugins.set(plugin, normalizedPlugin);
        return normalizedPlugin;
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * The factory of `ConfigArray` objects.
     */
    class ConfigArrayFactory {
        /**
         * Initialize this instance.
         * @param {ConfigArrayFactoryOptions} [options] The map for additional plugins.
         */
        constructor({ additionalPluginPool = new Map(), cwd = process.cwd(), resolvePluginsRelativeTo, builtInRules, resolver = ModuleResolver, eslintAllPath, getEslintAllConfig, eslintRecommendedPath, getEslintRecommendedConfig } = {}) {
            internalSlotsMap$1.set(this, {
                additionalPluginPool,
                cwd,
                resolvePluginsRelativeTo: resolvePluginsRelativeTo &&
                    path__default["default"].resolve(cwd, resolvePluginsRelativeTo),
                builtInRules,
                resolver,
                eslintAllPath,
                getEslintAllConfig,
                eslintRecommendedPath,
                getEslintRecommendedConfig
            });
        }
        /**
         * Create `ConfigArray` instance from a config data.
         * @param {ConfigData|null} configData The config data to create.
         * @param {Object} [options] The options.
         * @param {string} [options.basePath] The base path to resolve relative paths in `overrides[].files`, `overrides[].excludedFiles`, and `ignorePatterns`.
         * @param {string} [options.filePath] The path to this config data.
         * @param {string} [options.name] The config name.
         * @returns {ConfigArray} Loaded config.
         */
        create(configData, { basePath, filePath, name } = {}) {
            if (!configData) {
                return new ConfigArray();
            }
            const slots = internalSlotsMap$1.get(this);
            const ctx = createContext(slots, "config", name, filePath, basePath);
            const elements = this._normalizeConfigData(configData, ctx);
            return new ConfigArray(...elements);
        }
        /**
         * Load a config file.
         * @param {string} filePath The path to a config file.
         * @param {Object} [options] The options.
         * @param {string} [options.basePath] The base path to resolve relative paths in `overrides[].files`, `overrides[].excludedFiles`, and `ignorePatterns`.
         * @param {string} [options.name] The config name.
         * @returns {ConfigArray} Loaded config.
         */
        loadFile(filePath, { basePath, name } = {}) {
            const slots = internalSlotsMap$1.get(this);
            const ctx = createContext(slots, "config", name, filePath, basePath);
            return new ConfigArray(...this._loadConfigData(ctx));
        }
        /**
         * Load the config file on a given directory if exists.
         * @param {string} directoryPath The path to a directory.
         * @param {Object} [options] The options.
         * @param {string} [options.basePath] The base path to resolve relative paths in `overrides[].files`, `overrides[].excludedFiles`, and `ignorePatterns`.
         * @param {string} [options.name] The config name.
         * @returns {ConfigArray} Loaded config. An empty `ConfigArray` if any config doesn't exist.
         */
        loadInDirectory(directoryPath, { basePath, name } = {}) {
            const slots = internalSlotsMap$1.get(this);
            for (const filename of configFilenames) {
                const ctx = createContext(slots, "config", name, path__default["default"].join(directoryPath, filename), basePath);
                if (fs__default["default"].existsSync(ctx.filePath) && fs__default["default"].statSync(ctx.filePath).isFile()) {
                    let configData;
                    try {
                        configData = loadConfigFile(ctx.filePath);
                    }
                    catch (error) {
                        if (!error || error.code !== "ESLINT_CONFIG_FIELD_NOT_FOUND") {
                            throw error;
                        }
                    }
                    if (configData) {
                        debug$2(`Config file found: ${ctx.filePath}`);
                        return new ConfigArray(...this._normalizeConfigData(configData, ctx));
                    }
                }
            }
            debug$2(`Config file not found on ${directoryPath}`);
            return new ConfigArray();
        }
        /**
         * Check if a config file on a given directory exists or not.
         * @param {string} directoryPath The path to a directory.
         * @returns {string | null} The path to the found config file. If not found then null.
         */
        static getPathToConfigFileInDirectory(directoryPath) {
            for (const filename of configFilenames) {
                const filePath = path__default["default"].join(directoryPath, filename);
                if (fs__default["default"].existsSync(filePath)) {
                    if (filename === "package.json") {
                        try {
                            loadPackageJSONConfigFile(filePath);
                            return filePath;
                        }
                        catch { /* ignore */ }
                    }
                    else {
                        return filePath;
                    }
                }
            }
            return null;
        }
        /**
         * Load `.eslintignore` file.
         * @param {string} filePath The path to a `.eslintignore` file to load.
         * @returns {ConfigArray} Loaded config. An empty `ConfigArray` if any config doesn't exist.
         */
        loadESLintIgnore(filePath) {
            const slots = internalSlotsMap$1.get(this);
            const ctx = createContext(slots, "ignore", void 0, filePath, slots.cwd);
            const ignorePatterns = loadESLintIgnoreFile(ctx.filePath);
            return new ConfigArray(...this._normalizeESLintIgnoreData(ignorePatterns, ctx));
        }
        /**
         * Load `.eslintignore` file in the current working directory.
         * @returns {ConfigArray} Loaded config. An empty `ConfigArray` if any config doesn't exist.
         */
        loadDefaultESLintIgnore() {
            const slots = internalSlotsMap$1.get(this);
            const eslintIgnorePath = path__default["default"].resolve(slots.cwd, ".eslintignore");
            const packageJsonPath = path__default["default"].resolve(slots.cwd, "package.json");
            if (fs__default["default"].existsSync(eslintIgnorePath)) {
                return this.loadESLintIgnore(eslintIgnorePath);
            }
            if (fs__default["default"].existsSync(packageJsonPath)) {
                const data = loadJSONConfigFile(packageJsonPath);
                if (Object.hasOwnProperty.call(data, "eslintIgnore")) {
                    if (!Array.isArray(data.eslintIgnore)) {
                        throw new Error("Package.json eslintIgnore property requires an array of paths");
                    }
                    const ctx = createContext(slots, "ignore", "eslintIgnore in package.json", packageJsonPath, slots.cwd);
                    return new ConfigArray(...this._normalizeESLintIgnoreData(data.eslintIgnore, ctx));
                }
            }
            return new ConfigArray();
        }
        /**
         * Load a given config file.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} Loaded config.
         * @private
         */
        _loadConfigData(ctx) {
            return this._normalizeConfigData(loadConfigFile(ctx.filePath), ctx);
        }
        /**
         * Normalize a given `.eslintignore` data to config array elements.
         * @param {string[]} ignorePatterns The patterns to ignore files.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
         * @private
         */
        *_normalizeESLintIgnoreData(ignorePatterns, ctx) {
            const elements = this._normalizeObjectConfigData({ ignorePatterns }, ctx);
            // Set `ignorePattern.loose` flag for backward compatibility.
            for (const element of elements) {
                if (element.ignorePattern) {
                    element.ignorePattern.loose = true;
                }
                yield element;
            }
        }
        /**
         * Normalize a given config to an array.
         * @param {ConfigData} configData The config data to normalize.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
         * @private
         */
        _normalizeConfigData(configData, ctx) {
            const validator = new ConfigValidator();
            validator.validateConfigSchema(configData, ctx.name || ctx.filePath);
            return this._normalizeObjectConfigData(configData, ctx);
        }
        /**
         * Normalize a given config to an array.
         * @param {ConfigData|OverrideConfigData} configData The config data to normalize.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
         * @private
         */
        *_normalizeObjectConfigData(configData, ctx) {
            const { files, excludedFiles, ...configBody } = configData;
            const criteria = OverrideTester.create(files, excludedFiles, ctx.matchBasePath);
            const elements = this._normalizeObjectConfigDataBody(configBody, ctx);
            // Apply the criteria to every element.
            for (const element of elements) {
                /*
                 * Merge the criteria.
                 * This is for the `overrides` entries that came from the
                 * configurations of `overrides[].extends`.
                 */
                element.criteria = OverrideTester.and(criteria, element.criteria);
                /*
                 * Remove `root` property to ignore `root` settings which came from
                 * `extends` in `overrides`.
                 */
                if (element.criteria) {
                    element.root = void 0;
                }
                yield element;
            }
        }
        /**
         * Normalize a given config to an array.
         * @param {ConfigData} configData The config data to normalize.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
         * @private
         */
        *_normalizeObjectConfigDataBody({ env, extends: extend, globals, ignorePatterns, noInlineConfig, parser: parserName, parserOptions, plugins: pluginList, processor, reportUnusedDisableDirectives, root, rules, settings, overrides: overrideList = [] }, ctx) {
            const extendList = Array.isArray(extend) ? extend : [extend];
            const ignorePattern = ignorePatterns && new IgnorePattern(Array.isArray(ignorePatterns) ? ignorePatterns : [ignorePatterns], ctx.matchBasePath);
            // Flatten `extends`.
            for (const extendName of extendList.filter(Boolean)) {
                yield* this._loadExtends(extendName, ctx);
            }
            // Load parser & plugins.
            const parser = parserName && this._loadParser(parserName, ctx);
            const plugins = pluginList && this._loadPlugins(pluginList, ctx);
            // Yield pseudo config data for file extension processors.
            if (plugins) {
                yield* this._takeFileExtensionProcessors(plugins, ctx);
            }
            // Yield the config data except `extends` and `overrides`.
            yield {
                // Debug information.
                type: ctx.type,
                name: ctx.name,
                filePath: ctx.filePath,
                // Config data.
                criteria: null,
                env,
                globals,
                ignorePattern,
                noInlineConfig,
                parser,
                parserOptions,
                plugins,
                processor,
                reportUnusedDisableDirectives,
                root,
                rules,
                settings
            };
            // Flatten `overries`.
            for (let i = 0; i < overrideList.length; ++i) {
                yield* this._normalizeObjectConfigData(overrideList[i], { ...ctx, name: `${ctx.name}#overrides[${i}]` });
            }
        }
        /**
         * Load configs of an element in `extends`.
         * @param {string} extendName The name of a base config.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
         * @private
         */
        _loadExtends(extendName, ctx) {
            debug$2("Loading {extends:%j} relative to %s", extendName, ctx.filePath);
            try {
                if (extendName.startsWith("eslint:")) {
                    return this._loadExtendedBuiltInConfig(extendName, ctx);
                }
                if (extendName.startsWith("plugin:")) {
                    return this._loadExtendedPluginConfig(extendName, ctx);
                }
                return this._loadExtendedShareableConfig(extendName, ctx);
            }
            catch (error) {
                error.message += `\nReferenced from: ${ctx.filePath || ctx.name}`;
                throw error;
            }
        }
        /**
         * Load configs of an element in `extends`.
         * @param {string} extendName The name of a base config.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
         * @private
         */
        _loadExtendedBuiltInConfig(extendName, ctx) {
            const { eslintAllPath, getEslintAllConfig, eslintRecommendedPath, getEslintRecommendedConfig } = internalSlotsMap$1.get(this);
            if (extendName === "eslint:recommended") {
                const name = `${ctx.name} » ${extendName}`;
                if (getEslintRecommendedConfig) {
                    if (typeof getEslintRecommendedConfig !== "function") {
                        throw new Error(`getEslintRecommendedConfig must be a function instead of '${getEslintRecommendedConfig}'`);
                    }
                    return this._normalizeConfigData(getEslintRecommendedConfig(), { ...ctx, name, filePath: "" });
                }
                return this._loadConfigData({
                    ...ctx,
                    name,
                    filePath: eslintRecommendedPath
                });
            }
            if (extendName === "eslint:all") {
                const name = `${ctx.name} » ${extendName}`;
                if (getEslintAllConfig) {
                    if (typeof getEslintAllConfig !== "function") {
                        throw new Error(`getEslintAllConfig must be a function instead of '${getEslintAllConfig}'`);
                    }
                    return this._normalizeConfigData(getEslintAllConfig(), { ...ctx, name, filePath: "" });
                }
                return this._loadConfigData({
                    ...ctx,
                    name,
                    filePath: eslintAllPath
                });
            }
            throw configInvalidError(extendName, ctx.name, "extend-config-missing");
        }
        /**
         * Load configs of an element in `extends`.
         * @param {string} extendName The name of a base config.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
         * @private
         */
        _loadExtendedPluginConfig(extendName, ctx) {
            const slashIndex = extendName.lastIndexOf("/");
            if (slashIndex === -1) {
                throw configInvalidError(extendName, ctx.filePath, "plugin-invalid");
            }
            const pluginName = extendName.slice("plugin:".length, slashIndex);
            const configName = extendName.slice(slashIndex + 1);
            if (isFilePath(pluginName)) {
                throw new Error("'extends' cannot use a file path for plugins.");
            }
            const plugin = this._loadPlugin(pluginName, ctx);
            const configData = plugin.definition &&
                plugin.definition.configs[configName];
            if (configData) {
                return this._normalizeConfigData(configData, {
                    ...ctx,
                    filePath: plugin.filePath || ctx.filePath,
                    name: `${ctx.name} » plugin:${plugin.id}/${configName}`
                });
            }
            throw plugin.error || configInvalidError(extendName, ctx.filePath, "extend-config-missing");
        }
        /**
         * Load configs of an element in `extends`.
         * @param {string} extendName The name of a base config.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
         * @private
         */
        _loadExtendedShareableConfig(extendName, ctx) {
            const { cwd, resolver } = internalSlotsMap$1.get(this);
            const relativeTo = ctx.filePath || path__default["default"].join(cwd, "__placeholder__.js");
            let request;
            if (isFilePath(extendName)) {
                request = extendName;
            }
            else if (extendName.startsWith(".")) {
                request = `./${extendName}`; // For backward compatibility. A ton of tests depended on this behavior.
            }
            else {
                request = normalizePackageName(extendName, "eslint-config");
            }
            let filePath;
            try {
                filePath = resolver.resolve(request, relativeTo);
            }
            catch (error) {
                /* istanbul ignore else */
                if (error && error.code === "MODULE_NOT_FOUND") {
                    throw configInvalidError(extendName, ctx.filePath, "extend-config-missing");
                }
                throw error;
            }
            writeDebugLogForLoading(request, relativeTo, filePath);
            return this._loadConfigData({
                ...ctx,
                filePath,
                name: `${ctx.name} » ${request}`
            });
        }
        /**
         * Load given plugins.
         * @param {string[]} names The plugin names to load.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {Record<string,DependentPlugin>} The loaded parser.
         * @private
         */
        _loadPlugins(names, ctx) {
            return names.reduce((map, name) => {
                if (isFilePath(name)) {
                    throw new Error("Plugins array cannot includes file paths.");
                }
                const plugin = this._loadPlugin(name, ctx);
                map[plugin.id] = plugin;
                return map;
            }, {});
        }
        /**
         * Load a given parser.
         * @param {string} nameOrPath The package name or the path to a parser file.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {DependentParser} The loaded parser.
         */
        _loadParser(nameOrPath, ctx) {
            debug$2("Loading parser %j from %s", nameOrPath, ctx.filePath);
            const { cwd, resolver } = internalSlotsMap$1.get(this);
            const relativeTo = ctx.filePath || path__default["default"].join(cwd, "__placeholder__.js");
            try {
                const filePath = resolver.resolve(nameOrPath, relativeTo);
                writeDebugLogForLoading(nameOrPath, relativeTo, filePath);
                return new ConfigDependency({
                    definition: require$1(filePath),
                    filePath,
                    id: nameOrPath,
                    importerName: ctx.name,
                    importerPath: ctx.filePath
                });
            }
            catch (error) {
                // If the parser name is "espree", load the espree of ESLint.
                if (nameOrPath === "espree") {
                    debug$2("Fallback espree.");
                    return new ConfigDependency({
                        definition: require$1("espree"),
                        filePath: require$1.resolve("espree"),
                        id: nameOrPath,
                        importerName: ctx.name,
                        importerPath: ctx.filePath
                    });
                }
                debug$2("Failed to load parser '%s' declared in '%s'.", nameOrPath, ctx.name);
                error.message = `Failed to load parser '${nameOrPath}' declared in '${ctx.name}': ${error.message}`;
                return new ConfigDependency({
                    error,
                    id: nameOrPath,
                    importerName: ctx.name,
                    importerPath: ctx.filePath
                });
            }
        }
        /**
         * Load a given plugin.
         * @param {string} name The plugin name to load.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {DependentPlugin} The loaded plugin.
         * @private
         */
        _loadPlugin(name, ctx) {
            debug$2("Loading plugin %j from %s", name, ctx.filePath);
            const { additionalPluginPool, resolver } = internalSlotsMap$1.get(this);
            const request = normalizePackageName(name, "eslint-plugin");
            const id = getShorthandName(request, "eslint-plugin");
            const relativeTo = path__default["default"].join(ctx.pluginBasePath, "__placeholder__.js");
            if (name.match(/\s+/u)) {
                const error = Object.assign(new Error(`Whitespace found in plugin name '${name}'`), {
                    messageTemplate: "whitespace-found",
                    messageData: { pluginName: request }
                });
                return new ConfigDependency({
                    error,
                    id,
                    importerName: ctx.name,
                    importerPath: ctx.filePath
                });
            }
            // Check for additional pool.
            const plugin = additionalPluginPool.get(request) ||
                additionalPluginPool.get(id);
            if (plugin) {
                return new ConfigDependency({
                    definition: normalizePlugin(plugin),
                    filePath: "",
                    id,
                    importerName: ctx.name,
                    importerPath: ctx.filePath
                });
            }
            let filePath;
            let error;
            try {
                filePath = resolver.resolve(request, relativeTo);
            }
            catch (resolveError) {
                error = resolveError;
                /* istanbul ignore else */
                if (error && error.code === "MODULE_NOT_FOUND") {
                    error.messageTemplate = "plugin-missing";
                    error.messageData = {
                        pluginName: request,
                        resolvePluginsRelativeTo: ctx.pluginBasePath,
                        importerName: ctx.name
                    };
                }
            }
            if (filePath) {
                try {
                    writeDebugLogForLoading(request, relativeTo, filePath);
                    const startTime = Date.now();
                    const pluginDefinition = require$1(filePath);
                    debug$2(`Plugin ${filePath} loaded in: ${Date.now() - startTime}ms`);
                    return new ConfigDependency({
                        definition: normalizePlugin(pluginDefinition),
                        filePath,
                        id,
                        importerName: ctx.name,
                        importerPath: ctx.filePath
                    });
                }
                catch (loadError) {
                    error = loadError;
                }
            }
            debug$2("Failed to load plugin '%s' declared in '%s'.", name, ctx.name);
            error.message = `Failed to load plugin '${name}' declared in '${ctx.name}': ${error.message}`;
            return new ConfigDependency({
                error,
                id,
                importerName: ctx.name,
                importerPath: ctx.filePath
            });
        }
        /**
         * Take file expression processors as config array elements.
         * @param {Record<string,DependentPlugin>} plugins The plugin definitions.
         * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
         * @returns {IterableIterator<ConfigArrayElement>} The config array elements of file expression processors.
         * @private
         */
        *_takeFileExtensionProcessors(plugins, ctx) {
            for (const pluginId of Object.keys(plugins)) {
                const processors = plugins[pluginId] &&
                    plugins[pluginId].definition &&
                    plugins[pluginId].definition.processors;
                if (!processors) {
                    continue;
                }
                for (const processorId of Object.keys(processors)) {
                    if (processorId.startsWith(".")) {
                        yield* this._normalizeObjectConfigData({
                            files: [`*${processorId}`],
                            processor: `${pluginId}/${processorId}`
                        }, {
                            ...ctx,
                            type: "implicit-processor",
                            name: `${ctx.name}#processors["${pluginId}/${processorId}"]`
                        });
                    }
                }
            }
        }
    }
    /**
     * @fileoverview `CascadingConfigArrayFactory` class.
     *
     * `CascadingConfigArrayFactory` class has a responsibility:
     *
     * 1. Handles cascading of config files.
     *
     * It provides two methods:
     *
     * - `getConfigArrayForFile(filePath)`
     *     Get the corresponded configuration of a given file. This method doesn't
     *     throw even if the given file didn't exist.
     * - `clearCache()`
     *     Clear the internal cache. You have to call this method when
     *     `additionalPluginPool` was updated if `baseConfig` or `cliConfig` depends
     *     on the additional plugins. (`CLIEngine#addPlugin()` method calls this.)
     *
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    const debug$1 = debugOrig__default["default"]("eslintrc:cascading-config-array-factory");
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    // Define types for VSCode IntelliSense.
    /** @typedef {import("./shared/types").ConfigData} ConfigData */
    /** @typedef {import("./shared/types").Parser} Parser */
    /** @typedef {import("./shared/types").Plugin} Plugin */
    /** @typedef {import("./shared/types").Rule} Rule */
    /** @typedef {ReturnType<ConfigArrayFactory["create"]>} ConfigArray */
    /**
     * @typedef {Object} CascadingConfigArrayFactoryOptions
     * @property {Map<string,Plugin>} [additionalPluginPool] The map for additional plugins.
     * @property {ConfigData} [baseConfig] The config by `baseConfig` option.
     * @property {ConfigData} [cliConfig] The config by CLI options (`--env`, `--global`, `--ignore-pattern`, `--parser`, `--parser-options`, `--plugin`, and `--rule`). CLI options overwrite the setting in config files.
     * @property {string} [cwd] The base directory to start lookup.
     * @property {string} [ignorePath] The path to the alternative file of `.eslintignore`.
     * @property {string[]} [rulePaths] The value of `--rulesdir` option.
     * @property {string} [specificConfigPath] The value of `--config` option.
     * @property {boolean} [useEslintrc] if `false` then it doesn't load config files.
     * @property {Function} loadRules The function to use to load rules.
     * @property {Map<string,Rule>} builtInRules The rules that are built in to ESLint.
     * @property {Object} [resolver=ModuleResolver] The module resolver object.
     * @property {string} eslintAllPath The path to the definitions for eslint:all.
     * @property {Function} getEslintAllConfig Returns the config data for eslint:all.
     * @property {string} eslintRecommendedPath The path to the definitions for eslint:recommended.
     * @property {Function} getEslintRecommendedConfig Returns the config data for eslint:recommended.
     */
    /**
     * @typedef {Object} CascadingConfigArrayFactoryInternalSlots
     * @property {ConfigArray} baseConfigArray The config array of `baseConfig` option.
     * @property {ConfigData} baseConfigData The config data of `baseConfig` option. This is used to reset `baseConfigArray`.
     * @property {ConfigArray} cliConfigArray The config array of CLI options.
     * @property {ConfigData} cliConfigData The config data of CLI options. This is used to reset `cliConfigArray`.
     * @property {ConfigArrayFactory} configArrayFactory The factory for config arrays.
     * @property {Map<string, ConfigArray>} configCache The cache from directory paths to config arrays.
     * @property {string} cwd The base directory to start lookup.
     * @property {WeakMap<ConfigArray, ConfigArray>} finalizeCache The cache from config arrays to finalized config arrays.
     * @property {string} [ignorePath] The path to the alternative file of `.eslintignore`.
     * @property {string[]|null} rulePaths The value of `--rulesdir` option. This is used to reset `baseConfigArray`.
     * @property {string|null} specificConfigPath The value of `--config` option. This is used to reset `cliConfigArray`.
     * @property {boolean} useEslintrc if `false` then it doesn't load config files.
     * @property {Function} loadRules The function to use to load rules.
     * @property {Map<string,Rule>} builtInRules The rules that are built in to ESLint.
     * @property {Object} [resolver=ModuleResolver] The module resolver object.
     * @property {string} eslintAllPath The path to the definitions for eslint:all.
     * @property {Function} getEslintAllConfig Returns the config data for eslint:all.
     * @property {string} eslintRecommendedPath The path to the definitions for eslint:recommended.
     * @property {Function} getEslintRecommendedConfig Returns the config data for eslint:recommended.
     */
    /** @type {WeakMap<CascadingConfigArrayFactory, CascadingConfigArrayFactoryInternalSlots>} */
    const internalSlotsMap = new WeakMap();
    /**
     * Create the config array from `baseConfig` and `rulePaths`.
     * @param {CascadingConfigArrayFactoryInternalSlots} slots The slots.
     * @returns {ConfigArray} The config array of the base configs.
     */
    function createBaseConfigArray({ configArrayFactory, baseConfigData, rulePaths, cwd, loadRules }) {
        const baseConfigArray = configArrayFactory.create(baseConfigData, { name: "BaseConfig" });
        /*
         * Create the config array element for the default ignore patterns.
         * This element has `ignorePattern` property that ignores the default
         * patterns in the current working directory.
         */
        baseConfigArray.unshift(configArrayFactory.create({ ignorePatterns: IgnorePattern.DefaultPatterns }, { name: "DefaultIgnorePattern" })[0]);
        /*
         * Load rules `--rulesdir` option as a pseudo plugin.
         * Use a pseudo plugin to define rules of `--rulesdir`, so we can validate
         * the rule's options with only information in the config array.
         */
        if (rulePaths && rulePaths.length > 0) {
            baseConfigArray.push({
                type: "config",
                name: "--rulesdir",
                filePath: "",
                plugins: {
                    "": new ConfigDependency({
                        definition: {
                            rules: rulePaths.reduce((map, rulesPath) => Object.assign(map, loadRules(rulesPath, cwd)), {})
                        },
                        filePath: "",
                        id: "",
                        importerName: "--rulesdir",
                        importerPath: ""
                    })
                }
            });
        }
        return baseConfigArray;
    }
    /**
     * Create the config array from CLI options.
     * @param {CascadingConfigArrayFactoryInternalSlots} slots The slots.
     * @returns {ConfigArray} The config array of the base configs.
     */
    function createCLIConfigArray({ cliConfigData, configArrayFactory, cwd, ignorePath, specificConfigPath }) {
        const cliConfigArray = configArrayFactory.create(cliConfigData, { name: "CLIOptions" });
        cliConfigArray.unshift(...(ignorePath
            ? configArrayFactory.loadESLintIgnore(ignorePath)
            : configArrayFactory.loadDefaultESLintIgnore()));
        if (specificConfigPath) {
            cliConfigArray.unshift(...configArrayFactory.loadFile(specificConfigPath, { name: "--config", basePath: cwd }));
        }
        return cliConfigArray;
    }
    /**
     * The error type when there are files matched by a glob, but all of them have been ignored.
     */
    class ConfigurationNotFoundError extends Error {
        // eslint-disable-next-line jsdoc/require-description
        /**
         * @param {string} directoryPath The directory path.
         */
        constructor(directoryPath) {
            super(`No ESLint configuration found in ${directoryPath}.`);
            this.messageTemplate = "no-config-found";
            this.messageData = { directoryPath };
        }
    }
    /**
     * This class provides the functionality that enumerates every file which is
     * matched by given glob patterns and that configuration.
     */
    class CascadingConfigArrayFactory {
        /**
         * Initialize this enumerator.
         * @param {CascadingConfigArrayFactoryOptions} options The options.
         */
        constructor({ additionalPluginPool = new Map(), baseConfig: baseConfigData = null, cliConfig: cliConfigData = null, cwd = process.cwd(), ignorePath, resolvePluginsRelativeTo, rulePaths = [], specificConfigPath = null, useEslintrc = true, builtInRules = new Map(), loadRules, resolver, eslintRecommendedPath, getEslintRecommendedConfig, eslintAllPath, getEslintAllConfig } = {}) {
            const configArrayFactory = new ConfigArrayFactory({
                additionalPluginPool,
                cwd,
                resolvePluginsRelativeTo,
                builtInRules,
                resolver,
                eslintRecommendedPath,
                getEslintRecommendedConfig,
                eslintAllPath,
                getEslintAllConfig
            });
            internalSlotsMap.set(this, {
                baseConfigArray: createBaseConfigArray({
                    baseConfigData,
                    configArrayFactory,
                    cwd,
                    rulePaths,
                    loadRules
                }),
                baseConfigData,
                cliConfigArray: createCLIConfigArray({
                    cliConfigData,
                    configArrayFactory,
                    cwd,
                    ignorePath,
                    specificConfigPath
                }),
                cliConfigData,
                configArrayFactory,
                configCache: new Map(),
                cwd,
                finalizeCache: new WeakMap(),
                ignorePath,
                rulePaths,
                specificConfigPath,
                useEslintrc,
                builtInRules,
                loadRules
            });
        }
        /**
         * The path to the current working directory.
         * This is used by tests.
         * @type {string}
         */
        get cwd() {
            const { cwd } = internalSlotsMap.get(this);
            return cwd;
        }
        /**
         * Get the config array of a given file.
         * If `filePath` was not given, it returns the config which contains only
         * `baseConfigData` and `cliConfigData`.
         * @param {string} [filePath] The file path to a file.
         * @param {Object} [options] The options.
         * @param {boolean} [options.ignoreNotFoundError] If `true` then it doesn't throw `ConfigurationNotFoundError`.
         * @returns {ConfigArray} The config array of the file.
         */
        getConfigArrayForFile(filePath, { ignoreNotFoundError = false } = {}) {
            const { baseConfigArray, cliConfigArray, cwd } = internalSlotsMap.get(this);
            if (!filePath) {
                return new ConfigArray(...baseConfigArray, ...cliConfigArray);
            }
            const directoryPath = path__default["default"].dirname(path__default["default"].resolve(cwd, filePath));
            debug$1(`Load config files for ${directoryPath}.`);
            return this._finalizeConfigArray(this._loadConfigInAncestors(directoryPath), directoryPath, ignoreNotFoundError);
        }
        /**
         * Set the config data to override all configs.
         * Require to call `clearCache()` method after this method is called.
         * @param {ConfigData} configData The config data to override all configs.
         * @returns {void}
         */
        setOverrideConfig(configData) {
            const slots = internalSlotsMap.get(this);
            slots.cliConfigData = configData;
        }
        /**
         * Clear config cache.
         * @returns {void}
         */
        clearCache() {
            const slots = internalSlotsMap.get(this);
            slots.baseConfigArray = createBaseConfigArray(slots);
            slots.cliConfigArray = createCLIConfigArray(slots);
            slots.configCache.clear();
        }
        /**
         * Load and normalize config files from the ancestor directories.
         * @param {string} directoryPath The path to a leaf directory.
         * @param {boolean} configsExistInSubdirs `true` if configurations exist in subdirectories.
         * @returns {ConfigArray} The loaded config.
         * @private
         */
        _loadConfigInAncestors(directoryPath, configsExistInSubdirs = false) {
            const { baseConfigArray, configArrayFactory, configCache, cwd, useEslintrc } = internalSlotsMap.get(this);
            if (!useEslintrc) {
                return baseConfigArray;
            }
            let configArray = configCache.get(directoryPath);
            // Hit cache.
            if (configArray) {
                debug$1(`Cache hit: ${directoryPath}.`);
                return configArray;
            }
            debug$1(`No cache found: ${directoryPath}.`);
            const homePath = os__default["default"].homedir();
            // Consider this is root.
            if (directoryPath === homePath && cwd !== homePath) {
                debug$1("Stop traversing because of considered root.");
                if (configsExistInSubdirs) {
                    const filePath = ConfigArrayFactory.getPathToConfigFileInDirectory(directoryPath);
                    if (filePath) {
                        emitDeprecationWarning(filePath, "ESLINT_PERSONAL_CONFIG_SUPPRESS");
                    }
                }
                return this._cacheConfig(directoryPath, baseConfigArray);
            }
            // Load the config on this directory.
            try {
                configArray = configArrayFactory.loadInDirectory(directoryPath);
            }
            catch (error) {
                /* istanbul ignore next */
                if (error.code === "EACCES") {
                    debug$1("Stop traversing because of 'EACCES' error.");
                    return this._cacheConfig(directoryPath, baseConfigArray);
                }
                throw error;
            }
            if (configArray.length > 0 && configArray.isRoot()) {
                debug$1("Stop traversing because of 'root:true'.");
                configArray.unshift(...baseConfigArray);
                return this._cacheConfig(directoryPath, configArray);
            }
            // Load from the ancestors and merge it.
            const parentPath = path__default["default"].dirname(directoryPath);
            const parentConfigArray = parentPath && parentPath !== directoryPath
                ? this._loadConfigInAncestors(parentPath, configsExistInSubdirs || configArray.length > 0)
                : baseConfigArray;
            if (configArray.length > 0) {
                configArray.unshift(...parentConfigArray);
            }
            else {
                configArray = parentConfigArray;
            }
            // Cache and return.
            return this._cacheConfig(directoryPath, configArray);
        }
        /**
         * Freeze and cache a given config.
         * @param {string} directoryPath The path to a directory as a cache key.
         * @param {ConfigArray} configArray The config array as a cache value.
         * @returns {ConfigArray} The `configArray` (frozen).
         */
        _cacheConfig(directoryPath, configArray) {
            const { configCache } = internalSlotsMap.get(this);
            Object.freeze(configArray);
            configCache.set(directoryPath, configArray);
            return configArray;
        }
        /**
         * Finalize a given config array.
         * Concatenate `--config` and other CLI options.
         * @param {ConfigArray} configArray The parent config array.
         * @param {string} directoryPath The path to the leaf directory to find config files.
         * @param {boolean} ignoreNotFoundError If `true` then it doesn't throw `ConfigurationNotFoundError`.
         * @returns {ConfigArray} The loaded config.
         * @private
         */
        _finalizeConfigArray(configArray, directoryPath, ignoreNotFoundError) {
            const { cliConfigArray, configArrayFactory, finalizeCache, useEslintrc, builtInRules } = internalSlotsMap.get(this);
            let finalConfigArray = finalizeCache.get(configArray);
            if (!finalConfigArray) {
                finalConfigArray = configArray;
                // Load the personal config if there are no regular config files.
                if (useEslintrc &&
                    configArray.every(c => !c.filePath) &&
                    cliConfigArray.every(c => !c.filePath) // `--config` option can be a file.
                ) {
                    const homePath = os__default["default"].homedir();
                    debug$1("Loading the config file of the home directory:", homePath);
                    const personalConfigArray = configArrayFactory.loadInDirectory(homePath, { name: "PersonalConfig" });
                    if (personalConfigArray.length > 0 &&
                        !directoryPath.startsWith(homePath)) {
                        const lastElement = personalConfigArray[personalConfigArray.length - 1];
                        emitDeprecationWarning(lastElement.filePath, "ESLINT_PERSONAL_CONFIG_LOAD");
                    }
                    finalConfigArray = finalConfigArray.concat(personalConfigArray);
                }
                // Apply CLI options.
                if (cliConfigArray.length > 0) {
                    finalConfigArray = finalConfigArray.concat(cliConfigArray);
                }
                // Validate rule settings and environments.
                const validator = new ConfigValidator({
                    builtInRules
                });
                validator.validateConfigArray(finalConfigArray);
                // Cache it.
                Object.freeze(finalConfigArray);
                finalizeCache.set(configArray, finalConfigArray);
                debug$1("Configuration was determined: %o on %s", finalConfigArray, directoryPath);
            }
            // At least one element (the default ignore patterns) exists.
            if (!ignoreNotFoundError && useEslintrc && finalConfigArray.length <= 1) {
                throw new ConfigurationNotFoundError(directoryPath);
            }
            return finalConfigArray;
        }
    }
    /**
     * @fileoverview Compatibility class for flat config.
     * @author Nicholas C. Zakas
     */
    //-----------------------------------------------------------------------------
    // Helpers
    //-----------------------------------------------------------------------------
    /** @typedef {import("../../shared/types").Environment} Environment */
    /** @typedef {import("../../shared/types").Processor} Processor */
    const debug = debugOrig__default["default"]("eslintrc:flat-compat");
    const cafactory = Symbol("cafactory");
    /**
     * Translates an ESLintRC-style config object into a flag-config-style config
     * object.
     * @param {Object} eslintrcConfig An ESLintRC-style config object.
     * @param {Object} options Options to help translate the config.
     * @param {string} options.resolveConfigRelativeTo To the directory to resolve
     *      configs from.
     * @param {string} options.resolvePluginsRelativeTo The directory to resolve
     *      plugins from.
     * @param {ReadOnlyMap<string,Environment>} options.pluginEnvironments A map of plugin environment
     *      names to objects.
     * @param {ReadOnlyMap<string,Processor>} options.pluginProcessors A map of plugin processor
     *      names to objects.
     * @returns {Object} A flag-config-style config object.
     */
    function translateESLintRC(eslintrcConfig, { resolveConfigRelativeTo, resolvePluginsRelativeTo, pluginEnvironments, pluginProcessors }) {
        const flatConfig = {};
        const configs = [];
        const languageOptions = {};
        const linterOptions = {};
        const keysToCopy = ["settings", "rules", "processor"];
        const languageOptionsKeysToCopy = ["globals", "parser", "parserOptions"];
        const linterOptionsKeysToCopy = ["noInlineConfig", "reportUnusedDisableDirectives"];
        // copy over simple translations
        for (const key of keysToCopy) {
            if (key in eslintrcConfig && typeof eslintrcConfig[key] !== "undefined") {
                flatConfig[key] = eslintrcConfig[key];
            }
        }
        // copy over languageOptions
        for (const key of languageOptionsKeysToCopy) {
            if (key in eslintrcConfig && typeof eslintrcConfig[key] !== "undefined") {
                // create the languageOptions key in the flat config
                flatConfig.languageOptions = languageOptions;
                if (key === "parser") {
                    debug(`Resolving parser '${languageOptions[key]}' relative to ${resolveConfigRelativeTo}`);
                    if (eslintrcConfig[key].error) {
                        throw eslintrcConfig[key].error;
                    }
                    languageOptions[key] = eslintrcConfig[key].definition;
                    continue;
                }
                // clone any object values that are in the eslintrc config
                if (eslintrcConfig[key] && typeof eslintrcConfig[key] === "object") {
                    languageOptions[key] = {
                        ...eslintrcConfig[key]
                    };
                }
                else {
                    languageOptions[key] = eslintrcConfig[key];
                }
            }
        }
        // copy over linterOptions
        for (const key of linterOptionsKeysToCopy) {
            if (key in eslintrcConfig && typeof eslintrcConfig[key] !== "undefined") {
                flatConfig.linterOptions = linterOptions;
                linterOptions[key] = eslintrcConfig[key];
            }
        }
        // move ecmaVersion a level up
        if (languageOptions.parserOptions) {
            if ("ecmaVersion" in languageOptions.parserOptions) {
                languageOptions.ecmaVersion = languageOptions.parserOptions.ecmaVersion;
                delete languageOptions.parserOptions.ecmaVersion;
            }
            if ("sourceType" in languageOptions.parserOptions) {
                languageOptions.sourceType = languageOptions.parserOptions.sourceType;
                delete languageOptions.parserOptions.sourceType;
            }
            // check to see if we even need parserOptions anymore and remove it if not
            if (Object.keys(languageOptions.parserOptions).length === 0) {
                delete languageOptions.parserOptions;
            }
        }
        // overrides
        if (eslintrcConfig.criteria) {
            flatConfig.files = [absoluteFilePath => eslintrcConfig.criteria.test(absoluteFilePath)];
        }
        // translate plugins
        if (eslintrcConfig.plugins && typeof eslintrcConfig.plugins === "object") {
            debug(`Translating plugins: ${eslintrcConfig.plugins}`);
            flatConfig.plugins = {};
            for (const pluginName of Object.keys(eslintrcConfig.plugins)) {
                debug(`Translating plugin: ${pluginName}`);
                debug(`Resolving plugin '${pluginName} relative to ${resolvePluginsRelativeTo}`);
                const { definition: plugin, error } = eslintrcConfig.plugins[pluginName];
                if (error) {
                    throw error;
                }
                flatConfig.plugins[pluginName] = plugin;
                // create a config for any processors
                if (plugin.processors) {
                    for (const processorName of Object.keys(plugin.processors)) {
                        if (processorName.startsWith(".")) {
                            debug(`Assigning processor: ${pluginName}/${processorName}`);
                            configs.unshift({
                                files: [`**/*${processorName}`],
                                processor: pluginProcessors.get(`${pluginName}/${processorName}`)
                            });
                        }
                    }
                }
            }
        }
        // translate env - must come after plugins
        if (eslintrcConfig.env && typeof eslintrcConfig.env === "object") {
            for (const envName of Object.keys(eslintrcConfig.env)) {
                // only add environments that are true
                if (eslintrcConfig.env[envName]) {
                    debug(`Translating environment: ${envName}`);
                    if (environments.has(envName)) {
                        // built-in environments should be defined first
                        configs.unshift(...translateESLintRC(environments.get(envName), {
                            resolveConfigRelativeTo,
                            resolvePluginsRelativeTo
                        }));
                    }
                    else if (pluginEnvironments.has(envName)) {
                        // if the environment comes from a plugin, it should come after the plugin config
                        configs.push(...translateESLintRC(pluginEnvironments.get(envName), {
                            resolveConfigRelativeTo,
                            resolvePluginsRelativeTo
                        }));
                    }
                }
            }
        }
        // only add if there are actually keys in the config
        if (Object.keys(flatConfig).length > 0) {
            configs.push(flatConfig);
        }
        return configs;
    }
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    /**
     * A compatibility class for working with configs.
     */
    class FlatCompat {
        constructor({ baseDirectory = process.cwd(), resolvePluginsRelativeTo = baseDirectory, recommendedConfig, allConfig } = {}) {
            this.baseDirectory = baseDirectory;
            this.resolvePluginsRelativeTo = resolvePluginsRelativeTo;
            this[cafactory] = new ConfigArrayFactory({
                cwd: baseDirectory,
                resolvePluginsRelativeTo,
                getEslintAllConfig: () => {
                    if (!allConfig) {
                        throw new TypeError("Missing parameter 'allConfig' in FlatCompat constructor.");
                    }
                    return allConfig;
                },
                getEslintRecommendedConfig: () => {
                    if (!recommendedConfig) {
                        throw new TypeError("Missing parameter 'recommendedConfig' in FlatCompat constructor.");
                    }
                    return recommendedConfig;
                }
            });
        }
        /**
         * Translates an ESLintRC-style config into a flag-config-style config.
         * @param {Object} eslintrcConfig The ESLintRC-style config object.
         * @returns {Object} A flag-config-style config object.
         */
        config(eslintrcConfig) {
            const eslintrcArray = this[cafactory].create(eslintrcConfig, {
                basePath: this.baseDirectory
            });
            const flatArray = [];
            let hasIgnorePatterns = false;
            eslintrcArray.forEach(configData => {
                if (configData.type === "config") {
                    hasIgnorePatterns = hasIgnorePatterns || configData.ignorePattern;
                    flatArray.push(...translateESLintRC(configData, {
                        resolveConfigRelativeTo: path__default["default"].join(this.baseDirectory, "__placeholder.js"),
                        resolvePluginsRelativeTo: path__default["default"].join(this.resolvePluginsRelativeTo, "__placeholder.js"),
                        pluginEnvironments: eslintrcArray.pluginEnvironments,
                        pluginProcessors: eslintrcArray.pluginProcessors
                    }));
                }
            });
            // combine ignorePatterns to emulate ESLintRC behavior better
            if (hasIgnorePatterns) {
                flatArray.unshift({
                    ignores: [filePath => {
                            // Compute the final config for this file.
                            // This filters config array elements by `files`/`excludedFiles` then merges the elements.
                            const finalConfig = eslintrcArray.extractConfig(filePath);
                            // Test the `ignorePattern` properties of the final config.
                            return Boolean(finalConfig.ignores) && finalConfig.ignores(filePath);
                        }]
                });
            }
            return flatArray;
        }
        /**
         * Translates the `env` section of an ESLintRC-style config.
         * @param {Object} envConfig The `env` section of an ESLintRC config.
         * @returns {Object[]} An array of flag-config objects representing the environments.
         */
        env(envConfig) {
            return this.config({
                env: envConfig
            });
        }
        /**
         * Translates the `extends` section of an ESLintRC-style config.
         * @param {...string} configsToExtend The names of the configs to load.
         * @returns {Object[]} An array of flag-config objects representing the config.
         */
        extends(...configsToExtend) {
            return this.config({
                extends: configsToExtend
            });
        }
        /**
         * Translates the `plugins` section of an ESLintRC-style config.
         * @param {...string} plugins The names of the plugins to load.
         * @returns {Object[]} An array of flag-config objects representing the plugins.
         */
        plugins(...plugins) {
            return this.config({
                plugins
            });
        }
    }
    /**
     * @fileoverview Package exports for @eslint/eslintrc
     * @author Nicholas C. Zakas
     */
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    const Legacy = {
        ConfigArray,
        createConfigArrayFactoryContext: createContext,
        CascadingConfigArrayFactory,
        ConfigArrayFactory,
        ConfigDependency,
        ExtractedConfig,
        IgnorePattern,
        OverrideTester,
        getUsedExtractedConfigs,
        environments,
        // shared
        ConfigOps,
        ConfigValidator,
        ModuleResolver,
        naming
    };
    exports.FlatCompat = FlatCompat;
    exports.Legacy = Legacy;
    
},
/* import-fresh/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const path = require('path');
    const resolveFrom = require(224) /* resolve-from */;
    const parentModule = require(225) /* parent-module */;
    module.exports = moduleId => {
        if (typeof moduleId !== 'string') {
            throw new TypeError('Expected a string');
        }
        const parentPath = parentModule(__filename);
        const cwd = parentPath ? path.dirname(parentPath) : __dirname;
        const filePath = resolveFrom(cwd, moduleId);
        const oldModule = require.cache[filePath];
        // Delete itself from module parent
        if (oldModule && oldModule.parent) {
            let i = oldModule.parent.children.length;
            while (i--) {
                if (oldModule.parent.children[i].id === filePath) {
                    oldModule.parent.children.splice(i, 1);
                }
            }
        }
        delete require.cache[filePath]; // Delete module from cache
        const parent = require.cache[parentPath]; // If `filePath` and `parentPath` are the same, cache will already be deleted so we won't get a memory leak in next step
        return parent === undefined ? require(filePath) : parent.require(filePath); // In case cache doesn't have parent, fall back to normal require
    };
},
/* resolve-from/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const path = require('path');
    const Module = require('module');
    const fs = require('fs');
    const resolveFrom = (fromDir, moduleId, silent) => {
        if (typeof fromDir !== 'string') {
            throw new TypeError(`Expected \`fromDir\` to be of type \`string\`, got \`${typeof fromDir}\``);
        }
        if (typeof moduleId !== 'string') {
            throw new TypeError(`Expected \`moduleId\` to be of type \`string\`, got \`${typeof moduleId}\``);
        }
        try {
            fromDir = fs.realpathSync(fromDir);
        }
        catch (err) {
            if (err.code === 'ENOENT') {
                fromDir = path.resolve(fromDir);
            }
            else if (silent) {
                return null;
            }
            else {
                throw err;
            }
        }
        const fromFile = path.join(fromDir, 'noop.js');
        const resolveFileName = () => Module._resolveFilename(moduleId, {
            id: fromFile,
            filename: fromFile,
            paths: Module._nodeModulePaths(fromDir)
        });
        if (silent) {
            try {
                return resolveFileName();
            }
            catch (err) {
                return null;
            }
        }
        return resolveFileName();
    };
    module.exports = (fromDir, moduleId) => resolveFrom(fromDir, moduleId);
    module.exports.silent = (fromDir, moduleId) => resolveFrom(fromDir, moduleId, true);
},
/* parent-module/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const callsites = require(226) /* callsites */;
    module.exports = filepath => {
        const stacks = callsites();
        if (!filepath) {
            return stacks[2].getFileName();
        }
        let seenVal = false;
        // Skip the first stack as it's this function
        stacks.shift();
        for (const stack of stacks) {
            const parentFilepath = stack.getFileName();
            if (typeof parentFilepath !== 'string') {
                continue;
            }
            if (parentFilepath === filepath) {
                seenVal = true;
                continue;
            }
            // Skip native modules
            if (parentFilepath === 'module.js') {
                continue;
            }
            if (seenVal && parentFilepath !== filepath) {
                return parentFilepath;
            }
        }
    };
},
/* callsites/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const callsites = () => {
        const _prepareStackTrace = Error.prepareStackTrace;
        Error.prepareStackTrace = (_, stack) => stack;
        const stack = new Error().stack.slice(1);
        Error.prepareStackTrace = _prepareStackTrace;
        return stack;
    };
    module.exports = callsites;
    // TODO: Remove this for the next major release
    module.exports.default = callsites;
},
/* strip-json-comments/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const singleComment = Symbol('singleComment');
    const multiComment = Symbol('multiComment');
    const stripWithoutWhitespace = () => '';
    const stripWithWhitespace = (string, start, end) => string.slice(start, end).replace(/\S/g, ' ');
    const isEscaped = (jsonString, quotePosition) => {
        let index = quotePosition - 1;
        let backslashCount = 0;
        while (jsonString[index] === '\\') {
            index -= 1;
            backslashCount += 1;
        }
        return Boolean(backslashCount % 2);
    };
    module.exports = (jsonString, options = {}) => {
        if (typeof jsonString !== 'string') {
            throw new TypeError(`Expected argument \`jsonString\` to be a \`string\`, got \`${typeof jsonString}\``);
        }
        const strip = options.whitespace === false ? stripWithoutWhitespace : stripWithWhitespace;
        let insideString = false;
        let insideComment = false;
        let offset = 0;
        let result = '';
        for (let i = 0; i < jsonString.length; i++) {
            const currentCharacter = jsonString[i];
            const nextCharacter = jsonString[i + 1];
            if (!insideComment && currentCharacter === '"') {
                const escaped = isEscaped(jsonString, i);
                if (!escaped) {
                    insideString = !insideString;
                }
            }
            if (insideString) {
                continue;
            }
            if (!insideComment && currentCharacter + nextCharacter === '//') {
                result += jsonString.slice(offset, i);
                offset = i;
                insideComment = singleComment;
                i++;
            }
            else if (insideComment === singleComment && currentCharacter + nextCharacter === '\r\n') {
                i++;
                insideComment = false;
                result += strip(jsonString, offset, i);
                offset = i;
                continue;
            }
            else if (insideComment === singleComment && currentCharacter === '\n') {
                insideComment = false;
                result += strip(jsonString, offset, i);
                offset = i;
            }
            else if (!insideComment && currentCharacter + nextCharacter === '/*') {
                result += jsonString.slice(offset, i);
                offset = i;
                insideComment = multiComment;
                i++;
                continue;
            }
            else if (insideComment === multiComment && currentCharacter + nextCharacter === '*/') {
                i++;
                insideComment = false;
                result += strip(jsonString, offset, i + 1);
                offset = i + 1;
                continue;
            }
        }
        return result + (insideComment ? strip(jsonString.slice(offset)) : jsonString.slice(offset));
    };
},
/* ignore/index.js */ function _(require, module, exports, __esModule, __esExport) {
    // A simple implementation of make-array
    function makeArray(subject) {
        return Array.isArray(subject)
            ? subject
            : [subject];
    }
    const EMPTY = '';
    const SPACE = ' ';
    const ESCAPE = '\\';
    const REGEX_TEST_BLANK_LINE = /^\s+$/;
    const REGEX_INVALID_TRAILING_BACKSLASH = /(?:[^\\]|^)\\$/;
    const REGEX_REPLACE_LEADING_EXCAPED_EXCLAMATION = /^\\!/;
    const REGEX_REPLACE_LEADING_EXCAPED_HASH = /^\\#/;
    const REGEX_SPLITALL_CRLF = /\r?\n/g;
    // /foo,
    // ./foo,
    // ../foo,
    // .
    // ..
    const REGEX_TEST_INVALID_PATH = /^\.*\/|^\.+$/;
    const SLASH = '/';
    // Do not use ternary expression here, since "istanbul ignore next" is buggy
    let TMP_KEY_IGNORE = 'node-ignore';
    /* istanbul ignore else */
    if (typeof Symbol !== 'undefined') {
        TMP_KEY_IGNORE = Symbol.for('node-ignore');
    }
    const KEY_IGNORE = TMP_KEY_IGNORE;
    const define = (object, key, value) => Object.defineProperty(object, key, { value });
    const REGEX_REGEXP_RANGE = /([0-z])-([0-z])/g;
    const RETURN_FALSE = () => false;
    // Sanitize the range of a regular expression
    // The cases are complicated, see test cases for details
    const sanitizeRange = range => range.replace(REGEX_REGEXP_RANGE, (match, from, to) => from.charCodeAt(0) <= to.charCodeAt(0)
        ? match
        // Invalid range (out of order) which is ok for gitignore rules but
        //   fatal for JavaScript regular expression, so eliminate it.
        : EMPTY);
    // See fixtures #59
    const cleanRangeBackSlash = slashes => {
        const { length } = slashes;
        return slashes.slice(0, length - length % 2);
    };
    // > If the pattern ends with a slash,
    // > it is removed for the purpose of the following description,
    // > but it would only find a match with a directory.
    // > In other words, foo/ will match a directory foo and paths underneath it,
    // > but will not match a regular file or a symbolic link foo
    // >  (this is consistent with the way how pathspec works in general in Git).
    // '`foo/`' will not match regular file '`foo`' or symbolic link '`foo`'
    // -> ignore-rules will not deal with it, because it costs extra `fs.stat` call
    //      you could use option `mark: true` with `glob`
    // '`foo/`' should not continue with the '`..`'
    const REPLACERS = [
        // > Trailing spaces are ignored unless they are quoted with backslash ("\")
        [
            // (a\ ) -> (a )
            // (a  ) -> (a)
            // (a \ ) -> (a  )
            /\\?\s+$/,
            match => match.indexOf('\\') === 0
                ? SPACE
                : EMPTY
        ],
        // replace (\ ) with ' '
        [
            /\\\s/g,
            () => SPACE
        ],
        // Escape metacharacters
        // which is written down by users but means special for regular expressions.
        // > There are 12 characters with special meanings:
        // > - the backslash \,
        // > - the caret ^,
        // > - the dollar sign $,
        // > - the period or dot .,
        // > - the vertical bar or pipe symbol |,
        // > - the question mark ?,
        // > - the asterisk or star *,
        // > - the plus sign +,
        // > - the opening parenthesis (,
        // > - the closing parenthesis ),
        // > - and the opening square bracket [,
        // > - the opening curly brace {,
        // > These special characters are often called "metacharacters".
        [
            /[\\$.|*+(){^]/g,
            match => `\\${match}`
        ],
        [
            // > a question mark (?) matches a single character
            /(?!\\)\?/g,
            () => '[^/]'
        ],
        // leading slash
        [
            // > A leading slash matches the beginning of the pathname.
            // > For example, "/*.c" matches "cat-file.c" but not "mozilla-sha1/sha1.c".
            // A leading slash matches the beginning of the pathname
            /^\//,
            () => '^'
        ],
        // replace special metacharacter slash after the leading slash
        [
            /\//g,
            () => '\\/'
        ],
        [
            // > A leading "**" followed by a slash means match in all directories.
            // > For example, "**/foo" matches file or directory "foo" anywhere,
            // > the same as pattern "foo".
            // > "**/foo/bar" matches file or directory "bar" anywhere that is directly
            // >   under directory "foo".
            // Notice that the '*'s have been replaced as '\\*'
            /^\^*\\\*\\\*\\\//,
            // '**/foo' <-> 'foo'
            () => '^(?:.*\\/)?'
        ],
        // starting
        [
            // there will be no leading '/'
            //   (which has been replaced by section "leading slash")
            // If starts with '**', adding a '^' to the regular expression also works
            /^(?=[^^])/,
            function startingReplacer() {
                // If has a slash `/` at the beginning or middle
                return !/\/(?!$)/.test(this)
                    // > Prior to 2.22.1
                    // > If the pattern does not contain a slash /,
                    // >   Git treats it as a shell glob pattern
                    // Actually, if there is only a trailing slash,
                    //   git also treats it as a shell glob pattern
                    // After 2.22.1 (compatible but clearer)
                    // > If there is a separator at the beginning or middle (or both)
                    // > of the pattern, then the pattern is relative to the directory
                    // > level of the particular .gitignore file itself.
                    // > Otherwise the pattern may also match at any level below
                    // > the .gitignore level.
                    ? '(?:^|\\/)'
                    // > Otherwise, Git treats the pattern as a shell glob suitable for
                    // >   consumption by fnmatch(3)
                    : '^';
            }
        ],
        // two globstars
        [
            // Use lookahead assertions so that we could match more than one `'/**'`
            /\\\/\\\*\\\*(?=\\\/|$)/g,
            // Zero, one or several directories
            // should not use '*', or it will be replaced by the next replacer
            // Check if it is not the last `'/**'`
            (_, index, str) => index + 6 < str.length
                // case: /**/
                // > A slash followed by two consecutive asterisks then a slash matches
                // >   zero or more directories.
                // > For example, "a/**/b" matches "a/b", "a/x/b", "a/x/y/b" and so on.
                // '/**/'
                ? '(?:\\/[^\\/]+)*'
                // case: /**
                // > A trailing `"/**"` matches everything inside.
                // #21: everything inside but it should not include the current folder
                : '\\/.+'
        ],
        // normal intermediate wildcards
        [
            // Never replace escaped '*'
            // ignore rule '\*' will match the path '*'
            // 'abc.*/' -> go
            // 'abc.*'  -> skip this rule,
            //    coz trailing single wildcard will be handed by [trailing wildcard]
            /(^|[^\\]+)(\\\*)+(?=.+)/g,
            // '*.js' matches '.js'
            // '*.js' doesn't match 'abc'
            (_, p1, p2) => {
                // 1.
                // > An asterisk "*" matches anything except a slash.
                // 2.
                // > Other consecutive asterisks are considered regular asterisks
                // > and will match according to the previous rules.
                const unescaped = p2.replace(/\\\*/g, '[^\\/]*');
                return p1 + unescaped;
            }
        ],
        [
            // unescape, revert step 3 except for back slash
            // For example, if a user escape a '\\*',
            // after step 3, the result will be '\\\\\\*'
            /\\\\\\(?=[$.|*+(){^])/g,
            () => ESCAPE
        ],
        [
            // '\\\\' -> '\\'
            /\\\\/g,
            () => ESCAPE
        ],
        [
            // > The range notation, e.g. [a-zA-Z],
            // > can be used to match one of the characters in a range.
            // `\` is escaped by step 3
            /(\\)?\[([^\]/]*?)(\\*)($|\])/g,
            (match, leadEscape, range, endEscape, close) => leadEscape === ESCAPE
                // '\\[bar]' -> '\\\\[bar\\]'
                ? `\\[${range}${cleanRangeBackSlash(endEscape)}${close}`
                : close === ']'
                    ? endEscape.length % 2 === 0
                        // A normal case, and it is a range notation
                        // '[bar]'
                        // '[bar\\\\]'
                        ? `[${sanitizeRange(range)}${endEscape}]`
                        // Invalid range notaton
                        // '[bar\\]' -> '[bar\\\\]'
                        : '[]'
                    : '[]'
        ],
        // ending
        [
            // 'js' will not match 'js.'
            // 'ab' will not match 'abc'
            /(?:[^*])$/,
            // WTF!
            // https://git-scm.com/docs/gitignore
            // changes in [2.22.1](https://git-scm.com/docs/gitignore/2.22.1)
            // which re-fixes #24, #38
            // > If there is a separator at the end of the pattern then the pattern
            // > will only match directories, otherwise the pattern can match both
            // > files and directories.
            // 'js*' will not match 'a.js'
            // 'js/' will not match 'a.js'
            // 'js' will match 'a.js' and 'a.js/'
            match => /\/$/.test(match)
                // foo/ will not match 'foo'
                ? `${match}$`
                // foo matches 'foo' and 'foo/'
                : `${match}(?=$|\\/$)`
        ],
        // trailing wildcard
        [
            /(\^|\\\/)?\\\*$/,
            (_, p1) => {
                const prefix = p1
                    // '\^':
                    // '/*' does not match EMPTY
                    // '/*' does not match everything
                    // '\\\/':
                    // 'abc/*' does not match 'abc/'
                    ? `${p1}[^/]+`
                    // 'a*' matches 'a'
                    // 'a*' matches 'aa'
                    : '[^/]*';
                return `${prefix}(?=$|\\/$)`;
            }
        ],
    ];
    // A simple cache, because an ignore rule only has only one certain meaning
    const regexCache = Object.create(null);
    // @param {pattern}
    const makeRegex = (pattern, ignoreCase) => {
        let source = regexCache[pattern];
        if (!source) {
            source = REPLACERS.reduce((prev, current) => prev.replace(current[0], current[1].bind(pattern)), pattern);
            regexCache[pattern] = source;
        }
        return ignoreCase
            ? new RegExp(source, 'i')
            : new RegExp(source);
    };
    const isString = subject => typeof subject === 'string';
    // > A blank line matches no files, so it can serve as a separator for readability.
    const checkPattern = pattern => pattern
        && isString(pattern)
        && !REGEX_TEST_BLANK_LINE.test(pattern)
        && !REGEX_INVALID_TRAILING_BACKSLASH.test(pattern)
        // > A line starting with # serves as a comment.
        && pattern.indexOf('#') !== 0;
    const splitPattern = pattern => pattern.split(REGEX_SPLITALL_CRLF);
    class IgnoreRule {
        constructor(origin, pattern, negative, regex) {
            this.origin = origin;
            this.pattern = pattern;
            this.negative = negative;
            this.regex = regex;
        }
    }
    const createRule = (pattern, ignoreCase) => {
        const origin = pattern;
        let negative = false;
        // > An optional prefix "!" which negates the pattern;
        if (pattern.indexOf('!') === 0) {
            negative = true;
            pattern = pattern.substr(1);
        }
        pattern = pattern
            // > Put a backslash ("\") in front of the first "!" for patterns that
            // >   begin with a literal "!", for example, `"\!important!.txt"`.
            .replace(REGEX_REPLACE_LEADING_EXCAPED_EXCLAMATION, '!')
            // > Put a backslash ("\") in front of the first hash for patterns that
            // >   begin with a hash.
            .replace(REGEX_REPLACE_LEADING_EXCAPED_HASH, '#');
        const regex = makeRegex(pattern, ignoreCase);
        return new IgnoreRule(origin, pattern, negative, regex);
    };
    const throwError = (message, Ctor) => {
        throw new Ctor(message);
    };
    const checkPath = (path, originalPath, doThrow) => {
        if (!isString(path)) {
            return doThrow(`path must be a string, but got \`${originalPath}\``, TypeError);
        }
        // We don't know if we should ignore EMPTY, so throw
        if (!path) {
            return doThrow(`path must not be empty`, TypeError);
        }
        // Check if it is a relative path
        if (checkPath.isNotRelative(path)) {
            const r = '`path.relative()`d';
            return doThrow(`path should be a ${r} string, but got "${originalPath}"`, RangeError);
        }
        return true;
    };
    const isNotRelative = path => REGEX_TEST_INVALID_PATH.test(path);
    checkPath.isNotRelative = isNotRelative;
    checkPath.convert = p => p;
    class Ignore {
        constructor({ ignorecase = true, ignoreCase = ignorecase, allowRelativePaths = false } = {}) {
            define(this, KEY_IGNORE, true);
            this._rules = [];
            this._ignoreCase = ignoreCase;
            this._allowRelativePaths = allowRelativePaths;
            this._initCache();
        }
        _initCache() {
            this._ignoreCache = Object.create(null);
            this._testCache = Object.create(null);
        }
        _addPattern(pattern) {
            // #32
            if (pattern && pattern[KEY_IGNORE]) {
                this._rules = this._rules.concat(pattern._rules);
                this._added = true;
                return;
            }
            if (checkPattern(pattern)) {
                const rule = createRule(pattern, this._ignoreCase);
                this._added = true;
                this._rules.push(rule);
            }
        }
        // @param {Array<string> | string | Ignore} pattern
        add(pattern) {
            this._added = false;
            makeArray(isString(pattern)
                ? splitPattern(pattern)
                : pattern).forEach(this._addPattern, this);
            // Some rules have just added to the ignore,
            // making the behavior changed.
            if (this._added) {
                this._initCache();
            }
            return this;
        }
        // legacy
        addPattern(pattern) {
            return this.add(pattern);
        }
        //          |           ignored : unignored
        // negative |   0:0   |   0:1   |   1:0   |   1:1
        // -------- | ------- | ------- | ------- | --------
        //     0    |  TEST   |  TEST   |  SKIP   |    X
        //     1    |  TESTIF |  SKIP   |  TEST   |    X
        // - SKIP: always skip
        // - TEST: always test
        // - TESTIF: only test if checkUnignored
        // - X: that never happen
        // @param {boolean} whether should check if the path is unignored,
        //   setting `checkUnignored` to `false` could reduce additional
        //   path matching.
        // @returns {TestResult} true if a file is ignored
        _testOne(path, checkUnignored) {
            let ignored = false;
            let unignored = false;
            this._rules.forEach(rule => {
                const { negative } = rule;
                if (unignored === negative && ignored !== unignored
                    || negative && !ignored && !unignored && !checkUnignored) {
                    return;
                }
                const matched = rule.regex.test(path);
                if (matched) {
                    ignored = !negative;
                    unignored = negative;
                }
            });
            return {
                ignored,
                unignored
            };
        }
        // @returns {TestResult}
        _test(originalPath, cache, checkUnignored, slices) {
            const path = originalPath
                // Supports nullable path
                && checkPath.convert(originalPath);
            checkPath(path, originalPath, this._allowRelativePaths
                ? RETURN_FALSE
                : throwError);
            return this._t(path, cache, checkUnignored, slices);
        }
        _t(path, cache, checkUnignored, slices) {
            if (path in cache) {
                return cache[path];
            }
            if (!slices) {
                // path/to/a.js
                // ['path', 'to', 'a.js']
                slices = path.split(SLASH);
            }
            slices.pop();
            // If the path has no parent directory, just test it
            if (!slices.length) {
                return cache[path] = this._testOne(path, checkUnignored);
            }
            const parent = this._t(slices.join(SLASH) + SLASH, cache, checkUnignored, slices);
            // If the path contains a parent directory, check the parent first
            return cache[path] = parent.ignored
                // > It is not possible to re-include a file if a parent directory of
                // >   that file is excluded.
                ? parent
                : this._testOne(path, checkUnignored);
        }
        ignores(path) {
            return this._test(path, this._ignoreCache, false).ignored;
        }
        createFilter() {
            return path => !this.ignores(path);
        }
        filter(paths) {
            return makeArray(paths).filter(this.createFilter());
        }
        // @returns {TestResult}
        test(path) {
            return this._test(path, this._testCache, true);
        }
    }
    const factory = options => new Ignore(options);
    const isPathValid = path => checkPath(path && checkPath.convert(path), path, RETURN_FALSE);
    factory.isPathValid = isPathValid;
    // Fixes typescript
    factory.default = factory;
    module.exports = factory;
    // Windows
    // --------------------------------------------------------------
    /* istanbul ignore if */
    if (
    // Detect `process` so that it can run in browsers.
    typeof process !== 'undefined'
        && (process.env && process.env.IGNORE_TEST_WIN32
            || process.platform === 'win32')) {
        /* eslint no-control-regex: "off" */
        const makePosix = str => /^\\\\\?\\/.test(str)
            || /["<>|\u0000-\u001F]+/u.test(str)
            ? str
            : str.replace(/\\/g, '/');
        checkPath.convert = makePosix;
        // 'C:\\foo'     <- 'C:\\foo' has been converted to 'C:/'
        // 'd:\\foo'
        const REGIX_IS_WINDOWS_PATH_ABSOLUTE = /^[a-z]:\//i;
        checkPath.isNotRelative = path => REGIX_IS_WINDOWS_PATH_ABSOLUTE.test(path)
            || isNotRelative(path);
    }
},
/* minimatch/minimatch.js */ function _(require, module, exports, __esModule, __esExport) {
    module.exports = minimatch;
    minimatch.Minimatch = Minimatch;
    var path = (function () { try {
        return require('path');
    }
    catch (e) { } }()) || {
        sep: '/'
    };
    minimatch.sep = path.sep;
    var GLOBSTAR = minimatch.GLOBSTAR = Minimatch.GLOBSTAR = {};
    var expand = require(230) /* brace-expansion */;
    var plTypes = {
        '!': { open: '(?:(?!(?:', close: '))[^/]*?)' },
        '?': { open: '(?:', close: ')?' },
        '+': { open: '(?:', close: ')+' },
        '*': { open: '(?:', close: ')*' },
        '@': { open: '(?:', close: ')' }
    };
    // any single thing other than /
    // don't need to escape / when using new RegExp()
    var qmark = '[^/]';
    // * => any number of characters
    var star = qmark + '*?';
    // ** when dots are allowed.  Anything goes, except .. and .
    // not (^ or / followed by one or two dots followed by $ or /),
    // followed by anything, any number of times.
    var twoStarDot = '(?:(?!(?:\\\/|^)(?:\\.{1,2})($|\\\/)).)*?';
    // not a ^ or / followed by a dot,
    // followed by anything, any number of times.
    var twoStarNoDot = '(?:(?!(?:\\\/|^)\\.).)*?';
    // characters that need to be escaped in RegExp.
    var reSpecials = charSet('().*{}+?[]^$\\!');
    // "abc" -> { a:true, b:true, c:true }
    function charSet(s) {
        return s.split('').reduce(function (set, c) {
            set[c] = true;
            return set;
        }, {});
    }
    // normalizes slashes.
    var slashSplit = /\/+/;
    minimatch.filter = filter;
    function filter(pattern, options) {
        options = options || {};
        return function (p, i, list) {
            return minimatch(p, pattern, options);
        };
    }
    function ext(a, b) {
        b = b || {};
        var t = {};
        Object.keys(a).forEach(function (k) {
            t[k] = a[k];
        });
        Object.keys(b).forEach(function (k) {
            t[k] = b[k];
        });
        return t;
    }
    minimatch.defaults = function (def) {
        if (!def || typeof def !== 'object' || !Object.keys(def).length) {
            return minimatch;
        }
        var orig = minimatch;
        var m = function minimatch(p, pattern, options) {
            return orig(p, pattern, ext(def, options));
        };
        m.Minimatch = function Minimatch(pattern, options) {
            return new orig.Minimatch(pattern, ext(def, options));
        };
        m.Minimatch.defaults = function defaults(options) {
            return orig.defaults(ext(def, options)).Minimatch;
        };
        m.filter = function filter(pattern, options) {
            return orig.filter(pattern, ext(def, options));
        };
        m.defaults = function defaults(options) {
            return orig.defaults(ext(def, options));
        };
        m.makeRe = function makeRe(pattern, options) {
            return orig.makeRe(pattern, ext(def, options));
        };
        m.braceExpand = function braceExpand(pattern, options) {
            return orig.braceExpand(pattern, ext(def, options));
        };
        m.match = function (list, pattern, options) {
            return orig.match(list, pattern, ext(def, options));
        };
        return m;
    };
    Minimatch.defaults = function (def) {
        return minimatch.defaults(def).Minimatch;
    };
    function minimatch(p, pattern, options) {
        assertValidPattern(pattern);
        if (!options)
            options = {};
        // shortcut: comments match nothing.
        if (!options.nocomment && pattern.charAt(0) === '#') {
            return false;
        }
        return new Minimatch(pattern, options).match(p);
    }
    function Minimatch(pattern, options) {
        if (!(this instanceof Minimatch)) {
            return new Minimatch(pattern, options);
        }
        assertValidPattern(pattern);
        if (!options)
            options = {};
        pattern = pattern.trim();
        // windows support: need to use /, not \
        if (!options.allowWindowsEscape && path.sep !== '/') {
            pattern = pattern.split(path.sep).join('/');
        }
        this.options = options;
        this.set = [];
        this.pattern = pattern;
        this.regexp = null;
        this.negate = false;
        this.comment = false;
        this.empty = false;
        this.partial = !!options.partial;
        // make the set of regexps etc.
        this.make();
    }
    Minimatch.prototype.debug = function () { };
    Minimatch.prototype.make = make;
    function make() {
        var pattern = this.pattern;
        var options = this.options;
        // empty patterns and comments match nothing.
        if (!options.nocomment && pattern.charAt(0) === '#') {
            this.comment = true;
            return;
        }
        if (!pattern) {
            this.empty = true;
            return;
        }
        // step 1: figure out negation, etc.
        this.parseNegate();
        // step 2: expand braces
        var set = this.globSet = this.braceExpand();
        if (options.debug)
            this.debug = function debug() { console.error.apply(console, arguments); };
        this.debug(this.pattern, set);
        // step 3: now we have a set, so turn each one into a series of path-portion
        // matching patterns.
        // These will be regexps, except in the case of "**", which is
        // set to the GLOBSTAR object for globstar behavior,
        // and will not contain any / characters
        set = this.globParts = set.map(function (s) {
            return s.split(slashSplit);
        });
        this.debug(this.pattern, set);
        // glob --> regexps
        set = set.map(function (s, si, set) {
            return s.map(this.parse, this);
        }, this);
        this.debug(this.pattern, set);
        // filter out everything that didn't compile properly.
        set = set.filter(function (s) {
            return s.indexOf(false) === -1;
        });
        this.debug(this.pattern, set);
        this.set = set;
    }
    Minimatch.prototype.parseNegate = parseNegate;
    function parseNegate() {
        var pattern = this.pattern;
        var negate = false;
        var options = this.options;
        var negateOffset = 0;
        if (options.nonegate)
            return;
        for (var i = 0, l = pattern.length; i < l && pattern.charAt(i) === '!'; i++) {
            negate = !negate;
            negateOffset++;
        }
        if (negateOffset)
            this.pattern = pattern.substr(negateOffset);
        this.negate = negate;
    }
    // Brace expansion:
    // a{b,c}d -> abd acd
    // a{b,}c -> abc ac
    // a{0..3}d -> a0d a1d a2d a3d
    // a{b,c{d,e}f}g -> abg acdfg acefg
    // a{b,c}d{e,f}g -> abdeg acdeg abdeg abdfg
    //
    // Invalid sets are not expanded.
    // a{2..}b -> a{2..}b
    // a{b}c -> a{b}c
    minimatch.braceExpand = function (pattern, options) {
        return braceExpand(pattern, options);
    };
    Minimatch.prototype.braceExpand = braceExpand;
    function braceExpand(pattern, options) {
        if (!options) {
            if (this instanceof Minimatch) {
                options = this.options;
            }
            else {
                options = {};
            }
        }
        pattern = typeof pattern === 'undefined'
            ? this.pattern : pattern;
        assertValidPattern(pattern);
        // Thanks to Yeting Li <https://github.com/yetingli> for
        // improving this regexp to avoid a ReDOS vulnerability.
        if (options.nobrace || !/\{(?:(?!\{).)*\}/.test(pattern)) {
            // shortcut. no need to expand.
            return [pattern];
        }
        return expand(pattern);
    }
    var MAX_PATTERN_LENGTH = 1024 * 64;
    var assertValidPattern = function (pattern) {
        if (typeof pattern !== 'string') {
            throw new TypeError('invalid pattern');
        }
        if (pattern.length > MAX_PATTERN_LENGTH) {
            throw new TypeError('pattern is too long');
        }
    };
    // parse a component of the expanded set.
    // At this point, no pattern may contain "/" in it
    // so we're going to return a 2d array, where each entry is the full
    // pattern, split on '/', and then turned into a regular expression.
    // A regexp is made at the end which joins each array with an
    // escaped /, and another full one which joins each regexp with |.
    //
    // Following the lead of Bash 4.1, note that "**" only has special meaning
    // when it is the *only* thing in a path portion.  Otherwise, any series
    // of * is equivalent to a single *.  Globstar behavior is enabled by
    // default, and can be disabled by setting options.noglobstar.
    Minimatch.prototype.parse = parse;
    var SUBPARSE = {};
    function parse(pattern, isSub) {
        assertValidPattern(pattern);
        var options = this.options;
        // shortcuts
        if (pattern === '**') {
            if (!options.noglobstar)
                return GLOBSTAR;
            else
                pattern = '*';
        }
        if (pattern === '')
            return '';
        var re = '';
        var hasMagic = !!options.nocase;
        var escaping = false;
        // ? => one single character
        var patternListStack = [];
        var negativeLists = [];
        var stateChar;
        var inClass = false;
        var reClassStart = -1;
        var classStart = -1;
        // . and .. never match anything that doesn't start with .,
        // even when options.dot is set.
        var patternStart = pattern.charAt(0) === '.' ? '' // anything
            // not (start or / followed by . or .. followed by / or end)
            : options.dot ? '(?!(?:^|\\\/)\\.{1,2}(?:$|\\\/))'
                : '(?!\\.)';
        var self = this;
        function clearStateChar() {
            if (stateChar) {
                // we had some state-tracking character
                // that wasn't consumed by this pass.
                switch (stateChar) {
                    case '*':
                        re += star;
                        hasMagic = true;
                        break;
                    case '?':
                        re += qmark;
                        hasMagic = true;
                        break;
                    default:
                        re += '\\' + stateChar;
                        break;
                }
                self.debug('clearStateChar %j %j', stateChar, re);
                stateChar = false;
            }
        }
        for (var i = 0, len = pattern.length, c; (i < len) && (c = pattern.charAt(i)); i++) {
            this.debug('%s\t%s %s %j', pattern, i, re, c);
            // skip over any that are escaped.
            if (escaping && reSpecials[c]) {
                re += '\\' + c;
                escaping = false;
                continue;
            }
            switch (c) {
                /* istanbul ignore next */
                case '/': {
                    // completely not allowed, even escaped.
                    // Should already be path-split by now.
                    return false;
                }
                case '\\':
                    clearStateChar();
                    escaping = true;
                    continue;
                // the various stateChar values
                // for the "extglob" stuff.
                case '?':
                case '*':
                case '+':
                case '@':
                case '!':
                    this.debug('%s\t%s %s %j <-- stateChar', pattern, i, re, c);
                    // all of those are literals inside a class, except that
                    // the glob [!a] means [^a] in regexp
                    if (inClass) {
                        this.debug('  in class');
                        if (c === '!' && i === classStart + 1)
                            c = '^';
                        re += c;
                        continue;
                    }
                    // if we already have a stateChar, then it means
                    // that there was something like ** or +? in there.
                    // Handle the stateChar, then proceed with this one.
                    self.debug('call clearStateChar %j', stateChar);
                    clearStateChar();
                    stateChar = c;
                    // if extglob is disabled, then +(asdf|foo) isn't a thing.
                    // just clear the statechar *now*, rather than even diving into
                    // the patternList stuff.
                    if (options.noext)
                        clearStateChar();
                    continue;
                case '(':
                    if (inClass) {
                        re += '(';
                        continue;
                    }
                    if (!stateChar) {
                        re += '\\(';
                        continue;
                    }
                    patternListStack.push({
                        type: stateChar,
                        start: i - 1,
                        reStart: re.length,
                        open: plTypes[stateChar].open,
                        close: plTypes[stateChar].close
                    });
                    // negation is (?:(?!js)[^/]*)
                    re += stateChar === '!' ? '(?:(?!(?:' : '(?:';
                    this.debug('plType %j %j', stateChar, re);
                    stateChar = false;
                    continue;
                case ')':
                    if (inClass || !patternListStack.length) {
                        re += '\\)';
                        continue;
                    }
                    clearStateChar();
                    hasMagic = true;
                    var pl = patternListStack.pop();
                    // negation is (?:(?!js)[^/]*)
                    // The others are (?:<pattern>)<type>
                    re += pl.close;
                    if (pl.type === '!') {
                        negativeLists.push(pl);
                    }
                    pl.reEnd = re.length;
                    continue;
                case '|':
                    if (inClass || !patternListStack.length || escaping) {
                        re += '\\|';
                        escaping = false;
                        continue;
                    }
                    clearStateChar();
                    re += '|';
                    continue;
                // these are mostly the same in regexp and glob
                case '[':
                    // swallow any state-tracking char before the [
                    clearStateChar();
                    if (inClass) {
                        re += '\\' + c;
                        continue;
                    }
                    inClass = true;
                    classStart = i;
                    reClassStart = re.length;
                    re += c;
                    continue;
                case ']':
                    //  a right bracket shall lose its special
                    //  meaning and represent itself in
                    //  a bracket expression if it occurs
                    //  first in the list.  -- POSIX.2 2.8.3.2
                    if (i === classStart + 1 || !inClass) {
                        re += '\\' + c;
                        escaping = false;
                        continue;
                    }
                    // handle the case where we left a class open.
                    // "[z-a]" is valid, equivalent to "\[z-a\]"
                    // split where the last [ was, make sure we don't have
                    // an invalid re. if so, re-walk the contents of the
                    // would-be class to re-translate any characters that
                    // were passed through as-is
                    // TODO: It would probably be faster to determine this
                    // without a try/catch and a new RegExp, but it's tricky
                    // to do safely.  For now, this is safe and works.
                    var cs = pattern.substring(classStart + 1, i);
                    try {
                        RegExp('[' + cs + ']');
                    }
                    catch (er) {
                        // not a valid class!
                        var sp = this.parse(cs, SUBPARSE);
                        re = re.substr(0, reClassStart) + '\\[' + sp[0] + '\\]';
                        hasMagic = hasMagic || sp[1];
                        inClass = false;
                        continue;
                    }
                    // finish up the class.
                    hasMagic = true;
                    inClass = false;
                    re += c;
                    continue;
                default:
                    // swallow any state char that wasn't consumed
                    clearStateChar();
                    if (escaping) {
                        // no need
                        escaping = false;
                    }
                    else if (reSpecials[c]
                        && !(c === '^' && inClass)) {
                        re += '\\';
                    }
                    re += c;
            } // switch
        } // for
        // handle the case where we left a class open.
        // "[abc" is valid, equivalent to "\[abc"
        if (inClass) {
            // split where the last [ was, and escape it
            // this is a huge pita.  We now have to re-walk
            // the contents of the would-be class to re-translate
            // any characters that were passed through as-is
            cs = pattern.substr(classStart + 1);
            sp = this.parse(cs, SUBPARSE);
            re = re.substr(0, reClassStart) + '\\[' + sp[0];
            hasMagic = hasMagic || sp[1];
        }
        // handle the case where we had a +( thing at the *end*
        // of the pattern.
        // each pattern list stack adds 3 chars, and we need to go through
        // and escape any | chars that were passed through as-is for the regexp.
        // Go through and escape them, taking care not to double-escape any
        // | chars that were already escaped.
        for (pl = patternListStack.pop(); pl; pl = patternListStack.pop()) {
            var tail = re.slice(pl.reStart + pl.open.length);
            this.debug('setting tail', re, pl);
            // maybe some even number of \, then maybe 1 \, followed by a |
            tail = tail.replace(/((?:\\{2}){0,64})(\\?)\|/g, function (_, $1, $2) {
                if (!$2) {
                    // the | isn't already escaped, so escape it.
                    $2 = '\\';
                }
                // need to escape all those slashes *again*, without escaping the
                // one that we need for escaping the | character.  As it works out,
                // escaping an even number of slashes can be done by simply repeating
                // it exactly after itself.  That's why this trick works.
                //
                // I am sorry that you have to see this.
                return $1 + $1 + $2 + '|';
            });
            this.debug('tail=%j\n   %s', tail, tail, pl, re);
            var t = pl.type === '*' ? star
                : pl.type === '?' ? qmark
                    : '\\' + pl.type;
            hasMagic = true;
            re = re.slice(0, pl.reStart) + t + '\\(' + tail;
        }
        // handle trailing things that only matter at the very end.
        clearStateChar();
        if (escaping) {
            // trailing \\
            re += '\\\\';
        }
        // only need to apply the nodot start if the re starts with
        // something that could conceivably capture a dot
        var addPatternStart = false;
        switch (re.charAt(0)) {
            case '[':
            case '.':
            case '(': addPatternStart = true;
        }
        // Hack to work around lack of negative lookbehind in JS
        // A pattern like: *.!(x).!(y|z) needs to ensure that a name
        // like 'a.xyz.yz' doesn't match.  So, the first negative
        // lookahead, has to look ALL the way ahead, to the end of
        // the pattern.
        for (var n = negativeLists.length - 1; n > -1; n--) {
            var nl = negativeLists[n];
            var nlBefore = re.slice(0, nl.reStart);
            var nlFirst = re.slice(nl.reStart, nl.reEnd - 8);
            var nlLast = re.slice(nl.reEnd - 8, nl.reEnd);
            var nlAfter = re.slice(nl.reEnd);
            nlLast += nlAfter;
            // Handle nested stuff like *(*.js|!(*.json)), where open parens
            // mean that we should *not* include the ) in the bit that is considered
            // "after" the negated section.
            var openParensBefore = nlBefore.split('(').length - 1;
            var cleanAfter = nlAfter;
            for (i = 0; i < openParensBefore; i++) {
                cleanAfter = cleanAfter.replace(/\)[+*?]?/, '');
            }
            nlAfter = cleanAfter;
            var dollar = '';
            if (nlAfter === '' && isSub !== SUBPARSE) {
                dollar = '$';
            }
            var newRe = nlBefore + nlFirst + nlAfter + dollar + nlLast;
            re = newRe;
        }
        // if the re is not "" at this point, then we need to make sure
        // it doesn't match against an empty path part.
        // Otherwise a/* will match a/, which it should not.
        if (re !== '' && hasMagic) {
            re = '(?=.)' + re;
        }
        if (addPatternStart) {
            re = patternStart + re;
        }
        // parsing just a piece of a larger pattern.
        if (isSub === SUBPARSE) {
            return [re, hasMagic];
        }
        // skip the regexp for non-magical patterns
        // unescape anything in it, though, so that it'll be
        // an exact match against a file etc.
        if (!hasMagic) {
            return globUnescape(pattern);
        }
        var flags = options.nocase ? 'i' : '';
        try {
            var regExp = new RegExp('^' + re + '$', flags);
        }
        catch (er) /* istanbul ignore next - should be impossible */ {
            // If it was an invalid regular expression, then it can't match
            // anything.  This trick looks for a character after the end of
            // the string, which is of course impossible, except in multi-line
            // mode, but it's not a /m regex.
            return new RegExp('$.');
        }
        regExp._glob = pattern;
        regExp._src = re;
        return regExp;
    }
    minimatch.makeRe = function (pattern, options) {
        return new Minimatch(pattern, options || {}).makeRe();
    };
    Minimatch.prototype.makeRe = makeRe;
    function makeRe() {
        if (this.regexp || this.regexp === false)
            return this.regexp;
        // at this point, this.set is a 2d array of partial
        // pattern strings, or "**".
        //
        // It's better to use .match().  This function shouldn't
        // be used, really, but it's pretty convenient sometimes,
        // when you just want to work with a regex.
        var set = this.set;
        if (!set.length) {
            this.regexp = false;
            return this.regexp;
        }
        var options = this.options;
        var twoStar = options.noglobstar ? star
            : options.dot ? twoStarDot
                : twoStarNoDot;
        var flags = options.nocase ? 'i' : '';
        var re = set.map(function (pattern) {
            return pattern.map(function (p) {
                return (p === GLOBSTAR) ? twoStar
                    : (typeof p === 'string') ? regExpEscape(p)
                        : p._src;
            }).join('\\\/');
        }).join('|');
        // must match entire pattern
        // ending in a * or ** will make it less strict.
        re = '^(?:' + re + ')$';
        // can match anything, as long as it's not this.
        if (this.negate)
            re = '^(?!' + re + ').*$';
        try {
            this.regexp = new RegExp(re, flags);
        }
        catch (ex) /* istanbul ignore next - should be impossible */ {
            this.regexp = false;
        }
        return this.regexp;
    }
    minimatch.match = function (list, pattern, options) {
        options = options || {};
        var mm = new Minimatch(pattern, options);
        list = list.filter(function (f) {
            return mm.match(f);
        });
        if (mm.options.nonull && !list.length) {
            list.push(pattern);
        }
        return list;
    };
    Minimatch.prototype.match = function match(f, partial) {
        if (typeof partial === 'undefined')
            partial = this.partial;
        this.debug('match', f, this.pattern);
        // short-circuit in the case of busted things.
        // comments, etc.
        if (this.comment)
            return false;
        if (this.empty)
            return f === '';
        if (f === '/' && partial)
            return true;
        var options = this.options;
        // windows: need to use /, not \
        if (path.sep !== '/') {
            f = f.split(path.sep).join('/');
        }
        // treat the test path as a set of pathparts.
        f = f.split(slashSplit);
        this.debug(this.pattern, 'split', f);
        // just ONE of the pattern sets in this.set needs to match
        // in order for it to be valid.  If negating, then just one
        // match means that we have failed.
        // Either way, return on the first hit.
        var set = this.set;
        this.debug(this.pattern, 'set', set);
        // Find the basename of the path by looking for the last non-empty segment
        var filename;
        var i;
        for (i = f.length - 1; i >= 0; i--) {
            filename = f[i];
            if (filename)
                break;
        }
        for (i = 0; i < set.length; i++) {
            var pattern = set[i];
            var file = f;
            if (options.matchBase && pattern.length === 1) {
                file = [filename];
            }
            var hit = this.matchOne(file, pattern, partial);
            if (hit) {
                if (options.flipNegate)
                    return true;
                return !this.negate;
            }
        }
        // didn't get any hits.  this is success if it's a negative
        // pattern, failure otherwise.
        if (options.flipNegate)
            return false;
        return this.negate;
    };
    // set partial to true to test if, for example,
    // "/a/b" matches the start of "/*/b/*/d"
    // Partial means, if you run out of file before you run
    // out of pattern, then that's fine, as long as all
    // the parts match.
    Minimatch.prototype.matchOne = function (file, pattern, partial) {
        var options = this.options;
        this.debug('matchOne', { 'this': this, file: file, pattern: pattern });
        this.debug('matchOne', file.length, pattern.length);
        for (var fi = 0, pi = 0, fl = file.length, pl = pattern.length; (fi < fl) && (pi < pl); fi++, pi++) {
            this.debug('matchOne loop');
            var p = pattern[pi];
            var f = file[fi];
            this.debug(pattern, p, f);
            // should be impossible.
            // some invalid regexp stuff in the set.
            /* istanbul ignore if */
            if (p === false)
                return false;
            if (p === GLOBSTAR) {
                this.debug('GLOBSTAR', [pattern, p, f]);
                // "**"
                // a/**/b/**/c would match the following:
                // a/b/x/y/z/c
                // a/x/y/z/b/c
                // a/b/x/b/x/c
                // a/b/c
                // To do this, take the rest of the pattern after
                // the **, and see if it would match the file remainder.
                // If so, return success.
                // If not, the ** "swallows" a segment, and try again.
                // This is recursively awful.
                //
                // a/**/b/**/c matching a/b/x/y/z/c
                // - a matches a
                // - doublestar
                //   - matchOne(b/x/y/z/c, b/**/c)
                //     - b matches b
                //     - doublestar
                //       - matchOne(x/y/z/c, c) -> no
                //       - matchOne(y/z/c, c) -> no
                //       - matchOne(z/c, c) -> no
                //       - matchOne(c, c) yes, hit
                var fr = fi;
                var pr = pi + 1;
                if (pr === pl) {
                    this.debug('** at the end');
                    // a ** at the end will just swallow the rest.
                    // We have found a match.
                    // however, it will not swallow /.x, unless
                    // options.dot is set.
                    // . and .. are *never* matched by **, for explosively
                    // exponential reasons.
                    for (; fi < fl; fi++) {
                        if (file[fi] === '.' || file[fi] === '..' ||
                            (!options.dot && file[fi].charAt(0) === '.'))
                            return false;
                    }
                    return true;
                }
                // ok, let's see if we can swallow whatever we can.
                while (fr < fl) {
                    var swallowee = file[fr];
                    this.debug('\nglobstar while', file, fr, pattern, pr, swallowee);
                    // XXX remove this slice.  Just pass the start index.
                    if (this.matchOne(file.slice(fr), pattern.slice(pr), partial)) {
                        this.debug('globstar found match!', fr, fl, swallowee);
                        // found a match.
                        return true;
                    }
                    else {
                        // can't swallow "." or ".." ever.
                        // can only swallow ".foo" when explicitly asked.
                        if (swallowee === '.' || swallowee === '..' ||
                            (!options.dot && swallowee.charAt(0) === '.')) {
                            this.debug('dot detected!', file, fr, pattern, pr);
                            break;
                        }
                        // ** swallows a segment, and continue.
                        this.debug('globstar swallow a segment, and continue');
                        fr++;
                    }
                }
                // no match was found.
                // However, in partial mode, we can't say this is necessarily over.
                // If there's more *pattern* left, then
                /* istanbul ignore if */
                if (partial) {
                    // ran out of file
                    this.debug('\n>>> no match, partial?', file, fr, pattern, pr);
                    if (fr === fl)
                        return true;
                }
                return false;
            }
            // something other than **
            // non-magic patterns just have to match exactly
            // patterns with magic have been turned into regexps.
            var hit;
            if (typeof p === 'string') {
                hit = f === p;
                this.debug('string match', p, f, hit);
            }
            else {
                hit = f.match(p);
                this.debug('pattern match', p, f, hit);
            }
            if (!hit)
                return false;
        }
        // Note: ending in / means that we'll get a final ""
        // at the end of the pattern.  This can only match a
        // corresponding "" at the end of the file.
        // If the file ends in /, then it can only match a
        // a pattern that ends in /, unless the pattern just
        // doesn't have any more for it. But, a/b/ should *not*
        // match "a/b/*", even though "" matches against the
        // [^/]*? pattern, except in partial mode, where it might
        // simply not be reached yet.
        // However, a/b/ should still satisfy a/*
        // now either we fell off the end of the pattern, or we're done.
        if (fi === fl && pi === pl) {
            // ran out of pattern and filename at the same time.
            // an exact hit!
            return true;
        }
        else if (fi === fl) {
            // ran out of file, but still had pattern left.
            // this is ok if we're doing the match as part of
            // a glob fs traversal.
            return partial;
        }
        else /* istanbul ignore else */ if (pi === pl) {
            // ran out of pattern, still have file left.
            // this is only acceptable if we're on the very last
            // empty segment of a file with a trailing slash.
            // a/* should match a/b/
            return (fi === fl - 1) && (file[fi] === '');
        }
        // should be unreachable.
        /* istanbul ignore next */
        throw new Error('wtf?');
    };
    // replace stuff like \* with *
    function globUnescape(s) {
        return s.replace(/\\(.)/g, '$1');
    }
    function regExpEscape(s) {
        return s.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, '\\$&');
    }
},
/* brace-expansion/index.js */ function _(require, module, exports, __esModule, __esExport) {
    var concatMap = require(231) /* concat-map */;
    var balanced = require(232) /* balanced-match */;
    module.exports = expandTop;
    var escSlash = '\0SLASH' + Math.random() + '\0';
    var escOpen = '\0OPEN' + Math.random() + '\0';
    var escClose = '\0CLOSE' + Math.random() + '\0';
    var escComma = '\0COMMA' + Math.random() + '\0';
    var escPeriod = '\0PERIOD' + Math.random() + '\0';
    function numeric(str) {
        return parseInt(str, 10) == str
            ? parseInt(str, 10)
            : str.charCodeAt(0);
    }
    function escapeBraces(str) {
        return str.split('\\\\').join(escSlash)
            .split('\\{').join(escOpen)
            .split('\\}').join(escClose)
            .split('\\,').join(escComma)
            .split('\\.').join(escPeriod);
    }
    function unescapeBraces(str) {
        return str.split(escSlash).join('\\')
            .split(escOpen).join('{')
            .split(escClose).join('}')
            .split(escComma).join(',')
            .split(escPeriod).join('.');
    }
    // Basically just str.split(","), but handling cases
    // where we have nested braced sections, which should be
    // treated as individual members, like {a,{b,c},d}
    function parseCommaParts(str) {
        if (!str)
            return [''];
        var parts = [];
        var m = balanced('{', '}', str);
        if (!m)
            return str.split(',');
        var pre = m.pre;
        var body = m.body;
        var post = m.post;
        var p = pre.split(',');
        p[p.length - 1] += '{' + body + '}';
        var postParts = parseCommaParts(post);
        if (post.length) {
            p[p.length - 1] += postParts.shift();
            p.push.apply(p, postParts);
        }
        parts.push.apply(parts, p);
        return parts;
    }
    function expandTop(str) {
        if (!str)
            return [];
        // I don't know why Bash 4.3 does this, but it does.
        // Anything starting with {} will have the first two bytes preserved
        // but *only* at the top level, so {},a}b will not expand to anything,
        // but a{},b}c will be expanded to [a}c,abc].
        // One could argue that this is a bug in Bash, but since the goal of
        // this module is to match Bash's rules, we escape a leading {}
        if (str.substr(0, 2) === '{}') {
            str = '\\{\\}' + str.substr(2);
        }
        return expand(escapeBraces(str), true).map(unescapeBraces);
    }
    function identity(e) {
        return e;
    }
    function embrace(str) {
        return '{' + str + '}';
    }
    function isPadded(el) {
        return /^-?0\d/.test(el);
    }
    function lte(i, y) {
        return i <= y;
    }
    function gte(i, y) {
        return i >= y;
    }
    function expand(str, isTop) {
        var expansions = [];
        var m = balanced('{', '}', str);
        if (!m || /\$$/.test(m.pre))
            return [str];
        var isNumericSequence = /^-?\d+\.\.-?\d+(?:\.\.-?\d+)?$/.test(m.body);
        var isAlphaSequence = /^[a-zA-Z]\.\.[a-zA-Z](?:\.\.-?\d+)?$/.test(m.body);
        var isSequence = isNumericSequence || isAlphaSequence;
        var isOptions = m.body.indexOf(',') >= 0;
        if (!isSequence && !isOptions) {
            // {a},b}
            if (m.post.match(/,.*\}/)) {
                str = m.pre + '{' + m.body + escClose + m.post;
                return expand(str);
            }
            return [str];
        }
        var n;
        if (isSequence) {
            n = m.body.split(/\.\./);
        }
        else {
            n = parseCommaParts(m.body);
            if (n.length === 1) {
                // x{{a,b}}y ==> x{a}y x{b}y
                n = expand(n[0], false).map(embrace);
                if (n.length === 1) {
                    var post = m.post.length
                        ? expand(m.post, false)
                        : [''];
                    return post.map(function (p) {
                        return m.pre + n[0] + p;
                    });
                }
            }
        }
        // at this point, n is the parts, and we know it's not a comma set
        // with a single entry.
        // no need to expand pre, since it is guaranteed to be free of brace-sets
        var pre = m.pre;
        var post = m.post.length
            ? expand(m.post, false)
            : [''];
        var N;
        if (isSequence) {
            var x = numeric(n[0]);
            var y = numeric(n[1]);
            var width = Math.max(n[0].length, n[1].length);
            var incr = n.length == 3
                ? Math.abs(numeric(n[2]))
                : 1;
            var test = lte;
            var reverse = y < x;
            if (reverse) {
                incr *= -1;
                test = gte;
            }
            var pad = n.some(isPadded);
            N = [];
            for (var i = x; test(i, y); i += incr) {
                var c;
                if (isAlphaSequence) {
                    c = String.fromCharCode(i);
                    if (c === '\\')
                        c = '';
                }
                else {
                    c = String(i);
                    if (pad) {
                        var need = width - c.length;
                        if (need > 0) {
                            var z = new Array(need + 1).join('0');
                            if (i < 0)
                                c = '-' + z + c.slice(1);
                            else
                                c = z + c;
                        }
                    }
                }
                N.push(c);
            }
        }
        else {
            N = concatMap(n, function (el) { return expand(el, false); });
        }
        for (var j = 0; j < N.length; j++) {
            for (var k = 0; k < post.length; k++) {
                var expansion = pre + N[j] + post[k];
                if (!isTop || isSequence || expansion)
                    expansions.push(expansion);
            }
        }
        return expansions;
    }
},
/* concat-map/index.js */ function _(require, module, exports, __esModule, __esExport) {
    module.exports = function (xs, fn) {
        var res = [];
        for (var i = 0; i < xs.length; i++) {
            var x = fn(xs[i], i);
            if (isArray(x))
                res.push.apply(res, x);
            else
                res.push(x);
        }
        return res;
    };
    var isArray = Array.isArray || function (xs) {
        return Object.prototype.toString.call(xs) === '[object Array]';
    };
},
/* balanced-match/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = balanced;
    function balanced(a, b, str) {
        if (a instanceof RegExp)
            a = maybeMatch(a, str);
        if (b instanceof RegExp)
            b = maybeMatch(b, str);
        var r = range(a, b, str);
        return r && {
            start: r[0],
            end: r[1],
            pre: str.slice(0, r[0]),
            body: str.slice(r[0] + a.length, r[1]),
            post: str.slice(r[1] + b.length)
        };
    }
    function maybeMatch(reg, str) {
        var m = str.match(reg);
        return m ? m[0] : null;
    }
    balanced.range = range;
    function range(a, b, str) {
        var begs, beg, left, right, result;
        var ai = str.indexOf(a);
        var bi = str.indexOf(b, ai + 1);
        var i = ai;
        if (ai >= 0 && bi > 0) {
            if (a === b) {
                return [ai, bi];
            }
            begs = [];
            left = str.length;
            while (i >= 0 && !result) {
                if (i == ai) {
                    begs.push(i);
                    ai = str.indexOf(a, i + 1);
                }
                else if (begs.length == 1) {
                    result = [begs.pop(), bi];
                }
                else {
                    beg = begs.pop();
                    if (beg < left) {
                        left = beg;
                        right = bi;
                    }
                    bi = str.indexOf(b, i + 1);
                }
                i = ai < bi && ai >= 0 ? ai : bi;
            }
            if (begs.length) {
                result = [left, right];
            }
        }
        return result;
    }
},
/* ajv/lib/ajv.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var compileSchema = require(234) /* ./compile */, resolve = require(235) /* ./compile/resolve */, Cache = require(245) /* ./cache */, SchemaObject = require(240) /* ./compile/schema_obj */, stableStringify = require(243) /* fast-json-stable-stringify */, formats = require(246) /* ./compile/formats */, rules = require(247) /* ./compile/rules */, $dataMetaSchema = require(272) /* ./data */, util = require(238) /* ./compile/util */;
    module.exports = Ajv;
    Ajv.prototype.validate = validate;
    Ajv.prototype.compile = compile;
    Ajv.prototype.addSchema = addSchema;
    Ajv.prototype.addMetaSchema = addMetaSchema;
    Ajv.prototype.validateSchema = validateSchema;
    Ajv.prototype.getSchema = getSchema;
    Ajv.prototype.removeSchema = removeSchema;
    Ajv.prototype.addFormat = addFormat;
    Ajv.prototype.errorsText = errorsText;
    Ajv.prototype._addSchema = _addSchema;
    Ajv.prototype._compile = _compile;
    Ajv.prototype.compileAsync = require(273) /* ./compile/async */;
    var customKeyword = require(274) /* ./keyword */;
    Ajv.prototype.addKeyword = customKeyword.add;
    Ajv.prototype.getKeyword = customKeyword.get;
    Ajv.prototype.removeKeyword = customKeyword.remove;
    Ajv.prototype.validateKeyword = customKeyword.validate;
    var errorClasses = require(242) /* ./compile/error_classes */;
    Ajv.ValidationError = errorClasses.Validation;
    Ajv.MissingRefError = errorClasses.MissingRef;
    Ajv.$dataMetaSchema = $dataMetaSchema;
    var META_SCHEMA_ID = 'http://json-schema.org/draft-07/schema';
    var META_IGNORE_OPTIONS = ['removeAdditional', 'useDefaults', 'coerceTypes', 'strictDefaults'];
    var META_SUPPORT_DATA = ['/properties'];
    /**
     * Creates validator instance.
     * Usage: `Ajv(opts)`
     * @param {Object} opts optional options
     * @return {Object} ajv instance
     */
    function Ajv(opts) {
        if (!(this instanceof Ajv))
            return new Ajv(opts);
        opts = this._opts = util.copy(opts) || {};
        setLogger(this);
        this._schemas = {};
        this._refs = {};
        this._fragments = {};
        this._formats = formats(opts.format);
        this._cache = opts.cache || new Cache;
        this._loadingSchemas = {};
        this._compilations = [];
        this.RULES = rules();
        this._getId = chooseGetId(opts);
        opts.loopRequired = opts.loopRequired || Infinity;
        if (opts.errorDataPath == 'property')
            opts._errorDataPathProperty = true;
        if (opts.serialize === undefined)
            opts.serialize = stableStringify;
        this._metaOpts = getMetaSchemaOptions(this);
        if (opts.formats)
            addInitialFormats(this);
        if (opts.keywords)
            addInitialKeywords(this);
        addDefaultMetaSchema(this);
        if (typeof opts.meta == 'object')
            this.addMetaSchema(opts.meta);
        if (opts.nullable)
            this.addKeyword('nullable', { metaSchema: { type: 'boolean' } });
        addInitialSchemas(this);
    }
    /**
     * Validate data using schema
     * Schema will be compiled and cached (using serialized JSON as key. [fast-json-stable-stringify](https://github.com/epoberezkin/fast-json-stable-stringify) is used to serialize.
     * @this   Ajv
     * @param  {String|Object} schemaKeyRef key, ref or schema object
     * @param  {Any} data to be validated
     * @return {Boolean} validation result. Errors from the last validation will be available in `ajv.errors` (and also in compiled schema: `schema.errors`).
     */
    function validate(schemaKeyRef, data) {
        var v;
        if (typeof schemaKeyRef == 'string') {
            v = this.getSchema(schemaKeyRef);
            if (!v)
                throw new Error('no schema with key or ref "' + schemaKeyRef + '"');
        }
        else {
            var schemaObj = this._addSchema(schemaKeyRef);
            v = schemaObj.validate || this._compile(schemaObj);
        }
        var valid = v(data);
        if (v.$async !== true)
            this.errors = v.errors;
        return valid;
    }
    /**
     * Create validating function for passed schema.
     * @this   Ajv
     * @param  {Object} schema schema object
     * @param  {Boolean} _meta true if schema is a meta-schema. Used internally to compile meta schemas of custom keywords.
     * @return {Function} validating function
     */
    function compile(schema, _meta) {
        var schemaObj = this._addSchema(schema, undefined, _meta);
        return schemaObj.validate || this._compile(schemaObj);
    }
    /**
     * Adds schema to the instance.
     * @this   Ajv
     * @param {Object|Array} schema schema or array of schemas. If array is passed, `key` and other parameters will be ignored.
     * @param {String} key Optional schema key. Can be passed to `validate` method instead of schema object or id/ref. One schema per instance can have empty `id` and `key`.
     * @param {Boolean} _skipValidation true to skip schema validation. Used internally, option validateSchema should be used instead.
     * @param {Boolean} _meta true if schema is a meta-schema. Used internally, addMetaSchema should be used instead.
     * @return {Ajv} this for method chaining
     */
    function addSchema(schema, key, _skipValidation, _meta) {
        if (Array.isArray(schema)) {
            for (var i = 0; i < schema.length; i++)
                this.addSchema(schema[i], undefined, _skipValidation, _meta);
            return this;
        }
        var id = this._getId(schema);
        if (id !== undefined && typeof id != 'string')
            throw new Error('schema id must be string');
        key = resolve.normalizeId(key || id);
        checkUnique(this, key);
        this._schemas[key] = this._addSchema(schema, _skipValidation, _meta, true);
        return this;
    }
    /**
     * Add schema that will be used to validate other schemas
     * options in META_IGNORE_OPTIONS are alway set to false
     * @this   Ajv
     * @param {Object} schema schema object
     * @param {String} key optional schema key
     * @param {Boolean} skipValidation true to skip schema validation, can be used to override validateSchema option for meta-schema
     * @return {Ajv} this for method chaining
     */
    function addMetaSchema(schema, key, skipValidation) {
        this.addSchema(schema, key, skipValidation, true);
        return this;
    }
    /**
     * Validate schema
     * @this   Ajv
     * @param {Object} schema schema to validate
     * @param {Boolean} throwOrLogError pass true to throw (or log) an error if invalid
     * @return {Boolean} true if schema is valid
     */
    function validateSchema(schema, throwOrLogError) {
        var $schema = schema.$schema;
        if ($schema !== undefined && typeof $schema != 'string')
            throw new Error('$schema must be a string');
        $schema = $schema || this._opts.defaultMeta || defaultMeta(this);
        if (!$schema) {
            this.logger.warn('meta-schema not available');
            this.errors = null;
            return true;
        }
        var valid = this.validate($schema, schema);
        if (!valid && throwOrLogError) {
            var message = 'schema is invalid: ' + this.errorsText();
            if (this._opts.validateSchema == 'log')
                this.logger.error(message);
            else
                throw new Error(message);
        }
        return valid;
    }
    function defaultMeta(self) {
        var meta = self._opts.meta;
        self._opts.defaultMeta = typeof meta == 'object'
            ? self._getId(meta) || meta
            : self.getSchema(META_SCHEMA_ID)
                ? META_SCHEMA_ID
                : undefined;
        return self._opts.defaultMeta;
    }
    /**
     * Get compiled schema from the instance by `key` or `ref`.
     * @this   Ajv
     * @param  {String} keyRef `key` that was passed to `addSchema` or full schema reference (`schema.id` or resolved id).
     * @return {Function} schema validating function (with property `schema`).
     */
    function getSchema(keyRef) {
        var schemaObj = _getSchemaObj(this, keyRef);
        switch (typeof schemaObj) {
            case 'object': return schemaObj.validate || this._compile(schemaObj);
            case 'string': return this.getSchema(schemaObj);
            case 'undefined': return _getSchemaFragment(this, keyRef);
        }
    }
    function _getSchemaFragment(self, ref) {
        var res = resolve.schema.call(self, { schema: {} }, ref);
        if (res) {
            var schema = res.schema, root = res.root, baseId = res.baseId;
            var v = compileSchema.call(self, schema, root, undefined, baseId);
            self._fragments[ref] = new SchemaObject({
                ref: ref,
                fragment: true,
                schema: schema,
                root: root,
                baseId: baseId,
                validate: v
            });
            return v;
        }
    }
    function _getSchemaObj(self, keyRef) {
        keyRef = resolve.normalizeId(keyRef);
        return self._schemas[keyRef] || self._refs[keyRef] || self._fragments[keyRef];
    }
    /**
     * Remove cached schema(s).
     * If no parameter is passed all schemas but meta-schemas are removed.
     * If RegExp is passed all schemas with key/id matching pattern but meta-schemas are removed.
     * Even if schema is referenced by other schemas it still can be removed as other schemas have local references.
     * @this   Ajv
     * @param  {String|Object|RegExp} schemaKeyRef key, ref, pattern to match key/ref or schema object
     * @return {Ajv} this for method chaining
     */
    function removeSchema(schemaKeyRef) {
        if (schemaKeyRef instanceof RegExp) {
            _removeAllSchemas(this, this._schemas, schemaKeyRef);
            _removeAllSchemas(this, this._refs, schemaKeyRef);
            return this;
        }
        switch (typeof schemaKeyRef) {
            case 'undefined':
                _removeAllSchemas(this, this._schemas);
                _removeAllSchemas(this, this._refs);
                this._cache.clear();
                return this;
            case 'string':
                var schemaObj = _getSchemaObj(this, schemaKeyRef);
                if (schemaObj)
                    this._cache.del(schemaObj.cacheKey);
                delete this._schemas[schemaKeyRef];
                delete this._refs[schemaKeyRef];
                return this;
            case 'object':
                var serialize = this._opts.serialize;
                var cacheKey = serialize ? serialize(schemaKeyRef) : schemaKeyRef;
                this._cache.del(cacheKey);
                var id = this._getId(schemaKeyRef);
                if (id) {
                    id = resolve.normalizeId(id);
                    delete this._schemas[id];
                    delete this._refs[id];
                }
        }
        return this;
    }
    function _removeAllSchemas(self, schemas, regex) {
        for (var keyRef in schemas) {
            var schemaObj = schemas[keyRef];
            if (!schemaObj.meta && (!regex || regex.test(keyRef))) {
                self._cache.del(schemaObj.cacheKey);
                delete schemas[keyRef];
            }
        }
    }
    /* @this   Ajv */
    function _addSchema(schema, skipValidation, meta, shouldAddSchema) {
        if (typeof schema != 'object' && typeof schema != 'boolean')
            throw new Error('schema should be object or boolean');
        var serialize = this._opts.serialize;
        var cacheKey = serialize ? serialize(schema) : schema;
        var cached = this._cache.get(cacheKey);
        if (cached)
            return cached;
        shouldAddSchema = shouldAddSchema || this._opts.addUsedSchema !== false;
        var id = resolve.normalizeId(this._getId(schema));
        if (id && shouldAddSchema)
            checkUnique(this, id);
        var willValidate = this._opts.validateSchema !== false && !skipValidation;
        var recursiveMeta;
        if (willValidate && !(recursiveMeta = id && id == resolve.normalizeId(schema.$schema)))
            this.validateSchema(schema, true);
        var localRefs = resolve.ids.call(this, schema);
        var schemaObj = new SchemaObject({
            id: id,
            schema: schema,
            localRefs: localRefs,
            cacheKey: cacheKey,
            meta: meta
        });
        if (id[0] != '#' && shouldAddSchema)
            this._refs[id] = schemaObj;
        this._cache.put(cacheKey, schemaObj);
        if (willValidate && recursiveMeta)
            this.validateSchema(schema, true);
        return schemaObj;
    }
    /* @this   Ajv */
    function _compile(schemaObj, root) {
        if (schemaObj.compiling) {
            schemaObj.validate = callValidate;
            callValidate.schema = schemaObj.schema;
            callValidate.errors = null;
            callValidate.root = root ? root : callValidate;
            if (schemaObj.schema.$async === true)
                callValidate.$async = true;
            return callValidate;
        }
        schemaObj.compiling = true;
        var currentOpts;
        if (schemaObj.meta) {
            currentOpts = this._opts;
            this._opts = this._metaOpts;
        }
        var v;
        try {
            v = compileSchema.call(this, schemaObj.schema, root, schemaObj.localRefs);
        }
        catch (e) {
            delete schemaObj.validate;
            throw e;
        }
        finally {
            schemaObj.compiling = false;
            if (schemaObj.meta)
                this._opts = currentOpts;
        }
        schemaObj.validate = v;
        schemaObj.refs = v.refs;
        schemaObj.refVal = v.refVal;
        schemaObj.root = v.root;
        return v;
        /* @this   {*} - custom context, see passContext option */
        function callValidate() {
            /* jshint validthis: true */
            var _validate = schemaObj.validate;
            var result = _validate.apply(this, arguments);
            callValidate.errors = _validate.errors;
            return result;
        }
    }
    function chooseGetId(opts) {
        switch (opts.schemaId) {
            case 'auto': return _get$IdOrId;
            case 'id': return _getId;
            default: return _get$Id;
        }
    }
    /* @this   Ajv */
    function _getId(schema) {
        if (schema.$id)
            this.logger.warn('schema $id ignored', schema.$id);
        return schema.id;
    }
    /* @this   Ajv */
    function _get$Id(schema) {
        if (schema.id)
            this.logger.warn('schema id ignored', schema.id);
        return schema.$id;
    }
    function _get$IdOrId(schema) {
        if (schema.$id && schema.id && schema.$id != schema.id)
            throw new Error('schema $id is different from id');
        return schema.$id || schema.id;
    }
    /**
     * Convert array of error message objects to string
     * @this   Ajv
     * @param  {Array<Object>} errors optional array of validation errors, if not passed errors from the instance are used.
     * @param  {Object} options optional options with properties `separator` and `dataVar`.
     * @return {String} human readable string with all errors descriptions
     */
    function errorsText(errors, options) {
        errors = errors || this.errors;
        if (!errors)
            return 'No errors';
        options = options || {};
        var separator = options.separator === undefined ? ', ' : options.separator;
        var dataVar = options.dataVar === undefined ? 'data' : options.dataVar;
        var text = '';
        for (var i = 0; i < errors.length; i++) {
            var e = errors[i];
            if (e)
                text += dataVar + e.dataPath + ' ' + e.message + separator;
        }
        return text.slice(0, -separator.length);
    }
    /**
     * Add custom format
     * @this   Ajv
     * @param {String} name format name
     * @param {String|RegExp|Function} format string is converted to RegExp; function should return boolean (true when valid)
     * @return {Ajv} this for method chaining
     */
    function addFormat(name, format) {
        if (typeof format == 'string')
            format = new RegExp(format);
        this._formats[name] = format;
        return this;
    }
    function addDefaultMetaSchema(self) {
        var $dataSchema;
        if (self._opts.$data) {
            $dataSchema = require(278) /* ./refs/data.json */;
            self.addMetaSchema($dataSchema, $dataSchema.$id, true);
        }
        if (self._opts.meta === false)
            return;
        var metaSchema = require(277) /* ./refs/json-schema-draft-07.json */;
        if (self._opts.$data)
            metaSchema = $dataMetaSchema(metaSchema, META_SUPPORT_DATA);
        self.addMetaSchema(metaSchema, META_SCHEMA_ID, true);
        self._refs['http://json-schema.org/schema'] = META_SCHEMA_ID;
    }
    function addInitialSchemas(self) {
        var optsSchemas = self._opts.schemas;
        if (!optsSchemas)
            return;
        if (Array.isArray(optsSchemas))
            self.addSchema(optsSchemas);
        else
            for (var key in optsSchemas)
                self.addSchema(optsSchemas[key], key);
    }
    function addInitialFormats(self) {
        for (var name in self._opts.formats) {
            var format = self._opts.formats[name];
            self.addFormat(name, format);
        }
    }
    function addInitialKeywords(self) {
        for (var name in self._opts.keywords) {
            var keyword = self._opts.keywords[name];
            self.addKeyword(name, keyword);
        }
    }
    function checkUnique(self, id) {
        if (self._schemas[id] || self._refs[id])
            throw new Error('schema with key or id "' + id + '" already exists');
    }
    function getMetaSchemaOptions(self) {
        var metaOpts = util.copy(self._opts);
        for (var i = 0; i < META_IGNORE_OPTIONS.length; i++)
            delete metaOpts[META_IGNORE_OPTIONS[i]];
        return metaOpts;
    }
    function setLogger(self) {
        var logger = self._opts.logger;
        if (logger === false) {
            self.logger = { log: noop, warn: noop, error: noop };
        }
        else {
            if (logger === undefined)
                logger = console;
            if (!(typeof logger == 'object' && logger.log && logger.warn && logger.error))
                throw new Error('logger must implement log, warn and error methods');
            self.logger = logger;
        }
    }
    function noop() { }
},
/* ajv/lib/compile/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var resolve = require(235) /* ./resolve */, util = require(238) /* ./util */, errorClasses = require(242) /* ./error_classes */, stableStringify = require(243) /* fast-json-stable-stringify */;
    var validateGenerator = require(244) /* ../dotjs/validate */;
    /**
     * Functions below are used inside compiled validations function
     */
    var ucs2length = util.ucs2length;
    var equal = require(237) /* fast-deep-equal */;
    // this error is thrown by async schemas to return validation errors via exception
    var ValidationError = errorClasses.Validation;
    module.exports = compile;
    /**
     * Compiles schema to validation function
     * @this   Ajv
     * @param  {Object} schema schema object
     * @param  {Object} root object with information about the root schema for this schema
     * @param  {Object} localRefs the hash of local references inside the schema (created by resolve.id), used for inline resolution
     * @param  {String} baseId base ID for IDs in the schema
     * @return {Function} validation function
     */
    function compile(schema, root, localRefs, baseId) {
        /* jshint validthis: true, evil: true */
        /* eslint no-shadow: 0 */
        var self = this, opts = this._opts, refVal = [undefined], refs = {}, patterns = [], patternsHash = {}, defaults = [], defaultsHash = {}, customRules = [];
        root = root || { schema: schema, refVal: refVal, refs: refs };
        var c = checkCompiling.call(this, schema, root, baseId);
        var compilation = this._compilations[c.index];
        if (c.compiling)
            return (compilation.callValidate = callValidate);
        var formats = this._formats;
        var RULES = this.RULES;
        try {
            var v = localCompile(schema, root, localRefs, baseId);
            compilation.validate = v;
            var cv = compilation.callValidate;
            if (cv) {
                cv.schema = v.schema;
                cv.errors = null;
                cv.refs = v.refs;
                cv.refVal = v.refVal;
                cv.root = v.root;
                cv.$async = v.$async;
                if (opts.sourceCode)
                    cv.source = v.source;
            }
            return v;
        }
        finally {
            endCompiling.call(this, schema, root, baseId);
        }
        /* @this   {*} - custom context, see passContext option */
        function callValidate() {
            /* jshint validthis: true */
            var validate = compilation.validate;
            var result = validate.apply(this, arguments);
            callValidate.errors = validate.errors;
            return result;
        }
        function localCompile(_schema, _root, localRefs, baseId) {
            var isRoot = !_root || (_root && _root.schema == _schema);
            if (_root.schema != root.schema)
                return compile.call(self, _schema, _root, localRefs, baseId);
            var $async = _schema.$async === true;
            var sourceCode = validateGenerator({
                isTop: true,
                schema: _schema,
                isRoot: isRoot,
                baseId: baseId,
                root: _root,
                schemaPath: '',
                errSchemaPath: '#',
                errorPath: '""',
                MissingRefError: errorClasses.MissingRef,
                RULES: RULES,
                validate: validateGenerator,
                util: util,
                resolve: resolve,
                resolveRef: resolveRef,
                usePattern: usePattern,
                useDefault: useDefault,
                useCustomRule: useCustomRule,
                opts: opts,
                formats: formats,
                logger: self.logger,
                self: self
            });
            sourceCode = vars(refVal, refValCode) + vars(patterns, patternCode)
                + vars(defaults, defaultCode) + vars(customRules, customRuleCode)
                + sourceCode;
            if (opts.processCode)
                sourceCode = opts.processCode(sourceCode, _schema);
            // console.log('\n\n\n *** \n', JSON.stringify(sourceCode));
            var validate;
            try {
                var makeValidate = new Function('self', 'RULES', 'formats', 'root', 'refVal', 'defaults', 'customRules', 'equal', 'ucs2length', 'ValidationError', sourceCode);
                validate = makeValidate(self, RULES, formats, root, refVal, defaults, customRules, equal, ucs2length, ValidationError);
                refVal[0] = validate;
            }
            catch (e) {
                self.logger.error('Error compiling schema, function code:', sourceCode);
                throw e;
            }
            validate.schema = _schema;
            validate.errors = null;
            validate.refs = refs;
            validate.refVal = refVal;
            validate.root = isRoot ? validate : _root;
            if ($async)
                validate.$async = true;
            if (opts.sourceCode === true) {
                validate.source = {
                    code: sourceCode,
                    patterns: patterns,
                    defaults: defaults
                };
            }
            return validate;
        }
        function resolveRef(baseId, ref, isRoot) {
            ref = resolve.url(baseId, ref);
            var refIndex = refs[ref];
            var _refVal, refCode;
            if (refIndex !== undefined) {
                _refVal = refVal[refIndex];
                refCode = 'refVal[' + refIndex + ']';
                return resolvedRef(_refVal, refCode);
            }
            if (!isRoot && root.refs) {
                var rootRefId = root.refs[ref];
                if (rootRefId !== undefined) {
                    _refVal = root.refVal[rootRefId];
                    refCode = addLocalRef(ref, _refVal);
                    return resolvedRef(_refVal, refCode);
                }
            }
            refCode = addLocalRef(ref);
            var v = resolve.call(self, localCompile, root, ref);
            if (v === undefined) {
                var localSchema = localRefs && localRefs[ref];
                if (localSchema) {
                    v = resolve.inlineRef(localSchema, opts.inlineRefs)
                        ? localSchema
                        : compile.call(self, localSchema, root, localRefs, baseId);
                }
            }
            if (v === undefined) {
                removeLocalRef(ref);
            }
            else {
                replaceLocalRef(ref, v);
                return resolvedRef(v, refCode);
            }
        }
        function addLocalRef(ref, v) {
            var refId = refVal.length;
            refVal[refId] = v;
            refs[ref] = refId;
            return 'refVal' + refId;
        }
        function removeLocalRef(ref) {
            delete refs[ref];
        }
        function replaceLocalRef(ref, v) {
            var refId = refs[ref];
            refVal[refId] = v;
        }
        function resolvedRef(refVal, code) {
            return typeof refVal == 'object' || typeof refVal == 'boolean'
                ? { code: code, schema: refVal, inline: true }
                : { code: code, $async: refVal && !!refVal.$async };
        }
        function usePattern(regexStr) {
            var index = patternsHash[regexStr];
            if (index === undefined) {
                index = patternsHash[regexStr] = patterns.length;
                patterns[index] = regexStr;
            }
            return 'pattern' + index;
        }
        function useDefault(value) {
            switch (typeof value) {
                case 'boolean':
                case 'number':
                    return '' + value;
                case 'string':
                    return util.toQuotedString(value);
                case 'object':
                    if (value === null)
                        return 'null';
                    var valueStr = stableStringify(value);
                    var index = defaultsHash[valueStr];
                    if (index === undefined) {
                        index = defaultsHash[valueStr] = defaults.length;
                        defaults[index] = value;
                    }
                    return 'default' + index;
            }
        }
        function useCustomRule(rule, schema, parentSchema, it) {
            if (self._opts.validateSchema !== false) {
                var deps = rule.definition.dependencies;
                if (deps && !deps.every(function (keyword) {
                    return Object.prototype.hasOwnProperty.call(parentSchema, keyword);
                }))
                    throw new Error('parent schema must have all required keywords: ' + deps.join(','));
                var validateSchema = rule.definition.validateSchema;
                if (validateSchema) {
                    var valid = validateSchema(schema);
                    if (!valid) {
                        var message = 'keyword schema is invalid: ' + self.errorsText(validateSchema.errors);
                        if (self._opts.validateSchema == 'log')
                            self.logger.error(message);
                        else
                            throw new Error(message);
                    }
                }
            }
            var compile = rule.definition.compile, inline = rule.definition.inline, macro = rule.definition.macro;
            var validate;
            if (compile) {
                validate = compile.call(self, schema, parentSchema, it);
            }
            else if (macro) {
                validate = macro.call(self, schema, parentSchema, it);
                if (opts.validateSchema !== false)
                    self.validateSchema(validate, true);
            }
            else if (inline) {
                validate = inline.call(self, it, rule.keyword, schema, parentSchema);
            }
            else {
                validate = rule.definition.validate;
                if (!validate)
                    return;
            }
            if (validate === undefined)
                throw new Error('custom keyword "' + rule.keyword + '"failed to compile');
            var index = customRules.length;
            customRules[index] = validate;
            return {
                code: 'customRule' + index,
                validate: validate
            };
        }
    }
    /**
     * Checks if the schema is currently compiled
     * @this   Ajv
     * @param  {Object} schema schema to compile
     * @param  {Object} root root object
     * @param  {String} baseId base schema ID
     * @return {Object} object with properties "index" (compilation index) and "compiling" (boolean)
     */
    function checkCompiling(schema, root, baseId) {
        /* jshint validthis: true */
        var index = compIndex.call(this, schema, root, baseId);
        if (index >= 0)
            return { index: index, compiling: true };
        index = this._compilations.length;
        this._compilations[index] = {
            schema: schema,
            root: root,
            baseId: baseId
        };
        return { index: index, compiling: false };
    }
    /**
     * Removes the schema from the currently compiled list
     * @this   Ajv
     * @param  {Object} schema schema to compile
     * @param  {Object} root root object
     * @param  {String} baseId base schema ID
     */
    function endCompiling(schema, root, baseId) {
        /* jshint validthis: true */
        var i = compIndex.call(this, schema, root, baseId);
        if (i >= 0)
            this._compilations.splice(i, 1);
    }
    /**
     * Index of schema compilation in the currently compiled list
     * @this   Ajv
     * @param  {Object} schema schema to compile
     * @param  {Object} root root object
     * @param  {String} baseId base schema ID
     * @return {Integer} compilation index
     */
    function compIndex(schema, root, baseId) {
        /* jshint validthis: true */
        for (var i = 0; i < this._compilations.length; i++) {
            var c = this._compilations[i];
            if (c.schema == schema && c.root == root && c.baseId == baseId)
                return i;
        }
        return -1;
    }
    function patternCode(i, patterns) {
        return 'var pattern' + i + ' = new RegExp(' + util.toQuotedString(patterns[i]) + ');';
    }
    function defaultCode(i) {
        return 'var default' + i + ' = defaults[' + i + '];';
    }
    function refValCode(i, refVal) {
        return refVal[i] === undefined ? '' : 'var refVal' + i + ' = refVal[' + i + '];';
    }
    function customRuleCode(i) {
        return 'var customRule' + i + ' = customRules[' + i + '];';
    }
    function vars(arr, statement) {
        if (!arr.length)
            return '';
        var code = '';
        for (var i = 0; i < arr.length; i++)
            code += statement(i, arr);
        return code;
    }
},
/* ajv/lib/compile/resolve.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var URI = require(236) /* uri-js */, equal = require(237) /* fast-deep-equal */, util = require(238) /* ./util */, SchemaObject = require(240) /* ./schema_obj */, traverse = require(241) /* json-schema-traverse */;
    module.exports = resolve;
    resolve.normalizeId = normalizeId;
    resolve.fullPath = getFullPath;
    resolve.url = resolveUrl;
    resolve.ids = resolveIds;
    resolve.inlineRef = inlineRef;
    resolve.schema = resolveSchema;
    /**
     * [resolve and compile the references ($ref)]
     * @this   Ajv
     * @param  {Function} compile reference to schema compilation funciton (localCompile)
     * @param  {Object} root object with information about the root schema for the current schema
     * @param  {String} ref reference to resolve
     * @return {Object|Function} schema object (if the schema can be inlined) or validation function
     */
    function resolve(compile, root, ref) {
        /* jshint validthis: true */
        var refVal = this._refs[ref];
        if (typeof refVal == 'string') {
            if (this._refs[refVal])
                refVal = this._refs[refVal];
            else
                return resolve.call(this, compile, root, refVal);
        }
        refVal = refVal || this._schemas[ref];
        if (refVal instanceof SchemaObject) {
            return inlineRef(refVal.schema, this._opts.inlineRefs)
                ? refVal.schema
                : refVal.validate || this._compile(refVal);
        }
        var res = resolveSchema.call(this, root, ref);
        var schema, v, baseId;
        if (res) {
            schema = res.schema;
            root = res.root;
            baseId = res.baseId;
        }
        if (schema instanceof SchemaObject) {
            v = schema.validate || compile.call(this, schema.schema, root, undefined, baseId);
        }
        else if (schema !== undefined) {
            v = inlineRef(schema, this._opts.inlineRefs)
                ? schema
                : compile.call(this, schema, root, undefined, baseId);
        }
        return v;
    }
    /**
     * Resolve schema, its root and baseId
     * @this Ajv
     * @param  {Object} root root object with properties schema, refVal, refs
     * @param  {String} ref  reference to resolve
     * @return {Object} object with properties schema, root, baseId
     */
    function resolveSchema(root, ref) {
        /* jshint validthis: true */
        var p = URI.parse(ref), refPath = _getFullPath(p), baseId = getFullPath(this._getId(root.schema));
        if (Object.keys(root.schema).length === 0 || refPath !== baseId) {
            var id = normalizeId(refPath);
            var refVal = this._refs[id];
            if (typeof refVal == 'string') {
                return resolveRecursive.call(this, root, refVal, p);
            }
            else if (refVal instanceof SchemaObject) {
                if (!refVal.validate)
                    this._compile(refVal);
                root = refVal;
            }
            else {
                refVal = this._schemas[id];
                if (refVal instanceof SchemaObject) {
                    if (!refVal.validate)
                        this._compile(refVal);
                    if (id == normalizeId(ref))
                        return { schema: refVal, root: root, baseId: baseId };
                    root = refVal;
                }
                else {
                    return;
                }
            }
            if (!root.schema)
                return;
            baseId = getFullPath(this._getId(root.schema));
        }
        return getJsonPointer.call(this, p, baseId, root.schema, root);
    }
    /* @this Ajv */
    function resolveRecursive(root, ref, parsedRef) {
        /* jshint validthis: true */
        var res = resolveSchema.call(this, root, ref);
        if (res) {
            var schema = res.schema;
            var baseId = res.baseId;
            root = res.root;
            var id = this._getId(schema);
            if (id)
                baseId = resolveUrl(baseId, id);
            return getJsonPointer.call(this, parsedRef, baseId, schema, root);
        }
    }
    var PREVENT_SCOPE_CHANGE = util.toHash(['properties', 'patternProperties', 'enum', 'dependencies', 'definitions']);
    /* @this Ajv */
    function getJsonPointer(parsedRef, baseId, schema, root) {
        /* jshint validthis: true */
        parsedRef.fragment = parsedRef.fragment || '';
        if (parsedRef.fragment.slice(0, 1) != '/')
            return;
        var parts = parsedRef.fragment.split('/');
        for (var i = 1; i < parts.length; i++) {
            var part = parts[i];
            if (part) {
                part = util.unescapeFragment(part);
                schema = schema[part];
                if (schema === undefined)
                    break;
                var id;
                if (!PREVENT_SCOPE_CHANGE[part]) {
                    id = this._getId(schema);
                    if (id)
                        baseId = resolveUrl(baseId, id);
                    if (schema.$ref) {
                        var $ref = resolveUrl(baseId, schema.$ref);
                        var res = resolveSchema.call(this, root, $ref);
                        if (res) {
                            schema = res.schema;
                            root = res.root;
                            baseId = res.baseId;
                        }
                    }
                }
            }
        }
        if (schema !== undefined && schema !== root.schema)
            return { schema: schema, root: root, baseId: baseId };
    }
    var SIMPLE_INLINED = util.toHash([
        'type', 'format', 'pattern',
        'maxLength', 'minLength',
        'maxProperties', 'minProperties',
        'maxItems', 'minItems',
        'maximum', 'minimum',
        'uniqueItems', 'multipleOf',
        'required', 'enum'
    ]);
    function inlineRef(schema, limit) {
        if (limit === false)
            return false;
        if (limit === undefined || limit === true)
            return checkNoRef(schema);
        else if (limit)
            return countKeys(schema) <= limit;
    }
    function checkNoRef(schema) {
        var item;
        if (Array.isArray(schema)) {
            for (var i = 0; i < schema.length; i++) {
                item = schema[i];
                if (typeof item == 'object' && !checkNoRef(item))
                    return false;
            }
        }
        else {
            for (var key in schema) {
                if (key == '$ref')
                    return false;
                item = schema[key];
                if (typeof item == 'object' && !checkNoRef(item))
                    return false;
            }
        }
        return true;
    }
    function countKeys(schema) {
        var count = 0, item;
        if (Array.isArray(schema)) {
            for (var i = 0; i < schema.length; i++) {
                item = schema[i];
                if (typeof item == 'object')
                    count += countKeys(item);
                if (count == Infinity)
                    return Infinity;
            }
        }
        else {
            for (var key in schema) {
                if (key == '$ref')
                    return Infinity;
                if (SIMPLE_INLINED[key]) {
                    count++;
                }
                else {
                    item = schema[key];
                    if (typeof item == 'object')
                        count += countKeys(item) + 1;
                    if (count == Infinity)
                        return Infinity;
                }
            }
        }
        return count;
    }
    function getFullPath(id, normalize) {
        if (normalize !== false)
            id = normalizeId(id);
        var p = URI.parse(id);
        return _getFullPath(p);
    }
    function _getFullPath(p) {
        return URI.serialize(p).split('#')[0] + '#';
    }
    var TRAILING_SLASH_HASH = /#\/?$/;
    function normalizeId(id) {
        return id ? id.replace(TRAILING_SLASH_HASH, '') : '';
    }
    function resolveUrl(baseId, id) {
        id = normalizeId(id);
        return URI.resolve(baseId, id);
    }
    /* @this Ajv */
    function resolveIds(schema) {
        var schemaId = normalizeId(this._getId(schema));
        var baseIds = { '': schemaId };
        var fullPaths = { '': getFullPath(schemaId, false) };
        var localRefs = {};
        var self = this;
        traverse(schema, { allKeys: true }, function (sch, jsonPtr, rootSchema, parentJsonPtr, parentKeyword, parentSchema, keyIndex) {
            if (jsonPtr === '')
                return;
            var id = self._getId(sch);
            var baseId = baseIds[parentJsonPtr];
            var fullPath = fullPaths[parentJsonPtr] + '/' + parentKeyword;
            if (keyIndex !== undefined)
                fullPath += '/' + (typeof keyIndex == 'number' ? keyIndex : util.escapeFragment(keyIndex));
            if (typeof id == 'string') {
                id = baseId = normalizeId(baseId ? URI.resolve(baseId, id) : id);
                var refVal = self._refs[id];
                if (typeof refVal == 'string')
                    refVal = self._refs[refVal];
                if (refVal && refVal.schema) {
                    if (!equal(sch, refVal.schema))
                        throw new Error('id "' + id + '" resolves to more than one schema');
                }
                else if (id != normalizeId(fullPath)) {
                    if (id[0] == '#') {
                        if (localRefs[id] && !equal(sch, localRefs[id]))
                            throw new Error('id "' + id + '" resolves to more than one schema');
                        localRefs[id] = sch;
                    }
                    else {
                        self._refs[id] = fullPath;
                    }
                }
            }
            baseIds[jsonPtr] = baseId;
            fullPaths[jsonPtr] = fullPath;
        });
        return localRefs;
    }
},
/* uri-js/dist/es5/uri.all.js */ function _(require, module, exports, __esModule, __esExport) {
    /** @license URI.js v4.4.1 (c) 2011 Gary Court. License: http://github.com/garycourt/uri-js */
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
            typeof define === 'function' && define.amd ? define(['exports'], factory) :
                (factory((global.URI = global.URI || {})));
    }(this, (function (exports) {
        'use strict';
        function merge() {
            for (var _len = arguments.length, sets = Array(_len), _key = 0; _key < _len; _key++) {
                sets[_key] = arguments[_key];
            }
            if (sets.length > 1) {
                sets[0] = sets[0].slice(0, -1);
                var xl = sets.length - 1;
                for (var x = 1; x < xl; ++x) {
                    sets[x] = sets[x].slice(1, -1);
                }
                sets[xl] = sets[xl].slice(1);
                return sets.join('');
            }
            else {
                return sets[0];
            }
        }
        function subexp(str) {
            return "(?:" + str + ")";
        }
        function typeOf(o) {
            return o === undefined ? "undefined" : o === null ? "null" : Object.prototype.toString.call(o).split(" ").pop().split("]").shift().toLowerCase();
        }
        function toUpperCase(str) {
            return str.toUpperCase();
        }
        function toArray(obj) {
            return obj !== undefined && obj !== null ? obj instanceof Array ? obj : typeof obj.length !== "number" || obj.split || obj.setInterval || obj.call ? [obj] : Array.prototype.slice.call(obj) : [];
        }
        function assign(target, source) {
            var obj = target;
            if (source) {
                for (var key in source) {
                    obj[key] = source[key];
                }
            }
            return obj;
        }
        function buildExps(isIRI) {
            var ALPHA$$ = "[A-Za-z]", CR$ = "[\\x0D]", DIGIT$$ = "[0-9]", DQUOTE$$ = "[\\x22]", HEXDIG$$ = merge(DIGIT$$, "[A-Fa-f]"), 
            //case-insensitive
            LF$$ = "[\\x0A]", SP$$ = "[\\x20]", PCT_ENCODED$ = subexp(subexp("%[EFef]" + HEXDIG$$ + "%" + HEXDIG$$ + HEXDIG$$ + "%" + HEXDIG$$ + HEXDIG$$) + "|" + subexp("%[89A-Fa-f]" + HEXDIG$$ + "%" + HEXDIG$$ + HEXDIG$$) + "|" + subexp("%" + HEXDIG$$ + HEXDIG$$)), 
            //expanded
            GEN_DELIMS$$ = "[\\:\\/\\?\\#\\[\\]\\@]", SUB_DELIMS$$ = "[\\!\\$\\&\\'\\(\\)\\*\\+\\,\\;\\=]", RESERVED$$ = merge(GEN_DELIMS$$, SUB_DELIMS$$), UCSCHAR$$ = isIRI ? "[\\xA0-\\u200D\\u2010-\\u2029\\u202F-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFEF]" : "[]", 
            //subset, excludes bidi control characters
            IPRIVATE$$ = isIRI ? "[\\uE000-\\uF8FF]" : "[]", 
            //subset
            UNRESERVED$$ = merge(ALPHA$$, DIGIT$$, "[\\-\\.\\_\\~]", UCSCHAR$$), SCHEME$ = subexp(ALPHA$$ + merge(ALPHA$$, DIGIT$$, "[\\+\\-\\.]") + "*"), USERINFO$ = subexp(subexp(PCT_ENCODED$ + "|" + merge(UNRESERVED$$, SUB_DELIMS$$, "[\\:]")) + "*"), DEC_OCTET$ = subexp(subexp("25[0-5]") + "|" + subexp("2[0-4]" + DIGIT$$) + "|" + subexp("1" + DIGIT$$ + DIGIT$$) + "|" + subexp("[1-9]" + DIGIT$$) + "|" + DIGIT$$), DEC_OCTET_RELAXED$ = subexp(subexp("25[0-5]") + "|" + subexp("2[0-4]" + DIGIT$$) + "|" + subexp("1" + DIGIT$$ + DIGIT$$) + "|" + subexp("0?[1-9]" + DIGIT$$) + "|0?0?" + DIGIT$$), 
            //relaxed parsing rules
            IPV4ADDRESS$ = subexp(DEC_OCTET_RELAXED$ + "\\." + DEC_OCTET_RELAXED$ + "\\." + DEC_OCTET_RELAXED$ + "\\." + DEC_OCTET_RELAXED$), H16$ = subexp(HEXDIG$$ + "{1,4}"), LS32$ = subexp(subexp(H16$ + "\\:" + H16$) + "|" + IPV4ADDRESS$), IPV6ADDRESS1$ = subexp(subexp(H16$ + "\\:") + "{6}" + LS32$), 
            //                           6( h16 ":" ) ls32
            IPV6ADDRESS2$ = subexp("\\:\\:" + subexp(H16$ + "\\:") + "{5}" + LS32$), 
            //                      "::" 5( h16 ":" ) ls32
            IPV6ADDRESS3$ = subexp(subexp(H16$) + "?\\:\\:" + subexp(H16$ + "\\:") + "{4}" + LS32$), 
            //[               h16 ] "::" 4( h16 ":" ) ls32
            IPV6ADDRESS4$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,1}" + H16$) + "?\\:\\:" + subexp(H16$ + "\\:") + "{3}" + LS32$), 
            //[ *1( h16 ":" ) h16 ] "::" 3( h16 ":" ) ls32
            IPV6ADDRESS5$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,2}" + H16$) + "?\\:\\:" + subexp(H16$ + "\\:") + "{2}" + LS32$), 
            //[ *2( h16 ":" ) h16 ] "::" 2( h16 ":" ) ls32
            IPV6ADDRESS6$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,3}" + H16$) + "?\\:\\:" + H16$ + "\\:" + LS32$), 
            //[ *3( h16 ":" ) h16 ] "::"    h16 ":"   ls32
            IPV6ADDRESS7$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,4}" + H16$) + "?\\:\\:" + LS32$), 
            //[ *4( h16 ":" ) h16 ] "::"              ls32
            IPV6ADDRESS8$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,5}" + H16$) + "?\\:\\:" + H16$), 
            //[ *5( h16 ":" ) h16 ] "::"              h16
            IPV6ADDRESS9$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,6}" + H16$) + "?\\:\\:"), 
            //[ *6( h16 ":" ) h16 ] "::"
            IPV6ADDRESS$ = subexp([IPV6ADDRESS1$, IPV6ADDRESS2$, IPV6ADDRESS3$, IPV6ADDRESS4$, IPV6ADDRESS5$, IPV6ADDRESS6$, IPV6ADDRESS7$, IPV6ADDRESS8$, IPV6ADDRESS9$].join("|")), ZONEID$ = subexp(subexp(UNRESERVED$$ + "|" + PCT_ENCODED$) + "+"), 
            //RFC 6874
            IPV6ADDRZ$ = subexp(IPV6ADDRESS$ + "\\%25" + ZONEID$), 
            //RFC 6874
            IPV6ADDRZ_RELAXED$ = subexp(IPV6ADDRESS$ + subexp("\\%25|\\%(?!" + HEXDIG$$ + "{2})") + ZONEID$), 
            //RFC 6874, with relaxed parsing rules
            IPVFUTURE$ = subexp("[vV]" + HEXDIG$$ + "+\\." + merge(UNRESERVED$$, SUB_DELIMS$$, "[\\:]") + "+"), IP_LITERAL$ = subexp("\\[" + subexp(IPV6ADDRZ_RELAXED$ + "|" + IPV6ADDRESS$ + "|" + IPVFUTURE$) + "\\]"), 
            //RFC 6874
            REG_NAME$ = subexp(subexp(PCT_ENCODED$ + "|" + merge(UNRESERVED$$, SUB_DELIMS$$)) + "*"), HOST$ = subexp(IP_LITERAL$ + "|" + IPV4ADDRESS$ + "(?!" + REG_NAME$ + ")" + "|" + REG_NAME$), PORT$ = subexp(DIGIT$$ + "*"), AUTHORITY$ = subexp(subexp(USERINFO$ + "@") + "?" + HOST$ + subexp("\\:" + PORT$) + "?"), PCHAR$ = subexp(PCT_ENCODED$ + "|" + merge(UNRESERVED$$, SUB_DELIMS$$, "[\\:\\@]")), SEGMENT$ = subexp(PCHAR$ + "*"), SEGMENT_NZ$ = subexp(PCHAR$ + "+"), SEGMENT_NZ_NC$ = subexp(subexp(PCT_ENCODED$ + "|" + merge(UNRESERVED$$, SUB_DELIMS$$, "[\\@]")) + "+"), PATH_ABEMPTY$ = subexp(subexp("\\/" + SEGMENT$) + "*"), PATH_ABSOLUTE$ = subexp("\\/" + subexp(SEGMENT_NZ$ + PATH_ABEMPTY$) + "?"), 
            //simplified
            PATH_NOSCHEME$ = subexp(SEGMENT_NZ_NC$ + PATH_ABEMPTY$), 
            //simplified
            PATH_ROOTLESS$ = subexp(SEGMENT_NZ$ + PATH_ABEMPTY$), 
            //simplified
            PATH_EMPTY$ = "(?!" + PCHAR$ + ")", PATH$ = subexp(PATH_ABEMPTY$ + "|" + PATH_ABSOLUTE$ + "|" + PATH_NOSCHEME$ + "|" + PATH_ROOTLESS$ + "|" + PATH_EMPTY$), QUERY$ = subexp(subexp(PCHAR$ + "|" + merge("[\\/\\?]", IPRIVATE$$)) + "*"), FRAGMENT$ = subexp(subexp(PCHAR$ + "|[\\/\\?]") + "*"), HIER_PART$ = subexp(subexp("\\/\\/" + AUTHORITY$ + PATH_ABEMPTY$) + "|" + PATH_ABSOLUTE$ + "|" + PATH_ROOTLESS$ + "|" + PATH_EMPTY$), URI$ = subexp(SCHEME$ + "\\:" + HIER_PART$ + subexp("\\?" + QUERY$) + "?" + subexp("\\#" + FRAGMENT$) + "?"), RELATIVE_PART$ = subexp(subexp("\\/\\/" + AUTHORITY$ + PATH_ABEMPTY$) + "|" + PATH_ABSOLUTE$ + "|" + PATH_NOSCHEME$ + "|" + PATH_EMPTY$), RELATIVE$ = subexp(RELATIVE_PART$ + subexp("\\?" + QUERY$) + "?" + subexp("\\#" + FRAGMENT$) + "?"), URI_REFERENCE$ = subexp(URI$ + "|" + RELATIVE$), ABSOLUTE_URI$ = subexp(SCHEME$ + "\\:" + HIER_PART$ + subexp("\\?" + QUERY$) + "?"), GENERIC_REF$ = "^(" + SCHEME$ + ")\\:" + subexp(subexp("\\/\\/(" + subexp("(" + USERINFO$ + ")@") + "?(" + HOST$ + ")" + subexp("\\:(" + PORT$ + ")") + "?)") + "?(" + PATH_ABEMPTY$ + "|" + PATH_ABSOLUTE$ + "|" + PATH_ROOTLESS$ + "|" + PATH_EMPTY$ + ")") + subexp("\\?(" + QUERY$ + ")") + "?" + subexp("\\#(" + FRAGMENT$ + ")") + "?$", RELATIVE_REF$ = "^(){0}" + subexp(subexp("\\/\\/(" + subexp("(" + USERINFO$ + ")@") + "?(" + HOST$ + ")" + subexp("\\:(" + PORT$ + ")") + "?)") + "?(" + PATH_ABEMPTY$ + "|" + PATH_ABSOLUTE$ + "|" + PATH_NOSCHEME$ + "|" + PATH_EMPTY$ + ")") + subexp("\\?(" + QUERY$ + ")") + "?" + subexp("\\#(" + FRAGMENT$ + ")") + "?$", ABSOLUTE_REF$ = "^(" + SCHEME$ + ")\\:" + subexp(subexp("\\/\\/(" + subexp("(" + USERINFO$ + ")@") + "?(" + HOST$ + ")" + subexp("\\:(" + PORT$ + ")") + "?)") + "?(" + PATH_ABEMPTY$ + "|" + PATH_ABSOLUTE$ + "|" + PATH_ROOTLESS$ + "|" + PATH_EMPTY$ + ")") + subexp("\\?(" + QUERY$ + ")") + "?$", SAMEDOC_REF$ = "^" + subexp("\\#(" + FRAGMENT$ + ")") + "?$", AUTHORITY_REF$ = "^" + subexp("(" + USERINFO$ + ")@") + "?(" + HOST$ + ")" + subexp("\\:(" + PORT$ + ")") + "?$";
            return {
                NOT_SCHEME: new RegExp(merge("[^]", ALPHA$$, DIGIT$$, "[\\+\\-\\.]"), "g"),
                NOT_USERINFO: new RegExp(merge("[^\\%\\:]", UNRESERVED$$, SUB_DELIMS$$), "g"),
                NOT_HOST: new RegExp(merge("[^\\%\\[\\]\\:]", UNRESERVED$$, SUB_DELIMS$$), "g"),
                NOT_PATH: new RegExp(merge("[^\\%\\/\\:\\@]", UNRESERVED$$, SUB_DELIMS$$), "g"),
                NOT_PATH_NOSCHEME: new RegExp(merge("[^\\%\\/\\@]", UNRESERVED$$, SUB_DELIMS$$), "g"),
                NOT_QUERY: new RegExp(merge("[^\\%]", UNRESERVED$$, SUB_DELIMS$$, "[\\:\\@\\/\\?]", IPRIVATE$$), "g"),
                NOT_FRAGMENT: new RegExp(merge("[^\\%]", UNRESERVED$$, SUB_DELIMS$$, "[\\:\\@\\/\\?]"), "g"),
                ESCAPE: new RegExp(merge("[^]", UNRESERVED$$, SUB_DELIMS$$), "g"),
                UNRESERVED: new RegExp(UNRESERVED$$, "g"),
                OTHER_CHARS: new RegExp(merge("[^\\%]", UNRESERVED$$, RESERVED$$), "g"),
                PCT_ENCODED: new RegExp(PCT_ENCODED$, "g"),
                IPV4ADDRESS: new RegExp("^(" + IPV4ADDRESS$ + ")$"),
                IPV6ADDRESS: new RegExp("^\\[?(" + IPV6ADDRESS$ + ")" + subexp(subexp("\\%25|\\%(?!" + HEXDIG$$ + "{2})") + "(" + ZONEID$ + ")") + "?\\]?$") //RFC 6874, with relaxed parsing rules
            };
        }
        var URI_PROTOCOL = buildExps(false);
        var IRI_PROTOCOL = buildExps(true);
        var slicedToArray = function () {
            function sliceIterator(arr, i) {
                var _arr = [];
                var _n = true;
                var _d = false;
                var _e = undefined;
                try {
                    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
                        _arr.push(_s.value);
                        if (i && _arr.length === i)
                            break;
                    }
                }
                catch (err) {
                    _d = true;
                    _e = err;
                }
                finally {
                    try {
                        if (!_n && _i["return"])
                            _i["return"]();
                    }
                    finally {
                        if (_d)
                            throw _e;
                    }
                }
                return _arr;
            }
            return function (arr, i) {
                if (Array.isArray(arr)) {
                    return arr;
                }
                else if (Symbol.iterator in Object(arr)) {
                    return sliceIterator(arr, i);
                }
                else {
                    throw new TypeError("Invalid attempt to destructure non-iterable instance");
                }
            };
        }();
        var toConsumableArray = function (arr) {
            if (Array.isArray(arr)) {
                for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++)
                    arr2[i] = arr[i];
                return arr2;
            }
            else {
                return Array.from(arr);
            }
        };
        /** Highest positive signed 32-bit float value */
        var maxInt = 2147483647; // aka. 0x7FFFFFFF or 2^31-1
        /** Bootstring parameters */
        var base = 36;
        var tMin = 1;
        var tMax = 26;
        var skew = 38;
        var damp = 700;
        var initialBias = 72;
        var initialN = 128; // 0x80
        var delimiter = '-'; // '\x2D'
        /** Regular expressions */
        var regexPunycode = /^xn--/;
        var regexNonASCII = /[^\0-\x7E]/; // non-ASCII chars
        var regexSeparators = /[\x2E\u3002\uFF0E\uFF61]/g; // RFC 3490 separators
        /** Error messages */
        var errors = {
            'overflow': 'Overflow: input needs wider integers to process',
            'not-basic': 'Illegal input >= 0x80 (not a basic code point)',
            'invalid-input': 'Invalid input'
        };
        /** Convenience shortcuts */
        var baseMinusTMin = base - tMin;
        var floor = Math.floor;
        var stringFromCharCode = String.fromCharCode;
        /*--------------------------------------------------------------------------*/
        /**
         * A generic error utility function.
         * @private
         * @param {String} type The error type.
         * @returns {Error} Throws a `RangeError` with the applicable error message.
         */
        function error$1(type) {
            throw new RangeError(errors[type]);
        }
        /**
         * A generic `Array#map` utility function.
         * @private
         * @param {Array} array The array to iterate over.
         * @param {Function} callback The function that gets called for every array
         * item.
         * @returns {Array} A new array of values returned by the callback function.
         */
        function map(array, fn) {
            var result = [];
            var length = array.length;
            while (length--) {
                result[length] = fn(array[length]);
            }
            return result;
        }
        /**
         * A simple `Array#map`-like wrapper to work with domain name strings or email
         * addresses.
         * @private
         * @param {String} domain The domain name or email address.
         * @param {Function} callback The function that gets called for every
         * character.
         * @returns {Array} A new string of characters returned by the callback
         * function.
         */
        function mapDomain(string, fn) {
            var parts = string.split('@');
            var result = '';
            if (parts.length > 1) {
                // In email addresses, only the domain name should be punycoded. Leave
                // the local part (i.e. everything up to `@`) intact.
                result = parts[0] + '@';
                string = parts[1];
            }
            // Avoid `split(regex)` for IE8 compatibility. See #17.
            string = string.replace(regexSeparators, '\x2E');
            var labels = string.split('.');
            var encoded = map(labels, fn).join('.');
            return result + encoded;
        }
        /**
         * Creates an array containing the numeric code points of each Unicode
         * character in the string. While JavaScript uses UCS-2 internally,
         * this function will convert a pair of surrogate halves (each of which
         * UCS-2 exposes as separate characters) into a single code point,
         * matching UTF-16.
         * @see `punycode.ucs2.encode`
         * @see <https://mathiasbynens.be/notes/javascript-encoding>
         * @memberOf punycode.ucs2
         * @name decode
         * @param {String} string The Unicode input string (UCS-2).
         * @returns {Array} The new array of code points.
         */
        function ucs2decode(string) {
            var output = [];
            var counter = 0;
            var length = string.length;
            while (counter < length) {
                var value = string.charCodeAt(counter++);
                if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
                    // It's a high surrogate, and there is a next character.
                    var extra = string.charCodeAt(counter++);
                    if ((extra & 0xFC00) == 0xDC00) {
                        // Low surrogate.
                        output.push(((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
                    }
                    else {
                        // It's an unmatched surrogate; only append this code unit, in case the
                        // next code unit is the high surrogate of a surrogate pair.
                        output.push(value);
                        counter--;
                    }
                }
                else {
                    output.push(value);
                }
            }
            return output;
        }
        /**
         * Creates a string based on an array of numeric code points.
         * @see `punycode.ucs2.decode`
         * @memberOf punycode.ucs2
         * @name encode
         * @param {Array} codePoints The array of numeric code points.
         * @returns {String} The new Unicode string (UCS-2).
         */
        var ucs2encode = function ucs2encode(array) {
            return String.fromCodePoint.apply(String, toConsumableArray(array));
        };
        /**
         * Converts a basic code point into a digit/integer.
         * @see `digitToBasic()`
         * @private
         * @param {Number} codePoint The basic numeric code point value.
         * @returns {Number} The numeric value of a basic code point (for use in
         * representing integers) in the range `0` to `base - 1`, or `base` if
         * the code point does not represent a value.
         */
        var basicToDigit = function basicToDigit(codePoint) {
            if (codePoint - 0x30 < 0x0A) {
                return codePoint - 0x16;
            }
            if (codePoint - 0x41 < 0x1A) {
                return codePoint - 0x41;
            }
            if (codePoint - 0x61 < 0x1A) {
                return codePoint - 0x61;
            }
            return base;
        };
        /**
         * Converts a digit/integer into a basic code point.
         * @see `basicToDigit()`
         * @private
         * @param {Number} digit The numeric value of a basic code point.
         * @returns {Number} The basic code point whose value (when used for
         * representing integers) is `digit`, which needs to be in the range
         * `0` to `base - 1`. If `flag` is non-zero, the uppercase form is
         * used; else, the lowercase form is used. The behavior is undefined
         * if `flag` is non-zero and `digit` has no uppercase form.
         */
        var digitToBasic = function digitToBasic(digit, flag) {
            //  0..25 map to ASCII a..z or A..Z
            // 26..35 map to ASCII 0..9
            return digit + 22 + 75 * (digit < 26) - ((flag != 0) << 5);
        };
        /**
         * Bias adaptation function as per section 3.4 of RFC 3492.
         * https://tools.ietf.org/html/rfc3492#section-3.4
         * @private
         */
        var adapt = function adapt(delta, numPoints, firstTime) {
            var k = 0;
            delta = firstTime ? floor(delta / damp) : delta >> 1;
            delta += floor(delta / numPoints);
            for (; /* no initialization */ delta > baseMinusTMin * tMax >> 1; k += base) {
                delta = floor(delta / baseMinusTMin);
            }
            return floor(k + (baseMinusTMin + 1) * delta / (delta + skew));
        };
        /**
         * Converts a Punycode string of ASCII-only symbols to a string of Unicode
         * symbols.
         * @memberOf punycode
         * @param {String} input The Punycode string of ASCII-only symbols.
         * @returns {String} The resulting string of Unicode symbols.
         */
        var decode = function decode(input) {
            // Don't use UCS-2.
            var output = [];
            var inputLength = input.length;
            var i = 0;
            var n = initialN;
            var bias = initialBias;
            // Handle the basic code points: let `basic` be the number of input code
            // points before the last delimiter, or `0` if there is none, then copy
            // the first basic code points to the output.
            var basic = input.lastIndexOf(delimiter);
            if (basic < 0) {
                basic = 0;
            }
            for (var j = 0; j < basic; ++j) {
                // if it's not a basic code point
                if (input.charCodeAt(j) >= 0x80) {
                    error$1('not-basic');
                }
                output.push(input.charCodeAt(j));
            }
            // Main decoding loop: start just after the last delimiter if any basic code
            // points were copied; start at the beginning otherwise.
            for (var index = basic > 0 ? basic + 1 : 0; index < inputLength;) /* no final expression */ {
                // `index` is the index of the next character to be consumed.
                // Decode a generalized variable-length integer into `delta`,
                // which gets added to `i`. The overflow checking is easier
                // if we increase `i` as we go, then subtract off its starting
                // value at the end to obtain `delta`.
                var oldi = i;
                for (var w = 1, k = base;; /* no condition */ k += base) {
                    if (index >= inputLength) {
                        error$1('invalid-input');
                    }
                    var digit = basicToDigit(input.charCodeAt(index++));
                    if (digit >= base || digit > floor((maxInt - i) / w)) {
                        error$1('overflow');
                    }
                    i += digit * w;
                    var t = k <= bias ? tMin : k >= bias + tMax ? tMax : k - bias;
                    if (digit < t) {
                        break;
                    }
                    var baseMinusT = base - t;
                    if (w > floor(maxInt / baseMinusT)) {
                        error$1('overflow');
                    }
                    w *= baseMinusT;
                }
                var out = output.length + 1;
                bias = adapt(i - oldi, out, oldi == 0);
                // `i` was supposed to wrap around from `out` to `0`,
                // incrementing `n` each time, so we'll fix that now:
                if (floor(i / out) > maxInt - n) {
                    error$1('overflow');
                }
                n += floor(i / out);
                i %= out;
                // Insert `n` at position `i` of the output.
                output.splice(i++, 0, n);
            }
            return String.fromCodePoint.apply(String, output);
        };
        /**
         * Converts a string of Unicode symbols (e.g. a domain name label) to a
         * Punycode string of ASCII-only symbols.
         * @memberOf punycode
         * @param {String} input The string of Unicode symbols.
         * @returns {String} The resulting Punycode string of ASCII-only symbols.
         */
        var encode = function encode(input) {
            var output = [];
            // Convert the input in UCS-2 to an array of Unicode code points.
            input = ucs2decode(input);
            // Cache the length.
            var inputLength = input.length;
            // Initialize the state.
            var n = initialN;
            var delta = 0;
            var bias = initialBias;
            // Handle the basic code points.
            var _iteratorNormalCompletion = true;
            var _didIteratorError = false;
            var _iteratorError = undefined;
            try {
                for (var _iterator = input[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                    var _currentValue2 = _step.value;
                    if (_currentValue2 < 0x80) {
                        output.push(stringFromCharCode(_currentValue2));
                    }
                }
            }
            catch (err) {
                _didIteratorError = true;
                _iteratorError = err;
            }
            finally {
                try {
                    if (!_iteratorNormalCompletion && _iterator.return) {
                        _iterator.return();
                    }
                }
                finally {
                    if (_didIteratorError) {
                        throw _iteratorError;
                    }
                }
            }
            var basicLength = output.length;
            var handledCPCount = basicLength;
            // `handledCPCount` is the number of code points that have been handled;
            // `basicLength` is the number of basic code points.
            // Finish the basic string with a delimiter unless it's empty.
            if (basicLength) {
                output.push(delimiter);
            }
            // Main encoding loop:
            while (handledCPCount < inputLength) {
                // All non-basic code points < n have been handled already. Find the next
                // larger one:
                var m = maxInt;
                var _iteratorNormalCompletion2 = true;
                var _didIteratorError2 = false;
                var _iteratorError2 = undefined;
                try {
                    for (var _iterator2 = input[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
                        var currentValue = _step2.value;
                        if (currentValue >= n && currentValue < m) {
                            m = currentValue;
                        }
                    }
                    // Increase `delta` enough to advance the decoder's <n,i> state to <m,0>,
                    // but guard against overflow.
                }
                catch (err) {
                    _didIteratorError2 = true;
                    _iteratorError2 = err;
                }
                finally {
                    try {
                        if (!_iteratorNormalCompletion2 && _iterator2.return) {
                            _iterator2.return();
                        }
                    }
                    finally {
                        if (_didIteratorError2) {
                            throw _iteratorError2;
                        }
                    }
                }
                var handledCPCountPlusOne = handledCPCount + 1;
                if (m - n > floor((maxInt - delta) / handledCPCountPlusOne)) {
                    error$1('overflow');
                }
                delta += (m - n) * handledCPCountPlusOne;
                n = m;
                var _iteratorNormalCompletion3 = true;
                var _didIteratorError3 = false;
                var _iteratorError3 = undefined;
                try {
                    for (var _iterator3 = input[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
                        var _currentValue = _step3.value;
                        if (_currentValue < n && ++delta > maxInt) {
                            error$1('overflow');
                        }
                        if (_currentValue == n) {
                            // Represent delta as a generalized variable-length integer.
                            var q = delta;
                            for (var k = base;; /* no condition */ k += base) {
                                var t = k <= bias ? tMin : k >= bias + tMax ? tMax : k - bias;
                                if (q < t) {
                                    break;
                                }
                                var qMinusT = q - t;
                                var baseMinusT = base - t;
                                output.push(stringFromCharCode(digitToBasic(t + qMinusT % baseMinusT, 0)));
                                q = floor(qMinusT / baseMinusT);
                            }
                            output.push(stringFromCharCode(digitToBasic(q, 0)));
                            bias = adapt(delta, handledCPCountPlusOne, handledCPCount == basicLength);
                            delta = 0;
                            ++handledCPCount;
                        }
                    }
                }
                catch (err) {
                    _didIteratorError3 = true;
                    _iteratorError3 = err;
                }
                finally {
                    try {
                        if (!_iteratorNormalCompletion3 && _iterator3.return) {
                            _iterator3.return();
                        }
                    }
                    finally {
                        if (_didIteratorError3) {
                            throw _iteratorError3;
                        }
                    }
                }
                ++delta;
                ++n;
            }
            return output.join('');
        };
        /**
         * Converts a Punycode string representing a domain name or an email address
         * to Unicode. Only the Punycoded parts of the input will be converted, i.e.
         * it doesn't matter if you call it on a string that has already been
         * converted to Unicode.
         * @memberOf punycode
         * @param {String} input The Punycoded domain name or email address to
         * convert to Unicode.
         * @returns {String} The Unicode representation of the given Punycode
         * string.
         */
        var toUnicode = function toUnicode(input) {
            return mapDomain(input, function (string) {
                return regexPunycode.test(string) ? decode(string.slice(4).toLowerCase()) : string;
            });
        };
        /**
         * Converts a Unicode string representing a domain name or an email address to
         * Punycode. Only the non-ASCII parts of the domain name will be converted,
         * i.e. it doesn't matter if you call it with a domain that's already in
         * ASCII.
         * @memberOf punycode
         * @param {String} input The domain name or email address to convert, as a
         * Unicode string.
         * @returns {String} The Punycode representation of the given domain name or
         * email address.
         */
        var toASCII = function toASCII(input) {
            return mapDomain(input, function (string) {
                return regexNonASCII.test(string) ? 'xn--' + encode(string) : string;
            });
        };
        /*--------------------------------------------------------------------------*/
        /** Define the public API */
        var punycode = {
            /**
          * A string representing the current Punycode.js version number.
          * @memberOf punycode
          * @type String
          */
            'version': '2.1.0',
            /**
          * An object of methods to convert from JavaScript's internal character
          * representation (UCS-2) to Unicode code points, and back.
          * @see <https://mathiasbynens.be/notes/javascript-encoding>
          * @memberOf punycode
          * @type Object
          */
            'ucs2': {
                'decode': ucs2decode,
                'encode': ucs2encode
            },
            'decode': decode,
            'encode': encode,
            'toASCII': toASCII,
            'toUnicode': toUnicode
        };
        /**
         * URI.js
         *
         * @fileoverview An RFC 3986 compliant, scheme extendable URI parsing/validating/resolving library for JavaScript.
         * @author <a href="mailto:gary.court@gmail.com">Gary Court</a>
         * @see http://github.com/garycourt/uri-js
         */
        /**
         * Copyright 2011 Gary Court. All rights reserved.
         *
         * Redistribution and use in source and binary forms, with or without modification, are
         * permitted provided that the following conditions are met:
         *
         *    1. Redistributions of source code must retain the above copyright notice, this list of
         *       conditions and the following disclaimer.
         *
         *    2. Redistributions in binary form must reproduce the above copyright notice, this list
         *       of conditions and the following disclaimer in the documentation and/or other materials
         *       provided with the distribution.
         *
         * THIS SOFTWARE IS PROVIDED BY GARY COURT ``AS IS'' AND ANY EXPRESS OR IMPLIED
         * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
         * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GARY COURT OR
         * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
         * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
         * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
         * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
         * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
         * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
         *
         * The views and conclusions contained in the software and documentation are those of the
         * authors and should not be interpreted as representing official policies, either expressed
         * or implied, of Gary Court.
         */
        var SCHEMES = {};
        function pctEncChar(chr) {
            var c = chr.charCodeAt(0);
            var e = void 0;
            if (c < 16)
                e = "%0" + c.toString(16).toUpperCase();
            else if (c < 128)
                e = "%" + c.toString(16).toUpperCase();
            else if (c < 2048)
                e = "%" + (c >> 6 | 192).toString(16).toUpperCase() + "%" + (c & 63 | 128).toString(16).toUpperCase();
            else
                e = "%" + (c >> 12 | 224).toString(16).toUpperCase() + "%" + (c >> 6 & 63 | 128).toString(16).toUpperCase() + "%" + (c & 63 | 128).toString(16).toUpperCase();
            return e;
        }
        function pctDecChars(str) {
            var newStr = "";
            var i = 0;
            var il = str.length;
            while (i < il) {
                var c = parseInt(str.substr(i + 1, 2), 16);
                if (c < 128) {
                    newStr += String.fromCharCode(c);
                    i += 3;
                }
                else if (c >= 194 && c < 224) {
                    if (il - i >= 6) {
                        var c2 = parseInt(str.substr(i + 4, 2), 16);
                        newStr += String.fromCharCode((c & 31) << 6 | c2 & 63);
                    }
                    else {
                        newStr += str.substr(i, 6);
                    }
                    i += 6;
                }
                else if (c >= 224) {
                    if (il - i >= 9) {
                        var _c = parseInt(str.substr(i + 4, 2), 16);
                        var c3 = parseInt(str.substr(i + 7, 2), 16);
                        newStr += String.fromCharCode((c & 15) << 12 | (_c & 63) << 6 | c3 & 63);
                    }
                    else {
                        newStr += str.substr(i, 9);
                    }
                    i += 9;
                }
                else {
                    newStr += str.substr(i, 3);
                    i += 3;
                }
            }
            return newStr;
        }
        function _normalizeComponentEncoding(components, protocol) {
            function decodeUnreserved(str) {
                var decStr = pctDecChars(str);
                return !decStr.match(protocol.UNRESERVED) ? str : decStr;
            }
            if (components.scheme)
                components.scheme = String(components.scheme).replace(protocol.PCT_ENCODED, decodeUnreserved).toLowerCase().replace(protocol.NOT_SCHEME, "");
            if (components.userinfo !== undefined)
                components.userinfo = String(components.userinfo).replace(protocol.PCT_ENCODED, decodeUnreserved).replace(protocol.NOT_USERINFO, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
            if (components.host !== undefined)
                components.host = String(components.host).replace(protocol.PCT_ENCODED, decodeUnreserved).toLowerCase().replace(protocol.NOT_HOST, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
            if (components.path !== undefined)
                components.path = String(components.path).replace(protocol.PCT_ENCODED, decodeUnreserved).replace(components.scheme ? protocol.NOT_PATH : protocol.NOT_PATH_NOSCHEME, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
            if (components.query !== undefined)
                components.query = String(components.query).replace(protocol.PCT_ENCODED, decodeUnreserved).replace(protocol.NOT_QUERY, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
            if (components.fragment !== undefined)
                components.fragment = String(components.fragment).replace(protocol.PCT_ENCODED, decodeUnreserved).replace(protocol.NOT_FRAGMENT, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
            return components;
        }
        function _stripLeadingZeros(str) {
            return str.replace(/^0*(.*)/, "$1") || "0";
        }
        function _normalizeIPv4(host, protocol) {
            var matches = host.match(protocol.IPV4ADDRESS) || [];
            var _matches = slicedToArray(matches, 2), address = _matches[1];
            if (address) {
                return address.split(".").map(_stripLeadingZeros).join(".");
            }
            else {
                return host;
            }
        }
        function _normalizeIPv6(host, protocol) {
            var matches = host.match(protocol.IPV6ADDRESS) || [];
            var _matches2 = slicedToArray(matches, 3), address = _matches2[1], zone = _matches2[2];
            if (address) {
                var _address$toLowerCase$ = address.toLowerCase().split('::').reverse(), _address$toLowerCase$2 = slicedToArray(_address$toLowerCase$, 2), last = _address$toLowerCase$2[0], first = _address$toLowerCase$2[1];
                var firstFields = first ? first.split(":").map(_stripLeadingZeros) : [];
                var lastFields = last.split(":").map(_stripLeadingZeros);
                var isLastFieldIPv4Address = protocol.IPV4ADDRESS.test(lastFields[lastFields.length - 1]);
                var fieldCount = isLastFieldIPv4Address ? 7 : 8;
                var lastFieldsStart = lastFields.length - fieldCount;
                var fields = Array(fieldCount);
                for (var x = 0; x < fieldCount; ++x) {
                    fields[x] = firstFields[x] || lastFields[lastFieldsStart + x] || '';
                }
                if (isLastFieldIPv4Address) {
                    fields[fieldCount - 1] = _normalizeIPv4(fields[fieldCount - 1], protocol);
                }
                var allZeroFields = fields.reduce(function (acc, field, index) {
                    if (!field || field === "0") {
                        var lastLongest = acc[acc.length - 1];
                        if (lastLongest && lastLongest.index + lastLongest.length === index) {
                            lastLongest.length++;
                        }
                        else {
                            acc.push({ index: index, length: 1 });
                        }
                    }
                    return acc;
                }, []);
                var longestZeroFields = allZeroFields.sort(function (a, b) {
                    return b.length - a.length;
                })[0];
                var newHost = void 0;
                if (longestZeroFields && longestZeroFields.length > 1) {
                    var newFirst = fields.slice(0, longestZeroFields.index);
                    var newLast = fields.slice(longestZeroFields.index + longestZeroFields.length);
                    newHost = newFirst.join(":") + "::" + newLast.join(":");
                }
                else {
                    newHost = fields.join(":");
                }
                if (zone) {
                    newHost += "%" + zone;
                }
                return newHost;
            }
            else {
                return host;
            }
        }
        var URI_PARSE = /^(?:([^:\/?#]+):)?(?:\/\/((?:([^\/?#@]*)@)?(\[[^\/?#\]]+\]|[^\/?#:]*)(?:\:(\d*))?))?([^?#]*)(?:\?([^#]*))?(?:#((?:.|\n|\r)*))?/i;
        var NO_MATCH_IS_UNDEFINED = "".match(/(){0}/)[1] === undefined;
        function parse(uriString) {
            var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
            var components = {};
            var protocol = options.iri !== false ? IRI_PROTOCOL : URI_PROTOCOL;
            if (options.reference === "suffix")
                uriString = (options.scheme ? options.scheme + ":" : "") + "//" + uriString;
            var matches = uriString.match(URI_PARSE);
            if (matches) {
                if (NO_MATCH_IS_UNDEFINED) {
                    //store each component
                    components.scheme = matches[1];
                    components.userinfo = matches[3];
                    components.host = matches[4];
                    components.port = parseInt(matches[5], 10);
                    components.path = matches[6] || "";
                    components.query = matches[7];
                    components.fragment = matches[8];
                    //fix port number
                    if (isNaN(components.port)) {
                        components.port = matches[5];
                    }
                }
                else {
                    //IE FIX for improper RegExp matching
                    //store each component
                    components.scheme = matches[1] || undefined;
                    components.userinfo = uriString.indexOf("@") !== -1 ? matches[3] : undefined;
                    components.host = uriString.indexOf("//") !== -1 ? matches[4] : undefined;
                    components.port = parseInt(matches[5], 10);
                    components.path = matches[6] || "";
                    components.query = uriString.indexOf("?") !== -1 ? matches[7] : undefined;
                    components.fragment = uriString.indexOf("#") !== -1 ? matches[8] : undefined;
                    //fix port number
                    if (isNaN(components.port)) {
                        components.port = uriString.match(/\/\/(?:.|\n)*\:(?:\/|\?|\#|$)/) ? matches[4] : undefined;
                    }
                }
                if (components.host) {
                    //normalize IP hosts
                    components.host = _normalizeIPv6(_normalizeIPv4(components.host, protocol), protocol);
                }
                //determine reference type
                if (components.scheme === undefined && components.userinfo === undefined && components.host === undefined && components.port === undefined && !components.path && components.query === undefined) {
                    components.reference = "same-document";
                }
                else if (components.scheme === undefined) {
                    components.reference = "relative";
                }
                else if (components.fragment === undefined) {
                    components.reference = "absolute";
                }
                else {
                    components.reference = "uri";
                }
                //check for reference errors
                if (options.reference && options.reference !== "suffix" && options.reference !== components.reference) {
                    components.error = components.error || "URI is not a " + options.reference + " reference.";
                }
                //find scheme handler
                var schemeHandler = SCHEMES[(options.scheme || components.scheme || "").toLowerCase()];
                //check if scheme can't handle IRIs
                if (!options.unicodeSupport && (!schemeHandler || !schemeHandler.unicodeSupport)) {
                    //if host component is a domain name
                    if (components.host && (options.domainHost || schemeHandler && schemeHandler.domainHost)) {
                        //convert Unicode IDN -> ASCII IDN
                        try {
                            components.host = punycode.toASCII(components.host.replace(protocol.PCT_ENCODED, pctDecChars).toLowerCase());
                        }
                        catch (e) {
                            components.error = components.error || "Host's domain name can not be converted to ASCII via punycode: " + e;
                        }
                    }
                    //convert IRI -> URI
                    _normalizeComponentEncoding(components, URI_PROTOCOL);
                }
                else {
                    //normalize encodings
                    _normalizeComponentEncoding(components, protocol);
                }
                //perform scheme specific parsing
                if (schemeHandler && schemeHandler.parse) {
                    schemeHandler.parse(components, options);
                }
            }
            else {
                components.error = components.error || "URI can not be parsed.";
            }
            return components;
        }
        function _recomposeAuthority(components, options) {
            var protocol = options.iri !== false ? IRI_PROTOCOL : URI_PROTOCOL;
            var uriTokens = [];
            if (components.userinfo !== undefined) {
                uriTokens.push(components.userinfo);
                uriTokens.push("@");
            }
            if (components.host !== undefined) {
                //normalize IP hosts, add brackets and escape zone separator for IPv6
                uriTokens.push(_normalizeIPv6(_normalizeIPv4(String(components.host), protocol), protocol).replace(protocol.IPV6ADDRESS, function (_, $1, $2) {
                    return "[" + $1 + ($2 ? "%25" + $2 : "") + "]";
                }));
            }
            if (typeof components.port === "number" || typeof components.port === "string") {
                uriTokens.push(":");
                uriTokens.push(String(components.port));
            }
            return uriTokens.length ? uriTokens.join("") : undefined;
        }
        var RDS1 = /^\.\.?\//;
        var RDS2 = /^\/\.(\/|$)/;
        var RDS3 = /^\/\.\.(\/|$)/;
        var RDS5 = /^\/?(?:.|\n)*?(?=\/|$)/;
        function removeDotSegments(input) {
            var output = [];
            while (input.length) {
                if (input.match(RDS1)) {
                    input = input.replace(RDS1, "");
                }
                else if (input.match(RDS2)) {
                    input = input.replace(RDS2, "/");
                }
                else if (input.match(RDS3)) {
                    input = input.replace(RDS3, "/");
                    output.pop();
                }
                else if (input === "." || input === "..") {
                    input = "";
                }
                else {
                    var im = input.match(RDS5);
                    if (im) {
                        var s = im[0];
                        input = input.slice(s.length);
                        output.push(s);
                    }
                    else {
                        throw new Error("Unexpected dot segment condition");
                    }
                }
            }
            return output.join("");
        }
        function serialize(components) {
            var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
            var protocol = options.iri ? IRI_PROTOCOL : URI_PROTOCOL;
            var uriTokens = [];
            //find scheme handler
            var schemeHandler = SCHEMES[(options.scheme || components.scheme || "").toLowerCase()];
            //perform scheme specific serialization
            if (schemeHandler && schemeHandler.serialize)
                schemeHandler.serialize(components, options);
            if (components.host) {
                //if host component is an IPv6 address
                if (protocol.IPV6ADDRESS.test(components.host)) { }
                //TODO: normalize IPv6 address as per RFC 5952
                //if host component is a domain name
                else if (options.domainHost || schemeHandler && schemeHandler.domainHost) {
                    //convert IDN via punycode
                    try {
                        components.host = !options.iri ? punycode.toASCII(components.host.replace(protocol.PCT_ENCODED, pctDecChars).toLowerCase()) : punycode.toUnicode(components.host);
                    }
                    catch (e) {
                        components.error = components.error || "Host's domain name can not be converted to " + (!options.iri ? "ASCII" : "Unicode") + " via punycode: " + e;
                    }
                }
            }
            //normalize encoding
            _normalizeComponentEncoding(components, protocol);
            if (options.reference !== "suffix" && components.scheme) {
                uriTokens.push(components.scheme);
                uriTokens.push(":");
            }
            var authority = _recomposeAuthority(components, options);
            if (authority !== undefined) {
                if (options.reference !== "suffix") {
                    uriTokens.push("//");
                }
                uriTokens.push(authority);
                if (components.path && components.path.charAt(0) !== "/") {
                    uriTokens.push("/");
                }
            }
            if (components.path !== undefined) {
                var s = components.path;
                if (!options.absolutePath && (!schemeHandler || !schemeHandler.absolutePath)) {
                    s = removeDotSegments(s);
                }
                if (authority === undefined) {
                    s = s.replace(/^\/\//, "/%2F"); //don't allow the path to start with "//"
                }
                uriTokens.push(s);
            }
            if (components.query !== undefined) {
                uriTokens.push("?");
                uriTokens.push(components.query);
            }
            if (components.fragment !== undefined) {
                uriTokens.push("#");
                uriTokens.push(components.fragment);
            }
            return uriTokens.join(""); //merge tokens into a string
        }
        function resolveComponents(base, relative) {
            var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
            var skipNormalization = arguments[3];
            var target = {};
            if (!skipNormalization) {
                base = parse(serialize(base, options), options); //normalize base components
                relative = parse(serialize(relative, options), options); //normalize relative components
            }
            options = options || {};
            if (!options.tolerant && relative.scheme) {
                target.scheme = relative.scheme;
                //target.authority = relative.authority;
                target.userinfo = relative.userinfo;
                target.host = relative.host;
                target.port = relative.port;
                target.path = removeDotSegments(relative.path || "");
                target.query = relative.query;
            }
            else {
                if (relative.userinfo !== undefined || relative.host !== undefined || relative.port !== undefined) {
                    //target.authority = relative.authority;
                    target.userinfo = relative.userinfo;
                    target.host = relative.host;
                    target.port = relative.port;
                    target.path = removeDotSegments(relative.path || "");
                    target.query = relative.query;
                }
                else {
                    if (!relative.path) {
                        target.path = base.path;
                        if (relative.query !== undefined) {
                            target.query = relative.query;
                        }
                        else {
                            target.query = base.query;
                        }
                    }
                    else {
                        if (relative.path.charAt(0) === "/") {
                            target.path = removeDotSegments(relative.path);
                        }
                        else {
                            if ((base.userinfo !== undefined || base.host !== undefined || base.port !== undefined) && !base.path) {
                                target.path = "/" + relative.path;
                            }
                            else if (!base.path) {
                                target.path = relative.path;
                            }
                            else {
                                target.path = base.path.slice(0, base.path.lastIndexOf("/") + 1) + relative.path;
                            }
                            target.path = removeDotSegments(target.path);
                        }
                        target.query = relative.query;
                    }
                    //target.authority = base.authority;
                    target.userinfo = base.userinfo;
                    target.host = base.host;
                    target.port = base.port;
                }
                target.scheme = base.scheme;
            }
            target.fragment = relative.fragment;
            return target;
        }
        function resolve(baseURI, relativeURI, options) {
            var schemelessOptions = assign({ scheme: 'null' }, options);
            return serialize(resolveComponents(parse(baseURI, schemelessOptions), parse(relativeURI, schemelessOptions), schemelessOptions, true), schemelessOptions);
        }
        function normalize(uri, options) {
            if (typeof uri === "string") {
                uri = serialize(parse(uri, options), options);
            }
            else if (typeOf(uri) === "object") {
                uri = parse(serialize(uri, options), options);
            }
            return uri;
        }
        function equal(uriA, uriB, options) {
            if (typeof uriA === "string") {
                uriA = serialize(parse(uriA, options), options);
            }
            else if (typeOf(uriA) === "object") {
                uriA = serialize(uriA, options);
            }
            if (typeof uriB === "string") {
                uriB = serialize(parse(uriB, options), options);
            }
            else if (typeOf(uriB) === "object") {
                uriB = serialize(uriB, options);
            }
            return uriA === uriB;
        }
        function escapeComponent(str, options) {
            return str && str.toString().replace(!options || !options.iri ? URI_PROTOCOL.ESCAPE : IRI_PROTOCOL.ESCAPE, pctEncChar);
        }
        function unescapeComponent(str, options) {
            return str && str.toString().replace(!options || !options.iri ? URI_PROTOCOL.PCT_ENCODED : IRI_PROTOCOL.PCT_ENCODED, pctDecChars);
        }
        var handler = {
            scheme: "http",
            domainHost: true,
            parse: function parse(components, options) {
                //report missing host
                if (!components.host) {
                    components.error = components.error || "HTTP URIs must have a host.";
                }
                return components;
            },
            serialize: function serialize(components, options) {
                var secure = String(components.scheme).toLowerCase() === "https";
                //normalize the default port
                if (components.port === (secure ? 443 : 80) || components.port === "") {
                    components.port = undefined;
                }
                //normalize the empty path
                if (!components.path) {
                    components.path = "/";
                }
                //NOTE: We do not parse query strings for HTTP URIs
                //as WWW Form Url Encoded query strings are part of the HTML4+ spec,
                //and not the HTTP spec.
                return components;
            }
        };
        var handler$1 = {
            scheme: "https",
            domainHost: handler.domainHost,
            parse: handler.parse,
            serialize: handler.serialize
        };
        function isSecure(wsComponents) {
            return typeof wsComponents.secure === 'boolean' ? wsComponents.secure : String(wsComponents.scheme).toLowerCase() === "wss";
        }
        //RFC 6455
        var handler$2 = {
            scheme: "ws",
            domainHost: true,
            parse: function parse(components, options) {
                var wsComponents = components;
                //indicate if the secure flag is set
                wsComponents.secure = isSecure(wsComponents);
                //construct resouce name
                wsComponents.resourceName = (wsComponents.path || '/') + (wsComponents.query ? '?' + wsComponents.query : '');
                wsComponents.path = undefined;
                wsComponents.query = undefined;
                return wsComponents;
            },
            serialize: function serialize(wsComponents, options) {
                //normalize the default port
                if (wsComponents.port === (isSecure(wsComponents) ? 443 : 80) || wsComponents.port === "") {
                    wsComponents.port = undefined;
                }
                //ensure scheme matches secure flag
                if (typeof wsComponents.secure === 'boolean') {
                    wsComponents.scheme = wsComponents.secure ? 'wss' : 'ws';
                    wsComponents.secure = undefined;
                }
                //reconstruct path from resource name
                if (wsComponents.resourceName) {
                    var _wsComponents$resourc = wsComponents.resourceName.split('?'), _wsComponents$resourc2 = slicedToArray(_wsComponents$resourc, 2), path = _wsComponents$resourc2[0], query = _wsComponents$resourc2[1];
                    wsComponents.path = path && path !== '/' ? path : undefined;
                    wsComponents.query = query;
                    wsComponents.resourceName = undefined;
                }
                //forbid fragment component
                wsComponents.fragment = undefined;
                return wsComponents;
            }
        };
        var handler$3 = {
            scheme: "wss",
            domainHost: handler$2.domainHost,
            parse: handler$2.parse,
            serialize: handler$2.serialize
        };
        var O = {};
        var isIRI = true;
        //RFC 3986
        var UNRESERVED$$ = "[A-Za-z0-9\\-\\.\\_\\~" + (isIRI ? "\\xA0-\\u200D\\u2010-\\u2029\\u202F-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFEF" : "") + "]";
        var HEXDIG$$ = "[0-9A-Fa-f]"; //case-insensitive
        var PCT_ENCODED$ = subexp(subexp("%[EFef]" + HEXDIG$$ + "%" + HEXDIG$$ + HEXDIG$$ + "%" + HEXDIG$$ + HEXDIG$$) + "|" + subexp("%[89A-Fa-f]" + HEXDIG$$ + "%" + HEXDIG$$ + HEXDIG$$) + "|" + subexp("%" + HEXDIG$$ + HEXDIG$$)); //expanded
        //RFC 5322, except these symbols as per RFC 6068: @ : / ? # [ ] & ; =
        //const ATEXT$$ = "[A-Za-z0-9\\!\\#\\$\\%\\&\\'\\*\\+\\-\\/\\=\\?\\^\\_\\`\\{\\|\\}\\~]";
        //const WSP$$ = "[\\x20\\x09]";
        //const OBS_QTEXT$$ = "[\\x01-\\x08\\x0B\\x0C\\x0E-\\x1F\\x7F]";  //(%d1-8 / %d11-12 / %d14-31 / %d127)
        //const QTEXT$$ = merge("[\\x21\\x23-\\x5B\\x5D-\\x7E]", OBS_QTEXT$$);  //%d33 / %d35-91 / %d93-126 / obs-qtext
        //const VCHAR$$ = "[\\x21-\\x7E]";
        //const WSP$$ = "[\\x20\\x09]";
        //const OBS_QP$ = subexp("\\\\" + merge("[\\x00\\x0D\\x0A]", OBS_QTEXT$$));  //%d0 / CR / LF / obs-qtext
        //const FWS$ = subexp(subexp(WSP$$ + "*" + "\\x0D\\x0A") + "?" + WSP$$ + "+");
        //const QUOTED_PAIR$ = subexp(subexp("\\\\" + subexp(VCHAR$$ + "|" + WSP$$)) + "|" + OBS_QP$);
        //const QUOTED_STRING$ = subexp('\\"' + subexp(FWS$ + "?" + QCONTENT$) + "*" + FWS$ + "?" + '\\"');
        var ATEXT$$ = "[A-Za-z0-9\\!\\$\\%\\'\\*\\+\\-\\^\\_\\`\\{\\|\\}\\~]";
        var QTEXT$$ = "[\\!\\$\\%\\'\\(\\)\\*\\+\\,\\-\\.0-9\\<\\>A-Z\\x5E-\\x7E]";
        var VCHAR$$ = merge(QTEXT$$, "[\\\"\\\\]");
        var SOME_DELIMS$$ = "[\\!\\$\\'\\(\\)\\*\\+\\,\\;\\:\\@]";
        var UNRESERVED = new RegExp(UNRESERVED$$, "g");
        var PCT_ENCODED = new RegExp(PCT_ENCODED$, "g");
        var NOT_LOCAL_PART = new RegExp(merge("[^]", ATEXT$$, "[\\.]", '[\\"]', VCHAR$$), "g");
        var NOT_HFNAME = new RegExp(merge("[^]", UNRESERVED$$, SOME_DELIMS$$), "g");
        var NOT_HFVALUE = NOT_HFNAME;
        function decodeUnreserved(str) {
            var decStr = pctDecChars(str);
            return !decStr.match(UNRESERVED) ? str : decStr;
        }
        var handler$4 = {
            scheme: "mailto",
            parse: function parse$$1(components, options) {
                var mailtoComponents = components;
                var to = mailtoComponents.to = mailtoComponents.path ? mailtoComponents.path.split(",") : [];
                mailtoComponents.path = undefined;
                if (mailtoComponents.query) {
                    var unknownHeaders = false;
                    var headers = {};
                    var hfields = mailtoComponents.query.split("&");
                    for (var x = 0, xl = hfields.length; x < xl; ++x) {
                        var hfield = hfields[x].split("=");
                        switch (hfield[0]) {
                            case "to":
                                var toAddrs = hfield[1].split(",");
                                for (var _x = 0, _xl = toAddrs.length; _x < _xl; ++_x) {
                                    to.push(toAddrs[_x]);
                                }
                                break;
                            case "subject":
                                mailtoComponents.subject = unescapeComponent(hfield[1], options);
                                break;
                            case "body":
                                mailtoComponents.body = unescapeComponent(hfield[1], options);
                                break;
                            default:
                                unknownHeaders = true;
                                headers[unescapeComponent(hfield[0], options)] = unescapeComponent(hfield[1], options);
                                break;
                        }
                    }
                    if (unknownHeaders)
                        mailtoComponents.headers = headers;
                }
                mailtoComponents.query = undefined;
                for (var _x2 = 0, _xl2 = to.length; _x2 < _xl2; ++_x2) {
                    var addr = to[_x2].split("@");
                    addr[0] = unescapeComponent(addr[0]);
                    if (!options.unicodeSupport) {
                        //convert Unicode IDN -> ASCII IDN
                        try {
                            addr[1] = punycode.toASCII(unescapeComponent(addr[1], options).toLowerCase());
                        }
                        catch (e) {
                            mailtoComponents.error = mailtoComponents.error || "Email address's domain name can not be converted to ASCII via punycode: " + e;
                        }
                    }
                    else {
                        addr[1] = unescapeComponent(addr[1], options).toLowerCase();
                    }
                    to[_x2] = addr.join("@");
                }
                return mailtoComponents;
            },
            serialize: function serialize$$1(mailtoComponents, options) {
                var components = mailtoComponents;
                var to = toArray(mailtoComponents.to);
                if (to) {
                    for (var x = 0, xl = to.length; x < xl; ++x) {
                        var toAddr = String(to[x]);
                        var atIdx = toAddr.lastIndexOf("@");
                        var localPart = toAddr.slice(0, atIdx).replace(PCT_ENCODED, decodeUnreserved).replace(PCT_ENCODED, toUpperCase).replace(NOT_LOCAL_PART, pctEncChar);
                        var domain = toAddr.slice(atIdx + 1);
                        //convert IDN via punycode
                        try {
                            domain = !options.iri ? punycode.toASCII(unescapeComponent(domain, options).toLowerCase()) : punycode.toUnicode(domain);
                        }
                        catch (e) {
                            components.error = components.error || "Email address's domain name can not be converted to " + (!options.iri ? "ASCII" : "Unicode") + " via punycode: " + e;
                        }
                        to[x] = localPart + "@" + domain;
                    }
                    components.path = to.join(",");
                }
                var headers = mailtoComponents.headers = mailtoComponents.headers || {};
                if (mailtoComponents.subject)
                    headers["subject"] = mailtoComponents.subject;
                if (mailtoComponents.body)
                    headers["body"] = mailtoComponents.body;
                var fields = [];
                for (var name in headers) {
                    if (headers[name] !== O[name]) {
                        fields.push(name.replace(PCT_ENCODED, decodeUnreserved).replace(PCT_ENCODED, toUpperCase).replace(NOT_HFNAME, pctEncChar) + "=" + headers[name].replace(PCT_ENCODED, decodeUnreserved).replace(PCT_ENCODED, toUpperCase).replace(NOT_HFVALUE, pctEncChar));
                    }
                }
                if (fields.length) {
                    components.query = fields.join("&");
                }
                return components;
            }
        };
        var URN_PARSE = /^([^\:]+)\:(.*)/;
        //RFC 2141
        var handler$5 = {
            scheme: "urn",
            parse: function parse$$1(components, options) {
                var matches = components.path && components.path.match(URN_PARSE);
                var urnComponents = components;
                if (matches) {
                    var scheme = options.scheme || urnComponents.scheme || "urn";
                    var nid = matches[1].toLowerCase();
                    var nss = matches[2];
                    var urnScheme = scheme + ":" + (options.nid || nid);
                    var schemeHandler = SCHEMES[urnScheme];
                    urnComponents.nid = nid;
                    urnComponents.nss = nss;
                    urnComponents.path = undefined;
                    if (schemeHandler) {
                        urnComponents = schemeHandler.parse(urnComponents, options);
                    }
                }
                else {
                    urnComponents.error = urnComponents.error || "URN can not be parsed.";
                }
                return urnComponents;
            },
            serialize: function serialize$$1(urnComponents, options) {
                var scheme = options.scheme || urnComponents.scheme || "urn";
                var nid = urnComponents.nid;
                var urnScheme = scheme + ":" + (options.nid || nid);
                var schemeHandler = SCHEMES[urnScheme];
                if (schemeHandler) {
                    urnComponents = schemeHandler.serialize(urnComponents, options);
                }
                var uriComponents = urnComponents;
                var nss = urnComponents.nss;
                uriComponents.path = (nid || options.nid) + ":" + nss;
                return uriComponents;
            }
        };
        var UUID = /^[0-9A-Fa-f]{8}(?:\-[0-9A-Fa-f]{4}){3}\-[0-9A-Fa-f]{12}$/;
        //RFC 4122
        var handler$6 = {
            scheme: "urn:uuid",
            parse: function parse(urnComponents, options) {
                var uuidComponents = urnComponents;
                uuidComponents.uuid = uuidComponents.nss;
                uuidComponents.nss = undefined;
                if (!options.tolerant && (!uuidComponents.uuid || !uuidComponents.uuid.match(UUID))) {
                    uuidComponents.error = uuidComponents.error || "UUID is not valid.";
                }
                return uuidComponents;
            },
            serialize: function serialize(uuidComponents, options) {
                var urnComponents = uuidComponents;
                //normalize UUID
                urnComponents.nss = (uuidComponents.uuid || "").toLowerCase();
                return urnComponents;
            }
        };
        SCHEMES[handler.scheme] = handler;
        SCHEMES[handler$1.scheme] = handler$1;
        SCHEMES[handler$2.scheme] = handler$2;
        SCHEMES[handler$3.scheme] = handler$3;
        SCHEMES[handler$4.scheme] = handler$4;
        SCHEMES[handler$5.scheme] = handler$5;
        SCHEMES[handler$6.scheme] = handler$6;
        exports.SCHEMES = SCHEMES;
        exports.pctEncChar = pctEncChar;
        exports.pctDecChars = pctDecChars;
        exports.parse = parse;
        exports.removeDotSegments = removeDotSegments;
        exports.serialize = serialize;
        exports.resolveComponents = resolveComponents;
        exports.resolve = resolve;
        exports.normalize = normalize;
        exports.equal = equal;
        exports.escapeComponent = escapeComponent;
        exports.unescapeComponent = unescapeComponent;
        Object.defineProperty(exports, '__esModule', { value: true });
    })));
    
},
/* fast-deep-equal/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    // do not edit .js files directly - edit src/index.jst
    module.exports = function equal(a, b) {
        if (a === b)
            return true;
        if (a && b && typeof a == 'object' && typeof b == 'object') {
            if (a.constructor !== b.constructor)
                return false;
            var length, i, keys;
            if (Array.isArray(a)) {
                length = a.length;
                if (length != b.length)
                    return false;
                for (i = length; i-- !== 0;)
                    if (!equal(a[i], b[i]))
                        return false;
                return true;
            }
            if (a.constructor === RegExp)
                return a.source === b.source && a.flags === b.flags;
            if (a.valueOf !== Object.prototype.valueOf)
                return a.valueOf() === b.valueOf();
            if (a.toString !== Object.prototype.toString)
                return a.toString() === b.toString();
            keys = Object.keys(a);
            length = keys.length;
            if (length !== Object.keys(b).length)
                return false;
            for (i = length; i-- !== 0;)
                if (!Object.prototype.hasOwnProperty.call(b, keys[i]))
                    return false;
            for (i = length; i-- !== 0;) {
                var key = keys[i];
                if (!equal(a[key], b[key]))
                    return false;
            }
            return true;
        }
        // true if both NaN, false otherwise
        return a !== a && b !== b;
    };
},
/* ajv/lib/compile/util.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = {
        copy: copy,
        checkDataType: checkDataType,
        checkDataTypes: checkDataTypes,
        coerceToTypes: coerceToTypes,
        toHash: toHash,
        getProperty: getProperty,
        escapeQuotes: escapeQuotes,
        equal: require(237) /* fast-deep-equal */,
        ucs2length: require(239) /* ./ucs2length */,
        varOccurences: varOccurences,
        varReplace: varReplace,
        schemaHasRules: schemaHasRules,
        schemaHasRulesExcept: schemaHasRulesExcept,
        schemaUnknownRules: schemaUnknownRules,
        toQuotedString: toQuotedString,
        getPathExpr: getPathExpr,
        getPath: getPath,
        getData: getData,
        unescapeFragment: unescapeFragment,
        unescapeJsonPointer: unescapeJsonPointer,
        escapeFragment: escapeFragment,
        escapeJsonPointer: escapeJsonPointer
    };
    function copy(o, to) {
        to = to || {};
        for (var key in o)
            to[key] = o[key];
        return to;
    }
    function checkDataType(dataType, data, strictNumbers, negate) {
        var EQUAL = negate ? ' !== ' : ' === ', AND = negate ? ' || ' : ' && ', OK = negate ? '!' : '', NOT = negate ? '' : '!';
        switch (dataType) {
            case 'null': return data + EQUAL + 'null';
            case 'array': return OK + 'Array.isArray(' + data + ')';
            case 'object': return '(' + OK + data + AND +
                'typeof ' + data + EQUAL + '"object"' + AND +
                NOT + 'Array.isArray(' + data + '))';
            case 'integer': return '(typeof ' + data + EQUAL + '"number"' + AND +
                NOT + '(' + data + ' % 1)' +
                AND + data + EQUAL + data +
                (strictNumbers ? (AND + OK + 'isFinite(' + data + ')') : '') + ')';
            case 'number': return '(typeof ' + data + EQUAL + '"' + dataType + '"' +
                (strictNumbers ? (AND + OK + 'isFinite(' + data + ')') : '') + ')';
            default: return 'typeof ' + data + EQUAL + '"' + dataType + '"';
        }
    }
    function checkDataTypes(dataTypes, data, strictNumbers) {
        switch (dataTypes.length) {
            case 1: return checkDataType(dataTypes[0], data, strictNumbers, true);
            default:
                var code = '';
                var types = toHash(dataTypes);
                if (types.array && types.object) {
                    code = types.null ? '(' : '(!' + data + ' || ';
                    code += 'typeof ' + data + ' !== "object")';
                    delete types.null;
                    delete types.array;
                    delete types.object;
                }
                if (types.number)
                    delete types.integer;
                for (var t in types)
                    code += (code ? ' && ' : '') + checkDataType(t, data, strictNumbers, true);
                return code;
        }
    }
    var COERCE_TO_TYPES = toHash(['string', 'number', 'integer', 'boolean', 'null']);
    function coerceToTypes(optionCoerceTypes, dataTypes) {
        if (Array.isArray(dataTypes)) {
            var types = [];
            for (var i = 0; i < dataTypes.length; i++) {
                var t = dataTypes[i];
                if (COERCE_TO_TYPES[t])
                    types[types.length] = t;
                else if (optionCoerceTypes === 'array' && t === 'array')
                    types[types.length] = t;
            }
            if (types.length)
                return types;
        }
        else if (COERCE_TO_TYPES[dataTypes]) {
            return [dataTypes];
        }
        else if (optionCoerceTypes === 'array' && dataTypes === 'array') {
            return ['array'];
        }
    }
    function toHash(arr) {
        var hash = {};
        for (var i = 0; i < arr.length; i++)
            hash[arr[i]] = true;
        return hash;
    }
    var IDENTIFIER = /^[a-z$_][a-z$_0-9]*$/i;
    var SINGLE_QUOTE = /'|\\/g;
    function getProperty(key) {
        return typeof key == 'number'
            ? '[' + key + ']'
            : IDENTIFIER.test(key)
                ? '.' + key
                : "['" + escapeQuotes(key) + "']";
    }
    function escapeQuotes(str) {
        return str.replace(SINGLE_QUOTE, '\\$&')
            .replace(/\n/g, '\\n')
            .replace(/\r/g, '\\r')
            .replace(/\f/g, '\\f')
            .replace(/\t/g, '\\t');
    }
    function varOccurences(str, dataVar) {
        dataVar += '[^0-9]';
        var matches = str.match(new RegExp(dataVar, 'g'));
        return matches ? matches.length : 0;
    }
    function varReplace(str, dataVar, expr) {
        dataVar += '([^0-9])';
        expr = expr.replace(/\$/g, '$$$$');
        return str.replace(new RegExp(dataVar, 'g'), expr + '$1');
    }
    function schemaHasRules(schema, rules) {
        if (typeof schema == 'boolean')
            return !schema;
        for (var key in schema)
            if (rules[key])
                return true;
    }
    function schemaHasRulesExcept(schema, rules, exceptKeyword) {
        if (typeof schema == 'boolean')
            return !schema && exceptKeyword != 'not';
        for (var key in schema)
            if (key != exceptKeyword && rules[key])
                return true;
    }
    function schemaUnknownRules(schema, rules) {
        if (typeof schema == 'boolean')
            return;
        for (var key in schema)
            if (!rules[key])
                return key;
    }
    function toQuotedString(str) {
        return '\'' + escapeQuotes(str) + '\'';
    }
    function getPathExpr(currentPath, expr, jsonPointers, isNumber) {
        var path = jsonPointers // false by default
            ? '\'/\' + ' + expr + (isNumber ? '' : '.replace(/~/g, \'~0\').replace(/\\//g, \'~1\')')
            : (isNumber ? '\'[\' + ' + expr + ' + \']\'' : '\'[\\\'\' + ' + expr + ' + \'\\\']\'');
        return joinPaths(currentPath, path);
    }
    function getPath(currentPath, prop, jsonPointers) {
        var path = jsonPointers // false by default
            ? toQuotedString('/' + escapeJsonPointer(prop))
            : toQuotedString(getProperty(prop));
        return joinPaths(currentPath, path);
    }
    var JSON_POINTER = /^\/(?:[^~]|~0|~1)*$/;
    var RELATIVE_JSON_POINTER = /^([0-9]+)(#|\/(?:[^~]|~0|~1)*)?$/;
    function getData($data, lvl, paths) {
        var up, jsonPointer, data, matches;
        if ($data === '')
            return 'rootData';
        if ($data[0] == '/') {
            if (!JSON_POINTER.test($data))
                throw new Error('Invalid JSON-pointer: ' + $data);
            jsonPointer = $data;
            data = 'rootData';
        }
        else {
            matches = $data.match(RELATIVE_JSON_POINTER);
            if (!matches)
                throw new Error('Invalid JSON-pointer: ' + $data);
            up = +matches[1];
            jsonPointer = matches[2];
            if (jsonPointer == '#') {
                if (up >= lvl)
                    throw new Error('Cannot access property/index ' + up + ' levels up, current level is ' + lvl);
                return paths[lvl - up];
            }
            if (up > lvl)
                throw new Error('Cannot access data ' + up + ' levels up, current level is ' + lvl);
            data = 'data' + ((lvl - up) || '');
            if (!jsonPointer)
                return data;
        }
        var expr = data;
        var segments = jsonPointer.split('/');
        for (var i = 0; i < segments.length; i++) {
            var segment = segments[i];
            if (segment) {
                data += getProperty(unescapeJsonPointer(segment));
                expr += ' && ' + data;
            }
        }
        return expr;
    }
    function joinPaths(a, b) {
        if (a == '""')
            return b;
        return (a + ' + ' + b).replace(/([^\\])' \+ '/g, '$1');
    }
    function unescapeFragment(str) {
        return unescapeJsonPointer(decodeURIComponent(str));
    }
    function escapeFragment(str) {
        return encodeURIComponent(escapeJsonPointer(str));
    }
    function escapeJsonPointer(str) {
        return str.replace(/~/g, '~0').replace(/\//g, '~1');
    }
    function unescapeJsonPointer(str) {
        return str.replace(/~1/g, '/').replace(/~0/g, '~');
    }
},
/* ajv/lib/compile/ucs2length.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    // https://mathiasbynens.be/notes/javascript-encoding
    // https://github.com/bestiejs/punycode.js - punycode.ucs2.decode
    module.exports = function ucs2length(str) {
        var length = 0, len = str.length, pos = 0, value;
        while (pos < len) {
            length++;
            value = str.charCodeAt(pos++);
            if (value >= 0xD800 && value <= 0xDBFF && pos < len) {
                // high surrogate, and there is a next character
                value = str.charCodeAt(pos);
                if ((value & 0xFC00) == 0xDC00)
                    pos++; // low surrogate
            }
        }
        return length;
    };
},
/* ajv/lib/compile/schema_obj.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var util = require(238) /* ./util */;
    module.exports = SchemaObject;
    function SchemaObject(obj) {
        util.copy(obj, this);
    }
},
/* json-schema-traverse/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var traverse = module.exports = function (schema, opts, cb) {
        // Legacy support for v0.3.1 and earlier.
        if (typeof opts == 'function') {
            cb = opts;
            opts = {};
        }
        cb = opts.cb || cb;
        var pre = (typeof cb == 'function') ? cb : cb.pre || function () { };
        var post = cb.post || function () { };
        _traverse(opts, pre, post, schema, '', schema);
    };
    traverse.keywords = {
        additionalItems: true,
        items: true,
        contains: true,
        additionalProperties: true,
        propertyNames: true,
        not: true
    };
    traverse.arrayKeywords = {
        items: true,
        allOf: true,
        anyOf: true,
        oneOf: true
    };
    traverse.propsKeywords = {
        definitions: true,
        properties: true,
        patternProperties: true,
        dependencies: true
    };
    traverse.skipKeywords = {
        default: true,
        enum: true,
        const: true,
        required: true,
        maximum: true,
        minimum: true,
        exclusiveMaximum: true,
        exclusiveMinimum: true,
        multipleOf: true,
        maxLength: true,
        minLength: true,
        pattern: true,
        format: true,
        maxItems: true,
        minItems: true,
        uniqueItems: true,
        maxProperties: true,
        minProperties: true
    };
    function _traverse(opts, pre, post, schema, jsonPtr, rootSchema, parentJsonPtr, parentKeyword, parentSchema, keyIndex) {
        if (schema && typeof schema == 'object' && !Array.isArray(schema)) {
            pre(schema, jsonPtr, rootSchema, parentJsonPtr, parentKeyword, parentSchema, keyIndex);
            for (var key in schema) {
                var sch = schema[key];
                if (Array.isArray(sch)) {
                    if (key in traverse.arrayKeywords) {
                        for (var i = 0; i < sch.length; i++)
                            _traverse(opts, pre, post, sch[i], jsonPtr + '/' + key + '/' + i, rootSchema, jsonPtr, key, schema, i);
                    }
                }
                else if (key in traverse.propsKeywords) {
                    if (sch && typeof sch == 'object') {
                        for (var prop in sch)
                            _traverse(opts, pre, post, sch[prop], jsonPtr + '/' + key + '/' + escapeJsonPtr(prop), rootSchema, jsonPtr, key, schema, prop);
                    }
                }
                else if (key in traverse.keywords || (opts.allKeys && !(key in traverse.skipKeywords))) {
                    _traverse(opts, pre, post, sch, jsonPtr + '/' + key, rootSchema, jsonPtr, key, schema);
                }
            }
            post(schema, jsonPtr, rootSchema, parentJsonPtr, parentKeyword, parentSchema, keyIndex);
        }
    }
    function escapeJsonPtr(str) {
        return str.replace(/~/g, '~0').replace(/\//g, '~1');
    }
},
/* ajv/lib/compile/error_classes.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var resolve = require(235) /* ./resolve */;
    module.exports = {
        Validation: errorSubclass(ValidationError),
        MissingRef: errorSubclass(MissingRefError)
    };
    function ValidationError(errors) {
        this.message = 'validation failed';
        this.errors = errors;
        this.ajv = this.validation = true;
    }
    MissingRefError.message = function (baseId, ref) {
        return 'can\'t resolve reference ' + ref + ' from id ' + baseId;
    };
    function MissingRefError(baseId, ref, message) {
        this.message = message || MissingRefError.message(baseId, ref);
        this.missingRef = resolve.url(baseId, ref);
        this.missingSchema = resolve.normalizeId(resolve.fullPath(this.missingRef));
    }
    function errorSubclass(Subclass) {
        Subclass.prototype = Object.create(Error.prototype);
        Subclass.prototype.constructor = Subclass;
        return Subclass;
    }
},
/* fast-json-stable-stringify/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function (data, opts) {
        if (!opts)
            opts = {};
        if (typeof opts === 'function')
            opts = { cmp: opts };
        var cycles = (typeof opts.cycles === 'boolean') ? opts.cycles : false;
        var cmp = opts.cmp && (function (f) {
            return function (node) {
                return function (a, b) {
                    var aobj = { key: a, value: node[a] };
                    var bobj = { key: b, value: node[b] };
                    return f(aobj, bobj);
                };
            };
        })(opts.cmp);
        var seen = [];
        return (function stringify(node) {
            if (node && node.toJSON && typeof node.toJSON === 'function') {
                node = node.toJSON();
            }
            if (node === undefined)
                return;
            if (typeof node == 'number')
                return isFinite(node) ? '' + node : 'null';
            if (typeof node !== 'object')
                return JSON.stringify(node);
            var i, out;
            if (Array.isArray(node)) {
                out = '[';
                for (i = 0; i < node.length; i++) {
                    if (i)
                        out += ',';
                    out += stringify(node[i]) || 'null';
                }
                return out + ']';
            }
            if (node === null)
                return 'null';
            if (seen.indexOf(node) !== -1) {
                if (cycles)
                    return JSON.stringify('__cycle__');
                throw new TypeError('Converting circular structure to JSON');
            }
            var seenIndex = seen.push(node) - 1;
            var keys = Object.keys(node).sort(cmp && cmp(node));
            out = '';
            for (i = 0; i < keys.length; i++) {
                var key = keys[i];
                var value = stringify(node[key]);
                if (!value)
                    continue;
                if (out)
                    out += ',';
                out += JSON.stringify(key) + ':' + value;
            }
            seen.splice(seenIndex, 1);
            return '{' + out + '}';
        })(data);
    };
},
/* ajv/lib/dotjs/validate.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_validate(it, $keyword, $ruleType) {
        var out = '';
        var $async = it.schema.$async === true, $refKeywords = it.util.schemaHasRulesExcept(it.schema, it.RULES.all, '$ref'), $id = it.self._getId(it.schema);
        if (it.opts.strictKeywords) {
            var $unknownKwd = it.util.schemaUnknownRules(it.schema, it.RULES.keywords);
            if ($unknownKwd) {
                var $keywordsMsg = 'unknown keyword: ' + $unknownKwd;
                if (it.opts.strictKeywords === 'log')
                    it.logger.warn($keywordsMsg);
                else
                    throw new Error($keywordsMsg);
            }
        }
        if (it.isTop) {
            out += ' var validate = ';
            if ($async) {
                it.async = true;
                out += 'async ';
            }
            out += 'function(data, dataPath, parentData, parentDataProperty, rootData) { \'use strict\'; ';
            if ($id && (it.opts.sourceCode || it.opts.processCode)) {
                out += ' ' + ('/\*# sourceURL=' + $id + ' */') + ' ';
            }
        }
        if (typeof it.schema == 'boolean' || !($refKeywords || it.schema.$ref)) {
            var $keyword = 'false schema';
            var $lvl = it.level;
            var $dataLvl = it.dataLevel;
            var $schema = it.schema[$keyword];
            var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
            var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
            var $breakOnError = !it.opts.allErrors;
            var $errorKeyword;
            var $data = 'data' + ($dataLvl || '');
            var $valid = 'valid' + $lvl;
            if (it.schema === false) {
                if (it.isTop) {
                    $breakOnError = true;
                }
                else {
                    out += ' var ' + ($valid) + ' = false; ';
                }
                var $$outStack = $$outStack || [];
                $$outStack.push(out);
                out = ''; /* istanbul ignore else */
                if (it.createErrors !== false) {
                    out += ' { keyword: \'' + ($errorKeyword || 'false schema') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: {} ';
                    if (it.opts.messages !== false) {
                        out += ' , message: \'boolean schema is false\' ';
                    }
                    if (it.opts.verbose) {
                        out += ' , schema: false , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                    }
                    out += ' } ';
                }
                else {
                    out += ' {} ';
                }
                var __err = out;
                out = $$outStack.pop();
                if (!it.compositeRule && $breakOnError) {
                    /* istanbul ignore if */
                    if (it.async) {
                        out += ' throw new ValidationError([' + (__err) + ']); ';
                    }
                    else {
                        out += ' validate.errors = [' + (__err) + ']; return false; ';
                    }
                }
                else {
                    out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                }
            }
            else {
                if (it.isTop) {
                    if ($async) {
                        out += ' return data; ';
                    }
                    else {
                        out += ' validate.errors = null; return true; ';
                    }
                }
                else {
                    out += ' var ' + ($valid) + ' = true; ';
                }
            }
            if (it.isTop) {
                out += ' }; return validate; ';
            }
            return out;
        }
        if (it.isTop) {
            var $top = it.isTop, $lvl = it.level = 0, $dataLvl = it.dataLevel = 0, $data = 'data';
            it.rootId = it.resolve.fullPath(it.self._getId(it.root.schema));
            it.baseId = it.baseId || it.rootId;
            delete it.isTop;
            it.dataPathArr = [""];
            if (it.schema.default !== undefined && it.opts.useDefaults && it.opts.strictDefaults) {
                var $defaultMsg = 'default is ignored in the schema root';
                if (it.opts.strictDefaults === 'log')
                    it.logger.warn($defaultMsg);
                else
                    throw new Error($defaultMsg);
            }
            out += ' var vErrors = null; ';
            out += ' var errors = 0;     ';
            out += ' if (rootData === undefined) rootData = data; ';
        }
        else {
            var $lvl = it.level, $dataLvl = it.dataLevel, $data = 'data' + ($dataLvl || '');
            if ($id)
                it.baseId = it.resolve.url(it.baseId, $id);
            if ($async && !it.async)
                throw new Error('async schema in sync schema');
            out += ' var errs_' + ($lvl) + ' = errors;';
        }
        var $valid = 'valid' + $lvl, $breakOnError = !it.opts.allErrors, $closingBraces1 = '', $closingBraces2 = '';
        var $errorKeyword;
        var $typeSchema = it.schema.type, $typeIsArray = Array.isArray($typeSchema);
        if ($typeSchema && it.opts.nullable && it.schema.nullable === true) {
            if ($typeIsArray) {
                if ($typeSchema.indexOf('null') == -1)
                    $typeSchema = $typeSchema.concat('null');
            }
            else if ($typeSchema != 'null') {
                $typeSchema = [$typeSchema, 'null'];
                $typeIsArray = true;
            }
        }
        if ($typeIsArray && $typeSchema.length == 1) {
            $typeSchema = $typeSchema[0];
            $typeIsArray = false;
        }
        if (it.schema.$ref && $refKeywords) {
            if (it.opts.extendRefs == 'fail') {
                throw new Error('$ref: validation keywords used in schema at path "' + it.errSchemaPath + '" (see option extendRefs)');
            }
            else if (it.opts.extendRefs !== true) {
                $refKeywords = false;
                it.logger.warn('$ref: keywords ignored in schema at path "' + it.errSchemaPath + '"');
            }
        }
        if (it.schema.$comment && it.opts.$comment) {
            out += ' ' + (it.RULES.all.$comment.code(it, '$comment'));
        }
        if ($typeSchema) {
            if (it.opts.coerceTypes) {
                var $coerceToTypes = it.util.coerceToTypes(it.opts.coerceTypes, $typeSchema);
            }
            var $rulesGroup = it.RULES.types[$typeSchema];
            if ($coerceToTypes || $typeIsArray || $rulesGroup === true || ($rulesGroup && !$shouldUseGroup($rulesGroup))) {
                var $schemaPath = it.schemaPath + '.type', $errSchemaPath = it.errSchemaPath + '/type';
                var $schemaPath = it.schemaPath + '.type', $errSchemaPath = it.errSchemaPath + '/type', $method = $typeIsArray ? 'checkDataTypes' : 'checkDataType';
                out += ' if (' + (it.util[$method]($typeSchema, $data, it.opts.strictNumbers, true)) + ') { ';
                if ($coerceToTypes) {
                    var $dataType = 'dataType' + $lvl, $coerced = 'coerced' + $lvl;
                    out += ' var ' + ($dataType) + ' = typeof ' + ($data) + '; var ' + ($coerced) + ' = undefined; ';
                    if (it.opts.coerceTypes == 'array') {
                        out += ' if (' + ($dataType) + ' == \'object\' && Array.isArray(' + ($data) + ') && ' + ($data) + '.length == 1) { ' + ($data) + ' = ' + ($data) + '[0]; ' + ($dataType) + ' = typeof ' + ($data) + '; if (' + (it.util.checkDataType(it.schema.type, $data, it.opts.strictNumbers)) + ') ' + ($coerced) + ' = ' + ($data) + '; } ';
                    }
                    out += ' if (' + ($coerced) + ' !== undefined) ; ';
                    var arr1 = $coerceToTypes;
                    if (arr1) {
                        var $type, $i = -1, l1 = arr1.length - 1;
                        while ($i < l1) {
                            $type = arr1[$i += 1];
                            if ($type == 'string') {
                                out += ' else if (' + ($dataType) + ' == \'number\' || ' + ($dataType) + ' == \'boolean\') ' + ($coerced) + ' = \'\' + ' + ($data) + '; else if (' + ($data) + ' === null) ' + ($coerced) + ' = \'\'; ';
                            }
                            else if ($type == 'number' || $type == 'integer') {
                                out += ' else if (' + ($dataType) + ' == \'boolean\' || ' + ($data) + ' === null || (' + ($dataType) + ' == \'string\' && ' + ($data) + ' && ' + ($data) + ' == +' + ($data) + ' ';
                                if ($type == 'integer') {
                                    out += ' && !(' + ($data) + ' % 1)';
                                }
                                out += ')) ' + ($coerced) + ' = +' + ($data) + '; ';
                            }
                            else if ($type == 'boolean') {
                                out += ' else if (' + ($data) + ' === \'false\' || ' + ($data) + ' === 0 || ' + ($data) + ' === null) ' + ($coerced) + ' = false; else if (' + ($data) + ' === \'true\' || ' + ($data) + ' === 1) ' + ($coerced) + ' = true; ';
                            }
                            else if ($type == 'null') {
                                out += ' else if (' + ($data) + ' === \'\' || ' + ($data) + ' === 0 || ' + ($data) + ' === false) ' + ($coerced) + ' = null; ';
                            }
                            else if (it.opts.coerceTypes == 'array' && $type == 'array') {
                                out += ' else if (' + ($dataType) + ' == \'string\' || ' + ($dataType) + ' == \'number\' || ' + ($dataType) + ' == \'boolean\' || ' + ($data) + ' == null) ' + ($coerced) + ' = [' + ($data) + ']; ';
                            }
                        }
                    }
                    out += ' else {   ';
                    var $$outStack = $$outStack || [];
                    $$outStack.push(out);
                    out = ''; /* istanbul ignore else */
                    if (it.createErrors !== false) {
                        out += ' { keyword: \'' + ($errorKeyword || 'type') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { type: \'';
                        if ($typeIsArray) {
                            out += '' + ($typeSchema.join(","));
                        }
                        else {
                            out += '' + ($typeSchema);
                        }
                        out += '\' } ';
                        if (it.opts.messages !== false) {
                            out += ' , message: \'should be ';
                            if ($typeIsArray) {
                                out += '' + ($typeSchema.join(","));
                            }
                            else {
                                out += '' + ($typeSchema);
                            }
                            out += '\' ';
                        }
                        if (it.opts.verbose) {
                            out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                        }
                        out += ' } ';
                    }
                    else {
                        out += ' {} ';
                    }
                    var __err = out;
                    out = $$outStack.pop();
                    if (!it.compositeRule && $breakOnError) {
                        /* istanbul ignore if */
                        if (it.async) {
                            out += ' throw new ValidationError([' + (__err) + ']); ';
                        }
                        else {
                            out += ' validate.errors = [' + (__err) + ']; return false; ';
                        }
                    }
                    else {
                        out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                    }
                    out += ' } if (' + ($coerced) + ' !== undefined) {  ';
                    var $parentData = $dataLvl ? 'data' + (($dataLvl - 1) || '') : 'parentData', $parentDataProperty = $dataLvl ? it.dataPathArr[$dataLvl] : 'parentDataProperty';
                    out += ' ' + ($data) + ' = ' + ($coerced) + '; ';
                    if (!$dataLvl) {
                        out += 'if (' + ($parentData) + ' !== undefined)';
                    }
                    out += ' ' + ($parentData) + '[' + ($parentDataProperty) + '] = ' + ($coerced) + '; } ';
                }
                else {
                    var $$outStack = $$outStack || [];
                    $$outStack.push(out);
                    out = ''; /* istanbul ignore else */
                    if (it.createErrors !== false) {
                        out += ' { keyword: \'' + ($errorKeyword || 'type') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { type: \'';
                        if ($typeIsArray) {
                            out += '' + ($typeSchema.join(","));
                        }
                        else {
                            out += '' + ($typeSchema);
                        }
                        out += '\' } ';
                        if (it.opts.messages !== false) {
                            out += ' , message: \'should be ';
                            if ($typeIsArray) {
                                out += '' + ($typeSchema.join(","));
                            }
                            else {
                                out += '' + ($typeSchema);
                            }
                            out += '\' ';
                        }
                        if (it.opts.verbose) {
                            out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                        }
                        out += ' } ';
                    }
                    else {
                        out += ' {} ';
                    }
                    var __err = out;
                    out = $$outStack.pop();
                    if (!it.compositeRule && $breakOnError) {
                        /* istanbul ignore if */
                        if (it.async) {
                            out += ' throw new ValidationError([' + (__err) + ']); ';
                        }
                        else {
                            out += ' validate.errors = [' + (__err) + ']; return false; ';
                        }
                    }
                    else {
                        out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                    }
                }
                out += ' } ';
            }
        }
        if (it.schema.$ref && !$refKeywords) {
            out += ' ' + (it.RULES.all.$ref.code(it, '$ref')) + ' ';
            if ($breakOnError) {
                out += ' } if (errors === ';
                if ($top) {
                    out += '0';
                }
                else {
                    out += 'errs_' + ($lvl);
                }
                out += ') { ';
                $closingBraces2 += '}';
            }
        }
        else {
            var arr2 = it.RULES;
            if (arr2) {
                var $rulesGroup, i2 = -1, l2 = arr2.length - 1;
                while (i2 < l2) {
                    $rulesGroup = arr2[i2 += 1];
                    if ($shouldUseGroup($rulesGroup)) {
                        if ($rulesGroup.type) {
                            out += ' if (' + (it.util.checkDataType($rulesGroup.type, $data, it.opts.strictNumbers)) + ') { ';
                        }
                        if (it.opts.useDefaults) {
                            if ($rulesGroup.type == 'object' && it.schema.properties) {
                                var $schema = it.schema.properties, $schemaKeys = Object.keys($schema);
                                var arr3 = $schemaKeys;
                                if (arr3) {
                                    var $propertyKey, i3 = -1, l3 = arr3.length - 1;
                                    while (i3 < l3) {
                                        $propertyKey = arr3[i3 += 1];
                                        var $sch = $schema[$propertyKey];
                                        if ($sch.default !== undefined) {
                                            var $passData = $data + it.util.getProperty($propertyKey);
                                            if (it.compositeRule) {
                                                if (it.opts.strictDefaults) {
                                                    var $defaultMsg = 'default is ignored for: ' + $passData;
                                                    if (it.opts.strictDefaults === 'log')
                                                        it.logger.warn($defaultMsg);
                                                    else
                                                        throw new Error($defaultMsg);
                                                }
                                            }
                                            else {
                                                out += ' if (' + ($passData) + ' === undefined ';
                                                if (it.opts.useDefaults == 'empty') {
                                                    out += ' || ' + ($passData) + ' === null || ' + ($passData) + ' === \'\' ';
                                                }
                                                out += ' ) ' + ($passData) + ' = ';
                                                if (it.opts.useDefaults == 'shared') {
                                                    out += ' ' + (it.useDefault($sch.default)) + ' ';
                                                }
                                                else {
                                                    out += ' ' + (JSON.stringify($sch.default)) + ' ';
                                                }
                                                out += '; ';
                                            }
                                        }
                                    }
                                }
                            }
                            else if ($rulesGroup.type == 'array' && Array.isArray(it.schema.items)) {
                                var arr4 = it.schema.items;
                                if (arr4) {
                                    var $sch, $i = -1, l4 = arr4.length - 1;
                                    while ($i < l4) {
                                        $sch = arr4[$i += 1];
                                        if ($sch.default !== undefined) {
                                            var $passData = $data + '[' + $i + ']';
                                            if (it.compositeRule) {
                                                if (it.opts.strictDefaults) {
                                                    var $defaultMsg = 'default is ignored for: ' + $passData;
                                                    if (it.opts.strictDefaults === 'log')
                                                        it.logger.warn($defaultMsg);
                                                    else
                                                        throw new Error($defaultMsg);
                                                }
                                            }
                                            else {
                                                out += ' if (' + ($passData) + ' === undefined ';
                                                if (it.opts.useDefaults == 'empty') {
                                                    out += ' || ' + ($passData) + ' === null || ' + ($passData) + ' === \'\' ';
                                                }
                                                out += ' ) ' + ($passData) + ' = ';
                                                if (it.opts.useDefaults == 'shared') {
                                                    out += ' ' + (it.useDefault($sch.default)) + ' ';
                                                }
                                                else {
                                                    out += ' ' + (JSON.stringify($sch.default)) + ' ';
                                                }
                                                out += '; ';
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        var arr5 = $rulesGroup.rules;
                        if (arr5) {
                            var $rule, i5 = -1, l5 = arr5.length - 1;
                            while (i5 < l5) {
                                $rule = arr5[i5 += 1];
                                if ($shouldUseRule($rule)) {
                                    var $code = $rule.code(it, $rule.keyword, $rulesGroup.type);
                                    if ($code) {
                                        out += ' ' + ($code) + ' ';
                                        if ($breakOnError) {
                                            $closingBraces1 += '}';
                                        }
                                    }
                                }
                            }
                        }
                        if ($breakOnError) {
                            out += ' ' + ($closingBraces1) + ' ';
                            $closingBraces1 = '';
                        }
                        if ($rulesGroup.type) {
                            out += ' } ';
                            if ($typeSchema && $typeSchema === $rulesGroup.type && !$coerceToTypes) {
                                out += ' else { ';
                                var $schemaPath = it.schemaPath + '.type', $errSchemaPath = it.errSchemaPath + '/type';
                                var $$outStack = $$outStack || [];
                                $$outStack.push(out);
                                out = ''; /* istanbul ignore else */
                                if (it.createErrors !== false) {
                                    out += ' { keyword: \'' + ($errorKeyword || 'type') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { type: \'';
                                    if ($typeIsArray) {
                                        out += '' + ($typeSchema.join(","));
                                    }
                                    else {
                                        out += '' + ($typeSchema);
                                    }
                                    out += '\' } ';
                                    if (it.opts.messages !== false) {
                                        out += ' , message: \'should be ';
                                        if ($typeIsArray) {
                                            out += '' + ($typeSchema.join(","));
                                        }
                                        else {
                                            out += '' + ($typeSchema);
                                        }
                                        out += '\' ';
                                    }
                                    if (it.opts.verbose) {
                                        out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                                    }
                                    out += ' } ';
                                }
                                else {
                                    out += ' {} ';
                                }
                                var __err = out;
                                out = $$outStack.pop();
                                if (!it.compositeRule && $breakOnError) {
                                    /* istanbul ignore if */
                                    if (it.async) {
                                        out += ' throw new ValidationError([' + (__err) + ']); ';
                                    }
                                    else {
                                        out += ' validate.errors = [' + (__err) + ']; return false; ';
                                    }
                                }
                                else {
                                    out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                                }
                                out += ' } ';
                            }
                        }
                        if ($breakOnError) {
                            out += ' if (errors === ';
                            if ($top) {
                                out += '0';
                            }
                            else {
                                out += 'errs_' + ($lvl);
                            }
                            out += ') { ';
                            $closingBraces2 += '}';
                        }
                    }
                }
            }
        }
        if ($breakOnError) {
            out += ' ' + ($closingBraces2) + ' ';
        }
        if ($top) {
            if ($async) {
                out += ' if (errors === 0) return data;           ';
                out += ' else throw new ValidationError(vErrors); ';
            }
            else {
                out += ' validate.errors = vErrors; ';
                out += ' return errors === 0;       ';
            }
            out += ' }; return validate;';
        }
        else {
            out += ' var ' + ($valid) + ' = errors === errs_' + ($lvl) + ';';
        }
        function $shouldUseGroup($rulesGroup) {
            var rules = $rulesGroup.rules;
            for (var i = 0; i < rules.length; i++)
                if ($shouldUseRule(rules[i]))
                    return true;
        }
        function $shouldUseRule($rule) {
            return it.schema[$rule.keyword] !== undefined || ($rule.implements && $ruleImplementsSomeKeyword($rule));
        }
        function $ruleImplementsSomeKeyword($rule) {
            var impl = $rule.implements;
            for (var i = 0; i < impl.length; i++)
                if (it.schema[impl[i]] !== undefined)
                    return true;
        }
        return out;
    };
},
/* ajv/lib/cache.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var Cache = module.exports = function Cache() {
        this._cache = {};
    };
    Cache.prototype.put = function Cache_put(key, value) {
        this._cache[key] = value;
    };
    Cache.prototype.get = function Cache_get(key) {
        return this._cache[key];
    };
    Cache.prototype.del = function Cache_del(key) {
        delete this._cache[key];
    };
    Cache.prototype.clear = function Cache_clear() {
        this._cache = {};
    };
},
/* ajv/lib/compile/formats.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var util = require(238) /* ./util */;
    var DATE = /^(\d\d\d\d)-(\d\d)-(\d\d)$/;
    var DAYS = [0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    var TIME = /^(\d\d):(\d\d):(\d\d)(\.\d+)?(z|[+-]\d\d(?::?\d\d)?)?$/i;
    var HOSTNAME = /^(?=.{1,253}\.?$)[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?(?:\.[a-z0-9](?:[-0-9a-z]{0,61}[0-9a-z])?)*\.?$/i;
    var URI = /^(?:[a-z][a-z0-9+\-.]*:)(?:\/?\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:]|%[0-9a-f]{2})*@)?(?:\[(?:(?:(?:(?:[0-9a-f]{1,4}:){6}|::(?:[0-9a-f]{1,4}:){5}|(?:[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){4}|(?:(?:[0-9a-f]{1,4}:){0,1}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){3}|(?:(?:[0-9a-f]{1,4}:){0,2}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){2}|(?:(?:[0-9a-f]{1,4}:){0,3}[0-9a-f]{1,4})?::[0-9a-f]{1,4}:|(?:(?:[0-9a-f]{1,4}:){0,4}[0-9a-f]{1,4})?::)(?:[0-9a-f]{1,4}:[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?))|(?:(?:[0-9a-f]{1,4}:){0,5}[0-9a-f]{1,4})?::[0-9a-f]{1,4}|(?:(?:[0-9a-f]{1,4}:){0,6}[0-9a-f]{1,4})?::)|[Vv][0-9a-f]+\.[a-z0-9\-._~!$&'()*+,;=:]+)\]|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)|(?:[a-z0-9\-._~!$&'()*+,;=]|%[0-9a-f]{2})*)(?::\d*)?(?:\/(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})*)*|\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})*)*)?|(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})*)*)(?:\?(?:[a-z0-9\-._~!$&'()*+,;=:@/?]|%[0-9a-f]{2})*)?(?:#(?:[a-z0-9\-._~!$&'()*+,;=:@/?]|%[0-9a-f]{2})*)?$/i;
    var URIREF = /^(?:[a-z][a-z0-9+\-.]*:)?(?:\/?\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:]|%[0-9a-f]{2})*@)?(?:\[(?:(?:(?:(?:[0-9a-f]{1,4}:){6}|::(?:[0-9a-f]{1,4}:){5}|(?:[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){4}|(?:(?:[0-9a-f]{1,4}:){0,1}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){3}|(?:(?:[0-9a-f]{1,4}:){0,2}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){2}|(?:(?:[0-9a-f]{1,4}:){0,3}[0-9a-f]{1,4})?::[0-9a-f]{1,4}:|(?:(?:[0-9a-f]{1,4}:){0,4}[0-9a-f]{1,4})?::)(?:[0-9a-f]{1,4}:[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?))|(?:(?:[0-9a-f]{1,4}:){0,5}[0-9a-f]{1,4})?::[0-9a-f]{1,4}|(?:(?:[0-9a-f]{1,4}:){0,6}[0-9a-f]{1,4})?::)|[Vv][0-9a-f]+\.[a-z0-9\-._~!$&'()*+,;=:]+)\]|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)|(?:[a-z0-9\-._~!$&'"()*+,;=]|%[0-9a-f]{2})*)(?::\d*)?(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*|\/(?:(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*)?|(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*)?(?:\?(?:[a-z0-9\-._~!$&'"()*+,;=:@/?]|%[0-9a-f]{2})*)?(?:#(?:[a-z0-9\-._~!$&'"()*+,;=:@/?]|%[0-9a-f]{2})*)?$/i;
    // uri-template: https://tools.ietf.org/html/rfc6570
    var URITEMPLATE = /^(?:(?:[^\x00-\x20"'<>%\\^`{|}]|%[0-9a-f]{2})|\{[+#./;?&=,!@|]?(?:[a-z0-9_]|%[0-9a-f]{2})+(?::[1-9][0-9]{0,3}|\*)?(?:,(?:[a-z0-9_]|%[0-9a-f]{2})+(?::[1-9][0-9]{0,3}|\*)?)*\})*$/i;
    // For the source: https://gist.github.com/dperini/729294
    // For test cases: https://mathiasbynens.be/demo/url-regex
    // @todo Delete current URL in favour of the commented out URL rule when this issue is fixed https://github.com/eslint/eslint/issues/7983.
    // var URL = /^(?:(?:https?|ftp):\/\/)(?:\S+(?::\S*)?@)?(?:(?!10(?:\.\d{1,3}){3})(?!127(?:\.\d{1,3}){3})(?!169\.254(?:\.\d{1,3}){2})(?!192\.168(?:\.\d{1,3}){2})(?!172\.(?:1[6-9]|2\d|3[0-1])(?:\.\d{1,3}){2})(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-z\u{00a1}-\u{ffff}0-9]+-)*[a-z\u{00a1}-\u{ffff}0-9]+)(?:\.(?:[a-z\u{00a1}-\u{ffff}0-9]+-)*[a-z\u{00a1}-\u{ffff}0-9]+)*(?:\.(?:[a-z\u{00a1}-\u{ffff}]{2,})))(?::\d{2,5})?(?:\/[^\s]*)?$/iu;
    var URL = /^(?:(?:http[s\u017F]?|ftp):\/\/)(?:(?:[\0-\x08\x0E-\x1F!-\x9F\xA1-\u167F\u1681-\u1FFF\u200B-\u2027\u202A-\u202E\u2030-\u205E\u2060-\u2FFF\u3001-\uD7FF\uE000-\uFEFE\uFF00-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+(?::(?:[\0-\x08\x0E-\x1F!-\x9F\xA1-\u167F\u1681-\u1FFF\u200B-\u2027\u202A-\u202E\u2030-\u205E\u2060-\u2FFF\u3001-\uD7FF\uE000-\uFEFE\uFF00-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])*)?@)?(?:(?!10(?:\.[0-9]{1,3}){3})(?!127(?:\.[0-9]{1,3}){3})(?!169\.254(?:\.[0-9]{1,3}){2})(?!192\.168(?:\.[0-9]{1,3}){2})(?!172\.(?:1[6-9]|2[0-9]|3[01])(?:\.[0-9]{1,3}){2})(?:[1-9][0-9]?|1[0-9][0-9]|2[01][0-9]|22[0-3])(?:\.(?:1?[0-9]{1,2}|2[0-4][0-9]|25[0-5])){2}(?:\.(?:[1-9][0-9]?|1[0-9][0-9]|2[0-4][0-9]|25[0-4]))|(?:(?:(?:[0-9a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+-)*(?:[0-9a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+)(?:\.(?:(?:[0-9a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+-)*(?:[0-9a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+)*(?:\.(?:(?:[a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]){2,})))(?::[0-9]{2,5})?(?:\/(?:[\0-\x08\x0E-\x1F!-\x9F\xA1-\u167F\u1681-\u1FFF\u200B-\u2027\u202A-\u202E\u2030-\u205E\u2060-\u2FFF\u3001-\uD7FF\uE000-\uFEFE\uFF00-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])*)?$/i;
    var UUID = /^(?:urn:uuid:)?[0-9a-f]{8}-(?:[0-9a-f]{4}-){3}[0-9a-f]{12}$/i;
    var JSON_POINTER = /^(?:\/(?:[^~/]|~0|~1)*)*$/;
    var JSON_POINTER_URI_FRAGMENT = /^#(?:\/(?:[a-z0-9_\-.!$&'()*+,;:=@]|%[0-9a-f]{2}|~0|~1)*)*$/i;
    var RELATIVE_JSON_POINTER = /^(?:0|[1-9][0-9]*)(?:#|(?:\/(?:[^~/]|~0|~1)*)*)$/;
    module.exports = formats;
    function formats(mode) {
        mode = mode == 'full' ? 'full' : 'fast';
        return util.copy(formats[mode]);
    }
    formats.fast = {
        // date: http://tools.ietf.org/html/rfc3339#section-5.6
        date: /^\d\d\d\d-[0-1]\d-[0-3]\d$/,
        // date-time: http://tools.ietf.org/html/rfc3339#section-5.6
        time: /^(?:[0-2]\d:[0-5]\d:[0-5]\d|23:59:60)(?:\.\d+)?(?:z|[+-]\d\d(?::?\d\d)?)?$/i,
        'date-time': /^\d\d\d\d-[0-1]\d-[0-3]\d[t\s](?:[0-2]\d:[0-5]\d:[0-5]\d|23:59:60)(?:\.\d+)?(?:z|[+-]\d\d(?::?\d\d)?)$/i,
        // uri: https://github.com/mafintosh/is-my-json-valid/blob/master/formats.js
        uri: /^(?:[a-z][a-z0-9+\-.]*:)(?:\/?\/)?[^\s]*$/i,
        'uri-reference': /^(?:(?:[a-z][a-z0-9+\-.]*:)?\/?\/)?(?:[^\\\s#][^\s#]*)?(?:#[^\\\s]*)?$/i,
        'uri-template': URITEMPLATE,
        url: URL,
        // email (sources from jsen validator):
        // http://stackoverflow.com/questions/201323/using-a-regular-expression-to-validate-an-email-address#answer-8829363
        // http://www.w3.org/TR/html5/forms.html#valid-e-mail-address (search for 'willful violation')
        email: /^[a-z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?)*$/i,
        hostname: HOSTNAME,
        // optimized https://www.safaribooksonline.com/library/view/regular-expressions-cookbook/9780596802837/ch07s16.html
        ipv4: /^(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)$/,
        // optimized http://stackoverflow.com/questions/53497/regular-expression-that-matches-valid-ipv6-addresses
        ipv6: /^\s*(?:(?:(?:[0-9a-f]{1,4}:){7}(?:[0-9a-f]{1,4}|:))|(?:(?:[0-9a-f]{1,4}:){6}(?::[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){5}(?:(?:(?::[0-9a-f]{1,4}){1,2})|:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){4}(?:(?:(?::[0-9a-f]{1,4}){1,3})|(?:(?::[0-9a-f]{1,4})?:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){3}(?:(?:(?::[0-9a-f]{1,4}){1,4})|(?:(?::[0-9a-f]{1,4}){0,2}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){2}(?:(?:(?::[0-9a-f]{1,4}){1,5})|(?:(?::[0-9a-f]{1,4}){0,3}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){1}(?:(?:(?::[0-9a-f]{1,4}){1,6})|(?:(?::[0-9a-f]{1,4}){0,4}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?::(?:(?:(?::[0-9a-f]{1,4}){1,7})|(?:(?::[0-9a-f]{1,4}){0,5}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(?:%.+)?\s*$/i,
        regex: regex,
        // uuid: http://tools.ietf.org/html/rfc4122
        uuid: UUID,
        // JSON-pointer: https://tools.ietf.org/html/rfc6901
        // uri fragment: https://tools.ietf.org/html/rfc3986#appendix-A
        'json-pointer': JSON_POINTER,
        'json-pointer-uri-fragment': JSON_POINTER_URI_FRAGMENT,
        // relative JSON-pointer: http://tools.ietf.org/html/draft-luff-relative-json-pointer-00
        'relative-json-pointer': RELATIVE_JSON_POINTER
    };
    formats.full = {
        date: date,
        time: time,
        'date-time': date_time,
        uri: uri,
        'uri-reference': URIREF,
        'uri-template': URITEMPLATE,
        url: URL,
        email: /^[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?$/i,
        hostname: HOSTNAME,
        ipv4: /^(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)$/,
        ipv6: /^\s*(?:(?:(?:[0-9a-f]{1,4}:){7}(?:[0-9a-f]{1,4}|:))|(?:(?:[0-9a-f]{1,4}:){6}(?::[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){5}(?:(?:(?::[0-9a-f]{1,4}){1,2})|:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){4}(?:(?:(?::[0-9a-f]{1,4}){1,3})|(?:(?::[0-9a-f]{1,4})?:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){3}(?:(?:(?::[0-9a-f]{1,4}){1,4})|(?:(?::[0-9a-f]{1,4}){0,2}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){2}(?:(?:(?::[0-9a-f]{1,4}){1,5})|(?:(?::[0-9a-f]{1,4}){0,3}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){1}(?:(?:(?::[0-9a-f]{1,4}){1,6})|(?:(?::[0-9a-f]{1,4}){0,4}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?::(?:(?:(?::[0-9a-f]{1,4}){1,7})|(?:(?::[0-9a-f]{1,4}){0,5}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(?:%.+)?\s*$/i,
        regex: regex,
        uuid: UUID,
        'json-pointer': JSON_POINTER,
        'json-pointer-uri-fragment': JSON_POINTER_URI_FRAGMENT,
        'relative-json-pointer': RELATIVE_JSON_POINTER
    };
    function isLeapYear(year) {
        // https://tools.ietf.org/html/rfc3339#appendix-C
        return year % 4 === 0 && (year % 100 !== 0 || year % 400 === 0);
    }
    function date(str) {
        // full-date from http://tools.ietf.org/html/rfc3339#section-5.6
        var matches = str.match(DATE);
        if (!matches)
            return false;
        var year = +matches[1];
        var month = +matches[2];
        var day = +matches[3];
        return month >= 1 && month <= 12 && day >= 1 &&
            day <= (month == 2 && isLeapYear(year) ? 29 : DAYS[month]);
    }
    function time(str, full) {
        var matches = str.match(TIME);
        if (!matches)
            return false;
        var hour = matches[1];
        var minute = matches[2];
        var second = matches[3];
        var timeZone = matches[5];
        return ((hour <= 23 && minute <= 59 && second <= 59) ||
            (hour == 23 && minute == 59 && second == 60)) &&
            (!full || timeZone);
    }
    var DATE_TIME_SEPARATOR = /t|\s/i;
    function date_time(str) {
        // http://tools.ietf.org/html/rfc3339#section-5.6
        var dateTime = str.split(DATE_TIME_SEPARATOR);
        return dateTime.length == 2 && date(dateTime[0]) && time(dateTime[1], true);
    }
    var NOT_URI_FRAGMENT = /\/|:/;
    function uri(str) {
        // http://jmrware.com/articles/2009/uri_regexp/URI_regex.html + optional protocol + required "."
        return NOT_URI_FRAGMENT.test(str) && URI.test(str);
    }
    var Z_ANCHOR = /[^\\]\\Z/;
    function regex(str) {
        if (Z_ANCHOR.test(str))
            return false;
        try {
            new RegExp(str);
            return true;
        }
        catch (e) {
            return false;
        }
    }
},
/* ajv/lib/compile/rules.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var ruleModules = require(248) /* ../dotjs */, toHash = require(238) /* ./util */.toHash;
    module.exports = function rules() {
        var RULES = [
            { type: 'number',
                rules: [{ 'maximum': ['exclusiveMaximum'] },
                    { 'minimum': ['exclusiveMinimum'] }, 'multipleOf', 'format'] },
            { type: 'string',
                rules: ['maxLength', 'minLength', 'pattern', 'format'] },
            { type: 'array',
                rules: ['maxItems', 'minItems', 'items', 'contains', 'uniqueItems'] },
            { type: 'object',
                rules: ['maxProperties', 'minProperties', 'required', 'dependencies', 'propertyNames',
                    { 'properties': ['additionalProperties', 'patternProperties'] }] },
            { rules: ['$ref', 'const', 'enum', 'not', 'anyOf', 'oneOf', 'allOf', 'if'] }
        ];
        var ALL = ['type', '$comment'];
        var KEYWORDS = [
            '$schema', '$id', 'id', '$data', '$async', 'title',
            'description', 'default', 'definitions',
            'examples', 'readOnly', 'writeOnly',
            'contentMediaType', 'contentEncoding',
            'additionalItems', 'then', 'else'
        ];
        var TYPES = ['number', 'integer', 'string', 'array', 'object', 'boolean', 'null'];
        RULES.all = toHash(ALL);
        RULES.types = toHash(TYPES);
        RULES.forEach(function (group) {
            group.rules = group.rules.map(function (keyword) {
                var implKeywords;
                if (typeof keyword == 'object') {
                    var key = Object.keys(keyword)[0];
                    implKeywords = keyword[key];
                    keyword = key;
                    implKeywords.forEach(function (k) {
                        ALL.push(k);
                        RULES.all[k] = true;
                    });
                }
                ALL.push(keyword);
                var rule = RULES.all[keyword] = {
                    keyword: keyword,
                    code: ruleModules[keyword],
                    implements: implKeywords
                };
                return rule;
            });
            RULES.all.$comment = {
                keyword: '$comment',
                code: ruleModules.$comment
            };
            if (group.type)
                RULES.types[group.type] = group;
        });
        RULES.keywords = toHash(ALL.concat(KEYWORDS));
        RULES.custom = {};
        return RULES;
    };
},
/* ajv/lib/dotjs/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    //all requires must be explicit because browserify won't work with dynamic requires
    module.exports = {
        '$ref': require(249) /* ./ref */,
        allOf: require(250) /* ./allOf */,
        anyOf: require(251) /* ./anyOf */,
        '$comment': require(252) /* ./comment */,
        const: require(253) /* ./const */,
        contains: require(254) /* ./contains */,
        dependencies: require(255) /* ./dependencies */,
        'enum': require(256) /* ./enum */,
        format: require(257) /* ./format */,
        'if': require(258) /* ./if */,
        items: require(259) /* ./items */,
        maximum: require(260) /* ./_limit */,
        minimum: require(260) /* ./_limit */,
        maxItems: require(261) /* ./_limitItems */,
        minItems: require(261) /* ./_limitItems */,
        maxLength: require(262) /* ./_limitLength */,
        minLength: require(262) /* ./_limitLength */,
        maxProperties: require(263) /* ./_limitProperties */,
        minProperties: require(263) /* ./_limitProperties */,
        multipleOf: require(264) /* ./multipleOf */,
        not: require(265) /* ./not */,
        oneOf: require(266) /* ./oneOf */,
        pattern: require(267) /* ./pattern */,
        properties: require(268) /* ./properties */,
        propertyNames: require(269) /* ./propertyNames */,
        required: require(270) /* ./required */,
        uniqueItems: require(271) /* ./uniqueItems */,
        validate: require(244) /* ./validate */
    };
},
/* ajv/lib/dotjs/ref.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_ref(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $async, $refCode;
        if ($schema == '#' || $schema == '#/') {
            if (it.isRoot) {
                $async = it.async;
                $refCode = 'validate';
            }
            else {
                $async = it.root.schema.$async === true;
                $refCode = 'root.refVal[0]';
            }
        }
        else {
            var $refVal = it.resolveRef(it.baseId, $schema, it.isRoot);
            if ($refVal === undefined) {
                var $message = it.MissingRefError.message(it.baseId, $schema);
                if (it.opts.missingRefs == 'fail') {
                    it.logger.error($message);
                    var $$outStack = $$outStack || [];
                    $$outStack.push(out);
                    out = ''; /* istanbul ignore else */
                    if (it.createErrors !== false) {
                        out += ' { keyword: \'' + ('$ref') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { ref: \'' + (it.util.escapeQuotes($schema)) + '\' } ';
                        if (it.opts.messages !== false) {
                            out += ' , message: \'can\\\'t resolve reference ' + (it.util.escapeQuotes($schema)) + '\' ';
                        }
                        if (it.opts.verbose) {
                            out += ' , schema: ' + (it.util.toQuotedString($schema)) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                        }
                        out += ' } ';
                    }
                    else {
                        out += ' {} ';
                    }
                    var __err = out;
                    out = $$outStack.pop();
                    if (!it.compositeRule && $breakOnError) {
                        /* istanbul ignore if */
                        if (it.async) {
                            out += ' throw new ValidationError([' + (__err) + ']); ';
                        }
                        else {
                            out += ' validate.errors = [' + (__err) + ']; return false; ';
                        }
                    }
                    else {
                        out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                    }
                    if ($breakOnError) {
                        out += ' if (false) { ';
                    }
                }
                else if (it.opts.missingRefs == 'ignore') {
                    it.logger.warn($message);
                    if ($breakOnError) {
                        out += ' if (true) { ';
                    }
                }
                else {
                    throw new it.MissingRefError(it.baseId, $schema, $message);
                }
            }
            else if ($refVal.inline) {
                var $it = it.util.copy(it);
                $it.level++;
                var $nextValid = 'valid' + $it.level;
                $it.schema = $refVal.schema;
                $it.schemaPath = '';
                $it.errSchemaPath = $schema;
                var $code = it.validate($it).replace(/validate\.schema/g, $refVal.code);
                out += ' ' + ($code) + ' ';
                if ($breakOnError) {
                    out += ' if (' + ($nextValid) + ') { ';
                }
            }
            else {
                $async = $refVal.$async === true || (it.async && $refVal.$async !== false);
                $refCode = $refVal.code;
            }
        }
        if ($refCode) {
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = '';
            if (it.opts.passContext) {
                out += ' ' + ($refCode) + '.call(this, ';
            }
            else {
                out += ' ' + ($refCode) + '( ';
            }
            out += ' ' + ($data) + ', (dataPath || \'\')';
            if (it.errorPath != '""') {
                out += ' + ' + (it.errorPath);
            }
            var $parentData = $dataLvl ? 'data' + (($dataLvl - 1) || '') : 'parentData', $parentDataProperty = $dataLvl ? it.dataPathArr[$dataLvl] : 'parentDataProperty';
            out += ' , ' + ($parentData) + ' , ' + ($parentDataProperty) + ', rootData)  ';
            var __callValidate = out;
            out = $$outStack.pop();
            if ($async) {
                if (!it.async)
                    throw new Error('async schema referenced by sync schema');
                if ($breakOnError) {
                    out += ' var ' + ($valid) + '; ';
                }
                out += ' try { await ' + (__callValidate) + '; ';
                if ($breakOnError) {
                    out += ' ' + ($valid) + ' = true; ';
                }
                out += ' } catch (e) { if (!(e instanceof ValidationError)) throw e; if (vErrors === null) vErrors = e.errors; else vErrors = vErrors.concat(e.errors); errors = vErrors.length; ';
                if ($breakOnError) {
                    out += ' ' + ($valid) + ' = false; ';
                }
                out += ' } ';
                if ($breakOnError) {
                    out += ' if (' + ($valid) + ') { ';
                }
            }
            else {
                out += ' if (!' + (__callValidate) + ') { if (vErrors === null) vErrors = ' + ($refCode) + '.errors; else vErrors = vErrors.concat(' + ($refCode) + '.errors); errors = vErrors.length; } ';
                if ($breakOnError) {
                    out += ' else { ';
                }
            }
        }
        return out;
    };
},
/* ajv/lib/dotjs/allOf.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_allOf(it, $keyword, $ruleType) {
        var out = ' ';
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $it = it.util.copy(it);
        var $closingBraces = '';
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        var $currentBaseId = $it.baseId, $allSchemasEmpty = true;
        var arr1 = $schema;
        if (arr1) {
            var $sch, $i = -1, l1 = arr1.length - 1;
            while ($i < l1) {
                $sch = arr1[$i += 1];
                if ((it.opts.strictKeywords ? (typeof $sch == 'object' && Object.keys($sch).length > 0) || $sch === false : it.util.schemaHasRules($sch, it.RULES.all))) {
                    $allSchemasEmpty = false;
                    $it.schema = $sch;
                    $it.schemaPath = $schemaPath + '[' + $i + ']';
                    $it.errSchemaPath = $errSchemaPath + '/' + $i;
                    out += '  ' + (it.validate($it)) + ' ';
                    $it.baseId = $currentBaseId;
                    if ($breakOnError) {
                        out += ' if (' + ($nextValid) + ') { ';
                        $closingBraces += '}';
                    }
                }
            }
        }
        if ($breakOnError) {
            if ($allSchemasEmpty) {
                out += ' if (true) { ';
            }
            else {
                out += ' ' + ($closingBraces.slice(0, -1)) + ' ';
            }
        }
        return out;
    };
},
/* ajv/lib/dotjs/anyOf.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_anyOf(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $errs = 'errs__' + $lvl;
        var $it = it.util.copy(it);
        var $closingBraces = '';
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        var $noEmptySchema = $schema.every(function ($sch) {
            return (it.opts.strictKeywords ? (typeof $sch == 'object' && Object.keys($sch).length > 0) || $sch === false : it.util.schemaHasRules($sch, it.RULES.all));
        });
        if ($noEmptySchema) {
            var $currentBaseId = $it.baseId;
            out += ' var ' + ($errs) + ' = errors; var ' + ($valid) + ' = false;  ';
            var $wasComposite = it.compositeRule;
            it.compositeRule = $it.compositeRule = true;
            var arr1 = $schema;
            if (arr1) {
                var $sch, $i = -1, l1 = arr1.length - 1;
                while ($i < l1) {
                    $sch = arr1[$i += 1];
                    $it.schema = $sch;
                    $it.schemaPath = $schemaPath + '[' + $i + ']';
                    $it.errSchemaPath = $errSchemaPath + '/' + $i;
                    out += '  ' + (it.validate($it)) + ' ';
                    $it.baseId = $currentBaseId;
                    out += ' ' + ($valid) + ' = ' + ($valid) + ' || ' + ($nextValid) + '; if (!' + ($valid) + ') { ';
                    $closingBraces += '}';
                }
            }
            it.compositeRule = $it.compositeRule = $wasComposite;
            out += ' ' + ($closingBraces) + ' if (!' + ($valid) + ') {   var err =   '; /* istanbul ignore else */
            if (it.createErrors !== false) {
                out += ' { keyword: \'' + ('anyOf') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: {} ';
                if (it.opts.messages !== false) {
                    out += ' , message: \'should match some schema in anyOf\' ';
                }
                if (it.opts.verbose) {
                    out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                }
                out += ' } ';
            }
            else {
                out += ' {} ';
            }
            out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
            if (!it.compositeRule && $breakOnError) {
                /* istanbul ignore if */
                if (it.async) {
                    out += ' throw new ValidationError(vErrors); ';
                }
                else {
                    out += ' validate.errors = vErrors; return false; ';
                }
            }
            out += ' } else {  errors = ' + ($errs) + '; if (vErrors !== null) { if (' + ($errs) + ') vErrors.length = ' + ($errs) + '; else vErrors = null; } ';
            if (it.opts.allErrors) {
                out += ' } ';
            }
        }
        else {
            if ($breakOnError) {
                out += ' if (true) { ';
            }
        }
        return out;
    };
},
/* ajv/lib/dotjs/comment.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_comment(it, $keyword, $ruleType) {
        var out = ' ';
        var $schema = it.schema[$keyword];
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $comment = it.util.toQuotedString($schema);
        if (it.opts.$comment === true) {
            out += ' console.log(' + ($comment) + ');';
        }
        else if (typeof it.opts.$comment == 'function') {
            out += ' self._opts.$comment(' + ($comment) + ', ' + (it.util.toQuotedString($errSchemaPath)) + ', validate.root.schema);';
        }
        return out;
    };
},
/* ajv/lib/dotjs/const.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_const(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        if (!$isData) {
            out += ' var schema' + ($lvl) + ' = validate.schema' + ($schemaPath) + ';';
        }
        out += 'var ' + ($valid) + ' = equal(' + ($data) + ', schema' + ($lvl) + '); if (!' + ($valid) + ') {   ';
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ('const') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { allowedValue: schema' + ($lvl) + ' } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should be equal to constant\' ';
            }
            if (it.opts.verbose) {
                out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += ' }';
        if ($breakOnError) {
            out += ' else { ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/contains.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_contains(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $errs = 'errs__' + $lvl;
        var $it = it.util.copy(it);
        var $closingBraces = '';
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        var $idx = 'i' + $lvl, $dataNxt = $it.dataLevel = it.dataLevel + 1, $nextData = 'data' + $dataNxt, $currentBaseId = it.baseId, $nonEmptySchema = (it.opts.strictKeywords ? (typeof $schema == 'object' && Object.keys($schema).length > 0) || $schema === false : it.util.schemaHasRules($schema, it.RULES.all));
        out += 'var ' + ($errs) + ' = errors;var ' + ($valid) + ';';
        if ($nonEmptySchema) {
            var $wasComposite = it.compositeRule;
            it.compositeRule = $it.compositeRule = true;
            $it.schema = $schema;
            $it.schemaPath = $schemaPath;
            $it.errSchemaPath = $errSchemaPath;
            out += ' var ' + ($nextValid) + ' = false; for (var ' + ($idx) + ' = 0; ' + ($idx) + ' < ' + ($data) + '.length; ' + ($idx) + '++) { ';
            $it.errorPath = it.util.getPathExpr(it.errorPath, $idx, it.opts.jsonPointers, true);
            var $passData = $data + '[' + $idx + ']';
            $it.dataPathArr[$dataNxt] = $idx;
            var $code = it.validate($it);
            $it.baseId = $currentBaseId;
            if (it.util.varOccurences($code, $nextData) < 2) {
                out += ' ' + (it.util.varReplace($code, $nextData, $passData)) + ' ';
            }
            else {
                out += ' var ' + ($nextData) + ' = ' + ($passData) + '; ' + ($code) + ' ';
            }
            out += ' if (' + ($nextValid) + ') break; }  ';
            it.compositeRule = $it.compositeRule = $wasComposite;
            out += ' ' + ($closingBraces) + ' if (!' + ($nextValid) + ') {';
        }
        else {
            out += ' if (' + ($data) + '.length == 0) {';
        }
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ('contains') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: {} ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should contain a valid item\' ';
            }
            if (it.opts.verbose) {
                out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += ' } else { ';
        if ($nonEmptySchema) {
            out += '  errors = ' + ($errs) + '; if (vErrors !== null) { if (' + ($errs) + ') vErrors.length = ' + ($errs) + '; else vErrors = null; } ';
        }
        if (it.opts.allErrors) {
            out += ' } ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/dependencies.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_dependencies(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $errs = 'errs__' + $lvl;
        var $it = it.util.copy(it);
        var $closingBraces = '';
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        var $schemaDeps = {}, $propertyDeps = {}, $ownProperties = it.opts.ownProperties;
        for ($property in $schema) {
            if ($property == '__proto__')
                continue;
            var $sch = $schema[$property];
            var $deps = Array.isArray($sch) ? $propertyDeps : $schemaDeps;
            $deps[$property] = $sch;
        }
        out += 'var ' + ($errs) + ' = errors;';
        var $currentErrorPath = it.errorPath;
        out += 'var missing' + ($lvl) + ';';
        for (var $property in $propertyDeps) {
            $deps = $propertyDeps[$property];
            if ($deps.length) {
                out += ' if ( ' + ($data) + (it.util.getProperty($property)) + ' !== undefined ';
                if ($ownProperties) {
                    out += ' && Object.prototype.hasOwnProperty.call(' + ($data) + ', \'' + (it.util.escapeQuotes($property)) + '\') ';
                }
                if ($breakOnError) {
                    out += ' && ( ';
                    var arr1 = $deps;
                    if (arr1) {
                        var $propertyKey, $i = -1, l1 = arr1.length - 1;
                        while ($i < l1) {
                            $propertyKey = arr1[$i += 1];
                            if ($i) {
                                out += ' || ';
                            }
                            var $prop = it.util.getProperty($propertyKey), $useData = $data + $prop;
                            out += ' ( ( ' + ($useData) + ' === undefined ';
                            if ($ownProperties) {
                                out += ' || ! Object.prototype.hasOwnProperty.call(' + ($data) + ', \'' + (it.util.escapeQuotes($propertyKey)) + '\') ';
                            }
                            out += ') && (missing' + ($lvl) + ' = ' + (it.util.toQuotedString(it.opts.jsonPointers ? $propertyKey : $prop)) + ') ) ';
                        }
                    }
                    out += ')) {  ';
                    var $propertyPath = 'missing' + $lvl, $missingProperty = '\' + ' + $propertyPath + ' + \'';
                    if (it.opts._errorDataPathProperty) {
                        it.errorPath = it.opts.jsonPointers ? it.util.getPathExpr($currentErrorPath, $propertyPath, true) : $currentErrorPath + ' + ' + $propertyPath;
                    }
                    var $$outStack = $$outStack || [];
                    $$outStack.push(out);
                    out = ''; /* istanbul ignore else */
                    if (it.createErrors !== false) {
                        out += ' { keyword: \'' + ('dependencies') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { property: \'' + (it.util.escapeQuotes($property)) + '\', missingProperty: \'' + ($missingProperty) + '\', depsCount: ' + ($deps.length) + ', deps: \'' + (it.util.escapeQuotes($deps.length == 1 ? $deps[0] : $deps.join(", "))) + '\' } ';
                        if (it.opts.messages !== false) {
                            out += ' , message: \'should have ';
                            if ($deps.length == 1) {
                                out += 'property ' + (it.util.escapeQuotes($deps[0]));
                            }
                            else {
                                out += 'properties ' + (it.util.escapeQuotes($deps.join(", ")));
                            }
                            out += ' when property ' + (it.util.escapeQuotes($property)) + ' is present\' ';
                        }
                        if (it.opts.verbose) {
                            out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                        }
                        out += ' } ';
                    }
                    else {
                        out += ' {} ';
                    }
                    var __err = out;
                    out = $$outStack.pop();
                    if (!it.compositeRule && $breakOnError) {
                        /* istanbul ignore if */
                        if (it.async) {
                            out += ' throw new ValidationError([' + (__err) + ']); ';
                        }
                        else {
                            out += ' validate.errors = [' + (__err) + ']; return false; ';
                        }
                    }
                    else {
                        out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                    }
                }
                else {
                    out += ' ) { ';
                    var arr2 = $deps;
                    if (arr2) {
                        var $propertyKey, i2 = -1, l2 = arr2.length - 1;
                        while (i2 < l2) {
                            $propertyKey = arr2[i2 += 1];
                            var $prop = it.util.getProperty($propertyKey), $missingProperty = it.util.escapeQuotes($propertyKey), $useData = $data + $prop;
                            if (it.opts._errorDataPathProperty) {
                                it.errorPath = it.util.getPath($currentErrorPath, $propertyKey, it.opts.jsonPointers);
                            }
                            out += ' if ( ' + ($useData) + ' === undefined ';
                            if ($ownProperties) {
                                out += ' || ! Object.prototype.hasOwnProperty.call(' + ($data) + ', \'' + (it.util.escapeQuotes($propertyKey)) + '\') ';
                            }
                            out += ') {  var err =   '; /* istanbul ignore else */
                            if (it.createErrors !== false) {
                                out += ' { keyword: \'' + ('dependencies') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { property: \'' + (it.util.escapeQuotes($property)) + '\', missingProperty: \'' + ($missingProperty) + '\', depsCount: ' + ($deps.length) + ', deps: \'' + (it.util.escapeQuotes($deps.length == 1 ? $deps[0] : $deps.join(", "))) + '\' } ';
                                if (it.opts.messages !== false) {
                                    out += ' , message: \'should have ';
                                    if ($deps.length == 1) {
                                        out += 'property ' + (it.util.escapeQuotes($deps[0]));
                                    }
                                    else {
                                        out += 'properties ' + (it.util.escapeQuotes($deps.join(", ")));
                                    }
                                    out += ' when property ' + (it.util.escapeQuotes($property)) + ' is present\' ';
                                }
                                if (it.opts.verbose) {
                                    out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                                }
                                out += ' } ';
                            }
                            else {
                                out += ' {} ';
                            }
                            out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } ';
                        }
                    }
                }
                out += ' }   ';
                if ($breakOnError) {
                    $closingBraces += '}';
                    out += ' else { ';
                }
            }
        }
        it.errorPath = $currentErrorPath;
        var $currentBaseId = $it.baseId;
        for (var $property in $schemaDeps) {
            var $sch = $schemaDeps[$property];
            if ((it.opts.strictKeywords ? (typeof $sch == 'object' && Object.keys($sch).length > 0) || $sch === false : it.util.schemaHasRules($sch, it.RULES.all))) {
                out += ' ' + ($nextValid) + ' = true; if ( ' + ($data) + (it.util.getProperty($property)) + ' !== undefined ';
                if ($ownProperties) {
                    out += ' && Object.prototype.hasOwnProperty.call(' + ($data) + ', \'' + (it.util.escapeQuotes($property)) + '\') ';
                }
                out += ') { ';
                $it.schema = $sch;
                $it.schemaPath = $schemaPath + it.util.getProperty($property);
                $it.errSchemaPath = $errSchemaPath + '/' + it.util.escapeFragment($property);
                out += '  ' + (it.validate($it)) + ' ';
                $it.baseId = $currentBaseId;
                out += ' }  ';
                if ($breakOnError) {
                    out += ' if (' + ($nextValid) + ') { ';
                    $closingBraces += '}';
                }
            }
        }
        if ($breakOnError) {
            out += '   ' + ($closingBraces) + ' if (' + ($errs) + ' == errors) {';
        }
        return out;
    };
},
/* ajv/lib/dotjs/enum.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_enum(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        var $i = 'i' + $lvl, $vSchema = 'schema' + $lvl;
        if (!$isData) {
            out += ' var ' + ($vSchema) + ' = validate.schema' + ($schemaPath) + ';';
        }
        out += 'var ' + ($valid) + ';';
        if ($isData) {
            out += ' if (schema' + ($lvl) + ' === undefined) ' + ($valid) + ' = true; else if (!Array.isArray(schema' + ($lvl) + ')) ' + ($valid) + ' = false; else {';
        }
        out += '' + ($valid) + ' = false;for (var ' + ($i) + '=0; ' + ($i) + '<' + ($vSchema) + '.length; ' + ($i) + '++) if (equal(' + ($data) + ', ' + ($vSchema) + '[' + ($i) + '])) { ' + ($valid) + ' = true; break; }';
        if ($isData) {
            out += '  }  ';
        }
        out += ' if (!' + ($valid) + ') {   ';
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ('enum') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { allowedValues: schema' + ($lvl) + ' } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should be equal to one of the allowed values\' ';
            }
            if (it.opts.verbose) {
                out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += ' }';
        if ($breakOnError) {
            out += ' else { ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/format.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_format(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        if (it.opts.format === false) {
            if ($breakOnError) {
                out += ' if (true) { ';
            }
            return out;
        }
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        var $unknownFormats = it.opts.unknownFormats, $allowUnknown = Array.isArray($unknownFormats);
        if ($isData) {
            var $format = 'format' + $lvl, $isObject = 'isObject' + $lvl, $formatType = 'formatType' + $lvl;
            out += ' var ' + ($format) + ' = formats[' + ($schemaValue) + ']; var ' + ($isObject) + ' = typeof ' + ($format) + ' == \'object\' && !(' + ($format) + ' instanceof RegExp) && ' + ($format) + '.validate; var ' + ($formatType) + ' = ' + ($isObject) + ' && ' + ($format) + '.type || \'string\'; if (' + ($isObject) + ') { ';
            if (it.async) {
                out += ' var async' + ($lvl) + ' = ' + ($format) + '.async; ';
            }
            out += ' ' + ($format) + ' = ' + ($format) + '.validate; } if (  ';
            if ($isData) {
                out += ' (' + ($schemaValue) + ' !== undefined && typeof ' + ($schemaValue) + ' != \'string\') || ';
            }
            out += ' (';
            if ($unknownFormats != 'ignore') {
                out += ' (' + ($schemaValue) + ' && !' + ($format) + ' ';
                if ($allowUnknown) {
                    out += ' && self._opts.unknownFormats.indexOf(' + ($schemaValue) + ') == -1 ';
                }
                out += ') || ';
            }
            out += ' (' + ($format) + ' && ' + ($formatType) + ' == \'' + ($ruleType) + '\' && !(typeof ' + ($format) + ' == \'function\' ? ';
            if (it.async) {
                out += ' (async' + ($lvl) + ' ? await ' + ($format) + '(' + ($data) + ') : ' + ($format) + '(' + ($data) + ')) ';
            }
            else {
                out += ' ' + ($format) + '(' + ($data) + ') ';
            }
            out += ' : ' + ($format) + '.test(' + ($data) + '))))) {';
        }
        else {
            var $format = it.formats[$schema];
            if (!$format) {
                if ($unknownFormats == 'ignore') {
                    it.logger.warn('unknown format "' + $schema + '" ignored in schema at path "' + it.errSchemaPath + '"');
                    if ($breakOnError) {
                        out += ' if (true) { ';
                    }
                    return out;
                }
                else if ($allowUnknown && $unknownFormats.indexOf($schema) >= 0) {
                    if ($breakOnError) {
                        out += ' if (true) { ';
                    }
                    return out;
                }
                else {
                    throw new Error('unknown format "' + $schema + '" is used in schema at path "' + it.errSchemaPath + '"');
                }
            }
            var $isObject = typeof $format == 'object' && !($format instanceof RegExp) && $format.validate;
            var $formatType = $isObject && $format.type || 'string';
            if ($isObject) {
                var $async = $format.async === true;
                $format = $format.validate;
            }
            if ($formatType != $ruleType) {
                if ($breakOnError) {
                    out += ' if (true) { ';
                }
                return out;
            }
            if ($async) {
                if (!it.async)
                    throw new Error('async format in sync schema');
                var $formatRef = 'formats' + it.util.getProperty($schema) + '.validate';
                out += ' if (!(await ' + ($formatRef) + '(' + ($data) + '))) { ';
            }
            else {
                out += ' if (! ';
                var $formatRef = 'formats' + it.util.getProperty($schema);
                if ($isObject)
                    $formatRef += '.validate';
                if (typeof $format == 'function') {
                    out += ' ' + ($formatRef) + '(' + ($data) + ') ';
                }
                else {
                    out += ' ' + ($formatRef) + '.test(' + ($data) + ') ';
                }
                out += ') { ';
            }
        }
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ('format') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { format:  ';
            if ($isData) {
                out += '' + ($schemaValue);
            }
            else {
                out += '' + (it.util.toQuotedString($schema));
            }
            out += '  } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should match format "';
                if ($isData) {
                    out += '\' + ' + ($schemaValue) + ' + \'';
                }
                else {
                    out += '' + (it.util.escapeQuotes($schema));
                }
                out += '"\' ';
            }
            if (it.opts.verbose) {
                out += ' , schema:  ';
                if ($isData) {
                    out += 'validate.schema' + ($schemaPath);
                }
                else {
                    out += '' + (it.util.toQuotedString($schema));
                }
                out += '         , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += ' } ';
        if ($breakOnError) {
            out += ' else { ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/if.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_if(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $errs = 'errs__' + $lvl;
        var $it = it.util.copy(it);
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        var $thenSch = it.schema['then'], $elseSch = it.schema['else'], $thenPresent = $thenSch !== undefined && (it.opts.strictKeywords ? (typeof $thenSch == 'object' && Object.keys($thenSch).length > 0) || $thenSch === false : it.util.schemaHasRules($thenSch, it.RULES.all)), $elsePresent = $elseSch !== undefined && (it.opts.strictKeywords ? (typeof $elseSch == 'object' && Object.keys($elseSch).length > 0) || $elseSch === false : it.util.schemaHasRules($elseSch, it.RULES.all)), $currentBaseId = $it.baseId;
        if ($thenPresent || $elsePresent) {
            var $ifClause;
            $it.createErrors = false;
            $it.schema = $schema;
            $it.schemaPath = $schemaPath;
            $it.errSchemaPath = $errSchemaPath;
            out += ' var ' + ($errs) + ' = errors; var ' + ($valid) + ' = true;  ';
            var $wasComposite = it.compositeRule;
            it.compositeRule = $it.compositeRule = true;
            out += '  ' + (it.validate($it)) + ' ';
            $it.baseId = $currentBaseId;
            $it.createErrors = true;
            out += '  errors = ' + ($errs) + '; if (vErrors !== null) { if (' + ($errs) + ') vErrors.length = ' + ($errs) + '; else vErrors = null; }  ';
            it.compositeRule = $it.compositeRule = $wasComposite;
            if ($thenPresent) {
                out += ' if (' + ($nextValid) + ') {  ';
                $it.schema = it.schema['then'];
                $it.schemaPath = it.schemaPath + '.then';
                $it.errSchemaPath = it.errSchemaPath + '/then';
                out += '  ' + (it.validate($it)) + ' ';
                $it.baseId = $currentBaseId;
                out += ' ' + ($valid) + ' = ' + ($nextValid) + '; ';
                if ($thenPresent && $elsePresent) {
                    $ifClause = 'ifClause' + $lvl;
                    out += ' var ' + ($ifClause) + ' = \'then\'; ';
                }
                else {
                    $ifClause = '\'then\'';
                }
                out += ' } ';
                if ($elsePresent) {
                    out += ' else { ';
                }
            }
            else {
                out += ' if (!' + ($nextValid) + ') { ';
            }
            if ($elsePresent) {
                $it.schema = it.schema['else'];
                $it.schemaPath = it.schemaPath + '.else';
                $it.errSchemaPath = it.errSchemaPath + '/else';
                out += '  ' + (it.validate($it)) + ' ';
                $it.baseId = $currentBaseId;
                out += ' ' + ($valid) + ' = ' + ($nextValid) + '; ';
                if ($thenPresent && $elsePresent) {
                    $ifClause = 'ifClause' + $lvl;
                    out += ' var ' + ($ifClause) + ' = \'else\'; ';
                }
                else {
                    $ifClause = '\'else\'';
                }
                out += ' } ';
            }
            out += ' if (!' + ($valid) + ') {   var err =   '; /* istanbul ignore else */
            if (it.createErrors !== false) {
                out += ' { keyword: \'' + ('if') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { failingKeyword: ' + ($ifClause) + ' } ';
                if (it.opts.messages !== false) {
                    out += ' , message: \'should match "\' + ' + ($ifClause) + ' + \'" schema\' ';
                }
                if (it.opts.verbose) {
                    out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                }
                out += ' } ';
            }
            else {
                out += ' {} ';
            }
            out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
            if (!it.compositeRule && $breakOnError) {
                /* istanbul ignore if */
                if (it.async) {
                    out += ' throw new ValidationError(vErrors); ';
                }
                else {
                    out += ' validate.errors = vErrors; return false; ';
                }
            }
            out += ' }   ';
            if ($breakOnError) {
                out += ' else { ';
            }
        }
        else {
            if ($breakOnError) {
                out += ' if (true) { ';
            }
        }
        return out;
    };
},
/* ajv/lib/dotjs/items.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_items(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $errs = 'errs__' + $lvl;
        var $it = it.util.copy(it);
        var $closingBraces = '';
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        var $idx = 'i' + $lvl, $dataNxt = $it.dataLevel = it.dataLevel + 1, $nextData = 'data' + $dataNxt, $currentBaseId = it.baseId;
        out += 'var ' + ($errs) + ' = errors;var ' + ($valid) + ';';
        if (Array.isArray($schema)) {
            var $additionalItems = it.schema.additionalItems;
            if ($additionalItems === false) {
                out += ' ' + ($valid) + ' = ' + ($data) + '.length <= ' + ($schema.length) + '; ';
                var $currErrSchemaPath = $errSchemaPath;
                $errSchemaPath = it.errSchemaPath + '/additionalItems';
                out += '  if (!' + ($valid) + ') {   ';
                var $$outStack = $$outStack || [];
                $$outStack.push(out);
                out = ''; /* istanbul ignore else */
                if (it.createErrors !== false) {
                    out += ' { keyword: \'' + ('additionalItems') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { limit: ' + ($schema.length) + ' } ';
                    if (it.opts.messages !== false) {
                        out += ' , message: \'should NOT have more than ' + ($schema.length) + ' items\' ';
                    }
                    if (it.opts.verbose) {
                        out += ' , schema: false , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                    }
                    out += ' } ';
                }
                else {
                    out += ' {} ';
                }
                var __err = out;
                out = $$outStack.pop();
                if (!it.compositeRule && $breakOnError) {
                    /* istanbul ignore if */
                    if (it.async) {
                        out += ' throw new ValidationError([' + (__err) + ']); ';
                    }
                    else {
                        out += ' validate.errors = [' + (__err) + ']; return false; ';
                    }
                }
                else {
                    out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                }
                out += ' } ';
                $errSchemaPath = $currErrSchemaPath;
                if ($breakOnError) {
                    $closingBraces += '}';
                    out += ' else { ';
                }
            }
            var arr1 = $schema;
            if (arr1) {
                var $sch, $i = -1, l1 = arr1.length - 1;
                while ($i < l1) {
                    $sch = arr1[$i += 1];
                    if ((it.opts.strictKeywords ? (typeof $sch == 'object' && Object.keys($sch).length > 0) || $sch === false : it.util.schemaHasRules($sch, it.RULES.all))) {
                        out += ' ' + ($nextValid) + ' = true; if (' + ($data) + '.length > ' + ($i) + ') { ';
                        var $passData = $data + '[' + $i + ']';
                        $it.schema = $sch;
                        $it.schemaPath = $schemaPath + '[' + $i + ']';
                        $it.errSchemaPath = $errSchemaPath + '/' + $i;
                        $it.errorPath = it.util.getPathExpr(it.errorPath, $i, it.opts.jsonPointers, true);
                        $it.dataPathArr[$dataNxt] = $i;
                        var $code = it.validate($it);
                        $it.baseId = $currentBaseId;
                        if (it.util.varOccurences($code, $nextData) < 2) {
                            out += ' ' + (it.util.varReplace($code, $nextData, $passData)) + ' ';
                        }
                        else {
                            out += ' var ' + ($nextData) + ' = ' + ($passData) + '; ' + ($code) + ' ';
                        }
                        out += ' }  ';
                        if ($breakOnError) {
                            out += ' if (' + ($nextValid) + ') { ';
                            $closingBraces += '}';
                        }
                    }
                }
            }
            if (typeof $additionalItems == 'object' && (it.opts.strictKeywords ? (typeof $additionalItems == 'object' && Object.keys($additionalItems).length > 0) || $additionalItems === false : it.util.schemaHasRules($additionalItems, it.RULES.all))) {
                $it.schema = $additionalItems;
                $it.schemaPath = it.schemaPath + '.additionalItems';
                $it.errSchemaPath = it.errSchemaPath + '/additionalItems';
                out += ' ' + ($nextValid) + ' = true; if (' + ($data) + '.length > ' + ($schema.length) + ') {  for (var ' + ($idx) + ' = ' + ($schema.length) + '; ' + ($idx) + ' < ' + ($data) + '.length; ' + ($idx) + '++) { ';
                $it.errorPath = it.util.getPathExpr(it.errorPath, $idx, it.opts.jsonPointers, true);
                var $passData = $data + '[' + $idx + ']';
                $it.dataPathArr[$dataNxt] = $idx;
                var $code = it.validate($it);
                $it.baseId = $currentBaseId;
                if (it.util.varOccurences($code, $nextData) < 2) {
                    out += ' ' + (it.util.varReplace($code, $nextData, $passData)) + ' ';
                }
                else {
                    out += ' var ' + ($nextData) + ' = ' + ($passData) + '; ' + ($code) + ' ';
                }
                if ($breakOnError) {
                    out += ' if (!' + ($nextValid) + ') break; ';
                }
                out += ' } }  ';
                if ($breakOnError) {
                    out += ' if (' + ($nextValid) + ') { ';
                    $closingBraces += '}';
                }
            }
        }
        else if ((it.opts.strictKeywords ? (typeof $schema == 'object' && Object.keys($schema).length > 0) || $schema === false : it.util.schemaHasRules($schema, it.RULES.all))) {
            $it.schema = $schema;
            $it.schemaPath = $schemaPath;
            $it.errSchemaPath = $errSchemaPath;
            out += '  for (var ' + ($idx) + ' = ' + (0) + '; ' + ($idx) + ' < ' + ($data) + '.length; ' + ($idx) + '++) { ';
            $it.errorPath = it.util.getPathExpr(it.errorPath, $idx, it.opts.jsonPointers, true);
            var $passData = $data + '[' + $idx + ']';
            $it.dataPathArr[$dataNxt] = $idx;
            var $code = it.validate($it);
            $it.baseId = $currentBaseId;
            if (it.util.varOccurences($code, $nextData) < 2) {
                out += ' ' + (it.util.varReplace($code, $nextData, $passData)) + ' ';
            }
            else {
                out += ' var ' + ($nextData) + ' = ' + ($passData) + '; ' + ($code) + ' ';
            }
            if ($breakOnError) {
                out += ' if (!' + ($nextValid) + ') break; ';
            }
            out += ' }';
        }
        if ($breakOnError) {
            out += ' ' + ($closingBraces) + ' if (' + ($errs) + ' == errors) {';
        }
        return out;
    };
},
/* ajv/lib/dotjs/_limit.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate__limit(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $errorKeyword;
        var $data = 'data' + ($dataLvl || '');
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        var $isMax = $keyword == 'maximum', $exclusiveKeyword = $isMax ? 'exclusiveMaximum' : 'exclusiveMinimum', $schemaExcl = it.schema[$exclusiveKeyword], $isDataExcl = it.opts.$data && $schemaExcl && $schemaExcl.$data, $op = $isMax ? '<' : '>', $notOp = $isMax ? '>' : '<', $errorKeyword = undefined;
        if (!($isData || typeof $schema == 'number' || $schema === undefined)) {
            throw new Error($keyword + ' must be number');
        }
        if (!($isDataExcl || $schemaExcl === undefined || typeof $schemaExcl == 'number' || typeof $schemaExcl == 'boolean')) {
            throw new Error($exclusiveKeyword + ' must be number or boolean');
        }
        if ($isDataExcl) {
            var $schemaValueExcl = it.util.getData($schemaExcl.$data, $dataLvl, it.dataPathArr), $exclusive = 'exclusive' + $lvl, $exclType = 'exclType' + $lvl, $exclIsNumber = 'exclIsNumber' + $lvl, $opExpr = 'op' + $lvl, $opStr = '\' + ' + $opExpr + ' + \'';
            out += ' var schemaExcl' + ($lvl) + ' = ' + ($schemaValueExcl) + '; ';
            $schemaValueExcl = 'schemaExcl' + $lvl;
            out += ' var ' + ($exclusive) + '; var ' + ($exclType) + ' = typeof ' + ($schemaValueExcl) + '; if (' + ($exclType) + ' != \'boolean\' && ' + ($exclType) + ' != \'undefined\' && ' + ($exclType) + ' != \'number\') { ';
            var $errorKeyword = $exclusiveKeyword;
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = ''; /* istanbul ignore else */
            if (it.createErrors !== false) {
                out += ' { keyword: \'' + ($errorKeyword || '_exclusiveLimit') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: {} ';
                if (it.opts.messages !== false) {
                    out += ' , message: \'' + ($exclusiveKeyword) + ' should be boolean\' ';
                }
                if (it.opts.verbose) {
                    out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                }
                out += ' } ';
            }
            else {
                out += ' {} ';
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it.compositeRule && $breakOnError) {
                /* istanbul ignore if */
                if (it.async) {
                    out += ' throw new ValidationError([' + (__err) + ']); ';
                }
                else {
                    out += ' validate.errors = [' + (__err) + ']; return false; ';
                }
            }
            else {
                out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
            }
            out += ' } else if ( ';
            if ($isData) {
                out += ' (' + ($schemaValue) + ' !== undefined && typeof ' + ($schemaValue) + ' != \'number\') || ';
            }
            out += ' ' + ($exclType) + ' == \'number\' ? ( (' + ($exclusive) + ' = ' + ($schemaValue) + ' === undefined || ' + ($schemaValueExcl) + ' ' + ($op) + '= ' + ($schemaValue) + ') ? ' + ($data) + ' ' + ($notOp) + '= ' + ($schemaValueExcl) + ' : ' + ($data) + ' ' + ($notOp) + ' ' + ($schemaValue) + ' ) : ( (' + ($exclusive) + ' = ' + ($schemaValueExcl) + ' === true) ? ' + ($data) + ' ' + ($notOp) + '= ' + ($schemaValue) + ' : ' + ($data) + ' ' + ($notOp) + ' ' + ($schemaValue) + ' ) || ' + ($data) + ' !== ' + ($data) + ') { var op' + ($lvl) + ' = ' + ($exclusive) + ' ? \'' + ($op) + '\' : \'' + ($op) + '=\'; ';
            if ($schema === undefined) {
                $errorKeyword = $exclusiveKeyword;
                $errSchemaPath = it.errSchemaPath + '/' + $exclusiveKeyword;
                $schemaValue = $schemaValueExcl;
                $isData = $isDataExcl;
            }
        }
        else {
            var $exclIsNumber = typeof $schemaExcl == 'number', $opStr = $op;
            if ($exclIsNumber && $isData) {
                var $opExpr = '\'' + $opStr + '\'';
                out += ' if ( ';
                if ($isData) {
                    out += ' (' + ($schemaValue) + ' !== undefined && typeof ' + ($schemaValue) + ' != \'number\') || ';
                }
                out += ' ( ' + ($schemaValue) + ' === undefined || ' + ($schemaExcl) + ' ' + ($op) + '= ' + ($schemaValue) + ' ? ' + ($data) + ' ' + ($notOp) + '= ' + ($schemaExcl) + ' : ' + ($data) + ' ' + ($notOp) + ' ' + ($schemaValue) + ' ) || ' + ($data) + ' !== ' + ($data) + ') { ';
            }
            else {
                if ($exclIsNumber && $schema === undefined) {
                    $exclusive = true;
                    $errorKeyword = $exclusiveKeyword;
                    $errSchemaPath = it.errSchemaPath + '/' + $exclusiveKeyword;
                    $schemaValue = $schemaExcl;
                    $notOp += '=';
                }
                else {
                    if ($exclIsNumber)
                        $schemaValue = Math[$isMax ? 'min' : 'max']($schemaExcl, $schema);
                    if ($schemaExcl === ($exclIsNumber ? $schemaValue : true)) {
                        $exclusive = true;
                        $errorKeyword = $exclusiveKeyword;
                        $errSchemaPath = it.errSchemaPath + '/' + $exclusiveKeyword;
                        $notOp += '=';
                    }
                    else {
                        $exclusive = false;
                        $opStr += '=';
                    }
                }
                var $opExpr = '\'' + $opStr + '\'';
                out += ' if ( ';
                if ($isData) {
                    out += ' (' + ($schemaValue) + ' !== undefined && typeof ' + ($schemaValue) + ' != \'number\') || ';
                }
                out += ' ' + ($data) + ' ' + ($notOp) + ' ' + ($schemaValue) + ' || ' + ($data) + ' !== ' + ($data) + ') { ';
            }
        }
        $errorKeyword = $errorKeyword || $keyword;
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ($errorKeyword || '_limit') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { comparison: ' + ($opExpr) + ', limit: ' + ($schemaValue) + ', exclusive: ' + ($exclusive) + ' } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should be ' + ($opStr) + ' ';
                if ($isData) {
                    out += '\' + ' + ($schemaValue);
                }
                else {
                    out += '' + ($schemaValue) + '\'';
                }
            }
            if (it.opts.verbose) {
                out += ' , schema:  ';
                if ($isData) {
                    out += 'validate.schema' + ($schemaPath);
                }
                else {
                    out += '' + ($schema);
                }
                out += '         , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += ' } ';
        if ($breakOnError) {
            out += ' else { ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/_limitItems.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate__limitItems(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $errorKeyword;
        var $data = 'data' + ($dataLvl || '');
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        if (!($isData || typeof $schema == 'number')) {
            throw new Error($keyword + ' must be number');
        }
        var $op = $keyword == 'maxItems' ? '>' : '<';
        out += 'if ( ';
        if ($isData) {
            out += ' (' + ($schemaValue) + ' !== undefined && typeof ' + ($schemaValue) + ' != \'number\') || ';
        }
        out += ' ' + ($data) + '.length ' + ($op) + ' ' + ($schemaValue) + ') { ';
        var $errorKeyword = $keyword;
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ($errorKeyword || '_limitItems') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { limit: ' + ($schemaValue) + ' } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should NOT have ';
                if ($keyword == 'maxItems') {
                    out += 'more';
                }
                else {
                    out += 'fewer';
                }
                out += ' than ';
                if ($isData) {
                    out += '\' + ' + ($schemaValue) + ' + \'';
                }
                else {
                    out += '' + ($schema);
                }
                out += ' items\' ';
            }
            if (it.opts.verbose) {
                out += ' , schema:  ';
                if ($isData) {
                    out += 'validate.schema' + ($schemaPath);
                }
                else {
                    out += '' + ($schema);
                }
                out += '         , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += '} ';
        if ($breakOnError) {
            out += ' else { ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/_limitLength.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate__limitLength(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $errorKeyword;
        var $data = 'data' + ($dataLvl || '');
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        if (!($isData || typeof $schema == 'number')) {
            throw new Error($keyword + ' must be number');
        }
        var $op = $keyword == 'maxLength' ? '>' : '<';
        out += 'if ( ';
        if ($isData) {
            out += ' (' + ($schemaValue) + ' !== undefined && typeof ' + ($schemaValue) + ' != \'number\') || ';
        }
        if (it.opts.unicode === false) {
            out += ' ' + ($data) + '.length ';
        }
        else {
            out += ' ucs2length(' + ($data) + ') ';
        }
        out += ' ' + ($op) + ' ' + ($schemaValue) + ') { ';
        var $errorKeyword = $keyword;
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ($errorKeyword || '_limitLength') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { limit: ' + ($schemaValue) + ' } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should NOT be ';
                if ($keyword == 'maxLength') {
                    out += 'longer';
                }
                else {
                    out += 'shorter';
                }
                out += ' than ';
                if ($isData) {
                    out += '\' + ' + ($schemaValue) + ' + \'';
                }
                else {
                    out += '' + ($schema);
                }
                out += ' characters\' ';
            }
            if (it.opts.verbose) {
                out += ' , schema:  ';
                if ($isData) {
                    out += 'validate.schema' + ($schemaPath);
                }
                else {
                    out += '' + ($schema);
                }
                out += '         , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += '} ';
        if ($breakOnError) {
            out += ' else { ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/_limitProperties.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate__limitProperties(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $errorKeyword;
        var $data = 'data' + ($dataLvl || '');
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        if (!($isData || typeof $schema == 'number')) {
            throw new Error($keyword + ' must be number');
        }
        var $op = $keyword == 'maxProperties' ? '>' : '<';
        out += 'if ( ';
        if ($isData) {
            out += ' (' + ($schemaValue) + ' !== undefined && typeof ' + ($schemaValue) + ' != \'number\') || ';
        }
        out += ' Object.keys(' + ($data) + ').length ' + ($op) + ' ' + ($schemaValue) + ') { ';
        var $errorKeyword = $keyword;
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ($errorKeyword || '_limitProperties') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { limit: ' + ($schemaValue) + ' } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should NOT have ';
                if ($keyword == 'maxProperties') {
                    out += 'more';
                }
                else {
                    out += 'fewer';
                }
                out += ' than ';
                if ($isData) {
                    out += '\' + ' + ($schemaValue) + ' + \'';
                }
                else {
                    out += '' + ($schema);
                }
                out += ' properties\' ';
            }
            if (it.opts.verbose) {
                out += ' , schema:  ';
                if ($isData) {
                    out += 'validate.schema' + ($schemaPath);
                }
                else {
                    out += '' + ($schema);
                }
                out += '         , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += '} ';
        if ($breakOnError) {
            out += ' else { ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/multipleOf.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_multipleOf(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        if (!($isData || typeof $schema == 'number')) {
            throw new Error($keyword + ' must be number');
        }
        out += 'var division' + ($lvl) + ';if (';
        if ($isData) {
            out += ' ' + ($schemaValue) + ' !== undefined && ( typeof ' + ($schemaValue) + ' != \'number\' || ';
        }
        out += ' (division' + ($lvl) + ' = ' + ($data) + ' / ' + ($schemaValue) + ', ';
        if (it.opts.multipleOfPrecision) {
            out += ' Math.abs(Math.round(division' + ($lvl) + ') - division' + ($lvl) + ') > 1e-' + (it.opts.multipleOfPrecision) + ' ';
        }
        else {
            out += ' division' + ($lvl) + ' !== parseInt(division' + ($lvl) + ') ';
        }
        out += ' ) ';
        if ($isData) {
            out += '  )  ';
        }
        out += ' ) {   ';
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ('multipleOf') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { multipleOf: ' + ($schemaValue) + ' } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should be multiple of ';
                if ($isData) {
                    out += '\' + ' + ($schemaValue);
                }
                else {
                    out += '' + ($schemaValue) + '\'';
                }
            }
            if (it.opts.verbose) {
                out += ' , schema:  ';
                if ($isData) {
                    out += 'validate.schema' + ($schemaPath);
                }
                else {
                    out += '' + ($schema);
                }
                out += '         , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += '} ';
        if ($breakOnError) {
            out += ' else { ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/not.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_not(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $errs = 'errs__' + $lvl;
        var $it = it.util.copy(it);
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        if ((it.opts.strictKeywords ? (typeof $schema == 'object' && Object.keys($schema).length > 0) || $schema === false : it.util.schemaHasRules($schema, it.RULES.all))) {
            $it.schema = $schema;
            $it.schemaPath = $schemaPath;
            $it.errSchemaPath = $errSchemaPath;
            out += ' var ' + ($errs) + ' = errors;  ';
            var $wasComposite = it.compositeRule;
            it.compositeRule = $it.compositeRule = true;
            $it.createErrors = false;
            var $allErrorsOption;
            if ($it.opts.allErrors) {
                $allErrorsOption = $it.opts.allErrors;
                $it.opts.allErrors = false;
            }
            out += ' ' + (it.validate($it)) + ' ';
            $it.createErrors = true;
            if ($allErrorsOption)
                $it.opts.allErrors = $allErrorsOption;
            it.compositeRule = $it.compositeRule = $wasComposite;
            out += ' if (' + ($nextValid) + ') {   ';
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = ''; /* istanbul ignore else */
            if (it.createErrors !== false) {
                out += ' { keyword: \'' + ('not') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: {} ';
                if (it.opts.messages !== false) {
                    out += ' , message: \'should NOT be valid\' ';
                }
                if (it.opts.verbose) {
                    out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                }
                out += ' } ';
            }
            else {
                out += ' {} ';
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it.compositeRule && $breakOnError) {
                /* istanbul ignore if */
                if (it.async) {
                    out += ' throw new ValidationError([' + (__err) + ']); ';
                }
                else {
                    out += ' validate.errors = [' + (__err) + ']; return false; ';
                }
            }
            else {
                out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
            }
            out += ' } else {  errors = ' + ($errs) + '; if (vErrors !== null) { if (' + ($errs) + ') vErrors.length = ' + ($errs) + '; else vErrors = null; } ';
            if (it.opts.allErrors) {
                out += ' } ';
            }
        }
        else {
            out += '  var err =   '; /* istanbul ignore else */
            if (it.createErrors !== false) {
                out += ' { keyword: \'' + ('not') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: {} ';
                if (it.opts.messages !== false) {
                    out += ' , message: \'should NOT be valid\' ';
                }
                if (it.opts.verbose) {
                    out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                }
                out += ' } ';
            }
            else {
                out += ' {} ';
            }
            out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
            if ($breakOnError) {
                out += ' if (false) { ';
            }
        }
        return out;
    };
},
/* ajv/lib/dotjs/oneOf.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_oneOf(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $errs = 'errs__' + $lvl;
        var $it = it.util.copy(it);
        var $closingBraces = '';
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        var $currentBaseId = $it.baseId, $prevValid = 'prevValid' + $lvl, $passingSchemas = 'passingSchemas' + $lvl;
        out += 'var ' + ($errs) + ' = errors , ' + ($prevValid) + ' = false , ' + ($valid) + ' = false , ' + ($passingSchemas) + ' = null; ';
        var $wasComposite = it.compositeRule;
        it.compositeRule = $it.compositeRule = true;
        var arr1 = $schema;
        if (arr1) {
            var $sch, $i = -1, l1 = arr1.length - 1;
            while ($i < l1) {
                $sch = arr1[$i += 1];
                if ((it.opts.strictKeywords ? (typeof $sch == 'object' && Object.keys($sch).length > 0) || $sch === false : it.util.schemaHasRules($sch, it.RULES.all))) {
                    $it.schema = $sch;
                    $it.schemaPath = $schemaPath + '[' + $i + ']';
                    $it.errSchemaPath = $errSchemaPath + '/' + $i;
                    out += '  ' + (it.validate($it)) + ' ';
                    $it.baseId = $currentBaseId;
                }
                else {
                    out += ' var ' + ($nextValid) + ' = true; ';
                }
                if ($i) {
                    out += ' if (' + ($nextValid) + ' && ' + ($prevValid) + ') { ' + ($valid) + ' = false; ' + ($passingSchemas) + ' = [' + ($passingSchemas) + ', ' + ($i) + ']; } else { ';
                    $closingBraces += '}';
                }
                out += ' if (' + ($nextValid) + ') { ' + ($valid) + ' = ' + ($prevValid) + ' = true; ' + ($passingSchemas) + ' = ' + ($i) + '; }';
            }
        }
        it.compositeRule = $it.compositeRule = $wasComposite;
        out += '' + ($closingBraces) + 'if (!' + ($valid) + ') {   var err =   '; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ('oneOf') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { passingSchemas: ' + ($passingSchemas) + ' } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should match exactly one schema in oneOf\' ';
            }
            if (it.opts.verbose) {
                out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError(vErrors); ';
            }
            else {
                out += ' validate.errors = vErrors; return false; ';
            }
        }
        out += '} else {  errors = ' + ($errs) + '; if (vErrors !== null) { if (' + ($errs) + ') vErrors.length = ' + ($errs) + '; else vErrors = null; }';
        if (it.opts.allErrors) {
            out += ' } ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/pattern.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_pattern(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        var $regexp = $isData ? '(new RegExp(' + $schemaValue + '))' : it.usePattern($schema);
        out += 'if ( ';
        if ($isData) {
            out += ' (' + ($schemaValue) + ' !== undefined && typeof ' + ($schemaValue) + ' != \'string\') || ';
        }
        out += ' !' + ($regexp) + '.test(' + ($data) + ') ) {   ';
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = ''; /* istanbul ignore else */
        if (it.createErrors !== false) {
            out += ' { keyword: \'' + ('pattern') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { pattern:  ';
            if ($isData) {
                out += '' + ($schemaValue);
            }
            else {
                out += '' + (it.util.toQuotedString($schema));
            }
            out += '  } ';
            if (it.opts.messages !== false) {
                out += ' , message: \'should match pattern "';
                if ($isData) {
                    out += '\' + ' + ($schemaValue) + ' + \'';
                }
                else {
                    out += '' + (it.util.escapeQuotes($schema));
                }
                out += '"\' ';
            }
            if (it.opts.verbose) {
                out += ' , schema:  ';
                if ($isData) {
                    out += 'validate.schema' + ($schemaPath);
                }
                else {
                    out += '' + (it.util.toQuotedString($schema));
                }
                out += '         , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
            }
            out += ' } ';
        }
        else {
            out += ' {} ';
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it.compositeRule && $breakOnError) {
            /* istanbul ignore if */
            if (it.async) {
                out += ' throw new ValidationError([' + (__err) + ']); ';
            }
            else {
                out += ' validate.errors = [' + (__err) + ']; return false; ';
            }
        }
        else {
            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
        }
        out += '} ';
        if ($breakOnError) {
            out += ' else { ';
        }
        return out;
    };
},
/* ajv/lib/dotjs/properties.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_properties(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $errs = 'errs__' + $lvl;
        var $it = it.util.copy(it);
        var $closingBraces = '';
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        var $key = 'key' + $lvl, $idx = 'idx' + $lvl, $dataNxt = $it.dataLevel = it.dataLevel + 1, $nextData = 'data' + $dataNxt, $dataProperties = 'dataProperties' + $lvl;
        var $schemaKeys = Object.keys($schema || {}).filter(notProto), $pProperties = it.schema.patternProperties || {}, $pPropertyKeys = Object.keys($pProperties).filter(notProto), $aProperties = it.schema.additionalProperties, $someProperties = $schemaKeys.length || $pPropertyKeys.length, $noAdditional = $aProperties === false, $additionalIsSchema = typeof $aProperties == 'object' && Object.keys($aProperties).length, $removeAdditional = it.opts.removeAdditional, $checkAdditional = $noAdditional || $additionalIsSchema || $removeAdditional, $ownProperties = it.opts.ownProperties, $currentBaseId = it.baseId;
        var $required = it.schema.required;
        if ($required && !(it.opts.$data && $required.$data) && $required.length < it.opts.loopRequired) {
            var $requiredHash = it.util.toHash($required);
        }
        function notProto(p) {
            return p !== '__proto__';
        }
        out += 'var ' + ($errs) + ' = errors;var ' + ($nextValid) + ' = true;';
        if ($ownProperties) {
            out += ' var ' + ($dataProperties) + ' = undefined;';
        }
        if ($checkAdditional) {
            if ($ownProperties) {
                out += ' ' + ($dataProperties) + ' = ' + ($dataProperties) + ' || Object.keys(' + ($data) + '); for (var ' + ($idx) + '=0; ' + ($idx) + '<' + ($dataProperties) + '.length; ' + ($idx) + '++) { var ' + ($key) + ' = ' + ($dataProperties) + '[' + ($idx) + ']; ';
            }
            else {
                out += ' for (var ' + ($key) + ' in ' + ($data) + ') { ';
            }
            if ($someProperties) {
                out += ' var isAdditional' + ($lvl) + ' = !(false ';
                if ($schemaKeys.length) {
                    if ($schemaKeys.length > 8) {
                        out += ' || validate.schema' + ($schemaPath) + '.hasOwnProperty(' + ($key) + ') ';
                    }
                    else {
                        var arr1 = $schemaKeys;
                        if (arr1) {
                            var $propertyKey, i1 = -1, l1 = arr1.length - 1;
                            while (i1 < l1) {
                                $propertyKey = arr1[i1 += 1];
                                out += ' || ' + ($key) + ' == ' + (it.util.toQuotedString($propertyKey)) + ' ';
                            }
                        }
                    }
                }
                if ($pPropertyKeys.length) {
                    var arr2 = $pPropertyKeys;
                    if (arr2) {
                        var $pProperty, $i = -1, l2 = arr2.length - 1;
                        while ($i < l2) {
                            $pProperty = arr2[$i += 1];
                            out += ' || ' + (it.usePattern($pProperty)) + '.test(' + ($key) + ') ';
                        }
                    }
                }
                out += ' ); if (isAdditional' + ($lvl) + ') { ';
            }
            if ($removeAdditional == 'all') {
                out += ' delete ' + ($data) + '[' + ($key) + ']; ';
            }
            else {
                var $currentErrorPath = it.errorPath;
                var $additionalProperty = '\' + ' + $key + ' + \'';
                if (it.opts._errorDataPathProperty) {
                    it.errorPath = it.util.getPathExpr(it.errorPath, $key, it.opts.jsonPointers);
                }
                if ($noAdditional) {
                    if ($removeAdditional) {
                        out += ' delete ' + ($data) + '[' + ($key) + ']; ';
                    }
                    else {
                        out += ' ' + ($nextValid) + ' = false; ';
                        var $currErrSchemaPath = $errSchemaPath;
                        $errSchemaPath = it.errSchemaPath + '/additionalProperties';
                        var $$outStack = $$outStack || [];
                        $$outStack.push(out);
                        out = ''; /* istanbul ignore else */
                        if (it.createErrors !== false) {
                            out += ' { keyword: \'' + ('additionalProperties') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { additionalProperty: \'' + ($additionalProperty) + '\' } ';
                            if (it.opts.messages !== false) {
                                out += ' , message: \'';
                                if (it.opts._errorDataPathProperty) {
                                    out += 'is an invalid additional property';
                                }
                                else {
                                    out += 'should NOT have additional properties';
                                }
                                out += '\' ';
                            }
                            if (it.opts.verbose) {
                                out += ' , schema: false , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                            }
                            out += ' } ';
                        }
                        else {
                            out += ' {} ';
                        }
                        var __err = out;
                        out = $$outStack.pop();
                        if (!it.compositeRule && $breakOnError) {
                            /* istanbul ignore if */
                            if (it.async) {
                                out += ' throw new ValidationError([' + (__err) + ']); ';
                            }
                            else {
                                out += ' validate.errors = [' + (__err) + ']; return false; ';
                            }
                        }
                        else {
                            out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                        }
                        $errSchemaPath = $currErrSchemaPath;
                        if ($breakOnError) {
                            out += ' break; ';
                        }
                    }
                }
                else if ($additionalIsSchema) {
                    if ($removeAdditional == 'failing') {
                        out += ' var ' + ($errs) + ' = errors;  ';
                        var $wasComposite = it.compositeRule;
                        it.compositeRule = $it.compositeRule = true;
                        $it.schema = $aProperties;
                        $it.schemaPath = it.schemaPath + '.additionalProperties';
                        $it.errSchemaPath = it.errSchemaPath + '/additionalProperties';
                        $it.errorPath = it.opts._errorDataPathProperty ? it.errorPath : it.util.getPathExpr(it.errorPath, $key, it.opts.jsonPointers);
                        var $passData = $data + '[' + $key + ']';
                        $it.dataPathArr[$dataNxt] = $key;
                        var $code = it.validate($it);
                        $it.baseId = $currentBaseId;
                        if (it.util.varOccurences($code, $nextData) < 2) {
                            out += ' ' + (it.util.varReplace($code, $nextData, $passData)) + ' ';
                        }
                        else {
                            out += ' var ' + ($nextData) + ' = ' + ($passData) + '; ' + ($code) + ' ';
                        }
                        out += ' if (!' + ($nextValid) + ') { errors = ' + ($errs) + '; if (validate.errors !== null) { if (errors) validate.errors.length = errors; else validate.errors = null; } delete ' + ($data) + '[' + ($key) + ']; }  ';
                        it.compositeRule = $it.compositeRule = $wasComposite;
                    }
                    else {
                        $it.schema = $aProperties;
                        $it.schemaPath = it.schemaPath + '.additionalProperties';
                        $it.errSchemaPath = it.errSchemaPath + '/additionalProperties';
                        $it.errorPath = it.opts._errorDataPathProperty ? it.errorPath : it.util.getPathExpr(it.errorPath, $key, it.opts.jsonPointers);
                        var $passData = $data + '[' + $key + ']';
                        $it.dataPathArr[$dataNxt] = $key;
                        var $code = it.validate($it);
                        $it.baseId = $currentBaseId;
                        if (it.util.varOccurences($code, $nextData) < 2) {
                            out += ' ' + (it.util.varReplace($code, $nextData, $passData)) + ' ';
                        }
                        else {
                            out += ' var ' + ($nextData) + ' = ' + ($passData) + '; ' + ($code) + ' ';
                        }
                        if ($breakOnError) {
                            out += ' if (!' + ($nextValid) + ') break; ';
                        }
                    }
                }
                it.errorPath = $currentErrorPath;
            }
            if ($someProperties) {
                out += ' } ';
            }
            out += ' }  ';
            if ($breakOnError) {
                out += ' if (' + ($nextValid) + ') { ';
                $closingBraces += '}';
            }
        }
        var $useDefaults = it.opts.useDefaults && !it.compositeRule;
        if ($schemaKeys.length) {
            var arr3 = $schemaKeys;
            if (arr3) {
                var $propertyKey, i3 = -1, l3 = arr3.length - 1;
                while (i3 < l3) {
                    $propertyKey = arr3[i3 += 1];
                    var $sch = $schema[$propertyKey];
                    if ((it.opts.strictKeywords ? (typeof $sch == 'object' && Object.keys($sch).length > 0) || $sch === false : it.util.schemaHasRules($sch, it.RULES.all))) {
                        var $prop = it.util.getProperty($propertyKey), $passData = $data + $prop, $hasDefault = $useDefaults && $sch.default !== undefined;
                        $it.schema = $sch;
                        $it.schemaPath = $schemaPath + $prop;
                        $it.errSchemaPath = $errSchemaPath + '/' + it.util.escapeFragment($propertyKey);
                        $it.errorPath = it.util.getPath(it.errorPath, $propertyKey, it.opts.jsonPointers);
                        $it.dataPathArr[$dataNxt] = it.util.toQuotedString($propertyKey);
                        var $code = it.validate($it);
                        $it.baseId = $currentBaseId;
                        if (it.util.varOccurences($code, $nextData) < 2) {
                            $code = it.util.varReplace($code, $nextData, $passData);
                            var $useData = $passData;
                        }
                        else {
                            var $useData = $nextData;
                            out += ' var ' + ($nextData) + ' = ' + ($passData) + '; ';
                        }
                        if ($hasDefault) {
                            out += ' ' + ($code) + ' ';
                        }
                        else {
                            if ($requiredHash && $requiredHash[$propertyKey]) {
                                out += ' if ( ' + ($useData) + ' === undefined ';
                                if ($ownProperties) {
                                    out += ' || ! Object.prototype.hasOwnProperty.call(' + ($data) + ', \'' + (it.util.escapeQuotes($propertyKey)) + '\') ';
                                }
                                out += ') { ' + ($nextValid) + ' = false; ';
                                var $currentErrorPath = it.errorPath, $currErrSchemaPath = $errSchemaPath, $missingProperty = it.util.escapeQuotes($propertyKey);
                                if (it.opts._errorDataPathProperty) {
                                    it.errorPath = it.util.getPath($currentErrorPath, $propertyKey, it.opts.jsonPointers);
                                }
                                $errSchemaPath = it.errSchemaPath + '/required';
                                var $$outStack = $$outStack || [];
                                $$outStack.push(out);
                                out = ''; /* istanbul ignore else */
                                if (it.createErrors !== false) {
                                    out += ' { keyword: \'' + ('required') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { missingProperty: \'' + ($missingProperty) + '\' } ';
                                    if (it.opts.messages !== false) {
                                        out += ' , message: \'';
                                        if (it.opts._errorDataPathProperty) {
                                            out += 'is a required property';
                                        }
                                        else {
                                            out += 'should have required property \\\'' + ($missingProperty) + '\\\'';
                                        }
                                        out += '\' ';
                                    }
                                    if (it.opts.verbose) {
                                        out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                                    }
                                    out += ' } ';
                                }
                                else {
                                    out += ' {} ';
                                }
                                var __err = out;
                                out = $$outStack.pop();
                                if (!it.compositeRule && $breakOnError) {
                                    /* istanbul ignore if */
                                    if (it.async) {
                                        out += ' throw new ValidationError([' + (__err) + ']); ';
                                    }
                                    else {
                                        out += ' validate.errors = [' + (__err) + ']; return false; ';
                                    }
                                }
                                else {
                                    out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                                }
                                $errSchemaPath = $currErrSchemaPath;
                                it.errorPath = $currentErrorPath;
                                out += ' } else { ';
                            }
                            else {
                                if ($breakOnError) {
                                    out += ' if ( ' + ($useData) + ' === undefined ';
                                    if ($ownProperties) {
                                        out += ' || ! Object.prototype.hasOwnProperty.call(' + ($data) + ', \'' + (it.util.escapeQuotes($propertyKey)) + '\') ';
                                    }
                                    out += ') { ' + ($nextValid) + ' = true; } else { ';
                                }
                                else {
                                    out += ' if (' + ($useData) + ' !== undefined ';
                                    if ($ownProperties) {
                                        out += ' &&   Object.prototype.hasOwnProperty.call(' + ($data) + ', \'' + (it.util.escapeQuotes($propertyKey)) + '\') ';
                                    }
                                    out += ' ) { ';
                                }
                            }
                            out += ' ' + ($code) + ' } ';
                        }
                    }
                    if ($breakOnError) {
                        out += ' if (' + ($nextValid) + ') { ';
                        $closingBraces += '}';
                    }
                }
            }
        }
        if ($pPropertyKeys.length) {
            var arr4 = $pPropertyKeys;
            if (arr4) {
                var $pProperty, i4 = -1, l4 = arr4.length - 1;
                while (i4 < l4) {
                    $pProperty = arr4[i4 += 1];
                    var $sch = $pProperties[$pProperty];
                    if ((it.opts.strictKeywords ? (typeof $sch == 'object' && Object.keys($sch).length > 0) || $sch === false : it.util.schemaHasRules($sch, it.RULES.all))) {
                        $it.schema = $sch;
                        $it.schemaPath = it.schemaPath + '.patternProperties' + it.util.getProperty($pProperty);
                        $it.errSchemaPath = it.errSchemaPath + '/patternProperties/' + it.util.escapeFragment($pProperty);
                        if ($ownProperties) {
                            out += ' ' + ($dataProperties) + ' = ' + ($dataProperties) + ' || Object.keys(' + ($data) + '); for (var ' + ($idx) + '=0; ' + ($idx) + '<' + ($dataProperties) + '.length; ' + ($idx) + '++) { var ' + ($key) + ' = ' + ($dataProperties) + '[' + ($idx) + ']; ';
                        }
                        else {
                            out += ' for (var ' + ($key) + ' in ' + ($data) + ') { ';
                        }
                        out += ' if (' + (it.usePattern($pProperty)) + '.test(' + ($key) + ')) { ';
                        $it.errorPath = it.util.getPathExpr(it.errorPath, $key, it.opts.jsonPointers);
                        var $passData = $data + '[' + $key + ']';
                        $it.dataPathArr[$dataNxt] = $key;
                        var $code = it.validate($it);
                        $it.baseId = $currentBaseId;
                        if (it.util.varOccurences($code, $nextData) < 2) {
                            out += ' ' + (it.util.varReplace($code, $nextData, $passData)) + ' ';
                        }
                        else {
                            out += ' var ' + ($nextData) + ' = ' + ($passData) + '; ' + ($code) + ' ';
                        }
                        if ($breakOnError) {
                            out += ' if (!' + ($nextValid) + ') break; ';
                        }
                        out += ' } ';
                        if ($breakOnError) {
                            out += ' else ' + ($nextValid) + ' = true; ';
                        }
                        out += ' }  ';
                        if ($breakOnError) {
                            out += ' if (' + ($nextValid) + ') { ';
                            $closingBraces += '}';
                        }
                    }
                }
            }
        }
        if ($breakOnError) {
            out += ' ' + ($closingBraces) + ' if (' + ($errs) + ' == errors) {';
        }
        return out;
    };
},
/* ajv/lib/dotjs/propertyNames.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_propertyNames(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $errs = 'errs__' + $lvl;
        var $it = it.util.copy(it);
        var $closingBraces = '';
        $it.level++;
        var $nextValid = 'valid' + $it.level;
        out += 'var ' + ($errs) + ' = errors;';
        if ((it.opts.strictKeywords ? (typeof $schema == 'object' && Object.keys($schema).length > 0) || $schema === false : it.util.schemaHasRules($schema, it.RULES.all))) {
            $it.schema = $schema;
            $it.schemaPath = $schemaPath;
            $it.errSchemaPath = $errSchemaPath;
            var $key = 'key' + $lvl, $idx = 'idx' + $lvl, $i = 'i' + $lvl, $invalidName = '\' + ' + $key + ' + \'', $dataNxt = $it.dataLevel = it.dataLevel + 1, $nextData = 'data' + $dataNxt, $dataProperties = 'dataProperties' + $lvl, $ownProperties = it.opts.ownProperties, $currentBaseId = it.baseId;
            if ($ownProperties) {
                out += ' var ' + ($dataProperties) + ' = undefined; ';
            }
            if ($ownProperties) {
                out += ' ' + ($dataProperties) + ' = ' + ($dataProperties) + ' || Object.keys(' + ($data) + '); for (var ' + ($idx) + '=0; ' + ($idx) + '<' + ($dataProperties) + '.length; ' + ($idx) + '++) { var ' + ($key) + ' = ' + ($dataProperties) + '[' + ($idx) + ']; ';
            }
            else {
                out += ' for (var ' + ($key) + ' in ' + ($data) + ') { ';
            }
            out += ' var startErrs' + ($lvl) + ' = errors; ';
            var $passData = $key;
            var $wasComposite = it.compositeRule;
            it.compositeRule = $it.compositeRule = true;
            var $code = it.validate($it);
            $it.baseId = $currentBaseId;
            if (it.util.varOccurences($code, $nextData) < 2) {
                out += ' ' + (it.util.varReplace($code, $nextData, $passData)) + ' ';
            }
            else {
                out += ' var ' + ($nextData) + ' = ' + ($passData) + '; ' + ($code) + ' ';
            }
            it.compositeRule = $it.compositeRule = $wasComposite;
            out += ' if (!' + ($nextValid) + ') { for (var ' + ($i) + '=startErrs' + ($lvl) + '; ' + ($i) + '<errors; ' + ($i) + '++) { vErrors[' + ($i) + '].propertyName = ' + ($key) + '; }   var err =   '; /* istanbul ignore else */
            if (it.createErrors !== false) {
                out += ' { keyword: \'' + ('propertyNames') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { propertyName: \'' + ($invalidName) + '\' } ';
                if (it.opts.messages !== false) {
                    out += ' , message: \'property name \\\'' + ($invalidName) + '\\\' is invalid\' ';
                }
                if (it.opts.verbose) {
                    out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                }
                out += ' } ';
            }
            else {
                out += ' {} ';
            }
            out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
            if (!it.compositeRule && $breakOnError) {
                /* istanbul ignore if */
                if (it.async) {
                    out += ' throw new ValidationError(vErrors); ';
                }
                else {
                    out += ' validate.errors = vErrors; return false; ';
                }
            }
            if ($breakOnError) {
                out += ' break; ';
            }
            out += ' } }';
        }
        if ($breakOnError) {
            out += ' ' + ($closingBraces) + ' if (' + ($errs) + ' == errors) {';
        }
        return out;
    };
},
/* ajv/lib/dotjs/required.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_required(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        var $vSchema = 'schema' + $lvl;
        if (!$isData) {
            if ($schema.length < it.opts.loopRequired && it.schema.properties && Object.keys(it.schema.properties).length) {
                var $required = [];
                var arr1 = $schema;
                if (arr1) {
                    var $property, i1 = -1, l1 = arr1.length - 1;
                    while (i1 < l1) {
                        $property = arr1[i1 += 1];
                        var $propertySch = it.schema.properties[$property];
                        if (!($propertySch && (it.opts.strictKeywords ? (typeof $propertySch == 'object' && Object.keys($propertySch).length > 0) || $propertySch === false : it.util.schemaHasRules($propertySch, it.RULES.all)))) {
                            $required[$required.length] = $property;
                        }
                    }
                }
            }
            else {
                var $required = $schema;
            }
        }
        if ($isData || $required.length) {
            var $currentErrorPath = it.errorPath, $loopRequired = $isData || $required.length >= it.opts.loopRequired, $ownProperties = it.opts.ownProperties;
            if ($breakOnError) {
                out += ' var missing' + ($lvl) + '; ';
                if ($loopRequired) {
                    if (!$isData) {
                        out += ' var ' + ($vSchema) + ' = validate.schema' + ($schemaPath) + '; ';
                    }
                    var $i = 'i' + $lvl, $propertyPath = 'schema' + $lvl + '[' + $i + ']', $missingProperty = '\' + ' + $propertyPath + ' + \'';
                    if (it.opts._errorDataPathProperty) {
                        it.errorPath = it.util.getPathExpr($currentErrorPath, $propertyPath, it.opts.jsonPointers);
                    }
                    out += ' var ' + ($valid) + ' = true; ';
                    if ($isData) {
                        out += ' if (schema' + ($lvl) + ' === undefined) ' + ($valid) + ' = true; else if (!Array.isArray(schema' + ($lvl) + ')) ' + ($valid) + ' = false; else {';
                    }
                    out += ' for (var ' + ($i) + ' = 0; ' + ($i) + ' < ' + ($vSchema) + '.length; ' + ($i) + '++) { ' + ($valid) + ' = ' + ($data) + '[' + ($vSchema) + '[' + ($i) + ']] !== undefined ';
                    if ($ownProperties) {
                        out += ' &&   Object.prototype.hasOwnProperty.call(' + ($data) + ', ' + ($vSchema) + '[' + ($i) + ']) ';
                    }
                    out += '; if (!' + ($valid) + ') break; } ';
                    if ($isData) {
                        out += '  }  ';
                    }
                    out += '  if (!' + ($valid) + ') {   ';
                    var $$outStack = $$outStack || [];
                    $$outStack.push(out);
                    out = ''; /* istanbul ignore else */
                    if (it.createErrors !== false) {
                        out += ' { keyword: \'' + ('required') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { missingProperty: \'' + ($missingProperty) + '\' } ';
                        if (it.opts.messages !== false) {
                            out += ' , message: \'';
                            if (it.opts._errorDataPathProperty) {
                                out += 'is a required property';
                            }
                            else {
                                out += 'should have required property \\\'' + ($missingProperty) + '\\\'';
                            }
                            out += '\' ';
                        }
                        if (it.opts.verbose) {
                            out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                        }
                        out += ' } ';
                    }
                    else {
                        out += ' {} ';
                    }
                    var __err = out;
                    out = $$outStack.pop();
                    if (!it.compositeRule && $breakOnError) {
                        /* istanbul ignore if */
                        if (it.async) {
                            out += ' throw new ValidationError([' + (__err) + ']); ';
                        }
                        else {
                            out += ' validate.errors = [' + (__err) + ']; return false; ';
                        }
                    }
                    else {
                        out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                    }
                    out += ' } else { ';
                }
                else {
                    out += ' if ( ';
                    var arr2 = $required;
                    if (arr2) {
                        var $propertyKey, $i = -1, l2 = arr2.length - 1;
                        while ($i < l2) {
                            $propertyKey = arr2[$i += 1];
                            if ($i) {
                                out += ' || ';
                            }
                            var $prop = it.util.getProperty($propertyKey), $useData = $data + $prop;
                            out += ' ( ( ' + ($useData) + ' === undefined ';
                            if ($ownProperties) {
                                out += ' || ! Object.prototype.hasOwnProperty.call(' + ($data) + ', \'' + (it.util.escapeQuotes($propertyKey)) + '\') ';
                            }
                            out += ') && (missing' + ($lvl) + ' = ' + (it.util.toQuotedString(it.opts.jsonPointers ? $propertyKey : $prop)) + ') ) ';
                        }
                    }
                    out += ') {  ';
                    var $propertyPath = 'missing' + $lvl, $missingProperty = '\' + ' + $propertyPath + ' + \'';
                    if (it.opts._errorDataPathProperty) {
                        it.errorPath = it.opts.jsonPointers ? it.util.getPathExpr($currentErrorPath, $propertyPath, true) : $currentErrorPath + ' + ' + $propertyPath;
                    }
                    var $$outStack = $$outStack || [];
                    $$outStack.push(out);
                    out = ''; /* istanbul ignore else */
                    if (it.createErrors !== false) {
                        out += ' { keyword: \'' + ('required') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { missingProperty: \'' + ($missingProperty) + '\' } ';
                        if (it.opts.messages !== false) {
                            out += ' , message: \'';
                            if (it.opts._errorDataPathProperty) {
                                out += 'is a required property';
                            }
                            else {
                                out += 'should have required property \\\'' + ($missingProperty) + '\\\'';
                            }
                            out += '\' ';
                        }
                        if (it.opts.verbose) {
                            out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                        }
                        out += ' } ';
                    }
                    else {
                        out += ' {} ';
                    }
                    var __err = out;
                    out = $$outStack.pop();
                    if (!it.compositeRule && $breakOnError) {
                        /* istanbul ignore if */
                        if (it.async) {
                            out += ' throw new ValidationError([' + (__err) + ']); ';
                        }
                        else {
                            out += ' validate.errors = [' + (__err) + ']; return false; ';
                        }
                    }
                    else {
                        out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                    }
                    out += ' } else { ';
                }
            }
            else {
                if ($loopRequired) {
                    if (!$isData) {
                        out += ' var ' + ($vSchema) + ' = validate.schema' + ($schemaPath) + '; ';
                    }
                    var $i = 'i' + $lvl, $propertyPath = 'schema' + $lvl + '[' + $i + ']', $missingProperty = '\' + ' + $propertyPath + ' + \'';
                    if (it.opts._errorDataPathProperty) {
                        it.errorPath = it.util.getPathExpr($currentErrorPath, $propertyPath, it.opts.jsonPointers);
                    }
                    if ($isData) {
                        out += ' if (' + ($vSchema) + ' && !Array.isArray(' + ($vSchema) + ')) {  var err =   '; /* istanbul ignore else */
                        if (it.createErrors !== false) {
                            out += ' { keyword: \'' + ('required') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { missingProperty: \'' + ($missingProperty) + '\' } ';
                            if (it.opts.messages !== false) {
                                out += ' , message: \'';
                                if (it.opts._errorDataPathProperty) {
                                    out += 'is a required property';
                                }
                                else {
                                    out += 'should have required property \\\'' + ($missingProperty) + '\\\'';
                                }
                                out += '\' ';
                            }
                            if (it.opts.verbose) {
                                out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                            }
                            out += ' } ';
                        }
                        else {
                            out += ' {} ';
                        }
                        out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } else if (' + ($vSchema) + ' !== undefined) { ';
                    }
                    out += ' for (var ' + ($i) + ' = 0; ' + ($i) + ' < ' + ($vSchema) + '.length; ' + ($i) + '++) { if (' + ($data) + '[' + ($vSchema) + '[' + ($i) + ']] === undefined ';
                    if ($ownProperties) {
                        out += ' || ! Object.prototype.hasOwnProperty.call(' + ($data) + ', ' + ($vSchema) + '[' + ($i) + ']) ';
                    }
                    out += ') {  var err =   '; /* istanbul ignore else */
                    if (it.createErrors !== false) {
                        out += ' { keyword: \'' + ('required') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { missingProperty: \'' + ($missingProperty) + '\' } ';
                        if (it.opts.messages !== false) {
                            out += ' , message: \'';
                            if (it.opts._errorDataPathProperty) {
                                out += 'is a required property';
                            }
                            else {
                                out += 'should have required property \\\'' + ($missingProperty) + '\\\'';
                            }
                            out += '\' ';
                        }
                        if (it.opts.verbose) {
                            out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                        }
                        out += ' } ';
                    }
                    else {
                        out += ' {} ';
                    }
                    out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } } ';
                    if ($isData) {
                        out += '  }  ';
                    }
                }
                else {
                    var arr3 = $required;
                    if (arr3) {
                        var $propertyKey, i3 = -1, l3 = arr3.length - 1;
                        while (i3 < l3) {
                            $propertyKey = arr3[i3 += 1];
                            var $prop = it.util.getProperty($propertyKey), $missingProperty = it.util.escapeQuotes($propertyKey), $useData = $data + $prop;
                            if (it.opts._errorDataPathProperty) {
                                it.errorPath = it.util.getPath($currentErrorPath, $propertyKey, it.opts.jsonPointers);
                            }
                            out += ' if ( ' + ($useData) + ' === undefined ';
                            if ($ownProperties) {
                                out += ' || ! Object.prototype.hasOwnProperty.call(' + ($data) + ', \'' + (it.util.escapeQuotes($propertyKey)) + '\') ';
                            }
                            out += ') {  var err =   '; /* istanbul ignore else */
                            if (it.createErrors !== false) {
                                out += ' { keyword: \'' + ('required') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { missingProperty: \'' + ($missingProperty) + '\' } ';
                                if (it.opts.messages !== false) {
                                    out += ' , message: \'';
                                    if (it.opts._errorDataPathProperty) {
                                        out += 'is a required property';
                                    }
                                    else {
                                        out += 'should have required property \\\'' + ($missingProperty) + '\\\'';
                                    }
                                    out += '\' ';
                                }
                                if (it.opts.verbose) {
                                    out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                                }
                                out += ' } ';
                            }
                            else {
                                out += ' {} ';
                            }
                            out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } ';
                        }
                    }
                }
            }
            it.errorPath = $currentErrorPath;
        }
        else if ($breakOnError) {
            out += ' if (true) {';
        }
        return out;
    };
},
/* ajv/lib/dotjs/uniqueItems.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_uniqueItems(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        if (($schema || $isData) && it.opts.uniqueItems !== false) {
            if ($isData) {
                out += ' var ' + ($valid) + '; if (' + ($schemaValue) + ' === false || ' + ($schemaValue) + ' === undefined) ' + ($valid) + ' = true; else if (typeof ' + ($schemaValue) + ' != \'boolean\') ' + ($valid) + ' = false; else { ';
            }
            out += ' var i = ' + ($data) + '.length , ' + ($valid) + ' = true , j; if (i > 1) { ';
            var $itemType = it.schema.items && it.schema.items.type, $typeIsArray = Array.isArray($itemType);
            if (!$itemType || $itemType == 'object' || $itemType == 'array' || ($typeIsArray && ($itemType.indexOf('object') >= 0 || $itemType.indexOf('array') >= 0))) {
                out += ' outer: for (;i--;) { for (j = i; j--;) { if (equal(' + ($data) + '[i], ' + ($data) + '[j])) { ' + ($valid) + ' = false; break outer; } } } ';
            }
            else {
                out += ' var itemIndices = {}, item; for (;i--;) { var item = ' + ($data) + '[i]; ';
                var $method = 'checkDataType' + ($typeIsArray ? 's' : '');
                out += ' if (' + (it.util[$method]($itemType, 'item', it.opts.strictNumbers, true)) + ') continue; ';
                if ($typeIsArray) {
                    out += ' if (typeof item == \'string\') item = \'"\' + item; ';
                }
                out += ' if (typeof itemIndices[item] == \'number\') { ' + ($valid) + ' = false; j = itemIndices[item]; break; } itemIndices[item] = i; } ';
            }
            out += ' } ';
            if ($isData) {
                out += '  }  ';
            }
            out += ' if (!' + ($valid) + ') {   ';
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = ''; /* istanbul ignore else */
            if (it.createErrors !== false) {
                out += ' { keyword: \'' + ('uniqueItems') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { i: i, j: j } ';
                if (it.opts.messages !== false) {
                    out += ' , message: \'should NOT have duplicate items (items ## \' + j + \' and \' + i + \' are identical)\' ';
                }
                if (it.opts.verbose) {
                    out += ' , schema:  ';
                    if ($isData) {
                        out += 'validate.schema' + ($schemaPath);
                    }
                    else {
                        out += '' + ($schema);
                    }
                    out += '         , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                }
                out += ' } ';
            }
            else {
                out += ' {} ';
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it.compositeRule && $breakOnError) {
                /* istanbul ignore if */
                if (it.async) {
                    out += ' throw new ValidationError([' + (__err) + ']); ';
                }
                else {
                    out += ' validate.errors = [' + (__err) + ']; return false; ';
                }
            }
            else {
                out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
            }
            out += ' } ';
            if ($breakOnError) {
                out += ' else { ';
            }
        }
        else {
            if ($breakOnError) {
                out += ' if (true) { ';
            }
        }
        return out;
    };
},
/* ajv/lib/data.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var KEYWORDS = [
        'multipleOf',
        'maximum',
        'exclusiveMaximum',
        'minimum',
        'exclusiveMinimum',
        'maxLength',
        'minLength',
        'pattern',
        'additionalItems',
        'maxItems',
        'minItems',
        'uniqueItems',
        'maxProperties',
        'minProperties',
        'required',
        'additionalProperties',
        'enum',
        'format',
        'const'
    ];
    module.exports = function (metaSchema, keywordsJsonPointers) {
        for (var i = 0; i < keywordsJsonPointers.length; i++) {
            metaSchema = JSON.parse(JSON.stringify(metaSchema));
            var segments = keywordsJsonPointers[i].split('/');
            var keywords = metaSchema;
            var j;
            for (j = 1; j < segments.length; j++)
                keywords = keywords[segments[j]];
            for (j = 0; j < KEYWORDS.length; j++) {
                var key = KEYWORDS[j];
                var schema = keywords[key];
                if (schema) {
                    keywords[key] = {
                        anyOf: [
                            schema,
                            { $ref: 'https://raw.githubusercontent.com/ajv-validator/ajv/master/lib/refs/data.json#' }
                        ]
                    };
                }
            }
        }
        return metaSchema;
    };
},
/* ajv/lib/compile/async.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var MissingRefError = require(242) /* ./error_classes */.MissingRef;
    module.exports = compileAsync;
    /**
     * Creates validating function for passed schema with asynchronous loading of missing schemas.
     * `loadSchema` option should be a function that accepts schema uri and returns promise that resolves with the schema.
     * @this  Ajv
     * @param {Object}   schema schema object
     * @param {Boolean}  meta optional true to compile meta-schema; this parameter can be skipped
     * @param {Function} callback an optional node-style callback, it is called with 2 parameters: error (or null) and validating function.
     * @return {Promise} promise that resolves with a validating function.
     */
    function compileAsync(schema, meta, callback) {
        /* eslint no-shadow: 0 */
        /* global Promise */
        /* jshint validthis: true */
        var self = this;
        if (typeof this._opts.loadSchema != 'function')
            throw new Error('options.loadSchema should be a function');
        if (typeof meta == 'function') {
            callback = meta;
            meta = undefined;
        }
        var p = loadMetaSchemaOf(schema).then(function () {
            var schemaObj = self._addSchema(schema, undefined, meta);
            return schemaObj.validate || _compileAsync(schemaObj);
        });
        if (callback) {
            p.then(function (v) { callback(null, v); }, callback);
        }
        return p;
        function loadMetaSchemaOf(sch) {
            var $schema = sch.$schema;
            return $schema && !self.getSchema($schema)
                ? compileAsync.call(self, { $ref: $schema }, true)
                : Promise.resolve();
        }
        function _compileAsync(schemaObj) {
            try {
                return self._compile(schemaObj);
            }
            catch (e) {
                if (e instanceof MissingRefError)
                    return loadMissingSchema(e);
                throw e;
            }
            function loadMissingSchema(e) {
                var ref = e.missingSchema;
                if (added(ref))
                    throw new Error('Schema ' + ref + ' is loaded but ' + e.missingRef + ' cannot be resolved');
                var schemaPromise = self._loadingSchemas[ref];
                if (!schemaPromise) {
                    schemaPromise = self._loadingSchemas[ref] = self._opts.loadSchema(ref);
                    schemaPromise.then(removePromise, removePromise);
                }
                return schemaPromise.then(function (sch) {
                    if (!added(ref)) {
                        return loadMetaSchemaOf(sch).then(function () {
                            if (!added(ref))
                                self.addSchema(sch, ref, undefined, meta);
                        });
                    }
                }).then(function () {
                    return _compileAsync(schemaObj);
                });
                function removePromise() {
                    delete self._loadingSchemas[ref];
                }
                function added(ref) {
                    return self._refs[ref] || self._schemas[ref];
                }
            }
        }
    }
},
/* ajv/lib/keyword.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var IDENTIFIER = /^[a-z_$][a-z0-9_$-]*$/i;
    var customRuleCode = require(275) /* ./dotjs/custom */;
    var definitionSchema = require(276) /* ./definition_schema */;
    module.exports = {
        add: addKeyword,
        get: getKeyword,
        remove: removeKeyword,
        validate: validateKeyword
    };
    /**
     * Define custom keyword
     * @this  Ajv
     * @param {String} keyword custom keyword, should be unique (including different from all standard, custom and macro keywords).
     * @param {Object} definition keyword definition object with properties `type` (type(s) which the keyword applies to), `validate` or `compile`.
     * @return {Ajv} this for method chaining
     */
    function addKeyword(keyword, definition) {
        /* jshint validthis: true */
        /* eslint no-shadow: 0 */
        var RULES = this.RULES;
        if (RULES.keywords[keyword])
            throw new Error('Keyword ' + keyword + ' is already defined');
        if (!IDENTIFIER.test(keyword))
            throw new Error('Keyword ' + keyword + ' is not a valid identifier');
        if (definition) {
            this.validateKeyword(definition, true);
            var dataType = definition.type;
            if (Array.isArray(dataType)) {
                for (var i = 0; i < dataType.length; i++)
                    _addRule(keyword, dataType[i], definition);
            }
            else {
                _addRule(keyword, dataType, definition);
            }
            var metaSchema = definition.metaSchema;
            if (metaSchema) {
                if (definition.$data && this._opts.$data) {
                    metaSchema = {
                        anyOf: [
                            metaSchema,
                            { '$ref': 'https://raw.githubusercontent.com/ajv-validator/ajv/master/lib/refs/data.json#' }
                        ]
                    };
                }
                definition.validateSchema = this.compile(metaSchema, true);
            }
        }
        RULES.keywords[keyword] = RULES.all[keyword] = true;
        function _addRule(keyword, dataType, definition) {
            var ruleGroup;
            for (var i = 0; i < RULES.length; i++) {
                var rg = RULES[i];
                if (rg.type == dataType) {
                    ruleGroup = rg;
                    break;
                }
            }
            if (!ruleGroup) {
                ruleGroup = { type: dataType, rules: [] };
                RULES.push(ruleGroup);
            }
            var rule = {
                keyword: keyword,
                definition: definition,
                custom: true,
                code: customRuleCode,
                implements: definition.implements
            };
            ruleGroup.rules.push(rule);
            RULES.custom[keyword] = rule;
        }
        return this;
    }
    /**
     * Get keyword
     * @this  Ajv
     * @param {String} keyword pre-defined or custom keyword.
     * @return {Object|Boolean} custom keyword definition, `true` if it is a predefined keyword, `false` otherwise.
     */
    function getKeyword(keyword) {
        /* jshint validthis: true */
        var rule = this.RULES.custom[keyword];
        return rule ? rule.definition : this.RULES.keywords[keyword] || false;
    }
    /**
     * Remove keyword
     * @this  Ajv
     * @param {String} keyword pre-defined or custom keyword.
     * @return {Ajv} this for method chaining
     */
    function removeKeyword(keyword) {
        /* jshint validthis: true */
        var RULES = this.RULES;
        delete RULES.keywords[keyword];
        delete RULES.all[keyword];
        delete RULES.custom[keyword];
        for (var i = 0; i < RULES.length; i++) {
            var rules = RULES[i].rules;
            for (var j = 0; j < rules.length; j++) {
                if (rules[j].keyword == keyword) {
                    rules.splice(j, 1);
                    break;
                }
            }
        }
        return this;
    }
    /**
     * Validate keyword definition
     * @this  Ajv
     * @param {Object} definition keyword definition object.
     * @param {Boolean} throwError true to throw exception if definition is invalid
     * @return {boolean} validation result
     */
    function validateKeyword(definition, throwError) {
        validateKeyword.errors = null;
        var v = this._validateKeyword = this._validateKeyword
            || this.compile(definitionSchema, true);
        if (v(definition))
            return true;
        validateKeyword.errors = v.errors;
        if (throwError)
            throw new Error('custom keyword definition is invalid: ' + this.errorsText(v.errors));
        else
            return false;
    }
},
/* ajv/lib/dotjs/custom.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function generate_custom(it, $keyword, $ruleType) {
        var out = ' ';
        var $lvl = it.level;
        var $dataLvl = it.dataLevel;
        var $schema = it.schema[$keyword];
        var $schemaPath = it.schemaPath + it.util.getProperty($keyword);
        var $errSchemaPath = it.errSchemaPath + '/' + $keyword;
        var $breakOnError = !it.opts.allErrors;
        var $errorKeyword;
        var $data = 'data' + ($dataLvl || '');
        var $valid = 'valid' + $lvl;
        var $errs = 'errs__' + $lvl;
        var $isData = it.opts.$data && $schema && $schema.$data, $schemaValue;
        if ($isData) {
            out += ' var schema' + ($lvl) + ' = ' + (it.util.getData($schema.$data, $dataLvl, it.dataPathArr)) + '; ';
            $schemaValue = 'schema' + $lvl;
        }
        else {
            $schemaValue = $schema;
        }
        var $rule = this, $definition = 'definition' + $lvl, $rDef = $rule.definition, $closingBraces = '';
        var $compile, $inline, $macro, $ruleValidate, $validateCode;
        if ($isData && $rDef.$data) {
            $validateCode = 'keywordValidate' + $lvl;
            var $validateSchema = $rDef.validateSchema;
            out += ' var ' + ($definition) + ' = RULES.custom[\'' + ($keyword) + '\'].definition; var ' + ($validateCode) + ' = ' + ($definition) + '.validate;';
        }
        else {
            $ruleValidate = it.useCustomRule($rule, $schema, it.schema, it);
            if (!$ruleValidate)
                return;
            $schemaValue = 'validate.schema' + $schemaPath;
            $validateCode = $ruleValidate.code;
            $compile = $rDef.compile;
            $inline = $rDef.inline;
            $macro = $rDef.macro;
        }
        var $ruleErrs = $validateCode + '.errors', $i = 'i' + $lvl, $ruleErr = 'ruleErr' + $lvl, $asyncKeyword = $rDef.async;
        if ($asyncKeyword && !it.async)
            throw new Error('async keyword in sync schema');
        if (!($inline || $macro)) {
            out += '' + ($ruleErrs) + ' = null;';
        }
        out += 'var ' + ($errs) + ' = errors;var ' + ($valid) + ';';
        if ($isData && $rDef.$data) {
            $closingBraces += '}';
            out += ' if (' + ($schemaValue) + ' === undefined) { ' + ($valid) + ' = true; } else { ';
            if ($validateSchema) {
                $closingBraces += '}';
                out += ' ' + ($valid) + ' = ' + ($definition) + '.validateSchema(' + ($schemaValue) + '); if (' + ($valid) + ') { ';
            }
        }
        if ($inline) {
            if ($rDef.statements) {
                out += ' ' + ($ruleValidate.validate) + ' ';
            }
            else {
                out += ' ' + ($valid) + ' = ' + ($ruleValidate.validate) + '; ';
            }
        }
        else if ($macro) {
            var $it = it.util.copy(it);
            var $closingBraces = '';
            $it.level++;
            var $nextValid = 'valid' + $it.level;
            $it.schema = $ruleValidate.validate;
            $it.schemaPath = '';
            var $wasComposite = it.compositeRule;
            it.compositeRule = $it.compositeRule = true;
            var $code = it.validate($it).replace(/validate\.schema/g, $validateCode);
            it.compositeRule = $it.compositeRule = $wasComposite;
            out += ' ' + ($code);
        }
        else {
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = '';
            out += '  ' + ($validateCode) + '.call( ';
            if (it.opts.passContext) {
                out += 'this';
            }
            else {
                out += 'self';
            }
            if ($compile || $rDef.schema === false) {
                out += ' , ' + ($data) + ' ';
            }
            else {
                out += ' , ' + ($schemaValue) + ' , ' + ($data) + ' , validate.schema' + (it.schemaPath) + ' ';
            }
            out += ' , (dataPath || \'\')';
            if (it.errorPath != '""') {
                out += ' + ' + (it.errorPath);
            }
            var $parentData = $dataLvl ? 'data' + (($dataLvl - 1) || '') : 'parentData', $parentDataProperty = $dataLvl ? it.dataPathArr[$dataLvl] : 'parentDataProperty';
            out += ' , ' + ($parentData) + ' , ' + ($parentDataProperty) + ' , rootData )  ';
            var def_callRuleValidate = out;
            out = $$outStack.pop();
            if ($rDef.errors === false) {
                out += ' ' + ($valid) + ' = ';
                if ($asyncKeyword) {
                    out += 'await ';
                }
                out += '' + (def_callRuleValidate) + '; ';
            }
            else {
                if ($asyncKeyword) {
                    $ruleErrs = 'customErrors' + $lvl;
                    out += ' var ' + ($ruleErrs) + ' = null; try { ' + ($valid) + ' = await ' + (def_callRuleValidate) + '; } catch (e) { ' + ($valid) + ' = false; if (e instanceof ValidationError) ' + ($ruleErrs) + ' = e.errors; else throw e; } ';
                }
                else {
                    out += ' ' + ($ruleErrs) + ' = null; ' + ($valid) + ' = ' + (def_callRuleValidate) + '; ';
                }
            }
        }
        if ($rDef.modifying) {
            out += ' if (' + ($parentData) + ') ' + ($data) + ' = ' + ($parentData) + '[' + ($parentDataProperty) + '];';
        }
        out += '' + ($closingBraces);
        if ($rDef.valid) {
            if ($breakOnError) {
                out += ' if (true) { ';
            }
        }
        else {
            out += ' if ( ';
            if ($rDef.valid === undefined) {
                out += ' !';
                if ($macro) {
                    out += '' + ($nextValid);
                }
                else {
                    out += '' + ($valid);
                }
            }
            else {
                out += ' ' + (!$rDef.valid) + ' ';
            }
            out += ') { ';
            $errorKeyword = $rule.keyword;
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = '';
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = ''; /* istanbul ignore else */
            if (it.createErrors !== false) {
                out += ' { keyword: \'' + ($errorKeyword || 'custom') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { keyword: \'' + ($rule.keyword) + '\' } ';
                if (it.opts.messages !== false) {
                    out += ' , message: \'should pass "' + ($rule.keyword) + '" keyword validation\' ';
                }
                if (it.opts.verbose) {
                    out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                }
                out += ' } ';
            }
            else {
                out += ' {} ';
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it.compositeRule && $breakOnError) {
                /* istanbul ignore if */
                if (it.async) {
                    out += ' throw new ValidationError([' + (__err) + ']); ';
                }
                else {
                    out += ' validate.errors = [' + (__err) + ']; return false; ';
                }
            }
            else {
                out += ' var err = ' + (__err) + ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
            }
            var def_customError = out;
            out = $$outStack.pop();
            if ($inline) {
                if ($rDef.errors) {
                    if ($rDef.errors != 'full') {
                        out += '  for (var ' + ($i) + '=' + ($errs) + '; ' + ($i) + '<errors; ' + ($i) + '++) { var ' + ($ruleErr) + ' = vErrors[' + ($i) + ']; if (' + ($ruleErr) + '.dataPath === undefined) ' + ($ruleErr) + '.dataPath = (dataPath || \'\') + ' + (it.errorPath) + '; if (' + ($ruleErr) + '.schemaPath === undefined) { ' + ($ruleErr) + '.schemaPath = "' + ($errSchemaPath) + '"; } ';
                        if (it.opts.verbose) {
                            out += ' ' + ($ruleErr) + '.schema = ' + ($schemaValue) + '; ' + ($ruleErr) + '.data = ' + ($data) + '; ';
                        }
                        out += ' } ';
                    }
                }
                else {
                    if ($rDef.errors === false) {
                        out += ' ' + (def_customError) + ' ';
                    }
                    else {
                        out += ' if (' + ($errs) + ' == errors) { ' + (def_customError) + ' } else {  for (var ' + ($i) + '=' + ($errs) + '; ' + ($i) + '<errors; ' + ($i) + '++) { var ' + ($ruleErr) + ' = vErrors[' + ($i) + ']; if (' + ($ruleErr) + '.dataPath === undefined) ' + ($ruleErr) + '.dataPath = (dataPath || \'\') + ' + (it.errorPath) + '; if (' + ($ruleErr) + '.schemaPath === undefined) { ' + ($ruleErr) + '.schemaPath = "' + ($errSchemaPath) + '"; } ';
                        if (it.opts.verbose) {
                            out += ' ' + ($ruleErr) + '.schema = ' + ($schemaValue) + '; ' + ($ruleErr) + '.data = ' + ($data) + '; ';
                        }
                        out += ' } } ';
                    }
                }
            }
            else if ($macro) {
                out += '   var err =   '; /* istanbul ignore else */
                if (it.createErrors !== false) {
                    out += ' { keyword: \'' + ($errorKeyword || 'custom') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: ' + (it.util.toQuotedString($errSchemaPath)) + ' , params: { keyword: \'' + ($rule.keyword) + '\' } ';
                    if (it.opts.messages !== false) {
                        out += ' , message: \'should pass "' + ($rule.keyword) + '" keyword validation\' ';
                    }
                    if (it.opts.verbose) {
                        out += ' , schema: validate.schema' + ($schemaPath) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
                    }
                    out += ' } ';
                }
                else {
                    out += ' {} ';
                }
                out += ';  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
                if (!it.compositeRule && $breakOnError) {
                    /* istanbul ignore if */
                    if (it.async) {
                        out += ' throw new ValidationError(vErrors); ';
                    }
                    else {
                        out += ' validate.errors = vErrors; return false; ';
                    }
                }
            }
            else {
                if ($rDef.errors === false) {
                    out += ' ' + (def_customError) + ' ';
                }
                else {
                    out += ' if (Array.isArray(' + ($ruleErrs) + ')) { if (vErrors === null) vErrors = ' + ($ruleErrs) + '; else vErrors = vErrors.concat(' + ($ruleErrs) + '); errors = vErrors.length;  for (var ' + ($i) + '=' + ($errs) + '; ' + ($i) + '<errors; ' + ($i) + '++) { var ' + ($ruleErr) + ' = vErrors[' + ($i) + ']; if (' + ($ruleErr) + '.dataPath === undefined) ' + ($ruleErr) + '.dataPath = (dataPath || \'\') + ' + (it.errorPath) + ';  ' + ($ruleErr) + '.schemaPath = "' + ($errSchemaPath) + '";  ';
                    if (it.opts.verbose) {
                        out += ' ' + ($ruleErr) + '.schema = ' + ($schemaValue) + '; ' + ($ruleErr) + '.data = ' + ($data) + '; ';
                    }
                    out += ' } } else { ' + (def_customError) + ' } ';
                }
            }
            out += ' } ';
            if ($breakOnError) {
                out += ' else { ';
            }
        }
        return out;
    };
},
/* ajv/lib/definition_schema.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var metaSchema = require(277) /* ./refs/json-schema-draft-07.json */;
    module.exports = {
        $id: 'https://github.com/ajv-validator/ajv/blob/master/lib/definition_schema.js',
        definitions: {
            simpleTypes: metaSchema.definitions.simpleTypes
        },
        type: 'object',
        dependencies: {
            schema: ['validate'],
            $data: ['validate'],
            statements: ['inline'],
            valid: { not: { required: ['macro'] } }
        },
        properties: {
            type: metaSchema.properties.type,
            schema: { type: 'boolean' },
            statements: { type: 'boolean' },
            dependencies: {
                type: 'array',
                items: { type: 'string' }
            },
            metaSchema: { type: 'object' },
            modifying: { type: 'boolean' },
            valid: { type: 'boolean' },
            $data: { type: 'boolean' },
            async: { type: 'boolean' },
            errors: {
                anyOf: [
                    { type: 'boolean' },
                    { const: 'full' }
                ]
            }
        }
    };
},
/* ajv/lib/refs/json-schema-draft-07.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "$id": "http://json-schema.org/draft-07/schema#",
        "title": "Core schema meta-schema",
        "definitions": {
            "schemaArray": {
                "type": "array",
                "minItems": 1,
                "items": { "$ref": "#" }
            },
            "nonNegativeInteger": {
                "type": "integer",
                "minimum": 0
            },
            "nonNegativeIntegerDefault0": {
                "allOf": [
                    { "$ref": "#/definitions/nonNegativeInteger" },
                    { "default": 0 }
                ]
            },
            "simpleTypes": {
                "enum": [
                    "array",
                    "boolean",
                    "integer",
                    "null",
                    "number",
                    "object",
                    "string"
                ]
            },
            "stringArray": {
                "type": "array",
                "items": { "type": "string" },
                "uniqueItems": true,
                "default": []
            }
        },
        "type": ["object", "boolean"],
        "properties": {
            "$id": {
                "type": "string",
                "format": "uri-reference"
            },
            "$schema": {
                "type": "string",
                "format": "uri"
            },
            "$ref": {
                "type": "string",
                "format": "uri-reference"
            },
            "$comment": {
                "type": "string"
            },
            "title": {
                "type": "string"
            },
            "description": {
                "type": "string"
            },
            "default": true,
            "readOnly": {
                "type": "boolean",
                "default": false
            },
            "examples": {
                "type": "array",
                "items": true
            },
            "multipleOf": {
                "type": "number",
                "exclusiveMinimum": 0
            },
            "maximum": {
                "type": "number"
            },
            "exclusiveMaximum": {
                "type": "number"
            },
            "minimum": {
                "type": "number"
            },
            "exclusiveMinimum": {
                "type": "number"
            },
            "maxLength": { "$ref": "#/definitions/nonNegativeInteger" },
            "minLength": { "$ref": "#/definitions/nonNegativeIntegerDefault0" },
            "pattern": {
                "type": "string",
                "format": "regex"
            },
            "additionalItems": { "$ref": "#" },
            "items": {
                "anyOf": [
                    { "$ref": "#" },
                    { "$ref": "#/definitions/schemaArray" }
                ],
                "default": true
            },
            "maxItems": { "$ref": "#/definitions/nonNegativeInteger" },
            "minItems": { "$ref": "#/definitions/nonNegativeIntegerDefault0" },
            "uniqueItems": {
                "type": "boolean",
                "default": false
            },
            "contains": { "$ref": "#" },
            "maxProperties": { "$ref": "#/definitions/nonNegativeInteger" },
            "minProperties": { "$ref": "#/definitions/nonNegativeIntegerDefault0" },
            "required": { "$ref": "#/definitions/stringArray" },
            "additionalProperties": { "$ref": "#" },
            "definitions": {
                "type": "object",
                "additionalProperties": { "$ref": "#" },
                "default": {}
            },
            "properties": {
                "type": "object",
                "additionalProperties": { "$ref": "#" },
                "default": {}
            },
            "patternProperties": {
                "type": "object",
                "additionalProperties": { "$ref": "#" },
                "propertyNames": { "format": "regex" },
                "default": {}
            },
            "dependencies": {
                "type": "object",
                "additionalProperties": {
                    "anyOf": [
                        { "$ref": "#" },
                        { "$ref": "#/definitions/stringArray" }
                    ]
                }
            },
            "propertyNames": { "$ref": "#" },
            "const": true,
            "enum": {
                "type": "array",
                "items": true,
                "minItems": 1,
                "uniqueItems": true
            },
            "type": {
                "anyOf": [
                    { "$ref": "#/definitions/simpleTypes" },
                    {
                        "type": "array",
                        "items": { "$ref": "#/definitions/simpleTypes" },
                        "minItems": 1,
                        "uniqueItems": true
                    }
                ]
            },
            "format": { "type": "string" },
            "contentMediaType": { "type": "string" },
            "contentEncoding": { "type": "string" },
            "if": { "$ref": "#" },
            "then": { "$ref": "#" },
            "else": { "$ref": "#" },
            "allOf": { "$ref": "#/definitions/schemaArray" },
            "anyOf": { "$ref": "#/definitions/schemaArray" },
            "oneOf": { "$ref": "#/definitions/schemaArray" },
            "not": { "$ref": "#" }
        },
        "default": true
    };
    module.exports = json;
},
/* ajv/lib/refs/data.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "$id": "https://raw.githubusercontent.com/ajv-validator/ajv/master/lib/refs/data.json#",
        "description": "Meta-schema for $data reference (JSON Schema extension proposal)",
        "type": "object",
        "required": ["$data"],
        "properties": {
            "$data": {
                "type": "string",
                "anyOf": [
                    { "format": "relative-json-pointer" },
                    { "format": "json-pointer" }
                ]
            }
        },
        "additionalProperties": false
    };
    module.exports = json;
},
/* globals/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = require(280) /* ./globals.json */;
},
/* globals/globals.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "builtin": {
            "AggregateError": false,
            "Array": false,
            "ArrayBuffer": false,
            "Atomics": false,
            "BigInt": false,
            "BigInt64Array": false,
            "BigUint64Array": false,
            "Boolean": false,
            "constructor": false,
            "DataView": false,
            "Date": false,
            "decodeURI": false,
            "decodeURIComponent": false,
            "encodeURI": false,
            "encodeURIComponent": false,
            "Error": false,
            "escape": false,
            "eval": false,
            "EvalError": false,
            "FinalizationRegistry": false,
            "Float32Array": false,
            "Float64Array": false,
            "Function": false,
            "globalThis": false,
            "hasOwnProperty": false,
            "Infinity": false,
            "Int16Array": false,
            "Int32Array": false,
            "Int8Array": false,
            "isFinite": false,
            "isNaN": false,
            "isPrototypeOf": false,
            "JSON": false,
            "Map": false,
            "Math": false,
            "NaN": false,
            "Number": false,
            "Object": false,
            "parseFloat": false,
            "parseInt": false,
            "Promise": false,
            "propertyIsEnumerable": false,
            "Proxy": false,
            "RangeError": false,
            "ReferenceError": false,
            "Reflect": false,
            "RegExp": false,
            "Set": false,
            "SharedArrayBuffer": false,
            "String": false,
            "Symbol": false,
            "SyntaxError": false,
            "toLocaleString": false,
            "toString": false,
            "TypeError": false,
            "Uint16Array": false,
            "Uint32Array": false,
            "Uint8Array": false,
            "Uint8ClampedArray": false,
            "undefined": false,
            "unescape": false,
            "URIError": false,
            "valueOf": false,
            "WeakMap": false,
            "WeakRef": false,
            "WeakSet": false
        },
        "es5": {
            "Array": false,
            "Boolean": false,
            "constructor": false,
            "Date": false,
            "decodeURI": false,
            "decodeURIComponent": false,
            "encodeURI": false,
            "encodeURIComponent": false,
            "Error": false,
            "escape": false,
            "eval": false,
            "EvalError": false,
            "Function": false,
            "hasOwnProperty": false,
            "Infinity": false,
            "isFinite": false,
            "isNaN": false,
            "isPrototypeOf": false,
            "JSON": false,
            "Math": false,
            "NaN": false,
            "Number": false,
            "Object": false,
            "parseFloat": false,
            "parseInt": false,
            "propertyIsEnumerable": false,
            "RangeError": false,
            "ReferenceError": false,
            "RegExp": false,
            "String": false,
            "SyntaxError": false,
            "toLocaleString": false,
            "toString": false,
            "TypeError": false,
            "undefined": false,
            "unescape": false,
            "URIError": false,
            "valueOf": false
        },
        "es2015": {
            "Array": false,
            "ArrayBuffer": false,
            "Boolean": false,
            "constructor": false,
            "DataView": false,
            "Date": false,
            "decodeURI": false,
            "decodeURIComponent": false,
            "encodeURI": false,
            "encodeURIComponent": false,
            "Error": false,
            "escape": false,
            "eval": false,
            "EvalError": false,
            "Float32Array": false,
            "Float64Array": false,
            "Function": false,
            "hasOwnProperty": false,
            "Infinity": false,
            "Int16Array": false,
            "Int32Array": false,
            "Int8Array": false,
            "isFinite": false,
            "isNaN": false,
            "isPrototypeOf": false,
            "JSON": false,
            "Map": false,
            "Math": false,
            "NaN": false,
            "Number": false,
            "Object": false,
            "parseFloat": false,
            "parseInt": false,
            "Promise": false,
            "propertyIsEnumerable": false,
            "Proxy": false,
            "RangeError": false,
            "ReferenceError": false,
            "Reflect": false,
            "RegExp": false,
            "Set": false,
            "String": false,
            "Symbol": false,
            "SyntaxError": false,
            "toLocaleString": false,
            "toString": false,
            "TypeError": false,
            "Uint16Array": false,
            "Uint32Array": false,
            "Uint8Array": false,
            "Uint8ClampedArray": false,
            "undefined": false,
            "unescape": false,
            "URIError": false,
            "valueOf": false,
            "WeakMap": false,
            "WeakSet": false
        },
        "es2017": {
            "Array": false,
            "ArrayBuffer": false,
            "Atomics": false,
            "Boolean": false,
            "constructor": false,
            "DataView": false,
            "Date": false,
            "decodeURI": false,
            "decodeURIComponent": false,
            "encodeURI": false,
            "encodeURIComponent": false,
            "Error": false,
            "escape": false,
            "eval": false,
            "EvalError": false,
            "Float32Array": false,
            "Float64Array": false,
            "Function": false,
            "hasOwnProperty": false,
            "Infinity": false,
            "Int16Array": false,
            "Int32Array": false,
            "Int8Array": false,
            "isFinite": false,
            "isNaN": false,
            "isPrototypeOf": false,
            "JSON": false,
            "Map": false,
            "Math": false,
            "NaN": false,
            "Number": false,
            "Object": false,
            "parseFloat": false,
            "parseInt": false,
            "Promise": false,
            "propertyIsEnumerable": false,
            "Proxy": false,
            "RangeError": false,
            "ReferenceError": false,
            "Reflect": false,
            "RegExp": false,
            "Set": false,
            "SharedArrayBuffer": false,
            "String": false,
            "Symbol": false,
            "SyntaxError": false,
            "toLocaleString": false,
            "toString": false,
            "TypeError": false,
            "Uint16Array": false,
            "Uint32Array": false,
            "Uint8Array": false,
            "Uint8ClampedArray": false,
            "undefined": false,
            "unescape": false,
            "URIError": false,
            "valueOf": false,
            "WeakMap": false,
            "WeakSet": false
        },
        "es2020": {
            "Array": false,
            "ArrayBuffer": false,
            "Atomics": false,
            "BigInt": false,
            "BigInt64Array": false,
            "BigUint64Array": false,
            "Boolean": false,
            "constructor": false,
            "DataView": false,
            "Date": false,
            "decodeURI": false,
            "decodeURIComponent": false,
            "encodeURI": false,
            "encodeURIComponent": false,
            "Error": false,
            "escape": false,
            "eval": false,
            "EvalError": false,
            "Float32Array": false,
            "Float64Array": false,
            "Function": false,
            "globalThis": false,
            "hasOwnProperty": false,
            "Infinity": false,
            "Int16Array": false,
            "Int32Array": false,
            "Int8Array": false,
            "isFinite": false,
            "isNaN": false,
            "isPrototypeOf": false,
            "JSON": false,
            "Map": false,
            "Math": false,
            "NaN": false,
            "Number": false,
            "Object": false,
            "parseFloat": false,
            "parseInt": false,
            "Promise": false,
            "propertyIsEnumerable": false,
            "Proxy": false,
            "RangeError": false,
            "ReferenceError": false,
            "Reflect": false,
            "RegExp": false,
            "Set": false,
            "SharedArrayBuffer": false,
            "String": false,
            "Symbol": false,
            "SyntaxError": false,
            "toLocaleString": false,
            "toString": false,
            "TypeError": false,
            "Uint16Array": false,
            "Uint32Array": false,
            "Uint8Array": false,
            "Uint8ClampedArray": false,
            "undefined": false,
            "unescape": false,
            "URIError": false,
            "valueOf": false,
            "WeakMap": false,
            "WeakSet": false
        },
        "es2021": {
            "AggregateError": false,
            "Array": false,
            "ArrayBuffer": false,
            "Atomics": false,
            "BigInt": false,
            "BigInt64Array": false,
            "BigUint64Array": false,
            "Boolean": false,
            "constructor": false,
            "DataView": false,
            "Date": false,
            "decodeURI": false,
            "decodeURIComponent": false,
            "encodeURI": false,
            "encodeURIComponent": false,
            "Error": false,
            "escape": false,
            "eval": false,
            "EvalError": false,
            "FinalizationRegistry": false,
            "Float32Array": false,
            "Float64Array": false,
            "Function": false,
            "globalThis": false,
            "hasOwnProperty": false,
            "Infinity": false,
            "Int16Array": false,
            "Int32Array": false,
            "Int8Array": false,
            "isFinite": false,
            "isNaN": false,
            "isPrototypeOf": false,
            "JSON": false,
            "Map": false,
            "Math": false,
            "NaN": false,
            "Number": false,
            "Object": false,
            "parseFloat": false,
            "parseInt": false,
            "Promise": false,
            "propertyIsEnumerable": false,
            "Proxy": false,
            "RangeError": false,
            "ReferenceError": false,
            "Reflect": false,
            "RegExp": false,
            "Set": false,
            "SharedArrayBuffer": false,
            "String": false,
            "Symbol": false,
            "SyntaxError": false,
            "toLocaleString": false,
            "toString": false,
            "TypeError": false,
            "Uint16Array": false,
            "Uint32Array": false,
            "Uint8Array": false,
            "Uint8ClampedArray": false,
            "undefined": false,
            "unescape": false,
            "URIError": false,
            "valueOf": false,
            "WeakMap": false,
            "WeakRef": false,
            "WeakSet": false
        },
        "browser": {
            "AbortController": false,
            "AbortSignal": false,
            "addEventListener": false,
            "alert": false,
            "AnalyserNode": false,
            "Animation": false,
            "AnimationEffectReadOnly": false,
            "AnimationEffectTiming": false,
            "AnimationEffectTimingReadOnly": false,
            "AnimationEvent": false,
            "AnimationPlaybackEvent": false,
            "AnimationTimeline": false,
            "applicationCache": false,
            "ApplicationCache": false,
            "ApplicationCacheErrorEvent": false,
            "atob": false,
            "Attr": false,
            "Audio": false,
            "AudioBuffer": false,
            "AudioBufferSourceNode": false,
            "AudioContext": false,
            "AudioDestinationNode": false,
            "AudioListener": false,
            "AudioNode": false,
            "AudioParam": false,
            "AudioProcessingEvent": false,
            "AudioScheduledSourceNode": false,
            "AudioWorkletGlobalScope": false,
            "AudioWorkletNode": false,
            "AudioWorkletProcessor": false,
            "BarProp": false,
            "BaseAudioContext": false,
            "BatteryManager": false,
            "BeforeUnloadEvent": false,
            "BiquadFilterNode": false,
            "Blob": false,
            "BlobEvent": false,
            "blur": false,
            "BroadcastChannel": false,
            "btoa": false,
            "BudgetService": false,
            "ByteLengthQueuingStrategy": false,
            "Cache": false,
            "caches": false,
            "CacheStorage": false,
            "cancelAnimationFrame": false,
            "cancelIdleCallback": false,
            "CanvasCaptureMediaStreamTrack": false,
            "CanvasGradient": false,
            "CanvasPattern": false,
            "CanvasRenderingContext2D": false,
            "ChannelMergerNode": false,
            "ChannelSplitterNode": false,
            "CharacterData": false,
            "clearInterval": false,
            "clearTimeout": false,
            "clientInformation": false,
            "ClipboardEvent": false,
            "ClipboardItem": false,
            "close": false,
            "closed": false,
            "CloseEvent": false,
            "Comment": false,
            "CompositionEvent": false,
            "confirm": false,
            "console": false,
            "ConstantSourceNode": false,
            "ConvolverNode": false,
            "CountQueuingStrategy": false,
            "createImageBitmap": false,
            "Credential": false,
            "CredentialsContainer": false,
            "crypto": false,
            "Crypto": false,
            "CryptoKey": false,
            "CSS": false,
            "CSSConditionRule": false,
            "CSSFontFaceRule": false,
            "CSSGroupingRule": false,
            "CSSImportRule": false,
            "CSSKeyframeRule": false,
            "CSSKeyframesRule": false,
            "CSSMatrixComponent": false,
            "CSSMediaRule": false,
            "CSSNamespaceRule": false,
            "CSSPageRule": false,
            "CSSPerspective": false,
            "CSSRotate": false,
            "CSSRule": false,
            "CSSRuleList": false,
            "CSSScale": false,
            "CSSSkew": false,
            "CSSSkewX": false,
            "CSSSkewY": false,
            "CSSStyleDeclaration": false,
            "CSSStyleRule": false,
            "CSSStyleSheet": false,
            "CSSSupportsRule": false,
            "CSSTransformValue": false,
            "CSSTranslate": false,
            "CustomElementRegistry": false,
            "customElements": false,
            "CustomEvent": false,
            "DataTransfer": false,
            "DataTransferItem": false,
            "DataTransferItemList": false,
            "defaultstatus": false,
            "defaultStatus": false,
            "DelayNode": false,
            "DeviceMotionEvent": false,
            "DeviceOrientationEvent": false,
            "devicePixelRatio": false,
            "dispatchEvent": false,
            "document": false,
            "Document": false,
            "DocumentFragment": false,
            "DocumentType": false,
            "DOMError": false,
            "DOMException": false,
            "DOMImplementation": false,
            "DOMMatrix": false,
            "DOMMatrixReadOnly": false,
            "DOMParser": false,
            "DOMPoint": false,
            "DOMPointReadOnly": false,
            "DOMQuad": false,
            "DOMRect": false,
            "DOMRectList": false,
            "DOMRectReadOnly": false,
            "DOMStringList": false,
            "DOMStringMap": false,
            "DOMTokenList": false,
            "DragEvent": false,
            "DynamicsCompressorNode": false,
            "Element": false,
            "ErrorEvent": false,
            "event": false,
            "Event": false,
            "EventSource": false,
            "EventTarget": false,
            "external": false,
            "fetch": false,
            "File": false,
            "FileList": false,
            "FileReader": false,
            "find": false,
            "focus": false,
            "FocusEvent": false,
            "FontFace": false,
            "FontFaceSetLoadEvent": false,
            "FormData": false,
            "FormDataEvent": false,
            "frameElement": false,
            "frames": false,
            "GainNode": false,
            "Gamepad": false,
            "GamepadButton": false,
            "GamepadEvent": false,
            "getComputedStyle": false,
            "getSelection": false,
            "HashChangeEvent": false,
            "Headers": false,
            "history": false,
            "History": false,
            "HTMLAllCollection": false,
            "HTMLAnchorElement": false,
            "HTMLAreaElement": false,
            "HTMLAudioElement": false,
            "HTMLBaseElement": false,
            "HTMLBodyElement": false,
            "HTMLBRElement": false,
            "HTMLButtonElement": false,
            "HTMLCanvasElement": false,
            "HTMLCollection": false,
            "HTMLContentElement": false,
            "HTMLDataElement": false,
            "HTMLDataListElement": false,
            "HTMLDetailsElement": false,
            "HTMLDialogElement": false,
            "HTMLDirectoryElement": false,
            "HTMLDivElement": false,
            "HTMLDListElement": false,
            "HTMLDocument": false,
            "HTMLElement": false,
            "HTMLEmbedElement": false,
            "HTMLFieldSetElement": false,
            "HTMLFontElement": false,
            "HTMLFormControlsCollection": false,
            "HTMLFormElement": false,
            "HTMLFrameElement": false,
            "HTMLFrameSetElement": false,
            "HTMLHeadElement": false,
            "HTMLHeadingElement": false,
            "HTMLHRElement": false,
            "HTMLHtmlElement": false,
            "HTMLIFrameElement": false,
            "HTMLImageElement": false,
            "HTMLInputElement": false,
            "HTMLLabelElement": false,
            "HTMLLegendElement": false,
            "HTMLLIElement": false,
            "HTMLLinkElement": false,
            "HTMLMapElement": false,
            "HTMLMarqueeElement": false,
            "HTMLMediaElement": false,
            "HTMLMenuElement": false,
            "HTMLMetaElement": false,
            "HTMLMeterElement": false,
            "HTMLModElement": false,
            "HTMLObjectElement": false,
            "HTMLOListElement": false,
            "HTMLOptGroupElement": false,
            "HTMLOptionElement": false,
            "HTMLOptionsCollection": false,
            "HTMLOutputElement": false,
            "HTMLParagraphElement": false,
            "HTMLParamElement": false,
            "HTMLPictureElement": false,
            "HTMLPreElement": false,
            "HTMLProgressElement": false,
            "HTMLQuoteElement": false,
            "HTMLScriptElement": false,
            "HTMLSelectElement": false,
            "HTMLShadowElement": false,
            "HTMLSlotElement": false,
            "HTMLSourceElement": false,
            "HTMLSpanElement": false,
            "HTMLStyleElement": false,
            "HTMLTableCaptionElement": false,
            "HTMLTableCellElement": false,
            "HTMLTableColElement": false,
            "HTMLTableElement": false,
            "HTMLTableRowElement": false,
            "HTMLTableSectionElement": false,
            "HTMLTemplateElement": false,
            "HTMLTextAreaElement": false,
            "HTMLTimeElement": false,
            "HTMLTitleElement": false,
            "HTMLTrackElement": false,
            "HTMLUListElement": false,
            "HTMLUnknownElement": false,
            "HTMLVideoElement": false,
            "IDBCursor": false,
            "IDBCursorWithValue": false,
            "IDBDatabase": false,
            "IDBFactory": false,
            "IDBIndex": false,
            "IDBKeyRange": false,
            "IDBObjectStore": false,
            "IDBOpenDBRequest": false,
            "IDBRequest": false,
            "IDBTransaction": false,
            "IDBVersionChangeEvent": false,
            "IdleDeadline": false,
            "IIRFilterNode": false,
            "Image": false,
            "ImageBitmap": false,
            "ImageBitmapRenderingContext": false,
            "ImageCapture": false,
            "ImageData": false,
            "indexedDB": false,
            "innerHeight": false,
            "innerWidth": false,
            "InputEvent": false,
            "IntersectionObserver": false,
            "IntersectionObserverEntry": false,
            "Intl": false,
            "isSecureContext": false,
            "KeyboardEvent": false,
            "KeyframeEffect": false,
            "KeyframeEffectReadOnly": false,
            "length": false,
            "localStorage": false,
            "location": true,
            "Location": false,
            "locationbar": false,
            "matchMedia": false,
            "MediaDeviceInfo": false,
            "MediaDevices": false,
            "MediaElementAudioSourceNode": false,
            "MediaEncryptedEvent": false,
            "MediaError": false,
            "MediaKeyMessageEvent": false,
            "MediaKeySession": false,
            "MediaKeyStatusMap": false,
            "MediaKeySystemAccess": false,
            "MediaList": false,
            "MediaMetadata": false,
            "MediaQueryList": false,
            "MediaQueryListEvent": false,
            "MediaRecorder": false,
            "MediaSettingsRange": false,
            "MediaSource": false,
            "MediaStream": false,
            "MediaStreamAudioDestinationNode": false,
            "MediaStreamAudioSourceNode": false,
            "MediaStreamEvent": false,
            "MediaStreamTrack": false,
            "MediaStreamTrackEvent": false,
            "menubar": false,
            "MessageChannel": false,
            "MessageEvent": false,
            "MessagePort": false,
            "MIDIAccess": false,
            "MIDIConnectionEvent": false,
            "MIDIInput": false,
            "MIDIInputMap": false,
            "MIDIMessageEvent": false,
            "MIDIOutput": false,
            "MIDIOutputMap": false,
            "MIDIPort": false,
            "MimeType": false,
            "MimeTypeArray": false,
            "MouseEvent": false,
            "moveBy": false,
            "moveTo": false,
            "MutationEvent": false,
            "MutationObserver": false,
            "MutationRecord": false,
            "name": false,
            "NamedNodeMap": false,
            "NavigationPreloadManager": false,
            "navigator": false,
            "Navigator": false,
            "NavigatorUAData": false,
            "NetworkInformation": false,
            "Node": false,
            "NodeFilter": false,
            "NodeIterator": false,
            "NodeList": false,
            "Notification": false,
            "OfflineAudioCompletionEvent": false,
            "OfflineAudioContext": false,
            "offscreenBuffering": false,
            "OffscreenCanvas": true,
            "OffscreenCanvasRenderingContext2D": false,
            "onabort": true,
            "onafterprint": true,
            "onanimationend": true,
            "onanimationiteration": true,
            "onanimationstart": true,
            "onappinstalled": true,
            "onauxclick": true,
            "onbeforeinstallprompt": true,
            "onbeforeprint": true,
            "onbeforeunload": true,
            "onblur": true,
            "oncancel": true,
            "oncanplay": true,
            "oncanplaythrough": true,
            "onchange": true,
            "onclick": true,
            "onclose": true,
            "oncontextmenu": true,
            "oncuechange": true,
            "ondblclick": true,
            "ondevicemotion": true,
            "ondeviceorientation": true,
            "ondeviceorientationabsolute": true,
            "ondrag": true,
            "ondragend": true,
            "ondragenter": true,
            "ondragleave": true,
            "ondragover": true,
            "ondragstart": true,
            "ondrop": true,
            "ondurationchange": true,
            "onemptied": true,
            "onended": true,
            "onerror": true,
            "onfocus": true,
            "ongotpointercapture": true,
            "onhashchange": true,
            "oninput": true,
            "oninvalid": true,
            "onkeydown": true,
            "onkeypress": true,
            "onkeyup": true,
            "onlanguagechange": true,
            "onload": true,
            "onloadeddata": true,
            "onloadedmetadata": true,
            "onloadstart": true,
            "onlostpointercapture": true,
            "onmessage": true,
            "onmessageerror": true,
            "onmousedown": true,
            "onmouseenter": true,
            "onmouseleave": true,
            "onmousemove": true,
            "onmouseout": true,
            "onmouseover": true,
            "onmouseup": true,
            "onmousewheel": true,
            "onoffline": true,
            "ononline": true,
            "onpagehide": true,
            "onpageshow": true,
            "onpause": true,
            "onplay": true,
            "onplaying": true,
            "onpointercancel": true,
            "onpointerdown": true,
            "onpointerenter": true,
            "onpointerleave": true,
            "onpointermove": true,
            "onpointerout": true,
            "onpointerover": true,
            "onpointerup": true,
            "onpopstate": true,
            "onprogress": true,
            "onratechange": true,
            "onrejectionhandled": true,
            "onreset": true,
            "onresize": true,
            "onscroll": true,
            "onsearch": true,
            "onseeked": true,
            "onseeking": true,
            "onselect": true,
            "onstalled": true,
            "onstorage": true,
            "onsubmit": true,
            "onsuspend": true,
            "ontimeupdate": true,
            "ontoggle": true,
            "ontransitionend": true,
            "onunhandledrejection": true,
            "onunload": true,
            "onvolumechange": true,
            "onwaiting": true,
            "onwheel": true,
            "open": false,
            "openDatabase": false,
            "opener": false,
            "Option": false,
            "origin": false,
            "OscillatorNode": false,
            "outerHeight": false,
            "outerWidth": false,
            "OverconstrainedError": false,
            "PageTransitionEvent": false,
            "pageXOffset": false,
            "pageYOffset": false,
            "PannerNode": false,
            "parent": false,
            "Path2D": false,
            "PaymentAddress": false,
            "PaymentRequest": false,
            "PaymentRequestUpdateEvent": false,
            "PaymentResponse": false,
            "performance": false,
            "Performance": false,
            "PerformanceEntry": false,
            "PerformanceLongTaskTiming": false,
            "PerformanceMark": false,
            "PerformanceMeasure": false,
            "PerformanceNavigation": false,
            "PerformanceNavigationTiming": false,
            "PerformanceObserver": false,
            "PerformanceObserverEntryList": false,
            "PerformancePaintTiming": false,
            "PerformanceResourceTiming": false,
            "PerformanceTiming": false,
            "PeriodicWave": false,
            "Permissions": false,
            "PermissionStatus": false,
            "personalbar": false,
            "PhotoCapabilities": false,
            "Plugin": false,
            "PluginArray": false,
            "PointerEvent": false,
            "PopStateEvent": false,
            "postMessage": false,
            "Presentation": false,
            "PresentationAvailability": false,
            "PresentationConnection": false,
            "PresentationConnectionAvailableEvent": false,
            "PresentationConnectionCloseEvent": false,
            "PresentationConnectionList": false,
            "PresentationReceiver": false,
            "PresentationRequest": false,
            "print": false,
            "ProcessingInstruction": false,
            "ProgressEvent": false,
            "PromiseRejectionEvent": false,
            "prompt": false,
            "PushManager": false,
            "PushSubscription": false,
            "PushSubscriptionOptions": false,
            "queueMicrotask": false,
            "RadioNodeList": false,
            "Range": false,
            "ReadableStream": false,
            "registerProcessor": false,
            "RemotePlayback": false,
            "removeEventListener": false,
            "reportError": false,
            "Request": false,
            "requestAnimationFrame": false,
            "requestIdleCallback": false,
            "resizeBy": false,
            "ResizeObserver": false,
            "ResizeObserverEntry": false,
            "resizeTo": false,
            "Response": false,
            "RTCCertificate": false,
            "RTCDataChannel": false,
            "RTCDataChannelEvent": false,
            "RTCDtlsTransport": false,
            "RTCIceCandidate": false,
            "RTCIceGatherer": false,
            "RTCIceTransport": false,
            "RTCPeerConnection": false,
            "RTCPeerConnectionIceEvent": false,
            "RTCRtpContributingSource": false,
            "RTCRtpReceiver": false,
            "RTCRtpSender": false,
            "RTCSctpTransport": false,
            "RTCSessionDescription": false,
            "RTCStatsReport": false,
            "RTCTrackEvent": false,
            "screen": false,
            "Screen": false,
            "screenLeft": false,
            "ScreenOrientation": false,
            "screenTop": false,
            "screenX": false,
            "screenY": false,
            "ScriptProcessorNode": false,
            "scroll": false,
            "scrollbars": false,
            "scrollBy": false,
            "scrollTo": false,
            "scrollX": false,
            "scrollY": false,
            "SecurityPolicyViolationEvent": false,
            "Selection": false,
            "self": false,
            "ServiceWorker": false,
            "ServiceWorkerContainer": false,
            "ServiceWorkerRegistration": false,
            "sessionStorage": false,
            "setInterval": false,
            "setTimeout": false,
            "ShadowRoot": false,
            "SharedWorker": false,
            "SourceBuffer": false,
            "SourceBufferList": false,
            "speechSynthesis": false,
            "SpeechSynthesisEvent": false,
            "SpeechSynthesisUtterance": false,
            "StaticRange": false,
            "status": false,
            "statusbar": false,
            "StereoPannerNode": false,
            "stop": false,
            "Storage": false,
            "StorageEvent": false,
            "StorageManager": false,
            "structuredClone": false,
            "styleMedia": false,
            "StyleSheet": false,
            "StyleSheetList": false,
            "SubmitEvent": false,
            "SubtleCrypto": false,
            "SVGAElement": false,
            "SVGAngle": false,
            "SVGAnimatedAngle": false,
            "SVGAnimatedBoolean": false,
            "SVGAnimatedEnumeration": false,
            "SVGAnimatedInteger": false,
            "SVGAnimatedLength": false,
            "SVGAnimatedLengthList": false,
            "SVGAnimatedNumber": false,
            "SVGAnimatedNumberList": false,
            "SVGAnimatedPreserveAspectRatio": false,
            "SVGAnimatedRect": false,
            "SVGAnimatedString": false,
            "SVGAnimatedTransformList": false,
            "SVGAnimateElement": false,
            "SVGAnimateMotionElement": false,
            "SVGAnimateTransformElement": false,
            "SVGAnimationElement": false,
            "SVGCircleElement": false,
            "SVGClipPathElement": false,
            "SVGComponentTransferFunctionElement": false,
            "SVGDefsElement": false,
            "SVGDescElement": false,
            "SVGDiscardElement": false,
            "SVGElement": false,
            "SVGEllipseElement": false,
            "SVGFEBlendElement": false,
            "SVGFEColorMatrixElement": false,
            "SVGFEComponentTransferElement": false,
            "SVGFECompositeElement": false,
            "SVGFEConvolveMatrixElement": false,
            "SVGFEDiffuseLightingElement": false,
            "SVGFEDisplacementMapElement": false,
            "SVGFEDistantLightElement": false,
            "SVGFEDropShadowElement": false,
            "SVGFEFloodElement": false,
            "SVGFEFuncAElement": false,
            "SVGFEFuncBElement": false,
            "SVGFEFuncGElement": false,
            "SVGFEFuncRElement": false,
            "SVGFEGaussianBlurElement": false,
            "SVGFEImageElement": false,
            "SVGFEMergeElement": false,
            "SVGFEMergeNodeElement": false,
            "SVGFEMorphologyElement": false,
            "SVGFEOffsetElement": false,
            "SVGFEPointLightElement": false,
            "SVGFESpecularLightingElement": false,
            "SVGFESpotLightElement": false,
            "SVGFETileElement": false,
            "SVGFETurbulenceElement": false,
            "SVGFilterElement": false,
            "SVGForeignObjectElement": false,
            "SVGGElement": false,
            "SVGGeometryElement": false,
            "SVGGradientElement": false,
            "SVGGraphicsElement": false,
            "SVGImageElement": false,
            "SVGLength": false,
            "SVGLengthList": false,
            "SVGLinearGradientElement": false,
            "SVGLineElement": false,
            "SVGMarkerElement": false,
            "SVGMaskElement": false,
            "SVGMatrix": false,
            "SVGMetadataElement": false,
            "SVGMPathElement": false,
            "SVGNumber": false,
            "SVGNumberList": false,
            "SVGPathElement": false,
            "SVGPatternElement": false,
            "SVGPoint": false,
            "SVGPointList": false,
            "SVGPolygonElement": false,
            "SVGPolylineElement": false,
            "SVGPreserveAspectRatio": false,
            "SVGRadialGradientElement": false,
            "SVGRect": false,
            "SVGRectElement": false,
            "SVGScriptElement": false,
            "SVGSetElement": false,
            "SVGStopElement": false,
            "SVGStringList": false,
            "SVGStyleElement": false,
            "SVGSVGElement": false,
            "SVGSwitchElement": false,
            "SVGSymbolElement": false,
            "SVGTextContentElement": false,
            "SVGTextElement": false,
            "SVGTextPathElement": false,
            "SVGTextPositioningElement": false,
            "SVGTitleElement": false,
            "SVGTransform": false,
            "SVGTransformList": false,
            "SVGTSpanElement": false,
            "SVGUnitTypes": false,
            "SVGUseElement": false,
            "SVGViewElement": false,
            "TaskAttributionTiming": false,
            "Text": false,
            "TextDecoder": false,
            "TextEncoder": false,
            "TextEvent": false,
            "TextMetrics": false,
            "TextTrack": false,
            "TextTrackCue": false,
            "TextTrackCueList": false,
            "TextTrackList": false,
            "TimeRanges": false,
            "toolbar": false,
            "top": false,
            "Touch": false,
            "TouchEvent": false,
            "TouchList": false,
            "TrackEvent": false,
            "TransformStream": false,
            "TransitionEvent": false,
            "TreeWalker": false,
            "UIEvent": false,
            "URL": false,
            "URLSearchParams": false,
            "ValidityState": false,
            "visualViewport": false,
            "VisualViewport": false,
            "VTTCue": false,
            "WaveShaperNode": false,
            "WebAssembly": false,
            "WebGL2RenderingContext": false,
            "WebGLActiveInfo": false,
            "WebGLBuffer": false,
            "WebGLContextEvent": false,
            "WebGLFramebuffer": false,
            "WebGLProgram": false,
            "WebGLQuery": false,
            "WebGLRenderbuffer": false,
            "WebGLRenderingContext": false,
            "WebGLSampler": false,
            "WebGLShader": false,
            "WebGLShaderPrecisionFormat": false,
            "WebGLSync": false,
            "WebGLTexture": false,
            "WebGLTransformFeedback": false,
            "WebGLUniformLocation": false,
            "WebGLVertexArrayObject": false,
            "WebSocket": false,
            "WheelEvent": false,
            "window": false,
            "Window": false,
            "Worker": false,
            "WritableStream": false,
            "XMLDocument": false,
            "XMLHttpRequest": false,
            "XMLHttpRequestEventTarget": false,
            "XMLHttpRequestUpload": false,
            "XMLSerializer": false,
            "XPathEvaluator": false,
            "XPathExpression": false,
            "XPathResult": false,
            "XSLTProcessor": false
        },
        "worker": {
            "addEventListener": false,
            "applicationCache": false,
            "atob": false,
            "Blob": false,
            "BroadcastChannel": false,
            "btoa": false,
            "Cache": false,
            "caches": false,
            "clearInterval": false,
            "clearTimeout": false,
            "close": true,
            "console": false,
            "CustomEvent": false,
            "ErrorEvent": false,
            "Event": false,
            "fetch": false,
            "FileReaderSync": false,
            "FormData": false,
            "Headers": false,
            "IDBCursor": false,
            "IDBCursorWithValue": false,
            "IDBDatabase": false,
            "IDBFactory": false,
            "IDBIndex": false,
            "IDBKeyRange": false,
            "IDBObjectStore": false,
            "IDBOpenDBRequest": false,
            "IDBRequest": false,
            "IDBTransaction": false,
            "IDBVersionChangeEvent": false,
            "ImageData": false,
            "importScripts": true,
            "indexedDB": false,
            "location": false,
            "MessageChannel": false,
            "MessageEvent": false,
            "MessagePort": false,
            "name": false,
            "navigator": false,
            "Notification": false,
            "onclose": true,
            "onconnect": true,
            "onerror": true,
            "onlanguagechange": true,
            "onmessage": true,
            "onoffline": true,
            "ononline": true,
            "onrejectionhandled": true,
            "onunhandledrejection": true,
            "performance": false,
            "Performance": false,
            "PerformanceEntry": false,
            "PerformanceMark": false,
            "PerformanceMeasure": false,
            "PerformanceNavigation": false,
            "PerformanceResourceTiming": false,
            "PerformanceTiming": false,
            "postMessage": true,
            "Promise": false,
            "queueMicrotask": false,
            "removeEventListener": false,
            "reportError": false,
            "Request": false,
            "Response": false,
            "self": true,
            "ServiceWorkerRegistration": false,
            "setInterval": false,
            "setTimeout": false,
            "TextDecoder": false,
            "TextEncoder": false,
            "URL": false,
            "URLSearchParams": false,
            "WebSocket": false,
            "Worker": false,
            "WorkerGlobalScope": false,
            "XMLHttpRequest": false
        },
        "node": {
            "__dirname": false,
            "__filename": false,
            "AbortController": false,
            "AbortSignal": false,
            "atob": false,
            "btoa": false,
            "Buffer": false,
            "clearImmediate": false,
            "clearInterval": false,
            "clearTimeout": false,
            "console": false,
            "DOMException": false,
            "Event": false,
            "EventTarget": false,
            "exports": true,
            "fetch": false,
            "FormData": false,
            "global": false,
            "Headers": false,
            "Intl": false,
            "MessageChannel": false,
            "MessageEvent": false,
            "MessagePort": false,
            "module": false,
            "performance": false,
            "process": false,
            "queueMicrotask": false,
            "Request": false,
            "require": false,
            "Response": false,
            "setImmediate": false,
            "setInterval": false,
            "setTimeout": false,
            "structuredClone": false,
            "TextDecoder": false,
            "TextEncoder": false,
            "URL": false,
            "URLSearchParams": false
        },
        "nodeBuiltin": {
            "AbortController": false,
            "AbortSignal": false,
            "atob": false,
            "btoa": false,
            "Buffer": false,
            "clearImmediate": false,
            "clearInterval": false,
            "clearTimeout": false,
            "console": false,
            "DOMException": false,
            "Event": false,
            "EventTarget": false,
            "fetch": false,
            "FormData": false,
            "global": false,
            "Headers": false,
            "Intl": false,
            "MessageChannel": false,
            "MessageEvent": false,
            "MessagePort": false,
            "performance": false,
            "process": false,
            "queueMicrotask": false,
            "Request": false,
            "Response": false,
            "setImmediate": false,
            "setInterval": false,
            "setTimeout": false,
            "structuredClone": false,
            "TextDecoder": false,
            "TextEncoder": false,
            "URL": false,
            "URLSearchParams": false
        },
        "commonjs": {
            "exports": true,
            "global": false,
            "module": false,
            "require": false
        },
        "amd": {
            "define": false,
            "require": false
        },
        "mocha": {
            "after": false,
            "afterEach": false,
            "before": false,
            "beforeEach": false,
            "context": false,
            "describe": false,
            "it": false,
            "mocha": false,
            "run": false,
            "setup": false,
            "specify": false,
            "suite": false,
            "suiteSetup": false,
            "suiteTeardown": false,
            "teardown": false,
            "test": false,
            "xcontext": false,
            "xdescribe": false,
            "xit": false,
            "xspecify": false
        },
        "jasmine": {
            "afterAll": false,
            "afterEach": false,
            "beforeAll": false,
            "beforeEach": false,
            "describe": false,
            "expect": false,
            "expectAsync": false,
            "fail": false,
            "fdescribe": false,
            "fit": false,
            "it": false,
            "jasmine": false,
            "pending": false,
            "runs": false,
            "spyOn": false,
            "spyOnAllFunctions": false,
            "spyOnProperty": false,
            "waits": false,
            "waitsFor": false,
            "xdescribe": false,
            "xit": false
        },
        "jest": {
            "afterAll": false,
            "afterEach": false,
            "beforeAll": false,
            "beforeEach": false,
            "describe": false,
            "expect": false,
            "fdescribe": false,
            "fit": false,
            "it": false,
            "jest": false,
            "pit": false,
            "require": false,
            "test": false,
            "xdescribe": false,
            "xit": false,
            "xtest": false
        },
        "qunit": {
            "asyncTest": false,
            "deepEqual": false,
            "equal": false,
            "expect": false,
            "module": false,
            "notDeepEqual": false,
            "notEqual": false,
            "notOk": false,
            "notPropEqual": false,
            "notStrictEqual": false,
            "ok": false,
            "propEqual": false,
            "QUnit": false,
            "raises": false,
            "start": false,
            "stop": false,
            "strictEqual": false,
            "test": false,
            "throws": false
        },
        "phantomjs": {
            "console": true,
            "exports": true,
            "phantom": true,
            "require": true,
            "WebPage": true
        },
        "couch": {
            "emit": false,
            "exports": false,
            "getRow": false,
            "log": false,
            "module": false,
            "provides": false,
            "require": false,
            "respond": false,
            "send": false,
            "start": false,
            "sum": false
        },
        "rhino": {
            "defineClass": false,
            "deserialize": false,
            "gc": false,
            "help": false,
            "importClass": false,
            "importPackage": false,
            "java": false,
            "load": false,
            "loadClass": false,
            "Packages": false,
            "print": false,
            "quit": false,
            "readFile": false,
            "readUrl": false,
            "runCommand": false,
            "seal": false,
            "serialize": false,
            "spawn": false,
            "sync": false,
            "toint32": false,
            "version": false
        },
        "nashorn": {
            "__DIR__": false,
            "__FILE__": false,
            "__LINE__": false,
            "com": false,
            "edu": false,
            "exit": false,
            "java": false,
            "Java": false,
            "javafx": false,
            "JavaImporter": false,
            "javax": false,
            "JSAdapter": false,
            "load": false,
            "loadWithNewGlobal": false,
            "org": false,
            "Packages": false,
            "print": false,
            "quit": false
        },
        "wsh": {
            "ActiveXObject": false,
            "CollectGarbage": false,
            "Debug": false,
            "Enumerator": false,
            "GetObject": false,
            "RuntimeObject": false,
            "ScriptEngine": false,
            "ScriptEngineBuildVersion": false,
            "ScriptEngineMajorVersion": false,
            "ScriptEngineMinorVersion": false,
            "VBArray": false,
            "WScript": false,
            "WSH": false
        },
        "jquery": {
            "$": false,
            "jQuery": false
        },
        "yui": {
            "YAHOO": false,
            "YAHOO_config": false,
            "YUI": false,
            "YUI_config": false
        },
        "shelljs": {
            "cat": false,
            "cd": false,
            "chmod": false,
            "config": false,
            "cp": false,
            "dirs": false,
            "echo": false,
            "env": false,
            "error": false,
            "exec": false,
            "exit": false,
            "find": false,
            "grep": false,
            "ln": false,
            "ls": false,
            "mkdir": false,
            "mv": false,
            "popd": false,
            "pushd": false,
            "pwd": false,
            "rm": false,
            "sed": false,
            "set": false,
            "target": false,
            "tempdir": false,
            "test": false,
            "touch": false,
            "which": false
        },
        "prototypejs": {
            "$": false,
            "$$": false,
            "$A": false,
            "$break": false,
            "$continue": false,
            "$F": false,
            "$H": false,
            "$R": false,
            "$w": false,
            "Abstract": false,
            "Ajax": false,
            "Autocompleter": false,
            "Builder": false,
            "Class": false,
            "Control": false,
            "Draggable": false,
            "Draggables": false,
            "Droppables": false,
            "Effect": false,
            "Element": false,
            "Enumerable": false,
            "Event": false,
            "Field": false,
            "Form": false,
            "Hash": false,
            "Insertion": false,
            "ObjectRange": false,
            "PeriodicalExecuter": false,
            "Position": false,
            "Prototype": false,
            "Scriptaculous": false,
            "Selector": false,
            "Sortable": false,
            "SortableObserver": false,
            "Sound": false,
            "Template": false,
            "Toggle": false,
            "Try": false
        },
        "meteor": {
            "$": false,
            "Accounts": false,
            "AccountsClient": false,
            "AccountsCommon": false,
            "AccountsServer": false,
            "App": false,
            "Assets": false,
            "Blaze": false,
            "check": false,
            "Cordova": false,
            "DDP": false,
            "DDPRateLimiter": false,
            "DDPServer": false,
            "Deps": false,
            "EJSON": false,
            "Email": false,
            "HTTP": false,
            "Log": false,
            "Match": false,
            "Meteor": false,
            "Mongo": false,
            "MongoInternals": false,
            "Npm": false,
            "Package": false,
            "Plugin": false,
            "process": false,
            "Random": false,
            "ReactiveDict": false,
            "ReactiveVar": false,
            "Router": false,
            "ServiceConfiguration": false,
            "Session": false,
            "share": false,
            "Spacebars": false,
            "Template": false,
            "Tinytest": false,
            "Tracker": false,
            "UI": false,
            "Utils": false,
            "WebApp": false,
            "WebAppInternals": false
        },
        "mongo": {
            "_isWindows": false,
            "_rand": false,
            "BulkWriteResult": false,
            "cat": false,
            "cd": false,
            "connect": false,
            "db": false,
            "getHostName": false,
            "getMemInfo": false,
            "hostname": false,
            "ISODate": false,
            "listFiles": false,
            "load": false,
            "ls": false,
            "md5sumFile": false,
            "mkdir": false,
            "Mongo": false,
            "NumberInt": false,
            "NumberLong": false,
            "ObjectId": false,
            "PlanCache": false,
            "print": false,
            "printjson": false,
            "pwd": false,
            "quit": false,
            "removeFile": false,
            "rs": false,
            "sh": false,
            "UUID": false,
            "version": false,
            "WriteResult": false
        },
        "applescript": {
            "$": false,
            "Application": false,
            "Automation": false,
            "console": false,
            "delay": false,
            "Library": false,
            "ObjC": false,
            "ObjectSpecifier": false,
            "Path": false,
            "Progress": false,
            "Ref": false
        },
        "serviceworker": {
            "addEventListener": false,
            "applicationCache": false,
            "atob": false,
            "Blob": false,
            "BroadcastChannel": false,
            "btoa": false,
            "Cache": false,
            "caches": false,
            "CacheStorage": false,
            "clearInterval": false,
            "clearTimeout": false,
            "Client": false,
            "clients": false,
            "Clients": false,
            "close": true,
            "console": false,
            "CustomEvent": false,
            "ErrorEvent": false,
            "Event": false,
            "ExtendableEvent": false,
            "ExtendableMessageEvent": false,
            "fetch": false,
            "FetchEvent": false,
            "FileReaderSync": false,
            "FormData": false,
            "Headers": false,
            "IDBCursor": false,
            "IDBCursorWithValue": false,
            "IDBDatabase": false,
            "IDBFactory": false,
            "IDBIndex": false,
            "IDBKeyRange": false,
            "IDBObjectStore": false,
            "IDBOpenDBRequest": false,
            "IDBRequest": false,
            "IDBTransaction": false,
            "IDBVersionChangeEvent": false,
            "ImageData": false,
            "importScripts": false,
            "indexedDB": false,
            "location": false,
            "MessageChannel": false,
            "MessageEvent": false,
            "MessagePort": false,
            "name": false,
            "navigator": false,
            "Notification": false,
            "onclose": true,
            "onconnect": true,
            "onerror": true,
            "onfetch": true,
            "oninstall": true,
            "onlanguagechange": true,
            "onmessage": true,
            "onmessageerror": true,
            "onnotificationclick": true,
            "onnotificationclose": true,
            "onoffline": true,
            "ononline": true,
            "onpush": true,
            "onpushsubscriptionchange": true,
            "onrejectionhandled": true,
            "onsync": true,
            "onunhandledrejection": true,
            "performance": false,
            "Performance": false,
            "PerformanceEntry": false,
            "PerformanceMark": false,
            "PerformanceMeasure": false,
            "PerformanceNavigation": false,
            "PerformanceResourceTiming": false,
            "PerformanceTiming": false,
            "postMessage": true,
            "Promise": false,
            "queueMicrotask": false,
            "registration": false,
            "removeEventListener": false,
            "Request": false,
            "Response": false,
            "self": false,
            "ServiceWorker": false,
            "ServiceWorkerContainer": false,
            "ServiceWorkerGlobalScope": false,
            "ServiceWorkerMessageEvent": false,
            "ServiceWorkerRegistration": false,
            "setInterval": false,
            "setTimeout": false,
            "skipWaiting": false,
            "TextDecoder": false,
            "TextEncoder": false,
            "URL": false,
            "URLSearchParams": false,
            "WebSocket": false,
            "WindowClient": false,
            "Worker": false,
            "WorkerGlobalScope": false,
            "XMLHttpRequest": false
        },
        "atomtest": {
            "advanceClock": false,
            "atom": false,
            "fakeClearInterval": false,
            "fakeClearTimeout": false,
            "fakeSetInterval": false,
            "fakeSetTimeout": false,
            "resetTimeouts": false,
            "waitsForPromise": false
        },
        "embertest": {
            "andThen": false,
            "click": false,
            "currentPath": false,
            "currentRouteName": false,
            "currentURL": false,
            "fillIn": false,
            "find": false,
            "findAll": false,
            "findWithAssert": false,
            "keyEvent": false,
            "pauseTest": false,
            "resumeTest": false,
            "triggerEvent": false,
            "visit": false,
            "wait": false
        },
        "protractor": {
            "$": false,
            "$$": false,
            "browser": false,
            "by": false,
            "By": false,
            "DartObject": false,
            "element": false,
            "protractor": false
        },
        "shared-node-browser": {
            "AbortController": false,
            "AbortSignal": false,
            "atob": false,
            "btoa": false,
            "clearInterval": false,
            "clearTimeout": false,
            "console": false,
            "DOMException": false,
            "Event": false,
            "EventTarget": false,
            "fetch": false,
            "FormData": false,
            "Headers": false,
            "Intl": false,
            "MessageChannel": false,
            "MessageEvent": false,
            "MessagePort": false,
            "performance": false,
            "queueMicrotask": false,
            "Request": false,
            "Response": false,
            "setInterval": false,
            "setTimeout": false,
            "structuredClone": false,
            "TextDecoder": false,
            "TextEncoder": false,
            "URL": false,
            "URLSearchParams": false
        },
        "webextensions": {
            "browser": false,
            "chrome": false,
            "opr": false
        },
        "greasemonkey": {
            "cloneInto": false,
            "createObjectIn": false,
            "exportFunction": false,
            "GM": false,
            "GM_addElement": false,
            "GM_addStyle": false,
            "GM_addValueChangeListener": false,
            "GM_deleteValue": false,
            "GM_download": false,
            "GM_getResourceText": false,
            "GM_getResourceURL": false,
            "GM_getTab": false,
            "GM_getTabs": false,
            "GM_getValue": false,
            "GM_info": false,
            "GM_listValues": false,
            "GM_log": false,
            "GM_notification": false,
            "GM_openInTab": false,
            "GM_registerMenuCommand": false,
            "GM_removeValueChangeListener": false,
            "GM_saveTab": false,
            "GM_setClipboard": false,
            "GM_setValue": false,
            "GM_unregisterMenuCommand": false,
            "GM_xmlhttpRequest": false,
            "unsafeWindow": false
        },
        "devtools": {
            "$": false,
            "$_": false,
            "$$": false,
            "$0": false,
            "$1": false,
            "$2": false,
            "$3": false,
            "$4": false,
            "$x": false,
            "chrome": false,
            "clear": false,
            "copy": false,
            "debug": false,
            "dir": false,
            "dirxml": false,
            "getEventListeners": false,
            "inspect": false,
            "keys": false,
            "monitor": false,
            "monitorEvents": false,
            "profile": false,
            "profileEnd": false,
            "queryObjects": false,
            "table": false,
            "undebug": false,
            "unmonitor": false,
            "unmonitorEvents": false,
            "values": false
        }
    };
    module.exports = json;
},
/* eslint/lib/cli-engine/file-enumerator.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview `FileEnumerator` class.
     *
     * `FileEnumerator` class has two responsibilities:
     *
     * 1. Find target files by processing glob patterns.
     * 2. Tie each target file and appropriate configuration.
     *
     * It provides a method:
     *
     * - `iterateFiles(patterns)`
     *     Iterate files which are matched by given patterns together with the
     *     corresponded configuration. This is for `CLIEngine#executeOnFiles()`.
     *     While iterating files, it loads the configuration file of each directory
     *     before iterate files on the directory, so we can use the configuration
     *     files to determine target files.
     *
     * @example
     * const enumerator = new FileEnumerator();
     * const linter = new Linter();
     *
     * for (const { config, filePath } of enumerator.iterateFiles(["*.js"])) {
     *     const code = fs.readFileSync(filePath, "utf8");
     *     const messages = linter.verify(code, config, filePath);
     *
     *     console.log(messages);
     * }
     *
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const fs = require("fs");
    const path = require("path");
    const getGlobParent = require(282) /* glob-parent */;
    const isGlob = require(283) /* is-glob */;
    const escapeRegExp = require(285) /* escape-string-regexp */;
    const { Minimatch } = require(229) /* minimatch */;
    const { Legacy: { IgnorePattern, CascadingConfigArrayFactory } } = require(222) /* @eslint/eslintrc */;
    const debug = require(72) /* debug */("eslint:file-enumerator");
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const minimatchOpts = { dot: true, matchBase: true };
    const dotfilesPattern = /(?:(?:^\.)|(?:[/\\]\.))[^/\\.].*/u;
    const NONE = 0;
    const IGNORED_SILENTLY = 1;
    const IGNORED = 2;
    // For VSCode intellisense
    /** @typedef {ReturnType<CascadingConfigArrayFactory.getConfigArrayForFile>} ConfigArray */
    /**
     * @typedef {Object} FileEnumeratorOptions
     * @property {CascadingConfigArrayFactory} [configArrayFactory] The factory for config arrays.
     * @property {string} [cwd] The base directory to start lookup.
     * @property {string[]} [extensions] The extensions to match files for directory patterns.
     * @property {boolean} [globInputPaths] Set to false to skip glob resolution of input file paths to lint (default: true). If false, each input file paths is assumed to be a non-glob path to an existing file.
     * @property {boolean} [ignore] The flag to check ignored files.
     * @property {string[]} [rulePaths] The value of `--rulesdir` option.
     */
    /**
     * @typedef {Object} FileAndConfig
     * @property {string} filePath The path to a target file.
     * @property {ConfigArray} config The config entries of that file.
     * @property {boolean} ignored If `true` then this file should be ignored and warned because it was directly specified.
     */
    /**
     * @typedef {Object} FileEntry
     * @property {string} filePath The path to a target file.
     * @property {ConfigArray} config The config entries of that file.
     * @property {NONE|IGNORED_SILENTLY|IGNORED} flag The flag.
     * - `NONE` means the file is a target file.
     * - `IGNORED_SILENTLY` means the file should be ignored silently.
     * - `IGNORED` means the file should be ignored and warned because it was directly specified.
     */
    /**
     * @typedef {Object} FileEnumeratorInternalSlots
     * @property {CascadingConfigArrayFactory} configArrayFactory The factory for config arrays.
     * @property {string} cwd The base directory to start lookup.
     * @property {RegExp|null} extensionRegExp The RegExp to test if a string ends with specific file extensions.
     * @property {boolean} globInputPaths Set to false to skip glob resolution of input file paths to lint (default: true). If false, each input file paths is assumed to be a non-glob path to an existing file.
     * @property {boolean} ignoreFlag The flag to check ignored files.
     * @property {(filePath:string, dot:boolean) => boolean} defaultIgnores The default predicate function to ignore files.
     */
    /** @type {WeakMap<FileEnumerator, FileEnumeratorInternalSlots>} */
    const internalSlotsMap = new WeakMap();
    /**
     * Check if a string is a glob pattern or not.
     * @param {string} pattern A glob pattern.
     * @returns {boolean} `true` if the string is a glob pattern.
     */
    function isGlobPattern(pattern) {
        return isGlob(path.sep === "\\" ? pattern.replace(/\\/gu, "/") : pattern);
    }
    /**
     * Get stats of a given path.
     * @param {string} filePath The path to target file.
     * @throws {Error} As may be thrown by `fs.statSync`.
     * @returns {fs.Stats|null} The stats.
     * @private
     */
    function statSafeSync(filePath) {
        try {
            return fs.statSync(filePath);
        }
        catch (error) {
            /* c8 ignore next */
            if (error.code !== "ENOENT") {
                throw error;
            }
            return null;
        }
    }
    /**
     * Get filenames in a given path to a directory.
     * @param {string} directoryPath The path to target directory.
     * @throws {Error} As may be thrown by `fs.readdirSync`.
     * @returns {import("fs").Dirent[]} The filenames.
     * @private
     */
    function readdirSafeSync(directoryPath) {
        try {
            return fs.readdirSync(directoryPath, { withFileTypes: true });
        }
        catch (error) {
            /* c8 ignore next */
            if (error.code !== "ENOENT") {
                throw error;
            }
            return [];
        }
    }
    /**
     * Create a `RegExp` object to detect extensions.
     * @param {string[] | null} extensions The extensions to create.
     * @returns {RegExp | null} The created `RegExp` object or null.
     */
    function createExtensionRegExp(extensions) {
        if (extensions) {
            const normalizedExts = extensions.map(ext => escapeRegExp(ext.startsWith(".")
                ? ext.slice(1)
                : ext));
            return new RegExp(`.\\.(?:${normalizedExts.join("|")})$`, "u");
        }
        return null;
    }
    /**
     * The error type when no files match a glob.
     */
    class NoFilesFoundError extends Error {
        /**
         * @param {string} pattern The glob pattern which was not found.
         * @param {boolean} globDisabled If `true` then the pattern was a glob pattern, but glob was disabled.
         */
        constructor(pattern, globDisabled) {
            super(`No files matching '${pattern}' were found${globDisabled ? " (glob was disabled)" : ""}.`);
            this.messageTemplate = "file-not-found";
            this.messageData = { pattern, globDisabled };
        }
    }
    /**
     * The error type when there are files matched by a glob, but all of them have been ignored.
     */
    class AllFilesIgnoredError extends Error {
        /**
         * @param {string} pattern The glob pattern which was not found.
         */
        constructor(pattern) {
            super(`All files matched by '${pattern}' are ignored.`);
            this.messageTemplate = "all-files-ignored";
            this.messageData = { pattern };
        }
    }
    /**
     * This class provides the functionality that enumerates every file which is
     * matched by given glob patterns and that configuration.
     */
    class FileEnumerator {
        /**
         * Initialize this enumerator.
         * @param {FileEnumeratorOptions} options The options.
         */
        constructor({ cwd = process.cwd(), configArrayFactory = new CascadingConfigArrayFactory({
            cwd,
            getEslintRecommendedConfig: () => require(286) /* @eslint/js */.configs.recommended,
            getEslintAllConfig: () => require(286) /* @eslint/js */.configs.all
        }), extensions = null, globInputPaths = true, errorOnUnmatchedPattern = true, ignore = true } = {}) {
            internalSlotsMap.set(this, {
                configArrayFactory,
                cwd,
                defaultIgnores: IgnorePattern.createDefaultIgnore(cwd),
                extensionRegExp: createExtensionRegExp(extensions),
                globInputPaths,
                errorOnUnmatchedPattern,
                ignoreFlag: ignore
            });
        }
        /**
         * Check if a given file is target or not.
         * @param {string} filePath The path to a candidate file.
         * @param {ConfigArray} [providedConfig] Optional. The configuration for the file.
         * @returns {boolean} `true` if the file is a target.
         */
        isTargetPath(filePath, providedConfig) {
            const { configArrayFactory, extensionRegExp } = internalSlotsMap.get(this);
            // If `--ext` option is present, use it.
            if (extensionRegExp) {
                return extensionRegExp.test(filePath);
            }
            // `.js` file is target by default.
            if (filePath.endsWith(".js")) {
                return true;
            }
            // use `overrides[].files` to check additional targets.
            const config = providedConfig ||
                configArrayFactory.getConfigArrayForFile(filePath, { ignoreNotFoundError: true });
            return config.isAdditionalTargetPath(filePath);
        }
        /**
         * Iterate files which are matched by given glob patterns.
         * @param {string|string[]} patternOrPatterns The glob patterns to iterate files.
         * @throws {NoFilesFoundError|AllFilesIgnoredError} On an unmatched pattern.
         * @returns {IterableIterator<FileAndConfig>} The found files.
         */
        *iterateFiles(patternOrPatterns) {
            const { globInputPaths, errorOnUnmatchedPattern } = internalSlotsMap.get(this);
            const patterns = Array.isArray(patternOrPatterns)
                ? patternOrPatterns
                : [patternOrPatterns];
            debug("Start to iterate files: %o", patterns);
            // The set of paths to remove duplicate.
            const set = new Set();
            for (const pattern of patterns) {
                let foundRegardlessOfIgnored = false;
                let found = false;
                // Skip empty string.
                if (!pattern) {
                    continue;
                }
                // Iterate files of this pattern.
                for (const { config, filePath, flag } of this._iterateFiles(pattern)) {
                    foundRegardlessOfIgnored = true;
                    if (flag === IGNORED_SILENTLY) {
                        continue;
                    }
                    found = true;
                    // Remove duplicate paths while yielding paths.
                    if (!set.has(filePath)) {
                        set.add(filePath);
                        yield {
                            config,
                            filePath,
                            ignored: flag === IGNORED
                        };
                    }
                }
                // Raise an error if any files were not found.
                if (errorOnUnmatchedPattern) {
                    if (!foundRegardlessOfIgnored) {
                        throw new NoFilesFoundError(pattern, !globInputPaths && isGlob(pattern));
                    }
                    if (!found) {
                        throw new AllFilesIgnoredError(pattern);
                    }
                }
            }
            debug(`Complete iterating files: ${JSON.stringify(patterns)}`);
        }
        /**
         * Iterate files which are matched by a given glob pattern.
         * @param {string} pattern The glob pattern to iterate files.
         * @returns {IterableIterator<FileEntry>} The found files.
         */
        _iterateFiles(pattern) {
            const { cwd, globInputPaths } = internalSlotsMap.get(this);
            const absolutePath = path.resolve(cwd, pattern);
            const isDot = dotfilesPattern.test(pattern);
            const stat = statSafeSync(absolutePath);
            if (stat && stat.isDirectory()) {
                return this._iterateFilesWithDirectory(absolutePath, isDot);
            }
            if (stat && stat.isFile()) {
                return this._iterateFilesWithFile(absolutePath);
            }
            if (globInputPaths && isGlobPattern(pattern)) {
                return this._iterateFilesWithGlob(pattern, isDot);
            }
            return [];
        }
        /**
         * Iterate a file which is matched by a given path.
         * @param {string} filePath The path to the target file.
         * @returns {IterableIterator<FileEntry>} The found files.
         * @private
         */
        _iterateFilesWithFile(filePath) {
            debug(`File: ${filePath}`);
            const { configArrayFactory } = internalSlotsMap.get(this);
            const config = configArrayFactory.getConfigArrayForFile(filePath);
            const ignored = this._isIgnoredFile(filePath, { config, direct: true });
            const flag = ignored ? IGNORED : NONE;
            return [{ config, filePath, flag }];
        }
        /**
         * Iterate files in a given path.
         * @param {string} directoryPath The path to the target directory.
         * @param {boolean} dotfiles If `true` then it doesn't skip dot files by default.
         * @returns {IterableIterator<FileEntry>} The found files.
         * @private
         */
        _iterateFilesWithDirectory(directoryPath, dotfiles) {
            debug(`Directory: ${directoryPath}`);
            return this._iterateFilesRecursive(directoryPath, { dotfiles, recursive: true, selector: null });
        }
        /**
         * Iterate files which are matched by a given glob pattern.
         * @param {string} pattern The glob pattern to iterate files.
         * @param {boolean} dotfiles If `true` then it doesn't skip dot files by default.
         * @returns {IterableIterator<FileEntry>} The found files.
         * @private
         */
        _iterateFilesWithGlob(pattern, dotfiles) {
            debug(`Glob: ${pattern}`);
            const { cwd } = internalSlotsMap.get(this);
            const directoryPath = path.resolve(cwd, getGlobParent(pattern));
            const absolutePath = path.resolve(cwd, pattern);
            const globPart = absolutePath.slice(directoryPath.length + 1);
            /*
             * recursive if there are `**` or path separators in the glob part.
             * Otherwise, patterns such as `src/*.js`, it doesn't need recursive.
             */
            const recursive = /\*\*|\/|\\/u.test(globPart);
            const selector = new Minimatch(absolutePath, minimatchOpts);
            debug(`recursive? ${recursive}`);
            return this._iterateFilesRecursive(directoryPath, { dotfiles, recursive, selector });
        }
        /**
         * Iterate files in a given path.
         * @param {string} directoryPath The path to the target directory.
         * @param {Object} options The options to iterate files.
         * @param {boolean} [options.dotfiles] If `true` then it doesn't skip dot files by default.
         * @param {boolean} [options.recursive] If `true` then it dives into sub directories.
         * @param {InstanceType<Minimatch>} [options.selector] The matcher to choose files.
         * @returns {IterableIterator<FileEntry>} The found files.
         * @private
         */
        *_iterateFilesRecursive(directoryPath, options) {
            debug(`Enter the directory: ${directoryPath}`);
            const { configArrayFactory } = internalSlotsMap.get(this);
            /** @type {ConfigArray|null} */
            let config = null;
            // Enumerate the files of this directory.
            for (const entry of readdirSafeSync(directoryPath)) {
                const filePath = path.join(directoryPath, entry.name);
                const fileInfo = entry.isSymbolicLink() ? statSafeSync(filePath) : entry;
                if (!fileInfo) {
                    continue;
                }
                // Check if the file is matched.
                if (fileInfo.isFile()) {
                    if (!config) {
                        config = configArrayFactory.getConfigArrayForFile(filePath, 
                        /*
                         * We must ignore `ConfigurationNotFoundError` at this
                         * point because we don't know if target files exist in
                         * this directory.
                         */
                        { ignoreNotFoundError: true });
                    }
                    const matched = options.selector
                        // Started with a glob pattern; choose by the pattern.
                        ? options.selector.match(filePath)
                        // Started with a directory path; choose by file extensions.
                        : this.isTargetPath(filePath, config);
                    if (matched) {
                        const ignored = this._isIgnoredFile(filePath, { ...options, config });
                        const flag = ignored ? IGNORED_SILENTLY : NONE;
                        debug(`Yield: ${entry.name}${ignored ? " but ignored" : ""}`);
                        yield {
                            config: configArrayFactory.getConfigArrayForFile(filePath),
                            filePath,
                            flag
                        };
                    }
                    else {
                        debug(`Didn't match: ${entry.name}`);
                    }
                    // Dive into the sub directory.
                }
                else if (options.recursive && fileInfo.isDirectory()) {
                    if (!config) {
                        config = configArrayFactory.getConfigArrayForFile(filePath, { ignoreNotFoundError: true });
                    }
                    const ignored = this._isIgnoredFile(filePath + path.sep, { ...options, config });
                    if (!ignored) {
                        yield* this._iterateFilesRecursive(filePath, options);
                    }
                }
            }
            debug(`Leave the directory: ${directoryPath}`);
        }
        /**
         * Check if a given file should be ignored.
         * @param {string} filePath The path to a file to check.
         * @param {Object} options Options
         * @param {ConfigArray} [options.config] The config for this file.
         * @param {boolean} [options.dotfiles] If `true` then this is not ignore dot files by default.
         * @param {boolean} [options.direct] If `true` then this is a direct specified file.
         * @returns {boolean} `true` if the file should be ignored.
         * @private
         */
        _isIgnoredFile(filePath, { config: providedConfig, dotfiles = false, direct = false }) {
            const { configArrayFactory, defaultIgnores, ignoreFlag } = internalSlotsMap.get(this);
            if (ignoreFlag) {
                const config = providedConfig ||
                    configArrayFactory.getConfigArrayForFile(filePath, { ignoreNotFoundError: true });
                const ignores = config.extractConfig(filePath).ignores || defaultIgnores;
                return ignores(filePath, dotfiles);
            }
            return !direct && defaultIgnores(filePath, dotfiles);
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = { FileEnumerator };
},
/* glob-parent/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var isGlob = require(283) /* is-glob */;
    var pathPosixDirname = require('path').posix.dirname;
    var isWin32 = require('os').platform() === 'win32';
    var slash = '/';
    var backslash = /\\/g;
    var escaped = /\\([!*?|[\](){}])/g;
    /**
     * @param {string} str
     * @param {Object} opts
     * @param {boolean} [opts.flipBackslashes=true]
     */
    module.exports = function globParent(str, opts) {
        var options = Object.assign({ flipBackslashes: true }, opts);
        // flip windows path separators
        if (options.flipBackslashes && isWin32 && str.indexOf(slash) < 0) {
            str = str.replace(backslash, slash);
        }
        // special case for strings ending in enclosure containing path separator
        if (isEnclosure(str)) {
            str += slash;
        }
        // preserves full path in case of trailing path separator
        str += 'a';
        // remove path parts that are globby
        do {
            str = pathPosixDirname(str);
        } while (isGlobby(str));
        // remove escape chars and return result
        return str.replace(escaped, '$1');
    };
    function isEnclosure(str) {
        var lastChar = str.slice(-1);
        var enclosureStart;
        switch (lastChar) {
            case '}':
                enclosureStart = '{';
                break;
            case ']':
                enclosureStart = '[';
                break;
            default:
                return false;
        }
        var foundIndex = str.indexOf(enclosureStart);
        if (foundIndex < 0) {
            return false;
        }
        return str.slice(foundIndex + 1, -1).includes(slash);
    }
    function isGlobby(str) {
        if (/\([^()]+$/.test(str)) {
            return true;
        }
        if (str[0] === '{' || str[0] === '[') {
            return true;
        }
        if (/[^\\][{[]/.test(str)) {
            return true;
        }
        return isGlob(str);
    }
},
/* is-glob/index.js */ function _(require, module, exports, __esModule, __esExport) {/*!
     * is-glob <https://github.com/jonschlinkert/is-glob>
     *
     * Copyright (c) 2014-2017, Jon Schlinkert.
     * Released under the MIT License.
     */
    var isExtglob = require(284) /* is-extglob */;
    var chars = { '{': '}', '(': ')', '[': ']' };
    var strictCheck = function (str) {
        if (str[0] === '!') {
            return true;
        }
        var index = 0;
        var pipeIndex = -2;
        var closeSquareIndex = -2;
        var closeCurlyIndex = -2;
        var closeParenIndex = -2;
        var backSlashIndex = -2;
        while (index < str.length) {
            if (str[index] === '*') {
                return true;
            }
            if (str[index + 1] === '?' && /[\].+)]/.test(str[index])) {
                return true;
            }
            if (closeSquareIndex !== -1 && str[index] === '[' && str[index + 1] !== ']') {
                if (closeSquareIndex < index) {
                    closeSquareIndex = str.indexOf(']', index);
                }
                if (closeSquareIndex > index) {
                    if (backSlashIndex === -1 || backSlashIndex > closeSquareIndex) {
                        return true;
                    }
                    backSlashIndex = str.indexOf('\\', index);
                    if (backSlashIndex === -1 || backSlashIndex > closeSquareIndex) {
                        return true;
                    }
                }
            }
            if (closeCurlyIndex !== -1 && str[index] === '{' && str[index + 1] !== '}') {
                closeCurlyIndex = str.indexOf('}', index);
                if (closeCurlyIndex > index) {
                    backSlashIndex = str.indexOf('\\', index);
                    if (backSlashIndex === -1 || backSlashIndex > closeCurlyIndex) {
                        return true;
                    }
                }
            }
            if (closeParenIndex !== -1 && str[index] === '(' && str[index + 1] === '?' && /[:!=]/.test(str[index + 2]) && str[index + 3] !== ')') {
                closeParenIndex = str.indexOf(')', index);
                if (closeParenIndex > index) {
                    backSlashIndex = str.indexOf('\\', index);
                    if (backSlashIndex === -1 || backSlashIndex > closeParenIndex) {
                        return true;
                    }
                }
            }
            if (pipeIndex !== -1 && str[index] === '(' && str[index + 1] !== '|') {
                if (pipeIndex < index) {
                    pipeIndex = str.indexOf('|', index);
                }
                if (pipeIndex !== -1 && str[pipeIndex + 1] !== ')') {
                    closeParenIndex = str.indexOf(')', pipeIndex);
                    if (closeParenIndex > pipeIndex) {
                        backSlashIndex = str.indexOf('\\', pipeIndex);
                        if (backSlashIndex === -1 || backSlashIndex > closeParenIndex) {
                            return true;
                        }
                    }
                }
            }
            if (str[index] === '\\') {
                var open = str[index + 1];
                index += 2;
                var close = chars[open];
                if (close) {
                    var n = str.indexOf(close, index);
                    if (n !== -1) {
                        index = n + 1;
                    }
                }
                if (str[index] === '!') {
                    return true;
                }
            }
            else {
                index++;
            }
        }
        return false;
    };
    var relaxedCheck = function (str) {
        if (str[0] === '!') {
            return true;
        }
        var index = 0;
        while (index < str.length) {
            if (/[*?{}()[\]]/.test(str[index])) {
                return true;
            }
            if (str[index] === '\\') {
                var open = str[index + 1];
                index += 2;
                var close = chars[open];
                if (close) {
                    var n = str.indexOf(close, index);
                    if (n !== -1) {
                        index = n + 1;
                    }
                }
                if (str[index] === '!') {
                    return true;
                }
            }
            else {
                index++;
            }
        }
        return false;
    };
    module.exports = function isGlob(str, options) {
        if (typeof str !== 'string' || str === '') {
            return false;
        }
        if (isExtglob(str)) {
            return true;
        }
        var check = strictCheck;
        // optionally relax check
        if (options && options.strict === false) {
            check = relaxedCheck;
        }
        return check(str);
    };
},
/* is-extglob/index.js */ function _(require, module, exports, __esModule, __esExport) {/*!
     * is-extglob <https://github.com/jonschlinkert/is-extglob>
     *
     * Copyright (c) 2014-2016, Jon Schlinkert.
     * Licensed under the MIT License.
     */
    module.exports = function isExtglob(str) {
        if (typeof str !== 'string' || str === '') {
            return false;
        }
        var match;
        while ((match = /(\\).|([@?!+*]\(.*\))/g.exec(str))) {
            if (match[2])
                return true;
            str = str.slice(match.index + match[0].length);
        }
        return false;
    };
},
/* escape-string-regexp/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = string => {
        if (typeof string !== 'string') {
            throw new TypeError('Expected a string');
        }
        // Escape characters with special meaning either inside or outside character sets.
        // Use a simple backslash escape when it’s always valid, and a \unnnn escape when the simpler form would be disallowed by Unicode patterns’ stricter grammar.
        return string
            .replace(/[|\\{}()[\]^$+*?.]/g, '\\$&')
            .replace(/-/g, '\\x2d');
    };
},
/* @eslint/js/src/index.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Main package entrypoint.
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = {
        configs: {
            all: require(287) /* ./configs/eslint-all */,
            recommended: require(288) /* ./configs/eslint-recommended */
        }
    };
},
/* @eslint/js/src/configs/eslint-all.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
     * WARNING: This file is autogenerated using the tools/update-eslint-all.js
     * script. Do not edit manually.
     */
    "use strict";
    /* eslint quote-props: off -- autogenerated so don't lint */
    module.exports = Object.freeze({
        "rules": {
            "accessor-pairs": "error",
            "array-bracket-newline": "error",
            "array-bracket-spacing": "error",
            "array-callback-return": "error",
            "array-element-newline": "error",
            "arrow-body-style": "error",
            "arrow-parens": "error",
            "arrow-spacing": "error",
            "block-scoped-var": "error",
            "block-spacing": "error",
            "brace-style": "error",
            "camelcase": "error",
            "capitalized-comments": "error",
            "class-methods-use-this": "error",
            "comma-dangle": "error",
            "comma-spacing": "error",
            "comma-style": "error",
            "complexity": "error",
            "computed-property-spacing": "error",
            "consistent-return": "error",
            "consistent-this": "error",
            "constructor-super": "error",
            "curly": "error",
            "default-case": "error",
            "default-case-last": "error",
            "default-param-last": "error",
            "dot-location": "error",
            "dot-notation": "error",
            "eol-last": "error",
            "eqeqeq": "error",
            "for-direction": "error",
            "func-call-spacing": "error",
            "func-name-matching": "error",
            "func-names": "error",
            "func-style": "error",
            "function-call-argument-newline": "error",
            "function-paren-newline": "error",
            "generator-star-spacing": "error",
            "getter-return": "error",
            "grouped-accessor-pairs": "error",
            "guard-for-in": "error",
            "id-denylist": "error",
            "id-length": "error",
            "id-match": "error",
            "implicit-arrow-linebreak": "error",
            "indent": "error",
            "init-declarations": "error",
            "jsx-quotes": "error",
            "key-spacing": "error",
            "keyword-spacing": "error",
            "line-comment-position": "error",
            "linebreak-style": "error",
            "lines-around-comment": "error",
            "lines-between-class-members": "error",
            "logical-assignment-operators": "error",
            "max-classes-per-file": "error",
            "max-depth": "error",
            "max-len": "error",
            "max-lines": "error",
            "max-lines-per-function": "error",
            "max-nested-callbacks": "error",
            "max-params": "error",
            "max-statements": "error",
            "max-statements-per-line": "error",
            "multiline-comment-style": "error",
            "multiline-ternary": "error",
            "new-cap": "error",
            "new-parens": "error",
            "newline-per-chained-call": "error",
            "no-alert": "error",
            "no-array-constructor": "error",
            "no-async-promise-executor": "error",
            "no-await-in-loop": "error",
            "no-bitwise": "error",
            "no-caller": "error",
            "no-case-declarations": "error",
            "no-class-assign": "error",
            "no-compare-neg-zero": "error",
            "no-cond-assign": "error",
            "no-confusing-arrow": "error",
            "no-console": "error",
            "no-const-assign": "error",
            "no-constant-binary-expression": "error",
            "no-constant-condition": "error",
            "no-constructor-return": "error",
            "no-continue": "error",
            "no-control-regex": "error",
            "no-debugger": "error",
            "no-delete-var": "error",
            "no-div-regex": "error",
            "no-dupe-args": "error",
            "no-dupe-class-members": "error",
            "no-dupe-else-if": "error",
            "no-dupe-keys": "error",
            "no-duplicate-case": "error",
            "no-duplicate-imports": "error",
            "no-else-return": "error",
            "no-empty": "error",
            "no-empty-character-class": "error",
            "no-empty-function": "error",
            "no-empty-pattern": "error",
            "no-empty-static-block": "error",
            "no-eq-null": "error",
            "no-eval": "error",
            "no-ex-assign": "error",
            "no-extend-native": "error",
            "no-extra-bind": "error",
            "no-extra-boolean-cast": "error",
            "no-extra-label": "error",
            "no-extra-parens": "error",
            "no-extra-semi": "error",
            "no-fallthrough": "error",
            "no-floating-decimal": "error",
            "no-func-assign": "error",
            "no-global-assign": "error",
            "no-implicit-coercion": "error",
            "no-implicit-globals": "error",
            "no-implied-eval": "error",
            "no-import-assign": "error",
            "no-inline-comments": "error",
            "no-inner-declarations": "error",
            "no-invalid-regexp": "error",
            "no-invalid-this": "error",
            "no-irregular-whitespace": "error",
            "no-iterator": "error",
            "no-label-var": "error",
            "no-labels": "error",
            "no-lone-blocks": "error",
            "no-lonely-if": "error",
            "no-loop-func": "error",
            "no-loss-of-precision": "error",
            "no-magic-numbers": "error",
            "no-misleading-character-class": "error",
            "no-mixed-operators": "error",
            "no-mixed-spaces-and-tabs": "error",
            "no-multi-assign": "error",
            "no-multi-spaces": "error",
            "no-multi-str": "error",
            "no-multiple-empty-lines": "error",
            "no-negated-condition": "error",
            "no-nested-ternary": "error",
            "no-new": "error",
            "no-new-func": "error",
            "no-new-native-nonconstructor": "error",
            "no-new-object": "error",
            "no-new-symbol": "error",
            "no-new-wrappers": "error",
            "no-nonoctal-decimal-escape": "error",
            "no-obj-calls": "error",
            "no-octal": "error",
            "no-octal-escape": "error",
            "no-param-reassign": "error",
            "no-plusplus": "error",
            "no-promise-executor-return": "error",
            "no-proto": "error",
            "no-prototype-builtins": "error",
            "no-redeclare": "error",
            "no-regex-spaces": "error",
            "no-restricted-exports": "error",
            "no-restricted-globals": "error",
            "no-restricted-imports": "error",
            "no-restricted-properties": "error",
            "no-restricted-syntax": "error",
            "no-return-assign": "error",
            "no-return-await": "error",
            "no-script-url": "error",
            "no-self-assign": "error",
            "no-self-compare": "error",
            "no-sequences": "error",
            "no-setter-return": "error",
            "no-shadow": "error",
            "no-shadow-restricted-names": "error",
            "no-sparse-arrays": "error",
            "no-tabs": "error",
            "no-template-curly-in-string": "error",
            "no-ternary": "error",
            "no-this-before-super": "error",
            "no-throw-literal": "error",
            "no-trailing-spaces": "error",
            "no-undef": "error",
            "no-undef-init": "error",
            "no-undefined": "error",
            "no-underscore-dangle": "error",
            "no-unexpected-multiline": "error",
            "no-unmodified-loop-condition": "error",
            "no-unneeded-ternary": "error",
            "no-unreachable": "error",
            "no-unreachable-loop": "error",
            "no-unsafe-finally": "error",
            "no-unsafe-negation": "error",
            "no-unsafe-optional-chaining": "error",
            "no-unused-expressions": "error",
            "no-unused-labels": "error",
            "no-unused-private-class-members": "error",
            "no-unused-vars": "error",
            "no-use-before-define": "error",
            "no-useless-backreference": "error",
            "no-useless-call": "error",
            "no-useless-catch": "error",
            "no-useless-computed-key": "error",
            "no-useless-concat": "error",
            "no-useless-constructor": "error",
            "no-useless-escape": "error",
            "no-useless-rename": "error",
            "no-useless-return": "error",
            "no-var": "error",
            "no-void": "error",
            "no-warning-comments": "error",
            "no-whitespace-before-property": "error",
            "no-with": "error",
            "nonblock-statement-body-position": "error",
            "object-curly-newline": "error",
            "object-curly-spacing": "error",
            "object-property-newline": "error",
            "object-shorthand": "error",
            "one-var": "error",
            "one-var-declaration-per-line": "error",
            "operator-assignment": "error",
            "operator-linebreak": "error",
            "padded-blocks": "error",
            "padding-line-between-statements": "error",
            "prefer-arrow-callback": "error",
            "prefer-const": "error",
            "prefer-destructuring": "error",
            "prefer-exponentiation-operator": "error",
            "prefer-named-capture-group": "error",
            "prefer-numeric-literals": "error",
            "prefer-object-has-own": "error",
            "prefer-object-spread": "error",
            "prefer-promise-reject-errors": "error",
            "prefer-regex-literals": "error",
            "prefer-rest-params": "error",
            "prefer-spread": "error",
            "prefer-template": "error",
            "quote-props": "error",
            "quotes": "error",
            "radix": "error",
            "require-atomic-updates": "error",
            "require-await": "error",
            "require-unicode-regexp": "error",
            "require-yield": "error",
            "rest-spread-spacing": "error",
            "semi": "error",
            "semi-spacing": "error",
            "semi-style": "error",
            "sort-imports": "error",
            "sort-keys": "error",
            "sort-vars": "error",
            "space-before-blocks": "error",
            "space-before-function-paren": "error",
            "space-in-parens": "error",
            "space-infix-ops": "error",
            "space-unary-ops": "error",
            "spaced-comment": "error",
            "strict": "error",
            "switch-colon-spacing": "error",
            "symbol-description": "error",
            "template-curly-spacing": "error",
            "template-tag-spacing": "error",
            "unicode-bom": "error",
            "use-isnan": "error",
            "valid-typeof": "error",
            "vars-on-top": "error",
            "wrap-iife": "error",
            "wrap-regex": "error",
            "yield-star-spacing": "error",
            "yoda": "error"
        }
    });
},
/* @eslint/js/src/configs/eslint-recommended.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Configuration applied when a user configuration extends from
     * eslint:recommended.
     * @author Nicholas C. Zakas
     */
    "use strict";
    /* eslint sort-keys: ["error", "asc"] -- Long, so make more readable */
    /** @type {import("../lib/shared/types").ConfigData} */
    module.exports = Object.freeze({
        rules: Object.freeze({
            "constructor-super": "error",
            "for-direction": "error",
            "getter-return": "error",
            "no-async-promise-executor": "error",
            "no-case-declarations": "error",
            "no-class-assign": "error",
            "no-compare-neg-zero": "error",
            "no-cond-assign": "error",
            "no-const-assign": "error",
            "no-constant-condition": "error",
            "no-control-regex": "error",
            "no-debugger": "error",
            "no-delete-var": "error",
            "no-dupe-args": "error",
            "no-dupe-class-members": "error",
            "no-dupe-else-if": "error",
            "no-dupe-keys": "error",
            "no-duplicate-case": "error",
            "no-empty": "error",
            "no-empty-character-class": "error",
            "no-empty-pattern": "error",
            "no-ex-assign": "error",
            "no-extra-boolean-cast": "error",
            "no-extra-semi": "error",
            "no-fallthrough": "error",
            "no-func-assign": "error",
            "no-global-assign": "error",
            "no-import-assign": "error",
            "no-inner-declarations": "error",
            "no-invalid-regexp": "error",
            "no-irregular-whitespace": "error",
            "no-loss-of-precision": "error",
            "no-misleading-character-class": "error",
            "no-mixed-spaces-and-tabs": "error",
            "no-new-symbol": "error",
            "no-nonoctal-decimal-escape": "error",
            "no-obj-calls": "error",
            "no-octal": "error",
            "no-prototype-builtins": "error",
            "no-redeclare": "error",
            "no-regex-spaces": "error",
            "no-self-assign": "error",
            "no-setter-return": "error",
            "no-shadow-restricted-names": "error",
            "no-sparse-arrays": "error",
            "no-this-before-super": "error",
            "no-undef": "error",
            "no-unexpected-multiline": "error",
            "no-unreachable": "error",
            "no-unsafe-finally": "error",
            "no-unsafe-negation": "error",
            "no-unsafe-optional-chaining": "error",
            "no-unused-labels": "error",
            "no-unused-vars": "error",
            "no-useless-backreference": "error",
            "no-useless-catch": "error",
            "no-useless-escape": "error",
            "no-with": "error",
            "require-yield": "error",
            "use-isnan": "error",
            "valid-typeof": "error"
        })
    });
},
/* eslint/lib/linter/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const { Linter } = require(290) /* ./linter */;
    const interpolate = require(355) /* ./interpolate */;
    const SourceCodeFixer = require(691) /* ./source-code-fixer */;
    module.exports = {
        Linter,
        // For testers.
        SourceCodeFixer,
        interpolate
    };
},
/* eslint/lib/linter/linter.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Main Linter Class
     * @author Gyandeep Singh
     * @author aladdin-add
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const path = require("path"), eslintScope = require(291) /* eslint-scope */, evk = require(304) /* eslint-visitor-keys */, espree = require(305) /* espree */, merge = require(308) /* lodash.merge */, pkg = require(221) /* ../../package.json */, astUtils = require(309) /* ../shared/ast-utils */, { directivesPattern } = require(310) /* ../shared/directives */, { Legacy: { ConfigOps, ConfigValidator, environments: BuiltInEnvironments } } = require(311) /* @eslint/eslintrc/universal */, Traverser = require(313) /* ../shared/traverser */, { SourceCode } = require(314) /* ../source-code */, CodePathAnalyzer = require(330) /* ./code-path-analysis/code-path-analyzer */, applyDisableDirectives = require(337) /* ./apply-disable-directives */, ConfigCommentParser = require(338) /* ./config-comment-parser */, NodeEventGenerator = require(351) /* ./node-event-generator */, createReportTranslator = require(353) /* ./report-translator */, Rules = require(356) /* ./rules */, createEmitter = require(690) /* ./safe-emitter */, SourceCodeFixer = require(691) /* ./source-code-fixer */, timing = require(692) /* ./timing */, ruleReplacements = require(693) /* ../../conf/replacements.json */;
    const { getRuleFromConfig } = require(694) /* ../config/flat-config-helpers */;
    const { FlatConfigArray } = require(695) /* ../config/flat-config-array */;
    const debug = require(72) /* debug */("eslint:linter");
    const MAX_AUTOFIX_PASSES = 10;
    const DEFAULT_PARSER_NAME = "espree";
    const DEFAULT_ECMA_VERSION = 5;
    const commentParser = new ConfigCommentParser();
    const DEFAULT_ERROR_LOC = { start: { line: 1, column: 0 }, end: { line: 1, column: 1 } };
    const parserSymbol = Symbol.for("eslint.RuleTester.parser");
    const globals = require(706) /* ../../conf/globals */;
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /** @typedef {InstanceType<import("../cli-engine/config-array").ConfigArray>} ConfigArray */
    /** @typedef {InstanceType<import("../cli-engine/config-array").ExtractedConfig>} ExtractedConfig */
    /** @typedef {import("../shared/types").ConfigData} ConfigData */
    /** @typedef {import("../shared/types").Environment} Environment */
    /** @typedef {import("../shared/types").GlobalConf} GlobalConf */
    /** @typedef {import("../shared/types").LintMessage} LintMessage */
    /** @typedef {import("../shared/types").SuppressedLintMessage} SuppressedLintMessage */
    /** @typedef {import("../shared/types").ParserOptions} ParserOptions */
    /** @typedef {import("../shared/types").LanguageOptions} LanguageOptions */
    /** @typedef {import("../shared/types").Processor} Processor */
    /** @typedef {import("../shared/types").Rule} Rule */
    /* eslint-disable jsdoc/valid-types -- https://github.com/jsdoc-type-pratt-parser/jsdoc-type-pratt-parser/issues/4#issuecomment-778805577 */
    /**
     * @template T
     * @typedef {{ [P in keyof T]-?: T[P] }} Required
     */
    /* eslint-enable jsdoc/valid-types -- https://github.com/jsdoc-type-pratt-parser/jsdoc-type-pratt-parser/issues/4#issuecomment-778805577 */
    /**
     * @typedef {Object} DisableDirective
     * @property {("disable"|"enable"|"disable-line"|"disable-next-line")} type Type of directive
     * @property {number} line The line number
     * @property {number} column The column number
     * @property {(string|null)} ruleId The rule ID
     * @property {string} justification The justification of directive
     */
    /**
     * The private data for `Linter` instance.
     * @typedef {Object} LinterInternalSlots
     * @property {ConfigArray|null} lastConfigArray The `ConfigArray` instance that the last `verify()` call used.
     * @property {SourceCode|null} lastSourceCode The `SourceCode` instance that the last `verify()` call used.
     * @property {SuppressedLintMessage[]} lastSuppressedMessages The `SuppressedLintMessage[]` instance that the last `verify()` call produced.
     * @property {Map<string, Parser>} parserMap The loaded parsers.
     * @property {Rules} ruleMap The loaded rules.
     */
    /**
     * @typedef {Object} VerifyOptions
     * @property {boolean} [allowInlineConfig] Allow/disallow inline comments' ability
     *      to change config once it is set. Defaults to true if not supplied.
     *      Useful if you want to validate JS without comments overriding rules.
     * @property {boolean} [disableFixes] if `true` then the linter doesn't make `fix`
     *      properties into the lint result.
     * @property {string} [filename] the filename of the source code.
     * @property {boolean | "off" | "warn" | "error"} [reportUnusedDisableDirectives] Adds reported errors for
     *      unused `eslint-disable` directives.
     */
    /**
     * @typedef {Object} ProcessorOptions
     * @property {(filename:string, text:string) => boolean} [filterCodeBlock] the
     *      predicate function that selects adopt code blocks.
     * @property {Processor.postprocess} [postprocess] postprocessor for report
     *      messages. If provided, this should accept an array of the message lists
     *      for each code block returned from the preprocessor, apply a mapping to
     *      the messages as appropriate, and return a one-dimensional array of
     *      messages.
     * @property {Processor.preprocess} [preprocess] preprocessor for source text.
     *      If provided, this should accept a string of source text, and return an
     *      array of code blocks to lint.
     */
    /**
     * @typedef {Object} FixOptions
     * @property {boolean | ((message: LintMessage) => boolean)} [fix] Determines
     *      whether fixes should be applied.
     */
    /**
     * @typedef {Object} InternalOptions
     * @property {string | null} warnInlineConfig The config name what `noInlineConfig` setting came from. If `noInlineConfig` setting didn't exist, this is null. If this is a config name, then the linter warns directive comments.
     * @property {"off" | "warn" | "error"} reportUnusedDisableDirectives (boolean values were normalized)
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Determines if a given object is Espree.
     * @param {Object} parser The parser to check.
     * @returns {boolean} True if the parser is Espree or false if not.
     */
    function isEspree(parser) {
        return !!(parser === espree || parser[parserSymbol] === espree);
    }
    /**
     * Retrieves globals for the given ecmaVersion.
     * @param {number} ecmaVersion The version to retrieve globals for.
     * @returns {Object} The globals for the given ecmaVersion.
     */
    function getGlobalsForEcmaVersion(ecmaVersion) {
        switch (ecmaVersion) {
            case 3:
                return globals.es3;
            case 5:
                return globals.es5;
            default:
                if (ecmaVersion < 2015) {
                    return globals[`es${ecmaVersion + 2009}`];
                }
                return globals[`es${ecmaVersion}`];
        }
    }
    /**
     * Ensures that variables representing built-in properties of the Global Object,
     * and any globals declared by special block comments, are present in the global
     * scope.
     * @param {Scope} globalScope The global scope.
     * @param {Object} configGlobals The globals declared in configuration
     * @param {{exportedVariables: Object, enabledGlobals: Object}} commentDirectives Directives from comment configuration
     * @returns {void}
     */
    function addDeclaredGlobals(globalScope, configGlobals, { exportedVariables, enabledGlobals }) {
        // Define configured global variables.
        for (const id of new Set([...Object.keys(configGlobals), ...Object.keys(enabledGlobals)])) {
            /*
             * `ConfigOps.normalizeConfigGlobal` will throw an error if a configured global value is invalid. However, these errors would
             * typically be caught when validating a config anyway (validity for inline global comments is checked separately).
             */
            const configValue = configGlobals[id] === void 0 ? void 0 : ConfigOps.normalizeConfigGlobal(configGlobals[id]);
            const commentValue = enabledGlobals[id] && enabledGlobals[id].value;
            const value = commentValue || configValue;
            const sourceComments = enabledGlobals[id] && enabledGlobals[id].comments;
            if (value === "off") {
                continue;
            }
            let variable = globalScope.set.get(id);
            if (!variable) {
                variable = new eslintScope.Variable(id, globalScope);
                globalScope.variables.push(variable);
                globalScope.set.set(id, variable);
            }
            variable.eslintImplicitGlobalSetting = configValue;
            variable.eslintExplicitGlobal = sourceComments !== void 0;
            variable.eslintExplicitGlobalComments = sourceComments;
            variable.writeable = (value === "writable");
        }
        // mark all exported variables as such
        Object.keys(exportedVariables).forEach(name => {
            const variable = globalScope.set.get(name);
            if (variable) {
                variable.eslintUsed = true;
                variable.eslintExported = true;
            }
        });
        /*
         * "through" contains all references which definitions cannot be found.
         * Since we augment the global scope using configuration, we need to update
         * references and remove the ones that were added by configuration.
         */
        globalScope.through = globalScope.through.filter(reference => {
            const name = reference.identifier.name;
            const variable = globalScope.set.get(name);
            if (variable) {
                /*
                 * Links the variable and the reference.
                 * And this reference is removed from `Scope#through`.
                 */
                reference.resolved = variable;
                variable.references.push(reference);
                return false;
            }
            return true;
        });
    }
    /**
     * creates a missing-rule message.
     * @param {string} ruleId the ruleId to create
     * @returns {string} created error message
     * @private
     */
    function createMissingRuleMessage(ruleId) {
        return Object.prototype.hasOwnProperty.call(ruleReplacements.rules, ruleId)
            ? `Rule '${ruleId}' was removed and replaced by: ${ruleReplacements.rules[ruleId].join(", ")}`
            : `Definition for rule '${ruleId}' was not found.`;
    }
    /**
     * creates a linting problem
     * @param {Object} options to create linting error
     * @param {string} [options.ruleId] the ruleId to report
     * @param {Object} [options.loc] the loc to report
     * @param {string} [options.message] the error message to report
     * @param {string} [options.severity] the error message to report
     * @returns {LintMessage} created problem, returns a missing-rule problem if only provided ruleId.
     * @private
     */
    function createLintingProblem(options) {
        const { ruleId = null, loc = DEFAULT_ERROR_LOC, message = createMissingRuleMessage(options.ruleId), severity = 2 } = options;
        return {
            ruleId,
            message,
            line: loc.start.line,
            column: loc.start.column + 1,
            endLine: loc.end.line,
            endColumn: loc.end.column + 1,
            severity,
            nodeType: null
        };
    }
    /**
     * Creates a collection of disable directives from a comment
     * @param {Object} options to create disable directives
     * @param {("disable"|"enable"|"disable-line"|"disable-next-line")} options.type The type of directive comment
     * @param {token} options.commentToken The Comment token
     * @param {string} options.value The value after the directive in the comment
     * comment specified no specific rules, so it applies to all rules (e.g. `eslint-disable`)
     * @param {string} options.justification The justification of the directive
     * @param {function(string): {create: Function}} options.ruleMapper A map from rule IDs to defined rules
     * @returns {Object} Directives and problems from the comment
     */
    function createDisableDirectives(options) {
        const { commentToken, type, value, justification, ruleMapper } = options;
        const ruleIds = Object.keys(commentParser.parseListConfig(value));
        const directiveRules = ruleIds.length ? ruleIds : [null];
        const result = {
            directives: [],
            directiveProblems: [] // problems in directives
        };
        const parentComment = { commentToken, ruleIds };
        for (const ruleId of directiveRules) {
            // push to directives, if the rule is defined(including null, e.g. /*eslint enable*/)
            if (ruleId === null || !!ruleMapper(ruleId)) {
                if (type === "disable-next-line") {
                    result.directives.push({
                        parentComment,
                        type,
                        line: commentToken.loc.end.line,
                        column: commentToken.loc.end.column + 1,
                        ruleId,
                        justification
                    });
                }
                else {
                    result.directives.push({
                        parentComment,
                        type,
                        line: commentToken.loc.start.line,
                        column: commentToken.loc.start.column + 1,
                        ruleId,
                        justification
                    });
                }
            }
            else {
                result.directiveProblems.push(createLintingProblem({ ruleId, loc: commentToken.loc }));
            }
        }
        return result;
    }
    /**
     * Extract the directive and the justification from a given directive comment and trim them.
     * @param {string} value The comment text to extract.
     * @returns {{directivePart: string, justificationPart: string}} The extracted directive and justification.
     */
    function extractDirectiveComment(value) {
        const match = /\s-{2,}\s/u.exec(value);
        if (!match) {
            return { directivePart: value.trim(), justificationPart: "" };
        }
        const directive = value.slice(0, match.index).trim();
        const justification = value.slice(match.index + match[0].length).trim();
        return { directivePart: directive, justificationPart: justification };
    }
    /**
     * Parses comments in file to extract file-specific config of rules, globals
     * and environments and merges them with global config; also code blocks
     * where reporting is disabled or enabled and merges them with reporting config.
     * @param {ASTNode} ast The top node of the AST.
     * @param {function(string): {create: Function}} ruleMapper A map from rule IDs to defined rules
     * @param {string|null} warnInlineConfig If a string then it should warn directive comments as disabled. The string value is the config name what the setting came from.
     * @returns {{configuredRules: Object, enabledGlobals: {value:string,comment:Token}[], exportedVariables: Object, problems: Problem[], disableDirectives: DisableDirective[]}}
     * A collection of the directive comments that were found, along with any problems that occurred when parsing
     */
    function getDirectiveComments(ast, ruleMapper, warnInlineConfig) {
        const configuredRules = {};
        const enabledGlobals = Object.create(null);
        const exportedVariables = {};
        const problems = [];
        const disableDirectives = [];
        const validator = new ConfigValidator({
            builtInRules: Rules
        });
        ast.comments.filter(token => token.type !== "Shebang").forEach(comment => {
            const { directivePart, justificationPart } = extractDirectiveComment(comment.value);
            const match = directivesPattern.exec(directivePart);
            if (!match) {
                return;
            }
            const directiveText = match[1];
            const lineCommentSupported = /^eslint-disable-(next-)?line$/u.test(directiveText);
            if (comment.type === "Line" && !lineCommentSupported) {
                return;
            }
            if (warnInlineConfig) {
                const kind = comment.type === "Block" ? `/*${directiveText}*/` : `//${directiveText}`;
                problems.push(createLintingProblem({
                    ruleId: null,
                    message: `'${kind}' has no effect because you have 'noInlineConfig' setting in ${warnInlineConfig}.`,
                    loc: comment.loc,
                    severity: 1
                }));
                return;
            }
            if (directiveText === "eslint-disable-line" && comment.loc.start.line !== comment.loc.end.line) {
                const message = `${directiveText} comment should not span multiple lines.`;
                problems.push(createLintingProblem({
                    ruleId: null,
                    message,
                    loc: comment.loc
                }));
                return;
            }
            const directiveValue = directivePart.slice(match.index + directiveText.length);
            switch (directiveText) {
                case "eslint-disable":
                case "eslint-enable":
                case "eslint-disable-next-line":
                case "eslint-disable-line": {
                    const directiveType = directiveText.slice("eslint-".length);
                    const options = { commentToken: comment, type: directiveType, value: directiveValue, justification: justificationPart, ruleMapper };
                    const { directives, directiveProblems } = createDisableDirectives(options);
                    disableDirectives.push(...directives);
                    problems.push(...directiveProblems);
                    break;
                }
                case "exported":
                    Object.assign(exportedVariables, commentParser.parseStringConfig(directiveValue, comment));
                    break;
                case "globals":
                case "global":
                    for (const [id, { value }] of Object.entries(commentParser.parseStringConfig(directiveValue, comment))) {
                        let normalizedValue;
                        try {
                            normalizedValue = ConfigOps.normalizeConfigGlobal(value);
                        }
                        catch (err) {
                            problems.push(createLintingProblem({
                                ruleId: null,
                                loc: comment.loc,
                                message: err.message
                            }));
                            continue;
                        }
                        if (enabledGlobals[id]) {
                            enabledGlobals[id].comments.push(comment);
                            enabledGlobals[id].value = normalizedValue;
                        }
                        else {
                            enabledGlobals[id] = {
                                comments: [comment],
                                value: normalizedValue
                            };
                        }
                    }
                    break;
                case "eslint": {
                    const parseResult = commentParser.parseJsonConfig(directiveValue, comment.loc);
                    if (parseResult.success) {
                        Object.keys(parseResult.config).forEach(name => {
                            const rule = ruleMapper(name);
                            const ruleValue = parseResult.config[name];
                            if (!rule) {
                                problems.push(createLintingProblem({ ruleId: name, loc: comment.loc }));
                                return;
                            }
                            try {
                                validator.validateRuleOptions(rule, name, ruleValue);
                            }
                            catch (err) {
                                problems.push(createLintingProblem({
                                    ruleId: name,
                                    message: err.message,
                                    loc: comment.loc
                                }));
                                // do not apply the config, if found invalid options.
                                return;
                            }
                            configuredRules[name] = ruleValue;
                        });
                    }
                    else {
                        problems.push(parseResult.error);
                    }
                    break;
                }
                // no default
            }
        });
        return {
            configuredRules,
            enabledGlobals,
            exportedVariables,
            problems,
            disableDirectives
        };
    }
    /**
     * Normalize ECMAScript version from the initial config
     * @param {Parser} parser The parser which uses this options.
     * @param {number} ecmaVersion ECMAScript version from the initial config
     * @returns {number} normalized ECMAScript version
     */
    function normalizeEcmaVersion(parser, ecmaVersion) {
        if (isEspree(parser)) {
            if (ecmaVersion === "latest") {
                return espree.latestEcmaVersion;
            }
        }
        /*
         * Calculate ECMAScript edition number from official year version starting with
         * ES2015, which corresponds with ES6 (or a difference of 2009).
         */
        return ecmaVersion >= 2015 ? ecmaVersion - 2009 : ecmaVersion;
    }
    /**
     * Normalize ECMAScript version from the initial config into languageOptions (year)
     * format.
     * @param {any} [ecmaVersion] ECMAScript version from the initial config
     * @returns {number} normalized ECMAScript version
     */
    function normalizeEcmaVersionForLanguageOptions(ecmaVersion) {
        switch (ecmaVersion) {
            case 3:
                return 3;
            // void 0 = no ecmaVersion specified so use the default
            case 5:
            case void 0:
                return 5;
            default:
                if (typeof ecmaVersion === "number") {
                    return ecmaVersion >= 2015 ? ecmaVersion : ecmaVersion + 2009;
                }
        }
        /*
         * We default to the latest supported ecmaVersion for everything else.
         * Remember, this is for languageOptions.ecmaVersion, which sets the version
         * that is used for a number of processes inside of ESLint. It's normally
         * safe to assume people want the latest unless otherwise specified.
         */
        return espree.latestEcmaVersion + 2009;
    }
    const eslintEnvPattern = /\/\*\s*eslint-env\s(.+?)(?:\*\/|$)/gsu;
    /**
     * Checks whether or not there is a comment which has "eslint-env *" in a given text.
     * @param {string} text A source code text to check.
     * @returns {Object|null} A result of parseListConfig() with "eslint-env *" comment.
     */
    function findEslintEnv(text) {
        let match, retv;
        eslintEnvPattern.lastIndex = 0;
        while ((match = eslintEnvPattern.exec(text)) !== null) {
            if (match[0].endsWith("*/")) {
                retv = Object.assign(retv || {}, commentParser.parseListConfig(extractDirectiveComment(match[1]).directivePart));
            }
        }
        return retv;
    }
    /**
     * Convert "/path/to/<text>" to "<text>".
     * `CLIEngine#executeOnText()` method gives "/path/to/<text>" if the filename
     * was omitted because `configArray.extractConfig()` requires an absolute path.
     * But the linter should pass `<text>` to `RuleContext#getFilename()` in that
     * case.
     * Also, code blocks can have their virtual filename. If the parent filename was
     * `<text>`, the virtual filename is `<text>/0_foo.js` or something like (i.e.,
     * it's not an absolute path).
     * @param {string} filename The filename to normalize.
     * @returns {string} The normalized filename.
     */
    function normalizeFilename(filename) {
        const parts = filename.split(path.sep);
        const index = parts.lastIndexOf("<text>");
        return index === -1 ? filename : parts.slice(index).join(path.sep);
    }
    /**
     * Normalizes the possible options for `linter.verify` and `linter.verifyAndFix` to a
     * consistent shape.
     * @param {VerifyOptions} providedOptions Options
     * @param {ConfigData} config Config.
     * @returns {Required<VerifyOptions> & InternalOptions} Normalized options
     */
    function normalizeVerifyOptions(providedOptions, config) {
        const linterOptions = config.linterOptions || config;
        // .noInlineConfig for eslintrc, .linterOptions.noInlineConfig for flat
        const disableInlineConfig = linterOptions.noInlineConfig === true;
        const ignoreInlineConfig = providedOptions.allowInlineConfig === false;
        const configNameOfNoInlineConfig = config.configNameOfNoInlineConfig
            ? ` (${config.configNameOfNoInlineConfig})`
            : "";
        let reportUnusedDisableDirectives = providedOptions.reportUnusedDisableDirectives;
        if (typeof reportUnusedDisableDirectives === "boolean") {
            reportUnusedDisableDirectives = reportUnusedDisableDirectives ? "error" : "off";
        }
        if (typeof reportUnusedDisableDirectives !== "string") {
            reportUnusedDisableDirectives =
                linterOptions.reportUnusedDisableDirectives
                    ? "warn" : "off";
        }
        return {
            filename: normalizeFilename(providedOptions.filename || "<input>"),
            allowInlineConfig: !ignoreInlineConfig,
            warnInlineConfig: disableInlineConfig && !ignoreInlineConfig
                ? `your config${configNameOfNoInlineConfig}`
                : null,
            reportUnusedDisableDirectives,
            disableFixes: Boolean(providedOptions.disableFixes)
        };
    }
    /**
     * Combines the provided parserOptions with the options from environments
     * @param {Parser} parser The parser which uses this options.
     * @param {ParserOptions} providedOptions The provided 'parserOptions' key in a config
     * @param {Environment[]} enabledEnvironments The environments enabled in configuration and with inline comments
     * @returns {ParserOptions} Resulting parser options after merge
     */
    function resolveParserOptions(parser, providedOptions, enabledEnvironments) {
        const parserOptionsFromEnv = enabledEnvironments
            .filter(env => env.parserOptions)
            .reduce((parserOptions, env) => merge(parserOptions, env.parserOptions), {});
        const mergedParserOptions = merge(parserOptionsFromEnv, providedOptions || {});
        const isModule = mergedParserOptions.sourceType === "module";
        if (isModule) {
            /*
             * can't have global return inside of modules
             * TODO: espree validate parserOptions.globalReturn when sourceType is setting to module.(@aladdin-add)
             */
            mergedParserOptions.ecmaFeatures = Object.assign({}, mergedParserOptions.ecmaFeatures, { globalReturn: false });
        }
        mergedParserOptions.ecmaVersion = normalizeEcmaVersion(parser, mergedParserOptions.ecmaVersion);
        return mergedParserOptions;
    }
    /**
     * Converts parserOptions to languageOptions for backwards compatibility with eslintrc.
     * @param {ConfigData} config Config object.
     * @param {Object} config.globals Global variable definitions.
     * @param {Parser} config.parser The parser to use.
     * @param {ParserOptions} config.parserOptions The parserOptions to use.
     * @returns {LanguageOptions} The languageOptions equivalent.
     */
    function createLanguageOptions({ globals: configuredGlobals, parser, parserOptions }) {
        const { ecmaVersion, sourceType } = parserOptions;
        return {
            globals: configuredGlobals,
            ecmaVersion: normalizeEcmaVersionForLanguageOptions(ecmaVersion),
            sourceType,
            parser,
            parserOptions
        };
    }
    /**
     * Combines the provided globals object with the globals from environments
     * @param {Record<string, GlobalConf>} providedGlobals The 'globals' key in a config
     * @param {Environment[]} enabledEnvironments The environments enabled in configuration and with inline comments
     * @returns {Record<string, GlobalConf>} The resolved globals object
     */
    function resolveGlobals(providedGlobals, enabledEnvironments) {
        return Object.assign({}, ...enabledEnvironments.filter(env => env.globals).map(env => env.globals), providedGlobals);
    }
    /**
     * Strips Unicode BOM from a given text.
     * @param {string} text A text to strip.
     * @returns {string} The stripped text.
     */
    function stripUnicodeBOM(text) {
        /*
         * Check Unicode BOM.
         * In JavaScript, string data is stored as UTF-16, so BOM is 0xFEFF.
         * http://www.ecma-international.org/ecma-262/6.0/#sec-unicode-format-control-characters
         */
        if (text.charCodeAt(0) === 0xFEFF) {
            return text.slice(1);
        }
        return text;
    }
    /**
     * Get the options for a rule (not including severity), if any
     * @param {Array|number} ruleConfig rule configuration
     * @returns {Array} of rule options, empty Array if none
     */
    function getRuleOptions(ruleConfig) {
        if (Array.isArray(ruleConfig)) {
            return ruleConfig.slice(1);
        }
        return [];
    }
    /**
     * Analyze scope of the given AST.
     * @param {ASTNode} ast The `Program` node to analyze.
     * @param {LanguageOptions} languageOptions The parser options.
     * @param {Record<string, string[]>} visitorKeys The visitor keys.
     * @returns {ScopeManager} The analysis result.
     */
    function analyzeScope(ast, languageOptions, visitorKeys) {
        const parserOptions = languageOptions.parserOptions;
        const ecmaFeatures = parserOptions.ecmaFeatures || {};
        const ecmaVersion = languageOptions.ecmaVersion || DEFAULT_ECMA_VERSION;
        return eslintScope.analyze(ast, {
            ignoreEval: true,
            nodejsScope: ecmaFeatures.globalReturn,
            impliedStrict: ecmaFeatures.impliedStrict,
            ecmaVersion: typeof ecmaVersion === "number" ? ecmaVersion : 6,
            sourceType: languageOptions.sourceType || "script",
            childVisitorKeys: visitorKeys || evk.KEYS,
            fallback: Traverser.getKeys
        });
    }
    /**
     * Parses text into an AST. Moved out here because the try-catch prevents
     * optimization of functions, so it's best to keep the try-catch as isolated
     * as possible
     * @param {string} text The text to parse.
     * @param {LanguageOptions} languageOptions Options to pass to the parser
     * @param {string} filePath The path to the file being parsed.
     * @returns {{success: false, error: Problem}|{success: true, sourceCode: SourceCode}}
     * An object containing the AST and parser services if parsing was successful, or the error if parsing failed
     * @private
     */
    function parse(text, languageOptions, filePath) {
        const textToParse = stripUnicodeBOM(text).replace(astUtils.shebangPattern, (match, captured) => `//${captured}`);
        const { ecmaVersion, sourceType, parser } = languageOptions;
        const parserOptions = Object.assign({ ecmaVersion, sourceType }, languageOptions.parserOptions, {
            loc: true,
            range: true,
            raw: true,
            tokens: true,
            comment: true,
            eslintVisitorKeys: true,
            eslintScopeManager: true,
            filePath
        });
        /*
         * Check for parsing errors first. If there's a parsing error, nothing
         * else can happen. However, a parsing error does not throw an error
         * from this method - it's just considered a fatal error message, a
         * problem that ESLint identified just like any other.
         */
        try {
            debug("Parsing:", filePath);
            const parseResult = (typeof parser.parseForESLint === "function")
                ? parser.parseForESLint(textToParse, parserOptions)
                : { ast: parser.parse(textToParse, parserOptions) };
            debug("Parsing successful:", filePath);
            const ast = parseResult.ast;
            const parserServices = parseResult.services || {};
            const visitorKeys = parseResult.visitorKeys || evk.KEYS;
            debug("Scope analysis:", filePath);
            const scopeManager = parseResult.scopeManager || analyzeScope(ast, languageOptions, visitorKeys);
            debug("Scope analysis successful:", filePath);
            return {
                success: true,
                /*
                 * Save all values that `parseForESLint()` returned.
                 * If a `SourceCode` object is given as the first parameter instead of source code text,
                 * linter skips the parsing process and reuses the source code object.
                 * In that case, linter needs all the values that `parseForESLint()` returned.
                 */
                sourceCode: new SourceCode({
                    text,
                    ast,
                    parserServices,
                    scopeManager,
                    visitorKeys
                })
            };
        }
        catch (ex) {
            // If the message includes a leading line number, strip it:
            const message = `Parsing error: ${ex.message.replace(/^line \d+:/iu, "").trim()}`;
            debug("%s\n%s", message, ex.stack);
            return {
                success: false,
                error: {
                    ruleId: null,
                    fatal: true,
                    severity: 2,
                    message,
                    line: ex.lineNumber,
                    column: ex.column
                }
            };
        }
    }
    /**
     * Gets the scope for the current node
     * @param {ScopeManager} scopeManager The scope manager for this AST
     * @param {ASTNode} currentNode The node to get the scope of
     * @returns {eslint-scope.Scope} The scope information for this node
     */
    function getScope(scopeManager, currentNode) {
        // On Program node, get the outermost scope to avoid return Node.js special function scope or ES modules scope.
        const inner = currentNode.type !== "Program";
        for (let node = currentNode; node; node = node.parent) {
            const scope = scopeManager.acquire(node, inner);
            if (scope) {
                if (scope.type === "function-expression-name") {
                    return scope.childScopes[0];
                }
                return scope;
            }
        }
        return scopeManager.scopes[0];
    }
    /**
     * Marks a variable as used in the current scope
     * @param {ScopeManager} scopeManager The scope manager for this AST. The scope may be mutated by this function.
     * @param {ASTNode} currentNode The node currently being traversed
     * @param {LanguageOptions} languageOptions The options used to parse this text
     * @param {string} name The name of the variable that should be marked as used.
     * @returns {boolean} True if the variable was found and marked as used, false if not.
     */
    function markVariableAsUsed(scopeManager, currentNode, languageOptions, name) {
        const parserOptions = languageOptions.parserOptions;
        const sourceType = languageOptions.sourceType;
        const hasGlobalReturn = (parserOptions.ecmaFeatures && parserOptions.ecmaFeatures.globalReturn) ||
            sourceType === "commonjs";
        const specialScope = hasGlobalReturn || sourceType === "module";
        const currentScope = getScope(scopeManager, currentNode);
        // Special Node.js scope means we need to start one level deeper
        const initialScope = currentScope.type === "global" && specialScope ? currentScope.childScopes[0] : currentScope;
        for (let scope = initialScope; scope; scope = scope.upper) {
            const variable = scope.variables.find(scopeVar => scopeVar.name === name);
            if (variable) {
                variable.eslintUsed = true;
                return true;
            }
        }
        return false;
    }
    /**
     * Runs a rule, and gets its listeners
     * @param {Rule} rule A normalized rule with a `create` method
     * @param {Context} ruleContext The context that should be passed to the rule
     * @throws {any} Any error during the rule's `create`
     * @returns {Object} A map of selector listeners provided by the rule
     */
    function createRuleListeners(rule, ruleContext) {
        try {
            return rule.create(ruleContext);
        }
        catch (ex) {
            ex.message = `Error while loading rule '${ruleContext.id}': ${ex.message}`;
            throw ex;
        }
    }
    /**
     * Gets all the ancestors of a given node
     * @param {ASTNode} node The node
     * @returns {ASTNode[]} All the ancestor nodes in the AST, not including the provided node, starting
     * from the root node and going inwards to the parent node.
     */
    function getAncestors(node) {
        const ancestorsStartingAtParent = [];
        for (let ancestor = node.parent; ancestor; ancestor = ancestor.parent) {
            ancestorsStartingAtParent.push(ancestor);
        }
        return ancestorsStartingAtParent.reverse();
    }
    // methods that exist on SourceCode object
    const DEPRECATED_SOURCECODE_PASSTHROUGHS = {
        getSource: "getText",
        getSourceLines: "getLines",
        getAllComments: "getAllComments",
        getNodeByRangeIndex: "getNodeByRangeIndex",
        getComments: "getComments",
        getCommentsBefore: "getCommentsBefore",
        getCommentsAfter: "getCommentsAfter",
        getCommentsInside: "getCommentsInside",
        getJSDocComment: "getJSDocComment",
        getFirstToken: "getFirstToken",
        getFirstTokens: "getFirstTokens",
        getLastToken: "getLastToken",
        getLastTokens: "getLastTokens",
        getTokenAfter: "getTokenAfter",
        getTokenBefore: "getTokenBefore",
        getTokenByRangeStart: "getTokenByRangeStart",
        getTokens: "getTokens",
        getTokensAfter: "getTokensAfter",
        getTokensBefore: "getTokensBefore",
        getTokensBetween: "getTokensBetween"
    };
    const BASE_TRAVERSAL_CONTEXT = Object.freeze(Object.keys(DEPRECATED_SOURCECODE_PASSTHROUGHS).reduce((contextInfo, methodName) => Object.assign(contextInfo, {
        [methodName](...args) {
            return this.getSourceCode()[DEPRECATED_SOURCECODE_PASSTHROUGHS[methodName]](...args);
        }
    }), {}));
    /**
     * Runs the given rules on the given SourceCode object
     * @param {SourceCode} sourceCode A SourceCode object for the given text
     * @param {Object} configuredRules The rules configuration
     * @param {function(string): Rule} ruleMapper A mapper function from rule names to rules
     * @param {string | undefined} parserName The name of the parser in the config
     * @param {LanguageOptions} languageOptions The options for parsing the code.
     * @param {Object} settings The settings that were enabled in the config
     * @param {string} filename The reported filename of the code
     * @param {boolean} disableFixes If true, it doesn't make `fix` properties.
     * @param {string | undefined} cwd cwd of the cli
     * @param {string} physicalFilename The full path of the file on disk without any code block information
     * @returns {Problem[]} An array of reported problems
     */
    function runRules(sourceCode, configuredRules, ruleMapper, parserName, languageOptions, settings, filename, disableFixes, cwd, physicalFilename) {
        const emitter = createEmitter();
        const nodeQueue = [];
        let currentNode = sourceCode.ast;
        Traverser.traverse(sourceCode.ast, {
            enter(node, parent) {
                node.parent = parent;
                nodeQueue.push({ isEntering: true, node });
            },
            leave(node) {
                nodeQueue.push({ isEntering: false, node });
            },
            visitorKeys: sourceCode.visitorKeys
        });
        /*
         * Create a frozen object with the ruleContext properties and methods that are shared by all rules.
         * All rule contexts will inherit from this object. This avoids the performance penalty of copying all the
         * properties once for each rule.
         */
        const sharedTraversalContext = Object.freeze(Object.assign(Object.create(BASE_TRAVERSAL_CONTEXT), {
            getAncestors: () => getAncestors(currentNode),
            getDeclaredVariables: sourceCode.scopeManager.getDeclaredVariables.bind(sourceCode.scopeManager),
            getCwd: () => cwd,
            getFilename: () => filename,
            getPhysicalFilename: () => physicalFilename || filename,
            getScope: () => getScope(sourceCode.scopeManager, currentNode),
            getSourceCode: () => sourceCode,
            markVariableAsUsed: name => markVariableAsUsed(sourceCode.scopeManager, currentNode, languageOptions, name),
            parserOptions: {
                ...languageOptions.parserOptions
            },
            parserPath: parserName,
            languageOptions,
            parserServices: sourceCode.parserServices,
            settings
        }));
        const lintingProblems = [];
        Object.keys(configuredRules).forEach(ruleId => {
            const severity = ConfigOps.getRuleSeverity(configuredRules[ruleId]);
            // not load disabled rules
            if (severity === 0) {
                return;
            }
            const rule = ruleMapper(ruleId);
            if (!rule) {
                lintingProblems.push(createLintingProblem({ ruleId }));
                return;
            }
            const messageIds = rule.meta && rule.meta.messages;
            let reportTranslator = null;
            const ruleContext = Object.freeze(Object.assign(Object.create(sharedTraversalContext), {
                id: ruleId,
                options: getRuleOptions(configuredRules[ruleId]),
                report(...args) {
                    /*
                     * Create a report translator lazily.
                     * In a vast majority of cases, any given rule reports zero errors on a given
                     * piece of code. Creating a translator lazily avoids the performance cost of
                     * creating a new translator function for each rule that usually doesn't get
                     * called.
                     *
                     * Using lazy report translators improves end-to-end performance by about 3%
                     * with Node 8.4.0.
                     */
                    if (reportTranslator === null) {
                        reportTranslator = createReportTranslator({
                            ruleId,
                            severity,
                            sourceCode,
                            messageIds,
                            disableFixes
                        });
                    }
                    const problem = reportTranslator(...args);
                    if (problem.fix && !(rule.meta && rule.meta.fixable)) {
                        throw new Error("Fixable rules must set the `meta.fixable` property to \"code\" or \"whitespace\".");
                    }
                    if (problem.suggestions && !(rule.meta && rule.meta.hasSuggestions === true)) {
                        if (rule.meta && rule.meta.docs && typeof rule.meta.docs.suggestion !== "undefined") {
                            // Encourage migration from the former property name.
                            throw new Error("Rules with suggestions must set the `meta.hasSuggestions` property to `true`. `meta.docs.suggestion` is ignored by ESLint.");
                        }
                        throw new Error("Rules with suggestions must set the `meta.hasSuggestions` property to `true`.");
                    }
                    lintingProblems.push(problem);
                }
            }));
            const ruleListeners = timing.enabled ? timing.time(ruleId, createRuleListeners)(rule, ruleContext) : createRuleListeners(rule, ruleContext);
            /**
             * Include `ruleId` in error logs
             * @param {Function} ruleListener A rule method that listens for a node.
             * @returns {Function} ruleListener wrapped in error handler
             */
            function addRuleErrorHandler(ruleListener) {
                return function ruleErrorHandler(...listenerArgs) {
                    try {
                        return ruleListener(...listenerArgs);
                    }
                    catch (e) {
                        e.ruleId = ruleId;
                        throw e;
                    }
                };
            }
            if (typeof ruleListeners === "undefined" || ruleListeners === null) {
                throw new Error(`The create() function for rule '${ruleId}' did not return an object.`);
            }
            // add all the selectors from the rule as listeners
            Object.keys(ruleListeners).forEach(selector => {
                const ruleListener = timing.enabled
                    ? timing.time(ruleId, ruleListeners[selector])
                    : ruleListeners[selector];
                emitter.on(selector, addRuleErrorHandler(ruleListener));
            });
        });
        // only run code path analyzer if the top level node is "Program", skip otherwise
        const eventGenerator = nodeQueue[0].node.type === "Program"
            ? new CodePathAnalyzer(new NodeEventGenerator(emitter, { visitorKeys: sourceCode.visitorKeys, fallback: Traverser.getKeys }))
            : new NodeEventGenerator(emitter, { visitorKeys: sourceCode.visitorKeys, fallback: Traverser.getKeys });
        nodeQueue.forEach(traversalInfo => {
            currentNode = traversalInfo.node;
            try {
                if (traversalInfo.isEntering) {
                    eventGenerator.enterNode(currentNode);
                }
                else {
                    eventGenerator.leaveNode(currentNode);
                }
            }
            catch (err) {
                err.currentNode = currentNode;
                throw err;
            }
        });
        return lintingProblems;
    }
    /**
     * Ensure the source code to be a string.
     * @param {string|SourceCode} textOrSourceCode The text or source code object.
     * @returns {string} The source code text.
     */
    function ensureText(textOrSourceCode) {
        if (typeof textOrSourceCode === "object") {
            const { hasBOM, text } = textOrSourceCode;
            const bom = hasBOM ? "\uFEFF" : "";
            return bom + text;
        }
        return String(textOrSourceCode);
    }
    /**
     * Get an environment.
     * @param {LinterInternalSlots} slots The internal slots of Linter.
     * @param {string} envId The environment ID to get.
     * @returns {Environment|null} The environment.
     */
    function getEnv(slots, envId) {
        return ((slots.lastConfigArray && slots.lastConfigArray.pluginEnvironments.get(envId)) ||
            BuiltInEnvironments.get(envId) ||
            null);
    }
    /**
     * Get a rule.
     * @param {LinterInternalSlots} slots The internal slots of Linter.
     * @param {string} ruleId The rule ID to get.
     * @returns {Rule|null} The rule.
     */
    function getRule(slots, ruleId) {
        return ((slots.lastConfigArray && slots.lastConfigArray.pluginRules.get(ruleId)) ||
            slots.ruleMap.get(ruleId));
    }
    /**
     * Normalize the value of the cwd
     * @param {string | undefined} cwd raw value of the cwd, path to a directory that should be considered as the current working directory, can be undefined.
     * @returns {string | undefined} normalized cwd
     */
    function normalizeCwd(cwd) {
        if (cwd) {
            return cwd;
        }
        if (typeof process === "object") {
            return process.cwd();
        }
        // It's more explicit to assign the undefined
        // eslint-disable-next-line no-undefined -- Consistently returning a value
        return undefined;
    }
    /**
     * The map to store private data.
     * @type {WeakMap<Linter, LinterInternalSlots>}
     */
    const internalSlotsMap = new WeakMap();
    /**
     * Throws an error when the given linter is in flat config mode.
     * @param {Linter} linter The linter to check.
     * @returns {void}
     * @throws {Error} If the linter is in flat config mode.
     */
    function assertEslintrcConfig(linter) {
        const { configType } = internalSlotsMap.get(linter);
        if (configType === "flat") {
            throw new Error("This method cannot be used with flat config. Add your entries directly into the config array.");
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * Object that is responsible for verifying JavaScript text
     * @name Linter
     */
    class Linter {
        /**
         * Initialize the Linter.
         * @param {Object} [config] the config object
         * @param {string} [config.cwd] path to a directory that should be considered as the current working directory, can be undefined.
         * @param {"flat"|"eslintrc"} [config.configType="eslintrc"] the type of config used.
         */
        constructor({ cwd, configType } = {}) {
            internalSlotsMap.set(this, {
                cwd: normalizeCwd(cwd),
                lastConfigArray: null,
                lastSourceCode: null,
                lastSuppressedMessages: [],
                configType,
                parserMap: new Map([["espree", espree]]),
                ruleMap: new Rules()
            });
            this.version = pkg.version;
        }
        /**
         * Getter for package version.
         * @static
         * @returns {string} The version from package.json.
         */
        static get version() {
            return pkg.version;
        }
        /**
         * Same as linter.verify, except without support for processors.
         * @param {string|SourceCode} textOrSourceCode The text to parse or a SourceCode object.
         * @param {ConfigData} providedConfig An ESLintConfig instance to configure everything.
         * @param {VerifyOptions} [providedOptions] The optional filename of the file being checked.
         * @throws {Error} If during rule execution.
         * @returns {(LintMessage|SuppressedLintMessage)[]} The results as an array of messages or an empty array if no messages.
         */
        _verifyWithoutProcessors(textOrSourceCode, providedConfig, providedOptions) {
            const slots = internalSlotsMap.get(this);
            const config = providedConfig || {};
            const options = normalizeVerifyOptions(providedOptions, config);
            let text;
            // evaluate arguments
            if (typeof textOrSourceCode === "string") {
                slots.lastSourceCode = null;
                text = textOrSourceCode;
            }
            else {
                slots.lastSourceCode = textOrSourceCode;
                text = textOrSourceCode.text;
            }
            // Resolve parser.
            let parserName = DEFAULT_PARSER_NAME;
            let parser = espree;
            if (typeof config.parser === "object" && config.parser !== null) {
                parserName = config.parser.filePath;
                parser = config.parser.definition;
            }
            else if (typeof config.parser === "string") {
                if (!slots.parserMap.has(config.parser)) {
                    return [{
                            ruleId: null,
                            fatal: true,
                            severity: 2,
                            message: `Configured parser '${config.parser}' was not found.`,
                            line: 0,
                            column: 0
                        }];
                }
                parserName = config.parser;
                parser = slots.parserMap.get(config.parser);
            }
            // search and apply "eslint-env *".
            const envInFile = options.allowInlineConfig && !options.warnInlineConfig
                ? findEslintEnv(text)
                : {};
            const resolvedEnvConfig = Object.assign({ builtin: true }, config.env, envInFile);
            const enabledEnvs = Object.keys(resolvedEnvConfig)
                .filter(envName => resolvedEnvConfig[envName])
                .map(envName => getEnv(slots, envName))
                .filter(env => env);
            const parserOptions = resolveParserOptions(parser, config.parserOptions || {}, enabledEnvs);
            const configuredGlobals = resolveGlobals(config.globals || {}, enabledEnvs);
            const settings = config.settings || {};
            const languageOptions = createLanguageOptions({
                globals: config.globals,
                parser,
                parserOptions
            });
            if (!slots.lastSourceCode) {
                const parseResult = parse(text, languageOptions, options.filename);
                if (!parseResult.success) {
                    return [parseResult.error];
                }
                slots.lastSourceCode = parseResult.sourceCode;
            }
            else {
                /*
                 * If the given source code object as the first argument does not have scopeManager, analyze the scope.
                 * This is for backward compatibility (SourceCode is frozen so it cannot rebind).
                 */
                if (!slots.lastSourceCode.scopeManager) {
                    slots.lastSourceCode = new SourceCode({
                        text: slots.lastSourceCode.text,
                        ast: slots.lastSourceCode.ast,
                        parserServices: slots.lastSourceCode.parserServices,
                        visitorKeys: slots.lastSourceCode.visitorKeys,
                        scopeManager: analyzeScope(slots.lastSourceCode.ast, languageOptions)
                    });
                }
            }
            const sourceCode = slots.lastSourceCode;
            const commentDirectives = options.allowInlineConfig
                ? getDirectiveComments(sourceCode.ast, ruleId => getRule(slots, ruleId), options.warnInlineConfig)
                : { configuredRules: {}, enabledGlobals: {}, exportedVariables: {}, problems: [], disableDirectives: [] };
            // augment global scope with declared global variables
            addDeclaredGlobals(sourceCode.scopeManager.scopes[0], configuredGlobals, { exportedVariables: commentDirectives.exportedVariables, enabledGlobals: commentDirectives.enabledGlobals });
            const configuredRules = Object.assign({}, config.rules, commentDirectives.configuredRules);
            let lintingProblems;
            try {
                lintingProblems = runRules(sourceCode, configuredRules, ruleId => getRule(slots, ruleId), parserName, languageOptions, settings, options.filename, options.disableFixes, slots.cwd, providedOptions.physicalFilename);
            }
            catch (err) {
                err.message += `\nOccurred while linting ${options.filename}`;
                debug("An error occurred while traversing");
                debug("Filename:", options.filename);
                if (err.currentNode) {
                    const { line } = err.currentNode.loc.start;
                    debug("Line:", line);
                    err.message += `:${line}`;
                }
                debug("Parser Options:", parserOptions);
                debug("Parser Path:", parserName);
                debug("Settings:", settings);
                if (err.ruleId) {
                    err.message += `\nRule: "${err.ruleId}"`;
                }
                throw err;
            }
            return applyDisableDirectives({
                directives: commentDirectives.disableDirectives,
                disableFixes: options.disableFixes,
                problems: lintingProblems
                    .concat(commentDirectives.problems)
                    .sort((problemA, problemB) => problemA.line - problemB.line || problemA.column - problemB.column),
                reportUnusedDisableDirectives: options.reportUnusedDisableDirectives
            });
        }
        /**
         * Verifies the text against the rules specified by the second argument.
         * @param {string|SourceCode} textOrSourceCode The text to parse or a SourceCode object.
         * @param {ConfigData|ConfigArray} config An ESLintConfig instance to configure everything.
         * @param {(string|(VerifyOptions&ProcessorOptions))} [filenameOrOptions] The optional filename of the file being checked.
         *      If this is not set, the filename will default to '<input>' in the rule context. If
         *      an object, then it has "filename", "allowInlineConfig", and some properties.
         * @returns {LintMessage[]} The results as an array of messages or an empty array if no messages.
         */
        verify(textOrSourceCode, config, filenameOrOptions) {
            debug("Verify");
            const { configType } = internalSlotsMap.get(this);
            const options = typeof filenameOrOptions === "string"
                ? { filename: filenameOrOptions }
                : filenameOrOptions || {};
            if (config) {
                if (configType === "flat") {
                    /*
                     * Because of how Webpack packages up the files, we can't
                     * compare directly to `FlatConfigArray` using `instanceof`
                     * because it's not the same `FlatConfigArray` as in the tests.
                     * So, we work around it by assuming an array is, in fact, a
                     * `FlatConfigArray` if it has a `getConfig()` method.
                     */
                    let configArray = config;
                    if (!Array.isArray(config) || typeof config.getConfig !== "function") {
                        configArray = new FlatConfigArray(config);
                        configArray.normalizeSync();
                    }
                    return this._distinguishSuppressedMessages(this._verifyWithFlatConfigArray(textOrSourceCode, configArray, options, true));
                }
                if (typeof config.extractConfig === "function") {
                    return this._distinguishSuppressedMessages(this._verifyWithConfigArray(textOrSourceCode, config, options));
                }
            }
            /*
             * If we get to here, it means `config` is just an object rather
             * than a config array so we can go right into linting.
             */
            /*
             * `Linter` doesn't support `overrides` property in configuration.
             * So we cannot apply multiple processors.
             */
            if (options.preprocess || options.postprocess) {
                return this._distinguishSuppressedMessages(this._verifyWithProcessor(textOrSourceCode, config, options));
            }
            return this._distinguishSuppressedMessages(this._verifyWithoutProcessors(textOrSourceCode, config, options));
        }
        /**
         * Verify with a processor.
         * @param {string|SourceCode} textOrSourceCode The source code.
         * @param {FlatConfig} config The config array.
         * @param {VerifyOptions&ProcessorOptions} options The options.
         * @param {FlatConfigArray} [configForRecursive] The `ConfigArray` object to apply multiple processors recursively.
         * @returns {(LintMessage|SuppressedLintMessage)[]} The found problems.
         */
        _verifyWithFlatConfigArrayAndProcessor(textOrSourceCode, config, options, configForRecursive) {
            const filename = options.filename || "<input>";
            const filenameToExpose = normalizeFilename(filename);
            const physicalFilename = options.physicalFilename || filenameToExpose;
            const text = ensureText(textOrSourceCode);
            const preprocess = options.preprocess || (rawText => [rawText]);
            const postprocess = options.postprocess || (messagesList => messagesList.flat());
            const filterCodeBlock = options.filterCodeBlock ||
                (blockFilename => blockFilename.endsWith(".js"));
            const originalExtname = path.extname(filename);
            let blocks;
            try {
                blocks = preprocess(text, filenameToExpose);
            }
            catch (ex) {
                // If the message includes a leading line number, strip it:
                const message = `Preprocessing error: ${ex.message.replace(/^line \d+:/iu, "").trim()}`;
                debug("%s\n%s", message, ex.stack);
                return [
                    {
                        ruleId: null,
                        fatal: true,
                        severity: 2,
                        message,
                        line: ex.lineNumber,
                        column: ex.column
                    }
                ];
            }
            const messageLists = blocks.map((block, i) => {
                debug("A code block was found: %o", block.filename || "(unnamed)");
                // Keep the legacy behavior.
                if (typeof block === "string") {
                    return this._verifyWithFlatConfigArrayAndWithoutProcessors(block, config, options);
                }
                const blockText = block.text;
                const blockName = path.join(filename, `${i}_${block.filename}`);
                // Skip this block if filtered.
                if (!filterCodeBlock(blockName, blockText)) {
                    debug("This code block was skipped.");
                    return [];
                }
                // Resolve configuration again if the file content or extension was changed.
                if (configForRecursive && (text !== blockText || path.extname(blockName) !== originalExtname)) {
                    debug("Resolving configuration again because the file content or extension was changed.");
                    return this._verifyWithFlatConfigArray(blockText, configForRecursive, { ...options, filename: blockName, physicalFilename });
                }
                // Does lint.
                return this._verifyWithFlatConfigArrayAndWithoutProcessors(blockText, config, { ...options, filename: blockName, physicalFilename });
            });
            return postprocess(messageLists, filenameToExpose);
        }
        /**
         * Same as linter.verify, except without support for processors.
         * @param {string|SourceCode} textOrSourceCode The text to parse or a SourceCode object.
         * @param {FlatConfig} providedConfig An ESLintConfig instance to configure everything.
         * @param {VerifyOptions} [providedOptions] The optional filename of the file being checked.
         * @throws {Error} If during rule execution.
         * @returns {(LintMessage|SuppressedLintMessage)[]} The results as an array of messages or an empty array if no messages.
         */
        _verifyWithFlatConfigArrayAndWithoutProcessors(textOrSourceCode, providedConfig, providedOptions) {
            const slots = internalSlotsMap.get(this);
            const config = providedConfig || {};
            const options = normalizeVerifyOptions(providedOptions, config);
            let text;
            // evaluate arguments
            if (typeof textOrSourceCode === "string") {
                slots.lastSourceCode = null;
                text = textOrSourceCode;
            }
            else {
                slots.lastSourceCode = textOrSourceCode;
                text = textOrSourceCode.text;
            }
            const languageOptions = config.languageOptions;
            languageOptions.ecmaVersion = normalizeEcmaVersionForLanguageOptions(languageOptions.ecmaVersion);
            /*
             * add configured globals and language globals
             *
             * using Object.assign instead of object spread for performance reasons
             * https://github.com/eslint/eslint/issues/16302
             */
            const configuredGlobals = Object.assign({}, getGlobalsForEcmaVersion(languageOptions.ecmaVersion), languageOptions.sourceType === "commonjs" ? globals.commonjs : void 0, languageOptions.globals);
            // double check that there is a parser to avoid mysterious error messages
            if (!languageOptions.parser) {
                throw new TypeError(`No parser specified for ${options.filename}`);
            }
            // Espree expects this information to be passed in
            if (isEspree(languageOptions.parser)) {
                const parserOptions = languageOptions.parserOptions;
                if (languageOptions.sourceType) {
                    parserOptions.sourceType = languageOptions.sourceType;
                    if (parserOptions.sourceType === "module" &&
                        parserOptions.ecmaFeatures &&
                        parserOptions.ecmaFeatures.globalReturn) {
                        parserOptions.ecmaFeatures.globalReturn = false;
                    }
                }
            }
            const settings = config.settings || {};
            if (!slots.lastSourceCode) {
                const parseResult = parse(text, languageOptions, options.filename);
                if (!parseResult.success) {
                    return [parseResult.error];
                }
                slots.lastSourceCode = parseResult.sourceCode;
            }
            else {
                /*
                 * If the given source code object as the first argument does not have scopeManager, analyze the scope.
                 * This is for backward compatibility (SourceCode is frozen so it cannot rebind).
                 */
                if (!slots.lastSourceCode.scopeManager) {
                    slots.lastSourceCode = new SourceCode({
                        text: slots.lastSourceCode.text,
                        ast: slots.lastSourceCode.ast,
                        parserServices: slots.lastSourceCode.parserServices,
                        visitorKeys: slots.lastSourceCode.visitorKeys,
                        scopeManager: analyzeScope(slots.lastSourceCode.ast, languageOptions)
                    });
                }
            }
            const sourceCode = slots.lastSourceCode;
            const commentDirectives = options.allowInlineConfig
                ? getDirectiveComments(sourceCode.ast, ruleId => getRuleFromConfig(ruleId, config), options.warnInlineConfig)
                : { configuredRules: {}, enabledGlobals: {}, exportedVariables: {}, problems: [], disableDirectives: [] };
            // augment global scope with declared global variables
            addDeclaredGlobals(sourceCode.scopeManager.scopes[0], configuredGlobals, { exportedVariables: commentDirectives.exportedVariables, enabledGlobals: commentDirectives.enabledGlobals });
            const configuredRules = Object.assign({}, config.rules, commentDirectives.configuredRules);
            let lintingProblems;
            try {
                lintingProblems = runRules(sourceCode, configuredRules, ruleId => getRuleFromConfig(ruleId, config), void 0, languageOptions, settings, options.filename, options.disableFixes, slots.cwd, providedOptions.physicalFilename);
            }
            catch (err) {
                err.message += `\nOccurred while linting ${options.filename}`;
                debug("An error occurred while traversing");
                debug("Filename:", options.filename);
                if (err.currentNode) {
                    const { line } = err.currentNode.loc.start;
                    debug("Line:", line);
                    err.message += `:${line}`;
                }
                debug("Parser Options:", languageOptions.parserOptions);
                // debug("Parser Path:", parserName);
                debug("Settings:", settings);
                if (err.ruleId) {
                    err.message += `\nRule: "${err.ruleId}"`;
                }
                throw err;
            }
            return applyDisableDirectives({
                directives: commentDirectives.disableDirectives,
                disableFixes: options.disableFixes,
                problems: lintingProblems
                    .concat(commentDirectives.problems)
                    .sort((problemA, problemB) => problemA.line - problemB.line || problemA.column - problemB.column),
                reportUnusedDisableDirectives: options.reportUnusedDisableDirectives
            });
        }
        /**
         * Verify a given code with `ConfigArray`.
         * @param {string|SourceCode} textOrSourceCode The source code.
         * @param {ConfigArray} configArray The config array.
         * @param {VerifyOptions&ProcessorOptions} options The options.
         * @returns {(LintMessage|SuppressedLintMessage)[]} The found problems.
         */
        _verifyWithConfigArray(textOrSourceCode, configArray, options) {
            debug("With ConfigArray: %s", options.filename);
            // Store the config array in order to get plugin envs and rules later.
            internalSlotsMap.get(this).lastConfigArray = configArray;
            // Extract the final config for this file.
            const config = configArray.extractConfig(options.filename);
            const processor = config.processor &&
                configArray.pluginProcessors.get(config.processor);
            // Verify.
            if (processor) {
                debug("Apply the processor: %o", config.processor);
                const { preprocess, postprocess, supportsAutofix } = processor;
                const disableFixes = options.disableFixes || !supportsAutofix;
                return this._verifyWithProcessor(textOrSourceCode, config, { ...options, disableFixes, postprocess, preprocess }, configArray);
            }
            return this._verifyWithoutProcessors(textOrSourceCode, config, options);
        }
        /**
         * Verify a given code with a flat config.
         * @param {string|SourceCode} textOrSourceCode The source code.
         * @param {FlatConfigArray} configArray The config array.
         * @param {VerifyOptions&ProcessorOptions} options The options.
         * @param {boolean} [firstCall=false] Indicates if this is being called directly
         *      from verify(). (TODO: Remove once eslintrc is removed.)
         * @returns {(LintMessage|SuppressedLintMessage)[]} The found problems.
         */
        _verifyWithFlatConfigArray(textOrSourceCode, configArray, options, firstCall = false) {
            debug("With flat config: %s", options.filename);
            // we need a filename to match configs against
            const filename = options.filename || "__placeholder__.js";
            // Store the config array in order to get plugin envs and rules later.
            internalSlotsMap.get(this).lastConfigArray = configArray;
            const config = configArray.getConfig(filename);
            if (!config) {
                return [
                    {
                        ruleId: null,
                        severity: 1,
                        message: `No matching configuration found for ${filename}.`,
                        line: 0,
                        column: 0
                    }
                ];
            }
            // Verify.
            if (config.processor) {
                debug("Apply the processor: %o", config.processor);
                const { preprocess, postprocess, supportsAutofix } = config.processor;
                const disableFixes = options.disableFixes || !supportsAutofix;
                return this._verifyWithFlatConfigArrayAndProcessor(textOrSourceCode, config, { ...options, filename, disableFixes, postprocess, preprocess }, configArray);
            }
            // check for options-based processing
            if (firstCall && (options.preprocess || options.postprocess)) {
                return this._verifyWithFlatConfigArrayAndProcessor(textOrSourceCode, config, options);
            }
            return this._verifyWithFlatConfigArrayAndWithoutProcessors(textOrSourceCode, config, options);
        }
        /**
         * Verify with a processor.
         * @param {string|SourceCode} textOrSourceCode The source code.
         * @param {ConfigData|ExtractedConfig} config The config array.
         * @param {VerifyOptions&ProcessorOptions} options The options.
         * @param {ConfigArray} [configForRecursive] The `ConfigArray` object to apply multiple processors recursively.
         * @returns {(LintMessage|SuppressedLintMessage)[]} The found problems.
         */
        _verifyWithProcessor(textOrSourceCode, config, options, configForRecursive) {
            const filename = options.filename || "<input>";
            const filenameToExpose = normalizeFilename(filename);
            const physicalFilename = options.physicalFilename || filenameToExpose;
            const text = ensureText(textOrSourceCode);
            const preprocess = options.preprocess || (rawText => [rawText]);
            const postprocess = options.postprocess || (messagesList => messagesList.flat());
            const filterCodeBlock = options.filterCodeBlock ||
                (blockFilename => blockFilename.endsWith(".js"));
            const originalExtname = path.extname(filename);
            let blocks;
            try {
                blocks = preprocess(text, filenameToExpose);
            }
            catch (ex) {
                // If the message includes a leading line number, strip it:
                const message = `Preprocessing error: ${ex.message.replace(/^line \d+:/iu, "").trim()}`;
                debug("%s\n%s", message, ex.stack);
                return [
                    {
                        ruleId: null,
                        fatal: true,
                        severity: 2,
                        message,
                        line: ex.lineNumber,
                        column: ex.column
                    }
                ];
            }
            const messageLists = blocks.map((block, i) => {
                debug("A code block was found: %o", block.filename || "(unnamed)");
                // Keep the legacy behavior.
                if (typeof block === "string") {
                    return this._verifyWithoutProcessors(block, config, options);
                }
                const blockText = block.text;
                const blockName = path.join(filename, `${i}_${block.filename}`);
                // Skip this block if filtered.
                if (!filterCodeBlock(blockName, blockText)) {
                    debug("This code block was skipped.");
                    return [];
                }
                // Resolve configuration again if the file content or extension was changed.
                if (configForRecursive && (text !== blockText || path.extname(blockName) !== originalExtname)) {
                    debug("Resolving configuration again because the file content or extension was changed.");
                    return this._verifyWithConfigArray(blockText, configForRecursive, { ...options, filename: blockName, physicalFilename });
                }
                // Does lint.
                return this._verifyWithoutProcessors(blockText, config, { ...options, filename: blockName, physicalFilename });
            });
            return postprocess(messageLists, filenameToExpose);
        }
        /**
         * Given a list of reported problems, distinguish problems between normal messages and suppressed messages.
         * The normal messages will be returned and the suppressed messages will be stored as lastSuppressedMessages.
         * @param {Problem[]} problems A list of reported problems.
         * @returns {LintMessage[]} A list of LintMessage.
         */
        _distinguishSuppressedMessages(problems) {
            const messages = [];
            const suppressedMessages = [];
            const slots = internalSlotsMap.get(this);
            for (const problem of problems) {
                if (problem.suppressions) {
                    suppressedMessages.push(problem);
                }
                else {
                    messages.push(problem);
                }
            }
            slots.lastSuppressedMessages = suppressedMessages;
            return messages;
        }
        /**
         * Gets the SourceCode object representing the parsed source.
         * @returns {SourceCode} The SourceCode object.
         */
        getSourceCode() {
            return internalSlotsMap.get(this).lastSourceCode;
        }
        /**
         * Gets the list of SuppressedLintMessage produced in the last running.
         * @returns {SuppressedLintMessage[]} The list of SuppressedLintMessage
         */
        getSuppressedMessages() {
            return internalSlotsMap.get(this).lastSuppressedMessages;
        }
        /**
         * Defines a new linting rule.
         * @param {string} ruleId A unique rule identifier
         * @param {Function | Rule} ruleModule Function from context to object mapping AST node types to event handlers
         * @returns {void}
         */
        defineRule(ruleId, ruleModule) {
            assertEslintrcConfig(this);
            internalSlotsMap.get(this).ruleMap.define(ruleId, ruleModule);
        }
        /**
         * Defines many new linting rules.
         * @param {Record<string, Function | Rule>} rulesToDefine map from unique rule identifier to rule
         * @returns {void}
         */
        defineRules(rulesToDefine) {
            assertEslintrcConfig(this);
            Object.getOwnPropertyNames(rulesToDefine).forEach(ruleId => {
                this.defineRule(ruleId, rulesToDefine[ruleId]);
            });
        }
        /**
         * Gets an object with all loaded rules.
         * @returns {Map<string, Rule>} All loaded rules
         */
        getRules() {
            assertEslintrcConfig(this);
            const { lastConfigArray, ruleMap } = internalSlotsMap.get(this);
            return new Map(function* () {
                yield* ruleMap;
                if (lastConfigArray) {
                    yield* lastConfigArray.pluginRules;
                }
            }());
        }
        /**
         * Define a new parser module
         * @param {string} parserId Name of the parser
         * @param {Parser} parserModule The parser object
         * @returns {void}
         */
        defineParser(parserId, parserModule) {
            assertEslintrcConfig(this);
            internalSlotsMap.get(this).parserMap.set(parserId, parserModule);
        }
        /**
         * Performs multiple autofix passes over the text until as many fixes as possible
         * have been applied.
         * @param {string} text The source text to apply fixes to.
         * @param {ConfigData|ConfigArray|FlatConfigArray} config The ESLint config object to use.
         * @param {VerifyOptions&ProcessorOptions&FixOptions} options The ESLint options object to use.
         * @returns {{fixed:boolean,messages:LintMessage[],output:string}} The result of the fix operation as returned from the
         *      SourceCodeFixer.
         */
        verifyAndFix(text, config, options) {
            let messages = [], fixedResult, fixed = false, passNumber = 0, currentText = text;
            const debugTextDescription = options && options.filename || `${text.slice(0, 10)}...`;
            const shouldFix = options && typeof options.fix !== "undefined" ? options.fix : true;
            /**
             * This loop continues until one of the following is true:
             *
             * 1. No more fixes have been applied.
             * 2. Ten passes have been made.
             *
             * That means anytime a fix is successfully applied, there will be another pass.
             * Essentially, guaranteeing a minimum of two passes.
             */
            do {
                passNumber++;
                debug(`Linting code for ${debugTextDescription} (pass ${passNumber})`);
                messages = this.verify(currentText, config, options);
                debug(`Generating fixed text for ${debugTextDescription} (pass ${passNumber})`);
                fixedResult = SourceCodeFixer.applyFixes(currentText, messages, shouldFix);
                /*
                 * stop if there are any syntax errors.
                 * 'fixedResult.output' is a empty string.
                 */
                if (messages.length === 1 && messages[0].fatal) {
                    break;
                }
                // keep track if any fixes were ever applied - important for return value
                fixed = fixed || fixedResult.fixed;
                // update to use the fixed output instead of the original text
                currentText = fixedResult.output;
            } while (fixedResult.fixed &&
                passNumber < MAX_AUTOFIX_PASSES);
            /*
             * If the last result had fixes, we need to lint again to be sure we have
             * the most up-to-date information.
             */
            if (fixedResult.fixed) {
                fixedResult.messages = this.verify(currentText, config, options);
            }
            // ensure the last result properly reflects if fixes were done
            fixedResult.fixed = fixed;
            fixedResult.output = currentText;
            return fixedResult;
        }
    }
    module.exports = {
        Linter,
        /**
         * Get the internal slots of a given Linter instance for tests.
         * @param {Linter} instance The Linter instance to get.
         * @returns {LinterInternalSlots} The internal slots.
         */
        getLinterInternalSlots(instance) {
            return internalSlotsMap.get(instance);
        }
    };
},
/* eslint-scope/lib/index.js */ function _(require, module, exports, __esModule, __esExport) {/*
      Copyright (C) 2012-2014 Yusuke Suzuki <utatane.tea@gmail.com>
      Copyright (C) 2013 Alex Seville <hi@alexanderseville.com>
      Copyright (C) 2014 Thiago de Arruda <tpadilha84@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    /**
     * Escope (<a href="http://github.com/estools/escope">escope</a>) is an <a
     * href="http://www.ecma-international.org/publications/standards/Ecma-262.htm">ECMAScript</a>
     * scope analyzer extracted from the <a
     * href="http://github.com/estools/esmangle">esmangle project</a/>.
     * <p>
     * <em>escope</em> finds lexical scopes in a source program, i.e. areas of that
     * program where different occurrences of the same identifier refer to the same
     * variable. With each scope the contained variables are collected, and each
     * identifier reference in code is linked to its corresponding variable (if
     * possible).
     * <p>
     * <em>escope</em> works on a syntax tree of the parsed source code which has
     * to adhere to the <a
     * href="https://developer.mozilla.org/en-US/docs/SpiderMonkey/Parser_API">
     * Mozilla Parser API</a>. E.g. <a href="https://github.com/eslint/espree">espree</a> is a parser
     * that produces such syntax trees.
     * <p>
     * The main interface is the {@link analyze} function.
     * @module escope
     */
    "use strict";
    /* eslint no-underscore-dangle: ["error", { "allow": ["__currentScope"] }] */
    const assert = require("assert");
    const ScopeManager = require(292) /* ./scope-manager */;
    const Referencer = require(299) /* ./referencer */;
    const Reference = require(296) /* ./reference */;
    const Variable = require(297) /* ./variable */;
    const Scope = require(293) /* ./scope */.Scope;
    const version = require(303) /* ../package.json */.version;
    /**
     * Set the default options
     * @returns {Object} options
     */
    function defaultOptions() {
        return {
            optimistic: false,
            directive: false,
            nodejsScope: false,
            impliedStrict: false,
            sourceType: "script",
            ecmaVersion: 5,
            childVisitorKeys: null,
            fallback: "iteration"
        };
    }
    /**
     * Preform deep update on option object
     * @param {Object} target - Options
     * @param {Object} override - Updates
     * @returns {Object} Updated options
     */
    function updateDeeply(target, override) {
        /**
         * Is hash object
         * @param {Object} value - Test value
         * @returns {boolean} Result
         */
        function isHashObject(value) {
            return typeof value === "object" && value instanceof Object && !(value instanceof Array) && !(value instanceof RegExp);
        }
        for (const key in override) {
            if (Object.prototype.hasOwnProperty.call(override, key)) {
                const val = override[key];
                if (isHashObject(val)) {
                    if (isHashObject(target[key])) {
                        updateDeeply(target[key], val);
                    }
                    else {
                        target[key] = updateDeeply({}, val);
                    }
                }
                else {
                    target[key] = val;
                }
            }
        }
        return target;
    }
    /**
     * Main interface function. Takes an Espree syntax tree and returns the
     * analyzed scopes.
     * @function analyze
     * @param {espree.Tree} tree - Abstract Syntax Tree
     * @param {Object} providedOptions - Options that tailor the scope analysis
     * @param {boolean} [providedOptions.optimistic=false] - the optimistic flag
     * @param {boolean} [providedOptions.directive=false]- the directive flag
     * @param {boolean} [providedOptions.ignoreEval=false]- whether to check 'eval()' calls
     * @param {boolean} [providedOptions.nodejsScope=false]- whether the whole
     * script is executed under node.js environment. When enabled, escope adds
     * a function scope immediately following the global scope.
     * @param {boolean} [providedOptions.impliedStrict=false]- implied strict mode
     * (if ecmaVersion >= 5).
     * @param {string} [providedOptions.sourceType='script']- the source type of the script. one of 'script' and 'module'
     * @param {number} [providedOptions.ecmaVersion=5]- which ECMAScript version is considered
     * @param {Object} [providedOptions.childVisitorKeys=null] - Additional known visitor keys. See [esrecurse](https://github.com/estools/esrecurse)'s the `childVisitorKeys` option.
     * @param {string} [providedOptions.fallback='iteration'] - A kind of the fallback in order to encounter with unknown node. See [esrecurse](https://github.com/estools/esrecurse)'s the `fallback` option.
     * @returns {ScopeManager} ScopeManager
     */
    function analyze(tree, providedOptions) {
        const options = updateDeeply(defaultOptions(), providedOptions);
        const scopeManager = new ScopeManager(options);
        const referencer = new Referencer(options, scopeManager);
        referencer.visit(tree);
        assert(scopeManager.__currentScope === null, "currentScope should be null.");
        return scopeManager;
    }
    module.exports = {
        /** @name module:escope.version */
        version,
        /** @name module:escope.Reference */
        Reference,
        /** @name module:escope.Variable */
        Variable,
        /** @name module:escope.Scope */
        Scope,
        /** @name module:escope.ScopeManager */
        ScopeManager,
        analyze
    };
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* eslint-scope/lib/scope-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
      Copyright (C) 2015 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    "use strict";
    /* eslint-disable no-underscore-dangle */
    const Scope = require(293) /* ./scope */;
    const assert = require("assert");
    const GlobalScope = Scope.GlobalScope;
    const CatchScope = Scope.CatchScope;
    const WithScope = Scope.WithScope;
    const ModuleScope = Scope.ModuleScope;
    const ClassScope = Scope.ClassScope;
    const SwitchScope = Scope.SwitchScope;
    const FunctionScope = Scope.FunctionScope;
    const ForScope = Scope.ForScope;
    const FunctionExpressionNameScope = Scope.FunctionExpressionNameScope;
    const BlockScope = Scope.BlockScope;
    /**
     * @class ScopeManager
     */
    class ScopeManager {
        constructor(options) {
            this.scopes = [];
            this.globalScope = null;
            this.__nodeToScope = new WeakMap();
            this.__currentScope = null;
            this.__options = options;
            this.__declaredVariables = new WeakMap();
        }
        __useDirective() {
            return this.__options.directive;
        }
        __isOptimistic() {
            return this.__options.optimistic;
        }
        __ignoreEval() {
            return this.__options.ignoreEval;
        }
        __isNodejsScope() {
            return this.__options.nodejsScope;
        }
        isModule() {
            return this.__options.sourceType === "module";
        }
        isImpliedStrict() {
            return this.__options.impliedStrict;
        }
        isStrictModeSupported() {
            return this.__options.ecmaVersion >= 5;
        }
        // Returns appropriate scope for this node.
        __get(node) {
            return this.__nodeToScope.get(node);
        }
        /**
         * Get variables that are declared by the node.
         *
         * "are declared by the node" means the node is same as `Variable.defs[].node` or `Variable.defs[].parent`.
         * If the node declares nothing, this method returns an empty array.
         * CAUTION: This API is experimental. See https://github.com/estools/escope/pull/69 for more details.
         *
         * @param {Espree.Node} node - a node to get.
         * @returns {Variable[]} variables that declared by the node.
         */
        getDeclaredVariables(node) {
            return this.__declaredVariables.get(node) || [];
        }
        /**
         * acquire scope from node.
         * @method ScopeManager#acquire
         * @param {Espree.Node} node - node for the acquired scope.
         * @param {boolean=} inner - look up the most inner scope, default value is false.
         * @returns {Scope?} Scope from node
         */
        acquire(node, inner) {
            /**
             * predicate
             * @param {Scope} testScope - scope to test
             * @returns {boolean} predicate
             */
            function predicate(testScope) {
                if (testScope.type === "function" && testScope.functionExpressionScope) {
                    return false;
                }
                return true;
            }
            const scopes = this.__get(node);
            if (!scopes || scopes.length === 0) {
                return null;
            }
            // Heuristic selection from all scopes.
            // If you would like to get all scopes, please use ScopeManager#acquireAll.
            if (scopes.length === 1) {
                return scopes[0];
            }
            if (inner) {
                for (let i = scopes.length - 1; i >= 0; --i) {
                    const scope = scopes[i];
                    if (predicate(scope)) {
                        return scope;
                    }
                }
            }
            else {
                for (let i = 0, iz = scopes.length; i < iz; ++i) {
                    const scope = scopes[i];
                    if (predicate(scope)) {
                        return scope;
                    }
                }
            }
            return null;
        }
        /**
         * acquire all scopes from node.
         * @method ScopeManager#acquireAll
         * @param {Espree.Node} node - node for the acquired scope.
         * @returns {Scopes?} Scope array
         */
        acquireAll(node) {
            return this.__get(node);
        }
        /**
         * release the node.
         * @method ScopeManager#release
         * @param {Espree.Node} node - releasing node.
         * @param {boolean=} inner - look up the most inner scope, default value is false.
         * @returns {Scope?} upper scope for the node.
         */
        release(node, inner) {
            const scopes = this.__get(node);
            if (scopes && scopes.length) {
                const scope = scopes[0].upper;
                if (!scope) {
                    return null;
                }
                return this.acquire(scope.block, inner);
            }
            return null;
        }
        attach() { } // eslint-disable-line class-methods-use-this
        detach() { } // eslint-disable-line class-methods-use-this
        __nestScope(scope) {
            if (scope instanceof GlobalScope) {
                assert(this.__currentScope === null);
                this.globalScope = scope;
            }
            this.__currentScope = scope;
            return scope;
        }
        __nestGlobalScope(node) {
            return this.__nestScope(new GlobalScope(this, node));
        }
        __nestBlockScope(node) {
            return this.__nestScope(new BlockScope(this, this.__currentScope, node));
        }
        __nestFunctionScope(node, isMethodDefinition) {
            return this.__nestScope(new FunctionScope(this, this.__currentScope, node, isMethodDefinition));
        }
        __nestForScope(node) {
            return this.__nestScope(new ForScope(this, this.__currentScope, node));
        }
        __nestCatchScope(node) {
            return this.__nestScope(new CatchScope(this, this.__currentScope, node));
        }
        __nestWithScope(node) {
            return this.__nestScope(new WithScope(this, this.__currentScope, node));
        }
        __nestClassScope(node) {
            return this.__nestScope(new ClassScope(this, this.__currentScope, node));
        }
        __nestSwitchScope(node) {
            return this.__nestScope(new SwitchScope(this, this.__currentScope, node));
        }
        __nestModuleScope(node) {
            return this.__nestScope(new ModuleScope(this, this.__currentScope, node));
        }
        __nestFunctionExpressionNameScope(node) {
            return this.__nestScope(new FunctionExpressionNameScope(this, this.__currentScope, node));
        }
        __isES6() {
            return this.__options.ecmaVersion >= 6;
        }
    }
    module.exports = ScopeManager;
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* eslint-scope/lib/scope.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
      Copyright (C) 2015 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    "use strict";
    /* eslint-disable no-underscore-dangle */
    /* eslint-disable no-undefined */
    const Syntax = require(294) /* estraverse */.Syntax;
    const Reference = require(296) /* ./reference */;
    const Variable = require(297) /* ./variable */;
    const Definition = require(298) /* ./definition */.Definition;
    const assert = require("assert");
    /**
     * Test if scope is struct
     * @param {Scope} scope - scope
     * @param {Block} block - block
     * @param {boolean} isMethodDefinition - is method definition
     * @param {boolean} useDirective - use directive
     * @returns {boolean} is strict scope
     */
    function isStrictScope(scope, block, isMethodDefinition, useDirective) {
        let body;
        // When upper scope is exists and strict, inner scope is also strict.
        if (scope.upper && scope.upper.isStrict) {
            return true;
        }
        if (isMethodDefinition) {
            return true;
        }
        if (scope.type === "class" || scope.type === "module") {
            return true;
        }
        if (scope.type === "block" || scope.type === "switch") {
            return false;
        }
        if (scope.type === "function") {
            if (block.type === Syntax.ArrowFunctionExpression && block.body.type !== Syntax.BlockStatement) {
                return false;
            }
            if (block.type === Syntax.Program) {
                body = block;
            }
            else {
                body = block.body;
            }
            if (!body) {
                return false;
            }
        }
        else if (scope.type === "global") {
            body = block;
        }
        else {
            return false;
        }
        // Search 'use strict' directive.
        if (useDirective) {
            for (let i = 0, iz = body.body.length; i < iz; ++i) {
                const stmt = body.body[i];
                if (stmt.type !== Syntax.DirectiveStatement) {
                    break;
                }
                if (stmt.raw === "\"use strict\"" || stmt.raw === "'use strict'") {
                    return true;
                }
            }
        }
        else {
            for (let i = 0, iz = body.body.length; i < iz; ++i) {
                const stmt = body.body[i];
                if (stmt.type !== Syntax.ExpressionStatement) {
                    break;
                }
                const expr = stmt.expression;
                if (expr.type !== Syntax.Literal || typeof expr.value !== "string") {
                    break;
                }
                if (expr.raw !== null && expr.raw !== undefined) {
                    if (expr.raw === "\"use strict\"" || expr.raw === "'use strict'") {
                        return true;
                    }
                }
                else {
                    if (expr.value === "use strict") {
                        return true;
                    }
                }
            }
        }
        return false;
    }
    /**
     * Register scope
     * @param {ScopeManager} scopeManager - scope manager
     * @param {Scope} scope - scope
     * @returns {void}
     */
    function registerScope(scopeManager, scope) {
        scopeManager.scopes.push(scope);
        const scopes = scopeManager.__nodeToScope.get(scope.block);
        if (scopes) {
            scopes.push(scope);
        }
        else {
            scopeManager.__nodeToScope.set(scope.block, [scope]);
        }
    }
    /**
     * Should be statically
     * @param {Object} def - def
     * @returns {boolean} should be statically
     */
    function shouldBeStatically(def) {
        return ((def.type === Variable.ClassName) ||
            (def.type === Variable.Variable && def.parent.kind !== "var"));
    }
    /**
     * @class Scope
     */
    class Scope {
        constructor(scopeManager, type, upperScope, block, isMethodDefinition) {
            /**
             * One of 'module', 'block', 'switch', 'function', 'catch', 'with', 'function', 'class', 'global'.
             * @member {String} Scope#type
             */
            this.type = type;
            /**
             * The scoped {@link Variable}s of this scope, as <code>{ Variable.name
             * : Variable }</code>.
             * @member {Map} Scope#set
             */
            this.set = new Map();
            /**
             * The tainted variables of this scope, as <code>{ Variable.name :
             * boolean }</code>.
             * @member {Map} Scope#taints */
            this.taints = new Map();
            /**
             * Generally, through the lexical scoping of JS you can always know
             * which variable an identifier in the source code refers to. There are
             * a few exceptions to this rule. With 'global' and 'with' scopes you
             * can only decide at runtime which variable a reference refers to.
             * Moreover, if 'eval()' is used in a scope, it might introduce new
             * bindings in this or its parent scopes.
             * All those scopes are considered 'dynamic'.
             * @member {boolean} Scope#dynamic
             */
            this.dynamic = this.type === "global" || this.type === "with";
            /**
             * A reference to the scope-defining syntax node.
             * @member {espree.Node} Scope#block
             */
            this.block = block;
            /**
             * The {@link Reference|references} that are not resolved with this scope.
             * @member {Reference[]} Scope#through
             */
            this.through = [];
            /**
             * The scoped {@link Variable}s of this scope. In the case of a
             * 'function' scope this includes the automatic argument <em>arguments</em> as
             * its first element, as well as all further formal arguments.
             * @member {Variable[]} Scope#variables
             */
            this.variables = [];
            /**
             * Any variable {@link Reference|reference} found in this scope. This
             * includes occurrences of local variables as well as variables from
             * parent scopes (including the global scope). For local variables
             * this also includes defining occurrences (like in a 'var' statement).
             * In a 'function' scope this does not include the occurrences of the
             * formal parameter in the parameter list.
             * @member {Reference[]} Scope#references
             */
            this.references = [];
            /**
             * For 'global' and 'function' scopes, this is a self-reference. For
             * other scope types this is the <em>variableScope</em> value of the
             * parent scope.
             * @member {Scope} Scope#variableScope
             */
            this.variableScope =
                (this.type === "global" || this.type === "function" || this.type === "module") ? this : upperScope.variableScope;
            /**
             * Whether this scope is created by a FunctionExpression.
             * @member {boolean} Scope#functionExpressionScope
             */
            this.functionExpressionScope = false;
            /**
             * Whether this is a scope that contains an 'eval()' invocation.
             * @member {boolean} Scope#directCallToEvalScope
             */
            this.directCallToEvalScope = false;
            /**
             * @member {boolean} Scope#thisFound
             */
            this.thisFound = false;
            this.__left = [];
            /**
             * Reference to the parent {@link Scope|scope}.
             * @member {Scope} Scope#upper
             */
            this.upper = upperScope;
            /**
             * Whether 'use strict' is in effect in this scope.
             * @member {boolean} Scope#isStrict
             */
            this.isStrict = isStrictScope(this, block, isMethodDefinition, scopeManager.__useDirective());
            /**
             * List of nested {@link Scope}s.
             * @member {Scope[]} Scope#childScopes
             */
            this.childScopes = [];
            if (this.upper) {
                this.upper.childScopes.push(this);
            }
            this.__declaredVariables = scopeManager.__declaredVariables;
            registerScope(scopeManager, this);
        }
        __shouldStaticallyClose(scopeManager) {
            return (!this.dynamic || scopeManager.__isOptimistic());
        }
        __shouldStaticallyCloseForGlobal(ref) {
            // On global scope, let/const/class declarations should be resolved statically.
            const name = ref.identifier.name;
            if (!this.set.has(name)) {
                return false;
            }
            const variable = this.set.get(name);
            const defs = variable.defs;
            return defs.length > 0 && defs.every(shouldBeStatically);
        }
        __staticCloseRef(ref) {
            if (!this.__resolve(ref)) {
                this.__delegateToUpperScope(ref);
            }
        }
        __dynamicCloseRef(ref) {
            // notify all names are through to global
            let current = this;
            do {
                current.through.push(ref);
                current = current.upper;
            } while (current);
        }
        __globalCloseRef(ref) {
            // let/const/class declarations should be resolved statically.
            // others should be resolved dynamically.
            if (this.__shouldStaticallyCloseForGlobal(ref)) {
                this.__staticCloseRef(ref);
            }
            else {
                this.__dynamicCloseRef(ref);
            }
        }
        __close(scopeManager) {
            let closeRef;
            if (this.__shouldStaticallyClose(scopeManager)) {
                closeRef = this.__staticCloseRef;
            }
            else if (this.type !== "global") {
                closeRef = this.__dynamicCloseRef;
            }
            else {
                closeRef = this.__globalCloseRef;
            }
            // Try Resolving all references in this scope.
            for (let i = 0, iz = this.__left.length; i < iz; ++i) {
                const ref = this.__left[i];
                closeRef.call(this, ref);
            }
            this.__left = null;
            return this.upper;
        }
        // To override by function scopes.
        // References in default parameters isn't resolved to variables which are in their function body.
        __isValidResolution(ref, variable) {
            return true;
        }
        __resolve(ref) {
            const name = ref.identifier.name;
            if (!this.set.has(name)) {
                return false;
            }
            const variable = this.set.get(name);
            if (!this.__isValidResolution(ref, variable)) {
                return false;
            }
            variable.references.push(ref);
            variable.stack = variable.stack && ref.from.variableScope === this.variableScope;
            if (ref.tainted) {
                variable.tainted = true;
                this.taints.set(variable.name, true);
            }
            ref.resolved = variable;
            return true;
        }
        __delegateToUpperScope(ref) {
            if (this.upper) {
                this.upper.__left.push(ref);
            }
            this.through.push(ref);
        }
        __addDeclaredVariablesOfNode(variable, node) {
            if (node === null || node === undefined) {
                return;
            }
            let variables = this.__declaredVariables.get(node);
            if (variables === null || variables === undefined) {
                variables = [];
                this.__declaredVariables.set(node, variables);
            }
            if (variables.indexOf(variable) === -1) {
                variables.push(variable);
            }
        }
        __defineGeneric(name, set, variables, node, def) {
            let variable;
            variable = set.get(name);
            if (!variable) {
                variable = new Variable(name, this);
                set.set(name, variable);
                variables.push(variable);
            }
            if (def) {
                variable.defs.push(def);
                this.__addDeclaredVariablesOfNode(variable, def.node);
                this.__addDeclaredVariablesOfNode(variable, def.parent);
            }
            if (node) {
                variable.identifiers.push(node);
            }
        }
        __define(node, def) {
            if (node && node.type === Syntax.Identifier) {
                this.__defineGeneric(node.name, this.set, this.variables, node, def);
            }
        }
        __referencing(node, assign, writeExpr, maybeImplicitGlobal, partial, init) {
            // because Array element may be null
            if (!node || node.type !== Syntax.Identifier) {
                return;
            }
            // Specially handle like `this`.
            if (node.name === "super") {
                return;
            }
            const ref = new Reference(node, this, assign || Reference.READ, writeExpr, maybeImplicitGlobal, !!partial, !!init);
            this.references.push(ref);
            this.__left.push(ref);
        }
        __detectEval() {
            let current = this;
            this.directCallToEvalScope = true;
            do {
                current.dynamic = true;
                current = current.upper;
            } while (current);
        }
        __detectThis() {
            this.thisFound = true;
        }
        __isClosed() {
            return this.__left === null;
        }
        /**
         * returns resolved {Reference}
         * @method Scope#resolve
         * @param {Espree.Identifier} ident - identifier to be resolved.
         * @returns {Reference} reference
         */
        resolve(ident) {
            let ref, i, iz;
            assert(this.__isClosed(), "Scope should be closed.");
            assert(ident.type === Syntax.Identifier, "Target should be identifier.");
            for (i = 0, iz = this.references.length; i < iz; ++i) {
                ref = this.references[i];
                if (ref.identifier === ident) {
                    return ref;
                }
            }
            return null;
        }
        /**
         * returns this scope is static
         * @method Scope#isStatic
         * @returns {boolean} static
         */
        isStatic() {
            return !this.dynamic;
        }
        /**
         * returns this scope has materialized arguments
         * @method Scope#isArgumentsMaterialized
         * @returns {boolean} arguemnts materialized
         */
        isArgumentsMaterialized() {
            return true;
        }
        /**
         * returns this scope has materialized `this` reference
         * @method Scope#isThisMaterialized
         * @returns {boolean} this materialized
         */
        isThisMaterialized() {
            return true;
        }
        isUsedName(name) {
            if (this.set.has(name)) {
                return true;
            }
            for (let i = 0, iz = this.through.length; i < iz; ++i) {
                if (this.through[i].identifier.name === name) {
                    return true;
                }
            }
            return false;
        }
    }
    class GlobalScope extends Scope {
        constructor(scopeManager, block) {
            super(scopeManager, "global", null, block, false);
            this.implicit = {
                set: new Map(),
                variables: [],
                /**
                * List of {@link Reference}s that are left to be resolved (i.e. which
                * need to be linked to the variable they refer to).
                * @member {Reference[]} Scope#implicit#left
                */
                left: []
            };
        }
        __close(scopeManager) {
            const implicit = [];
            for (let i = 0, iz = this.__left.length; i < iz; ++i) {
                const ref = this.__left[i];
                if (ref.__maybeImplicitGlobal && !this.set.has(ref.identifier.name)) {
                    implicit.push(ref.__maybeImplicitGlobal);
                }
            }
            // create an implicit global variable from assignment expression
            for (let i = 0, iz = implicit.length; i < iz; ++i) {
                const info = implicit[i];
                this.__defineImplicit(info.pattern, new Definition(Variable.ImplicitGlobalVariable, info.pattern, info.node, null, null, null));
            }
            this.implicit.left = this.__left;
            return super.__close(scopeManager);
        }
        __defineImplicit(node, def) {
            if (node && node.type === Syntax.Identifier) {
                this.__defineGeneric(node.name, this.implicit.set, this.implicit.variables, node, def);
            }
        }
    }
    class ModuleScope extends Scope {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, "module", upperScope, block, false);
        }
    }
    class FunctionExpressionNameScope extends Scope {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, "function-expression-name", upperScope, block, false);
            this.__define(block.id, new Definition(Variable.FunctionName, block.id, block, null, null, null));
            this.functionExpressionScope = true;
        }
    }
    class CatchScope extends Scope {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, "catch", upperScope, block, false);
        }
    }
    class WithScope extends Scope {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, "with", upperScope, block, false);
        }
        __close(scopeManager) {
            if (this.__shouldStaticallyClose(scopeManager)) {
                return super.__close(scopeManager);
            }
            for (let i = 0, iz = this.__left.length; i < iz; ++i) {
                const ref = this.__left[i];
                ref.tainted = true;
                this.__delegateToUpperScope(ref);
            }
            this.__left = null;
            return this.upper;
        }
    }
    class BlockScope extends Scope {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, "block", upperScope, block, false);
        }
    }
    class SwitchScope extends Scope {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, "switch", upperScope, block, false);
        }
    }
    class FunctionScope extends Scope {
        constructor(scopeManager, upperScope, block, isMethodDefinition) {
            super(scopeManager, "function", upperScope, block, isMethodDefinition);
            // section 9.2.13, FunctionDeclarationInstantiation.
            // NOTE Arrow functions never have an arguments objects.
            if (this.block.type !== Syntax.ArrowFunctionExpression) {
                this.__defineArguments();
            }
        }
        isArgumentsMaterialized() {
            // TODO(Constellation)
            // We can more aggressive on this condition like this.
            //
            // function t() {
            //     // arguments of t is always hidden.
            //     function arguments() {
            //     }
            // }
            if (this.block.type === Syntax.ArrowFunctionExpression) {
                return false;
            }
            if (!this.isStatic()) {
                return true;
            }
            const variable = this.set.get("arguments");
            assert(variable, "Always have arguments variable.");
            return variable.tainted || variable.references.length !== 0;
        }
        isThisMaterialized() {
            if (!this.isStatic()) {
                return true;
            }
            return this.thisFound;
        }
        __defineArguments() {
            this.__defineGeneric("arguments", this.set, this.variables, null, null);
            this.taints.set("arguments", true);
        }
        // References in default parameters isn't resolved to variables which are in their function body.
        //     const x = 1
        //     function f(a = x) { // This `x` is resolved to the `x` in the outer scope.
        //         const x = 2
        //         console.log(a)
        //     }
        __isValidResolution(ref, variable) {
            // If `options.nodejsScope` is true, `this.block` becomes a Program node.
            if (this.block.type === "Program") {
                return true;
            }
            const bodyStart = this.block.body.range[0];
            // It's invalid resolution in the following case:
            return !(variable.scope === this &&
                ref.identifier.range[0] < bodyStart && // the reference is in the parameter part.
                variable.defs.every(d => d.name.range[0] >= bodyStart) // the variable is in the body.
            );
        }
    }
    class ForScope extends Scope {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, "for", upperScope, block, false);
        }
    }
    class ClassScope extends Scope {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, "class", upperScope, block, false);
        }
    }
    module.exports = {
        Scope,
        GlobalScope,
        ModuleScope,
        FunctionExpressionNameScope,
        CatchScope,
        WithScope,
        BlockScope,
        SwitchScope,
        FunctionScope,
        ForScope,
        ClassScope
    };
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* estraverse/estraverse.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
      Copyright (C) 2012-2013 Yusuke Suzuki <utatane.tea@gmail.com>
      Copyright (C) 2012 Ariya Hidayat <ariya.hidayat@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    /*jslint vars:false, bitwise:true*/
    /*jshint indent:4*/
    /*global exports:true*/
    (function clone(exports) {
        'use strict';
        var Syntax, VisitorOption, VisitorKeys, BREAK, SKIP, REMOVE;
        function deepCopy(obj) {
            var ret = {}, key, val;
            for (key in obj) {
                if (obj.hasOwnProperty(key)) {
                    val = obj[key];
                    if (typeof val === 'object' && val !== null) {
                        ret[key] = deepCopy(val);
                    }
                    else {
                        ret[key] = val;
                    }
                }
            }
            return ret;
        }
        // based on LLVM libc++ upper_bound / lower_bound
        // MIT License
        function upperBound(array, func) {
            var diff, len, i, current;
            len = array.length;
            i = 0;
            while (len) {
                diff = len >>> 1;
                current = i + diff;
                if (func(array[current])) {
                    len = diff;
                }
                else {
                    i = current + 1;
                    len -= diff + 1;
                }
            }
            return i;
        }
        Syntax = {
            AssignmentExpression: 'AssignmentExpression',
            AssignmentPattern: 'AssignmentPattern',
            ArrayExpression: 'ArrayExpression',
            ArrayPattern: 'ArrayPattern',
            ArrowFunctionExpression: 'ArrowFunctionExpression',
            AwaitExpression: 'AwaitExpression',
            BlockStatement: 'BlockStatement',
            BinaryExpression: 'BinaryExpression',
            BreakStatement: 'BreakStatement',
            CallExpression: 'CallExpression',
            CatchClause: 'CatchClause',
            ClassBody: 'ClassBody',
            ClassDeclaration: 'ClassDeclaration',
            ClassExpression: 'ClassExpression',
            ComprehensionBlock: 'ComprehensionBlock',
            ComprehensionExpression: 'ComprehensionExpression',
            ConditionalExpression: 'ConditionalExpression',
            ContinueStatement: 'ContinueStatement',
            DebuggerStatement: 'DebuggerStatement',
            DirectiveStatement: 'DirectiveStatement',
            DoWhileStatement: 'DoWhileStatement',
            EmptyStatement: 'EmptyStatement',
            ExportAllDeclaration: 'ExportAllDeclaration',
            ExportDefaultDeclaration: 'ExportDefaultDeclaration',
            ExportNamedDeclaration: 'ExportNamedDeclaration',
            ExportSpecifier: 'ExportSpecifier',
            ExpressionStatement: 'ExpressionStatement',
            ForStatement: 'ForStatement',
            ForInStatement: 'ForInStatement',
            ForOfStatement: 'ForOfStatement',
            FunctionDeclaration: 'FunctionDeclaration',
            FunctionExpression: 'FunctionExpression',
            GeneratorExpression: 'GeneratorExpression',
            Identifier: 'Identifier',
            IfStatement: 'IfStatement',
            ImportExpression: 'ImportExpression',
            ImportDeclaration: 'ImportDeclaration',
            ImportDefaultSpecifier: 'ImportDefaultSpecifier',
            ImportNamespaceSpecifier: 'ImportNamespaceSpecifier',
            ImportSpecifier: 'ImportSpecifier',
            Literal: 'Literal',
            LabeledStatement: 'LabeledStatement',
            LogicalExpression: 'LogicalExpression',
            MemberExpression: 'MemberExpression',
            MetaProperty: 'MetaProperty',
            MethodDefinition: 'MethodDefinition',
            ModuleSpecifier: 'ModuleSpecifier',
            NewExpression: 'NewExpression',
            ObjectExpression: 'ObjectExpression',
            ObjectPattern: 'ObjectPattern',
            Program: 'Program',
            Property: 'Property',
            RestElement: 'RestElement',
            ReturnStatement: 'ReturnStatement',
            SequenceExpression: 'SequenceExpression',
            SpreadElement: 'SpreadElement',
            Super: 'Super',
            SwitchStatement: 'SwitchStatement',
            SwitchCase: 'SwitchCase',
            TaggedTemplateExpression: 'TaggedTemplateExpression',
            TemplateElement: 'TemplateElement',
            TemplateLiteral: 'TemplateLiteral',
            ThisExpression: 'ThisExpression',
            ThrowStatement: 'ThrowStatement',
            TryStatement: 'TryStatement',
            UnaryExpression: 'UnaryExpression',
            UpdateExpression: 'UpdateExpression',
            VariableDeclaration: 'VariableDeclaration',
            VariableDeclarator: 'VariableDeclarator',
            WhileStatement: 'WhileStatement',
            WithStatement: 'WithStatement',
            YieldExpression: 'YieldExpression'
        };
        VisitorKeys = {
            AssignmentExpression: ['left', 'right'],
            AssignmentPattern: ['left', 'right'],
            ArrayExpression: ['elements'],
            ArrayPattern: ['elements'],
            ArrowFunctionExpression: ['params', 'body'],
            AwaitExpression: ['argument'],
            BlockStatement: ['body'],
            BinaryExpression: ['left', 'right'],
            BreakStatement: ['label'],
            CallExpression: ['callee', 'arguments'],
            CatchClause: ['param', 'body'],
            ClassBody: ['body'],
            ClassDeclaration: ['id', 'superClass', 'body'],
            ClassExpression: ['id', 'superClass', 'body'],
            ComprehensionBlock: ['left', 'right'],
            ComprehensionExpression: ['blocks', 'filter', 'body'],
            ConditionalExpression: ['test', 'consequent', 'alternate'],
            ContinueStatement: ['label'],
            DebuggerStatement: [],
            DirectiveStatement: [],
            DoWhileStatement: ['body', 'test'],
            EmptyStatement: [],
            ExportAllDeclaration: ['source'],
            ExportDefaultDeclaration: ['declaration'],
            ExportNamedDeclaration: ['declaration', 'specifiers', 'source'],
            ExportSpecifier: ['exported', 'local'],
            ExpressionStatement: ['expression'],
            ForStatement: ['init', 'test', 'update', 'body'],
            ForInStatement: ['left', 'right', 'body'],
            ForOfStatement: ['left', 'right', 'body'],
            FunctionDeclaration: ['id', 'params', 'body'],
            FunctionExpression: ['id', 'params', 'body'],
            GeneratorExpression: ['blocks', 'filter', 'body'],
            Identifier: [],
            IfStatement: ['test', 'consequent', 'alternate'],
            ImportExpression: ['source'],
            ImportDeclaration: ['specifiers', 'source'],
            ImportDefaultSpecifier: ['local'],
            ImportNamespaceSpecifier: ['local'],
            ImportSpecifier: ['imported', 'local'],
            Literal: [],
            LabeledStatement: ['label', 'body'],
            LogicalExpression: ['left', 'right'],
            MemberExpression: ['object', 'property'],
            MetaProperty: ['meta', 'property'],
            MethodDefinition: ['key', 'value'],
            ModuleSpecifier: [],
            NewExpression: ['callee', 'arguments'],
            ObjectExpression: ['properties'],
            ObjectPattern: ['properties'],
            Program: ['body'],
            Property: ['key', 'value'],
            RestElement: ['argument'],
            ReturnStatement: ['argument'],
            SequenceExpression: ['expressions'],
            SpreadElement: ['argument'],
            Super: [],
            SwitchStatement: ['discriminant', 'cases'],
            SwitchCase: ['test', 'consequent'],
            TaggedTemplateExpression: ['tag', 'quasi'],
            TemplateElement: [],
            TemplateLiteral: ['quasis', 'expressions'],
            ThisExpression: [],
            ThrowStatement: ['argument'],
            TryStatement: ['block', 'handler', 'finalizer'],
            UnaryExpression: ['argument'],
            UpdateExpression: ['argument'],
            VariableDeclaration: ['declarations'],
            VariableDeclarator: ['id', 'init'],
            WhileStatement: ['test', 'body'],
            WithStatement: ['object', 'body'],
            YieldExpression: ['argument']
        };
        // unique id
        BREAK = {};
        SKIP = {};
        REMOVE = {};
        VisitorOption = {
            Break: BREAK,
            Skip: SKIP,
            Remove: REMOVE
        };
        function Reference(parent, key) {
            this.parent = parent;
            this.key = key;
        }
        Reference.prototype.replace = function replace(node) {
            this.parent[this.key] = node;
        };
        Reference.prototype.remove = function remove() {
            if (Array.isArray(this.parent)) {
                this.parent.splice(this.key, 1);
                return true;
            }
            else {
                this.replace(null);
                return false;
            }
        };
        function Element(node, path, wrap, ref) {
            this.node = node;
            this.path = path;
            this.wrap = wrap;
            this.ref = ref;
        }
        function Controller() { }
        // API:
        // return property path array from root to current node
        Controller.prototype.path = function path() {
            var i, iz, j, jz, result, element;
            function addToPath(result, path) {
                if (Array.isArray(path)) {
                    for (j = 0, jz = path.length; j < jz; ++j) {
                        result.push(path[j]);
                    }
                }
                else {
                    result.push(path);
                }
            }
            // root node
            if (!this.__current.path) {
                return null;
            }
            // first node is sentinel, second node is root element
            result = [];
            for (i = 2, iz = this.__leavelist.length; i < iz; ++i) {
                element = this.__leavelist[i];
                addToPath(result, element.path);
            }
            addToPath(result, this.__current.path);
            return result;
        };
        // API:
        // return type of current node
        Controller.prototype.type = function () {
            var node = this.current();
            return node.type || this.__current.wrap;
        };
        // API:
        // return array of parent elements
        Controller.prototype.parents = function parents() {
            var i, iz, result;
            // first node is sentinel
            result = [];
            for (i = 1, iz = this.__leavelist.length; i < iz; ++i) {
                result.push(this.__leavelist[i].node);
            }
            return result;
        };
        // API:
        // return current node
        Controller.prototype.current = function current() {
            return this.__current.node;
        };
        Controller.prototype.__execute = function __execute(callback, element) {
            var previous, result;
            result = undefined;
            previous = this.__current;
            this.__current = element;
            this.__state = null;
            if (callback) {
                result = callback.call(this, element.node, this.__leavelist[this.__leavelist.length - 1].node);
            }
            this.__current = previous;
            return result;
        };
        // API:
        // notify control skip / break
        Controller.prototype.notify = function notify(flag) {
            this.__state = flag;
        };
        // API:
        // skip child nodes of current node
        Controller.prototype.skip = function () {
            this.notify(SKIP);
        };
        // API:
        // break traversals
        Controller.prototype['break'] = function () {
            this.notify(BREAK);
        };
        // API:
        // remove node
        Controller.prototype.remove = function () {
            this.notify(REMOVE);
        };
        Controller.prototype.__initialize = function (root, visitor) {
            this.visitor = visitor;
            this.root = root;
            this.__worklist = [];
            this.__leavelist = [];
            this.__current = null;
            this.__state = null;
            this.__fallback = null;
            if (visitor.fallback === 'iteration') {
                this.__fallback = Object.keys;
            }
            else if (typeof visitor.fallback === 'function') {
                this.__fallback = visitor.fallback;
            }
            this.__keys = VisitorKeys;
            if (visitor.keys) {
                this.__keys = Object.assign(Object.create(this.__keys), visitor.keys);
            }
        };
        function isNode(node) {
            if (node == null) {
                return false;
            }
            return typeof node === 'object' && typeof node.type === 'string';
        }
        function isProperty(nodeType, key) {
            return (nodeType === Syntax.ObjectExpression || nodeType === Syntax.ObjectPattern) && 'properties' === key;
        }
        Controller.prototype.traverse = function traverse(root, visitor) {
            var worklist, leavelist, element, node, nodeType, ret, key, current, current2, candidates, candidate, sentinel;
            this.__initialize(root, visitor);
            sentinel = {};
            // reference
            worklist = this.__worklist;
            leavelist = this.__leavelist;
            // initialize
            worklist.push(new Element(root, null, null, null));
            leavelist.push(new Element(null, null, null, null));
            while (worklist.length) {
                element = worklist.pop();
                if (element === sentinel) {
                    element = leavelist.pop();
                    ret = this.__execute(visitor.leave, element);
                    if (this.__state === BREAK || ret === BREAK) {
                        return;
                    }
                    continue;
                }
                if (element.node) {
                    ret = this.__execute(visitor.enter, element);
                    if (this.__state === BREAK || ret === BREAK) {
                        return;
                    }
                    worklist.push(sentinel);
                    leavelist.push(element);
                    if (this.__state === SKIP || ret === SKIP) {
                        continue;
                    }
                    node = element.node;
                    nodeType = node.type || element.wrap;
                    candidates = this.__keys[nodeType];
                    if (!candidates) {
                        if (this.__fallback) {
                            candidates = this.__fallback(node);
                        }
                        else {
                            throw new Error('Unknown node type ' + nodeType + '.');
                        }
                    }
                    current = candidates.length;
                    while ((current -= 1) >= 0) {
                        key = candidates[current];
                        candidate = node[key];
                        if (!candidate) {
                            continue;
                        }
                        if (Array.isArray(candidate)) {
                            current2 = candidate.length;
                            while ((current2 -= 1) >= 0) {
                                if (!candidate[current2]) {
                                    continue;
                                }
                                if (isProperty(nodeType, candidates[current])) {
                                    element = new Element(candidate[current2], [key, current2], 'Property', null);
                                }
                                else if (isNode(candidate[current2])) {
                                    element = new Element(candidate[current2], [key, current2], null, null);
                                }
                                else {
                                    continue;
                                }
                                worklist.push(element);
                            }
                        }
                        else if (isNode(candidate)) {
                            worklist.push(new Element(candidate, key, null, null));
                        }
                    }
                }
            }
        };
        Controller.prototype.replace = function replace(root, visitor) {
            var worklist, leavelist, node, nodeType, target, element, current, current2, candidates, candidate, sentinel, outer, key;
            function removeElem(element) {
                var i, key, nextElem, parent;
                if (element.ref.remove()) {
                    // When the reference is an element of an array.
                    key = element.ref.key;
                    parent = element.ref.parent;
                    // If removed from array, then decrease following items' keys.
                    i = worklist.length;
                    while (i--) {
                        nextElem = worklist[i];
                        if (nextElem.ref && nextElem.ref.parent === parent) {
                            if (nextElem.ref.key < key) {
                                break;
                            }
                            --nextElem.ref.key;
                        }
                    }
                }
            }
            this.__initialize(root, visitor);
            sentinel = {};
            // reference
            worklist = this.__worklist;
            leavelist = this.__leavelist;
            // initialize
            outer = {
                root: root
            };
            element = new Element(root, null, null, new Reference(outer, 'root'));
            worklist.push(element);
            leavelist.push(element);
            while (worklist.length) {
                element = worklist.pop();
                if (element === sentinel) {
                    element = leavelist.pop();
                    target = this.__execute(visitor.leave, element);
                    // node may be replaced with null,
                    // so distinguish between undefined and null in this place
                    if (target !== undefined && target !== BREAK && target !== SKIP && target !== REMOVE) {
                        // replace
                        element.ref.replace(target);
                    }
                    if (this.__state === REMOVE || target === REMOVE) {
                        removeElem(element);
                    }
                    if (this.__state === BREAK || target === BREAK) {
                        return outer.root;
                    }
                    continue;
                }
                target = this.__execute(visitor.enter, element);
                // node may be replaced with null,
                // so distinguish between undefined and null in this place
                if (target !== undefined && target !== BREAK && target !== SKIP && target !== REMOVE) {
                    // replace
                    element.ref.replace(target);
                    element.node = target;
                }
                if (this.__state === REMOVE || target === REMOVE) {
                    removeElem(element);
                    element.node = null;
                }
                if (this.__state === BREAK || target === BREAK) {
                    return outer.root;
                }
                // node may be null
                node = element.node;
                if (!node) {
                    continue;
                }
                worklist.push(sentinel);
                leavelist.push(element);
                if (this.__state === SKIP || target === SKIP) {
                    continue;
                }
                nodeType = node.type || element.wrap;
                candidates = this.__keys[nodeType];
                if (!candidates) {
                    if (this.__fallback) {
                        candidates = this.__fallback(node);
                    }
                    else {
                        throw new Error('Unknown node type ' + nodeType + '.');
                    }
                }
                current = candidates.length;
                while ((current -= 1) >= 0) {
                    key = candidates[current];
                    candidate = node[key];
                    if (!candidate) {
                        continue;
                    }
                    if (Array.isArray(candidate)) {
                        current2 = candidate.length;
                        while ((current2 -= 1) >= 0) {
                            if (!candidate[current2]) {
                                continue;
                            }
                            if (isProperty(nodeType, candidates[current])) {
                                element = new Element(candidate[current2], [key, current2], 'Property', new Reference(candidate, current2));
                            }
                            else if (isNode(candidate[current2])) {
                                element = new Element(candidate[current2], [key, current2], null, new Reference(candidate, current2));
                            }
                            else {
                                continue;
                            }
                            worklist.push(element);
                        }
                    }
                    else if (isNode(candidate)) {
                        worklist.push(new Element(candidate, key, null, new Reference(node, key)));
                    }
                }
            }
            return outer.root;
        };
        function traverse(root, visitor) {
            var controller = new Controller();
            return controller.traverse(root, visitor);
        }
        function replace(root, visitor) {
            var controller = new Controller();
            return controller.replace(root, visitor);
        }
        function extendCommentRange(comment, tokens) {
            var target;
            target = upperBound(tokens, function search(token) {
                return token.range[0] > comment.range[0];
            });
            comment.extendedRange = [comment.range[0], comment.range[1]];
            if (target !== tokens.length) {
                comment.extendedRange[1] = tokens[target].range[0];
            }
            target -= 1;
            if (target >= 0) {
                comment.extendedRange[0] = tokens[target].range[1];
            }
            return comment;
        }
        function attachComments(tree, providedComments, tokens) {
            // At first, we should calculate extended comment ranges.
            var comments = [], comment, len, i, cursor;
            if (!tree.range) {
                throw new Error('attachComments needs range information');
            }
            // tokens array is empty, we attach comments to tree as 'leadingComments'
            if (!tokens.length) {
                if (providedComments.length) {
                    for (i = 0, len = providedComments.length; i < len; i += 1) {
                        comment = deepCopy(providedComments[i]);
                        comment.extendedRange = [0, tree.range[0]];
                        comments.push(comment);
                    }
                    tree.leadingComments = comments;
                }
                return tree;
            }
            for (i = 0, len = providedComments.length; i < len; i += 1) {
                comments.push(extendCommentRange(deepCopy(providedComments[i]), tokens));
            }
            // This is based on John Freeman's implementation.
            cursor = 0;
            traverse(tree, {
                enter: function (node) {
                    var comment;
                    while (cursor < comments.length) {
                        comment = comments[cursor];
                        if (comment.extendedRange[1] > node.range[0]) {
                            break;
                        }
                        if (comment.extendedRange[1] === node.range[0]) {
                            if (!node.leadingComments) {
                                node.leadingComments = [];
                            }
                            node.leadingComments.push(comment);
                            comments.splice(cursor, 1);
                        }
                        else {
                            cursor += 1;
                        }
                    }
                    // already out of owned node
                    if (cursor === comments.length) {
                        return VisitorOption.Break;
                    }
                    if (comments[cursor].extendedRange[0] > node.range[1]) {
                        return VisitorOption.Skip;
                    }
                }
            });
            cursor = 0;
            traverse(tree, {
                leave: function (node) {
                    var comment;
                    while (cursor < comments.length) {
                        comment = comments[cursor];
                        if (node.range[1] < comment.extendedRange[0]) {
                            break;
                        }
                        if (node.range[1] === comment.extendedRange[0]) {
                            if (!node.trailingComments) {
                                node.trailingComments = [];
                            }
                            node.trailingComments.push(comment);
                            comments.splice(cursor, 1);
                        }
                        else {
                            cursor += 1;
                        }
                    }
                    // already out of owned node
                    if (cursor === comments.length) {
                        return VisitorOption.Break;
                    }
                    if (comments[cursor].extendedRange[0] > node.range[1]) {
                        return VisitorOption.Skip;
                    }
                }
            });
            return tree;
        }
        exports.version = require(295) /* ./package.json */.version;
        exports.Syntax = Syntax;
        exports.traverse = traverse;
        exports.replace = replace;
        exports.attachComments = attachComments;
        exports.VisitorKeys = VisitorKeys;
        exports.VisitorOption = VisitorOption;
        exports.Controller = Controller;
        exports.cloneEnvironment = function () { return clone({}); };
        return exports;
    }(exports));
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* estraverse/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "estraverse",
        "description": "ECMAScript JS AST traversal functions",
        "homepage": "https://github.com/estools/estraverse",
        "main": "estraverse.js",
        "version": "4.3.0",
        "engines": {
            "node": ">=4.0"
        },
        "maintainers": [
            {
                "name": "Yusuke Suzuki",
                "email": "utatane.tea@gmail.com",
                "web": "http://github.com/Constellation"
            }
        ],
        "repository": {
            "type": "git",
            "url": "http://github.com/estools/estraverse.git"
        },
        "devDependencies": {
            "babel-preset-env": "^1.6.1",
            "babel-register": "^6.3.13",
            "chai": "^2.1.1",
            "espree": "^1.11.0",
            "gulp": "^3.8.10",
            "gulp-bump": "^0.2.2",
            "gulp-filter": "^2.0.0",
            "gulp-git": "^1.0.1",
            "gulp-tag-version": "^1.3.0",
            "jshint": "^2.5.6",
            "mocha": "^2.1.0"
        },
        "license": "BSD-2-Clause",
        "scripts": {
            "test": "npm run-script lint && npm run-script unit-test",
            "lint": "jshint estraverse.js",
            "unit-test": "mocha --compilers js:babel-register"
        }
    };
    module.exports = json;
},
/* eslint-scope/lib/reference.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
      Copyright (C) 2015 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    "use strict";
    const READ = 0x1;
    const WRITE = 0x2;
    const RW = READ | WRITE;
    /**
     * A Reference represents a single occurrence of an identifier in code.
     * @class Reference
     */
    class Reference {
        constructor(ident, scope, flag, writeExpr, maybeImplicitGlobal, partial, init) {
            /**
             * Identifier syntax node.
             * @member {espreeIdentifier} Reference#identifier
             */
            this.identifier = ident;
            /**
             * Reference to the enclosing Scope.
             * @member {Scope} Reference#from
             */
            this.from = scope;
            /**
             * Whether the reference comes from a dynamic scope (such as 'eval',
             * 'with', etc.), and may be trapped by dynamic scopes.
             * @member {boolean} Reference#tainted
             */
            this.tainted = false;
            /**
             * The variable this reference is resolved with.
             * @member {Variable} Reference#resolved
             */
            this.resolved = null;
            /**
             * The read-write mode of the reference. (Value is one of {@link
             * Reference.READ}, {@link Reference.RW}, {@link Reference.WRITE}).
             * @member {number} Reference#flag
             * @private
             */
            this.flag = flag;
            if (this.isWrite()) {
                /**
                 * If reference is writeable, this is the tree being written to it.
                 * @member {espreeNode} Reference#writeExpr
                 */
                this.writeExpr = writeExpr;
                /**
                 * Whether the Reference might refer to a partial value of writeExpr.
                 * @member {boolean} Reference#partial
                 */
                this.partial = partial;
                /**
                 * Whether the Reference is to write of initialization.
                 * @member {boolean} Reference#init
                 */
                this.init = init;
            }
            this.__maybeImplicitGlobal = maybeImplicitGlobal;
        }
        /**
         * Whether the reference is static.
         * @method Reference#isStatic
         * @returns {boolean} static
         */
        isStatic() {
            return !this.tainted && this.resolved && this.resolved.scope.isStatic();
        }
        /**
         * Whether the reference is writeable.
         * @method Reference#isWrite
         * @returns {boolean} write
         */
        isWrite() {
            return !!(this.flag & Reference.WRITE);
        }
        /**
         * Whether the reference is readable.
         * @method Reference#isRead
         * @returns {boolean} read
         */
        isRead() {
            return !!(this.flag & Reference.READ);
        }
        /**
         * Whether the reference is read-only.
         * @method Reference#isReadOnly
         * @returns {boolean} read only
         */
        isReadOnly() {
            return this.flag === Reference.READ;
        }
        /**
         * Whether the reference is write-only.
         * @method Reference#isWriteOnly
         * @returns {boolean} write only
         */
        isWriteOnly() {
            return this.flag === Reference.WRITE;
        }
        /**
         * Whether the reference is read-write.
         * @method Reference#isReadWrite
         * @returns {boolean} read write
         */
        isReadWrite() {
            return this.flag === Reference.RW;
        }
    }
    /**
     * @constant Reference.READ
     * @private
     */
    Reference.READ = READ;
    /**
     * @constant Reference.WRITE
     * @private
     */
    Reference.WRITE = WRITE;
    /**
     * @constant Reference.RW
     * @private
     */
    Reference.RW = RW;
    module.exports = Reference;
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* eslint-scope/lib/variable.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
      Copyright (C) 2015 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    "use strict";
    /**
     * A Variable represents a locally scoped identifier. These include arguments to
     * functions.
     * @class Variable
     */
    class Variable {
        constructor(name, scope) {
            /**
             * The variable name, as given in the source code.
             * @member {String} Variable#name
             */
            this.name = name;
            /**
             * List of defining occurrences of this variable (like in 'var ...'
             * statements or as parameter), as AST nodes.
             * @member {espree.Identifier[]} Variable#identifiers
             */
            this.identifiers = [];
            /**
             * List of {@link Reference|references} of this variable (excluding parameter entries)
             * in its defining scope and all nested scopes. For defining
             * occurrences only see {@link Variable#defs}.
             * @member {Reference[]} Variable#references
             */
            this.references = [];
            /**
             * List of defining occurrences of this variable (like in 'var ...'
             * statements or as parameter), as custom objects.
             * @member {Definition[]} Variable#defs
             */
            this.defs = [];
            this.tainted = false;
            /**
             * Whether this is a stack variable.
             * @member {boolean} Variable#stack
             */
            this.stack = true;
            /**
             * Reference to the enclosing Scope.
             * @member {Scope} Variable#scope
             */
            this.scope = scope;
        }
    }
    Variable.CatchClause = "CatchClause";
    Variable.Parameter = "Parameter";
    Variable.FunctionName = "FunctionName";
    Variable.ClassName = "ClassName";
    Variable.Variable = "Variable";
    Variable.ImportBinding = "ImportBinding";
    Variable.ImplicitGlobalVariable = "ImplicitGlobalVariable";
    module.exports = Variable;
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* eslint-scope/lib/definition.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
      Copyright (C) 2015 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    "use strict";
    const Variable = require(297) /* ./variable */;
    /**
     * @class Definition
     */
    class Definition {
        constructor(type, name, node, parent, index, kind) {
            /**
             * @member {String} Definition#type - type of the occurrence (e.g. "Parameter", "Variable", ...).
             */
            this.type = type;
            /**
             * @member {espree.Identifier} Definition#name - the identifier AST node of the occurrence.
             */
            this.name = name;
            /**
             * @member {espree.Node} Definition#node - the enclosing node of the identifier.
             */
            this.node = node;
            /**
             * @member {espree.Node?} Definition#parent - the enclosing statement node of the identifier.
             */
            this.parent = parent;
            /**
             * @member {Number?} Definition#index - the index in the declaration statement.
             */
            this.index = index;
            /**
             * @member {String?} Definition#kind - the kind of the declaration statement.
             */
            this.kind = kind;
        }
    }
    /**
     * @class ParameterDefinition
     */
    class ParameterDefinition extends Definition {
        constructor(name, node, index, rest) {
            super(Variable.Parameter, name, node, null, index, null);
            /**
             * Whether the parameter definition is a part of a rest parameter.
             * @member {boolean} ParameterDefinition#rest
             */
            this.rest = rest;
        }
    }
    module.exports = {
        ParameterDefinition,
        Definition
    };
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* eslint-scope/lib/referencer.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
      Copyright (C) 2015 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    "use strict";
    /* eslint-disable no-underscore-dangle */
    /* eslint-disable no-undefined */
    const Syntax = require(294) /* estraverse */.Syntax;
    const esrecurse = require(300) /* esrecurse */;
    const Reference = require(296) /* ./reference */;
    const Variable = require(297) /* ./variable */;
    const PatternVisitor = require(302) /* ./pattern-visitor */;
    const definition = require(298) /* ./definition */;
    const assert = require("assert");
    const ParameterDefinition = definition.ParameterDefinition;
    const Definition = definition.Definition;
    /**
     * Traverse identifier in pattern
     * @param {Object} options - options
     * @param {pattern} rootPattern - root pattern
     * @param {Refencer} referencer - referencer
     * @param {callback} callback - callback
     * @returns {void}
     */
    function traverseIdentifierInPattern(options, rootPattern, referencer, callback) {
        // Call the callback at left hand identifier nodes, and Collect right hand nodes.
        const visitor = new PatternVisitor(options, rootPattern, callback);
        visitor.visit(rootPattern);
        // Process the right hand nodes recursively.
        if (referencer !== null && referencer !== undefined) {
            visitor.rightHandNodes.forEach(referencer.visit, referencer);
        }
    }
    // Importing ImportDeclaration.
    // http://people.mozilla.org/~jorendorff/es6-draft.html#sec-moduledeclarationinstantiation
    // https://github.com/estree/estree/blob/master/es6.md#importdeclaration
    // FIXME: Now, we don't create module environment, because the context is
    // implementation dependent.
    class Importer extends esrecurse.Visitor {
        constructor(declaration, referencer) {
            super(null, referencer.options);
            this.declaration = declaration;
            this.referencer = referencer;
        }
        visitImport(id, specifier) {
            this.referencer.visitPattern(id, pattern => {
                this.referencer.currentScope().__define(pattern, new Definition(Variable.ImportBinding, pattern, specifier, this.declaration, null, null));
            });
        }
        ImportNamespaceSpecifier(node) {
            const local = (node.local || node.id);
            if (local) {
                this.visitImport(local, node);
            }
        }
        ImportDefaultSpecifier(node) {
            const local = (node.local || node.id);
            this.visitImport(local, node);
        }
        ImportSpecifier(node) {
            const local = (node.local || node.id);
            if (node.name) {
                this.visitImport(node.name, node);
            }
            else {
                this.visitImport(local, node);
            }
        }
    }
    // Referencing variables and creating bindings.
    class Referencer extends esrecurse.Visitor {
        constructor(options, scopeManager) {
            super(null, options);
            this.options = options;
            this.scopeManager = scopeManager;
            this.parent = null;
            this.isInnerMethodDefinition = false;
        }
        currentScope() {
            return this.scopeManager.__currentScope;
        }
        close(node) {
            while (this.currentScope() && node === this.currentScope().block) {
                this.scopeManager.__currentScope = this.currentScope().__close(this.scopeManager);
            }
        }
        pushInnerMethodDefinition(isInnerMethodDefinition) {
            const previous = this.isInnerMethodDefinition;
            this.isInnerMethodDefinition = isInnerMethodDefinition;
            return previous;
        }
        popInnerMethodDefinition(isInnerMethodDefinition) {
            this.isInnerMethodDefinition = isInnerMethodDefinition;
        }
        referencingDefaultValue(pattern, assignments, maybeImplicitGlobal, init) {
            const scope = this.currentScope();
            assignments.forEach(assignment => {
                scope.__referencing(pattern, Reference.WRITE, assignment.right, maybeImplicitGlobal, pattern !== assignment.left, init);
            });
        }
        visitPattern(node, options, callback) {
            let visitPatternOptions = options;
            let visitPatternCallback = callback;
            if (typeof options === "function") {
                visitPatternCallback = options;
                visitPatternOptions = { processRightHandNodes: false };
            }
            traverseIdentifierInPattern(this.options, node, visitPatternOptions.processRightHandNodes ? this : null, visitPatternCallback);
        }
        visitFunction(node) {
            let i, iz;
            // FunctionDeclaration name is defined in upper scope
            // NOTE: Not referring variableScope. It is intended.
            // Since
            //  in ES5, FunctionDeclaration should be in FunctionBody.
            //  in ES6, FunctionDeclaration should be block scoped.
            if (node.type === Syntax.FunctionDeclaration) {
                // id is defined in upper scope
                this.currentScope().__define(node.id, new Definition(Variable.FunctionName, node.id, node, null, null, null));
            }
            // FunctionExpression with name creates its special scope;
            // FunctionExpressionNameScope.
            if (node.type === Syntax.FunctionExpression && node.id) {
                this.scopeManager.__nestFunctionExpressionNameScope(node);
            }
            // Consider this function is in the MethodDefinition.
            this.scopeManager.__nestFunctionScope(node, this.isInnerMethodDefinition);
            const that = this;
            /**
             * Visit pattern callback
             * @param {pattern} pattern - pattern
             * @param {Object} info - info
             * @returns {void}
             */
            function visitPatternCallback(pattern, info) {
                that.currentScope().__define(pattern, new ParameterDefinition(pattern, node, i, info.rest));
                that.referencingDefaultValue(pattern, info.assignments, null, true);
            }
            // Process parameter declarations.
            for (i = 0, iz = node.params.length; i < iz; ++i) {
                this.visitPattern(node.params[i], { processRightHandNodes: true }, visitPatternCallback);
            }
            // if there's a rest argument, add that
            if (node.rest) {
                this.visitPattern({
                    type: "RestElement",
                    argument: node.rest
                }, pattern => {
                    this.currentScope().__define(pattern, new ParameterDefinition(pattern, node, node.params.length, true));
                });
            }
            // In TypeScript there are a number of function-like constructs which have no body,
            // so check it exists before traversing
            if (node.body) {
                // Skip BlockStatement to prevent creating BlockStatement scope.
                if (node.body.type === Syntax.BlockStatement) {
                    this.visitChildren(node.body);
                }
                else {
                    this.visit(node.body);
                }
            }
            this.close(node);
        }
        visitClass(node) {
            if (node.type === Syntax.ClassDeclaration) {
                this.currentScope().__define(node.id, new Definition(Variable.ClassName, node.id, node, null, null, null));
            }
            this.visit(node.superClass);
            this.scopeManager.__nestClassScope(node);
            if (node.id) {
                this.currentScope().__define(node.id, new Definition(Variable.ClassName, node.id, node));
            }
            this.visit(node.body);
            this.close(node);
        }
        visitProperty(node) {
            let previous;
            if (node.computed) {
                this.visit(node.key);
            }
            const isMethodDefinition = node.type === Syntax.MethodDefinition;
            if (isMethodDefinition) {
                previous = this.pushInnerMethodDefinition(true);
            }
            this.visit(node.value);
            if (isMethodDefinition) {
                this.popInnerMethodDefinition(previous);
            }
        }
        visitForIn(node) {
            if (node.left.type === Syntax.VariableDeclaration && node.left.kind !== "var") {
                this.scopeManager.__nestForScope(node);
            }
            if (node.left.type === Syntax.VariableDeclaration) {
                this.visit(node.left);
                this.visitPattern(node.left.declarations[0].id, pattern => {
                    this.currentScope().__referencing(pattern, Reference.WRITE, node.right, null, true, true);
                });
            }
            else {
                this.visitPattern(node.left, { processRightHandNodes: true }, (pattern, info) => {
                    let maybeImplicitGlobal = null;
                    if (!this.currentScope().isStrict) {
                        maybeImplicitGlobal = {
                            pattern,
                            node
                        };
                    }
                    this.referencingDefaultValue(pattern, info.assignments, maybeImplicitGlobal, false);
                    this.currentScope().__referencing(pattern, Reference.WRITE, node.right, maybeImplicitGlobal, true, false);
                });
            }
            this.visit(node.right);
            this.visit(node.body);
            this.close(node);
        }
        visitVariableDeclaration(variableTargetScope, type, node, index) {
            const decl = node.declarations[index];
            const init = decl.init;
            this.visitPattern(decl.id, { processRightHandNodes: true }, (pattern, info) => {
                variableTargetScope.__define(pattern, new Definition(type, pattern, decl, node, index, node.kind));
                this.referencingDefaultValue(pattern, info.assignments, null, true);
                if (init) {
                    this.currentScope().__referencing(pattern, Reference.WRITE, init, null, !info.topLevel, true);
                }
            });
        }
        AssignmentExpression(node) {
            if (PatternVisitor.isPattern(node.left)) {
                if (node.operator === "=") {
                    this.visitPattern(node.left, { processRightHandNodes: true }, (pattern, info) => {
                        let maybeImplicitGlobal = null;
                        if (!this.currentScope().isStrict) {
                            maybeImplicitGlobal = {
                                pattern,
                                node
                            };
                        }
                        this.referencingDefaultValue(pattern, info.assignments, maybeImplicitGlobal, false);
                        this.currentScope().__referencing(pattern, Reference.WRITE, node.right, maybeImplicitGlobal, !info.topLevel, false);
                    });
                }
                else {
                    this.currentScope().__referencing(node.left, Reference.RW, node.right);
                }
            }
            else {
                this.visit(node.left);
            }
            this.visit(node.right);
        }
        CatchClause(node) {
            this.scopeManager.__nestCatchScope(node);
            this.visitPattern(node.param, { processRightHandNodes: true }, (pattern, info) => {
                this.currentScope().__define(pattern, new Definition(Variable.CatchClause, node.param, node, null, null, null));
                this.referencingDefaultValue(pattern, info.assignments, null, true);
            });
            this.visit(node.body);
            this.close(node);
        }
        Program(node) {
            this.scopeManager.__nestGlobalScope(node);
            if (this.scopeManager.__isNodejsScope()) {
                // Force strictness of GlobalScope to false when using node.js scope.
                this.currentScope().isStrict = false;
                this.scopeManager.__nestFunctionScope(node, false);
            }
            if (this.scopeManager.__isES6() && this.scopeManager.isModule()) {
                this.scopeManager.__nestModuleScope(node);
            }
            if (this.scopeManager.isStrictModeSupported() && this.scopeManager.isImpliedStrict()) {
                this.currentScope().isStrict = true;
            }
            this.visitChildren(node);
            this.close(node);
        }
        Identifier(node) {
            this.currentScope().__referencing(node);
        }
        UpdateExpression(node) {
            if (PatternVisitor.isPattern(node.argument)) {
                this.currentScope().__referencing(node.argument, Reference.RW, null);
            }
            else {
                this.visitChildren(node);
            }
        }
        MemberExpression(node) {
            this.visit(node.object);
            if (node.computed) {
                this.visit(node.property);
            }
        }
        Property(node) {
            this.visitProperty(node);
        }
        MethodDefinition(node) {
            this.visitProperty(node);
        }
        BreakStatement() { } // eslint-disable-line class-methods-use-this
        ContinueStatement() { } // eslint-disable-line class-methods-use-this
        LabeledStatement(node) {
            this.visit(node.body);
        }
        ForStatement(node) {
            // Create ForStatement declaration.
            // NOTE: In ES6, ForStatement dynamically generates
            // per iteration environment. However, escope is
            // a static analyzer, we only generate one scope for ForStatement.
            if (node.init && node.init.type === Syntax.VariableDeclaration && node.init.kind !== "var") {
                this.scopeManager.__nestForScope(node);
            }
            this.visitChildren(node);
            this.close(node);
        }
        ClassExpression(node) {
            this.visitClass(node);
        }
        ClassDeclaration(node) {
            this.visitClass(node);
        }
        CallExpression(node) {
            // Check this is direct call to eval
            if (!this.scopeManager.__ignoreEval() && node.callee.type === Syntax.Identifier && node.callee.name === "eval") {
                // NOTE: This should be `variableScope`. Since direct eval call always creates Lexical environment and
                // let / const should be enclosed into it. Only VariableDeclaration affects on the caller's environment.
                this.currentScope().variableScope.__detectEval();
            }
            this.visitChildren(node);
        }
        BlockStatement(node) {
            if (this.scopeManager.__isES6()) {
                this.scopeManager.__nestBlockScope(node);
            }
            this.visitChildren(node);
            this.close(node);
        }
        ThisExpression() {
            this.currentScope().variableScope.__detectThis();
        }
        WithStatement(node) {
            this.visit(node.object);
            // Then nest scope for WithStatement.
            this.scopeManager.__nestWithScope(node);
            this.visit(node.body);
            this.close(node);
        }
        VariableDeclaration(node) {
            const variableTargetScope = (node.kind === "var") ? this.currentScope().variableScope : this.currentScope();
            for (let i = 0, iz = node.declarations.length; i < iz; ++i) {
                const decl = node.declarations[i];
                this.visitVariableDeclaration(variableTargetScope, Variable.Variable, node, i);
                if (decl.init) {
                    this.visit(decl.init);
                }
            }
        }
        // sec 13.11.8
        SwitchStatement(node) {
            this.visit(node.discriminant);
            if (this.scopeManager.__isES6()) {
                this.scopeManager.__nestSwitchScope(node);
            }
            for (let i = 0, iz = node.cases.length; i < iz; ++i) {
                this.visit(node.cases[i]);
            }
            this.close(node);
        }
        FunctionDeclaration(node) {
            this.visitFunction(node);
        }
        FunctionExpression(node) {
            this.visitFunction(node);
        }
        ForOfStatement(node) {
            this.visitForIn(node);
        }
        ForInStatement(node) {
            this.visitForIn(node);
        }
        ArrowFunctionExpression(node) {
            this.visitFunction(node);
        }
        ImportDeclaration(node) {
            assert(this.scopeManager.__isES6() && this.scopeManager.isModule(), "ImportDeclaration should appear when the mode is ES6 and in the module context.");
            const importer = new Importer(node, this);
            importer.visit(node);
        }
        visitExportDeclaration(node) {
            if (node.source) {
                return;
            }
            if (node.declaration) {
                this.visit(node.declaration);
                return;
            }
            this.visitChildren(node);
        }
        // TODO: ExportDeclaration doesn't exist. for bc?
        ExportDeclaration(node) {
            this.visitExportDeclaration(node);
        }
        ExportAllDeclaration(node) {
            this.visitExportDeclaration(node);
        }
        ExportDefaultDeclaration(node) {
            this.visitExportDeclaration(node);
        }
        ExportNamedDeclaration(node) {
            this.visitExportDeclaration(node);
        }
        ExportSpecifier(node) {
            // TODO: `node.id` doesn't exist. for bc?
            const local = (node.id || node.local);
            this.visit(local);
        }
        MetaProperty() {
            // do nothing.
        }
    }
    module.exports = Referencer;
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* esrecurse/esrecurse.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
      Copyright (C) 2014 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    (function () {
        'use strict';
        var estraverse = require(294) /* estraverse */;
        function isNode(node) {
            if (node == null) {
                return false;
            }
            return typeof node === 'object' && typeof node.type === 'string';
        }
        function isProperty(nodeType, key) {
            return (nodeType === estraverse.Syntax.ObjectExpression || nodeType === estraverse.Syntax.ObjectPattern) && key === 'properties';
        }
        function Visitor(visitor, options) {
            options = options || {};
            this.__visitor = visitor || this;
            this.__childVisitorKeys = options.childVisitorKeys
                ? Object.assign({}, estraverse.VisitorKeys, options.childVisitorKeys)
                : estraverse.VisitorKeys;
            if (options.fallback === 'iteration') {
                this.__fallback = Object.keys;
            }
            else if (typeof options.fallback === 'function') {
                this.__fallback = options.fallback;
            }
        }
        /* Default method for visiting children.
         * When you need to call default visiting operation inside custom visiting
         * operation, you can use it with `this.visitChildren(node)`.
         */
        Visitor.prototype.visitChildren = function (node) {
            var type, children, i, iz, j, jz, child;
            if (node == null) {
                return;
            }
            type = node.type || estraverse.Syntax.Property;
            children = this.__childVisitorKeys[type];
            if (!children) {
                if (this.__fallback) {
                    children = this.__fallback(node);
                }
                else {
                    throw new Error('Unknown node type ' + type + '.');
                }
            }
            for (i = 0, iz = children.length; i < iz; ++i) {
                child = node[children[i]];
                if (child) {
                    if (Array.isArray(child)) {
                        for (j = 0, jz = child.length; j < jz; ++j) {
                            if (child[j]) {
                                if (isNode(child[j]) || isProperty(type, children[i])) {
                                    this.visit(child[j]);
                                }
                            }
                        }
                    }
                    else if (isNode(child)) {
                        this.visit(child);
                    }
                }
            }
        };
        /* Dispatching node. */
        Visitor.prototype.visit = function (node) {
            var type;
            if (node == null) {
                return;
            }
            type = node.type || estraverse.Syntax.Property;
            if (this.__visitor[type]) {
                this.__visitor[type].call(this, node);
                return;
            }
            this.visitChildren(node);
        };
        exports.version = require(301) /* ./package.json */.version;
        exports.Visitor = Visitor;
        exports.visit = function (node, visitor, options) {
            var v = new Visitor(visitor, options);
            v.visit(node);
        };
    }());
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* esrecurse/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "esrecurse",
        "description": "ECMAScript AST recursive visitor",
        "homepage": "https://github.com/estools/esrecurse",
        "main": "esrecurse.js",
        "version": "4.3.0",
        "engines": {
            "node": ">=4.0"
        },
        "maintainers": [
            {
                "name": "Yusuke Suzuki",
                "email": "utatane.tea@gmail.com",
                "web": "https://github.com/Constellation"
            }
        ],
        "repository": {
            "type": "git",
            "url": "https://github.com/estools/esrecurse.git"
        },
        "dependencies": {
            "estraverse": "^5.2.0"
        },
        "devDependencies": {
            "babel-cli": "^6.24.1",
            "babel-eslint": "^7.2.3",
            "babel-preset-es2015": "^6.24.1",
            "babel-register": "^6.24.1",
            "chai": "^4.0.2",
            "esprima": "^4.0.0",
            "gulp": "^3.9.0",
            "gulp-bump": "^2.7.0",
            "gulp-eslint": "^4.0.0",
            "gulp-filter": "^5.0.0",
            "gulp-git": "^2.4.1",
            "gulp-mocha": "^4.3.1",
            "gulp-tag-version": "^1.2.1",
            "jsdoc": "^3.3.0-alpha10",
            "minimist": "^1.1.0"
        },
        "license": "BSD-2-Clause",
        "scripts": {
            "test": "gulp travis",
            "unit-test": "gulp test",
            "lint": "gulp lint"
        },
        "babel": {
            "presets": [
                "es2015"
            ]
        }
    };
    module.exports = json;
},
/* eslint-scope/lib/pattern-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
      Copyright (C) 2015 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    "use strict";
    /* eslint-disable no-undefined */
    const Syntax = require(294) /* estraverse */.Syntax;
    const esrecurse = require(300) /* esrecurse */;
    /**
     * Get last array element
     * @param {array} xs - array
     * @returns {any} Last elment
     */
    function getLast(xs) {
        return xs[xs.length - 1] || null;
    }
    class PatternVisitor extends esrecurse.Visitor {
        static isPattern(node) {
            const nodeType = node.type;
            return (nodeType === Syntax.Identifier ||
                nodeType === Syntax.ObjectPattern ||
                nodeType === Syntax.ArrayPattern ||
                nodeType === Syntax.SpreadElement ||
                nodeType === Syntax.RestElement ||
                nodeType === Syntax.AssignmentPattern);
        }
        constructor(options, rootPattern, callback) {
            super(null, options);
            this.rootPattern = rootPattern;
            this.callback = callback;
            this.assignments = [];
            this.rightHandNodes = [];
            this.restElements = [];
        }
        Identifier(pattern) {
            const lastRestElement = getLast(this.restElements);
            this.callback(pattern, {
                topLevel: pattern === this.rootPattern,
                rest: lastRestElement !== null && lastRestElement !== undefined && lastRestElement.argument === pattern,
                assignments: this.assignments
            });
        }
        Property(property) {
            // Computed property's key is a right hand node.
            if (property.computed) {
                this.rightHandNodes.push(property.key);
            }
            // If it's shorthand, its key is same as its value.
            // If it's shorthand and has its default value, its key is same as its value.left (the value is AssignmentPattern).
            // If it's not shorthand, the name of new variable is its value's.
            this.visit(property.value);
        }
        ArrayPattern(pattern) {
            for (let i = 0, iz = pattern.elements.length; i < iz; ++i) {
                const element = pattern.elements[i];
                this.visit(element);
            }
        }
        AssignmentPattern(pattern) {
            this.assignments.push(pattern);
            this.visit(pattern.left);
            this.rightHandNodes.push(pattern.right);
            this.assignments.pop();
        }
        RestElement(pattern) {
            this.restElements.push(pattern);
            this.visit(pattern.argument);
            this.restElements.pop();
        }
        MemberExpression(node) {
            // Computed property's key is a right hand node.
            if (node.computed) {
                this.rightHandNodes.push(node.property);
            }
            // the object is only read, write to its property.
            this.rightHandNodes.push(node.object);
        }
        //
        // ForInStatement.left and AssignmentExpression.left are LeftHandSideExpression.
        // By spec, LeftHandSideExpression is Pattern or MemberExpression.
        //   (see also: https://github.com/estree/estree/pull/20#issuecomment-74584758)
        // But espree 2.0 parses to ArrayExpression, ObjectExpression, etc...
        //
        SpreadElement(node) {
            this.visit(node.argument);
        }
        ArrayExpression(node) {
            node.elements.forEach(this.visit, this);
        }
        AssignmentExpression(node) {
            this.assignments.push(node);
            this.visit(node.left);
            this.rightHandNodes.push(node.right);
            this.assignments.pop();
        }
        CallExpression(node) {
            // arguments are right hand nodes.
            node.arguments.forEach(a => {
                this.rightHandNodes.push(a);
            });
            this.visit(node.callee);
        }
    }
    module.exports = PatternVisitor;
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* eslint-scope/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "eslint-scope",
        "description": "ECMAScript scope analyzer for ESLint",
        "homepage": "http://github.com/eslint/eslint-scope",
        "main": "lib/index.js",
        "version": "5.1.1",
        "engines": {
            "node": ">=8.0.0"
        },
        "repository": "eslint/eslint-scope",
        "bugs": {
            "url": "https://github.com/eslint/eslint-scope/issues"
        },
        "license": "BSD-2-Clause",
        "scripts": {
            "test": "node Makefile.js test",
            "lint": "node Makefile.js lint",
            "generate-release": "eslint-generate-release",
            "generate-alpharelease": "eslint-generate-prerelease alpha",
            "generate-betarelease": "eslint-generate-prerelease beta",
            "generate-rcrelease": "eslint-generate-prerelease rc",
            "publish-release": "eslint-publish-release"
        },
        "files": [
            "LICENSE",
            "README.md",
            "lib"
        ],
        "dependencies": {
            "esrecurse": "^4.3.0",
            "estraverse": "^4.1.1"
        },
        "devDependencies": {
            "@typescript-eslint/parser": "^1.11.0",
            "chai": "^4.2.0",
            "eslint": "^6.0.1",
            "eslint-config-eslint": "^5.0.1",
            "eslint-plugin-node": "^9.1.0",
            "eslint-release": "^1.0.0",
            "eslint-visitor-keys": "^1.2.0",
            "espree": "^7.1.0",
            "istanbul": "^0.4.5",
            "mocha": "^6.1.4",
            "npm-license": "^0.3.3",
            "shelljs": "^0.8.3",
            "typescript": "^3.5.2"
        }
    };
    module.exports = json;
},
/* eslint-visitor-keys/dist/eslint-visitor-keys.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    /**
     * @typedef {import('./index.js').VisitorKeys} VisitorKeys
     */
    /**
     * @type {VisitorKeys}
     */
    const KEYS = {
        AssignmentExpression: [
            "left",
            "right"
        ],
        AssignmentPattern: [
            "left",
            "right"
        ],
        ArrayExpression: [
            "elements"
        ],
        ArrayPattern: [
            "elements"
        ],
        ArrowFunctionExpression: [
            "params",
            "body"
        ],
        AwaitExpression: [
            "argument"
        ],
        BlockStatement: [
            "body"
        ],
        BinaryExpression: [
            "left",
            "right"
        ],
        BreakStatement: [
            "label"
        ],
        CallExpression: [
            "callee",
            "arguments"
        ],
        CatchClause: [
            "param",
            "body"
        ],
        ChainExpression: [
            "expression"
        ],
        ClassBody: [
            "body"
        ],
        ClassDeclaration: [
            "id",
            "superClass",
            "body"
        ],
        ClassExpression: [
            "id",
            "superClass",
            "body"
        ],
        ConditionalExpression: [
            "test",
            "consequent",
            "alternate"
        ],
        ContinueStatement: [
            "label"
        ],
        DebuggerStatement: [],
        DoWhileStatement: [
            "body",
            "test"
        ],
        EmptyStatement: [],
        ExportAllDeclaration: [
            "exported",
            "source"
        ],
        ExportDefaultDeclaration: [
            "declaration"
        ],
        ExportNamedDeclaration: [
            "declaration",
            "specifiers",
            "source"
        ],
        ExportSpecifier: [
            "exported",
            "local"
        ],
        ExpressionStatement: [
            "expression"
        ],
        ExperimentalRestProperty: [
            "argument"
        ],
        ExperimentalSpreadProperty: [
            "argument"
        ],
        ForStatement: [
            "init",
            "test",
            "update",
            "body"
        ],
        ForInStatement: [
            "left",
            "right",
            "body"
        ],
        ForOfStatement: [
            "left",
            "right",
            "body"
        ],
        FunctionDeclaration: [
            "id",
            "params",
            "body"
        ],
        FunctionExpression: [
            "id",
            "params",
            "body"
        ],
        Identifier: [],
        IfStatement: [
            "test",
            "consequent",
            "alternate"
        ],
        ImportDeclaration: [
            "specifiers",
            "source"
        ],
        ImportDefaultSpecifier: [
            "local"
        ],
        ImportExpression: [
            "source"
        ],
        ImportNamespaceSpecifier: [
            "local"
        ],
        ImportSpecifier: [
            "imported",
            "local"
        ],
        JSXAttribute: [
            "name",
            "value"
        ],
        JSXClosingElement: [
            "name"
        ],
        JSXElement: [
            "openingElement",
            "children",
            "closingElement"
        ],
        JSXEmptyExpression: [],
        JSXExpressionContainer: [
            "expression"
        ],
        JSXIdentifier: [],
        JSXMemberExpression: [
            "object",
            "property"
        ],
        JSXNamespacedName: [
            "namespace",
            "name"
        ],
        JSXOpeningElement: [
            "name",
            "attributes"
        ],
        JSXSpreadAttribute: [
            "argument"
        ],
        JSXText: [],
        JSXFragment: [
            "openingFragment",
            "children",
            "closingFragment"
        ],
        JSXClosingFragment: [],
        JSXOpeningFragment: [],
        Literal: [],
        LabeledStatement: [
            "label",
            "body"
        ],
        LogicalExpression: [
            "left",
            "right"
        ],
        MemberExpression: [
            "object",
            "property"
        ],
        MetaProperty: [
            "meta",
            "property"
        ],
        MethodDefinition: [
            "key",
            "value"
        ],
        NewExpression: [
            "callee",
            "arguments"
        ],
        ObjectExpression: [
            "properties"
        ],
        ObjectPattern: [
            "properties"
        ],
        PrivateIdentifier: [],
        Program: [
            "body"
        ],
        Property: [
            "key",
            "value"
        ],
        PropertyDefinition: [
            "key",
            "value"
        ],
        RestElement: [
            "argument"
        ],
        ReturnStatement: [
            "argument"
        ],
        SequenceExpression: [
            "expressions"
        ],
        SpreadElement: [
            "argument"
        ],
        StaticBlock: [
            "body"
        ],
        Super: [],
        SwitchStatement: [
            "discriminant",
            "cases"
        ],
        SwitchCase: [
            "test",
            "consequent"
        ],
        TaggedTemplateExpression: [
            "tag",
            "quasi"
        ],
        TemplateElement: [],
        TemplateLiteral: [
            "quasis",
            "expressions"
        ],
        ThisExpression: [],
        ThrowStatement: [
            "argument"
        ],
        TryStatement: [
            "block",
            "handler",
            "finalizer"
        ],
        UnaryExpression: [
            "argument"
        ],
        UpdateExpression: [
            "argument"
        ],
        VariableDeclaration: [
            "declarations"
        ],
        VariableDeclarator: [
            "id",
            "init"
        ],
        WhileStatement: [
            "test",
            "body"
        ],
        WithStatement: [
            "object",
            "body"
        ],
        YieldExpression: [
            "argument"
        ]
    };
    // Types.
    const NODE_TYPES = Object.keys(KEYS);
    // Freeze the keys.
    for (const type of NODE_TYPES) {
        Object.freeze(KEYS[type]);
    }
    Object.freeze(KEYS);
    /**
     * @author Toru Nagashima <https://github.com/mysticatea>
     * See LICENSE file in root directory for full license.
     */
    /**
     * @typedef {{ readonly [type: string]: ReadonlyArray<string> }} VisitorKeys
     */
    // List to ignore keys.
    const KEY_BLACKLIST = new Set([
        "parent",
        "leadingComments",
        "trailingComments"
    ]);
    /**
     * Check whether a given key should be used or not.
     * @param {string} key The key to check.
     * @returns {boolean} `true` if the key should be used.
     */
    function filterKey(key) {
        return !KEY_BLACKLIST.has(key) && key[0] !== "_";
    }
    /**
     * Get visitor keys of a given node.
     * @param {object} node The AST node to get keys.
     * @returns {readonly string[]} Visitor keys of the node.
     */
    function getKeys(node) {
        return Object.keys(node).filter(filterKey);
    }
    // Disable valid-jsdoc rule because it reports syntax error on the type of @returns.
    // eslint-disable-next-line valid-jsdoc
    /**
     * Make the union set with `KEYS` and given keys.
     * @param {VisitorKeys} additionalKeys The additional keys.
     * @returns {VisitorKeys} The union set.
     */
    function unionWith(additionalKeys) {
        const retv = /** @type {{
            [type: string]: ReadonlyArray<string>
        }} */ (Object.assign({}, KEYS));
        for (const type of Object.keys(additionalKeys)) {
            if (Object.prototype.hasOwnProperty.call(retv, type)) {
                const keys = new Set(additionalKeys[type]);
                for (const key of retv[type]) {
                    keys.add(key);
                }
                retv[type] = Object.freeze(Array.from(keys));
            }
            else {
                retv[type] = Object.freeze(Array.from(additionalKeys[type]));
            }
        }
        return Object.freeze(retv);
    }
    exports.KEYS = KEYS;
    exports.getKeys = getKeys;
    exports.unionWith = unionWith;
    
},
/* espree/dist/espree.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    var acorn = require(47) /* acorn */;
    var jsx = require(306) /* acorn-jsx */;
    var visitorKeys = require(304) /* eslint-visitor-keys */;
    function _interopDefaultLegacy(e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }
    function _interopNamespace(e) {
        if (e && e.__esModule)
            return e;
        var n = Object.create(null);
        if (e) {
            Object.keys(e).forEach(function (k) {
                if (k !== 'default') {
                    var d = Object.getOwnPropertyDescriptor(e, k);
                    Object.defineProperty(n, k, d.get ? d : {
                        enumerable: true,
                        get: function () { return e[k]; }
                    });
                }
            });
        }
        n["default"] = e;
        return Object.freeze(n);
    }
    var acorn__namespace = /*#__PURE__*/ _interopNamespace(acorn);
    var jsx__default = /*#__PURE__*/ _interopDefaultLegacy(jsx);
    var visitorKeys__namespace = /*#__PURE__*/ _interopNamespace(visitorKeys);
    /**
     * @fileoverview Translates tokens between Acorn format and Esprima format.
     * @author Nicholas C. Zakas
     */
    /* eslint no-underscore-dangle: 0 */
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    // none!
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    // Esprima Token Types
    const Token = {
        Boolean: "Boolean",
        EOF: "<end>",
        Identifier: "Identifier",
        PrivateIdentifier: "PrivateIdentifier",
        Keyword: "Keyword",
        Null: "Null",
        Numeric: "Numeric",
        Punctuator: "Punctuator",
        String: "String",
        RegularExpression: "RegularExpression",
        Template: "Template",
        JSXIdentifier: "JSXIdentifier",
        JSXText: "JSXText"
    };
    /**
     * Converts part of a template into an Esprima token.
     * @param {AcornToken[]} tokens The Acorn tokens representing the template.
     * @param {string} code The source code.
     * @returns {EsprimaToken} The Esprima equivalent of the template token.
     * @private
     */
    function convertTemplatePart(tokens, code) {
        const firstToken = tokens[0], lastTemplateToken = tokens[tokens.length - 1];
        const token = {
            type: Token.Template,
            value: code.slice(firstToken.start, lastTemplateToken.end)
        };
        if (firstToken.loc) {
            token.loc = {
                start: firstToken.loc.start,
                end: lastTemplateToken.loc.end
            };
        }
        if (firstToken.range) {
            token.start = firstToken.range[0];
            token.end = lastTemplateToken.range[1];
            token.range = [token.start, token.end];
        }
        return token;
    }
    /**
     * Contains logic to translate Acorn tokens into Esprima tokens.
     * @param {Object} acornTokTypes The Acorn token types.
     * @param {string} code The source code Acorn is parsing. This is necessary
     *      to correct the "value" property of some tokens.
     * @constructor
     */
    function TokenTranslator(acornTokTypes, code) {
        // token types
        this._acornTokTypes = acornTokTypes;
        // token buffer for templates
        this._tokens = [];
        // track the last curly brace
        this._curlyBrace = null;
        // the source code
        this._code = code;
    }
    TokenTranslator.prototype = {
        constructor: TokenTranslator,
        /**
         * Translates a single Esprima token to a single Acorn token. This may be
         * inaccurate due to how templates are handled differently in Esprima and
         * Acorn, but should be accurate for all other tokens.
         * @param {AcornToken} token The Acorn token to translate.
         * @param {Object} extra Espree extra object.
         * @returns {EsprimaToken} The Esprima version of the token.
         */
        translate(token, extra) {
            const type = token.type, tt = this._acornTokTypes;
            if (type === tt.name) {
                token.type = Token.Identifier;
                // TODO: See if this is an Acorn bug
                if (token.value === "static") {
                    token.type = Token.Keyword;
                }
                if (extra.ecmaVersion > 5 && (token.value === "yield" || token.value === "let")) {
                    token.type = Token.Keyword;
                }
            }
            else if (type === tt.privateId) {
                token.type = Token.PrivateIdentifier;
            }
            else if (type === tt.semi || type === tt.comma ||
                type === tt.parenL || type === tt.parenR ||
                type === tt.braceL || type === tt.braceR ||
                type === tt.dot || type === tt.bracketL ||
                type === tt.colon || type === tt.question ||
                type === tt.bracketR || type === tt.ellipsis ||
                type === tt.arrow || type === tt.jsxTagStart ||
                type === tt.incDec || type === tt.starstar ||
                type === tt.jsxTagEnd || type === tt.prefix ||
                type === tt.questionDot ||
                (type.binop && !type.keyword) ||
                type.isAssign) {
                token.type = Token.Punctuator;
                token.value = this._code.slice(token.start, token.end);
            }
            else if (type === tt.jsxName) {
                token.type = Token.JSXIdentifier;
            }
            else if (type.label === "jsxText" || type === tt.jsxAttrValueToken) {
                token.type = Token.JSXText;
            }
            else if (type.keyword) {
                if (type.keyword === "true" || type.keyword === "false") {
                    token.type = Token.Boolean;
                }
                else if (type.keyword === "null") {
                    token.type = Token.Null;
                }
                else {
                    token.type = Token.Keyword;
                }
            }
            else if (type === tt.num) {
                token.type = Token.Numeric;
                token.value = this._code.slice(token.start, token.end);
            }
            else if (type === tt.string) {
                if (extra.jsxAttrValueToken) {
                    extra.jsxAttrValueToken = false;
                    token.type = Token.JSXText;
                }
                else {
                    token.type = Token.String;
                }
                token.value = this._code.slice(token.start, token.end);
            }
            else if (type === tt.regexp) {
                token.type = Token.RegularExpression;
                const value = token.value;
                token.regex = {
                    flags: value.flags,
                    pattern: value.pattern
                };
                token.value = `/${value.pattern}/${value.flags}`;
            }
            return token;
        },
        /**
         * Function to call during Acorn's onToken handler.
         * @param {AcornToken} token The Acorn token.
         * @param {Object} extra The Espree extra object.
         * @returns {void}
         */
        onToken(token, extra) {
            const that = this, tt = this._acornTokTypes, tokens = extra.tokens, templateTokens = this._tokens;
            /**
             * Flushes the buffered template tokens and resets the template
             * tracking.
             * @returns {void}
             * @private
             */
            function translateTemplateTokens() {
                tokens.push(convertTemplatePart(that._tokens, that._code));
                that._tokens = [];
            }
            if (token.type === tt.eof) {
                // might be one last curlyBrace
                if (this._curlyBrace) {
                    tokens.push(this.translate(this._curlyBrace, extra));
                }
                return;
            }
            if (token.type === tt.backQuote) {
                // if there's already a curly, it's not part of the template
                if (this._curlyBrace) {
                    tokens.push(this.translate(this._curlyBrace, extra));
                    this._curlyBrace = null;
                }
                templateTokens.push(token);
                // it's the end
                if (templateTokens.length > 1) {
                    translateTemplateTokens();
                }
                return;
            }
            if (token.type === tt.dollarBraceL) {
                templateTokens.push(token);
                translateTemplateTokens();
                return;
            }
            if (token.type === tt.braceR) {
                // if there's already a curly, it's not part of the template
                if (this._curlyBrace) {
                    tokens.push(this.translate(this._curlyBrace, extra));
                }
                // store new curly for later
                this._curlyBrace = token;
                return;
            }
            if (token.type === tt.template || token.type === tt.invalidTemplate) {
                if (this._curlyBrace) {
                    templateTokens.push(this._curlyBrace);
                    this._curlyBrace = null;
                }
                templateTokens.push(token);
                return;
            }
            if (this._curlyBrace) {
                tokens.push(this.translate(this._curlyBrace, extra));
                this._curlyBrace = null;
            }
            tokens.push(this.translate(token, extra));
        }
    };
    /**
     * @fileoverview A collection of methods for processing Espree's options.
     * @author Kai Cataldo
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const SUPPORTED_VERSIONS = [
        3,
        5,
        6,
        7,
        8,
        9,
        10,
        11,
        12,
        13,
        14 // 2023
    ];
    /**
     * Get the latest ECMAScript version supported by Espree.
     * @returns {number} The latest ECMAScript version.
     */
    function getLatestEcmaVersion() {
        return SUPPORTED_VERSIONS[SUPPORTED_VERSIONS.length - 1];
    }
    /**
     * Get the list of ECMAScript versions supported by Espree.
     * @returns {number[]} An array containing the supported ECMAScript versions.
     */
    function getSupportedEcmaVersions() {
        return [...SUPPORTED_VERSIONS];
    }
    /**
     * Normalize ECMAScript version from the initial config
     * @param {(number|"latest")} ecmaVersion ECMAScript version from the initial config
     * @throws {Error} throws an error if the ecmaVersion is invalid.
     * @returns {number} normalized ECMAScript version
     */
    function normalizeEcmaVersion(ecmaVersion = 5) {
        let version = ecmaVersion === "latest" ? getLatestEcmaVersion() : ecmaVersion;
        if (typeof version !== "number") {
            throw new Error(`ecmaVersion must be a number or "latest". Received value of type ${typeof ecmaVersion} instead.`);
        }
        // Calculate ECMAScript edition number from official year version starting with
        // ES2015, which corresponds with ES6 (or a difference of 2009).
        if (version >= 2015) {
            version -= 2009;
        }
        if (!SUPPORTED_VERSIONS.includes(version)) {
            throw new Error("Invalid ecmaVersion.");
        }
        return version;
    }
    /**
     * Normalize sourceType from the initial config
     * @param {string} sourceType to normalize
     * @throws {Error} throw an error if sourceType is invalid
     * @returns {string} normalized sourceType
     */
    function normalizeSourceType(sourceType = "script") {
        if (sourceType === "script" || sourceType === "module") {
            return sourceType;
        }
        if (sourceType === "commonjs") {
            return "script";
        }
        throw new Error("Invalid sourceType.");
    }
    /**
     * Normalize parserOptions
     * @param {Object} options the parser options to normalize
     * @throws {Error} throw an error if found invalid option.
     * @returns {Object} normalized options
     */
    function normalizeOptions(options) {
        const ecmaVersion = normalizeEcmaVersion(options.ecmaVersion);
        const sourceType = normalizeSourceType(options.sourceType);
        const ranges = options.range === true;
        const locations = options.loc === true;
        if (ecmaVersion !== 3 && options.allowReserved) {
            // a value of `false` is intentionally allowed here, so a shared config can overwrite it when needed
            throw new Error("`allowReserved` is only supported when ecmaVersion is 3");
        }
        if (typeof options.allowReserved !== "undefined" && typeof options.allowReserved !== "boolean") {
            throw new Error("`allowReserved`, when present, must be `true` or `false`");
        }
        const allowReserved = ecmaVersion === 3 ? (options.allowReserved || "never") : false;
        const ecmaFeatures = options.ecmaFeatures || {};
        const allowReturnOutsideFunction = options.sourceType === "commonjs" ||
            Boolean(ecmaFeatures.globalReturn);
        if (sourceType === "module" && ecmaVersion < 6) {
            throw new Error("sourceType 'module' is not supported when ecmaVersion < 2015. Consider adding `{ ecmaVersion: 2015 }` to the parser options.");
        }
        return Object.assign({}, options, {
            ecmaVersion,
            sourceType,
            ranges,
            locations,
            allowReserved,
            allowReturnOutsideFunction
        });
    }
    /* eslint-disable no-param-reassign*/
    const STATE = Symbol("espree's internal state");
    const ESPRIMA_FINISH_NODE = Symbol("espree's esprimaFinishNode");
    /**
     * Converts an Acorn comment to a Esprima comment.
     * @param {boolean} block True if it's a block comment, false if not.
     * @param {string} text The text of the comment.
     * @param {int} start The index at which the comment starts.
     * @param {int} end The index at which the comment ends.
     * @param {Location} startLoc The location at which the comment starts.
     * @param {Location} endLoc The location at which the comment ends.
     * @param {string} code The source code being parsed.
     * @returns {Object} The comment object.
     * @private
     */
    function convertAcornCommentToEsprimaComment(block, text, start, end, startLoc, endLoc, code) {
        let type;
        if (block) {
            type = "Block";
        }
        else if (code.slice(start, start + 2) === "#!") {
            type = "Hashbang";
        }
        else {
            type = "Line";
        }
        const comment = {
            type,
            value: text
        };
        if (typeof start === "number") {
            comment.start = start;
            comment.end = end;
            comment.range = [start, end];
        }
        if (typeof startLoc === "object") {
            comment.loc = {
                start: startLoc,
                end: endLoc
            };
        }
        return comment;
    }
    var espree = () => Parser => {
        const tokTypes = Object.assign({}, Parser.acorn.tokTypes);
        if (Parser.acornJsx) {
            Object.assign(tokTypes, Parser.acornJsx.tokTypes);
        }
        return class Espree extends Parser {
            constructor(opts, code) {
                if (typeof opts !== "object" || opts === null) {
                    opts = {};
                }
                if (typeof code !== "string" && !(code instanceof String)) {
                    code = String(code);
                }
                // save original source type in case of commonjs
                const originalSourceType = opts.sourceType;
                const options = normalizeOptions(opts);
                const ecmaFeatures = options.ecmaFeatures || {};
                const tokenTranslator = options.tokens === true
                    ? new TokenTranslator(tokTypes, code)
                    : null;
                /*
                 * Data that is unique to Espree and is not represented internally
                 * in Acorn.
                 *
                 * For ES2023 hashbangs, Espree will call `onComment()` during the
                 * constructor, so we must define state before having access to
                 * `this`.
                 */
                const state = {
                    originalSourceType: originalSourceType || options.sourceType,
                    tokens: tokenTranslator ? [] : null,
                    comments: options.comment === true ? [] : null,
                    impliedStrict: ecmaFeatures.impliedStrict === true && options.ecmaVersion >= 5,
                    ecmaVersion: options.ecmaVersion,
                    jsxAttrValueToken: false,
                    lastToken: null,
                    templateElements: []
                };
                // Initialize acorn parser.
                super({
                    // do not use spread, because we don't want to pass any unknown options to acorn
                    ecmaVersion: options.ecmaVersion,
                    sourceType: options.sourceType,
                    ranges: options.ranges,
                    locations: options.locations,
                    allowReserved: options.allowReserved,
                    // Truthy value is true for backward compatibility.
                    allowReturnOutsideFunction: options.allowReturnOutsideFunction,
                    // Collect tokens
                    onToken: token => {
                        if (tokenTranslator) {
                            // Use `tokens`, `ecmaVersion`, and `jsxAttrValueToken` in the state.
                            tokenTranslator.onToken(token, state);
                        }
                        if (token.type !== tokTypes.eof) {
                            state.lastToken = token;
                        }
                    },
                    // Collect comments
                    onComment: (block, text, start, end, startLoc, endLoc) => {
                        if (state.comments) {
                            const comment = convertAcornCommentToEsprimaComment(block, text, start, end, startLoc, endLoc, code);
                            state.comments.push(comment);
                        }
                    }
                }, code);
                /*
                 * We put all of this data into a symbol property as a way to avoid
                 * potential naming conflicts with future versions of Acorn.
                 */
                this[STATE] = state;
            }
            tokenize() {
                do {
                    this.next();
                } while (this.type !== tokTypes.eof);
                // Consume the final eof token
                this.next();
                const extra = this[STATE];
                const tokens = extra.tokens;
                if (extra.comments) {
                    tokens.comments = extra.comments;
                }
                return tokens;
            }
            finishNode(...args) {
                const result = super.finishNode(...args);
                return this[ESPRIMA_FINISH_NODE](result);
            }
            finishNodeAt(...args) {
                const result = super.finishNodeAt(...args);
                return this[ESPRIMA_FINISH_NODE](result);
            }
            parse() {
                const extra = this[STATE];
                const program = super.parse();
                program.sourceType = extra.originalSourceType;
                if (extra.comments) {
                    program.comments = extra.comments;
                }
                if (extra.tokens) {
                    program.tokens = extra.tokens;
                }
                /*
                 * Adjust opening and closing position of program to match Esprima.
                 * Acorn always starts programs at range 0 whereas Esprima starts at the
                 * first AST node's start (the only real difference is when there's leading
                 * whitespace or leading comments). Acorn also counts trailing whitespace
                 * as part of the program whereas Esprima only counts up to the last token.
                 */
                if (program.body.length) {
                    const [firstNode] = program.body;
                    if (program.range) {
                        program.range[0] = firstNode.range[0];
                    }
                    if (program.loc) {
                        program.loc.start = firstNode.loc.start;
                    }
                    program.start = firstNode.start;
                }
                if (extra.lastToken) {
                    if (program.range) {
                        program.range[1] = extra.lastToken.range[1];
                    }
                    if (program.loc) {
                        program.loc.end = extra.lastToken.loc.end;
                    }
                    program.end = extra.lastToken.end;
                }
                /*
                 * https://github.com/eslint/espree/issues/349
                 * Ensure that template elements have correct range information.
                 * This is one location where Acorn produces a different value
                 * for its start and end properties vs. the values present in the
                 * range property. In order to avoid confusion, we set the start
                 * and end properties to the values that are present in range.
                 * This is done here, instead of in finishNode(), because Acorn
                 * uses the values of start and end internally while parsing, making
                 * it dangerous to change those values while parsing is ongoing.
                 * By waiting until the end of parsing, we can safely change these
                 * values without affect any other part of the process.
                 */
                this[STATE].templateElements.forEach(templateElement => {
                    const startOffset = -1;
                    const endOffset = templateElement.tail ? 1 : 2;
                    templateElement.start += startOffset;
                    templateElement.end += endOffset;
                    if (templateElement.range) {
                        templateElement.range[0] += startOffset;
                        templateElement.range[1] += endOffset;
                    }
                    if (templateElement.loc) {
                        templateElement.loc.start.column += startOffset;
                        templateElement.loc.end.column += endOffset;
                    }
                });
                return program;
            }
            parseTopLevel(node) {
                if (this[STATE].impliedStrict) {
                    this.strict = true;
                }
                return super.parseTopLevel(node);
            }
            /**
             * Overwrites the default raise method to throw Esprima-style errors.
             * @param {int} pos The position of the error.
             * @param {string} message The error message.
             * @throws {SyntaxError} A syntax error.
             * @returns {void}
             */
            raise(pos, message) {
                const loc = Parser.acorn.getLineInfo(this.input, pos);
                const err = new SyntaxError(message);
                err.index = pos;
                err.lineNumber = loc.line;
                err.column = loc.column + 1; // acorn uses 0-based columns
                throw err;
            }
            /**
             * Overwrites the default raise method to throw Esprima-style errors.
             * @param {int} pos The position of the error.
             * @param {string} message The error message.
             * @throws {SyntaxError} A syntax error.
             * @returns {void}
             */
            raiseRecoverable(pos, message) {
                this.raise(pos, message);
            }
            /**
             * Overwrites the default unexpected method to throw Esprima-style errors.
             * @param {int} pos The position of the error.
             * @throws {SyntaxError} A syntax error.
             * @returns {void}
             */
            unexpected(pos) {
                let message = "Unexpected token";
                if (pos !== null && pos !== void 0) {
                    this.pos = pos;
                    if (this.options.locations) {
                        while (this.pos < this.lineStart) {
                            this.lineStart = this.input.lastIndexOf("\n", this.lineStart - 2) + 1;
                            --this.curLine;
                        }
                    }
                    this.nextToken();
                }
                if (this.end > this.start) {
                    message += ` ${this.input.slice(this.start, this.end)}`;
                }
                this.raise(this.start, message);
            }
            /*
            * Esprima-FB represents JSX strings as tokens called "JSXText", but Acorn-JSX
            * uses regular tt.string without any distinction between this and regular JS
            * strings. As such, we intercept an attempt to read a JSX string and set a flag
            * on extra so that when tokens are converted, the next token will be switched
            * to JSXText via onToken.
            */
            jsx_readString(quote) {
                const result = super.jsx_readString(quote);
                if (this.type === tokTypes.string) {
                    this[STATE].jsxAttrValueToken = true;
                }
                return result;
            }
            /**
             * Performs last-minute Esprima-specific compatibility checks and fixes.
             * @param {ASTNode} result The node to check.
             * @returns {ASTNode} The finished node.
             */
            [ESPRIMA_FINISH_NODE](result) {
                // Acorn doesn't count the opening and closing backticks as part of templates
                // so we have to adjust ranges/locations appropriately.
                if (result.type === "TemplateElement") {
                    // save template element references to fix start/end later
                    this[STATE].templateElements.push(result);
                }
                if (result.type.includes("Function") && !result.generator) {
                    result.generator = false;
                }
                return result;
            }
        };
    };
    const version$1 = "9.5.0";
    /**
     * @fileoverview Main Espree file that converts Acorn into Esprima output.
     *
     * This file contains code from the following MIT-licensed projects:
     * 1. Acorn
     * 2. Babylon
     * 3. Babel-ESLint
     *
     * This file also contains code from Esprima, which is BSD licensed.
     *
     * Acorn is Copyright 2012-2015 Acorn Contributors (https://github.com/marijnh/acorn/blob/master/AUTHORS)
     * Babylon is Copyright 2014-2015 various contributors (https://github.com/babel/babel/blob/master/packages/babylon/AUTHORS)
     * Babel-ESLint is Copyright 2014-2015 Sebastian McKenzie <sebmck@gmail.com>
     *
     * Redistribution and use in source and binary forms, with or without
     * modification, are permitted provided that the following conditions are met:
     *
     * * Redistributions of source code must retain the above copyright
     *   notice, this list of conditions and the following disclaimer.
     * * Redistributions in binary form must reproduce the above copyright
     *   notice, this list of conditions and the following disclaimer in the
     *   documentation and/or other materials provided with the distribution.
     *
     * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
     * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
     * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
     * ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
     * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
     * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
     * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
     * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
     * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
     * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
     *
     * Esprima is Copyright (c) jQuery Foundation, Inc. and Contributors, All Rights Reserved.
     *
     * Redistribution and use in source and binary forms, with or without
     * modification, are permitted provided that the following conditions are met:
     *
     *   * Redistributions of source code must retain the above copyright
     *     notice, this list of conditions and the following disclaimer.
     *   * Redistributions in binary form must reproduce the above copyright
     *     notice, this list of conditions and the following disclaimer in the
     *     documentation and/or other materials provided with the distribution.
     *
     * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
     * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
     * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
     * ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
     * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
     * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
     * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
     * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
     * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
     * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
     */
    // To initialize lazily.
    const parsers = {
        _regular: null,
        _jsx: null,
        get regular() {
            if (this._regular === null) {
                this._regular = acorn__namespace.Parser.extend(espree());
            }
            return this._regular;
        },
        get jsx() {
            if (this._jsx === null) {
                this._jsx = acorn__namespace.Parser.extend(jsx__default["default"](), espree());
            }
            return this._jsx;
        },
        get(options) {
            const useJsx = Boolean(options &&
                options.ecmaFeatures &&
                options.ecmaFeatures.jsx);
            return useJsx ? this.jsx : this.regular;
        }
    };
    //------------------------------------------------------------------------------
    // Tokenizer
    //------------------------------------------------------------------------------
    /**
     * Tokenizes the given code.
     * @param {string} code The code to tokenize.
     * @param {Object} options Options defining how to tokenize.
     * @returns {Token[]} An array of tokens.
     * @throws {SyntaxError} If the input code is invalid.
     * @private
     */
    function tokenize(code, options) {
        const Parser = parsers.get(options);
        // Ensure to collect tokens.
        if (!options || options.tokens !== true) {
            options = Object.assign({}, options, { tokens: true }); // eslint-disable-line no-param-reassign
        }
        return new Parser(options, code).tokenize();
    }
    //------------------------------------------------------------------------------
    // Parser
    //------------------------------------------------------------------------------
    /**
     * Parses the given code.
     * @param {string} code The code to tokenize.
     * @param {Object} options Options defining how to tokenize.
     * @returns {ASTNode} The "Program" AST node.
     * @throws {SyntaxError} If the input code is invalid.
     */
    function parse(code, options) {
        const Parser = parsers.get(options);
        return new Parser(options, code).parse();
    }
    //------------------------------------------------------------------------------
    // Public
    //------------------------------------------------------------------------------
    const version = version$1;
    const name = "espree";
    /* istanbul ignore next */
    const VisitorKeys = (function () {
        return visitorKeys__namespace.KEYS;
    }());
    // Derive node types from VisitorKeys
    /* istanbul ignore next */
    const Syntax = (function () {
        let key, types = {};
        if (typeof Object.create === "function") {
            types = Object.create(null);
        }
        for (key in VisitorKeys) {
            if (Object.hasOwnProperty.call(VisitorKeys, key)) {
                types[key] = key;
            }
        }
        if (typeof Object.freeze === "function") {
            Object.freeze(types);
        }
        return types;
    }());
    const latestEcmaVersion = getLatestEcmaVersion();
    const supportedEcmaVersions = getSupportedEcmaVersions();
    exports.Syntax = Syntax;
    exports.VisitorKeys = VisitorKeys;
    exports.latestEcmaVersion = latestEcmaVersion;
    exports.name = name;
    exports.parse = parse;
    exports.supportedEcmaVersions = supportedEcmaVersions;
    exports.tokenize = tokenize;
    exports.version = version;
    
},
/* acorn-jsx/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const XHTMLEntities = require(307) /* ./xhtml */;
    const hexNumber = /^[\da-fA-F]+$/;
    const decimalNumber = /^\d+$/;
    // The map to `acorn-jsx` tokens from `acorn` namespace objects.
    const acornJsxMap = new WeakMap();
    // Get the original tokens for the given `acorn` namespace object.
    function getJsxTokens(acorn) {
        acorn = acorn.Parser.acorn || acorn;
        let acornJsx = acornJsxMap.get(acorn);
        if (!acornJsx) {
            const tt = acorn.tokTypes;
            const TokContext = acorn.TokContext;
            const TokenType = acorn.TokenType;
            const tc_oTag = new TokContext('<tag', false);
            const tc_cTag = new TokContext('</tag', false);
            const tc_expr = new TokContext('<tag>...</tag>', true, true);
            const tokContexts = {
                tc_oTag: tc_oTag,
                tc_cTag: tc_cTag,
                tc_expr: tc_expr
            };
            const tokTypes = {
                jsxName: new TokenType('jsxName'),
                jsxText: new TokenType('jsxText', { beforeExpr: true }),
                jsxTagStart: new TokenType('jsxTagStart', { startsExpr: true }),
                jsxTagEnd: new TokenType('jsxTagEnd')
            };
            tokTypes.jsxTagStart.updateContext = function () {
                this.context.push(tc_expr); // treat as beginning of JSX expression
                this.context.push(tc_oTag); // start opening tag context
                this.exprAllowed = false;
            };
            tokTypes.jsxTagEnd.updateContext = function (prevType) {
                let out = this.context.pop();
                if (out === tc_oTag && prevType === tt.slash || out === tc_cTag) {
                    this.context.pop();
                    this.exprAllowed = this.curContext() === tc_expr;
                }
                else {
                    this.exprAllowed = true;
                }
            };
            acornJsx = { tokContexts: tokContexts, tokTypes: tokTypes };
            acornJsxMap.set(acorn, acornJsx);
        }
        return acornJsx;
    }
    // Transforms JSX element name to string.
    function getQualifiedJSXName(object) {
        if (!object)
            return object;
        if (object.type === 'JSXIdentifier')
            return object.name;
        if (object.type === 'JSXNamespacedName')
            return object.namespace.name + ':' + object.name.name;
        if (object.type === 'JSXMemberExpression')
            return getQualifiedJSXName(object.object) + '.' +
                getQualifiedJSXName(object.property);
    }
    module.exports = function (options) {
        options = options || {};
        return function (Parser) {
            return plugin({
                allowNamespaces: options.allowNamespaces !== false,
                allowNamespacedObjects: !!options.allowNamespacedObjects
            }, Parser);
        };
    };
    // This is `tokTypes` of the peer dep.
    // This can be different instances from the actual `tokTypes` this plugin uses.
    Object.defineProperty(module.exports, "tokTypes", {
        get: function get_tokTypes() {
            return getJsxTokens(require(47) /* acorn */).tokTypes;
        },
        configurable: true,
        enumerable: true
    });
    function plugin(options, Parser) {
        const acorn = Parser.acorn || require(47) /* acorn */;
        const acornJsx = getJsxTokens(acorn);
        const tt = acorn.tokTypes;
        const tok = acornJsx.tokTypes;
        const tokContexts = acorn.tokContexts;
        const tc_oTag = acornJsx.tokContexts.tc_oTag;
        const tc_cTag = acornJsx.tokContexts.tc_cTag;
        const tc_expr = acornJsx.tokContexts.tc_expr;
        const isNewLine = acorn.isNewLine;
        const isIdentifierStart = acorn.isIdentifierStart;
        const isIdentifierChar = acorn.isIdentifierChar;
        return class extends Parser {
            // Expose actual `tokTypes` and `tokContexts` to other plugins.
            static get acornJsx() {
                return acornJsx;
            }
            // Reads inline JSX contents token.
            jsx_readToken() {
                let out = '', chunkStart = this.pos;
                for (;;) {
                    if (this.pos >= this.input.length)
                        this.raise(this.start, 'Unterminated JSX contents');
                    let ch = this.input.charCodeAt(this.pos);
                    switch (ch) {
                        case 60: // '<'
                        case 123: // '{'
                            if (this.pos === this.start) {
                                if (ch === 60 && this.exprAllowed) {
                                    ++this.pos;
                                    return this.finishToken(tok.jsxTagStart);
                                }
                                return this.getTokenFromCode(ch);
                            }
                            out += this.input.slice(chunkStart, this.pos);
                            return this.finishToken(tok.jsxText, out);
                        case 38: // '&'
                            out += this.input.slice(chunkStart, this.pos);
                            out += this.jsx_readEntity();
                            chunkStart = this.pos;
                            break;
                        case 62: // '>'
                        case 125: // '}'
                            this.raise(this.pos, "Unexpected token `" + this.input[this.pos] + "`. Did you mean `" +
                                (ch === 62 ? "&gt;" : "&rbrace;") + "` or " + "`{\"" + this.input[this.pos] + "\"}" + "`?");
                        default:
                            if (isNewLine(ch)) {
                                out += this.input.slice(chunkStart, this.pos);
                                out += this.jsx_readNewLine(true);
                                chunkStart = this.pos;
                            }
                            else {
                                ++this.pos;
                            }
                    }
                }
            }
            jsx_readNewLine(normalizeCRLF) {
                let ch = this.input.charCodeAt(this.pos);
                let out;
                ++this.pos;
                if (ch === 13 && this.input.charCodeAt(this.pos) === 10) {
                    ++this.pos;
                    out = normalizeCRLF ? '\n' : '\r\n';
                }
                else {
                    out = String.fromCharCode(ch);
                }
                if (this.options.locations) {
                    ++this.curLine;
                    this.lineStart = this.pos;
                }
                return out;
            }
            jsx_readString(quote) {
                let out = '', chunkStart = ++this.pos;
                for (;;) {
                    if (this.pos >= this.input.length)
                        this.raise(this.start, 'Unterminated string constant');
                    let ch = this.input.charCodeAt(this.pos);
                    if (ch === quote)
                        break;
                    if (ch === 38) { // '&'
                        out += this.input.slice(chunkStart, this.pos);
                        out += this.jsx_readEntity();
                        chunkStart = this.pos;
                    }
                    else if (isNewLine(ch)) {
                        out += this.input.slice(chunkStart, this.pos);
                        out += this.jsx_readNewLine(false);
                        chunkStart = this.pos;
                    }
                    else {
                        ++this.pos;
                    }
                }
                out += this.input.slice(chunkStart, this.pos++);
                return this.finishToken(tt.string, out);
            }
            jsx_readEntity() {
                let str = '', count = 0, entity;
                let ch = this.input[this.pos];
                if (ch !== '&')
                    this.raise(this.pos, 'Entity must start with an ampersand');
                let startPos = ++this.pos;
                while (this.pos < this.input.length && count++ < 10) {
                    ch = this.input[this.pos++];
                    if (ch === ';') {
                        if (str[0] === '#') {
                            if (str[1] === 'x') {
                                str = str.substr(2);
                                if (hexNumber.test(str))
                                    entity = String.fromCharCode(parseInt(str, 16));
                            }
                            else {
                                str = str.substr(1);
                                if (decimalNumber.test(str))
                                    entity = String.fromCharCode(parseInt(str, 10));
                            }
                        }
                        else {
                            entity = XHTMLEntities[str];
                        }
                        break;
                    }
                    str += ch;
                }
                if (!entity) {
                    this.pos = startPos;
                    return '&';
                }
                return entity;
            }
            // Read a JSX identifier (valid tag or attribute name).
            //
            // Optimized version since JSX identifiers can't contain
            // escape characters and so can be read as single slice.
            // Also assumes that first character was already checked
            // by isIdentifierStart in readToken.
            jsx_readWord() {
                let ch, start = this.pos;
                do {
                    ch = this.input.charCodeAt(++this.pos);
                } while (isIdentifierChar(ch) || ch === 45); // '-'
                return this.finishToken(tok.jsxName, this.input.slice(start, this.pos));
            }
            // Parse next token as JSX identifier
            jsx_parseIdentifier() {
                let node = this.startNode();
                if (this.type === tok.jsxName)
                    node.name = this.value;
                else if (this.type.keyword)
                    node.name = this.type.keyword;
                else
                    this.unexpected();
                this.next();
                return this.finishNode(node, 'JSXIdentifier');
            }
            // Parse namespaced identifier.
            jsx_parseNamespacedName() {
                let startPos = this.start, startLoc = this.startLoc;
                let name = this.jsx_parseIdentifier();
                if (!options.allowNamespaces || !this.eat(tt.colon))
                    return name;
                var node = this.startNodeAt(startPos, startLoc);
                node.namespace = name;
                node.name = this.jsx_parseIdentifier();
                return this.finishNode(node, 'JSXNamespacedName');
            }
            // Parses element name in any form - namespaced, member
            // or single identifier.
            jsx_parseElementName() {
                if (this.type === tok.jsxTagEnd)
                    return '';
                let startPos = this.start, startLoc = this.startLoc;
                let node = this.jsx_parseNamespacedName();
                if (this.type === tt.dot && node.type === 'JSXNamespacedName' && !options.allowNamespacedObjects) {
                    this.unexpected();
                }
                while (this.eat(tt.dot)) {
                    let newNode = this.startNodeAt(startPos, startLoc);
                    newNode.object = node;
                    newNode.property = this.jsx_parseIdentifier();
                    node = this.finishNode(newNode, 'JSXMemberExpression');
                }
                return node;
            }
            // Parses any type of JSX attribute value.
            jsx_parseAttributeValue() {
                switch (this.type) {
                    case tt.braceL:
                        let node = this.jsx_parseExpressionContainer();
                        if (node.expression.type === 'JSXEmptyExpression')
                            this.raise(node.start, 'JSX attributes must only be assigned a non-empty expression');
                        return node;
                    case tok.jsxTagStart:
                    case tt.string:
                        return this.parseExprAtom();
                    default:
                        this.raise(this.start, 'JSX value should be either an expression or a quoted JSX text');
                }
            }
            // JSXEmptyExpression is unique type since it doesn't actually parse anything,
            // and so it should start at the end of last read token (left brace) and finish
            // at the beginning of the next one (right brace).
            jsx_parseEmptyExpression() {
                let node = this.startNodeAt(this.lastTokEnd, this.lastTokEndLoc);
                return this.finishNodeAt(node, 'JSXEmptyExpression', this.start, this.startLoc);
            }
            // Parses JSX expression enclosed into curly brackets.
            jsx_parseExpressionContainer() {
                let node = this.startNode();
                this.next();
                node.expression = this.type === tt.braceR
                    ? this.jsx_parseEmptyExpression()
                    : this.parseExpression();
                this.expect(tt.braceR);
                return this.finishNode(node, 'JSXExpressionContainer');
            }
            // Parses following JSX attribute name-value pair.
            jsx_parseAttribute() {
                let node = this.startNode();
                if (this.eat(tt.braceL)) {
                    this.expect(tt.ellipsis);
                    node.argument = this.parseMaybeAssign();
                    this.expect(tt.braceR);
                    return this.finishNode(node, 'JSXSpreadAttribute');
                }
                node.name = this.jsx_parseNamespacedName();
                node.value = this.eat(tt.eq) ? this.jsx_parseAttributeValue() : null;
                return this.finishNode(node, 'JSXAttribute');
            }
            // Parses JSX opening tag starting after '<'.
            jsx_parseOpeningElementAt(startPos, startLoc) {
                let node = this.startNodeAt(startPos, startLoc);
                node.attributes = [];
                let nodeName = this.jsx_parseElementName();
                if (nodeName)
                    node.name = nodeName;
                while (this.type !== tt.slash && this.type !== tok.jsxTagEnd)
                    node.attributes.push(this.jsx_parseAttribute());
                node.selfClosing = this.eat(tt.slash);
                this.expect(tok.jsxTagEnd);
                return this.finishNode(node, nodeName ? 'JSXOpeningElement' : 'JSXOpeningFragment');
            }
            // Parses JSX closing tag starting after '</'.
            jsx_parseClosingElementAt(startPos, startLoc) {
                let node = this.startNodeAt(startPos, startLoc);
                let nodeName = this.jsx_parseElementName();
                if (nodeName)
                    node.name = nodeName;
                this.expect(tok.jsxTagEnd);
                return this.finishNode(node, nodeName ? 'JSXClosingElement' : 'JSXClosingFragment');
            }
            // Parses entire JSX element, including it's opening tag
            // (starting after '<'), attributes, contents and closing tag.
            jsx_parseElementAt(startPos, startLoc) {
                let node = this.startNodeAt(startPos, startLoc);
                let children = [];
                let openingElement = this.jsx_parseOpeningElementAt(startPos, startLoc);
                let closingElement = null;
                if (!openingElement.selfClosing) {
                    contents: for (;;) {
                        switch (this.type) {
                            case tok.jsxTagStart:
                                startPos = this.start;
                                startLoc = this.startLoc;
                                this.next();
                                if (this.eat(tt.slash)) {
                                    closingElement = this.jsx_parseClosingElementAt(startPos, startLoc);
                                    break contents;
                                }
                                children.push(this.jsx_parseElementAt(startPos, startLoc));
                                break;
                            case tok.jsxText:
                                children.push(this.parseExprAtom());
                                break;
                            case tt.braceL:
                                children.push(this.jsx_parseExpressionContainer());
                                break;
                            default:
                                this.unexpected();
                        }
                    }
                    if (getQualifiedJSXName(closingElement.name) !== getQualifiedJSXName(openingElement.name)) {
                        this.raise(closingElement.start, 'Expected corresponding JSX closing tag for <' + getQualifiedJSXName(openingElement.name) + '>');
                    }
                }
                let fragmentOrElement = openingElement.name ? 'Element' : 'Fragment';
                node['opening' + fragmentOrElement] = openingElement;
                node['closing' + fragmentOrElement] = closingElement;
                node.children = children;
                if (this.type === tt.relational && this.value === "<") {
                    this.raise(this.start, "Adjacent JSX elements must be wrapped in an enclosing tag");
                }
                return this.finishNode(node, 'JSX' + fragmentOrElement);
            }
            // Parse JSX text
            jsx_parseText() {
                let node = this.parseLiteral(this.value);
                node.type = "JSXText";
                return node;
            }
            // Parses entire JSX element from current position.
            jsx_parseElement() {
                let startPos = this.start, startLoc = this.startLoc;
                this.next();
                return this.jsx_parseElementAt(startPos, startLoc);
            }
            parseExprAtom(refShortHandDefaultPos) {
                if (this.type === tok.jsxText)
                    return this.jsx_parseText();
                else if (this.type === tok.jsxTagStart)
                    return this.jsx_parseElement();
                else
                    return super.parseExprAtom(refShortHandDefaultPos);
            }
            readToken(code) {
                let context = this.curContext();
                if (context === tc_expr)
                    return this.jsx_readToken();
                if (context === tc_oTag || context === tc_cTag) {
                    if (isIdentifierStart(code))
                        return this.jsx_readWord();
                    if (code == 62) {
                        ++this.pos;
                        return this.finishToken(tok.jsxTagEnd);
                    }
                    if ((code === 34 || code === 39) && context == tc_oTag)
                        return this.jsx_readString(code);
                }
                if (code === 60 && this.exprAllowed && this.input.charCodeAt(this.pos + 1) !== 33) {
                    ++this.pos;
                    return this.finishToken(tok.jsxTagStart);
                }
                return super.readToken(code);
            }
            updateContext(prevType) {
                if (this.type == tt.braceL) {
                    var curContext = this.curContext();
                    if (curContext == tc_oTag)
                        this.context.push(tokContexts.b_expr);
                    else if (curContext == tc_expr)
                        this.context.push(tokContexts.b_tmpl);
                    else
                        super.updateContext(prevType);
                    this.exprAllowed = true;
                }
                else if (this.type === tt.slash && prevType === tok.jsxTagStart) {
                    this.context.length -= 2; // do not consider JSX expr -> JSX open tag -> ... anymore
                    this.context.push(tc_cTag); // reconsider as closing tag context
                    this.exprAllowed = false;
                }
                else {
                    return super.updateContext(prevType);
                }
            }
        };
    }
},
/* acorn-jsx/xhtml.js */ function _(require, module, exports, __esModule, __esExport) {
    module.exports = {
        quot: '\u0022',
        amp: '&',
        apos: '\u0027',
        lt: '<',
        gt: '>',
        nbsp: '\u00A0',
        iexcl: '\u00A1',
        cent: '\u00A2',
        pound: '\u00A3',
        curren: '\u00A4',
        yen: '\u00A5',
        brvbar: '\u00A6',
        sect: '\u00A7',
        uml: '\u00A8',
        copy: '\u00A9',
        ordf: '\u00AA',
        laquo: '\u00AB',
        not: '\u00AC',
        shy: '\u00AD',
        reg: '\u00AE',
        macr: '\u00AF',
        deg: '\u00B0',
        plusmn: '\u00B1',
        sup2: '\u00B2',
        sup3: '\u00B3',
        acute: '\u00B4',
        micro: '\u00B5',
        para: '\u00B6',
        middot: '\u00B7',
        cedil: '\u00B8',
        sup1: '\u00B9',
        ordm: '\u00BA',
        raquo: '\u00BB',
        frac14: '\u00BC',
        frac12: '\u00BD',
        frac34: '\u00BE',
        iquest: '\u00BF',
        Agrave: '\u00C0',
        Aacute: '\u00C1',
        Acirc: '\u00C2',
        Atilde: '\u00C3',
        Auml: '\u00C4',
        Aring: '\u00C5',
        AElig: '\u00C6',
        Ccedil: '\u00C7',
        Egrave: '\u00C8',
        Eacute: '\u00C9',
        Ecirc: '\u00CA',
        Euml: '\u00CB',
        Igrave: '\u00CC',
        Iacute: '\u00CD',
        Icirc: '\u00CE',
        Iuml: '\u00CF',
        ETH: '\u00D0',
        Ntilde: '\u00D1',
        Ograve: '\u00D2',
        Oacute: '\u00D3',
        Ocirc: '\u00D4',
        Otilde: '\u00D5',
        Ouml: '\u00D6',
        times: '\u00D7',
        Oslash: '\u00D8',
        Ugrave: '\u00D9',
        Uacute: '\u00DA',
        Ucirc: '\u00DB',
        Uuml: '\u00DC',
        Yacute: '\u00DD',
        THORN: '\u00DE',
        szlig: '\u00DF',
        agrave: '\u00E0',
        aacute: '\u00E1',
        acirc: '\u00E2',
        atilde: '\u00E3',
        auml: '\u00E4',
        aring: '\u00E5',
        aelig: '\u00E6',
        ccedil: '\u00E7',
        egrave: '\u00E8',
        eacute: '\u00E9',
        ecirc: '\u00EA',
        euml: '\u00EB',
        igrave: '\u00EC',
        iacute: '\u00ED',
        icirc: '\u00EE',
        iuml: '\u00EF',
        eth: '\u00F0',
        ntilde: '\u00F1',
        ograve: '\u00F2',
        oacute: '\u00F3',
        ocirc: '\u00F4',
        otilde: '\u00F5',
        ouml: '\u00F6',
        divide: '\u00F7',
        oslash: '\u00F8',
        ugrave: '\u00F9',
        uacute: '\u00FA',
        ucirc: '\u00FB',
        uuml: '\u00FC',
        yacute: '\u00FD',
        thorn: '\u00FE',
        yuml: '\u00FF',
        OElig: '\u0152',
        oelig: '\u0153',
        Scaron: '\u0160',
        scaron: '\u0161',
        Yuml: '\u0178',
        fnof: '\u0192',
        circ: '\u02C6',
        tilde: '\u02DC',
        Alpha: '\u0391',
        Beta: '\u0392',
        Gamma: '\u0393',
        Delta: '\u0394',
        Epsilon: '\u0395',
        Zeta: '\u0396',
        Eta: '\u0397',
        Theta: '\u0398',
        Iota: '\u0399',
        Kappa: '\u039A',
        Lambda: '\u039B',
        Mu: '\u039C',
        Nu: '\u039D',
        Xi: '\u039E',
        Omicron: '\u039F',
        Pi: '\u03A0',
        Rho: '\u03A1',
        Sigma: '\u03A3',
        Tau: '\u03A4',
        Upsilon: '\u03A5',
        Phi: '\u03A6',
        Chi: '\u03A7',
        Psi: '\u03A8',
        Omega: '\u03A9',
        alpha: '\u03B1',
        beta: '\u03B2',
        gamma: '\u03B3',
        delta: '\u03B4',
        epsilon: '\u03B5',
        zeta: '\u03B6',
        eta: '\u03B7',
        theta: '\u03B8',
        iota: '\u03B9',
        kappa: '\u03BA',
        lambda: '\u03BB',
        mu: '\u03BC',
        nu: '\u03BD',
        xi: '\u03BE',
        omicron: '\u03BF',
        pi: '\u03C0',
        rho: '\u03C1',
        sigmaf: '\u03C2',
        sigma: '\u03C3',
        tau: '\u03C4',
        upsilon: '\u03C5',
        phi: '\u03C6',
        chi: '\u03C7',
        psi: '\u03C8',
        omega: '\u03C9',
        thetasym: '\u03D1',
        upsih: '\u03D2',
        piv: '\u03D6',
        ensp: '\u2002',
        emsp: '\u2003',
        thinsp: '\u2009',
        zwnj: '\u200C',
        zwj: '\u200D',
        lrm: '\u200E',
        rlm: '\u200F',
        ndash: '\u2013',
        mdash: '\u2014',
        lsquo: '\u2018',
        rsquo: '\u2019',
        sbquo: '\u201A',
        ldquo: '\u201C',
        rdquo: '\u201D',
        bdquo: '\u201E',
        dagger: '\u2020',
        Dagger: '\u2021',
        bull: '\u2022',
        hellip: '\u2026',
        permil: '\u2030',
        prime: '\u2032',
        Prime: '\u2033',
        lsaquo: '\u2039',
        rsaquo: '\u203A',
        oline: '\u203E',
        frasl: '\u2044',
        euro: '\u20AC',
        image: '\u2111',
        weierp: '\u2118',
        real: '\u211C',
        trade: '\u2122',
        alefsym: '\u2135',
        larr: '\u2190',
        uarr: '\u2191',
        rarr: '\u2192',
        darr: '\u2193',
        harr: '\u2194',
        crarr: '\u21B5',
        lArr: '\u21D0',
        uArr: '\u21D1',
        rArr: '\u21D2',
        dArr: '\u21D3',
        hArr: '\u21D4',
        forall: '\u2200',
        part: '\u2202',
        exist: '\u2203',
        empty: '\u2205',
        nabla: '\u2207',
        isin: '\u2208',
        notin: '\u2209',
        ni: '\u220B',
        prod: '\u220F',
        sum: '\u2211',
        minus: '\u2212',
        lowast: '\u2217',
        radic: '\u221A',
        prop: '\u221D',
        infin: '\u221E',
        ang: '\u2220',
        and: '\u2227',
        or: '\u2228',
        cap: '\u2229',
        cup: '\u222A',
        'int': '\u222B',
        there4: '\u2234',
        sim: '\u223C',
        cong: '\u2245',
        asymp: '\u2248',
        ne: '\u2260',
        equiv: '\u2261',
        le: '\u2264',
        ge: '\u2265',
        sub: '\u2282',
        sup: '\u2283',
        nsub: '\u2284',
        sube: '\u2286',
        supe: '\u2287',
        oplus: '\u2295',
        otimes: '\u2297',
        perp: '\u22A5',
        sdot: '\u22C5',
        lceil: '\u2308',
        rceil: '\u2309',
        lfloor: '\u230A',
        rfloor: '\u230B',
        lang: '\u2329',
        rang: '\u232A',
        loz: '\u25CA',
        spades: '\u2660',
        clubs: '\u2663',
        hearts: '\u2665',
        diams: '\u2666'
    };
},
/* lodash.merge/index.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * Lodash (Custom Build) <https://lodash.com/>
     * Build: `lodash modularize exports="npm" -o ./`
     * Copyright OpenJS Foundation and other contributors <https://openjsf.org/>
     * Released under MIT license <https://lodash.com/license>
     * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
     * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
     */
    /** Used as the size to enable large array optimizations. */
    var LARGE_ARRAY_SIZE = 200;
    /** Used to stand-in for `undefined` hash values. */
    var HASH_UNDEFINED = '__lodash_hash_undefined__';
    /** Used to detect hot functions by number of calls within a span of milliseconds. */
    var HOT_COUNT = 800, HOT_SPAN = 16;
    /** Used as references for various `Number` constants. */
    var MAX_SAFE_INTEGER = 9007199254740991;
    /** `Object#toString` result references. */
    var argsTag = '[object Arguments]', arrayTag = '[object Array]', asyncTag = '[object AsyncFunction]', boolTag = '[object Boolean]', dateTag = '[object Date]', errorTag = '[object Error]', funcTag = '[object Function]', genTag = '[object GeneratorFunction]', mapTag = '[object Map]', numberTag = '[object Number]', nullTag = '[object Null]', objectTag = '[object Object]', proxyTag = '[object Proxy]', regexpTag = '[object RegExp]', setTag = '[object Set]', stringTag = '[object String]', undefinedTag = '[object Undefined]', weakMapTag = '[object WeakMap]';
    var arrayBufferTag = '[object ArrayBuffer]', dataViewTag = '[object DataView]', float32Tag = '[object Float32Array]', float64Tag = '[object Float64Array]', int8Tag = '[object Int8Array]', int16Tag = '[object Int16Array]', int32Tag = '[object Int32Array]', uint8Tag = '[object Uint8Array]', uint8ClampedTag = '[object Uint8ClampedArray]', uint16Tag = '[object Uint16Array]', uint32Tag = '[object Uint32Array]';
    /**
     * Used to match `RegExp`
     * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
     */
    var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;
    /** Used to detect host constructors (Safari). */
    var reIsHostCtor = /^\[object .+?Constructor\]$/;
    /** Used to detect unsigned integer values. */
    var reIsUint = /^(?:0|[1-9]\d*)$/;
    /** Used to identify `toStringTag` values of typed arrays. */
    var typedArrayTags = {};
    typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
        typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
            typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
                typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
                    typedArrayTags[uint32Tag] = true;
    typedArrayTags[argsTag] = typedArrayTags[arrayTag] =
        typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] =
            typedArrayTags[dataViewTag] = typedArrayTags[dateTag] =
                typedArrayTags[errorTag] = typedArrayTags[funcTag] =
                    typedArrayTags[mapTag] = typedArrayTags[numberTag] =
                        typedArrayTags[objectTag] = typedArrayTags[regexpTag] =
                            typedArrayTags[setTag] = typedArrayTags[stringTag] =
                                typedArrayTags[weakMapTag] = false;
    /** Detect free variable `global` from Node.js. */
    var freeGlobal = typeof global == 'object' && global && global.Object === Object && global;
    /** Detect free variable `self`. */
    var freeSelf = typeof self == 'object' && self && self.Object === Object && self;
    /** Used as a reference to the global object. */
    var root = freeGlobal || freeSelf || Function('return this')();
    /** Detect free variable `exports`. */
    var freeExports = typeof exports == 'object' && exports && !exports.nodeType && exports;
    /** Detect free variable `module`. */
    var freeModule = freeExports && typeof module == 'object' && module && !module.nodeType && module;
    /** Detect the popular CommonJS extension `module.exports`. */
    var moduleExports = freeModule && freeModule.exports === freeExports;
    /** Detect free variable `process` from Node.js. */
    var freeProcess = moduleExports && freeGlobal.process;
    /** Used to access faster Node.js helpers. */
    var nodeUtil = (function () {
        try {
            // Use `util.types` for Node.js 10+.
            var types = freeModule && freeModule.require && freeModule.require('util').types;
            if (types) {
                return types;
            }
            // Legacy `process.binding('util')` for Node.js < 10.
            return freeProcess && freeProcess.binding && freeProcess.binding('util');
        }
        catch (e) { }
    }());
    /* Node.js helper references. */
    var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;
    /**
     * A faster alternative to `Function#apply`, this function invokes `func`
     * with the `this` binding of `thisArg` and the arguments of `args`.
     *
     * @private
     * @param {Function} func The function to invoke.
     * @param {*} thisArg The `this` binding of `func`.
     * @param {Array} args The arguments to invoke `func` with.
     * @returns {*} Returns the result of `func`.
     */
    function apply(func, thisArg, args) {
        switch (args.length) {
            case 0: return func.call(thisArg);
            case 1: return func.call(thisArg, args[0]);
            case 2: return func.call(thisArg, args[0], args[1]);
            case 3: return func.call(thisArg, args[0], args[1], args[2]);
        }
        return func.apply(thisArg, args);
    }
    /**
     * The base implementation of `_.times` without support for iteratee shorthands
     * or max array length checks.
     *
     * @private
     * @param {number} n The number of times to invoke `iteratee`.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Array} Returns the array of results.
     */
    function baseTimes(n, iteratee) {
        var index = -1, result = Array(n);
        while (++index < n) {
            result[index] = iteratee(index);
        }
        return result;
    }
    /**
     * The base implementation of `_.unary` without support for storing metadata.
     *
     * @private
     * @param {Function} func The function to cap arguments for.
     * @returns {Function} Returns the new capped function.
     */
    function baseUnary(func) {
        return function (value) {
            return func(value);
        };
    }
    /**
     * Gets the value at `key` of `object`.
     *
     * @private
     * @param {Object} [object] The object to query.
     * @param {string} key The key of the property to get.
     * @returns {*} Returns the property value.
     */
    function getValue(object, key) {
        return object == null ? undefined : object[key];
    }
    /**
     * Creates a unary function that invokes `func` with its argument transformed.
     *
     * @private
     * @param {Function} func The function to wrap.
     * @param {Function} transform The argument transform.
     * @returns {Function} Returns the new function.
     */
    function overArg(func, transform) {
        return function (arg) {
            return func(transform(arg));
        };
    }
    /** Used for built-in method references. */
    var arrayProto = Array.prototype, funcProto = Function.prototype, objectProto = Object.prototype;
    /** Used to detect overreaching core-js shims. */
    var coreJsData = root['__core-js_shared__'];
    /** Used to resolve the decompiled source of functions. */
    var funcToString = funcProto.toString;
    /** Used to check objects for own properties. */
    var hasOwnProperty = objectProto.hasOwnProperty;
    /** Used to detect methods masquerading as native. */
    var maskSrcKey = (function () {
        var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || '');
        return uid ? ('Symbol(src)_1.' + uid) : '';
    }());
    /**
     * Used to resolve the
     * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
     * of values.
     */
    var nativeObjectToString = objectProto.toString;
    /** Used to infer the `Object` constructor. */
    var objectCtorString = funcToString.call(Object);
    /** Used to detect if a method is native. */
    var reIsNative = RegExp('^' +
        funcToString.call(hasOwnProperty).replace(reRegExpChar, '\\$&')
            .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$');
    /** Built-in value references. */
    var Buffer = moduleExports ? root.Buffer : undefined, Symbol = root.Symbol, Uint8Array = root.Uint8Array, allocUnsafe = Buffer ? Buffer.allocUnsafe : undefined, getPrototype = overArg(Object.getPrototypeOf, Object), objectCreate = Object.create, propertyIsEnumerable = objectProto.propertyIsEnumerable, splice = arrayProto.splice, symToStringTag = Symbol ? Symbol.toStringTag : undefined;
    var defineProperty = (function () {
        try {
            var func = getNative(Object, 'defineProperty');
            func({}, '', {});
            return func;
        }
        catch (e) { }
    }());
    /* Built-in method references for those with the same name as other `lodash` methods. */
    var nativeIsBuffer = Buffer ? Buffer.isBuffer : undefined, nativeMax = Math.max, nativeNow = Date.now;
    /* Built-in method references that are verified to be native. */
    var Map = getNative(root, 'Map'), nativeCreate = getNative(Object, 'create');
    /**
     * The base implementation of `_.create` without support for assigning
     * properties to the created object.
     *
     * @private
     * @param {Object} proto The object to inherit from.
     * @returns {Object} Returns the new object.
     */
    var baseCreate = (function () {
        function object() { }
        return function (proto) {
            if (!isObject(proto)) {
                return {};
            }
            if (objectCreate) {
                return objectCreate(proto);
            }
            object.prototype = proto;
            var result = new object;
            object.prototype = undefined;
            return result;
        };
    }());
    /**
     * Creates a hash object.
     *
     * @private
     * @constructor
     * @param {Array} [entries] The key-value pairs to cache.
     */
    function Hash(entries) {
        var index = -1, length = entries == null ? 0 : entries.length;
        this.clear();
        while (++index < length) {
            var entry = entries[index];
            this.set(entry[0], entry[1]);
        }
    }
    /**
     * Removes all key-value entries from the hash.
     *
     * @private
     * @name clear
     * @memberOf Hash
     */
    function hashClear() {
        this.__data__ = nativeCreate ? nativeCreate(null) : {};
        this.size = 0;
    }
    /**
     * Removes `key` and its value from the hash.
     *
     * @private
     * @name delete
     * @memberOf Hash
     * @param {Object} hash The hash to modify.
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
     */
    function hashDelete(key) {
        var result = this.has(key) && delete this.__data__[key];
        this.size -= result ? 1 : 0;
        return result;
    }
    /**
     * Gets the hash value for `key`.
     *
     * @private
     * @name get
     * @memberOf Hash
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the entry value.
     */
    function hashGet(key) {
        var data = this.__data__;
        if (nativeCreate) {
            var result = data[key];
            return result === HASH_UNDEFINED ? undefined : result;
        }
        return hasOwnProperty.call(data, key) ? data[key] : undefined;
    }
    /**
     * Checks if a hash value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf Hash
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function hashHas(key) {
        var data = this.__data__;
        return nativeCreate ? (data[key] !== undefined) : hasOwnProperty.call(data, key);
    }
    /**
     * Sets the hash `key` to `value`.
     *
     * @private
     * @name set
     * @memberOf Hash
     * @param {string} key The key of the value to set.
     * @param {*} value The value to set.
     * @returns {Object} Returns the hash instance.
     */
    function hashSet(key, value) {
        var data = this.__data__;
        this.size += this.has(key) ? 0 : 1;
        data[key] = (nativeCreate && value === undefined) ? HASH_UNDEFINED : value;
        return this;
    }
    // Add methods to `Hash`.
    Hash.prototype.clear = hashClear;
    Hash.prototype['delete'] = hashDelete;
    Hash.prototype.get = hashGet;
    Hash.prototype.has = hashHas;
    Hash.prototype.set = hashSet;
    /**
     * Creates an list cache object.
     *
     * @private
     * @constructor
     * @param {Array} [entries] The key-value pairs to cache.
     */
    function ListCache(entries) {
        var index = -1, length = entries == null ? 0 : entries.length;
        this.clear();
        while (++index < length) {
            var entry = entries[index];
            this.set(entry[0], entry[1]);
        }
    }
    /**
     * Removes all key-value entries from the list cache.
     *
     * @private
     * @name clear
     * @memberOf ListCache
     */
    function listCacheClear() {
        this.__data__ = [];
        this.size = 0;
    }
    /**
     * Removes `key` and its value from the list cache.
     *
     * @private
     * @name delete
     * @memberOf ListCache
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
     */
    function listCacheDelete(key) {
        var data = this.__data__, index = assocIndexOf(data, key);
        if (index < 0) {
            return false;
        }
        var lastIndex = data.length - 1;
        if (index == lastIndex) {
            data.pop();
        }
        else {
            splice.call(data, index, 1);
        }
        --this.size;
        return true;
    }
    /**
     * Gets the list cache value for `key`.
     *
     * @private
     * @name get
     * @memberOf ListCache
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the entry value.
     */
    function listCacheGet(key) {
        var data = this.__data__, index = assocIndexOf(data, key);
        return index < 0 ? undefined : data[index][1];
    }
    /**
     * Checks if a list cache value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf ListCache
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function listCacheHas(key) {
        return assocIndexOf(this.__data__, key) > -1;
    }
    /**
     * Sets the list cache `key` to `value`.
     *
     * @private
     * @name set
     * @memberOf ListCache
     * @param {string} key The key of the value to set.
     * @param {*} value The value to set.
     * @returns {Object} Returns the list cache instance.
     */
    function listCacheSet(key, value) {
        var data = this.__data__, index = assocIndexOf(data, key);
        if (index < 0) {
            ++this.size;
            data.push([key, value]);
        }
        else {
            data[index][1] = value;
        }
        return this;
    }
    // Add methods to `ListCache`.
    ListCache.prototype.clear = listCacheClear;
    ListCache.prototype['delete'] = listCacheDelete;
    ListCache.prototype.get = listCacheGet;
    ListCache.prototype.has = listCacheHas;
    ListCache.prototype.set = listCacheSet;
    /**
     * Creates a map cache object to store key-value pairs.
     *
     * @private
     * @constructor
     * @param {Array} [entries] The key-value pairs to cache.
     */
    function MapCache(entries) {
        var index = -1, length = entries == null ? 0 : entries.length;
        this.clear();
        while (++index < length) {
            var entry = entries[index];
            this.set(entry[0], entry[1]);
        }
    }
    /**
     * Removes all key-value entries from the map.
     *
     * @private
     * @name clear
     * @memberOf MapCache
     */
    function mapCacheClear() {
        this.size = 0;
        this.__data__ = {
            'hash': new Hash,
            'map': new (Map || ListCache),
            'string': new Hash
        };
    }
    /**
     * Removes `key` and its value from the map.
     *
     * @private
     * @name delete
     * @memberOf MapCache
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
     */
    function mapCacheDelete(key) {
        var result = getMapData(this, key)['delete'](key);
        this.size -= result ? 1 : 0;
        return result;
    }
    /**
     * Gets the map value for `key`.
     *
     * @private
     * @name get
     * @memberOf MapCache
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the entry value.
     */
    function mapCacheGet(key) {
        return getMapData(this, key).get(key);
    }
    /**
     * Checks if a map value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf MapCache
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function mapCacheHas(key) {
        return getMapData(this, key).has(key);
    }
    /**
     * Sets the map `key` to `value`.
     *
     * @private
     * @name set
     * @memberOf MapCache
     * @param {string} key The key of the value to set.
     * @param {*} value The value to set.
     * @returns {Object} Returns the map cache instance.
     */
    function mapCacheSet(key, value) {
        var data = getMapData(this, key), size = data.size;
        data.set(key, value);
        this.size += data.size == size ? 0 : 1;
        return this;
    }
    // Add methods to `MapCache`.
    MapCache.prototype.clear = mapCacheClear;
    MapCache.prototype['delete'] = mapCacheDelete;
    MapCache.prototype.get = mapCacheGet;
    MapCache.prototype.has = mapCacheHas;
    MapCache.prototype.set = mapCacheSet;
    /**
     * Creates a stack cache object to store key-value pairs.
     *
     * @private
     * @constructor
     * @param {Array} [entries] The key-value pairs to cache.
     */
    function Stack(entries) {
        var data = this.__data__ = new ListCache(entries);
        this.size = data.size;
    }
    /**
     * Removes all key-value entries from the stack.
     *
     * @private
     * @name clear
     * @memberOf Stack
     */
    function stackClear() {
        this.__data__ = new ListCache;
        this.size = 0;
    }
    /**
     * Removes `key` and its value from the stack.
     *
     * @private
     * @name delete
     * @memberOf Stack
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
     */
    function stackDelete(key) {
        var data = this.__data__, result = data['delete'](key);
        this.size = data.size;
        return result;
    }
    /**
     * Gets the stack value for `key`.
     *
     * @private
     * @name get
     * @memberOf Stack
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the entry value.
     */
    function stackGet(key) {
        return this.__data__.get(key);
    }
    /**
     * Checks if a stack value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf Stack
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function stackHas(key) {
        return this.__data__.has(key);
    }
    /**
     * Sets the stack `key` to `value`.
     *
     * @private
     * @name set
     * @memberOf Stack
     * @param {string} key The key of the value to set.
     * @param {*} value The value to set.
     * @returns {Object} Returns the stack cache instance.
     */
    function stackSet(key, value) {
        var data = this.__data__;
        if (data instanceof ListCache) {
            var pairs = data.__data__;
            if (!Map || (pairs.length < LARGE_ARRAY_SIZE - 1)) {
                pairs.push([key, value]);
                this.size = ++data.size;
                return this;
            }
            data = this.__data__ = new MapCache(pairs);
        }
        data.set(key, value);
        this.size = data.size;
        return this;
    }
    // Add methods to `Stack`.
    Stack.prototype.clear = stackClear;
    Stack.prototype['delete'] = stackDelete;
    Stack.prototype.get = stackGet;
    Stack.prototype.has = stackHas;
    Stack.prototype.set = stackSet;
    /**
     * Creates an array of the enumerable property names of the array-like `value`.
     *
     * @private
     * @param {*} value The value to query.
     * @param {boolean} inherited Specify returning inherited property names.
     * @returns {Array} Returns the array of property names.
     */
    function arrayLikeKeys(value, inherited) {
        var isArr = isArray(value), isArg = !isArr && isArguments(value), isBuff = !isArr && !isArg && isBuffer(value), isType = !isArr && !isArg && !isBuff && isTypedArray(value), skipIndexes = isArr || isArg || isBuff || isType, result = skipIndexes ? baseTimes(value.length, String) : [], length = result.length;
        for (var key in value) {
            if ((inherited || hasOwnProperty.call(value, key)) &&
                !(skipIndexes && (
                // Safari 9 has enumerable `arguments.length` in strict mode.
                key == 'length' ||
                    // Node.js 0.10 has enumerable non-index properties on buffers.
                    (isBuff && (key == 'offset' || key == 'parent')) ||
                    // PhantomJS 2 has enumerable non-index properties on typed arrays.
                    (isType && (key == 'buffer' || key == 'byteLength' || key == 'byteOffset')) ||
                    // Skip index properties.
                    isIndex(key, length)))) {
                result.push(key);
            }
        }
        return result;
    }
    /**
     * This function is like `assignValue` except that it doesn't assign
     * `undefined` values.
     *
     * @private
     * @param {Object} object The object to modify.
     * @param {string} key The key of the property to assign.
     * @param {*} value The value to assign.
     */
    function assignMergeValue(object, key, value) {
        if ((value !== undefined && !eq(object[key], value)) ||
            (value === undefined && !(key in object))) {
            baseAssignValue(object, key, value);
        }
    }
    /**
     * Assigns `value` to `key` of `object` if the existing value is not equivalent
     * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
     * for equality comparisons.
     *
     * @private
     * @param {Object} object The object to modify.
     * @param {string} key The key of the property to assign.
     * @param {*} value The value to assign.
     */
    function assignValue(object, key, value) {
        var objValue = object[key];
        if (!(hasOwnProperty.call(object, key) && eq(objValue, value)) ||
            (value === undefined && !(key in object))) {
            baseAssignValue(object, key, value);
        }
    }
    /**
     * Gets the index at which the `key` is found in `array` of key-value pairs.
     *
     * @private
     * @param {Array} array The array to inspect.
     * @param {*} key The key to search for.
     * @returns {number} Returns the index of the matched value, else `-1`.
     */
    function assocIndexOf(array, key) {
        var length = array.length;
        while (length--) {
            if (eq(array[length][0], key)) {
                return length;
            }
        }
        return -1;
    }
    /**
     * The base implementation of `assignValue` and `assignMergeValue` without
     * value checks.
     *
     * @private
     * @param {Object} object The object to modify.
     * @param {string} key The key of the property to assign.
     * @param {*} value The value to assign.
     */
    function baseAssignValue(object, key, value) {
        if (key == '__proto__' && defineProperty) {
            defineProperty(object, key, {
                'configurable': true,
                'enumerable': true,
                'value': value,
                'writable': true
            });
        }
        else {
            object[key] = value;
        }
    }
    /**
     * The base implementation of `baseForOwn` which iterates over `object`
     * properties returned by `keysFunc` and invokes `iteratee` for each property.
     * Iteratee functions may exit iteration early by explicitly returning `false`.
     *
     * @private
     * @param {Object} object The object to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @param {Function} keysFunc The function to get the keys of `object`.
     * @returns {Object} Returns `object`.
     */
    var baseFor = createBaseFor();
    /**
     * The base implementation of `getTag` without fallbacks for buggy environments.
     *
     * @private
     * @param {*} value The value to query.
     * @returns {string} Returns the `toStringTag`.
     */
    function baseGetTag(value) {
        if (value == null) {
            return value === undefined ? undefinedTag : nullTag;
        }
        return (symToStringTag && symToStringTag in Object(value))
            ? getRawTag(value)
            : objectToString(value);
    }
    /**
     * The base implementation of `_.isArguments`.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an `arguments` object,
     */
    function baseIsArguments(value) {
        return isObjectLike(value) && baseGetTag(value) == argsTag;
    }
    /**
     * The base implementation of `_.isNative` without bad shim checks.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a native function,
     *  else `false`.
     */
    function baseIsNative(value) {
        if (!isObject(value) || isMasked(value)) {
            return false;
        }
        var pattern = isFunction(value) ? reIsNative : reIsHostCtor;
        return pattern.test(toSource(value));
    }
    /**
     * The base implementation of `_.isTypedArray` without Node.js optimizations.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
     */
    function baseIsTypedArray(value) {
        return isObjectLike(value) &&
            isLength(value.length) && !!typedArrayTags[baseGetTag(value)];
    }
    /**
     * The base implementation of `_.keysIn` which doesn't treat sparse arrays as dense.
     *
     * @private
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property names.
     */
    function baseKeysIn(object) {
        if (!isObject(object)) {
            return nativeKeysIn(object);
        }
        var isProto = isPrototype(object), result = [];
        for (var key in object) {
            if (!(key == 'constructor' && (isProto || !hasOwnProperty.call(object, key)))) {
                result.push(key);
            }
        }
        return result;
    }
    /**
     * The base implementation of `_.merge` without support for multiple sources.
     *
     * @private
     * @param {Object} object The destination object.
     * @param {Object} source The source object.
     * @param {number} srcIndex The index of `source`.
     * @param {Function} [customizer] The function to customize merged values.
     * @param {Object} [stack] Tracks traversed source values and their merged
     *  counterparts.
     */
    function baseMerge(object, source, srcIndex, customizer, stack) {
        if (object === source) {
            return;
        }
        baseFor(source, function (srcValue, key) {
            stack || (stack = new Stack);
            if (isObject(srcValue)) {
                baseMergeDeep(object, source, key, srcIndex, baseMerge, customizer, stack);
            }
            else {
                var newValue = customizer
                    ? customizer(safeGet(object, key), srcValue, (key + ''), object, source, stack)
                    : undefined;
                if (newValue === undefined) {
                    newValue = srcValue;
                }
                assignMergeValue(object, key, newValue);
            }
        }, keysIn);
    }
    /**
     * A specialized version of `baseMerge` for arrays and objects which performs
     * deep merges and tracks traversed objects enabling objects with circular
     * references to be merged.
     *
     * @private
     * @param {Object} object The destination object.
     * @param {Object} source The source object.
     * @param {string} key The key of the value to merge.
     * @param {number} srcIndex The index of `source`.
     * @param {Function} mergeFunc The function to merge values.
     * @param {Function} [customizer] The function to customize assigned values.
     * @param {Object} [stack] Tracks traversed source values and their merged
     *  counterparts.
     */
    function baseMergeDeep(object, source, key, srcIndex, mergeFunc, customizer, stack) {
        var objValue = safeGet(object, key), srcValue = safeGet(source, key), stacked = stack.get(srcValue);
        if (stacked) {
            assignMergeValue(object, key, stacked);
            return;
        }
        var newValue = customizer
            ? customizer(objValue, srcValue, (key + ''), object, source, stack)
            : undefined;
        var isCommon = newValue === undefined;
        if (isCommon) {
            var isArr = isArray(srcValue), isBuff = !isArr && isBuffer(srcValue), isTyped = !isArr && !isBuff && isTypedArray(srcValue);
            newValue = srcValue;
            if (isArr || isBuff || isTyped) {
                if (isArray(objValue)) {
                    newValue = objValue;
                }
                else if (isArrayLikeObject(objValue)) {
                    newValue = copyArray(objValue);
                }
                else if (isBuff) {
                    isCommon = false;
                    newValue = cloneBuffer(srcValue, true);
                }
                else if (isTyped) {
                    isCommon = false;
                    newValue = cloneTypedArray(srcValue, true);
                }
                else {
                    newValue = [];
                }
            }
            else if (isPlainObject(srcValue) || isArguments(srcValue)) {
                newValue = objValue;
                if (isArguments(objValue)) {
                    newValue = toPlainObject(objValue);
                }
                else if (!isObject(objValue) || isFunction(objValue)) {
                    newValue = initCloneObject(srcValue);
                }
            }
            else {
                isCommon = false;
            }
        }
        if (isCommon) {
            // Recursively merge objects and arrays (susceptible to call stack limits).
            stack.set(srcValue, newValue);
            mergeFunc(newValue, srcValue, srcIndex, customizer, stack);
            stack['delete'](srcValue);
        }
        assignMergeValue(object, key, newValue);
    }
    /**
     * The base implementation of `_.rest` which doesn't validate or coerce arguments.
     *
     * @private
     * @param {Function} func The function to apply a rest parameter to.
     * @param {number} [start=func.length-1] The start position of the rest parameter.
     * @returns {Function} Returns the new function.
     */
    function baseRest(func, start) {
        return setToString(overRest(func, start, identity), func + '');
    }
    /**
     * The base implementation of `setToString` without support for hot loop shorting.
     *
     * @private
     * @param {Function} func The function to modify.
     * @param {Function} string The `toString` result.
     * @returns {Function} Returns `func`.
     */
    var baseSetToString = !defineProperty ? identity : function (func, string) {
        return defineProperty(func, 'toString', {
            'configurable': true,
            'enumerable': false,
            'value': constant(string),
            'writable': true
        });
    };
    /**
     * Creates a clone of  `buffer`.
     *
     * @private
     * @param {Buffer} buffer The buffer to clone.
     * @param {boolean} [isDeep] Specify a deep clone.
     * @returns {Buffer} Returns the cloned buffer.
     */
    function cloneBuffer(buffer, isDeep) {
        if (isDeep) {
            return buffer.slice();
        }
        var length = buffer.length, result = allocUnsafe ? allocUnsafe(length) : new buffer.constructor(length);
        buffer.copy(result);
        return result;
    }
    /**
     * Creates a clone of `arrayBuffer`.
     *
     * @private
     * @param {ArrayBuffer} arrayBuffer The array buffer to clone.
     * @returns {ArrayBuffer} Returns the cloned array buffer.
     */
    function cloneArrayBuffer(arrayBuffer) {
        var result = new arrayBuffer.constructor(arrayBuffer.byteLength);
        new Uint8Array(result).set(new Uint8Array(arrayBuffer));
        return result;
    }
    /**
     * Creates a clone of `typedArray`.
     *
     * @private
     * @param {Object} typedArray The typed array to clone.
     * @param {boolean} [isDeep] Specify a deep clone.
     * @returns {Object} Returns the cloned typed array.
     */
    function cloneTypedArray(typedArray, isDeep) {
        var buffer = isDeep ? cloneArrayBuffer(typedArray.buffer) : typedArray.buffer;
        return new typedArray.constructor(buffer, typedArray.byteOffset, typedArray.length);
    }
    /**
     * Copies the values of `source` to `array`.
     *
     * @private
     * @param {Array} source The array to copy values from.
     * @param {Array} [array=[]] The array to copy values to.
     * @returns {Array} Returns `array`.
     */
    function copyArray(source, array) {
        var index = -1, length = source.length;
        array || (array = Array(length));
        while (++index < length) {
            array[index] = source[index];
        }
        return array;
    }
    /**
     * Copies properties of `source` to `object`.
     *
     * @private
     * @param {Object} source The object to copy properties from.
     * @param {Array} props The property identifiers to copy.
     * @param {Object} [object={}] The object to copy properties to.
     * @param {Function} [customizer] The function to customize copied values.
     * @returns {Object} Returns `object`.
     */
    function copyObject(source, props, object, customizer) {
        var isNew = !object;
        object || (object = {});
        var index = -1, length = props.length;
        while (++index < length) {
            var key = props[index];
            var newValue = customizer
                ? customizer(object[key], source[key], key, object, source)
                : undefined;
            if (newValue === undefined) {
                newValue = source[key];
            }
            if (isNew) {
                baseAssignValue(object, key, newValue);
            }
            else {
                assignValue(object, key, newValue);
            }
        }
        return object;
    }
    /**
     * Creates a function like `_.assign`.
     *
     * @private
     * @param {Function} assigner The function to assign values.
     * @returns {Function} Returns the new assigner function.
     */
    function createAssigner(assigner) {
        return baseRest(function (object, sources) {
            var index = -1, length = sources.length, customizer = length > 1 ? sources[length - 1] : undefined, guard = length > 2 ? sources[2] : undefined;
            customizer = (assigner.length > 3 && typeof customizer == 'function')
                ? (length--, customizer)
                : undefined;
            if (guard && isIterateeCall(sources[0], sources[1], guard)) {
                customizer = length < 3 ? undefined : customizer;
                length = 1;
            }
            object = Object(object);
            while (++index < length) {
                var source = sources[index];
                if (source) {
                    assigner(object, source, index, customizer);
                }
            }
            return object;
        });
    }
    /**
     * Creates a base function for methods like `_.forIn` and `_.forOwn`.
     *
     * @private
     * @param {boolean} [fromRight] Specify iterating from right to left.
     * @returns {Function} Returns the new base function.
     */
    function createBaseFor(fromRight) {
        return function (object, iteratee, keysFunc) {
            var index = -1, iterable = Object(object), props = keysFunc(object), length = props.length;
            while (length--) {
                var key = props[fromRight ? length : ++index];
                if (iteratee(iterable[key], key, iterable) === false) {
                    break;
                }
            }
            return object;
        };
    }
    /**
     * Gets the data for `map`.
     *
     * @private
     * @param {Object} map The map to query.
     * @param {string} key The reference key.
     * @returns {*} Returns the map data.
     */
    function getMapData(map, key) {
        var data = map.__data__;
        return isKeyable(key)
            ? data[typeof key == 'string' ? 'string' : 'hash']
            : data.map;
    }
    /**
     * Gets the native function at `key` of `object`.
     *
     * @private
     * @param {Object} object The object to query.
     * @param {string} key The key of the method to get.
     * @returns {*} Returns the function if it's native, else `undefined`.
     */
    function getNative(object, key) {
        var value = getValue(object, key);
        return baseIsNative(value) ? value : undefined;
    }
    /**
     * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
     *
     * @private
     * @param {*} value The value to query.
     * @returns {string} Returns the raw `toStringTag`.
     */
    function getRawTag(value) {
        var isOwn = hasOwnProperty.call(value, symToStringTag), tag = value[symToStringTag];
        try {
            value[symToStringTag] = undefined;
            var unmasked = true;
        }
        catch (e) { }
        var result = nativeObjectToString.call(value);
        if (unmasked) {
            if (isOwn) {
                value[symToStringTag] = tag;
            }
            else {
                delete value[symToStringTag];
            }
        }
        return result;
    }
    /**
     * Initializes an object clone.
     *
     * @private
     * @param {Object} object The object to clone.
     * @returns {Object} Returns the initialized clone.
     */
    function initCloneObject(object) {
        return (typeof object.constructor == 'function' && !isPrototype(object))
            ? baseCreate(getPrototype(object))
            : {};
    }
    /**
     * Checks if `value` is a valid array-like index.
     *
     * @private
     * @param {*} value The value to check.
     * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
     * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
     */
    function isIndex(value, length) {
        var type = typeof value;
        length = length == null ? MAX_SAFE_INTEGER : length;
        return !!length &&
            (type == 'number' ||
                (type != 'symbol' && reIsUint.test(value))) &&
            (value > -1 && value % 1 == 0 && value < length);
    }
    /**
     * Checks if the given arguments are from an iteratee call.
     *
     * @private
     * @param {*} value The potential iteratee value argument.
     * @param {*} index The potential iteratee index or key argument.
     * @param {*} object The potential iteratee object argument.
     * @returns {boolean} Returns `true` if the arguments are from an iteratee call,
     *  else `false`.
     */
    function isIterateeCall(value, index, object) {
        if (!isObject(object)) {
            return false;
        }
        var type = typeof index;
        if (type == 'number'
            ? (isArrayLike(object) && isIndex(index, object.length))
            : (type == 'string' && index in object)) {
            return eq(object[index], value);
        }
        return false;
    }
    /**
     * Checks if `value` is suitable for use as unique object key.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
     */
    function isKeyable(value) {
        var type = typeof value;
        return (type == 'string' || type == 'number' || type == 'symbol' || type == 'boolean')
            ? (value !== '__proto__')
            : (value === null);
    }
    /**
     * Checks if `func` has its source masked.
     *
     * @private
     * @param {Function} func The function to check.
     * @returns {boolean} Returns `true` if `func` is masked, else `false`.
     */
    function isMasked(func) {
        return !!maskSrcKey && (maskSrcKey in func);
    }
    /**
     * Checks if `value` is likely a prototype object.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
     */
    function isPrototype(value) {
        var Ctor = value && value.constructor, proto = (typeof Ctor == 'function' && Ctor.prototype) || objectProto;
        return value === proto;
    }
    /**
     * This function is like
     * [`Object.keys`](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
     * except that it includes inherited enumerable properties.
     *
     * @private
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property names.
     */
    function nativeKeysIn(object) {
        var result = [];
        if (object != null) {
            for (var key in Object(object)) {
                result.push(key);
            }
        }
        return result;
    }
    /**
     * Converts `value` to a string using `Object.prototype.toString`.
     *
     * @private
     * @param {*} value The value to convert.
     * @returns {string} Returns the converted string.
     */
    function objectToString(value) {
        return nativeObjectToString.call(value);
    }
    /**
     * A specialized version of `baseRest` which transforms the rest array.
     *
     * @private
     * @param {Function} func The function to apply a rest parameter to.
     * @param {number} [start=func.length-1] The start position of the rest parameter.
     * @param {Function} transform The rest array transform.
     * @returns {Function} Returns the new function.
     */
    function overRest(func, start, transform) {
        start = nativeMax(start === undefined ? (func.length - 1) : start, 0);
        return function () {
            var args = arguments, index = -1, length = nativeMax(args.length - start, 0), array = Array(length);
            while (++index < length) {
                array[index] = args[start + index];
            }
            index = -1;
            var otherArgs = Array(start + 1);
            while (++index < start) {
                otherArgs[index] = args[index];
            }
            otherArgs[start] = transform(array);
            return apply(func, this, otherArgs);
        };
    }
    /**
     * Gets the value at `key`, unless `key` is "__proto__" or "constructor".
     *
     * @private
     * @param {Object} object The object to query.
     * @param {string} key The key of the property to get.
     * @returns {*} Returns the property value.
     */
    function safeGet(object, key) {
        if (key === 'constructor' && typeof object[key] === 'function') {
            return;
        }
        if (key == '__proto__') {
            return;
        }
        return object[key];
    }
    /**
     * Sets the `toString` method of `func` to return `string`.
     *
     * @private
     * @param {Function} func The function to modify.
     * @param {Function} string The `toString` result.
     * @returns {Function} Returns `func`.
     */
    var setToString = shortOut(baseSetToString);
    /**
     * Creates a function that'll short out and invoke `identity` instead
     * of `func` when it's called `HOT_COUNT` or more times in `HOT_SPAN`
     * milliseconds.
     *
     * @private
     * @param {Function} func The function to restrict.
     * @returns {Function} Returns the new shortable function.
     */
    function shortOut(func) {
        var count = 0, lastCalled = 0;
        return function () {
            var stamp = nativeNow(), remaining = HOT_SPAN - (stamp - lastCalled);
            lastCalled = stamp;
            if (remaining > 0) {
                if (++count >= HOT_COUNT) {
                    return arguments[0];
                }
            }
            else {
                count = 0;
            }
            return func.apply(undefined, arguments);
        };
    }
    /**
     * Converts `func` to its source code.
     *
     * @private
     * @param {Function} func The function to convert.
     * @returns {string} Returns the source code.
     */
    function toSource(func) {
        if (func != null) {
            try {
                return funcToString.call(func);
            }
            catch (e) { }
            try {
                return (func + '');
            }
            catch (e) { }
        }
        return '';
    }
    /**
     * Performs a
     * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
     * comparison between two values to determine if they are equivalent.
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
     * @example
     *
     * var object = { 'a': 1 };
     * var other = { 'a': 1 };
     *
     * _.eq(object, object);
     * // => true
     *
     * _.eq(object, other);
     * // => false
     *
     * _.eq('a', 'a');
     * // => true
     *
     * _.eq('a', Object('a'));
     * // => false
     *
     * _.eq(NaN, NaN);
     * // => true
     */
    function eq(value, other) {
        return value === other || (value !== value && other !== other);
    }
    /**
     * Checks if `value` is likely an `arguments` object.
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an `arguments` object,
     *  else `false`.
     * @example
     *
     * _.isArguments(function() { return arguments; }());
     * // => true
     *
     * _.isArguments([1, 2, 3]);
     * // => false
     */
    var isArguments = baseIsArguments(function () { return arguments; }()) ? baseIsArguments : function (value) {
        return isObjectLike(value) && hasOwnProperty.call(value, 'callee') &&
            !propertyIsEnumerable.call(value, 'callee');
    };
    /**
     * Checks if `value` is classified as an `Array` object.
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an array, else `false`.
     * @example
     *
     * _.isArray([1, 2, 3]);
     * // => true
     *
     * _.isArray(document.body.children);
     * // => false
     *
     * _.isArray('abc');
     * // => false
     *
     * _.isArray(_.noop);
     * // => false
     */
    var isArray = Array.isArray;
    /**
     * Checks if `value` is array-like. A value is considered array-like if it's
     * not a function and has a `value.length` that's an integer greater than or
     * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
     * @example
     *
     * _.isArrayLike([1, 2, 3]);
     * // => true
     *
     * _.isArrayLike(document.body.children);
     * // => true
     *
     * _.isArrayLike('abc');
     * // => true
     *
     * _.isArrayLike(_.noop);
     * // => false
     */
    function isArrayLike(value) {
        return value != null && isLength(value.length) && !isFunction(value);
    }
    /**
     * This method is like `_.isArrayLike` except that it also checks if `value`
     * is an object.
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an array-like object,
     *  else `false`.
     * @example
     *
     * _.isArrayLikeObject([1, 2, 3]);
     * // => true
     *
     * _.isArrayLikeObject(document.body.children);
     * // => true
     *
     * _.isArrayLikeObject('abc');
     * // => false
     *
     * _.isArrayLikeObject(_.noop);
     * // => false
     */
    function isArrayLikeObject(value) {
        return isObjectLike(value) && isArrayLike(value);
    }
    /**
     * Checks if `value` is a buffer.
     *
     * @static
     * @memberOf _
     * @since 4.3.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
     * @example
     *
     * _.isBuffer(new Buffer(2));
     * // => true
     *
     * _.isBuffer(new Uint8Array(2));
     * // => false
     */
    var isBuffer = nativeIsBuffer || stubFalse;
    /**
     * Checks if `value` is classified as a `Function` object.
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a function, else `false`.
     * @example
     *
     * _.isFunction(_);
     * // => true
     *
     * _.isFunction(/abc/);
     * // => false
     */
    function isFunction(value) {
        if (!isObject(value)) {
            return false;
        }
        // The use of `Object#toString` avoids issues with the `typeof` operator
        // in Safari 9 which returns 'object' for typed arrays and other constructors.
        var tag = baseGetTag(value);
        return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
    }
    /**
     * Checks if `value` is a valid array-like length.
     *
     * **Note:** This method is loosely based on
     * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
     * @example
     *
     * _.isLength(3);
     * // => true
     *
     * _.isLength(Number.MIN_VALUE);
     * // => false
     *
     * _.isLength(Infinity);
     * // => false
     *
     * _.isLength('3');
     * // => false
     */
    function isLength(value) {
        return typeof value == 'number' &&
            value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
    }
    /**
     * Checks if `value` is the
     * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
     * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an object, else `false`.
     * @example
     *
     * _.isObject({});
     * // => true
     *
     * _.isObject([1, 2, 3]);
     * // => true
     *
     * _.isObject(_.noop);
     * // => true
     *
     * _.isObject(null);
     * // => false
     */
    function isObject(value) {
        var type = typeof value;
        return value != null && (type == 'object' || type == 'function');
    }
    /**
     * Checks if `value` is object-like. A value is object-like if it's not `null`
     * and has a `typeof` result of "object".
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
     * @example
     *
     * _.isObjectLike({});
     * // => true
     *
     * _.isObjectLike([1, 2, 3]);
     * // => true
     *
     * _.isObjectLike(_.noop);
     * // => false
     *
     * _.isObjectLike(null);
     * // => false
     */
    function isObjectLike(value) {
        return value != null && typeof value == 'object';
    }
    /**
     * Checks if `value` is a plain object, that is, an object created by the
     * `Object` constructor or one with a `[[Prototype]]` of `null`.
     *
     * @static
     * @memberOf _
     * @since 0.8.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a plain object, else `false`.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     * }
     *
     * _.isPlainObject(new Foo);
     * // => false
     *
     * _.isPlainObject([1, 2, 3]);
     * // => false
     *
     * _.isPlainObject({ 'x': 0, 'y': 0 });
     * // => true
     *
     * _.isPlainObject(Object.create(null));
     * // => true
     */
    function isPlainObject(value) {
        if (!isObjectLike(value) || baseGetTag(value) != objectTag) {
            return false;
        }
        var proto = getPrototype(value);
        if (proto === null) {
            return true;
        }
        var Ctor = hasOwnProperty.call(proto, 'constructor') && proto.constructor;
        return typeof Ctor == 'function' && Ctor instanceof Ctor &&
            funcToString.call(Ctor) == objectCtorString;
    }
    /**
     * Checks if `value` is classified as a typed array.
     *
     * @static
     * @memberOf _
     * @since 3.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
     * @example
     *
     * _.isTypedArray(new Uint8Array);
     * // => true
     *
     * _.isTypedArray([]);
     * // => false
     */
    var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;
    /**
     * Converts `value` to a plain object flattening inherited enumerable string
     * keyed properties of `value` to own properties of the plain object.
     *
     * @static
     * @memberOf _
     * @since 3.0.0
     * @category Lang
     * @param {*} value The value to convert.
     * @returns {Object} Returns the converted plain object.
     * @example
     *
     * function Foo() {
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.assign({ 'a': 1 }, new Foo);
     * // => { 'a': 1, 'b': 2 }
     *
     * _.assign({ 'a': 1 }, _.toPlainObject(new Foo));
     * // => { 'a': 1, 'b': 2, 'c': 3 }
     */
    function toPlainObject(value) {
        return copyObject(value, keysIn(value));
    }
    /**
     * Creates an array of the own and inherited enumerable property names of `object`.
     *
     * **Note:** Non-object values are coerced to objects.
     *
     * @static
     * @memberOf _
     * @since 3.0.0
     * @category Object
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property names.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.keysIn(new Foo);
     * // => ['a', 'b', 'c'] (iteration order is not guaranteed)
     */
    function keysIn(object) {
        return isArrayLike(object) ? arrayLikeKeys(object, true) : baseKeysIn(object);
    }
    /**
     * This method is like `_.assign` except that it recursively merges own and
     * inherited enumerable string keyed properties of source objects into the
     * destination object. Source properties that resolve to `undefined` are
     * skipped if a destination value exists. Array and plain object properties
     * are merged recursively. Other objects and value types are overridden by
     * assignment. Source objects are applied from left to right. Subsequent
     * sources overwrite property assignments of previous sources.
     *
     * **Note:** This method mutates `object`.
     *
     * @static
     * @memberOf _
     * @since 0.5.0
     * @category Object
     * @param {Object} object The destination object.
     * @param {...Object} [sources] The source objects.
     * @returns {Object} Returns `object`.
     * @example
     *
     * var object = {
     *   'a': [{ 'b': 2 }, { 'd': 4 }]
     * };
     *
     * var other = {
     *   'a': [{ 'c': 3 }, { 'e': 5 }]
     * };
     *
     * _.merge(object, other);
     * // => { 'a': [{ 'b': 2, 'c': 3 }, { 'd': 4, 'e': 5 }] }
     */
    var merge = createAssigner(function (object, source, srcIndex) {
        baseMerge(object, source, srcIndex);
    });
    /**
     * Creates a function that returns `value`.
     *
     * @static
     * @memberOf _
     * @since 2.4.0
     * @category Util
     * @param {*} value The value to return from the new function.
     * @returns {Function} Returns the new constant function.
     * @example
     *
     * var objects = _.times(2, _.constant({ 'a': 1 }));
     *
     * console.log(objects);
     * // => [{ 'a': 1 }, { 'a': 1 }]
     *
     * console.log(objects[0] === objects[1]);
     * // => true
     */
    function constant(value) {
        return function () {
            return value;
        };
    }
    /**
     * This method returns the first argument it receives.
     *
     * @static
     * @since 0.1.0
     * @memberOf _
     * @category Util
     * @param {*} value Any value.
     * @returns {*} Returns `value`.
     * @example
     *
     * var object = { 'a': 1 };
     *
     * console.log(_.identity(object) === object);
     * // => true
     */
    function identity(value) {
        return value;
    }
    /**
     * This method returns `false`.
     *
     * @static
     * @memberOf _
     * @since 4.13.0
     * @category Util
     * @returns {boolean} Returns `false`.
     * @example
     *
     * _.times(2, _.stubFalse);
     * // => [false, false]
     */
    function stubFalse() {
        return false;
    }
    module.exports = merge;
},
/* eslint/lib/shared/ast-utils.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Common utils for AST.
     *
     * This file contains only shared items for core and rules.
     * If you make a utility for rules, please see `../rules/utils/ast-utils.js`.
     *
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    const breakableTypePattern = /^(?:(?:Do)?While|For(?:In|Of)?|Switch)Statement$/u;
    const lineBreakPattern = /\r\n|[\r\n\u2028\u2029]/u;
    const shebangPattern = /^#!([^\r\n]+)/u;
    /**
     * Creates a version of the `lineBreakPattern` regex with the global flag.
     * Global regexes are mutable, so this needs to be a function instead of a constant.
     * @returns {RegExp} A global regular expression that matches line terminators
     */
    function createGlobalLinebreakMatcher() {
        return new RegExp(lineBreakPattern.source, "gu");
    }
    module.exports = {
        breakableTypePattern,
        lineBreakPattern,
        createGlobalLinebreakMatcher,
        shebangPattern
    };
},
/* eslint/lib/shared/directives.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Common utils for directives.
     *
     * This file contains only shared items for directives.
     * If you make a utility for rules, please see `../rules/utils/ast-utils.js`.
     *
     * @author gfyoung <https://github.com/gfyoung>
     */
    "use strict";
    const directivesPattern = /^(eslint(?:-env|-enable|-disable(?:(?:-next)?-line)?)?|exported|globals?)(?:\s|$)/u;
    module.exports = {
        directivesPattern
    };
},
/* @eslint/eslintrc/universal.js */ function _(require, module, exports, __esModule, __esExport) {// Jest (and probably some other runtimes with custom implementations of
    // `require`) doesn't support `exports` in `package.json`, so this file is here
    // to help them load this module. Note that it is also `.js` and not `.cjs` for
    // the same reason - `cjs` files requires to be loaded with an extension, but
    // since Jest doesn't respect `module` outside of ESM mode it still works in
    // this case (and the `require` in _this_ file does specify the extension).
    // eslint-disable-next-line no-undef
    module.exports = require(312) /* ./dist/eslintrc-universal.cjs */;
},
/* @eslint/eslintrc/dist/eslintrc-universal.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    var util = require('util');
    var path = require('path');
    var Ajv = require(233) /* ajv */;
    var globals = require(279) /* globals */;
    function _interopDefaultLegacy(e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }
    var util__default = /*#__PURE__*/ _interopDefaultLegacy(util);
    var path__default = /*#__PURE__*/ _interopDefaultLegacy(path);
    var Ajv__default = /*#__PURE__*/ _interopDefaultLegacy(Ajv);
    var globals__default = /*#__PURE__*/ _interopDefaultLegacy(globals);
    /**
     * @fileoverview Config file operations. This file must be usable in the browser,
     * so no Node-specific code can be here.
     * @author Nicholas C. Zakas
     */
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    const RULE_SEVERITY_STRINGS = ["off", "warn", "error"], RULE_SEVERITY = RULE_SEVERITY_STRINGS.reduce((map, value, index) => {
        map[value] = index;
        return map;
    }, {}), VALID_SEVERITIES = [0, 1, 2, "off", "warn", "error"];
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * Normalizes the severity value of a rule's configuration to a number
     * @param {(number|string|[number, ...*]|[string, ...*])} ruleConfig A rule's configuration value, generally
     * received from the user. A valid config value is either 0, 1, 2, the string "off" (treated the same as 0),
     * the string "warn" (treated the same as 1), the string "error" (treated the same as 2), or an array
     * whose first element is one of the above values. Strings are matched case-insensitively.
     * @returns {(0|1|2)} The numeric severity value if the config value was valid, otherwise 0.
     */
    function getRuleSeverity(ruleConfig) {
        const severityValue = Array.isArray(ruleConfig) ? ruleConfig[0] : ruleConfig;
        if (severityValue === 0 || severityValue === 1 || severityValue === 2) {
            return severityValue;
        }
        if (typeof severityValue === "string") {
            return RULE_SEVERITY[severityValue.toLowerCase()] || 0;
        }
        return 0;
    }
    /**
     * Converts old-style severity settings (0, 1, 2) into new-style
     * severity settings (off, warn, error) for all rules. Assumption is that severity
     * values have already been validated as correct.
     * @param {Object} config The config object to normalize.
     * @returns {void}
     */
    function normalizeToStrings(config) {
        if (config.rules) {
            Object.keys(config.rules).forEach(ruleId => {
                const ruleConfig = config.rules[ruleId];
                if (typeof ruleConfig === "number") {
                    config.rules[ruleId] = RULE_SEVERITY_STRINGS[ruleConfig] || RULE_SEVERITY_STRINGS[0];
                }
                else if (Array.isArray(ruleConfig) && typeof ruleConfig[0] === "number") {
                    ruleConfig[0] = RULE_SEVERITY_STRINGS[ruleConfig[0]] || RULE_SEVERITY_STRINGS[0];
                }
            });
        }
    }
    /**
     * Determines if the severity for the given rule configuration represents an error.
     * @param {int|string|Array} ruleConfig The configuration for an individual rule.
     * @returns {boolean} True if the rule represents an error, false if not.
     */
    function isErrorSeverity(ruleConfig) {
        return getRuleSeverity(ruleConfig) === 2;
    }
    /**
     * Checks whether a given config has valid severity or not.
     * @param {number|string|Array} ruleConfig The configuration for an individual rule.
     * @returns {boolean} `true` if the configuration has valid severity.
     */
    function isValidSeverity(ruleConfig) {
        let severity = Array.isArray(ruleConfig) ? ruleConfig[0] : ruleConfig;
        if (typeof severity === "string") {
            severity = severity.toLowerCase();
        }
        return VALID_SEVERITIES.indexOf(severity) !== -1;
    }
    /**
     * Checks whether every rule of a given config has valid severity or not.
     * @param {Object} config The configuration for rules.
     * @returns {boolean} `true` if the configuration has valid severity.
     */
    function isEverySeverityValid(config) {
        return Object.keys(config).every(ruleId => isValidSeverity(config[ruleId]));
    }
    /**
     * Normalizes a value for a global in a config
     * @param {(boolean|string|null)} configuredValue The value given for a global in configuration or in
     * a global directive comment
     * @returns {("readable"|"writeable"|"off")} The value normalized as a string
     * @throws Error if global value is invalid
     */
    function normalizeConfigGlobal(configuredValue) {
        switch (configuredValue) {
            case "off":
                return "off";
            case true:
            case "true":
            case "writeable":
            case "writable":
                return "writable";
            case null:
            case false:
            case "false":
            case "readable":
            case "readonly":
                return "readonly";
            default:
                throw new Error(`'${configuredValue}' is not a valid configuration for a global (use 'readonly', 'writable', or 'off')`);
        }
    }
    var ConfigOps = {
        __proto__: null,
        getRuleSeverity: getRuleSeverity,
        normalizeToStrings: normalizeToStrings,
        isErrorSeverity: isErrorSeverity,
        isValidSeverity: isValidSeverity,
        isEverySeverityValid: isEverySeverityValid,
        normalizeConfigGlobal: normalizeConfigGlobal
    };
    /**
     * @fileoverview Provide the function that emits deprecation warnings.
     * @author Toru Nagashima <http://github.com/mysticatea>
     */
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    // Defitions for deprecation warnings.
    const deprecationWarningMessages = {
        ESLINT_LEGACY_ECMAFEATURES: "The 'ecmaFeatures' config file property is deprecated and has no effect.",
        ESLINT_PERSONAL_CONFIG_LOAD: "'~/.eslintrc.*' config files have been deprecated. " +
            "Please use a config file per project or the '--config' option.",
        ESLINT_PERSONAL_CONFIG_SUPPRESS: "'~/.eslintrc.*' config files have been deprecated. " +
            "Please remove it or add 'root:true' to the config files in your " +
            "projects in order to avoid loading '~/.eslintrc.*' accidentally."
    };
    const sourceFileErrorCache = new Set();
    /**
     * Emits a deprecation warning containing a given filepath. A new deprecation warning is emitted
     * for each unique file path, but repeated invocations with the same file path have no effect.
     * No warnings are emitted if the `--no-deprecation` or `--no-warnings` Node runtime flags are active.
     * @param {string} source The name of the configuration source to report the warning for.
     * @param {string} errorCode The warning message to show.
     * @returns {void}
     */
    function emitDeprecationWarning(source, errorCode) {
        const cacheKey = JSON.stringify({ source, errorCode });
        if (sourceFileErrorCache.has(cacheKey)) {
            return;
        }
        sourceFileErrorCache.add(cacheKey);
        const rel = path__default["default"].relative(process.cwd(), source);
        const message = deprecationWarningMessages[errorCode];
        process.emitWarning(`${message} (found in "${rel}")`, "DeprecationWarning", errorCode);
    }
    /**
     * @fileoverview The instance of Ajv validator.
     * @author Evgeny Poberezkin
     */
    //-----------------------------------------------------------------------------
    // Helpers
    //-----------------------------------------------------------------------------
    /*
     * Copied from ajv/lib/refs/json-schema-draft-04.json
     * The MIT License (MIT)
     * Copyright (c) 2015-2017 Evgeny Poberezkin
     */
    const metaSchema = {
        id: "http://json-schema.org/draft-04/schema#",
        $schema: "http://json-schema.org/draft-04/schema#",
        description: "Core schema meta-schema",
        definitions: {
            schemaArray: {
                type: "array",
                minItems: 1,
                items: { $ref: "#" }
            },
            positiveInteger: {
                type: "integer",
                minimum: 0
            },
            positiveIntegerDefault0: {
                allOf: [{ $ref: "#/definitions/positiveInteger" }, { default: 0 }]
            },
            simpleTypes: {
                enum: ["array", "boolean", "integer", "null", "number", "object", "string"]
            },
            stringArray: {
                type: "array",
                items: { type: "string" },
                minItems: 1,
                uniqueItems: true
            }
        },
        type: "object",
        properties: {
            id: {
                type: "string"
            },
            $schema: {
                type: "string"
            },
            title: {
                type: "string"
            },
            description: {
                type: "string"
            },
            default: {},
            multipleOf: {
                type: "number",
                minimum: 0,
                exclusiveMinimum: true
            },
            maximum: {
                type: "number"
            },
            exclusiveMaximum: {
                type: "boolean",
                default: false
            },
            minimum: {
                type: "number"
            },
            exclusiveMinimum: {
                type: "boolean",
                default: false
            },
            maxLength: { $ref: "#/definitions/positiveInteger" },
            minLength: { $ref: "#/definitions/positiveIntegerDefault0" },
            pattern: {
                type: "string",
                format: "regex"
            },
            additionalItems: {
                anyOf: [
                    { type: "boolean" },
                    { $ref: "#" }
                ],
                default: {}
            },
            items: {
                anyOf: [
                    { $ref: "#" },
                    { $ref: "#/definitions/schemaArray" }
                ],
                default: {}
            },
            maxItems: { $ref: "#/definitions/positiveInteger" },
            minItems: { $ref: "#/definitions/positiveIntegerDefault0" },
            uniqueItems: {
                type: "boolean",
                default: false
            },
            maxProperties: { $ref: "#/definitions/positiveInteger" },
            minProperties: { $ref: "#/definitions/positiveIntegerDefault0" },
            required: { $ref: "#/definitions/stringArray" },
            additionalProperties: {
                anyOf: [
                    { type: "boolean" },
                    { $ref: "#" }
                ],
                default: {}
            },
            definitions: {
                type: "object",
                additionalProperties: { $ref: "#" },
                default: {}
            },
            properties: {
                type: "object",
                additionalProperties: { $ref: "#" },
                default: {}
            },
            patternProperties: {
                type: "object",
                additionalProperties: { $ref: "#" },
                default: {}
            },
            dependencies: {
                type: "object",
                additionalProperties: {
                    anyOf: [
                        { $ref: "#" },
                        { $ref: "#/definitions/stringArray" }
                    ]
                }
            },
            enum: {
                type: "array",
                minItems: 1,
                uniqueItems: true
            },
            type: {
                anyOf: [
                    { $ref: "#/definitions/simpleTypes" },
                    {
                        type: "array",
                        items: { $ref: "#/definitions/simpleTypes" },
                        minItems: 1,
                        uniqueItems: true
                    }
                ]
            },
            format: { type: "string" },
            allOf: { $ref: "#/definitions/schemaArray" },
            anyOf: { $ref: "#/definitions/schemaArray" },
            oneOf: { $ref: "#/definitions/schemaArray" },
            not: { $ref: "#" }
        },
        dependencies: {
            exclusiveMaximum: ["maximum"],
            exclusiveMinimum: ["minimum"]
        },
        default: {}
    };
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    var ajvOrig = (additionalOptions = {}) => {
        const ajv = new Ajv__default["default"]({
            meta: false,
            useDefaults: true,
            validateSchema: false,
            missingRefs: "ignore",
            verbose: true,
            schemaId: "auto",
            ...additionalOptions
        });
        ajv.addMetaSchema(metaSchema);
        // eslint-disable-next-line no-underscore-dangle
        ajv._opts.defaultMeta = metaSchema.id;
        return ajv;
    };
    /**
     * @fileoverview Defines a schema for configs.
     * @author Sylvan Mably
     */
    const baseConfigProperties = {
        $schema: { type: "string" },
        env: { type: "object" },
        extends: { $ref: "#/definitions/stringOrStrings" },
        globals: { type: "object" },
        overrides: {
            type: "array",
            items: { $ref: "#/definitions/overrideConfig" },
            additionalItems: false
        },
        parser: { type: ["string", "null"] },
        parserOptions: { type: "object" },
        plugins: { type: "array" },
        processor: { type: "string" },
        rules: { type: "object" },
        settings: { type: "object" },
        noInlineConfig: { type: "boolean" },
        reportUnusedDisableDirectives: { type: "boolean" },
        ecmaFeatures: { type: "object" } // deprecated; logs a warning when used
    };
    const configSchema = {
        definitions: {
            stringOrStrings: {
                oneOf: [
                    { type: "string" },
                    {
                        type: "array",
                        items: { type: "string" },
                        additionalItems: false
                    }
                ]
            },
            stringOrStringsRequired: {
                oneOf: [
                    { type: "string" },
                    {
                        type: "array",
                        items: { type: "string" },
                        additionalItems: false,
                        minItems: 1
                    }
                ]
            },
            // Config at top-level.
            objectConfig: {
                type: "object",
                properties: {
                    root: { type: "boolean" },
                    ignorePatterns: { $ref: "#/definitions/stringOrStrings" },
                    ...baseConfigProperties
                },
                additionalProperties: false
            },
            // Config in `overrides`.
            overrideConfig: {
                type: "object",
                properties: {
                    excludedFiles: { $ref: "#/definitions/stringOrStrings" },
                    files: { $ref: "#/definitions/stringOrStringsRequired" },
                    ...baseConfigProperties
                },
                required: ["files"],
                additionalProperties: false
            }
        },
        $ref: "#/definitions/objectConfig"
    };
    /**
     * @fileoverview Defines environment settings and globals.
     * @author Elan Shanker
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Get the object that has difference.
     * @param {Record<string,boolean>} current The newer object.
     * @param {Record<string,boolean>} prev The older object.
     * @returns {Record<string,boolean>} The difference object.
     */
    function getDiff(current, prev) {
        const retv = {};
        for (const [key, value] of Object.entries(current)) {
            if (!Object.hasOwnProperty.call(prev, key)) {
                retv[key] = value;
            }
        }
        return retv;
    }
    const newGlobals2015 = getDiff(globals__default["default"].es2015, globals__default["default"].es5); // 19 variables such as Promise, Map, ...
    const newGlobals2017 = {
        Atomics: false,
        SharedArrayBuffer: false
    };
    const newGlobals2020 = {
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        globalThis: false
    };
    const newGlobals2021 = {
        AggregateError: false,
        FinalizationRegistry: false,
        WeakRef: false
    };
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /** @type {Map<string, import("../lib/shared/types").Environment>} */
    var environments = new Map(Object.entries({
        // Language
        builtin: {
            globals: globals__default["default"].es5
        },
        es6: {
            globals: newGlobals2015,
            parserOptions: {
                ecmaVersion: 6
            }
        },
        es2015: {
            globals: newGlobals2015,
            parserOptions: {
                ecmaVersion: 6
            }
        },
        es2016: {
            globals: newGlobals2015,
            parserOptions: {
                ecmaVersion: 7
            }
        },
        es2017: {
            globals: { ...newGlobals2015, ...newGlobals2017 },
            parserOptions: {
                ecmaVersion: 8
            }
        },
        es2018: {
            globals: { ...newGlobals2015, ...newGlobals2017 },
            parserOptions: {
                ecmaVersion: 9
            }
        },
        es2019: {
            globals: { ...newGlobals2015, ...newGlobals2017 },
            parserOptions: {
                ecmaVersion: 10
            }
        },
        es2020: {
            globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020 },
            parserOptions: {
                ecmaVersion: 11
            }
        },
        es2021: {
            globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020, ...newGlobals2021 },
            parserOptions: {
                ecmaVersion: 12
            }
        },
        es2022: {
            globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020, ...newGlobals2021 },
            parserOptions: {
                ecmaVersion: 13
            }
        },
        // Platforms
        browser: {
            globals: globals__default["default"].browser
        },
        node: {
            globals: globals__default["default"].node,
            parserOptions: {
                ecmaFeatures: {
                    globalReturn: true
                }
            }
        },
        "shared-node-browser": {
            globals: globals__default["default"]["shared-node-browser"]
        },
        worker: {
            globals: globals__default["default"].worker
        },
        serviceworker: {
            globals: globals__default["default"].serviceworker
        },
        // Frameworks
        commonjs: {
            globals: globals__default["default"].commonjs,
            parserOptions: {
                ecmaFeatures: {
                    globalReturn: true
                }
            }
        },
        amd: {
            globals: globals__default["default"].amd
        },
        mocha: {
            globals: globals__default["default"].mocha
        },
        jasmine: {
            globals: globals__default["default"].jasmine
        },
        jest: {
            globals: globals__default["default"].jest
        },
        phantomjs: {
            globals: globals__default["default"].phantomjs
        },
        jquery: {
            globals: globals__default["default"].jquery
        },
        qunit: {
            globals: globals__default["default"].qunit
        },
        prototypejs: {
            globals: globals__default["default"].prototypejs
        },
        shelljs: {
            globals: globals__default["default"].shelljs
        },
        meteor: {
            globals: globals__default["default"].meteor
        },
        mongo: {
            globals: globals__default["default"].mongo
        },
        protractor: {
            globals: globals__default["default"].protractor
        },
        applescript: {
            globals: globals__default["default"].applescript
        },
        nashorn: {
            globals: globals__default["default"].nashorn
        },
        atomtest: {
            globals: globals__default["default"].atomtest
        },
        embertest: {
            globals: globals__default["default"].embertest
        },
        webextensions: {
            globals: globals__default["default"].webextensions
        },
        greasemonkey: {
            globals: globals__default["default"].greasemonkey
        }
    }));
    /**
     * @fileoverview Validates configs.
     * @author Brandon Mills
     */
    const ajv = ajvOrig();
    const ruleValidators = new WeakMap();
    const noop = Function.prototype;
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    let validateSchema;
    const severityMap = {
        error: 2,
        warn: 1,
        off: 0
    };
    const validated = new WeakSet();
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    class ConfigValidator {
        constructor({ builtInRules = new Map() } = {}) {
            this.builtInRules = builtInRules;
        }
        /**
         * Gets a complete options schema for a rule.
         * @param {{create: Function, schema: (Array|null)}} rule A new-style rule object
         * @returns {Object} JSON Schema for the rule's options.
         */
        getRuleOptionsSchema(rule) {
            if (!rule) {
                return null;
            }
            const schema = rule.schema || rule.meta && rule.meta.schema;
            // Given a tuple of schemas, insert warning level at the beginning
            if (Array.isArray(schema)) {
                if (schema.length) {
                    return {
                        type: "array",
                        items: schema,
                        minItems: 0,
                        maxItems: schema.length
                    };
                }
                return {
                    type: "array",
                    minItems: 0,
                    maxItems: 0
                };
            }
            // Given a full schema, leave it alone
            return schema || null;
        }
        /**
         * Validates a rule's severity and returns the severity value. Throws an error if the severity is invalid.
         * @param {options} options The given options for the rule.
         * @returns {number|string} The rule's severity value
         */
        validateRuleSeverity(options) {
            const severity = Array.isArray(options) ? options[0] : options;
            const normSeverity = typeof severity === "string" ? severityMap[severity.toLowerCase()] : severity;
            if (normSeverity === 0 || normSeverity === 1 || normSeverity === 2) {
                return normSeverity;
            }
            throw new Error(`\tSeverity should be one of the following: 0 = off, 1 = warn, 2 = error (you passed '${util__default["default"].inspect(severity).replace(/'/gu, "\"").replace(/\n/gu, "")}').\n`);
        }
        /**
         * Validates the non-severity options passed to a rule, based on its schema.
         * @param {{create: Function}} rule The rule to validate
         * @param {Array} localOptions The options for the rule, excluding severity
         * @returns {void}
         */
        validateRuleSchema(rule, localOptions) {
            if (!ruleValidators.has(rule)) {
                const schema = this.getRuleOptionsSchema(rule);
                if (schema) {
                    ruleValidators.set(rule, ajv.compile(schema));
                }
            }
            const validateRule = ruleValidators.get(rule);
            if (validateRule) {
                validateRule(localOptions);
                if (validateRule.errors) {
                    throw new Error(validateRule.errors.map(error => `\tValue ${JSON.stringify(error.data)} ${error.message}.\n`).join(""));
                }
            }
        }
        /**
         * Validates a rule's options against its schema.
         * @param {{create: Function}|null} rule The rule that the config is being validated for
         * @param {string} ruleId The rule's unique name.
         * @param {Array|number} options The given options for the rule.
         * @param {string|null} source The name of the configuration source to report in any errors. If null or undefined,
         * no source is prepended to the message.
         * @returns {void}
         */
        validateRuleOptions(rule, ruleId, options, source = null) {
            try {
                const severity = this.validateRuleSeverity(options);
                if (severity !== 0) {
                    this.validateRuleSchema(rule, Array.isArray(options) ? options.slice(1) : []);
                }
            }
            catch (err) {
                const enhancedMessage = `Configuration for rule "${ruleId}" is invalid:\n${err.message}`;
                if (typeof source === "string") {
                    throw new Error(`${source}:\n\t${enhancedMessage}`);
                }
                else {
                    throw new Error(enhancedMessage);
                }
            }
        }
        /**
         * Validates an environment object
         * @param {Object} environment The environment config object to validate.
         * @param {string} source The name of the configuration source to report in any errors.
         * @param {function(envId:string): Object} [getAdditionalEnv] A map from strings to loaded environments.
         * @returns {void}
         */
        validateEnvironment(environment, source, getAdditionalEnv = noop) {
            // not having an environment is ok
            if (!environment) {
                return;
            }
            Object.keys(environment).forEach(id => {
                const env = getAdditionalEnv(id) || environments.get(id) || null;
                if (!env) {
                    const message = `${source}:\n\tEnvironment key "${id}" is unknown\n`;
                    throw new Error(message);
                }
            });
        }
        /**
         * Validates a rules config object
         * @param {Object} rulesConfig The rules config object to validate.
         * @param {string} source The name of the configuration source to report in any errors.
         * @param {function(ruleId:string): Object} getAdditionalRule A map from strings to loaded rules
         * @returns {void}
         */
        validateRules(rulesConfig, source, getAdditionalRule = noop) {
            if (!rulesConfig) {
                return;
            }
            Object.keys(rulesConfig).forEach(id => {
                const rule = getAdditionalRule(id) || this.builtInRules.get(id) || null;
                this.validateRuleOptions(rule, id, rulesConfig[id], source);
            });
        }
        /**
         * Validates a `globals` section of a config file
         * @param {Object} globalsConfig The `globals` section
         * @param {string|null} source The name of the configuration source to report in the event of an error.
         * @returns {void}
         */
        validateGlobals(globalsConfig, source = null) {
            if (!globalsConfig) {
                return;
            }
            Object.entries(globalsConfig)
                .forEach(([configuredGlobal, configuredValue]) => {
                try {
                    normalizeConfigGlobal(configuredValue);
                }
                catch (err) {
                    throw new Error(`ESLint configuration of global '${configuredGlobal}' in ${source} is invalid:\n${err.message}`);
                }
            });
        }
        /**
         * Validate `processor` configuration.
         * @param {string|undefined} processorName The processor name.
         * @param {string} source The name of config file.
         * @param {function(id:string): Processor} getProcessor The getter of defined processors.
         * @returns {void}
         */
        validateProcessor(processorName, source, getProcessor) {
            if (processorName && !getProcessor(processorName)) {
                throw new Error(`ESLint configuration of processor in '${source}' is invalid: '${processorName}' was not found.`);
            }
        }
        /**
         * Formats an array of schema validation errors.
         * @param {Array} errors An array of error messages to format.
         * @returns {string} Formatted error message
         */
        formatErrors(errors) {
            return errors.map(error => {
                if (error.keyword === "additionalProperties") {
                    const formattedPropertyPath = error.dataPath.length ? `${error.dataPath.slice(1)}.${error.params.additionalProperty}` : error.params.additionalProperty;
                    return `Unexpected top-level property "${formattedPropertyPath}"`;
                }
                if (error.keyword === "type") {
                    const formattedField = error.dataPath.slice(1);
                    const formattedExpectedType = Array.isArray(error.schema) ? error.schema.join("/") : error.schema;
                    const formattedValue = JSON.stringify(error.data);
                    return `Property "${formattedField}" is the wrong type (expected ${formattedExpectedType} but got \`${formattedValue}\`)`;
                }
                const field = error.dataPath[0] === "." ? error.dataPath.slice(1) : error.dataPath;
                return `"${field}" ${error.message}. Value: ${JSON.stringify(error.data)}`;
            }).map(message => `\t- ${message}.\n`).join("");
        }
        /**
         * Validates the top level properties of the config object.
         * @param {Object} config The config object to validate.
         * @param {string} source The name of the configuration source to report in any errors.
         * @returns {void}
         */
        validateConfigSchema(config, source = null) {
            validateSchema = validateSchema || ajv.compile(configSchema);
            if (!validateSchema(config)) {
                throw new Error(`ESLint configuration in ${source} is invalid:\n${this.formatErrors(validateSchema.errors)}`);
            }
            if (Object.hasOwnProperty.call(config, "ecmaFeatures")) {
                emitDeprecationWarning(source, "ESLINT_LEGACY_ECMAFEATURES");
            }
        }
        /**
         * Validates an entire config object.
         * @param {Object} config The config object to validate.
         * @param {string} source The name of the configuration source to report in any errors.
         * @param {function(ruleId:string): Object} [getAdditionalRule] A map from strings to loaded rules.
         * @param {function(envId:string): Object} [getAdditionalEnv] A map from strings to loaded envs.
         * @returns {void}
         */
        validate(config, source, getAdditionalRule, getAdditionalEnv) {
            this.validateConfigSchema(config, source);
            this.validateRules(config.rules, source, getAdditionalRule);
            this.validateEnvironment(config.env, source, getAdditionalEnv);
            this.validateGlobals(config.globals, source);
            for (const override of config.overrides || []) {
                this.validateRules(override.rules, source, getAdditionalRule);
                this.validateEnvironment(override.env, source, getAdditionalEnv);
                this.validateGlobals(config.globals, source);
            }
        }
        /**
         * Validate config array object.
         * @param {ConfigArray} configArray The config array to validate.
         * @returns {void}
         */
        validateConfigArray(configArray) {
            const getPluginEnv = Map.prototype.get.bind(configArray.pluginEnvironments);
            const getPluginProcessor = Map.prototype.get.bind(configArray.pluginProcessors);
            const getPluginRule = Map.prototype.get.bind(configArray.pluginRules);
            // Validate.
            for (const element of configArray) {
                if (validated.has(element)) {
                    continue;
                }
                validated.add(element);
                this.validateEnvironment(element.env, element.name, getPluginEnv);
                this.validateGlobals(element.globals, element.name);
                this.validateProcessor(element.processor, element.name, getPluginProcessor);
                this.validateRules(element.rules, element.name, getPluginRule);
            }
        }
    }
    /**
     * @fileoverview Common helpers for naming of plugins, formatters and configs
     */
    const NAMESPACE_REGEX = /^@.*\//iu;
    /**
     * Brings package name to correct format based on prefix
     * @param {string} name The name of the package.
     * @param {string} prefix Can be either "eslint-plugin", "eslint-config" or "eslint-formatter"
     * @returns {string} Normalized name of the package
     * @private
     */
    function normalizePackageName(name, prefix) {
        let normalizedName = name;
        /**
         * On Windows, name can come in with Windows slashes instead of Unix slashes.
         * Normalize to Unix first to avoid errors later on.
         * https://github.com/eslint/eslint/issues/5644
         */
        if (normalizedName.includes("\\")) {
            normalizedName = normalizedName.replace(/\\/gu, "/");
        }
        if (normalizedName.charAt(0) === "@") {
            /**
             * it's a scoped package
             * package name is the prefix, or just a username
             */
            const scopedPackageShortcutRegex = new RegExp(`^(@[^/]+)(?:/(?:${prefix})?)?$`, "u"), scopedPackageNameRegex = new RegExp(`^${prefix}(-|$)`, "u");
            if (scopedPackageShortcutRegex.test(normalizedName)) {
                normalizedName = normalizedName.replace(scopedPackageShortcutRegex, `$1/${prefix}`);
            }
            else if (!scopedPackageNameRegex.test(normalizedName.split("/")[1])) {
                /**
                 * for scoped packages, insert the prefix after the first / unless
                 * the path is already @scope/eslint or @scope/eslint-xxx-yyy
                 */
                normalizedName = normalizedName.replace(/^@([^/]+)\/(.*)$/u, `@$1/${prefix}-$2`);
            }
        }
        else if (!normalizedName.startsWith(`${prefix}-`)) {
            normalizedName = `${prefix}-${normalizedName}`;
        }
        return normalizedName;
    }
    /**
     * Removes the prefix from a fullname.
     * @param {string} fullname The term which may have the prefix.
     * @param {string} prefix The prefix to remove.
     * @returns {string} The term without prefix.
     */
    function getShorthandName(fullname, prefix) {
        if (fullname[0] === "@") {
            let matchResult = new RegExp(`^(@[^/]+)/${prefix}$`, "u").exec(fullname);
            if (matchResult) {
                return matchResult[1];
            }
            matchResult = new RegExp(`^(@[^/]+)/${prefix}-(.+)$`, "u").exec(fullname);
            if (matchResult) {
                return `${matchResult[1]}/${matchResult[2]}`;
            }
        }
        else if (fullname.startsWith(`${prefix}-`)) {
            return fullname.slice(prefix.length + 1);
        }
        return fullname;
    }
    /**
     * Gets the scope (namespace) of a term.
     * @param {string} term The term which may have the namespace.
     * @returns {string} The namespace of the term if it has one.
     */
    function getNamespaceFromTerm(term) {
        const match = term.match(NAMESPACE_REGEX);
        return match ? match[0] : "";
    }
    var naming = {
        __proto__: null,
        normalizePackageName: normalizePackageName,
        getShorthandName: getShorthandName,
        getNamespaceFromTerm: getNamespaceFromTerm
    };
    /**
     * @fileoverview Package exports for @eslint/eslintrc
     * @author Nicholas C. Zakas
     */
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    const Legacy = {
        environments,
        // shared
        ConfigOps,
        ConfigValidator,
        naming
    };
    exports.Legacy = Legacy;
    
},
/* eslint/lib/shared/traverser.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Traverser to traverse AST trees.
     * @author Nicholas C. Zakas
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const vk = require(304) /* eslint-visitor-keys */;
    const debug = require(72) /* debug */("eslint:traverser");
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Do nothing.
     * @returns {void}
     */
    function noop() {
        // do nothing.
    }
    /**
     * Check whether the given value is an ASTNode or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if the value is an ASTNode.
     */
    function isNode(x) {
        return x !== null && typeof x === "object" && typeof x.type === "string";
    }
    /**
     * Get the visitor keys of a given node.
     * @param {Object} visitorKeys The map of visitor keys.
     * @param {ASTNode} node The node to get their visitor keys.
     * @returns {string[]} The visitor keys of the node.
     */
    function getVisitorKeys(visitorKeys, node) {
        let keys = visitorKeys[node.type];
        if (!keys) {
            keys = vk.getKeys(node);
            debug("Unknown node type \"%s\": Estimated visitor keys %j", node.type, keys);
        }
        return keys;
    }
    /**
     * The traverser class to traverse AST trees.
     */
    class Traverser {
        constructor() {
            this._current = null;
            this._parents = [];
            this._skipped = false;
            this._broken = false;
            this._visitorKeys = null;
            this._enter = null;
            this._leave = null;
        }
        /**
         * Gives current node.
         * @returns {ASTNode} The current node.
         */
        current() {
            return this._current;
        }
        /**
         * Gives a copy of the ancestor nodes.
         * @returns {ASTNode[]} The ancestor nodes.
         */
        parents() {
            return this._parents.slice(0);
        }
        /**
         * Break the current traversal.
         * @returns {void}
         */
        break() {
            this._broken = true;
        }
        /**
         * Skip child nodes for the current traversal.
         * @returns {void}
         */
        skip() {
            this._skipped = true;
        }
        /**
         * Traverse the given AST tree.
         * @param {ASTNode} node The root node to traverse.
         * @param {Object} options The option object.
         * @param {Object} [options.visitorKeys=DEFAULT_VISITOR_KEYS] The keys of each node types to traverse child nodes. Default is `./default-visitor-keys.json`.
         * @param {Function} [options.enter=noop] The callback function which is called on entering each node.
         * @param {Function} [options.leave=noop] The callback function which is called on leaving each node.
         * @returns {void}
         */
        traverse(node, options) {
            this._current = null;
            this._parents = [];
            this._skipped = false;
            this._broken = false;
            this._visitorKeys = options.visitorKeys || vk.KEYS;
            this._enter = options.enter || noop;
            this._leave = options.leave || noop;
            this._traverse(node, null);
        }
        /**
         * Traverse the given AST tree recursively.
         * @param {ASTNode} node The current node.
         * @param {ASTNode|null} parent The parent node.
         * @returns {void}
         * @private
         */
        _traverse(node, parent) {
            if (!isNode(node)) {
                return;
            }
            this._current = node;
            this._skipped = false;
            this._enter(node, parent);
            if (!this._skipped && !this._broken) {
                const keys = getVisitorKeys(this._visitorKeys, node);
                if (keys.length >= 1) {
                    this._parents.push(node);
                    for (let i = 0; i < keys.length && !this._broken; ++i) {
                        const child = node[keys[i]];
                        if (Array.isArray(child)) {
                            for (let j = 0; j < child.length && !this._broken; ++j) {
                                this._traverse(child[j], node);
                            }
                        }
                        else {
                            this._traverse(child, node);
                        }
                    }
                    this._parents.pop();
                }
            }
            if (!this._broken) {
                this._leave(node, parent);
            }
            this._current = parent;
        }
        /**
         * Calculates the keys to use for traversal.
         * @param {ASTNode} node The node to read keys from.
         * @returns {string[]} An array of keys to visit on the node.
         * @private
         */
        static getKeys(node) {
            return vk.getKeys(node);
        }
        /**
         * Traverse the given AST tree.
         * @param {ASTNode} node The root node to traverse.
         * @param {Object} options The option object.
         * @param {Object} [options.visitorKeys=DEFAULT_VISITOR_KEYS] The keys of each node types to traverse child nodes. Default is `./default-visitor-keys.json`.
         * @param {Function} [options.enter=noop] The callback function which is called on entering each node.
         * @param {Function} [options.leave=noop] The callback function which is called on leaving each node.
         * @returns {void}
         */
        static traverse(node, options) {
            new Traverser().traverse(node, options);
        }
        /**
         * The default visitor keys.
         * @type {Object}
         */
        static get DEFAULT_VISITOR_KEYS() {
            return vk.KEYS;
        }
    }
    module.exports = Traverser;
},
/* eslint/lib/source-code/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    module.exports = {
        SourceCode: require(315) /* ./source-code */
    };
},
/* eslint/lib/source-code/source-code.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Abstraction of JavaScript source code.
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { isCommentToken } = require(316) /* @eslint-community/eslint-utils */, TokenStore = require(317) /* ./token-store */, astUtils = require(309) /* ../shared/ast-utils */, Traverser = require(313) /* ../shared/traverser */;
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    /**
     * Validates that the given AST has the required information.
     * @param {ASTNode} ast The Program node of the AST to check.
     * @throws {Error} If the AST doesn't contain the correct information.
     * @returns {void}
     * @private
     */
    function validate(ast) {
        if (!ast.tokens) {
            throw new Error("AST is missing the tokens array.");
        }
        if (!ast.comments) {
            throw new Error("AST is missing the comments array.");
        }
        if (!ast.loc) {
            throw new Error("AST is missing location information.");
        }
        if (!ast.range) {
            throw new Error("AST is missing range information");
        }
    }
    /**
     * Check to see if its a ES6 export declaration.
     * @param {ASTNode} astNode An AST node.
     * @returns {boolean} whether the given node represents an export declaration.
     * @private
     */
    function looksLikeExport(astNode) {
        return astNode.type === "ExportDefaultDeclaration" || astNode.type === "ExportNamedDeclaration" ||
            astNode.type === "ExportAllDeclaration" || astNode.type === "ExportSpecifier";
    }
    /**
     * Merges two sorted lists into a larger sorted list in O(n) time.
     * @param {Token[]} tokens The list of tokens.
     * @param {Token[]} comments The list of comments.
     * @returns {Token[]} A sorted list of tokens and comments.
     * @private
     */
    function sortedMerge(tokens, comments) {
        const result = [];
        let tokenIndex = 0;
        let commentIndex = 0;
        while (tokenIndex < tokens.length || commentIndex < comments.length) {
            if (commentIndex >= comments.length || tokenIndex < tokens.length && tokens[tokenIndex].range[0] < comments[commentIndex].range[0]) {
                result.push(tokens[tokenIndex++]);
            }
            else {
                result.push(comments[commentIndex++]);
            }
        }
        return result;
    }
    /**
     * Determines if two nodes or tokens overlap.
     * @param {ASTNode|Token} first The first node or token to check.
     * @param {ASTNode|Token} second The second node or token to check.
     * @returns {boolean} True if the two nodes or tokens overlap.
     * @private
     */
    function nodesOrTokensOverlap(first, second) {
        return (first.range[0] <= second.range[0] && first.range[1] >= second.range[0]) ||
            (second.range[0] <= first.range[0] && second.range[1] >= first.range[0]);
    }
    /**
     * Determines if two nodes or tokens have at least one whitespace character
     * between them. Order does not matter. Returns false if the given nodes or
     * tokens overlap.
     * @param {SourceCode} sourceCode The source code object.
     * @param {ASTNode|Token} first The first node or token to check between.
     * @param {ASTNode|Token} second The second node or token to check between.
     * @param {boolean} checkInsideOfJSXText If `true` is present, check inside of JSXText tokens for backward compatibility.
     * @returns {boolean} True if there is a whitespace character between
     * any of the tokens found between the two given nodes or tokens.
     * @public
     */
    function isSpaceBetween(sourceCode, first, second, checkInsideOfJSXText) {
        if (nodesOrTokensOverlap(first, second)) {
            return false;
        }
        const [startingNodeOrToken, endingNodeOrToken] = first.range[1] <= second.range[0]
            ? [first, second]
            : [second, first];
        const firstToken = sourceCode.getLastToken(startingNodeOrToken) || startingNodeOrToken;
        const finalToken = sourceCode.getFirstToken(endingNodeOrToken) || endingNodeOrToken;
        let currentToken = firstToken;
        while (currentToken !== finalToken) {
            const nextToken = sourceCode.getTokenAfter(currentToken, { includeComments: true });
            if (currentToken.range[1] !== nextToken.range[0] ||
                /*
                 * For backward compatibility, check spaces in JSXText.
                 * https://github.com/eslint/eslint/issues/12614
                 */
                (checkInsideOfJSXText &&
                    nextToken !== finalToken &&
                    nextToken.type === "JSXText" &&
                    /\s/u.test(nextToken.value))) {
                return true;
            }
            currentToken = nextToken;
        }
        return false;
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * Represents parsed source code.
     */
    class SourceCode extends TokenStore {
        /**
         * @param {string|Object} textOrConfig The source code text or config object.
         * @param {string} textOrConfig.text The source code text.
         * @param {ASTNode} textOrConfig.ast The Program node of the AST representing the code. This AST should be created from the text that BOM was stripped.
         * @param {Object|null} textOrConfig.parserServices The parser services.
         * @param {ScopeManager|null} textOrConfig.scopeManager The scope of this source code.
         * @param {Object|null} textOrConfig.visitorKeys The visitor keys to traverse AST.
         * @param {ASTNode} [astIfNoConfig] The Program node of the AST representing the code. This AST should be created from the text that BOM was stripped.
         */
        constructor(textOrConfig, astIfNoConfig) {
            let text, ast, parserServices, scopeManager, visitorKeys;
            // Process overloading.
            if (typeof textOrConfig === "string") {
                text = textOrConfig;
                ast = astIfNoConfig;
            }
            else if (typeof textOrConfig === "object" && textOrConfig !== null) {
                text = textOrConfig.text;
                ast = textOrConfig.ast;
                parserServices = textOrConfig.parserServices;
                scopeManager = textOrConfig.scopeManager;
                visitorKeys = textOrConfig.visitorKeys;
            }
            validate(ast);
            super(ast.tokens, ast.comments);
            /**
             * The flag to indicate that the source code has Unicode BOM.
             * @type {boolean}
             */
            this.hasBOM = (text.charCodeAt(0) === 0xFEFF);
            /**
             * The original text source code.
             * BOM was stripped from this text.
             * @type {string}
             */
            this.text = (this.hasBOM ? text.slice(1) : text);
            /**
             * The parsed AST for the source code.
             * @type {ASTNode}
             */
            this.ast = ast;
            /**
             * The parser services of this source code.
             * @type {Object}
             */
            this.parserServices = parserServices || {};
            /**
             * The scope of this source code.
             * @type {ScopeManager|null}
             */
            this.scopeManager = scopeManager || null;
            /**
             * The visitor keys to traverse AST.
             * @type {Object}
             */
            this.visitorKeys = visitorKeys || Traverser.DEFAULT_VISITOR_KEYS;
            // Check the source text for the presence of a shebang since it is parsed as a standard line comment.
            const shebangMatched = this.text.match(astUtils.shebangPattern);
            const hasShebang = shebangMatched && ast.comments.length && ast.comments[0].value === shebangMatched[1];
            if (hasShebang) {
                ast.comments[0].type = "Shebang";
            }
            this.tokensAndComments = sortedMerge(ast.tokens, ast.comments);
            /**
             * The source code split into lines according to ECMA-262 specification.
             * This is done to avoid each rule needing to do so separately.
             * @type {string[]}
             */
            this.lines = [];
            this.lineStartIndices = [0];
            const lineEndingPattern = astUtils.createGlobalLinebreakMatcher();
            let match;
            /*
             * Previously, this was implemented using a regex that
             * matched a sequence of non-linebreak characters followed by a
             * linebreak, then adding the lengths of the matches. However,
             * this caused a catastrophic backtracking issue when the end
             * of a file contained a large number of non-newline characters.
             * To avoid this, the current implementation just matches newlines
             * and uses match.index to get the correct line start indices.
             */
            while ((match = lineEndingPattern.exec(this.text))) {
                this.lines.push(this.text.slice(this.lineStartIndices[this.lineStartIndices.length - 1], match.index));
                this.lineStartIndices.push(match.index + match[0].length);
            }
            this.lines.push(this.text.slice(this.lineStartIndices[this.lineStartIndices.length - 1]));
            // Cache for comments found using getComments().
            this._commentCache = new WeakMap();
            // don't allow modification of this object
            Object.freeze(this);
            Object.freeze(this.lines);
        }
        /**
         * Split the source code into multiple lines based on the line delimiters.
         * @param {string} text Source code as a string.
         * @returns {string[]} Array of source code lines.
         * @public
         */
        static splitLines(text) {
            return text.split(astUtils.createGlobalLinebreakMatcher());
        }
        /**
         * Gets the source code for the given node.
         * @param {ASTNode} [node] The AST node to get the text for.
         * @param {int} [beforeCount] The number of characters before the node to retrieve.
         * @param {int} [afterCount] The number of characters after the node to retrieve.
         * @returns {string} The text representing the AST node.
         * @public
         */
        getText(node, beforeCount, afterCount) {
            if (node) {
                return this.text.slice(Math.max(node.range[0] - (beforeCount || 0), 0), node.range[1] + (afterCount || 0));
            }
            return this.text;
        }
        /**
         * Gets the entire source text split into an array of lines.
         * @returns {Array} The source text as an array of lines.
         * @public
         */
        getLines() {
            return this.lines;
        }
        /**
         * Retrieves an array containing all comments in the source code.
         * @returns {ASTNode[]} An array of comment nodes.
         * @public
         */
        getAllComments() {
            return this.ast.comments;
        }
        /**
         * Gets all comments for the given node.
         * @param {ASTNode} node The AST node to get the comments for.
         * @returns {Object} An object containing a leading and trailing array
         *      of comments indexed by their position.
         * @public
         * @deprecated replaced by getCommentsBefore(), getCommentsAfter(), and getCommentsInside().
         */
        getComments(node) {
            if (this._commentCache.has(node)) {
                return this._commentCache.get(node);
            }
            const comments = {
                leading: [],
                trailing: []
            };
            /*
             * Return all comments as leading comments of the Program node when
             * there is no executable code.
             */
            if (node.type === "Program") {
                if (node.body.length === 0) {
                    comments.leading = node.comments;
                }
            }
            else {
                /*
                 * Return comments as trailing comments of nodes that only contain
                 * comments (to mimic the comment attachment behavior present in Espree).
                 */
                if ((node.type === "BlockStatement" || node.type === "ClassBody") && node.body.length === 0 ||
                    node.type === "ObjectExpression" && node.properties.length === 0 ||
                    node.type === "ArrayExpression" && node.elements.length === 0 ||
                    node.type === "SwitchStatement" && node.cases.length === 0) {
                    comments.trailing = this.getTokens(node, {
                        includeComments: true,
                        filter: isCommentToken
                    });
                }
                /*
                 * Iterate over tokens before and after node and collect comment tokens.
                 * Do not include comments that exist outside of the parent node
                 * to avoid duplication.
                 */
                let currentToken = this.getTokenBefore(node, { includeComments: true });
                while (currentToken && isCommentToken(currentToken)) {
                    if (node.parent && node.parent.type !== "Program" && (currentToken.start < node.parent.start)) {
                        break;
                    }
                    comments.leading.push(currentToken);
                    currentToken = this.getTokenBefore(currentToken, { includeComments: true });
                }
                comments.leading.reverse();
                currentToken = this.getTokenAfter(node, { includeComments: true });
                while (currentToken && isCommentToken(currentToken)) {
                    if (node.parent && node.parent.type !== "Program" && (currentToken.end > node.parent.end)) {
                        break;
                    }
                    comments.trailing.push(currentToken);
                    currentToken = this.getTokenAfter(currentToken, { includeComments: true });
                }
            }
            this._commentCache.set(node, comments);
            return comments;
        }
        /**
         * Retrieves the JSDoc comment for a given node.
         * @param {ASTNode} node The AST node to get the comment for.
         * @returns {Token|null} The Block comment token containing the JSDoc comment
         *      for the given node or null if not found.
         * @public
         * @deprecated
         */
        getJSDocComment(node) {
            /**
             * Checks for the presence of a JSDoc comment for the given node and returns it.
             * @param {ASTNode} astNode The AST node to get the comment for.
             * @returns {Token|null} The Block comment token containing the JSDoc comment
             *      for the given node or null if not found.
             * @private
             */
            const findJSDocComment = astNode => {
                const tokenBefore = this.getTokenBefore(astNode, { includeComments: true });
                if (tokenBefore &&
                    isCommentToken(tokenBefore) &&
                    tokenBefore.type === "Block" &&
                    tokenBefore.value.charAt(0) === "*" &&
                    astNode.loc.start.line - tokenBefore.loc.end.line <= 1) {
                    return tokenBefore;
                }
                return null;
            };
            let parent = node.parent;
            switch (node.type) {
                case "ClassDeclaration":
                case "FunctionDeclaration":
                    return findJSDocComment(looksLikeExport(parent) ? parent : node);
                case "ClassExpression":
                    return findJSDocComment(parent.parent);
                case "ArrowFunctionExpression":
                case "FunctionExpression":
                    if (parent.type !== "CallExpression" && parent.type !== "NewExpression") {
                        while (!this.getCommentsBefore(parent).length &&
                            !/Function/u.test(parent.type) &&
                            parent.type !== "MethodDefinition" &&
                            parent.type !== "Property") {
                            parent = parent.parent;
                            if (!parent) {
                                break;
                            }
                        }
                        if (parent && parent.type !== "FunctionDeclaration" && parent.type !== "Program") {
                            return findJSDocComment(parent);
                        }
                    }
                    return findJSDocComment(node);
                // falls through
                default:
                    return null;
            }
        }
        /**
         * Gets the deepest node containing a range index.
         * @param {int} index Range index of the desired node.
         * @returns {ASTNode} The node if found or null if not found.
         * @public
         */
        getNodeByRangeIndex(index) {
            let result = null;
            Traverser.traverse(this.ast, {
                visitorKeys: this.visitorKeys,
                enter(node) {
                    if (node.range[0] <= index && index < node.range[1]) {
                        result = node;
                    }
                    else {
                        this.skip();
                    }
                },
                leave(node) {
                    if (node === result) {
                        this.break();
                    }
                }
            });
            return result;
        }
        /**
         * Determines if two nodes or tokens have at least one whitespace character
         * between them. Order does not matter. Returns false if the given nodes or
         * tokens overlap.
         * @param {ASTNode|Token} first The first node or token to check between.
         * @param {ASTNode|Token} second The second node or token to check between.
         * @returns {boolean} True if there is a whitespace character between
         * any of the tokens found between the two given nodes or tokens.
         * @public
         */
        isSpaceBetween(first, second) {
            return isSpaceBetween(this, first, second, false);
        }
        /**
         * Determines if two nodes or tokens have at least one whitespace character
         * between them. Order does not matter. Returns false if the given nodes or
         * tokens overlap.
         * For backward compatibility, this method returns true if there are
         * `JSXText` tokens that contain whitespaces between the two.
         * @param {ASTNode|Token} first The first node or token to check between.
         * @param {ASTNode|Token} second The second node or token to check between.
         * @returns {boolean} True if there is a whitespace character between
         * any of the tokens found between the two given nodes or tokens.
         * @deprecated in favor of isSpaceBetween().
         * @public
         */
        isSpaceBetweenTokens(first, second) {
            return isSpaceBetween(this, first, second, true);
        }
        /**
         * Converts a source text index into a (line, column) pair.
         * @param {number} index The index of a character in a file
         * @throws {TypeError} If non-numeric index or index out of range.
         * @returns {Object} A {line, column} location object with a 0-indexed column
         * @public
         */
        getLocFromIndex(index) {
            if (typeof index !== "number") {
                throw new TypeError("Expected `index` to be a number.");
            }
            if (index < 0 || index > this.text.length) {
                throw new RangeError(`Index out of range (requested index ${index}, but source text has length ${this.text.length}).`);
            }
            /*
             * For an argument of this.text.length, return the location one "spot" past the last character
             * of the file. If the last character is a linebreak, the location will be column 0 of the next
             * line; otherwise, the location will be in the next column on the same line.
             *
             * See getIndexFromLoc for the motivation for this special case.
             */
            if (index === this.text.length) {
                return { line: this.lines.length, column: this.lines[this.lines.length - 1].length };
            }
            /*
             * To figure out which line index is on, determine the last place at which index could
             * be inserted into lineStartIndices to keep the list sorted.
             */
            const lineNumber = index >= this.lineStartIndices[this.lineStartIndices.length - 1]
                ? this.lineStartIndices.length
                : this.lineStartIndices.findIndex(el => index < el);
            return { line: lineNumber, column: index - this.lineStartIndices[lineNumber - 1] };
        }
        /**
         * Converts a (line, column) pair into a range index.
         * @param {Object} loc A line/column location
         * @param {number} loc.line The line number of the location (1-indexed)
         * @param {number} loc.column The column number of the location (0-indexed)
         * @throws {TypeError|RangeError} If `loc` is not an object with a numeric
         *   `line` and `column`, if the `line` is less than or equal to zero or
         *   the line or column is out of the expected range.
         * @returns {number} The range index of the location in the file.
         * @public
         */
        getIndexFromLoc(loc) {
            if (typeof loc !== "object" || typeof loc.line !== "number" || typeof loc.column !== "number") {
                throw new TypeError("Expected `loc` to be an object with numeric `line` and `column` properties.");
            }
            if (loc.line <= 0) {
                throw new RangeError(`Line number out of range (line ${loc.line} requested). Line numbers should be 1-based.`);
            }
            if (loc.line > this.lineStartIndices.length) {
                throw new RangeError(`Line number out of range (line ${loc.line} requested, but only ${this.lineStartIndices.length} lines present).`);
            }
            const lineStartIndex = this.lineStartIndices[loc.line - 1];
            const lineEndIndex = loc.line === this.lineStartIndices.length ? this.text.length : this.lineStartIndices[loc.line];
            const positionIndex = lineStartIndex + loc.column;
            /*
             * By design, getIndexFromLoc({ line: lineNum, column: 0 }) should return the start index of
             * the given line, provided that the line number is valid element of this.lines. Since the
             * last element of this.lines is an empty string for files with trailing newlines, add a
             * special case where getting the index for the first location after the end of the file
             * will return the length of the file, rather than throwing an error. This allows rules to
             * use getIndexFromLoc consistently without worrying about edge cases at the end of a file.
             */
            if (loc.line === this.lineStartIndices.length && positionIndex > lineEndIndex ||
                loc.line < this.lineStartIndices.length && positionIndex >= lineEndIndex) {
                throw new RangeError(`Column number out of range (column ${loc.column} requested, but the length of line ${loc.line} is ${lineEndIndex - lineStartIndex}).`);
            }
            return positionIndex;
        }
    }
    module.exports = SourceCode;
},
/* @eslint-community/eslint-utils/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    var eslintVisitorKeys = require(304) /* eslint-visitor-keys */;
    /**
     * Get the innermost scope which contains a given location.
     * @param {Scope} initialScope The initial scope to search.
     * @param {Node} node The location to search.
     * @returns {Scope} The innermost scope.
     */
    function getInnermostScope(initialScope, node) {
        const location = node.range[0];
        let scope = initialScope;
        let found = false;
        do {
            found = false;
            for (const childScope of scope.childScopes) {
                const range = childScope.block.range;
                if (range[0] <= location && location < range[1]) {
                    scope = childScope;
                    found = true;
                    break;
                }
            }
        } while (found);
        return scope;
    }
    /**
     * Find the variable of a given name.
     * @param {Scope} initialScope The scope to start finding.
     * @param {string|Node} nameOrNode The variable name to find. If this is a Node object then it should be an Identifier node.
     * @returns {Variable|null} The found variable or null.
     */
    function findVariable(initialScope, nameOrNode) {
        let name = "";
        let scope = initialScope;
        if (typeof nameOrNode === "string") {
            name = nameOrNode;
        }
        else {
            name = nameOrNode.name;
            scope = getInnermostScope(scope, nameOrNode);
        }
        while (scope != null) {
            const variable = scope.set.get(name);
            if (variable != null) {
                return variable;
            }
            scope = scope.upper;
        }
        return null;
    }
    /**
     * Negate the result of `this` calling.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the result of `this(token)` is `false`.
     */
    function negate0(token) {
        return !this(token); //eslint-disable-line no-invalid-this
    }
    /**
     * Creates the negate function of the given function.
     * @param {function(Token):boolean} f - The function to negate.
     * @returns {function(Token):boolean} Negated function.
     */
    function negate(f) {
        return negate0.bind(f);
    }
    /**
     * Checks if the given token is a PunctuatorToken with the given value
     * @param {Token} token - The token to check.
     * @param {string} value - The value to check.
     * @returns {boolean} `true` if the token is a PunctuatorToken with the given value.
     */
    function isPunctuatorTokenWithValue(token, value) {
        return token.type === "Punctuator" && token.value === value;
    }
    /**
     * Checks if the given token is an arrow token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is an arrow token.
     */
    function isArrowToken(token) {
        return isPunctuatorTokenWithValue(token, "=>");
    }
    /**
     * Checks if the given token is a comma token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is a comma token.
     */
    function isCommaToken(token) {
        return isPunctuatorTokenWithValue(token, ",");
    }
    /**
     * Checks if the given token is a semicolon token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is a semicolon token.
     */
    function isSemicolonToken(token) {
        return isPunctuatorTokenWithValue(token, ";");
    }
    /**
     * Checks if the given token is a colon token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is a colon token.
     */
    function isColonToken(token) {
        return isPunctuatorTokenWithValue(token, ":");
    }
    /**
     * Checks if the given token is an opening parenthesis token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is an opening parenthesis token.
     */
    function isOpeningParenToken(token) {
        return isPunctuatorTokenWithValue(token, "(");
    }
    /**
     * Checks if the given token is a closing parenthesis token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is a closing parenthesis token.
     */
    function isClosingParenToken(token) {
        return isPunctuatorTokenWithValue(token, ")");
    }
    /**
     * Checks if the given token is an opening square bracket token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is an opening square bracket token.
     */
    function isOpeningBracketToken(token) {
        return isPunctuatorTokenWithValue(token, "[");
    }
    /**
     * Checks if the given token is a closing square bracket token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is a closing square bracket token.
     */
    function isClosingBracketToken(token) {
        return isPunctuatorTokenWithValue(token, "]");
    }
    /**
     * Checks if the given token is an opening brace token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is an opening brace token.
     */
    function isOpeningBraceToken(token) {
        return isPunctuatorTokenWithValue(token, "{");
    }
    /**
     * Checks if the given token is a closing brace token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is a closing brace token.
     */
    function isClosingBraceToken(token) {
        return isPunctuatorTokenWithValue(token, "}");
    }
    /**
     * Checks if the given token is a comment token or not.
     * @param {Token} token - The token to check.
     * @returns {boolean} `true` if the token is a comment token.
     */
    function isCommentToken(token) {
        return ["Block", "Line", "Shebang"].includes(token.type);
    }
    const isNotArrowToken = negate(isArrowToken);
    const isNotCommaToken = negate(isCommaToken);
    const isNotSemicolonToken = negate(isSemicolonToken);
    const isNotColonToken = negate(isColonToken);
    const isNotOpeningParenToken = negate(isOpeningParenToken);
    const isNotClosingParenToken = negate(isClosingParenToken);
    const isNotOpeningBracketToken = negate(isOpeningBracketToken);
    const isNotClosingBracketToken = negate(isClosingBracketToken);
    const isNotOpeningBraceToken = negate(isOpeningBraceToken);
    const isNotClosingBraceToken = negate(isClosingBraceToken);
    const isNotCommentToken = negate(isCommentToken);
    /**
     * Get the `(` token of the given function node.
     * @param {Node} node - The function node to get.
     * @param {SourceCode} sourceCode - The source code object to get tokens.
     * @returns {Token} `(` token.
     */
    function getOpeningParenOfParams(node, sourceCode) {
        return node.id
            ? sourceCode.getTokenAfter(node.id, isOpeningParenToken)
            : sourceCode.getFirstToken(node, isOpeningParenToken);
    }
    /**
     * Get the location of the given function node for reporting.
     * @param {Node} node - The function node to get.
     * @param {SourceCode} sourceCode - The source code object to get tokens.
     * @returns {string} The location of the function node for reporting.
     */
    function getFunctionHeadLocation(node, sourceCode) {
        const parent = node.parent;
        let start = null;
        let end = null;
        if (node.type === "ArrowFunctionExpression") {
            const arrowToken = sourceCode.getTokenBefore(node.body, isArrowToken);
            start = arrowToken.loc.start;
            end = arrowToken.loc.end;
        }
        else if (parent.type === "Property" ||
            parent.type === "MethodDefinition" ||
            parent.type === "PropertyDefinition") {
            start = parent.loc.start;
            end = getOpeningParenOfParams(node, sourceCode).loc.start;
        }
        else {
            start = node.loc.start;
            end = getOpeningParenOfParams(node, sourceCode).loc.start;
        }
        return {
            start: { ...start },
            end: { ...end },
        };
    }
    /* globals globalThis, global, self, window */
    const globalObject = typeof globalThis !== "undefined"
        ? globalThis
        : typeof self !== "undefined"
            ? self
            : typeof window !== "undefined"
                ? window
                : typeof global !== "undefined"
                    ? global
                    : {};
    const builtinNames = Object.freeze(new Set([
        "Array",
        "ArrayBuffer",
        "BigInt",
        "BigInt64Array",
        "BigUint64Array",
        "Boolean",
        "DataView",
        "Date",
        "decodeURI",
        "decodeURIComponent",
        "encodeURI",
        "encodeURIComponent",
        "escape",
        "Float32Array",
        "Float64Array",
        "Function",
        "Infinity",
        "Int16Array",
        "Int32Array",
        "Int8Array",
        "isFinite",
        "isNaN",
        "isPrototypeOf",
        "JSON",
        "Map",
        "Math",
        "NaN",
        "Number",
        "Object",
        "parseFloat",
        "parseInt",
        "Promise",
        "Proxy",
        "Reflect",
        "RegExp",
        "Set",
        "String",
        "Symbol",
        "Uint16Array",
        "Uint32Array",
        "Uint8Array",
        "Uint8ClampedArray",
        "undefined",
        "unescape",
        "WeakMap",
        "WeakSet",
    ]));
    const callAllowed = new Set([
        Array.isArray,
        typeof BigInt === "function" ? BigInt : undefined,
        Boolean,
        Date,
        Date.parse,
        decodeURI,
        decodeURIComponent,
        encodeURI,
        encodeURIComponent,
        escape,
        isFinite,
        isNaN,
        isPrototypeOf,
        ...Object.getOwnPropertyNames(Math)
            .map((k) => Math[k])
            .filter((f) => typeof f === "function"),
        Number,
        Number.isFinite,
        Number.isNaN,
        Number.parseFloat,
        Number.parseInt,
        Object,
        Object.entries,
        Object.is,
        Object.isExtensible,
        Object.isFrozen,
        Object.isSealed,
        Object.keys,
        Object.values,
        parseFloat,
        parseInt,
        RegExp,
        String,
        String.fromCharCode,
        String.fromCodePoint,
        String.raw,
        Symbol.for,
        Symbol.keyFor,
        unescape,
    ].filter((f) => typeof f === "function"));
    const callPassThrough = new Set([
        Object.freeze,
        Object.preventExtensions,
        Object.seal,
    ]);
    /**
     * Get the property descriptor.
     * @param {object} object The object to get.
     * @param {string|number|symbol} name The property name to get.
     */
    function getPropertyDescriptor(object, name) {
        let x = object;
        while ((typeof x === "object" || typeof x === "function") && x !== null) {
            const d = Object.getOwnPropertyDescriptor(x, name);
            if (d) {
                return d;
            }
            x = Object.getPrototypeOf(x);
        }
        return null;
    }
    /**
     * Check if a property is getter or not.
     * @param {object} object The object to check.
     * @param {string|number|symbol} name The property name to check.
     */
    function isGetter(object, name) {
        const d = getPropertyDescriptor(object, name);
        return d != null && d.get != null;
    }
    /**
     * Get the element values of a given node list.
     * @param {Node[]} nodeList The node list to get values.
     * @param {Scope|undefined} initialScope The initial scope to find variables.
     * @returns {any[]|null} The value list if all nodes are constant. Otherwise, null.
     */
    function getElementValues(nodeList, initialScope) {
        const valueList = [];
        for (let i = 0; i < nodeList.length; ++i) {
            const elementNode = nodeList[i];
            if (elementNode == null) {
                valueList.length = i + 1;
            }
            else if (elementNode.type === "SpreadElement") {
                const argument = getStaticValueR(elementNode.argument, initialScope);
                if (argument == null) {
                    return null;
                }
                valueList.push(...argument.value);
            }
            else {
                const element = getStaticValueR(elementNode, initialScope);
                if (element == null) {
                    return null;
                }
                valueList.push(element.value);
            }
        }
        return valueList;
    }
    const operations = Object.freeze({
        ArrayExpression(node, initialScope) {
            const elements = getElementValues(node.elements, initialScope);
            return elements != null ? { value: elements } : null;
        },
        AssignmentExpression(node, initialScope) {
            if (node.operator === "=") {
                return getStaticValueR(node.right, initialScope);
            }
            return null;
        },
        //eslint-disable-next-line complexity
        BinaryExpression(node, initialScope) {
            if (node.operator === "in" || node.operator === "instanceof") {
                // Not supported.
                return null;
            }
            const left = getStaticValueR(node.left, initialScope);
            const right = getStaticValueR(node.right, initialScope);
            if (left != null && right != null) {
                switch (node.operator) {
                    case "==":
                        return { value: left.value == right.value }; //eslint-disable-line eqeqeq
                    case "!=":
                        return { value: left.value != right.value }; //eslint-disable-line eqeqeq
                    case "===":
                        return { value: left.value === right.value };
                    case "!==":
                        return { value: left.value !== right.value };
                    case "<":
                        return { value: left.value < right.value };
                    case "<=":
                        return { value: left.value <= right.value };
                    case ">":
                        return { value: left.value > right.value };
                    case ">=":
                        return { value: left.value >= right.value };
                    case "<<":
                        return { value: left.value << right.value };
                    case ">>":
                        return { value: left.value >> right.value };
                    case ">>>":
                        return { value: left.value >>> right.value };
                    case "+":
                        return { value: left.value + right.value };
                    case "-":
                        return { value: left.value - right.value };
                    case "*":
                        return { value: left.value * right.value };
                    case "/":
                        return { value: left.value / right.value };
                    case "%":
                        return { value: left.value % right.value };
                    case "**":
                        return { value: left.value ** right.value };
                    case "|":
                        return { value: left.value | right.value };
                    case "^":
                        return { value: left.value ^ right.value };
                    case "&":
                        return { value: left.value & right.value };
                    // no default
                }
            }
            return null;
        },
        CallExpression(node, initialScope) {
            const calleeNode = node.callee;
            const args = getElementValues(node.arguments, initialScope);
            if (args != null) {
                if (calleeNode.type === "MemberExpression") {
                    if (calleeNode.property.type === "PrivateIdentifier") {
                        return null;
                    }
                    const object = getStaticValueR(calleeNode.object, initialScope);
                    if (object != null) {
                        if (object.value == null &&
                            (object.optional || node.optional)) {
                            return { value: undefined, optional: true };
                        }
                        const property = getStaticPropertyNameValue(calleeNode, initialScope);
                        if (property != null) {
                            const receiver = object.value;
                            const methodName = property.value;
                            if (callAllowed.has(receiver[methodName])) {
                                return { value: receiver[methodName](...args) };
                            }
                            if (callPassThrough.has(receiver[methodName])) {
                                return { value: args[0] };
                            }
                        }
                    }
                }
                else {
                    const callee = getStaticValueR(calleeNode, initialScope);
                    if (callee != null) {
                        if (callee.value == null && node.optional) {
                            return { value: undefined, optional: true };
                        }
                        const func = callee.value;
                        if (callAllowed.has(func)) {
                            return { value: func(...args) };
                        }
                        if (callPassThrough.has(func)) {
                            return { value: args[0] };
                        }
                    }
                }
            }
            return null;
        },
        ConditionalExpression(node, initialScope) {
            const test = getStaticValueR(node.test, initialScope);
            if (test != null) {
                return test.value
                    ? getStaticValueR(node.consequent, initialScope)
                    : getStaticValueR(node.alternate, initialScope);
            }
            return null;
        },
        ExpressionStatement(node, initialScope) {
            return getStaticValueR(node.expression, initialScope);
        },
        Identifier(node, initialScope) {
            if (initialScope != null) {
                const variable = findVariable(initialScope, node);
                // Built-in globals.
                if (variable != null &&
                    variable.defs.length === 0 &&
                    builtinNames.has(variable.name) &&
                    variable.name in globalObject) {
                    return { value: globalObject[variable.name] };
                }
                // Constants.
                if (variable != null && variable.defs.length === 1) {
                    const def = variable.defs[0];
                    if (def.parent &&
                        def.parent.kind === "const" &&
                        // TODO(mysticatea): don't support destructuring here.
                        def.node.id.type === "Identifier") {
                        return getStaticValueR(def.node.init, initialScope);
                    }
                }
            }
            return null;
        },
        Literal(node) {
            //istanbul ignore if : this is implementation-specific behavior.
            if ((node.regex != null || node.bigint != null) && node.value == null) {
                // It was a RegExp/BigInt literal, but Node.js didn't support it.
                return null;
            }
            return { value: node.value };
        },
        LogicalExpression(node, initialScope) {
            const left = getStaticValueR(node.left, initialScope);
            if (left != null) {
                if ((node.operator === "||" && Boolean(left.value) === true) ||
                    (node.operator === "&&" && Boolean(left.value) === false) ||
                    (node.operator === "??" && left.value != null)) {
                    return left;
                }
                const right = getStaticValueR(node.right, initialScope);
                if (right != null) {
                    return right;
                }
            }
            return null;
        },
        MemberExpression(node, initialScope) {
            if (node.property.type === "PrivateIdentifier") {
                return null;
            }
            const object = getStaticValueR(node.object, initialScope);
            if (object != null) {
                if (object.value == null && (object.optional || node.optional)) {
                    return { value: undefined, optional: true };
                }
                const property = getStaticPropertyNameValue(node, initialScope);
                if (property != null && !isGetter(object.value, property.value)) {
                    return { value: object.value[property.value] };
                }
            }
            return null;
        },
        ChainExpression(node, initialScope) {
            const expression = getStaticValueR(node.expression, initialScope);
            if (expression != null) {
                return { value: expression.value };
            }
            return null;
        },
        NewExpression(node, initialScope) {
            const callee = getStaticValueR(node.callee, initialScope);
            const args = getElementValues(node.arguments, initialScope);
            if (callee != null && args != null) {
                const Func = callee.value;
                if (callAllowed.has(Func)) {
                    return { value: new Func(...args) };
                }
            }
            return null;
        },
        ObjectExpression(node, initialScope) {
            const object = {};
            for (const propertyNode of node.properties) {
                if (propertyNode.type === "Property") {
                    if (propertyNode.kind !== "init") {
                        return null;
                    }
                    const key = getStaticPropertyNameValue(propertyNode, initialScope);
                    const value = getStaticValueR(propertyNode.value, initialScope);
                    if (key == null || value == null) {
                        return null;
                    }
                    object[key.value] = value.value;
                }
                else if (propertyNode.type === "SpreadElement" ||
                    propertyNode.type === "ExperimentalSpreadProperty") {
                    const argument = getStaticValueR(propertyNode.argument, initialScope);
                    if (argument == null) {
                        return null;
                    }
                    Object.assign(object, argument.value);
                }
                else {
                    return null;
                }
            }
            return { value: object };
        },
        SequenceExpression(node, initialScope) {
            const last = node.expressions[node.expressions.length - 1];
            return getStaticValueR(last, initialScope);
        },
        TaggedTemplateExpression(node, initialScope) {
            const tag = getStaticValueR(node.tag, initialScope);
            const expressions = getElementValues(node.quasi.expressions, initialScope);
            if (tag != null && expressions != null) {
                const func = tag.value;
                const strings = node.quasi.quasis.map((q) => q.value.cooked);
                strings.raw = node.quasi.quasis.map((q) => q.value.raw);
                if (func === String.raw) {
                    return { value: func(strings, ...expressions) };
                }
            }
            return null;
        },
        TemplateLiteral(node, initialScope) {
            const expressions = getElementValues(node.expressions, initialScope);
            if (expressions != null) {
                let value = node.quasis[0].value.cooked;
                for (let i = 0; i < expressions.length; ++i) {
                    value += expressions[i];
                    value += node.quasis[i + 1].value.cooked;
                }
                return { value };
            }
            return null;
        },
        UnaryExpression(node, initialScope) {
            if (node.operator === "delete") {
                // Not supported.
                return null;
            }
            if (node.operator === "void") {
                return { value: undefined };
            }
            const arg = getStaticValueR(node.argument, initialScope);
            if (arg != null) {
                switch (node.operator) {
                    case "-":
                        return { value: -arg.value };
                    case "+":
                        return { value: +arg.value }; //eslint-disable-line no-implicit-coercion
                    case "!":
                        return { value: !arg.value };
                    case "~":
                        return { value: ~arg.value };
                    case "typeof":
                        return { value: typeof arg.value };
                    // no default
                }
            }
            return null;
        },
    });
    /**
     * Get the value of a given node if it's a static value.
     * @param {Node} node The node to get.
     * @param {Scope|undefined} initialScope The scope to start finding variable.
     * @returns {{value:any}|{value:undefined,optional?:true}|null} The static value of the node, or `null`.
     */
    function getStaticValueR(node, initialScope) {
        if (node != null && Object.hasOwnProperty.call(operations, node.type)) {
            return operations[node.type](node, initialScope);
        }
        return null;
    }
    /**
     * Get the static value of property name from a MemberExpression node or a Property node.
     * @param {Node} node The node to get.
     * @param {Scope} [initialScope] The scope to start finding variable. Optional. If the node is a computed property node and this scope was given, this checks the computed property name by the `getStringIfConstant` function with the scope, and returns the value of it.
     * @returns {{value:any}|{value:undefined,optional?:true}|null} The static value of the property name of the node, or `null`.
     */
    function getStaticPropertyNameValue(node, initialScope) {
        const nameNode = node.type === "Property" ? node.key : node.property;
        if (node.computed) {
            return getStaticValueR(nameNode, initialScope);
        }
        if (nameNode.type === "Identifier") {
            return { value: nameNode.name };
        }
        if (nameNode.type === "Literal") {
            if (nameNode.bigint) {
                return { value: nameNode.bigint };
            }
            return { value: String(nameNode.value) };
        }
        return null;
    }
    /**
     * Get the value of a given node if it's a static value.
     * @param {Node} node The node to get.
     * @param {Scope} [initialScope] The scope to start finding variable. Optional. If this scope was given, this tries to resolve identifier references which are in the given node as much as possible.
     * @returns {{value:any}|{value:undefined,optional?:true}|null} The static value of the node, or `null`.
     */
    function getStaticValue(node, initialScope = null) {
        try {
            return getStaticValueR(node, initialScope);
        }
        catch (_error) {
            return null;
        }
    }
    /**
     * Get the value of a given node if it's a literal or a template literal.
     * @param {Node} node The node to get.
     * @param {Scope} [initialScope] The scope to start finding variable. Optional. If the node is an Identifier node and this scope was given, this checks the variable of the identifier, and returns the value of it if the variable is a constant.
     * @returns {string|null} The value of the node, or `null`.
     */
    function getStringIfConstant(node, initialScope = null) {
        // Handle the literals that the platform doesn't support natively.
        if (node && node.type === "Literal" && node.value === null) {
            if (node.regex) {
                return `/${node.regex.pattern}/${node.regex.flags}`;
            }
            if (node.bigint) {
                return node.bigint;
            }
        }
        const evaluated = getStaticValue(node, initialScope);
        return evaluated && String(evaluated.value);
    }
    /**
     * Get the property name from a MemberExpression node or a Property node.
     * @param {Node} node The node to get.
     * @param {Scope} [initialScope] The scope to start finding variable. Optional. If the node is a computed property node and this scope was given, this checks the computed property name by the `getStringIfConstant` function with the scope, and returns the value of it.
     * @returns {string|null} The property name of the node.
     */
    function getPropertyName(node, initialScope) {
        switch (node.type) {
            case "MemberExpression":
                if (node.computed) {
                    return getStringIfConstant(node.property, initialScope);
                }
                if (node.property.type === "PrivateIdentifier") {
                    return null;
                }
                return node.property.name;
            case "Property":
            case "MethodDefinition":
            case "PropertyDefinition":
                if (node.computed) {
                    return getStringIfConstant(node.key, initialScope);
                }
                if (node.key.type === "Literal") {
                    return String(node.key.value);
                }
                if (node.key.type === "PrivateIdentifier") {
                    return null;
                }
                return node.key.name;
            // no default
        }
        return null;
    }
    /**
     * Get the name and kind of the given function node.
     * @param {ASTNode} node - The function node to get.
     * @param {SourceCode} [sourceCode] The source code object to get the code of computed property keys.
     * @returns {string} The name and kind of the function node.
     */
    // eslint-disable-next-line complexity
    function getFunctionNameWithKind(node, sourceCode) {
        const parent = node.parent;
        const tokens = [];
        const isObjectMethod = parent.type === "Property" && parent.value === node;
        const isClassMethod = parent.type === "MethodDefinition" && parent.value === node;
        const isClassFieldMethod = parent.type === "PropertyDefinition" && parent.value === node;
        // Modifiers.
        if (isClassMethod || isClassFieldMethod) {
            if (parent.static) {
                tokens.push("static");
            }
            if (parent.key.type === "PrivateIdentifier") {
                tokens.push("private");
            }
        }
        if (node.async) {
            tokens.push("async");
        }
        if (node.generator) {
            tokens.push("generator");
        }
        // Kinds.
        if (isObjectMethod || isClassMethod) {
            if (parent.kind === "constructor") {
                return "constructor";
            }
            if (parent.kind === "get") {
                tokens.push("getter");
            }
            else if (parent.kind === "set") {
                tokens.push("setter");
            }
            else {
                tokens.push("method");
            }
        }
        else if (isClassFieldMethod) {
            tokens.push("method");
        }
        else {
            if (node.type === "ArrowFunctionExpression") {
                tokens.push("arrow");
            }
            tokens.push("function");
        }
        // Names.
        if (isObjectMethod || isClassMethod || isClassFieldMethod) {
            if (parent.key.type === "PrivateIdentifier") {
                tokens.push(`#${parent.key.name}`);
            }
            else {
                const name = getPropertyName(parent);
                if (name) {
                    tokens.push(`'${name}'`);
                }
                else if (sourceCode) {
                    const keyText = sourceCode.getText(parent.key);
                    if (!keyText.includes("\n")) {
                        tokens.push(`[${keyText}]`);
                    }
                }
            }
        }
        else if (node.id) {
            tokens.push(`'${node.id.name}'`);
        }
        else if (parent.type === "VariableDeclarator" &&
            parent.id &&
            parent.id.type === "Identifier") {
            tokens.push(`'${parent.id.name}'`);
        }
        else if ((parent.type === "AssignmentExpression" ||
            parent.type === "AssignmentPattern") &&
            parent.left &&
            parent.left.type === "Identifier") {
            tokens.push(`'${parent.left.name}'`);
        }
        else if (parent.type === "ExportDefaultDeclaration" &&
            parent.declaration === node) {
            tokens.push("'default'");
        }
        return tokens.join(" ");
    }
    const typeConversionBinaryOps = Object.freeze(new Set([
        "==",
        "!=",
        "<",
        "<=",
        ">",
        ">=",
        "<<",
        ">>",
        ">>>",
        "+",
        "-",
        "*",
        "/",
        "%",
        "|",
        "^",
        "&",
        "in",
    ]));
    const typeConversionUnaryOps = Object.freeze(new Set(["-", "+", "!", "~"]));
    /**
     * Check whether the given value is an ASTNode or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if the value is an ASTNode.
     */
    function isNode(x) {
        return x !== null && typeof x === "object" && typeof x.type === "string";
    }
    const visitor = Object.freeze(Object.assign(Object.create(null), {
        $visit(node, options, visitorKeys) {
            const { type } = node;
            if (typeof this[type] === "function") {
                return this[type](node, options, visitorKeys);
            }
            return this.$visitChildren(node, options, visitorKeys);
        },
        $visitChildren(node, options, visitorKeys) {
            const { type } = node;
            for (const key of visitorKeys[type] || eslintVisitorKeys.getKeys(node)) {
                const value = node[key];
                if (Array.isArray(value)) {
                    for (const element of value) {
                        if (isNode(element) &&
                            this.$visit(element, options, visitorKeys)) {
                            return true;
                        }
                    }
                }
                else if (isNode(value) &&
                    this.$visit(value, options, visitorKeys)) {
                    return true;
                }
            }
            return false;
        },
        ArrowFunctionExpression() {
            return false;
        },
        AssignmentExpression() {
            return true;
        },
        AwaitExpression() {
            return true;
        },
        BinaryExpression(node, options, visitorKeys) {
            if (options.considerImplicitTypeConversion &&
                typeConversionBinaryOps.has(node.operator) &&
                (node.left.type !== "Literal" || node.right.type !== "Literal")) {
                return true;
            }
            return this.$visitChildren(node, options, visitorKeys);
        },
        CallExpression() {
            return true;
        },
        FunctionExpression() {
            return false;
        },
        ImportExpression() {
            return true;
        },
        MemberExpression(node, options, visitorKeys) {
            if (options.considerGetters) {
                return true;
            }
            if (options.considerImplicitTypeConversion &&
                node.computed &&
                node.property.type !== "Literal") {
                return true;
            }
            return this.$visitChildren(node, options, visitorKeys);
        },
        MethodDefinition(node, options, visitorKeys) {
            if (options.considerImplicitTypeConversion &&
                node.computed &&
                node.key.type !== "Literal") {
                return true;
            }
            return this.$visitChildren(node, options, visitorKeys);
        },
        NewExpression() {
            return true;
        },
        Property(node, options, visitorKeys) {
            if (options.considerImplicitTypeConversion &&
                node.computed &&
                node.key.type !== "Literal") {
                return true;
            }
            return this.$visitChildren(node, options, visitorKeys);
        },
        PropertyDefinition(node, options, visitorKeys) {
            if (options.considerImplicitTypeConversion &&
                node.computed &&
                node.key.type !== "Literal") {
                return true;
            }
            return this.$visitChildren(node, options, visitorKeys);
        },
        UnaryExpression(node, options, visitorKeys) {
            if (node.operator === "delete") {
                return true;
            }
            if (options.considerImplicitTypeConversion &&
                typeConversionUnaryOps.has(node.operator) &&
                node.argument.type !== "Literal") {
                return true;
            }
            return this.$visitChildren(node, options, visitorKeys);
        },
        UpdateExpression() {
            return true;
        },
        YieldExpression() {
            return true;
        },
    }));
    /**
     * Check whether a given node has any side effect or not.
     * @param {Node} node The node to get.
     * @param {SourceCode} sourceCode The source code object.
     * @param {object} [options] The option object.
     * @param {boolean} [options.considerGetters=false] If `true` then it considers member accesses as the node which has side effects.
     * @param {boolean} [options.considerImplicitTypeConversion=false] If `true` then it considers implicit type conversion as the node which has side effects.
     * @param {object} [options.visitorKeys=KEYS] The keys to traverse nodes. Use `context.getSourceCode().visitorKeys`.
     * @returns {boolean} `true` if the node has a certain side effect.
     */
    function hasSideEffect(node, sourceCode, { considerGetters = false, considerImplicitTypeConversion = false } = {}) {
        return visitor.$visit(node, { considerGetters, considerImplicitTypeConversion }, sourceCode.visitorKeys || eslintVisitorKeys.KEYS);
    }
    /**
     * Get the left parenthesis of the parent node syntax if it exists.
     * E.g., `if (a) {}` then the `(`.
     * @param {Node} node The AST node to check.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {Token|null} The left parenthesis of the parent node syntax
     */
    function getParentSyntaxParen(node, sourceCode) {
        const parent = node.parent;
        switch (parent.type) {
            case "CallExpression":
            case "NewExpression":
                if (parent.arguments.length === 1 && parent.arguments[0] === node) {
                    return sourceCode.getTokenAfter(parent.callee, isOpeningParenToken);
                }
                return null;
            case "DoWhileStatement":
                if (parent.test === node) {
                    return sourceCode.getTokenAfter(parent.body, isOpeningParenToken);
                }
                return null;
            case "IfStatement":
            case "WhileStatement":
                if (parent.test === node) {
                    return sourceCode.getFirstToken(parent, 1);
                }
                return null;
            case "ImportExpression":
                if (parent.source === node) {
                    return sourceCode.getFirstToken(parent, 1);
                }
                return null;
            case "SwitchStatement":
                if (parent.discriminant === node) {
                    return sourceCode.getFirstToken(parent, 1);
                }
                return null;
            case "WithStatement":
                if (parent.object === node) {
                    return sourceCode.getFirstToken(parent, 1);
                }
                return null;
            default:
                return null;
        }
    }
    /**
     * Check whether a given node is parenthesized or not.
     * @param {number} times The number of parantheses.
     * @param {Node} node The AST node to check.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {boolean} `true` if the node is parenthesized the given times.
     */
    /**
     * Check whether a given node is parenthesized or not.
     * @param {Node} node The AST node to check.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {boolean} `true` if the node is parenthesized.
     */
    function isParenthesized(timesOrNode, nodeOrSourceCode, optionalSourceCode) {
        let times, node, sourceCode, maybeLeftParen, maybeRightParen;
        if (typeof timesOrNode === "number") {
            times = timesOrNode | 0;
            node = nodeOrSourceCode;
            sourceCode = optionalSourceCode;
            if (!(times >= 1)) {
                throw new TypeError("'times' should be a positive integer.");
            }
        }
        else {
            times = 1;
            node = timesOrNode;
            sourceCode = nodeOrSourceCode;
        }
        if (node == null ||
            // `Program` can't be parenthesized
            node.parent == null ||
            // `CatchClause.param` can't be parenthesized, example `try {} catch (error) {}`
            (node.parent.type === "CatchClause" && node.parent.param === node)) {
            return false;
        }
        maybeLeftParen = maybeRightParen = node;
        do {
            maybeLeftParen = sourceCode.getTokenBefore(maybeLeftParen);
            maybeRightParen = sourceCode.getTokenAfter(maybeRightParen);
        } while (maybeLeftParen != null &&
            maybeRightParen != null &&
            isOpeningParenToken(maybeLeftParen) &&
            isClosingParenToken(maybeRightParen) &&
            // Avoid false positive such as `if (a) {}`
            maybeLeftParen !== getParentSyntaxParen(node, sourceCode) &&
            --times > 0);
        return times === 0;
    }
    /**
     * @author Toru Nagashima <https://github.com/mysticatea>
     * See LICENSE file in root directory for full license.
     */
    const placeholder = /\$(?:[$&`']|[1-9][0-9]?)/gu;
    /** @type {WeakMap<PatternMatcher, {pattern:RegExp,escaped:boolean}>} */
    const internal = new WeakMap();
    /**
     * Check whether a given character is escaped or not.
     * @param {string} str The string to check.
     * @param {number} index The location of the character to check.
     * @returns {boolean} `true` if the character is escaped.
     */
    function isEscaped(str, index) {
        let escaped = false;
        for (let i = index - 1; i >= 0 && str.charCodeAt(i) === 0x5c; --i) {
            escaped = !escaped;
        }
        return escaped;
    }
    /**
     * Replace a given string by a given matcher.
     * @param {PatternMatcher} matcher The pattern matcher.
     * @param {string} str The string to be replaced.
     * @param {string} replacement The new substring to replace each matched part.
     * @returns {string} The replaced string.
     */
    function replaceS(matcher, str, replacement) {
        const chunks = [];
        let index = 0;
        /** @type {RegExpExecArray} */
        let match = null;
        /**
         * @param {string} key The placeholder.
         * @returns {string} The replaced string.
         */
        function replacer(key) {
            switch (key) {
                case "$$":
                    return "$";
                case "$&":
                    return match[0];
                case "$`":
                    return str.slice(0, match.index);
                case "$'":
                    return str.slice(match.index + match[0].length);
                default: {
                    const i = key.slice(1);
                    if (i in match) {
                        return match[i];
                    }
                    return key;
                }
            }
        }
        for (match of matcher.execAll(str)) {
            chunks.push(str.slice(index, match.index));
            chunks.push(replacement.replace(placeholder, replacer));
            index = match.index + match[0].length;
        }
        chunks.push(str.slice(index));
        return chunks.join("");
    }
    /**
     * Replace a given string by a given matcher.
     * @param {PatternMatcher} matcher The pattern matcher.
     * @param {string} str The string to be replaced.
     * @param {(...strs[])=>string} replace The function to replace each matched part.
     * @returns {string} The replaced string.
     */
    function replaceF(matcher, str, replace) {
        const chunks = [];
        let index = 0;
        for (const match of matcher.execAll(str)) {
            chunks.push(str.slice(index, match.index));
            chunks.push(String(replace(...match, match.index, match.input)));
            index = match.index + match[0].length;
        }
        chunks.push(str.slice(index));
        return chunks.join("");
    }
    /**
     * The class to find patterns as considering escape sequences.
     */
    class PatternMatcher {
        /**
         * Initialize this matcher.
         * @param {RegExp} pattern The pattern to match.
         * @param {{escaped:boolean}} options The options.
         */
        constructor(pattern, { escaped = false } = {}) {
            if (!(pattern instanceof RegExp)) {
                throw new TypeError("'pattern' should be a RegExp instance.");
            }
            if (!pattern.flags.includes("g")) {
                throw new Error("'pattern' should contains 'g' flag.");
            }
            internal.set(this, {
                pattern: new RegExp(pattern.source, pattern.flags),
                escaped: Boolean(escaped),
            });
        }
        /**
         * Find the pattern in a given string.
         * @param {string} str The string to find.
         * @returns {IterableIterator<RegExpExecArray>} The iterator which iterate the matched information.
         */
        *execAll(str) {
            const { pattern, escaped } = internal.get(this);
            let match = null;
            let lastIndex = 0;
            pattern.lastIndex = 0;
            while ((match = pattern.exec(str)) != null) {
                if (escaped || !isEscaped(str, match.index)) {
                    lastIndex = pattern.lastIndex;
                    yield match;
                    pattern.lastIndex = lastIndex;
                }
            }
        }
        /**
         * Check whether the pattern is found in a given string.
         * @param {string} str The string to check.
         * @returns {boolean} `true` if the pattern was found in the string.
         */
        test(str) {
            const it = this.execAll(str);
            const ret = it.next();
            return !ret.done;
        }
        /**
         * Replace a given string.
         * @param {string} str The string to be replaced.
         * @param {(string|((...strs:string[])=>string))} replacer The string or function to replace. This is the same as the 2nd argument of `String.prototype.replace`.
         * @returns {string} The replaced string.
         */
        [Symbol.replace](str, replacer) {
            return typeof replacer === "function"
                ? replaceF(this, String(str), replacer)
                : replaceS(this, String(str), String(replacer));
        }
    }
    const IMPORT_TYPE = /^(?:Import|Export(?:All|Default|Named))Declaration$/u;
    const has = Function.call.bind(Object.hasOwnProperty);
    const READ = Symbol("read");
    const CALL = Symbol("call");
    const CONSTRUCT = Symbol("construct");
    const ESM = Symbol("esm");
    const requireCall = { require: { [CALL]: true } };
    /**
     * Check whether a given variable is modified or not.
     * @param {Variable} variable The variable to check.
     * @returns {boolean} `true` if the variable is modified.
     */
    function isModifiedGlobal(variable) {
        return (variable == null ||
            variable.defs.length !== 0 ||
            variable.references.some((r) => r.isWrite()));
    }
    /**
     * Check if the value of a given node is passed through to the parent syntax as-is.
     * For example, `a` and `b` in (`a || b` and `c ? a : b`) are passed through.
     * @param {Node} node A node to check.
     * @returns {boolean} `true` if the node is passed through.
     */
    function isPassThrough(node) {
        const parent = node.parent;
        switch (parent && parent.type) {
            case "ConditionalExpression":
                return parent.consequent === node || parent.alternate === node;
            case "LogicalExpression":
                return true;
            case "SequenceExpression":
                return parent.expressions[parent.expressions.length - 1] === node;
            case "ChainExpression":
                return true;
            default:
                return false;
        }
    }
    /**
     * The reference tracker.
     */
    class ReferenceTracker {
        /**
         * Initialize this tracker.
         * @param {Scope} globalScope The global scope.
         * @param {object} [options] The options.
         * @param {"legacy"|"strict"} [options.mode="strict"] The mode to determine the ImportDeclaration's behavior for CJS modules.
         * @param {string[]} [options.globalObjectNames=["global","globalThis","self","window"]] The variable names for Global Object.
         */
        constructor(globalScope, { mode = "strict", globalObjectNames = ["global", "globalThis", "self", "window"], } = {}) {
            this.variableStack = [];
            this.globalScope = globalScope;
            this.mode = mode;
            this.globalObjectNames = globalObjectNames.slice(0);
        }
        /**
         * Iterate the references of global variables.
         * @param {object} traceMap The trace map.
         * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
         */
        *iterateGlobalReferences(traceMap) {
            for (const key of Object.keys(traceMap)) {
                const nextTraceMap = traceMap[key];
                const path = [key];
                const variable = this.globalScope.set.get(key);
                if (isModifiedGlobal(variable)) {
                    continue;
                }
                yield* this._iterateVariableReferences(variable, path, nextTraceMap, true);
            }
            for (const key of this.globalObjectNames) {
                const path = [];
                const variable = this.globalScope.set.get(key);
                if (isModifiedGlobal(variable)) {
                    continue;
                }
                yield* this._iterateVariableReferences(variable, path, traceMap, false);
            }
        }
        /**
         * Iterate the references of CommonJS modules.
         * @param {object} traceMap The trace map.
         * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
         */
        *iterateCjsReferences(traceMap) {
            for (const { node } of this.iterateGlobalReferences(requireCall)) {
                const key = getStringIfConstant(node.arguments[0]);
                if (key == null || !has(traceMap, key)) {
                    continue;
                }
                const nextTraceMap = traceMap[key];
                const path = [key];
                if (nextTraceMap[READ]) {
                    yield {
                        node,
                        path,
                        type: READ,
                        info: nextTraceMap[READ],
                    };
                }
                yield* this._iteratePropertyReferences(node, path, nextTraceMap);
            }
        }
        /**
         * Iterate the references of ES modules.
         * @param {object} traceMap The trace map.
         * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
         */
        *iterateEsmReferences(traceMap) {
            const programNode = this.globalScope.block;
            for (const node of programNode.body) {
                if (!IMPORT_TYPE.test(node.type) || node.source == null) {
                    continue;
                }
                const moduleId = node.source.value;
                if (!has(traceMap, moduleId)) {
                    continue;
                }
                const nextTraceMap = traceMap[moduleId];
                const path = [moduleId];
                if (nextTraceMap[READ]) {
                    yield { node, path, type: READ, info: nextTraceMap[READ] };
                }
                if (node.type === "ExportAllDeclaration") {
                    for (const key of Object.keys(nextTraceMap)) {
                        const exportTraceMap = nextTraceMap[key];
                        if (exportTraceMap[READ]) {
                            yield {
                                node,
                                path: path.concat(key),
                                type: READ,
                                info: exportTraceMap[READ],
                            };
                        }
                    }
                }
                else {
                    for (const specifier of node.specifiers) {
                        const esm = has(nextTraceMap, ESM);
                        const it = this._iterateImportReferences(specifier, path, esm
                            ? nextTraceMap
                            : this.mode === "legacy"
                                ? { default: nextTraceMap, ...nextTraceMap }
                                : { default: nextTraceMap });
                        if (esm) {
                            yield* it;
                        }
                        else {
                            for (const report of it) {
                                report.path = report.path.filter(exceptDefault);
                                if (report.path.length >= 2 ||
                                    report.type !== READ) {
                                    yield report;
                                }
                            }
                        }
                    }
                }
            }
        }
        /**
         * Iterate the references for a given variable.
         * @param {Variable} variable The variable to iterate that references.
         * @param {string[]} path The current path.
         * @param {object} traceMap The trace map.
         * @param {boolean} shouldReport = The flag to report those references.
         * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
         */
        *_iterateVariableReferences(variable, path, traceMap, shouldReport) {
            if (this.variableStack.includes(variable)) {
                return;
            }
            this.variableStack.push(variable);
            try {
                for (const reference of variable.references) {
                    if (!reference.isRead()) {
                        continue;
                    }
                    const node = reference.identifier;
                    if (shouldReport && traceMap[READ]) {
                        yield { node, path, type: READ, info: traceMap[READ] };
                    }
                    yield* this._iteratePropertyReferences(node, path, traceMap);
                }
            }
            finally {
                this.variableStack.pop();
            }
        }
        /**
         * Iterate the references for a given AST node.
         * @param rootNode The AST node to iterate references.
         * @param {string[]} path The current path.
         * @param {object} traceMap The trace map.
         * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
         */
        //eslint-disable-next-line complexity
        *_iteratePropertyReferences(rootNode, path, traceMap) {
            let node = rootNode;
            while (isPassThrough(node)) {
                node = node.parent;
            }
            const parent = node.parent;
            if (parent.type === "MemberExpression") {
                if (parent.object === node) {
                    const key = getPropertyName(parent);
                    if (key == null || !has(traceMap, key)) {
                        return;
                    }
                    path = path.concat(key); //eslint-disable-line no-param-reassign
                    const nextTraceMap = traceMap[key];
                    if (nextTraceMap[READ]) {
                        yield {
                            node: parent,
                            path,
                            type: READ,
                            info: nextTraceMap[READ],
                        };
                    }
                    yield* this._iteratePropertyReferences(parent, path, nextTraceMap);
                }
                return;
            }
            if (parent.type === "CallExpression") {
                if (parent.callee === node && traceMap[CALL]) {
                    yield { node: parent, path, type: CALL, info: traceMap[CALL] };
                }
                return;
            }
            if (parent.type === "NewExpression") {
                if (parent.callee === node && traceMap[CONSTRUCT]) {
                    yield {
                        node: parent,
                        path,
                        type: CONSTRUCT,
                        info: traceMap[CONSTRUCT],
                    };
                }
                return;
            }
            if (parent.type === "AssignmentExpression") {
                if (parent.right === node) {
                    yield* this._iterateLhsReferences(parent.left, path, traceMap);
                    yield* this._iteratePropertyReferences(parent, path, traceMap);
                }
                return;
            }
            if (parent.type === "AssignmentPattern") {
                if (parent.right === node) {
                    yield* this._iterateLhsReferences(parent.left, path, traceMap);
                }
                return;
            }
            if (parent.type === "VariableDeclarator") {
                if (parent.init === node) {
                    yield* this._iterateLhsReferences(parent.id, path, traceMap);
                }
            }
        }
        /**
         * Iterate the references for a given Pattern node.
         * @param {Node} patternNode The Pattern node to iterate references.
         * @param {string[]} path The current path.
         * @param {object} traceMap The trace map.
         * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
         */
        *_iterateLhsReferences(patternNode, path, traceMap) {
            if (patternNode.type === "Identifier") {
                const variable = findVariable(this.globalScope, patternNode);
                if (variable != null) {
                    yield* this._iterateVariableReferences(variable, path, traceMap, false);
                }
                return;
            }
            if (patternNode.type === "ObjectPattern") {
                for (const property of patternNode.properties) {
                    const key = getPropertyName(property);
                    if (key == null || !has(traceMap, key)) {
                        continue;
                    }
                    const nextPath = path.concat(key);
                    const nextTraceMap = traceMap[key];
                    if (nextTraceMap[READ]) {
                        yield {
                            node: property,
                            path: nextPath,
                            type: READ,
                            info: nextTraceMap[READ],
                        };
                    }
                    yield* this._iterateLhsReferences(property.value, nextPath, nextTraceMap);
                }
                return;
            }
            if (patternNode.type === "AssignmentPattern") {
                yield* this._iterateLhsReferences(patternNode.left, path, traceMap);
            }
        }
        /**
         * Iterate the references for a given ModuleSpecifier node.
         * @param {Node} specifierNode The ModuleSpecifier node to iterate references.
         * @param {string[]} path The current path.
         * @param {object} traceMap The trace map.
         * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
         */
        *_iterateImportReferences(specifierNode, path, traceMap) {
            const type = specifierNode.type;
            if (type === "ImportSpecifier" || type === "ImportDefaultSpecifier") {
                const key = type === "ImportDefaultSpecifier"
                    ? "default"
                    : specifierNode.imported.name;
                if (!has(traceMap, key)) {
                    return;
                }
                path = path.concat(key); //eslint-disable-line no-param-reassign
                const nextTraceMap = traceMap[key];
                if (nextTraceMap[READ]) {
                    yield {
                        node: specifierNode,
                        path,
                        type: READ,
                        info: nextTraceMap[READ],
                    };
                }
                yield* this._iterateVariableReferences(findVariable(this.globalScope, specifierNode.local), path, nextTraceMap, false);
                return;
            }
            if (type === "ImportNamespaceSpecifier") {
                yield* this._iterateVariableReferences(findVariable(this.globalScope, specifierNode.local), path, traceMap, false);
                return;
            }
            if (type === "ExportSpecifier") {
                const key = specifierNode.local.name;
                if (!has(traceMap, key)) {
                    return;
                }
                path = path.concat(key); //eslint-disable-line no-param-reassign
                const nextTraceMap = traceMap[key];
                if (nextTraceMap[READ]) {
                    yield {
                        node: specifierNode,
                        path,
                        type: READ,
                        info: nextTraceMap[READ],
                    };
                }
            }
        }
    }
    ReferenceTracker.READ = READ;
    ReferenceTracker.CALL = CALL;
    ReferenceTracker.CONSTRUCT = CONSTRUCT;
    ReferenceTracker.ESM = ESM;
    /**
     * This is a predicate function for Array#filter.
     * @param {string} name A name part.
     * @param {number} index The index of the name.
     * @returns {boolean} `false` if it's default.
     */
    function exceptDefault(name, index) {
        return !(index === 1 && name === "default");
    }
    var index = {
        CALL,
        CONSTRUCT,
        ESM,
        findVariable,
        getFunctionHeadLocation,
        getFunctionNameWithKind,
        getInnermostScope,
        getPropertyName,
        getStaticValue,
        getStringIfConstant,
        hasSideEffect,
        isArrowToken,
        isClosingBraceToken,
        isClosingBracketToken,
        isClosingParenToken,
        isColonToken,
        isCommaToken,
        isCommentToken,
        isNotArrowToken,
        isNotClosingBraceToken,
        isNotClosingBracketToken,
        isNotClosingParenToken,
        isNotColonToken,
        isNotCommaToken,
        isNotCommentToken,
        isNotOpeningBraceToken,
        isNotOpeningBracketToken,
        isNotOpeningParenToken,
        isNotSemicolonToken,
        isOpeningBraceToken,
        isOpeningBracketToken,
        isOpeningParenToken,
        isParenthesized,
        isSemicolonToken,
        PatternMatcher,
        READ,
        ReferenceTracker,
    };
    exports.CALL = CALL;
    exports.CONSTRUCT = CONSTRUCT;
    exports.ESM = ESM;
    exports.PatternMatcher = PatternMatcher;
    exports.READ = READ;
    exports.ReferenceTracker = ReferenceTracker;
    exports["default"] = index;
    exports.findVariable = findVariable;
    exports.getFunctionHeadLocation = getFunctionHeadLocation;
    exports.getFunctionNameWithKind = getFunctionNameWithKind;
    exports.getInnermostScope = getInnermostScope;
    exports.getPropertyName = getPropertyName;
    exports.getStaticValue = getStaticValue;
    exports.getStringIfConstant = getStringIfConstant;
    exports.hasSideEffect = hasSideEffect;
    exports.isArrowToken = isArrowToken;
    exports.isClosingBraceToken = isClosingBraceToken;
    exports.isClosingBracketToken = isClosingBracketToken;
    exports.isClosingParenToken = isClosingParenToken;
    exports.isColonToken = isColonToken;
    exports.isCommaToken = isCommaToken;
    exports.isCommentToken = isCommentToken;
    exports.isNotArrowToken = isNotArrowToken;
    exports.isNotClosingBraceToken = isNotClosingBraceToken;
    exports.isNotClosingBracketToken = isNotClosingBracketToken;
    exports.isNotClosingParenToken = isNotClosingParenToken;
    exports.isNotColonToken = isNotColonToken;
    exports.isNotCommaToken = isNotCommaToken;
    exports.isNotCommentToken = isNotCommentToken;
    exports.isNotOpeningBraceToken = isNotOpeningBraceToken;
    exports.isNotOpeningBracketToken = isNotOpeningBracketToken;
    exports.isNotOpeningParenToken = isNotOpeningParenToken;
    exports.isNotSemicolonToken = isNotSemicolonToken;
    exports.isOpeningBraceToken = isOpeningBraceToken;
    exports.isOpeningBracketToken = isOpeningBracketToken;
    exports.isOpeningParenToken = isOpeningParenToken;
    exports.isParenthesized = isParenthesized;
    exports.isSemicolonToken = isSemicolonToken;
    
},
/* eslint/lib/source-code/token-store/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Object to handle access and retrieval of tokens.
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const assert = require("assert");
    const { isCommentToken } = require(316) /* @eslint-community/eslint-utils */;
    const cursors = require(318) /* ./cursors */;
    const ForwardTokenCursor = require(326) /* ./forward-token-cursor */;
    const PaddedTokenCursor = require(329) /* ./padded-token-cursor */;
    const utils = require(321) /* ./utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const TOKENS = Symbol("tokens");
    const COMMENTS = Symbol("comments");
    const INDEX_MAP = Symbol("indexMap");
    /**
     * Creates the map from locations to indices in `tokens`.
     *
     * The first/last location of tokens is mapped to the index of the token.
     * The first/last location of comments is mapped to the index of the next token of each comment.
     * @param {Token[]} tokens The array of tokens.
     * @param {Comment[]} comments The array of comments.
     * @returns {Object} The map from locations to indices in `tokens`.
     * @private
     */
    function createIndexMap(tokens, comments) {
        const map = Object.create(null);
        let tokenIndex = 0;
        let commentIndex = 0;
        let nextStart = 0;
        let range = null;
        while (tokenIndex < tokens.length || commentIndex < comments.length) {
            nextStart = (commentIndex < comments.length) ? comments[commentIndex].range[0] : Number.MAX_SAFE_INTEGER;
            while (tokenIndex < tokens.length && (range = tokens[tokenIndex].range)[0] < nextStart) {
                map[range[0]] = tokenIndex;
                map[range[1] - 1] = tokenIndex;
                tokenIndex += 1;
            }
            nextStart = (tokenIndex < tokens.length) ? tokens[tokenIndex].range[0] : Number.MAX_SAFE_INTEGER;
            while (commentIndex < comments.length && (range = comments[commentIndex].range)[0] < nextStart) {
                map[range[0]] = tokenIndex;
                map[range[1] - 1] = tokenIndex;
                commentIndex += 1;
            }
        }
        return map;
    }
    /**
     * Creates the cursor iterates tokens with options.
     * @param {CursorFactory} factory The cursor factory to initialize cursor.
     * @param {Token[]} tokens The array of tokens.
     * @param {Comment[]} comments The array of comments.
     * @param {Object} indexMap The map from locations to indices in `tokens`.
     * @param {number} startLoc The start location of the iteration range.
     * @param {number} endLoc The end location of the iteration range.
     * @param {number|Function|Object} [opts=0] The option object. If this is a number then it's `opts.skip`. If this is a function then it's `opts.filter`.
     * @param {boolean} [opts.includeComments=false] The flag to iterate comments as well.
     * @param {Function|null} [opts.filter=null] The predicate function to choose tokens.
     * @param {number} [opts.skip=0] The count of tokens the cursor skips.
     * @returns {Cursor} The created cursor.
     * @private
     */
    function createCursorWithSkip(factory, tokens, comments, indexMap, startLoc, endLoc, opts) {
        let includeComments = false;
        let skip = 0;
        let filter = null;
        if (typeof opts === "number") {
            skip = opts | 0;
        }
        else if (typeof opts === "function") {
            filter = opts;
        }
        else if (opts) {
            includeComments = !!opts.includeComments;
            skip = opts.skip | 0;
            filter = opts.filter || null;
        }
        assert(skip >= 0, "options.skip should be zero or a positive integer.");
        assert(!filter || typeof filter === "function", "options.filter should be a function.");
        return factory.createCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments, filter, skip, -1);
    }
    /**
     * Creates the cursor iterates tokens with options.
     * @param {CursorFactory} factory The cursor factory to initialize cursor.
     * @param {Token[]} tokens The array of tokens.
     * @param {Comment[]} comments The array of comments.
     * @param {Object} indexMap The map from locations to indices in `tokens`.
     * @param {number} startLoc The start location of the iteration range.
     * @param {number} endLoc The end location of the iteration range.
     * @param {number|Function|Object} [opts=0] The option object. If this is a number then it's `opts.count`. If this is a function then it's `opts.filter`.
     * @param {boolean} [opts.includeComments] The flag to iterate comments as well.
     * @param {Function|null} [opts.filter=null] The predicate function to choose tokens.
     * @param {number} [opts.count=0] The maximum count of tokens the cursor iterates. Zero is no iteration for backward compatibility.
     * @returns {Cursor} The created cursor.
     * @private
     */
    function createCursorWithCount(factory, tokens, comments, indexMap, startLoc, endLoc, opts) {
        let includeComments = false;
        let count = 0;
        let countExists = false;
        let filter = null;
        if (typeof opts === "number") {
            count = opts | 0;
            countExists = true;
        }
        else if (typeof opts === "function") {
            filter = opts;
        }
        else if (opts) {
            includeComments = !!opts.includeComments;
            count = opts.count | 0;
            countExists = typeof opts.count === "number";
            filter = opts.filter || null;
        }
        assert(count >= 0, "options.count should be zero or a positive integer.");
        assert(!filter || typeof filter === "function", "options.filter should be a function.");
        return factory.createCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments, filter, 0, countExists ? count : -1);
    }
    /**
     * Creates the cursor iterates tokens with options.
     * This is overload function of the below.
     * @param {Token[]} tokens The array of tokens.
     * @param {Comment[]} comments The array of comments.
     * @param {Object} indexMap The map from locations to indices in `tokens`.
     * @param {number} startLoc The start location of the iteration range.
     * @param {number} endLoc The end location of the iteration range.
     * @param {Function|Object} opts The option object. If this is a function then it's `opts.filter`.
     * @param {boolean} [opts.includeComments] The flag to iterate comments as well.
     * @param {Function|null} [opts.filter=null] The predicate function to choose tokens.
     * @param {number} [opts.count=0] The maximum count of tokens the cursor iterates. Zero is no iteration for backward compatibility.
     * @returns {Cursor} The created cursor.
     * @private
     */
    /**
     * Creates the cursor iterates tokens with options.
     * @param {Token[]} tokens The array of tokens.
     * @param {Comment[]} comments The array of comments.
     * @param {Object} indexMap The map from locations to indices in `tokens`.
     * @param {number} startLoc The start location of the iteration range.
     * @param {number} endLoc The end location of the iteration range.
     * @param {number} [beforeCount=0] The number of tokens before the node to retrieve.
     * @param {boolean} [afterCount=0] The number of tokens after the node to retrieve.
     * @returns {Cursor} The created cursor.
     * @private
     */
    function createCursorWithPadding(tokens, comments, indexMap, startLoc, endLoc, beforeCount, afterCount) {
        if (typeof beforeCount === "undefined" && typeof afterCount === "undefined") {
            return new ForwardTokenCursor(tokens, comments, indexMap, startLoc, endLoc);
        }
        if (typeof beforeCount === "number" || typeof beforeCount === "undefined") {
            return new PaddedTokenCursor(tokens, comments, indexMap, startLoc, endLoc, beforeCount | 0, afterCount | 0);
        }
        return createCursorWithCount(cursors.forward, tokens, comments, indexMap, startLoc, endLoc, beforeCount);
    }
    /**
     * Gets comment tokens that are adjacent to the current cursor position.
     * @param {Cursor} cursor A cursor instance.
     * @returns {Array} An array of comment tokens adjacent to the current cursor position.
     * @private
     */
    function getAdjacentCommentTokensFromCursor(cursor) {
        const tokens = [];
        let currentToken = cursor.getOneToken();
        while (currentToken && isCommentToken(currentToken)) {
            tokens.push(currentToken);
            currentToken = cursor.getOneToken();
        }
        return tokens;
    }
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The token store.
     *
     * This class provides methods to get tokens by locations as fast as possible.
     * The methods are a part of public API, so we should be careful if it changes this class.
     *
     * People can get tokens in O(1) by the hash map which is mapping from the location of tokens/comments to tokens.
     * Also people can get a mix of tokens and comments in O(log k), the k is the number of comments.
     * Assuming that comments to be much fewer than tokens, this does not make hash map from token's locations to comments to reduce memory cost.
     * This uses binary-searching instead for comments.
     */
    module.exports = class TokenStore {
        /**
         * Initializes this token store.
         * @param {Token[]} tokens The array of tokens.
         * @param {Comment[]} comments The array of comments.
         */
        constructor(tokens, comments) {
            this[TOKENS] = tokens;
            this[COMMENTS] = comments;
            this[INDEX_MAP] = createIndexMap(tokens, comments);
        }
        //--------------------------------------------------------------------------
        // Gets single token.
        //--------------------------------------------------------------------------
        /**
         * Gets the token starting at the specified index.
         * @param {number} offset Index of the start of the token's range.
         * @param {Object} [options=0] The option object.
         * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
         * @returns {Token|null} The token starting at index, or null if no such token.
         */
        getTokenByRangeStart(offset, options) {
            const includeComments = options && options.includeComments;
            const token = cursors.forward.createBaseCursor(this[TOKENS], this[COMMENTS], this[INDEX_MAP], offset, -1, includeComments).getOneToken();
            if (token && token.range[0] === offset) {
                return token;
            }
            return null;
        }
        /**
         * Gets the first token of the given node.
         * @param {ASTNode} node The AST node.
         * @param {number|Function|Object} [options=0] The option object. If this is a number then it's `options.skip`. If this is a function then it's `options.filter`.
         * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
         * @param {Function|null} [options.filter=null] The predicate function to choose tokens.
         * @param {number} [options.skip=0] The count of tokens the cursor skips.
         * @returns {Token|null} An object representing the token.
         */
        getFirstToken(node, options) {
            return createCursorWithSkip(cursors.forward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], node.range[0], node.range[1], options).getOneToken();
        }
        /**
         * Gets the last token of the given node.
         * @param {ASTNode} node The AST node.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
         * @returns {Token|null} An object representing the token.
         */
        getLastToken(node, options) {
            return createCursorWithSkip(cursors.backward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], node.range[0], node.range[1], options).getOneToken();
        }
        /**
         * Gets the token that precedes a given node or token.
         * @param {ASTNode|Token|Comment} node The AST node or token.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
         * @returns {Token|null} An object representing the token.
         */
        getTokenBefore(node, options) {
            return createCursorWithSkip(cursors.backward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], -1, node.range[0], options).getOneToken();
        }
        /**
         * Gets the token that follows a given node or token.
         * @param {ASTNode|Token|Comment} node The AST node or token.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
         * @returns {Token|null} An object representing the token.
         */
        getTokenAfter(node, options) {
            return createCursorWithSkip(cursors.forward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], node.range[1], -1, options).getOneToken();
        }
        /**
         * Gets the first token between two non-overlapping nodes.
         * @param {ASTNode|Token|Comment} left Node before the desired token range.
         * @param {ASTNode|Token|Comment} right Node after the desired token range.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
         * @returns {Token|null} An object representing the token.
         */
        getFirstTokenBetween(left, right, options) {
            return createCursorWithSkip(cursors.forward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], left.range[1], right.range[0], options).getOneToken();
        }
        /**
         * Gets the last token between two non-overlapping nodes.
         * @param {ASTNode|Token|Comment} left Node before the desired token range.
         * @param {ASTNode|Token|Comment} right Node after the desired token range.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
         * @returns {Token|null} An object representing the token.
         */
        getLastTokenBetween(left, right, options) {
            return createCursorWithSkip(cursors.backward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], left.range[1], right.range[0], options).getOneToken();
        }
        /**
         * Gets the token that precedes a given node or token in the token stream.
         * This is defined for backward compatibility. Use `includeComments` option instead.
         * TODO: We have a plan to remove this in a future major version.
         * @param {ASTNode|Token|Comment} node The AST node or token.
         * @param {number} [skip=0] A number of tokens to skip.
         * @returns {Token|null} An object representing the token.
         * @deprecated
         */
        getTokenOrCommentBefore(node, skip) {
            return this.getTokenBefore(node, { includeComments: true, skip });
        }
        /**
         * Gets the token that follows a given node or token in the token stream.
         * This is defined for backward compatibility. Use `includeComments` option instead.
         * TODO: We have a plan to remove this in a future major version.
         * @param {ASTNode|Token|Comment} node The AST node or token.
         * @param {number} [skip=0] A number of tokens to skip.
         * @returns {Token|null} An object representing the token.
         * @deprecated
         */
        getTokenOrCommentAfter(node, skip) {
            return this.getTokenAfter(node, { includeComments: true, skip });
        }
        //--------------------------------------------------------------------------
        // Gets multiple tokens.
        //--------------------------------------------------------------------------
        /**
         * Gets the first `count` tokens of the given node.
         * @param {ASTNode} node The AST node.
         * @param {number|Function|Object} [options=0] The option object. If this is a number then it's `options.count`. If this is a function then it's `options.filter`.
         * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
         * @param {Function|null} [options.filter=null] The predicate function to choose tokens.
         * @param {number} [options.count=0] The maximum count of tokens the cursor iterates.
         * @returns {Token[]} Tokens.
         */
        getFirstTokens(node, options) {
            return createCursorWithCount(cursors.forward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], node.range[0], node.range[1], options).getAllTokens();
        }
        /**
         * Gets the last `count` tokens of the given node.
         * @param {ASTNode} node The AST node.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
         * @returns {Token[]} Tokens.
         */
        getLastTokens(node, options) {
            return createCursorWithCount(cursors.backward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], node.range[0], node.range[1], options).getAllTokens().reverse();
        }
        /**
         * Gets the `count` tokens that precedes a given node or token.
         * @param {ASTNode|Token|Comment} node The AST node or token.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
         * @returns {Token[]} Tokens.
         */
        getTokensBefore(node, options) {
            return createCursorWithCount(cursors.backward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], -1, node.range[0], options).getAllTokens().reverse();
        }
        /**
         * Gets the `count` tokens that follows a given node or token.
         * @param {ASTNode|Token|Comment} node The AST node or token.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
         * @returns {Token[]} Tokens.
         */
        getTokensAfter(node, options) {
            return createCursorWithCount(cursors.forward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], node.range[1], -1, options).getAllTokens();
        }
        /**
         * Gets the first `count` tokens between two non-overlapping nodes.
         * @param {ASTNode|Token|Comment} left Node before the desired token range.
         * @param {ASTNode|Token|Comment} right Node after the desired token range.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
         * @returns {Token[]} Tokens between left and right.
         */
        getFirstTokensBetween(left, right, options) {
            return createCursorWithCount(cursors.forward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], left.range[1], right.range[0], options).getAllTokens();
        }
        /**
         * Gets the last `count` tokens between two non-overlapping nodes.
         * @param {ASTNode|Token|Comment} left Node before the desired token range.
         * @param {ASTNode|Token|Comment} right Node after the desired token range.
         * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
         * @returns {Token[]} Tokens between left and right.
         */
        getLastTokensBetween(left, right, options) {
            return createCursorWithCount(cursors.backward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], left.range[1], right.range[0], options).getAllTokens().reverse();
        }
        /**
         * Gets all tokens that are related to the given node.
         * @param {ASTNode} node The AST node.
         * @param {Function|Object} options The option object. If this is a function then it's `options.filter`.
         * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
         * @param {Function|null} [options.filter=null] The predicate function to choose tokens.
         * @param {number} [options.count=0] The maximum count of tokens the cursor iterates.
         * @returns {Token[]} Array of objects representing tokens.
         */
        /**
         * Gets all tokens that are related to the given node.
         * @param {ASTNode} node The AST node.
         * @param {int} [beforeCount=0] The number of tokens before the node to retrieve.
         * @param {int} [afterCount=0] The number of tokens after the node to retrieve.
         * @returns {Token[]} Array of objects representing tokens.
         */
        getTokens(node, beforeCount, afterCount) {
            return createCursorWithPadding(this[TOKENS], this[COMMENTS], this[INDEX_MAP], node.range[0], node.range[1], beforeCount, afterCount).getAllTokens();
        }
        /**
         * Gets all of the tokens between two non-overlapping nodes.
         * @param {ASTNode|Token|Comment} left Node before the desired token range.
         * @param {ASTNode|Token|Comment} right Node after the desired token range.
         * @param {Function|Object} options The option object. If this is a function then it's `options.filter`.
         * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
         * @param {Function|null} [options.filter=null] The predicate function to choose tokens.
         * @param {number} [options.count=0] The maximum count of tokens the cursor iterates.
         * @returns {Token[]} Tokens between left and right.
         */
        /**
         * Gets all of the tokens between two non-overlapping nodes.
         * @param {ASTNode|Token|Comment} left Node before the desired token range.
         * @param {ASTNode|Token|Comment} right Node after the desired token range.
         * @param {int} [padding=0] Number of extra tokens on either side of center.
         * @returns {Token[]} Tokens between left and right.
         */
        getTokensBetween(left, right, padding) {
            return createCursorWithPadding(this[TOKENS], this[COMMENTS], this[INDEX_MAP], left.range[1], right.range[0], padding, padding).getAllTokens();
        }
        //--------------------------------------------------------------------------
        // Others.
        //--------------------------------------------------------------------------
        /**
         * Checks whether any comments exist or not between the given 2 nodes.
         * @param {ASTNode} left The node to check.
         * @param {ASTNode} right The node to check.
         * @returns {boolean} `true` if one or more comments exist.
         */
        commentsExistBetween(left, right) {
            const index = utils.search(this[COMMENTS], left.range[1]);
            return (index < this[COMMENTS].length &&
                this[COMMENTS][index].range[1] <= right.range[0]);
        }
        /**
         * Gets all comment tokens directly before the given node or token.
         * @param {ASTNode|token} nodeOrToken The AST node or token to check for adjacent comment tokens.
         * @returns {Array} An array of comments in occurrence order.
         */
        getCommentsBefore(nodeOrToken) {
            const cursor = createCursorWithCount(cursors.backward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], -1, nodeOrToken.range[0], { includeComments: true });
            return getAdjacentCommentTokensFromCursor(cursor).reverse();
        }
        /**
         * Gets all comment tokens directly after the given node or token.
         * @param {ASTNode|token} nodeOrToken The AST node or token to check for adjacent comment tokens.
         * @returns {Array} An array of comments in occurrence order.
         */
        getCommentsAfter(nodeOrToken) {
            const cursor = createCursorWithCount(cursors.forward, this[TOKENS], this[COMMENTS], this[INDEX_MAP], nodeOrToken.range[1], -1, { includeComments: true });
            return getAdjacentCommentTokensFromCursor(cursor);
        }
        /**
         * Gets all comment tokens inside the given node.
         * @param {ASTNode} node The AST node to get the comments for.
         * @returns {Array} An array of comments in occurrence order.
         */
        getCommentsInside(node) {
            return this.getTokens(node, {
                includeComments: true,
                filter: isCommentToken
            });
        }
    };
},
/* eslint/lib/source-code/token-store/cursors.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define 2 token factories; forward and backward.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const BackwardTokenCommentCursor = require(319) /* ./backward-token-comment-cursor */;
    const BackwardTokenCursor = require(322) /* ./backward-token-cursor */;
    const FilterCursor = require(323) /* ./filter-cursor */;
    const ForwardTokenCommentCursor = require(325) /* ./forward-token-comment-cursor */;
    const ForwardTokenCursor = require(326) /* ./forward-token-cursor */;
    const LimitCursor = require(327) /* ./limit-cursor */;
    const SkipCursor = require(328) /* ./skip-cursor */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * The cursor factory.
     * @private
     */
    class CursorFactory {
        /**
         * Initializes this cursor.
         * @param {Function} TokenCursor The class of the cursor which iterates tokens only.
         * @param {Function} TokenCommentCursor The class of the cursor which iterates the mix of tokens and comments.
         */
        constructor(TokenCursor, TokenCommentCursor) {
            this.TokenCursor = TokenCursor;
            this.TokenCommentCursor = TokenCommentCursor;
        }
        /**
         * Creates a base cursor instance that can be decorated by createCursor.
         * @param {Token[]} tokens The array of tokens.
         * @param {Comment[]} comments The array of comments.
         * @param {Object} indexMap The map from locations to indices in `tokens`.
         * @param {number} startLoc The start location of the iteration range.
         * @param {number} endLoc The end location of the iteration range.
         * @param {boolean} includeComments The flag to iterate comments as well.
         * @returns {Cursor} The created base cursor.
         */
        createBaseCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments) {
            const Cursor = includeComments ? this.TokenCommentCursor : this.TokenCursor;
            return new Cursor(tokens, comments, indexMap, startLoc, endLoc);
        }
        /**
         * Creates a cursor that iterates tokens with normalized options.
         * @param {Token[]} tokens The array of tokens.
         * @param {Comment[]} comments The array of comments.
         * @param {Object} indexMap The map from locations to indices in `tokens`.
         * @param {number} startLoc The start location of the iteration range.
         * @param {number} endLoc The end location of the iteration range.
         * @param {boolean} includeComments The flag to iterate comments as well.
         * @param {Function|null} filter The predicate function to choose tokens.
         * @param {number} skip The count of tokens the cursor skips.
         * @param {number} count The maximum count of tokens the cursor iterates. Zero is no iteration for backward compatibility.
         * @returns {Cursor} The created cursor.
         */
        createCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments, filter, skip, count) {
            let cursor = this.createBaseCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments);
            if (filter) {
                cursor = new FilterCursor(cursor, filter);
            }
            if (skip >= 1) {
                cursor = new SkipCursor(cursor, skip);
            }
            if (count >= 0) {
                cursor = new LimitCursor(cursor, count);
            }
            return cursor;
        }
    }
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    exports.forward = new CursorFactory(ForwardTokenCursor, ForwardTokenCommentCursor);
    exports.backward = new CursorFactory(BackwardTokenCursor, BackwardTokenCommentCursor);
},
/* eslint/lib/source-code/token-store/backward-token-comment-cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the cursor which iterates tokens and comments in reverse.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const Cursor = require(320) /* ./cursor */;
    const utils = require(321) /* ./utils */;
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The cursor which iterates tokens and comments in reverse.
     */
    module.exports = class BackwardTokenCommentCursor extends Cursor {
        /**
         * Initializes this cursor.
         * @param {Token[]} tokens The array of tokens.
         * @param {Comment[]} comments The array of comments.
         * @param {Object} indexMap The map from locations to indices in `tokens`.
         * @param {number} startLoc The start location of the iteration range.
         * @param {number} endLoc The end location of the iteration range.
         */
        constructor(tokens, comments, indexMap, startLoc, endLoc) {
            super();
            this.tokens = tokens;
            this.comments = comments;
            this.tokenIndex = utils.getLastIndex(tokens, indexMap, endLoc);
            this.commentIndex = utils.search(comments, endLoc) - 1;
            this.border = startLoc;
        }
        /** @inheritdoc */
        moveNext() {
            const token = (this.tokenIndex >= 0) ? this.tokens[this.tokenIndex] : null;
            const comment = (this.commentIndex >= 0) ? this.comments[this.commentIndex] : null;
            if (token && (!comment || token.range[1] > comment.range[1])) {
                this.current = token;
                this.tokenIndex -= 1;
            }
            else if (comment) {
                this.current = comment;
                this.commentIndex -= 1;
            }
            else {
                this.current = null;
            }
            return Boolean(this.current) && (this.border === -1 || this.current.range[0] >= this.border);
        }
    };
},
/* eslint/lib/source-code/token-store/cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the abstract class about cursors which iterate tokens.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The abstract class about cursors which iterate tokens.
     *
     * This class has 2 abstract methods.
     *
     * - `current: Token | Comment | null` ... The current token.
     * - `moveNext(): boolean` ... Moves this cursor to the next token. If the next token didn't exist, it returns `false`.
     *
     * This is similar to ES2015 Iterators.
     * However, Iterators were slow (at 2017-01), so I created this class as similar to C# IEnumerable.
     *
     * There are the following known sub classes.
     *
     * - ForwardTokenCursor .......... The cursor which iterates tokens only.
     * - BackwardTokenCursor ......... The cursor which iterates tokens only in reverse.
     * - ForwardTokenCommentCursor ... The cursor which iterates tokens and comments.
     * - BackwardTokenCommentCursor .. The cursor which iterates tokens and comments in reverse.
     * - DecorativeCursor
     *     - FilterCursor ............ The cursor which ignores the specified tokens.
     *     - SkipCursor .............. The cursor which ignores the first few tokens.
     *     - LimitCursor ............. The cursor which limits the count of tokens.
     *
     */
    module.exports = class Cursor {
        /**
         * Initializes this cursor.
         */
        constructor() {
            this.current = null;
        }
        /**
         * Gets the first token.
         * This consumes this cursor.
         * @returns {Token|Comment} The first token or null.
         */
        getOneToken() {
            return this.moveNext() ? this.current : null;
        }
        /**
         * Gets the first tokens.
         * This consumes this cursor.
         * @returns {(Token|Comment)[]} All tokens.
         */
        getAllTokens() {
            const tokens = [];
            while (this.moveNext()) {
                tokens.push(this.current);
            }
            return tokens;
        }
        /**
         * Moves this cursor to the next token.
         * @returns {boolean} `true` if the next token exists.
         * @abstract
         */
        /* c8 ignore next */
        moveNext() {
            throw new Error("Not implemented.");
        }
    };
},
/* eslint/lib/source-code/token-store/utils.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define utility functions for token store.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Gets `token.range[0]` from the given token.
     * @param {Node|Token|Comment} token The token to get.
     * @returns {number} The start location.
     * @private
     */
    function getStartLocation(token) {
        return token.range[0];
    }
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * Finds the index of the first token which is after the given location.
     * If it was not found, this returns `tokens.length`.
     * @param {(Token|Comment)[]} tokens It searches the token in this list.
     * @param {number} location The location to search.
     * @returns {number} The found index or `tokens.length`.
     */
    exports.search = function search(tokens, location) {
        const index = tokens.findIndex(el => location <= getStartLocation(el));
        return index === -1 ? tokens.length : index;
    };
    /**
     * Gets the index of the `startLoc` in `tokens`.
     * `startLoc` can be the value of `node.range[1]`, so this checks about `startLoc - 1` as well.
     * @param {(Token|Comment)[]} tokens The tokens to find an index.
     * @param {Object} indexMap The map from locations to indices.
     * @param {number} startLoc The location to get an index.
     * @returns {number} The index.
     */
    exports.getFirstIndex = function getFirstIndex(tokens, indexMap, startLoc) {
        if (startLoc in indexMap) {
            return indexMap[startLoc];
        }
        if ((startLoc - 1) in indexMap) {
            const index = indexMap[startLoc - 1];
            const token = (index >= 0 && index < tokens.length) ? tokens[index] : null;
            /*
             * For the map of "comment's location -> token's index", it points the next token of a comment.
             * In that case, +1 is unnecessary.
             */
            if (token && token.range[0] >= startLoc) {
                return index;
            }
            return index + 1;
        }
        return 0;
    };
    /**
     * Gets the index of the `endLoc` in `tokens`.
     * The information of end locations are recorded at `endLoc - 1` in `indexMap`, so this checks about `endLoc - 1` as well.
     * @param {(Token|Comment)[]} tokens The tokens to find an index.
     * @param {Object} indexMap The map from locations to indices.
     * @param {number} endLoc The location to get an index.
     * @returns {number} The index.
     */
    exports.getLastIndex = function getLastIndex(tokens, indexMap, endLoc) {
        if (endLoc in indexMap) {
            return indexMap[endLoc] - 1;
        }
        if ((endLoc - 1) in indexMap) {
            const index = indexMap[endLoc - 1];
            const token = (index >= 0 && index < tokens.length) ? tokens[index] : null;
            /*
             * For the map of "comment's location -> token's index", it points the next token of a comment.
             * In that case, -1 is necessary.
             */
            if (token && token.range[1] > endLoc) {
                return index - 1;
            }
            return index;
        }
        return tokens.length - 1;
    };
},
/* eslint/lib/source-code/token-store/backward-token-cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the cursor which iterates tokens only in reverse.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const Cursor = require(320) /* ./cursor */;
    const utils = require(321) /* ./utils */;
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The cursor which iterates tokens only in reverse.
     */
    module.exports = class BackwardTokenCursor extends Cursor {
        /**
         * Initializes this cursor.
         * @param {Token[]} tokens The array of tokens.
         * @param {Comment[]} comments The array of comments.
         * @param {Object} indexMap The map from locations to indices in `tokens`.
         * @param {number} startLoc The start location of the iteration range.
         * @param {number} endLoc The end location of the iteration range.
         */
        constructor(tokens, comments, indexMap, startLoc, endLoc) {
            super();
            this.tokens = tokens;
            this.index = utils.getLastIndex(tokens, indexMap, endLoc);
            this.indexEnd = utils.getFirstIndex(tokens, indexMap, startLoc);
        }
        /** @inheritdoc */
        moveNext() {
            if (this.index >= this.indexEnd) {
                this.current = this.tokens[this.index];
                this.index -= 1;
                return true;
            }
            return false;
        }
        /*
         *
         * Shorthand for performance.
         *
         */
        /** @inheritdoc */
        getOneToken() {
            return (this.index >= this.indexEnd) ? this.tokens[this.index] : null;
        }
    };
},
/* eslint/lib/source-code/token-store/filter-cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the cursor which ignores specified tokens.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const DecorativeCursor = require(324) /* ./decorative-cursor */;
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The decorative cursor which ignores specified tokens.
     */
    module.exports = class FilterCursor extends DecorativeCursor {
        /**
         * Initializes this cursor.
         * @param {Cursor} cursor The cursor to be decorated.
         * @param {Function} predicate The predicate function to decide tokens this cursor iterates.
         */
        constructor(cursor, predicate) {
            super(cursor);
            this.predicate = predicate;
        }
        /** @inheritdoc */
        moveNext() {
            const predicate = this.predicate;
            while (super.moveNext()) {
                if (predicate(this.current)) {
                    return true;
                }
            }
            return false;
        }
    };
},
/* eslint/lib/source-code/token-store/decorative-cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the abstract class about cursors which manipulate another cursor.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const Cursor = require(320) /* ./cursor */;
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The abstract class about cursors which manipulate another cursor.
     */
    module.exports = class DecorativeCursor extends Cursor {
        /**
         * Initializes this cursor.
         * @param {Cursor} cursor The cursor to be decorated.
         */
        constructor(cursor) {
            super();
            this.cursor = cursor;
        }
        /** @inheritdoc */
        moveNext() {
            const retv = this.cursor.moveNext();
            this.current = this.cursor.current;
            return retv;
        }
    };
},
/* eslint/lib/source-code/token-store/forward-token-comment-cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the cursor which iterates tokens and comments.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const Cursor = require(320) /* ./cursor */;
    const utils = require(321) /* ./utils */;
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The cursor which iterates tokens and comments.
     */
    module.exports = class ForwardTokenCommentCursor extends Cursor {
        /**
         * Initializes this cursor.
         * @param {Token[]} tokens The array of tokens.
         * @param {Comment[]} comments The array of comments.
         * @param {Object} indexMap The map from locations to indices in `tokens`.
         * @param {number} startLoc The start location of the iteration range.
         * @param {number} endLoc The end location of the iteration range.
         */
        constructor(tokens, comments, indexMap, startLoc, endLoc) {
            super();
            this.tokens = tokens;
            this.comments = comments;
            this.tokenIndex = utils.getFirstIndex(tokens, indexMap, startLoc);
            this.commentIndex = utils.search(comments, startLoc);
            this.border = endLoc;
        }
        /** @inheritdoc */
        moveNext() {
            const token = (this.tokenIndex < this.tokens.length) ? this.tokens[this.tokenIndex] : null;
            const comment = (this.commentIndex < this.comments.length) ? this.comments[this.commentIndex] : null;
            if (token && (!comment || token.range[0] < comment.range[0])) {
                this.current = token;
                this.tokenIndex += 1;
            }
            else if (comment) {
                this.current = comment;
                this.commentIndex += 1;
            }
            else {
                this.current = null;
            }
            return Boolean(this.current) && (this.border === -1 || this.current.range[1] <= this.border);
        }
    };
},
/* eslint/lib/source-code/token-store/forward-token-cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the cursor which iterates tokens only.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const Cursor = require(320) /* ./cursor */;
    const utils = require(321) /* ./utils */;
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The cursor which iterates tokens only.
     */
    module.exports = class ForwardTokenCursor extends Cursor {
        /**
         * Initializes this cursor.
         * @param {Token[]} tokens The array of tokens.
         * @param {Comment[]} comments The array of comments.
         * @param {Object} indexMap The map from locations to indices in `tokens`.
         * @param {number} startLoc The start location of the iteration range.
         * @param {number} endLoc The end location of the iteration range.
         */
        constructor(tokens, comments, indexMap, startLoc, endLoc) {
            super();
            this.tokens = tokens;
            this.index = utils.getFirstIndex(tokens, indexMap, startLoc);
            this.indexEnd = utils.getLastIndex(tokens, indexMap, endLoc);
        }
        /** @inheritdoc */
        moveNext() {
            if (this.index <= this.indexEnd) {
                this.current = this.tokens[this.index];
                this.index += 1;
                return true;
            }
            return false;
        }
        /*
         *
         * Shorthand for performance.
         *
         */
        /** @inheritdoc */
        getOneToken() {
            return (this.index <= this.indexEnd) ? this.tokens[this.index] : null;
        }
        /** @inheritdoc */
        getAllTokens() {
            return this.tokens.slice(this.index, this.indexEnd + 1);
        }
    };
},
/* eslint/lib/source-code/token-store/limit-cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the cursor which limits the number of tokens.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const DecorativeCursor = require(324) /* ./decorative-cursor */;
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The decorative cursor which limits the number of tokens.
     */
    module.exports = class LimitCursor extends DecorativeCursor {
        /**
         * Initializes this cursor.
         * @param {Cursor} cursor The cursor to be decorated.
         * @param {number} count The count of tokens this cursor iterates.
         */
        constructor(cursor, count) {
            super(cursor);
            this.count = count;
        }
        /** @inheritdoc */
        moveNext() {
            if (this.count > 0) {
                this.count -= 1;
                return super.moveNext();
            }
            return false;
        }
    };
},
/* eslint/lib/source-code/token-store/skip-cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the cursor which ignores the first few tokens.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const DecorativeCursor = require(324) /* ./decorative-cursor */;
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The decorative cursor which ignores the first few tokens.
     */
    module.exports = class SkipCursor extends DecorativeCursor {
        /**
         * Initializes this cursor.
         * @param {Cursor} cursor The cursor to be decorated.
         * @param {number} count The count of tokens this cursor skips.
         */
        constructor(cursor, count) {
            super(cursor);
            this.count = count;
        }
        /** @inheritdoc */
        moveNext() {
            while (this.count > 0) {
                this.count -= 1;
                if (!super.moveNext()) {
                    return false;
                }
            }
            return super.moveNext();
        }
    };
},
/* eslint/lib/source-code/token-store/padded-token-cursor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Define the cursor which iterates tokens only, with inflated range.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const ForwardTokenCursor = require(326) /* ./forward-token-cursor */;
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The cursor which iterates tokens only, with inflated range.
     * This is for the backward compatibility of padding options.
     */
    module.exports = class PaddedTokenCursor extends ForwardTokenCursor {
        /**
         * Initializes this cursor.
         * @param {Token[]} tokens The array of tokens.
         * @param {Comment[]} comments The array of comments.
         * @param {Object} indexMap The map from locations to indices in `tokens`.
         * @param {number} startLoc The start location of the iteration range.
         * @param {number} endLoc The end location of the iteration range.
         * @param {number} beforeCount The number of tokens this cursor iterates before start.
         * @param {number} afterCount The number of tokens this cursor iterates after end.
         */
        constructor(tokens, comments, indexMap, startLoc, endLoc, beforeCount, afterCount) {
            super(tokens, comments, indexMap, startLoc, endLoc);
            this.index = Math.max(0, this.index - beforeCount);
            this.indexEnd = Math.min(tokens.length - 1, this.indexEnd + afterCount);
        }
    };
},
/* eslint/lib/linter/code-path-analysis/code-path-analyzer.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A class of the code path analyzer.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const assert = require("assert"), { breakableTypePattern } = require(309) /* ../../shared/ast-utils */, CodePath = require(331) /* ./code-path */, CodePathSegment = require(333) /* ./code-path-segment */, IdGenerator = require(336) /* ./id-generator */, debug = require(334) /* ./debug-helpers */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a given node is a `case` node (not `default` node).
     * @param {ASTNode} node A `SwitchCase` node to check.
     * @returns {boolean} `true` if the node is a `case` node (not `default` node).
     */
    function isCaseNode(node) {
        return Boolean(node.test);
    }
    /**
     * Checks if a given node appears as the value of a PropertyDefinition node.
     * @param {ASTNode} node THe node to check.
     * @returns {boolean} `true` if the node is a PropertyDefinition value,
     *      false if not.
     */
    function isPropertyDefinitionValue(node) {
        const parent = node.parent;
        return parent && parent.type === "PropertyDefinition" && parent.value === node;
    }
    /**
     * Checks whether the given logical operator is taken into account for the code
     * path analysis.
     * @param {string} operator The operator found in the LogicalExpression node
     * @returns {boolean} `true` if the operator is "&&" or "||" or "??"
     */
    function isHandledLogicalOperator(operator) {
        return operator === "&&" || operator === "||" || operator === "??";
    }
    /**
     * Checks whether the given assignment operator is a logical assignment operator.
     * Logical assignments are taken into account for the code path analysis
     * because of their short-circuiting semantics.
     * @param {string} operator The operator found in the AssignmentExpression node
     * @returns {boolean} `true` if the operator is "&&=" or "||=" or "??="
     */
    function isLogicalAssignmentOperator(operator) {
        return operator === "&&=" || operator === "||=" || operator === "??=";
    }
    /**
     * Gets the label if the parent node of a given node is a LabeledStatement.
     * @param {ASTNode} node A node to get.
     * @returns {string|null} The label or `null`.
     */
    function getLabel(node) {
        if (node.parent.type === "LabeledStatement") {
            return node.parent.label.name;
        }
        return null;
    }
    /**
     * Checks whether or not a given logical expression node goes different path
     * between the `true` case and the `false` case.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node is a test of a choice statement.
     */
    function isForkingByTrueOrFalse(node) {
        const parent = node.parent;
        switch (parent.type) {
            case "ConditionalExpression":
            case "IfStatement":
            case "WhileStatement":
            case "DoWhileStatement":
            case "ForStatement":
                return parent.test === node;
            case "LogicalExpression":
                return isHandledLogicalOperator(parent.operator);
            case "AssignmentExpression":
                return isLogicalAssignmentOperator(parent.operator);
            default:
                return false;
        }
    }
    /**
     * Gets the boolean value of a given literal node.
     *
     * This is used to detect infinity loops (e.g. `while (true) {}`).
     * Statements preceded by an infinity loop are unreachable if the loop didn't
     * have any `break` statement.
     * @param {ASTNode} node A node to get.
     * @returns {boolean|undefined} a boolean value if the node is a Literal node,
     *   otherwise `undefined`.
     */
    function getBooleanValueIfSimpleConstant(node) {
        if (node.type === "Literal") {
            return Boolean(node.value);
        }
        return void 0;
    }
    /**
     * Checks that a given identifier node is a reference or not.
     *
     * This is used to detect the first throwable node in a `try` block.
     * @param {ASTNode} node An Identifier node to check.
     * @returns {boolean} `true` if the node is a reference.
     */
    function isIdentifierReference(node) {
        const parent = node.parent;
        switch (parent.type) {
            case "LabeledStatement":
            case "BreakStatement":
            case "ContinueStatement":
            case "ArrayPattern":
            case "RestElement":
            case "ImportSpecifier":
            case "ImportDefaultSpecifier":
            case "ImportNamespaceSpecifier":
            case "CatchClause":
                return false;
            case "FunctionDeclaration":
            case "FunctionExpression":
            case "ArrowFunctionExpression":
            case "ClassDeclaration":
            case "ClassExpression":
            case "VariableDeclarator":
                return parent.id !== node;
            case "Property":
            case "PropertyDefinition":
            case "MethodDefinition":
                return (parent.key !== node ||
                    parent.computed ||
                    parent.shorthand);
            case "AssignmentPattern":
                return parent.key !== node;
            default:
                return true;
        }
    }
    /**
     * Updates the current segment with the head segment.
     * This is similar to local branches and tracking branches of git.
     *
     * To separate the current and the head is in order to not make useless segments.
     *
     * In this process, both "onCodePathSegmentStart" and "onCodePathSegmentEnd"
     * events are fired.
     * @param {CodePathAnalyzer} analyzer The instance.
     * @param {ASTNode} node The current AST node.
     * @returns {void}
     */
    function forwardCurrentToHead(analyzer, node) {
        const codePath = analyzer.codePath;
        const state = CodePath.getState(codePath);
        const currentSegments = state.currentSegments;
        const headSegments = state.headSegments;
        const end = Math.max(currentSegments.length, headSegments.length);
        let i, currentSegment, headSegment;
        // Fires leaving events.
        for (i = 0; i < end; ++i) {
            currentSegment = currentSegments[i];
            headSegment = headSegments[i];
            if (currentSegment !== headSegment && currentSegment) {
                debug.dump(`onCodePathSegmentEnd ${currentSegment.id}`);
                if (currentSegment.reachable) {
                    analyzer.emitter.emit("onCodePathSegmentEnd", currentSegment, node);
                }
            }
        }
        // Update state.
        state.currentSegments = headSegments;
        // Fires entering events.
        for (i = 0; i < end; ++i) {
            currentSegment = currentSegments[i];
            headSegment = headSegments[i];
            if (currentSegment !== headSegment && headSegment) {
                debug.dump(`onCodePathSegmentStart ${headSegment.id}`);
                CodePathSegment.markUsed(headSegment);
                if (headSegment.reachable) {
                    analyzer.emitter.emit("onCodePathSegmentStart", headSegment, node);
                }
            }
        }
    }
    /**
     * Updates the current segment with empty.
     * This is called at the last of functions or the program.
     * @param {CodePathAnalyzer} analyzer The instance.
     * @param {ASTNode} node The current AST node.
     * @returns {void}
     */
    function leaveFromCurrentSegment(analyzer, node) {
        const state = CodePath.getState(analyzer.codePath);
        const currentSegments = state.currentSegments;
        for (let i = 0; i < currentSegments.length; ++i) {
            const currentSegment = currentSegments[i];
            debug.dump(`onCodePathSegmentEnd ${currentSegment.id}`);
            if (currentSegment.reachable) {
                analyzer.emitter.emit("onCodePathSegmentEnd", currentSegment, node);
            }
        }
        state.currentSegments = [];
    }
    /**
     * Updates the code path due to the position of a given node in the parent node
     * thereof.
     *
     * For example, if the node is `parent.consequent`, this creates a fork from the
     * current path.
     * @param {CodePathAnalyzer} analyzer The instance.
     * @param {ASTNode} node The current AST node.
     * @returns {void}
     */
    function preprocess(analyzer, node) {
        const codePath = analyzer.codePath;
        const state = CodePath.getState(codePath);
        const parent = node.parent;
        switch (parent.type) {
            // The `arguments.length == 0` case is in `postprocess` function.
            case "CallExpression":
                if (parent.optional === true && parent.arguments.length >= 1 && parent.arguments[0] === node) {
                    state.makeOptionalRight();
                }
                break;
            case "MemberExpression":
                if (parent.optional === true && parent.property === node) {
                    state.makeOptionalRight();
                }
                break;
            case "LogicalExpression":
                if (parent.right === node &&
                    isHandledLogicalOperator(parent.operator)) {
                    state.makeLogicalRight();
                }
                break;
            case "AssignmentExpression":
                if (parent.right === node &&
                    isLogicalAssignmentOperator(parent.operator)) {
                    state.makeLogicalRight();
                }
                break;
            case "ConditionalExpression":
            case "IfStatement":
                /*
                 * Fork if this node is at `consequent`/`alternate`.
                 * `popForkContext()` exists at `IfStatement:exit` and
                 * `ConditionalExpression:exit`.
                 */
                if (parent.consequent === node) {
                    state.makeIfConsequent();
                }
                else if (parent.alternate === node) {
                    state.makeIfAlternate();
                }
                break;
            case "SwitchCase":
                if (parent.consequent[0] === node) {
                    state.makeSwitchCaseBody(false, !parent.test);
                }
                break;
            case "TryStatement":
                if (parent.handler === node) {
                    state.makeCatchBlock();
                }
                else if (parent.finalizer === node) {
                    state.makeFinallyBlock();
                }
                break;
            case "WhileStatement":
                if (parent.test === node) {
                    state.makeWhileTest(getBooleanValueIfSimpleConstant(node));
                }
                else {
                    assert(parent.body === node);
                    state.makeWhileBody();
                }
                break;
            case "DoWhileStatement":
                if (parent.body === node) {
                    state.makeDoWhileBody();
                }
                else {
                    assert(parent.test === node);
                    state.makeDoWhileTest(getBooleanValueIfSimpleConstant(node));
                }
                break;
            case "ForStatement":
                if (parent.test === node) {
                    state.makeForTest(getBooleanValueIfSimpleConstant(node));
                }
                else if (parent.update === node) {
                    state.makeForUpdate();
                }
                else if (parent.body === node) {
                    state.makeForBody();
                }
                break;
            case "ForInStatement":
            case "ForOfStatement":
                if (parent.left === node) {
                    state.makeForInOfLeft();
                }
                else if (parent.right === node) {
                    state.makeForInOfRight();
                }
                else {
                    assert(parent.body === node);
                    state.makeForInOfBody();
                }
                break;
            case "AssignmentPattern":
                /*
                 * Fork if this node is at `right`.
                 * `left` is executed always, so it uses the current path.
                 * `popForkContext()` exists at `AssignmentPattern:exit`.
                 */
                if (parent.right === node) {
                    state.pushForkContext();
                    state.forkBypassPath();
                    state.forkPath();
                }
                break;
            default:
                break;
        }
    }
    /**
     * Updates the code path due to the type of a given node in entering.
     * @param {CodePathAnalyzer} analyzer The instance.
     * @param {ASTNode} node The current AST node.
     * @returns {void}
     */
    function processCodePathToEnter(analyzer, node) {
        let codePath = analyzer.codePath;
        let state = codePath && CodePath.getState(codePath);
        const parent = node.parent;
        /**
         * Creates a new code path and trigger the onCodePathStart event
         * based on the currently selected node.
         * @param {string} origin The reason the code path was started.
         * @returns {void}
         */
        function startCodePath(origin) {
            if (codePath) {
                // Emits onCodePathSegmentStart events if updated.
                forwardCurrentToHead(analyzer, node);
                debug.dumpState(node, state, false);
            }
            // Create the code path of this scope.
            codePath = analyzer.codePath = new CodePath({
                id: analyzer.idGenerator.next(),
                origin,
                upper: codePath,
                onLooped: analyzer.onLooped
            });
            state = CodePath.getState(codePath);
            // Emits onCodePathStart events.
            debug.dump(`onCodePathStart ${codePath.id}`);
            analyzer.emitter.emit("onCodePathStart", codePath, node);
        }
        /*
         * Special case: The right side of class field initializer is considered
         * to be its own function, so we need to start a new code path in this
         * case.
         */
        if (isPropertyDefinitionValue(node)) {
            startCodePath("class-field-initializer");
            /*
             * Intentional fall through because `node` needs to also be
             * processed by the code below. For example, if we have:
             *
             * class Foo {
             *     a = () => {}
             * }
             *
             * In this case, we also need start a second code path.
             */
        }
        switch (node.type) {
            case "Program":
                startCodePath("program");
                break;
            case "FunctionDeclaration":
            case "FunctionExpression":
            case "ArrowFunctionExpression":
                startCodePath("function");
                break;
            case "StaticBlock":
                startCodePath("class-static-block");
                break;
            case "ChainExpression":
                state.pushChainContext();
                break;
            case "CallExpression":
                if (node.optional === true) {
                    state.makeOptionalNode();
                }
                break;
            case "MemberExpression":
                if (node.optional === true) {
                    state.makeOptionalNode();
                }
                break;
            case "LogicalExpression":
                if (isHandledLogicalOperator(node.operator)) {
                    state.pushChoiceContext(node.operator, isForkingByTrueOrFalse(node));
                }
                break;
            case "AssignmentExpression":
                if (isLogicalAssignmentOperator(node.operator)) {
                    state.pushChoiceContext(node.operator.slice(0, -1), // removes `=` from the end
                    isForkingByTrueOrFalse(node));
                }
                break;
            case "ConditionalExpression":
            case "IfStatement":
                state.pushChoiceContext("test", false);
                break;
            case "SwitchStatement":
                state.pushSwitchContext(node.cases.some(isCaseNode), getLabel(node));
                break;
            case "TryStatement":
                state.pushTryContext(Boolean(node.finalizer));
                break;
            case "SwitchCase":
                /*
                 * Fork if this node is after the 2st node in `cases`.
                 * It's similar to `else` blocks.
                 * The next `test` node is processed in this path.
                 */
                if (parent.discriminant !== node && parent.cases[0] !== node) {
                    state.forkPath();
                }
                break;
            case "WhileStatement":
            case "DoWhileStatement":
            case "ForStatement":
            case "ForInStatement":
            case "ForOfStatement":
                state.pushLoopContext(node.type, getLabel(node));
                break;
            case "LabeledStatement":
                if (!breakableTypePattern.test(node.body.type)) {
                    state.pushBreakContext(false, node.label.name);
                }
                break;
            default:
                break;
        }
        // Emits onCodePathSegmentStart events if updated.
        forwardCurrentToHead(analyzer, node);
        debug.dumpState(node, state, false);
    }
    /**
     * Updates the code path due to the type of a given node in leaving.
     * @param {CodePathAnalyzer} analyzer The instance.
     * @param {ASTNode} node The current AST node.
     * @returns {void}
     */
    function processCodePathToExit(analyzer, node) {
        const codePath = analyzer.codePath;
        const state = CodePath.getState(codePath);
        let dontForward = false;
        switch (node.type) {
            case "ChainExpression":
                state.popChainContext();
                break;
            case "IfStatement":
            case "ConditionalExpression":
                state.popChoiceContext();
                break;
            case "LogicalExpression":
                if (isHandledLogicalOperator(node.operator)) {
                    state.popChoiceContext();
                }
                break;
            case "AssignmentExpression":
                if (isLogicalAssignmentOperator(node.operator)) {
                    state.popChoiceContext();
                }
                break;
            case "SwitchStatement":
                state.popSwitchContext();
                break;
            case "SwitchCase":
                /*
                 * This is the same as the process at the 1st `consequent` node in
                 * `preprocess` function.
                 * Must do if this `consequent` is empty.
                 */
                if (node.consequent.length === 0) {
                    state.makeSwitchCaseBody(true, !node.test);
                }
                if (state.forkContext.reachable) {
                    dontForward = true;
                }
                break;
            case "TryStatement":
                state.popTryContext();
                break;
            case "BreakStatement":
                forwardCurrentToHead(analyzer, node);
                state.makeBreak(node.label && node.label.name);
                dontForward = true;
                break;
            case "ContinueStatement":
                forwardCurrentToHead(analyzer, node);
                state.makeContinue(node.label && node.label.name);
                dontForward = true;
                break;
            case "ReturnStatement":
                forwardCurrentToHead(analyzer, node);
                state.makeReturn();
                dontForward = true;
                break;
            case "ThrowStatement":
                forwardCurrentToHead(analyzer, node);
                state.makeThrow();
                dontForward = true;
                break;
            case "Identifier":
                if (isIdentifierReference(node)) {
                    state.makeFirstThrowablePathInTryBlock();
                    dontForward = true;
                }
                break;
            case "CallExpression":
            case "ImportExpression":
            case "MemberExpression":
            case "NewExpression":
            case "YieldExpression":
                state.makeFirstThrowablePathInTryBlock();
                break;
            case "WhileStatement":
            case "DoWhileStatement":
            case "ForStatement":
            case "ForInStatement":
            case "ForOfStatement":
                state.popLoopContext();
                break;
            case "AssignmentPattern":
                state.popForkContext();
                break;
            case "LabeledStatement":
                if (!breakableTypePattern.test(node.body.type)) {
                    state.popBreakContext();
                }
                break;
            default:
                break;
        }
        // Emits onCodePathSegmentStart events if updated.
        if (!dontForward) {
            forwardCurrentToHead(analyzer, node);
        }
        debug.dumpState(node, state, true);
    }
    /**
     * Updates the code path to finalize the current code path.
     * @param {CodePathAnalyzer} analyzer The instance.
     * @param {ASTNode} node The current AST node.
     * @returns {void}
     */
    function postprocess(analyzer, node) {
        /**
         * Ends the code path for the current node.
         * @returns {void}
         */
        function endCodePath() {
            let codePath = analyzer.codePath;
            // Mark the current path as the final node.
            CodePath.getState(codePath).makeFinal();
            // Emits onCodePathSegmentEnd event of the current segments.
            leaveFromCurrentSegment(analyzer, node);
            // Emits onCodePathEnd event of this code path.
            debug.dump(`onCodePathEnd ${codePath.id}`);
            analyzer.emitter.emit("onCodePathEnd", codePath, node);
            debug.dumpDot(codePath);
            codePath = analyzer.codePath = analyzer.codePath.upper;
            if (codePath) {
                debug.dumpState(node, CodePath.getState(codePath), true);
            }
        }
        switch (node.type) {
            case "Program":
            case "FunctionDeclaration":
            case "FunctionExpression":
            case "ArrowFunctionExpression":
            case "StaticBlock": {
                endCodePath();
                break;
            }
            // The `arguments.length >= 1` case is in `preprocess` function.
            case "CallExpression":
                if (node.optional === true && node.arguments.length === 0) {
                    CodePath.getState(analyzer.codePath).makeOptionalRight();
                }
                break;
            default:
                break;
        }
        /*
         * Special case: The right side of class field initializer is considered
         * to be its own function, so we need to end a code path in this
         * case.
         *
         * We need to check after the other checks in order to close the
         * code paths in the correct order for code like this:
         *
         *
         * class Foo {
         *     a = () => {}
         * }
         *
         * In this case, The ArrowFunctionExpression code path is closed first
         * and then we need to close the code path for the PropertyDefinition
         * value.
         */
        if (isPropertyDefinitionValue(node)) {
            endCodePath();
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * The class to analyze code paths.
     * This class implements the EventGenerator interface.
     */
    class CodePathAnalyzer {
        /**
         * @param {EventGenerator} eventGenerator An event generator to wrap.
         */
        constructor(eventGenerator) {
            this.original = eventGenerator;
            this.emitter = eventGenerator.emitter;
            this.codePath = null;
            this.idGenerator = new IdGenerator("s");
            this.currentNode = null;
            this.onLooped = this.onLooped.bind(this);
        }
        /**
         * Does the process to enter a given AST node.
         * This updates state of analysis and calls `enterNode` of the wrapped.
         * @param {ASTNode} node A node which is entering.
         * @returns {void}
         */
        enterNode(node) {
            this.currentNode = node;
            // Updates the code path due to node's position in its parent node.
            if (node.parent) {
                preprocess(this, node);
            }
            /*
             * Updates the code path.
             * And emits onCodePathStart/onCodePathSegmentStart events.
             */
            processCodePathToEnter(this, node);
            // Emits node events.
            this.original.enterNode(node);
            this.currentNode = null;
        }
        /**
         * Does the process to leave a given AST node.
         * This updates state of analysis and calls `leaveNode` of the wrapped.
         * @param {ASTNode} node A node which is leaving.
         * @returns {void}
         */
        leaveNode(node) {
            this.currentNode = node;
            /*
             * Updates the code path.
             * And emits onCodePathStart/onCodePathSegmentStart events.
             */
            processCodePathToExit(this, node);
            // Emits node events.
            this.original.leaveNode(node);
            // Emits the last onCodePathStart/onCodePathSegmentStart events.
            postprocess(this, node);
            this.currentNode = null;
        }
        /**
         * This is called on a code path looped.
         * Then this raises a looped event.
         * @param {CodePathSegment} fromSegment A segment of prev.
         * @param {CodePathSegment} toSegment A segment of next.
         * @returns {void}
         */
        onLooped(fromSegment, toSegment) {
            if (fromSegment.reachable && toSegment.reachable) {
                debug.dump(`onCodePathSegmentLoop ${fromSegment.id} -> ${toSegment.id}`);
                this.emitter.emit("onCodePathSegmentLoop", fromSegment, toSegment, this.currentNode);
            }
        }
    }
    module.exports = CodePathAnalyzer;
},
/* eslint/lib/linter/code-path-analysis/code-path.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A class of the code path.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const CodePathState = require(332) /* ./code-path-state */;
    const IdGenerator = require(336) /* ./id-generator */;
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * A code path.
     */
    class CodePath {
        /**
         * Creates a new instance.
         * @param {Object} options Options for the function (see below).
         * @param {string} options.id An identifier.
         * @param {string} options.origin The type of code path origin.
         * @param {CodePath|null} options.upper The code path of the upper function scope.
         * @param {Function} options.onLooped A callback function to notify looping.
         */
        constructor({ id, origin, upper, onLooped }) {
            /**
             * The identifier of this code path.
             * Rules use it to store additional information of each rule.
             * @type {string}
             */
            this.id = id;
            /**
             * The reason that this code path was started. May be "program",
             * "function", "class-field-initializer", or "class-static-block".
             * @type {string}
             */
            this.origin = origin;
            /**
             * The code path of the upper function scope.
             * @type {CodePath|null}
             */
            this.upper = upper;
            /**
             * The code paths of nested function scopes.
             * @type {CodePath[]}
             */
            this.childCodePaths = [];
            // Initializes internal state.
            Object.defineProperty(this, "internal", { value: new CodePathState(new IdGenerator(`${id}_`), onLooped) });
            // Adds this into `childCodePaths` of `upper`.
            if (upper) {
                upper.childCodePaths.push(this);
            }
        }
        /**
         * Gets the state of a given code path.
         * @param {CodePath} codePath A code path to get.
         * @returns {CodePathState} The state of the code path.
         */
        static getState(codePath) {
            return codePath.internal;
        }
        /**
         * The initial code path segment.
         * @type {CodePathSegment}
         */
        get initialSegment() {
            return this.internal.initialSegment;
        }
        /**
         * Final code path segments.
         * This array is a mix of `returnedSegments` and `thrownSegments`.
         * @type {CodePathSegment[]}
         */
        get finalSegments() {
            return this.internal.finalSegments;
        }
        /**
         * Final code path segments which is with `return` statements.
         * This array contains the last path segment if it's reachable.
         * Since the reachable last path returns `undefined`.
         * @type {CodePathSegment[]}
         */
        get returnedSegments() {
            return this.internal.returnedForkContext;
        }
        /**
         * Final code path segments which is with `throw` statements.
         * @type {CodePathSegment[]}
         */
        get thrownSegments() {
            return this.internal.thrownForkContext;
        }
        /**
         * Current code path segments.
         * @type {CodePathSegment[]}
         */
        get currentSegments() {
            return this.internal.currentSegments;
        }
        /**
         * Traverses all segments in this code path.
         *
         *     codePath.traverseSegments(function(segment, controller) {
         *         // do something.
         *     });
         *
         * This method enumerates segments in order from the head.
         *
         * The `controller` object has two methods.
         *
         * - `controller.skip()` - Skip the following segments in this branch.
         * - `controller.break()` - Skip all following segments.
         * @param {Object} [options] Omittable.
         * @param {CodePathSegment} [options.first] The first segment to traverse.
         * @param {CodePathSegment} [options.last] The last segment to traverse.
         * @param {Function} callback A callback function.
         * @returns {void}
         */
        traverseSegments(options, callback) {
            let resolvedOptions;
            let resolvedCallback;
            if (typeof options === "function") {
                resolvedCallback = options;
                resolvedOptions = {};
            }
            else {
                resolvedOptions = options || {};
                resolvedCallback = callback;
            }
            const startSegment = resolvedOptions.first || this.internal.initialSegment;
            const lastSegment = resolvedOptions.last;
            let item = null;
            let index = 0;
            let end = 0;
            let segment = null;
            const visited = Object.create(null);
            const stack = [[startSegment, 0]];
            let skippedSegment = null;
            let broken = false;
            const controller = {
                skip() {
                    if (stack.length <= 1) {
                        broken = true;
                    }
                    else {
                        skippedSegment = stack[stack.length - 2][0];
                    }
                },
                break() {
                    broken = true;
                }
            };
            /**
             * Checks a given previous segment has been visited.
             * @param {CodePathSegment} prevSegment A previous segment to check.
             * @returns {boolean} `true` if the segment has been visited.
             */
            function isVisited(prevSegment) {
                return (visited[prevSegment.id] ||
                    segment.isLoopedPrevSegment(prevSegment));
            }
            while (stack.length > 0) {
                item = stack[stack.length - 1];
                segment = item[0];
                index = item[1];
                if (index === 0) {
                    // Skip if this segment has been visited already.
                    if (visited[segment.id]) {
                        stack.pop();
                        continue;
                    }
                    // Skip if all previous segments have not been visited.
                    if (segment !== startSegment &&
                        segment.prevSegments.length > 0 &&
                        !segment.prevSegments.every(isVisited)) {
                        stack.pop();
                        continue;
                    }
                    // Reset the flag of skipping if all branches have been skipped.
                    if (skippedSegment && segment.prevSegments.includes(skippedSegment)) {
                        skippedSegment = null;
                    }
                    visited[segment.id] = true;
                    // Call the callback when the first time.
                    if (!skippedSegment) {
                        resolvedCallback.call(this, segment, controller);
                        if (segment === lastSegment) {
                            controller.skip();
                        }
                        if (broken) {
                            break;
                        }
                    }
                }
                // Update the stack.
                end = segment.nextSegments.length - 1;
                if (index < end) {
                    item[1] += 1;
                    stack.push([segment.nextSegments[index], 0]);
                }
                else if (index === end) {
                    item[0] = segment.nextSegments[index];
                    item[1] = 0;
                }
                else {
                    stack.pop();
                }
            }
        }
    }
    module.exports = CodePath;
},
/* eslint/lib/linter/code-path-analysis/code-path-state.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A class to manage state of generating a code path.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const CodePathSegment = require(333) /* ./code-path-segment */, ForkContext = require(335) /* ./fork-context */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Adds given segments into the `dest` array.
     * If the `others` array does not includes the given segments, adds to the `all`
     * array as well.
     *
     * This adds only reachable and used segments.
     * @param {CodePathSegment[]} dest A destination array (`returnedSegments` or `thrownSegments`).
     * @param {CodePathSegment[]} others Another destination array (`returnedSegments` or `thrownSegments`).
     * @param {CodePathSegment[]} all The unified destination array (`finalSegments`).
     * @param {CodePathSegment[]} segments Segments to add.
     * @returns {void}
     */
    function addToReturnedOrThrown(dest, others, all, segments) {
        for (let i = 0; i < segments.length; ++i) {
            const segment = segments[i];
            dest.push(segment);
            if (!others.includes(segment)) {
                all.push(segment);
            }
        }
    }
    /**
     * Gets a loop-context for a `continue` statement.
     * @param {CodePathState} state A state to get.
     * @param {string} label The label of a `continue` statement.
     * @returns {LoopContext} A loop-context for a `continue` statement.
     */
    function getContinueContext(state, label) {
        if (!label) {
            return state.loopContext;
        }
        let context = state.loopContext;
        while (context) {
            if (context.label === label) {
                return context;
            }
            context = context.upper;
        }
        /* c8 ignore next */
        return null;
    }
    /**
     * Gets a context for a `break` statement.
     * @param {CodePathState} state A state to get.
     * @param {string} label The label of a `break` statement.
     * @returns {LoopContext|SwitchContext} A context for a `break` statement.
     */
    function getBreakContext(state, label) {
        let context = state.breakContext;
        while (context) {
            if (label ? context.label === label : context.breakable) {
                return context;
            }
            context = context.upper;
        }
        /* c8 ignore next */
        return null;
    }
    /**
     * Gets a context for a `return` statement.
     * @param {CodePathState} state A state to get.
     * @returns {TryContext|CodePathState} A context for a `return` statement.
     */
    function getReturnContext(state) {
        let context = state.tryContext;
        while (context) {
            if (context.hasFinalizer && context.position !== "finally") {
                return context;
            }
            context = context.upper;
        }
        return state;
    }
    /**
     * Gets a context for a `throw` statement.
     * @param {CodePathState} state A state to get.
     * @returns {TryContext|CodePathState} A context for a `throw` statement.
     */
    function getThrowContext(state) {
        let context = state.tryContext;
        while (context) {
            if (context.position === "try" ||
                (context.hasFinalizer && context.position === "catch")) {
                return context;
            }
            context = context.upper;
        }
        return state;
    }
    /**
     * Removes a given element from a given array.
     * @param {any[]} xs An array to remove the specific element.
     * @param {any} x An element to be removed.
     * @returns {void}
     */
    function remove(xs, x) {
        xs.splice(xs.indexOf(x), 1);
    }
    /**
     * Disconnect given segments.
     *
     * This is used in a process for switch statements.
     * If there is the "default" chunk before other cases, the order is different
     * between node's and running's.
     * @param {CodePathSegment[]} prevSegments Forward segments to disconnect.
     * @param {CodePathSegment[]} nextSegments Backward segments to disconnect.
     * @returns {void}
     */
    function removeConnection(prevSegments, nextSegments) {
        for (let i = 0; i < prevSegments.length; ++i) {
            const prevSegment = prevSegments[i];
            const nextSegment = nextSegments[i];
            remove(prevSegment.nextSegments, nextSegment);
            remove(prevSegment.allNextSegments, nextSegment);
            remove(nextSegment.prevSegments, prevSegment);
            remove(nextSegment.allPrevSegments, prevSegment);
        }
    }
    /**
     * Creates looping path.
     * @param {CodePathState} state The instance.
     * @param {CodePathSegment[]} unflattenedFromSegments Segments which are source.
     * @param {CodePathSegment[]} unflattenedToSegments Segments which are destination.
     * @returns {void}
     */
    function makeLooped(state, unflattenedFromSegments, unflattenedToSegments) {
        const fromSegments = CodePathSegment.flattenUnusedSegments(unflattenedFromSegments);
        const toSegments = CodePathSegment.flattenUnusedSegments(unflattenedToSegments);
        const end = Math.min(fromSegments.length, toSegments.length);
        for (let i = 0; i < end; ++i) {
            const fromSegment = fromSegments[i];
            const toSegment = toSegments[i];
            if (toSegment.reachable) {
                fromSegment.nextSegments.push(toSegment);
            }
            if (fromSegment.reachable) {
                toSegment.prevSegments.push(fromSegment);
            }
            fromSegment.allNextSegments.push(toSegment);
            toSegment.allPrevSegments.push(fromSegment);
            if (toSegment.allPrevSegments.length >= 2) {
                CodePathSegment.markPrevSegmentAsLooped(toSegment, fromSegment);
            }
            state.notifyLooped(fromSegment, toSegment);
        }
    }
    /**
     * Finalizes segments of `test` chunk of a ForStatement.
     *
     * - Adds `false` paths to paths which are leaving from the loop.
     * - Sets `true` paths to paths which go to the body.
     * @param {LoopContext} context A loop context to modify.
     * @param {ChoiceContext} choiceContext A choice context of this loop.
     * @param {CodePathSegment[]} head The current head paths.
     * @returns {void}
     */
    function finalizeTestSegmentsOfFor(context, choiceContext, head) {
        if (!choiceContext.processed) {
            choiceContext.trueForkContext.add(head);
            choiceContext.falseForkContext.add(head);
            choiceContext.qqForkContext.add(head);
        }
        if (context.test !== true) {
            context.brokenForkContext.addAll(choiceContext.falseForkContext);
        }
        context.endOfTestSegments = choiceContext.trueForkContext.makeNext(0, -1);
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * A class which manages state to analyze code paths.
     */
    class CodePathState {
        /**
         * @param {IdGenerator} idGenerator An id generator to generate id for code
         *   path segments.
         * @param {Function} onLooped A callback function to notify looping.
         */
        constructor(idGenerator, onLooped) {
            this.idGenerator = idGenerator;
            this.notifyLooped = onLooped;
            this.forkContext = ForkContext.newRoot(idGenerator);
            this.choiceContext = null;
            this.switchContext = null;
            this.tryContext = null;
            this.loopContext = null;
            this.breakContext = null;
            this.chainContext = null;
            this.currentSegments = [];
            this.initialSegment = this.forkContext.head[0];
            // returnedSegments and thrownSegments push elements into finalSegments also.
            const final = this.finalSegments = [];
            const returned = this.returnedForkContext = [];
            const thrown = this.thrownForkContext = [];
            returned.add = addToReturnedOrThrown.bind(null, returned, thrown, final);
            thrown.add = addToReturnedOrThrown.bind(null, thrown, returned, final);
        }
        /**
         * The head segments.
         * @type {CodePathSegment[]}
         */
        get headSegments() {
            return this.forkContext.head;
        }
        /**
         * The parent forking context.
         * This is used for the root of new forks.
         * @type {ForkContext}
         */
        get parentForkContext() {
            const current = this.forkContext;
            return current && current.upper;
        }
        /**
         * Creates and stacks new forking context.
         * @param {boolean} forkLeavingPath A flag which shows being in a
         *   "finally" block.
         * @returns {ForkContext} The created context.
         */
        pushForkContext(forkLeavingPath) {
            this.forkContext = ForkContext.newEmpty(this.forkContext, forkLeavingPath);
            return this.forkContext;
        }
        /**
         * Pops and merges the last forking context.
         * @returns {ForkContext} The last context.
         */
        popForkContext() {
            const lastContext = this.forkContext;
            this.forkContext = lastContext.upper;
            this.forkContext.replaceHead(lastContext.makeNext(0, -1));
            return lastContext;
        }
        /**
         * Creates a new path.
         * @returns {void}
         */
        forkPath() {
            this.forkContext.add(this.parentForkContext.makeNext(-1, -1));
        }
        /**
         * Creates a bypass path.
         * This is used for such as IfStatement which does not have "else" chunk.
         * @returns {void}
         */
        forkBypassPath() {
            this.forkContext.add(this.parentForkContext.head);
        }
        //--------------------------------------------------------------------------
        // ConditionalExpression, LogicalExpression, IfStatement
        //--------------------------------------------------------------------------
        /**
         * Creates a context for ConditionalExpression, LogicalExpression, AssignmentExpression (logical assignments only),
         * IfStatement, WhileStatement, DoWhileStatement, or ForStatement.
         *
         * LogicalExpressions have cases that it goes different paths between the
         * `true` case and the `false` case.
         *
         * For Example:
         *
         *     if (a || b) {
         *         foo();
         *     } else {
         *         bar();
         *     }
         *
         * In this case, `b` is evaluated always in the code path of the `else`
         * block, but it's not so in the code path of the `if` block.
         * So there are 3 paths.
         *
         *     a -> foo();
         *     a -> b -> foo();
         *     a -> b -> bar();
         * @param {string} kind A kind string.
         *   If the new context is LogicalExpression's or AssignmentExpression's, this is `"&&"` or `"||"` or `"??"`.
         *   If it's IfStatement's or ConditionalExpression's, this is `"test"`.
         *   Otherwise, this is `"loop"`.
         * @param {boolean} isForkingAsResult A flag that shows that goes different
         *   paths between `true` and `false`.
         * @returns {void}
         */
        pushChoiceContext(kind, isForkingAsResult) {
            this.choiceContext = {
                upper: this.choiceContext,
                kind,
                isForkingAsResult,
                trueForkContext: ForkContext.newEmpty(this.forkContext),
                falseForkContext: ForkContext.newEmpty(this.forkContext),
                qqForkContext: ForkContext.newEmpty(this.forkContext),
                processed: false
            };
        }
        /**
         * Pops the last choice context and finalizes it.
         * @throws {Error} (Unreachable.)
         * @returns {ChoiceContext} The popped context.
         */
        popChoiceContext() {
            const context = this.choiceContext;
            this.choiceContext = context.upper;
            const forkContext = this.forkContext;
            const headSegments = forkContext.head;
            switch (context.kind) {
                case "&&":
                case "||":
                case "??":
                    /*
                     * If any result were not transferred from child contexts,
                     * this sets the head segments to both cases.
                     * The head segments are the path of the right-hand operand.
                     */
                    if (!context.processed) {
                        context.trueForkContext.add(headSegments);
                        context.falseForkContext.add(headSegments);
                        context.qqForkContext.add(headSegments);
                    }
                    /*
                     * Transfers results to upper context if this context is in
                     * test chunk.
                     */
                    if (context.isForkingAsResult) {
                        const parentContext = this.choiceContext;
                        parentContext.trueForkContext.addAll(context.trueForkContext);
                        parentContext.falseForkContext.addAll(context.falseForkContext);
                        parentContext.qqForkContext.addAll(context.qqForkContext);
                        parentContext.processed = true;
                        return context;
                    }
                    break;
                case "test":
                    if (!context.processed) {
                        /*
                         * The head segments are the path of the `if` block here.
                         * Updates the `true` path with the end of the `if` block.
                         */
                        context.trueForkContext.clear();
                        context.trueForkContext.add(headSegments);
                    }
                    else {
                        /*
                         * The head segments are the path of the `else` block here.
                         * Updates the `false` path with the end of the `else`
                         * block.
                         */
                        context.falseForkContext.clear();
                        context.falseForkContext.add(headSegments);
                    }
                    break;
                case "loop":
                    /*
                     * Loops are addressed in popLoopContext().
                     * This is called from popLoopContext().
                     */
                    return context;
                /* c8 ignore next */
                default:
                    throw new Error("unreachable");
            }
            // Merges all paths.
            const prevForkContext = context.trueForkContext;
            prevForkContext.addAll(context.falseForkContext);
            forkContext.replaceHead(prevForkContext.makeNext(0, -1));
            return context;
        }
        /**
         * Makes a code path segment of the right-hand operand of a logical
         * expression.
         * @throws {Error} (Unreachable.)
         * @returns {void}
         */
        makeLogicalRight() {
            const context = this.choiceContext;
            const forkContext = this.forkContext;
            if (context.processed) {
                /*
                 * This got segments already from the child choice context.
                 * Creates the next path from own true/false fork context.
                 */
                let prevForkContext;
                switch (context.kind) {
                    case "&&": // if true then go to the right-hand side.
                        prevForkContext = context.trueForkContext;
                        break;
                    case "||": // if false then go to the right-hand side.
                        prevForkContext = context.falseForkContext;
                        break;
                    case "??": // Both true/false can short-circuit, so needs the third path to go to the right-hand side. That's qqForkContext.
                        prevForkContext = context.qqForkContext;
                        break;
                    default:
                        throw new Error("unreachable");
                }
                forkContext.replaceHead(prevForkContext.makeNext(0, -1));
                prevForkContext.clear();
                context.processed = false;
            }
            else {
                /*
                 * This did not get segments from the child choice context.
                 * So addresses the head segments.
                 * The head segments are the path of the left-hand operand.
                 */
                switch (context.kind) {
                    case "&&": // the false path can short-circuit.
                        context.falseForkContext.add(forkContext.head);
                        break;
                    case "||": // the true path can short-circuit.
                        context.trueForkContext.add(forkContext.head);
                        break;
                    case "??": // both can short-circuit.
                        context.trueForkContext.add(forkContext.head);
                        context.falseForkContext.add(forkContext.head);
                        break;
                    default:
                        throw new Error("unreachable");
                }
                forkContext.replaceHead(forkContext.makeNext(-1, -1));
            }
        }
        /**
         * Makes a code path segment of the `if` block.
         * @returns {void}
         */
        makeIfConsequent() {
            const context = this.choiceContext;
            const forkContext = this.forkContext;
            /*
             * If any result were not transferred from child contexts,
             * this sets the head segments to both cases.
             * The head segments are the path of the test expression.
             */
            if (!context.processed) {
                context.trueForkContext.add(forkContext.head);
                context.falseForkContext.add(forkContext.head);
                context.qqForkContext.add(forkContext.head);
            }
            context.processed = false;
            // Creates new path from the `true` case.
            forkContext.replaceHead(context.trueForkContext.makeNext(0, -1));
        }
        /**
         * Makes a code path segment of the `else` block.
         * @returns {void}
         */
        makeIfAlternate() {
            const context = this.choiceContext;
            const forkContext = this.forkContext;
            /*
             * The head segments are the path of the `if` block.
             * Updates the `true` path with the end of the `if` block.
             */
            context.trueForkContext.clear();
            context.trueForkContext.add(forkContext.head);
            context.processed = true;
            // Creates new path from the `false` case.
            forkContext.replaceHead(context.falseForkContext.makeNext(0, -1));
        }
        //--------------------------------------------------------------------------
        // ChainExpression
        //--------------------------------------------------------------------------
        /**
         * Push a new `ChainExpression` context to the stack.
         * This method is called on entering to each `ChainExpression` node.
         * This context is used to count forking in the optional chain then merge them on the exiting from the `ChainExpression` node.
         * @returns {void}
         */
        pushChainContext() {
            this.chainContext = {
                upper: this.chainContext,
                countChoiceContexts: 0
            };
        }
        /**
         * Pop a `ChainExpression` context from the stack.
         * This method is called on exiting from each `ChainExpression` node.
         * This merges all forks of the last optional chaining.
         * @returns {void}
         */
        popChainContext() {
            const context = this.chainContext;
            this.chainContext = context.upper;
            // pop all choice contexts of this.
            for (let i = context.countChoiceContexts; i > 0; --i) {
                this.popChoiceContext();
            }
        }
        /**
         * Create a choice context for optional access.
         * This method is called on entering to each `(Call|Member)Expression[optional=true]` node.
         * This creates a choice context as similar to `LogicalExpression[operator="??"]` node.
         * @returns {void}
         */
        makeOptionalNode() {
            if (this.chainContext) {
                this.chainContext.countChoiceContexts += 1;
                this.pushChoiceContext("??", false);
            }
        }
        /**
         * Create a fork.
         * This method is called on entering to the `arguments|property` property of each `(Call|Member)Expression` node.
         * @returns {void}
         */
        makeOptionalRight() {
            if (this.chainContext) {
                this.makeLogicalRight();
            }
        }
        //--------------------------------------------------------------------------
        // SwitchStatement
        //--------------------------------------------------------------------------
        /**
         * Creates a context object of SwitchStatement and stacks it.
         * @param {boolean} hasCase `true` if the switch statement has one or more
         *   case parts.
         * @param {string|null} label The label text.
         * @returns {void}
         */
        pushSwitchContext(hasCase, label) {
            this.switchContext = {
                upper: this.switchContext,
                hasCase,
                defaultSegments: null,
                defaultBodySegments: null,
                foundDefault: false,
                lastIsDefault: false,
                countForks: 0
            };
            this.pushBreakContext(true, label);
        }
        /**
         * Pops the last context of SwitchStatement and finalizes it.
         *
         * - Disposes all forking stack for `case` and `default`.
         * - Creates the next code path segment from `context.brokenForkContext`.
         * - If the last `SwitchCase` node is not a `default` part, creates a path
         *   to the `default` body.
         * @returns {void}
         */
        popSwitchContext() {
            const context = this.switchContext;
            this.switchContext = context.upper;
            const forkContext = this.forkContext;
            const brokenForkContext = this.popBreakContext().brokenForkContext;
            if (context.countForks === 0) {
                /*
                 * When there is only one `default` chunk and there is one or more
                 * `break` statements, even if forks are nothing, it needs to merge
                 * those.
                 */
                if (!brokenForkContext.empty) {
                    brokenForkContext.add(forkContext.makeNext(-1, -1));
                    forkContext.replaceHead(brokenForkContext.makeNext(0, -1));
                }
                return;
            }
            const lastSegments = forkContext.head;
            this.forkBypassPath();
            const lastCaseSegments = forkContext.head;
            /*
             * `brokenForkContext` is used to make the next segment.
             * It must add the last segment into `brokenForkContext`.
             */
            brokenForkContext.add(lastSegments);
            /*
             * A path which is failed in all case test should be connected to path
             * of `default` chunk.
             */
            if (!context.lastIsDefault) {
                if (context.defaultBodySegments) {
                    /*
                     * Remove a link from `default` label to its chunk.
                     * It's false route.
                     */
                    removeConnection(context.defaultSegments, context.defaultBodySegments);
                    makeLooped(this, lastCaseSegments, context.defaultBodySegments);
                }
                else {
                    /*
                     * It handles the last case body as broken if `default` chunk
                     * does not exist.
                     */
                    brokenForkContext.add(lastCaseSegments);
                }
            }
            // Pops the segment context stack until the entry segment.
            for (let i = 0; i < context.countForks; ++i) {
                this.forkContext = this.forkContext.upper;
            }
            /*
             * Creates a path from all brokenForkContext paths.
             * This is a path after switch statement.
             */
            this.forkContext.replaceHead(brokenForkContext.makeNext(0, -1));
        }
        /**
         * Makes a code path segment for a `SwitchCase` node.
         * @param {boolean} isEmpty `true` if the body is empty.
         * @param {boolean} isDefault `true` if the body is the default case.
         * @returns {void}
         */
        makeSwitchCaseBody(isEmpty, isDefault) {
            const context = this.switchContext;
            if (!context.hasCase) {
                return;
            }
            /*
             * Merge forks.
             * The parent fork context has two segments.
             * Those are from the current case and the body of the previous case.
             */
            const parentForkContext = this.forkContext;
            const forkContext = this.pushForkContext();
            forkContext.add(parentForkContext.makeNext(0, -1));
            /*
             * Save `default` chunk info.
             * If the `default` label is not at the last, we must make a path from
             * the last `case` to the `default` chunk.
             */
            if (isDefault) {
                context.defaultSegments = parentForkContext.head;
                if (isEmpty) {
                    context.foundDefault = true;
                }
                else {
                    context.defaultBodySegments = forkContext.head;
                }
            }
            else {
                if (!isEmpty && context.foundDefault) {
                    context.foundDefault = false;
                    context.defaultBodySegments = forkContext.head;
                }
            }
            context.lastIsDefault = isDefault;
            context.countForks += 1;
        }
        //--------------------------------------------------------------------------
        // TryStatement
        //--------------------------------------------------------------------------
        /**
         * Creates a context object of TryStatement and stacks it.
         * @param {boolean} hasFinalizer `true` if the try statement has a
         *   `finally` block.
         * @returns {void}
         */
        pushTryContext(hasFinalizer) {
            this.tryContext = {
                upper: this.tryContext,
                position: "try",
                hasFinalizer,
                returnedForkContext: hasFinalizer
                    ? ForkContext.newEmpty(this.forkContext)
                    : null,
                thrownForkContext: ForkContext.newEmpty(this.forkContext),
                lastOfTryIsReachable: false,
                lastOfCatchIsReachable: false
            };
        }
        /**
         * Pops the last context of TryStatement and finalizes it.
         * @returns {void}
         */
        popTryContext() {
            const context = this.tryContext;
            this.tryContext = context.upper;
            if (context.position === "catch") {
                // Merges two paths from the `try` block and `catch` block merely.
                this.popForkContext();
                return;
            }
            /*
             * The following process is executed only when there is the `finally`
             * block.
             */
            const returned = context.returnedForkContext;
            const thrown = context.thrownForkContext;
            if (returned.empty && thrown.empty) {
                return;
            }
            // Separate head to normal paths and leaving paths.
            const headSegments = this.forkContext.head;
            this.forkContext = this.forkContext.upper;
            const normalSegments = headSegments.slice(0, headSegments.length / 2 | 0);
            const leavingSegments = headSegments.slice(headSegments.length / 2 | 0);
            // Forwards the leaving path to upper contexts.
            if (!returned.empty) {
                getReturnContext(this).returnedForkContext.add(leavingSegments);
            }
            if (!thrown.empty) {
                getThrowContext(this).thrownForkContext.add(leavingSegments);
            }
            // Sets the normal path as the next.
            this.forkContext.replaceHead(normalSegments);
            /*
             * If both paths of the `try` block and the `catch` block are
             * unreachable, the next path becomes unreachable as well.
             */
            if (!context.lastOfTryIsReachable && !context.lastOfCatchIsReachable) {
                this.forkContext.makeUnreachable();
            }
        }
        /**
         * Makes a code path segment for a `catch` block.
         * @returns {void}
         */
        makeCatchBlock() {
            const context = this.tryContext;
            const forkContext = this.forkContext;
            const thrown = context.thrownForkContext;
            // Update state.
            context.position = "catch";
            context.thrownForkContext = ForkContext.newEmpty(forkContext);
            context.lastOfTryIsReachable = forkContext.reachable;
            // Merge thrown paths.
            thrown.add(forkContext.head);
            const thrownSegments = thrown.makeNext(0, -1);
            // Fork to a bypass and the merged thrown path.
            this.pushForkContext();
            this.forkBypassPath();
            this.forkContext.add(thrownSegments);
        }
        /**
         * Makes a code path segment for a `finally` block.
         *
         * In the `finally` block, parallel paths are created. The parallel paths
         * are used as leaving-paths. The leaving-paths are paths from `return`
         * statements and `throw` statements in a `try` block or a `catch` block.
         * @returns {void}
         */
        makeFinallyBlock() {
            const context = this.tryContext;
            let forkContext = this.forkContext;
            const returned = context.returnedForkContext;
            const thrown = context.thrownForkContext;
            const headOfLeavingSegments = forkContext.head;
            // Update state.
            if (context.position === "catch") {
                // Merges two paths from the `try` block and `catch` block.
                this.popForkContext();
                forkContext = this.forkContext;
                context.lastOfCatchIsReachable = forkContext.reachable;
            }
            else {
                context.lastOfTryIsReachable = forkContext.reachable;
            }
            context.position = "finally";
            if (returned.empty && thrown.empty) {
                // This path does not leave.
                return;
            }
            /*
             * Create a parallel segment from merging returned and thrown.
             * This segment will leave at the end of this finally block.
             */
            const segments = forkContext.makeNext(-1, -1);
            for (let i = 0; i < forkContext.count; ++i) {
                const prevSegsOfLeavingSegment = [headOfLeavingSegments[i]];
                for (let j = 0; j < returned.segmentsList.length; ++j) {
                    prevSegsOfLeavingSegment.push(returned.segmentsList[j][i]);
                }
                for (let j = 0; j < thrown.segmentsList.length; ++j) {
                    prevSegsOfLeavingSegment.push(thrown.segmentsList[j][i]);
                }
                segments.push(CodePathSegment.newNext(this.idGenerator.next(), prevSegsOfLeavingSegment));
            }
            this.pushForkContext(true);
            this.forkContext.add(segments);
        }
        /**
         * Makes a code path segment from the first throwable node to the `catch`
         * block or the `finally` block.
         * @returns {void}
         */
        makeFirstThrowablePathInTryBlock() {
            const forkContext = this.forkContext;
            if (!forkContext.reachable) {
                return;
            }
            const context = getThrowContext(this);
            if (context === this ||
                context.position !== "try" ||
                !context.thrownForkContext.empty) {
                return;
            }
            context.thrownForkContext.add(forkContext.head);
            forkContext.replaceHead(forkContext.makeNext(-1, -1));
        }
        //--------------------------------------------------------------------------
        // Loop Statements
        //--------------------------------------------------------------------------
        /**
         * Creates a context object of a loop statement and stacks it.
         * @param {string} type The type of the node which was triggered. One of
         *   `WhileStatement`, `DoWhileStatement`, `ForStatement`, `ForInStatement`,
         *   and `ForStatement`.
         * @param {string|null} label A label of the node which was triggered.
         * @throws {Error} (Unreachable - unknown type.)
         * @returns {void}
         */
        pushLoopContext(type, label) {
            const forkContext = this.forkContext;
            const breakContext = this.pushBreakContext(true, label);
            switch (type) {
                case "WhileStatement":
                    this.pushChoiceContext("loop", false);
                    this.loopContext = {
                        upper: this.loopContext,
                        type,
                        label,
                        test: void 0,
                        continueDestSegments: null,
                        brokenForkContext: breakContext.brokenForkContext
                    };
                    break;
                case "DoWhileStatement":
                    this.pushChoiceContext("loop", false);
                    this.loopContext = {
                        upper: this.loopContext,
                        type,
                        label,
                        test: void 0,
                        entrySegments: null,
                        continueForkContext: ForkContext.newEmpty(forkContext),
                        brokenForkContext: breakContext.brokenForkContext
                    };
                    break;
                case "ForStatement":
                    this.pushChoiceContext("loop", false);
                    this.loopContext = {
                        upper: this.loopContext,
                        type,
                        label,
                        test: void 0,
                        endOfInitSegments: null,
                        testSegments: null,
                        endOfTestSegments: null,
                        updateSegments: null,
                        endOfUpdateSegments: null,
                        continueDestSegments: null,
                        brokenForkContext: breakContext.brokenForkContext
                    };
                    break;
                case "ForInStatement":
                case "ForOfStatement":
                    this.loopContext = {
                        upper: this.loopContext,
                        type,
                        label,
                        prevSegments: null,
                        leftSegments: null,
                        endOfLeftSegments: null,
                        continueDestSegments: null,
                        brokenForkContext: breakContext.brokenForkContext
                    };
                    break;
                /* c8 ignore next */
                default:
                    throw new Error(`unknown type: "${type}"`);
            }
        }
        /**
         * Pops the last context of a loop statement and finalizes it.
         * @throws {Error} (Unreachable - unknown type.)
         * @returns {void}
         */
        popLoopContext() {
            const context = this.loopContext;
            this.loopContext = context.upper;
            const forkContext = this.forkContext;
            const brokenForkContext = this.popBreakContext().brokenForkContext;
            // Creates a looped path.
            switch (context.type) {
                case "WhileStatement":
                case "ForStatement":
                    this.popChoiceContext();
                    makeLooped(this, forkContext.head, context.continueDestSegments);
                    break;
                case "DoWhileStatement": {
                    const choiceContext = this.popChoiceContext();
                    if (!choiceContext.processed) {
                        choiceContext.trueForkContext.add(forkContext.head);
                        choiceContext.falseForkContext.add(forkContext.head);
                    }
                    if (context.test !== true) {
                        brokenForkContext.addAll(choiceContext.falseForkContext);
                    }
                    // `true` paths go to looping.
                    const segmentsList = choiceContext.trueForkContext.segmentsList;
                    for (let i = 0; i < segmentsList.length; ++i) {
                        makeLooped(this, segmentsList[i], context.entrySegments);
                    }
                    break;
                }
                case "ForInStatement":
                case "ForOfStatement":
                    brokenForkContext.add(forkContext.head);
                    makeLooped(this, forkContext.head, context.leftSegments);
                    break;
                /* c8 ignore next */
                default:
                    throw new Error("unreachable");
            }
            // Go next.
            if (brokenForkContext.empty) {
                forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
            }
            else {
                forkContext.replaceHead(brokenForkContext.makeNext(0, -1));
            }
        }
        /**
         * Makes a code path segment for the test part of a WhileStatement.
         * @param {boolean|undefined} test The test value (only when constant).
         * @returns {void}
         */
        makeWhileTest(test) {
            const context = this.loopContext;
            const forkContext = this.forkContext;
            const testSegments = forkContext.makeNext(0, -1);
            // Update state.
            context.test = test;
            context.continueDestSegments = testSegments;
            forkContext.replaceHead(testSegments);
        }
        /**
         * Makes a code path segment for the body part of a WhileStatement.
         * @returns {void}
         */
        makeWhileBody() {
            const context = this.loopContext;
            const choiceContext = this.choiceContext;
            const forkContext = this.forkContext;
            if (!choiceContext.processed) {
                choiceContext.trueForkContext.add(forkContext.head);
                choiceContext.falseForkContext.add(forkContext.head);
            }
            // Update state.
            if (context.test !== true) {
                context.brokenForkContext.addAll(choiceContext.falseForkContext);
            }
            forkContext.replaceHead(choiceContext.trueForkContext.makeNext(0, -1));
        }
        /**
         * Makes a code path segment for the body part of a DoWhileStatement.
         * @returns {void}
         */
        makeDoWhileBody() {
            const context = this.loopContext;
            const forkContext = this.forkContext;
            const bodySegments = forkContext.makeNext(-1, -1);
            // Update state.
            context.entrySegments = bodySegments;
            forkContext.replaceHead(bodySegments);
        }
        /**
         * Makes a code path segment for the test part of a DoWhileStatement.
         * @param {boolean|undefined} test The test value (only when constant).
         * @returns {void}
         */
        makeDoWhileTest(test) {
            const context = this.loopContext;
            const forkContext = this.forkContext;
            context.test = test;
            // Creates paths of `continue` statements.
            if (!context.continueForkContext.empty) {
                context.continueForkContext.add(forkContext.head);
                const testSegments = context.continueForkContext.makeNext(0, -1);
                forkContext.replaceHead(testSegments);
            }
        }
        /**
         * Makes a code path segment for the test part of a ForStatement.
         * @param {boolean|undefined} test The test value (only when constant).
         * @returns {void}
         */
        makeForTest(test) {
            const context = this.loopContext;
            const forkContext = this.forkContext;
            const endOfInitSegments = forkContext.head;
            const testSegments = forkContext.makeNext(-1, -1);
            // Update state.
            context.test = test;
            context.endOfInitSegments = endOfInitSegments;
            context.continueDestSegments = context.testSegments = testSegments;
            forkContext.replaceHead(testSegments);
        }
        /**
         * Makes a code path segment for the update part of a ForStatement.
         * @returns {void}
         */
        makeForUpdate() {
            const context = this.loopContext;
            const choiceContext = this.choiceContext;
            const forkContext = this.forkContext;
            // Make the next paths of the test.
            if (context.testSegments) {
                finalizeTestSegmentsOfFor(context, choiceContext, forkContext.head);
            }
            else {
                context.endOfInitSegments = forkContext.head;
            }
            // Update state.
            const updateSegments = forkContext.makeDisconnected(-1, -1);
            context.continueDestSegments = context.updateSegments = updateSegments;
            forkContext.replaceHead(updateSegments);
        }
        /**
         * Makes a code path segment for the body part of a ForStatement.
         * @returns {void}
         */
        makeForBody() {
            const context = this.loopContext;
            const choiceContext = this.choiceContext;
            const forkContext = this.forkContext;
            // Update state.
            if (context.updateSegments) {
                context.endOfUpdateSegments = forkContext.head;
                // `update` -> `test`
                if (context.testSegments) {
                    makeLooped(this, context.endOfUpdateSegments, context.testSegments);
                }
            }
            else if (context.testSegments) {
                finalizeTestSegmentsOfFor(context, choiceContext, forkContext.head);
            }
            else {
                context.endOfInitSegments = forkContext.head;
            }
            let bodySegments = context.endOfTestSegments;
            if (!bodySegments) {
                /*
                 * If there is not the `test` part, the `body` path comes from the
                 * `init` part and the `update` part.
                 */
                const prevForkContext = ForkContext.newEmpty(forkContext);
                prevForkContext.add(context.endOfInitSegments);
                if (context.endOfUpdateSegments) {
                    prevForkContext.add(context.endOfUpdateSegments);
                }
                bodySegments = prevForkContext.makeNext(0, -1);
            }
            context.continueDestSegments = context.continueDestSegments || bodySegments;
            forkContext.replaceHead(bodySegments);
        }
        /**
         * Makes a code path segment for the left part of a ForInStatement and a
         * ForOfStatement.
         * @returns {void}
         */
        makeForInOfLeft() {
            const context = this.loopContext;
            const forkContext = this.forkContext;
            const leftSegments = forkContext.makeDisconnected(-1, -1);
            // Update state.
            context.prevSegments = forkContext.head;
            context.leftSegments = context.continueDestSegments = leftSegments;
            forkContext.replaceHead(leftSegments);
        }
        /**
         * Makes a code path segment for the right part of a ForInStatement and a
         * ForOfStatement.
         * @returns {void}
         */
        makeForInOfRight() {
            const context = this.loopContext;
            const forkContext = this.forkContext;
            const temp = ForkContext.newEmpty(forkContext);
            temp.add(context.prevSegments);
            const rightSegments = temp.makeNext(-1, -1);
            // Update state.
            context.endOfLeftSegments = forkContext.head;
            forkContext.replaceHead(rightSegments);
        }
        /**
         * Makes a code path segment for the body part of a ForInStatement and a
         * ForOfStatement.
         * @returns {void}
         */
        makeForInOfBody() {
            const context = this.loopContext;
            const forkContext = this.forkContext;
            const temp = ForkContext.newEmpty(forkContext);
            temp.add(context.endOfLeftSegments);
            const bodySegments = temp.makeNext(-1, -1);
            // Make a path: `right` -> `left`.
            makeLooped(this, forkContext.head, context.leftSegments);
            // Update state.
            context.brokenForkContext.add(forkContext.head);
            forkContext.replaceHead(bodySegments);
        }
        //--------------------------------------------------------------------------
        // Control Statements
        //--------------------------------------------------------------------------
        /**
         * Creates new context for BreakStatement.
         * @param {boolean} breakable The flag to indicate it can break by
         *      an unlabeled BreakStatement.
         * @param {string|null} label The label of this context.
         * @returns {Object} The new context.
         */
        pushBreakContext(breakable, label) {
            this.breakContext = {
                upper: this.breakContext,
                breakable,
                label,
                brokenForkContext: ForkContext.newEmpty(this.forkContext)
            };
            return this.breakContext;
        }
        /**
         * Removes the top item of the break context stack.
         * @returns {Object} The removed context.
         */
        popBreakContext() {
            const context = this.breakContext;
            const forkContext = this.forkContext;
            this.breakContext = context.upper;
            // Process this context here for other than switches and loops.
            if (!context.breakable) {
                const brokenForkContext = context.brokenForkContext;
                if (!brokenForkContext.empty) {
                    brokenForkContext.add(forkContext.head);
                    forkContext.replaceHead(brokenForkContext.makeNext(0, -1));
                }
            }
            return context;
        }
        /**
         * Makes a path for a `break` statement.
         *
         * It registers the head segment to a context of `break`.
         * It makes new unreachable segment, then it set the head with the segment.
         * @param {string} label A label of the break statement.
         * @returns {void}
         */
        makeBreak(label) {
            const forkContext = this.forkContext;
            if (!forkContext.reachable) {
                return;
            }
            const context = getBreakContext(this, label);
            if (context) {
                context.brokenForkContext.add(forkContext.head);
            }
            /* c8 ignore next */
            forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
        }
        /**
         * Makes a path for a `continue` statement.
         *
         * It makes a looping path.
         * It makes new unreachable segment, then it set the head with the segment.
         * @param {string} label A label of the continue statement.
         * @returns {void}
         */
        makeContinue(label) {
            const forkContext = this.forkContext;
            if (!forkContext.reachable) {
                return;
            }
            const context = getContinueContext(this, label);
            if (context) {
                if (context.continueDestSegments) {
                    makeLooped(this, forkContext.head, context.continueDestSegments);
                    // If the context is a for-in/of loop, this effects a break also.
                    if (context.type === "ForInStatement" ||
                        context.type === "ForOfStatement") {
                        context.brokenForkContext.add(forkContext.head);
                    }
                }
                else {
                    context.continueForkContext.add(forkContext.head);
                }
            }
            forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
        }
        /**
         * Makes a path for a `return` statement.
         *
         * It registers the head segment to a context of `return`.
         * It makes new unreachable segment, then it set the head with the segment.
         * @returns {void}
         */
        makeReturn() {
            const forkContext = this.forkContext;
            if (forkContext.reachable) {
                getReturnContext(this).returnedForkContext.add(forkContext.head);
                forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
            }
        }
        /**
         * Makes a path for a `throw` statement.
         *
         * It registers the head segment to a context of `throw`.
         * It makes new unreachable segment, then it set the head with the segment.
         * @returns {void}
         */
        makeThrow() {
            const forkContext = this.forkContext;
            if (forkContext.reachable) {
                getThrowContext(this).thrownForkContext.add(forkContext.head);
                forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
            }
        }
        /**
         * Makes the final path.
         * @returns {void}
         */
        makeFinal() {
            const segments = this.currentSegments;
            if (segments.length > 0 && segments[0].reachable) {
                this.returnedForkContext.add(segments);
            }
        }
    }
    module.exports = CodePathState;
},
/* eslint/lib/linter/code-path-analysis/code-path-segment.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A class of the code path segment.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const debug = require(334) /* ./debug-helpers */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a given segment is reachable.
     * @param {CodePathSegment} segment A segment to check.
     * @returns {boolean} `true` if the segment is reachable.
     */
    function isReachable(segment) {
        return segment.reachable;
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * A code path segment.
     */
    class CodePathSegment {
        /**
         * @param {string} id An identifier.
         * @param {CodePathSegment[]} allPrevSegments An array of the previous segments.
         *   This array includes unreachable segments.
         * @param {boolean} reachable A flag which shows this is reachable.
         */
        constructor(id, allPrevSegments, reachable) {
            /**
             * The identifier of this code path.
             * Rules use it to store additional information of each rule.
             * @type {string}
             */
            this.id = id;
            /**
             * An array of the next segments.
             * @type {CodePathSegment[]}
             */
            this.nextSegments = [];
            /**
             * An array of the previous segments.
             * @type {CodePathSegment[]}
             */
            this.prevSegments = allPrevSegments.filter(isReachable);
            /**
             * An array of the next segments.
             * This array includes unreachable segments.
             * @type {CodePathSegment[]}
             */
            this.allNextSegments = [];
            /**
             * An array of the previous segments.
             * This array includes unreachable segments.
             * @type {CodePathSegment[]}
             */
            this.allPrevSegments = allPrevSegments;
            /**
             * A flag which shows this is reachable.
             * @type {boolean}
             */
            this.reachable = reachable;
            // Internal data.
            Object.defineProperty(this, "internal", {
                value: {
                    used: false,
                    loopedPrevSegments: []
                }
            });
            /* c8 ignore start */
            if (debug.enabled) {
                this.internal.nodes = [];
            } /* c8 ignore stop */
        }
        /**
         * Checks a given previous segment is coming from the end of a loop.
         * @param {CodePathSegment} segment A previous segment to check.
         * @returns {boolean} `true` if the segment is coming from the end of a loop.
         */
        isLoopedPrevSegment(segment) {
            return this.internal.loopedPrevSegments.includes(segment);
        }
        /**
         * Creates the root segment.
         * @param {string} id An identifier.
         * @returns {CodePathSegment} The created segment.
         */
        static newRoot(id) {
            return new CodePathSegment(id, [], true);
        }
        /**
         * Creates a segment that follows given segments.
         * @param {string} id An identifier.
         * @param {CodePathSegment[]} allPrevSegments An array of the previous segments.
         * @returns {CodePathSegment} The created segment.
         */
        static newNext(id, allPrevSegments) {
            return new CodePathSegment(id, CodePathSegment.flattenUnusedSegments(allPrevSegments), allPrevSegments.some(isReachable));
        }
        /**
         * Creates an unreachable segment that follows given segments.
         * @param {string} id An identifier.
         * @param {CodePathSegment[]} allPrevSegments An array of the previous segments.
         * @returns {CodePathSegment} The created segment.
         */
        static newUnreachable(id, allPrevSegments) {
            const segment = new CodePathSegment(id, CodePathSegment.flattenUnusedSegments(allPrevSegments), false);
            /*
             * In `if (a) return a; foo();` case, the unreachable segment preceded by
             * the return statement is not used but must not be remove.
             */
            CodePathSegment.markUsed(segment);
            return segment;
        }
        /**
         * Creates a segment that follows given segments.
         * This factory method does not connect with `allPrevSegments`.
         * But this inherits `reachable` flag.
         * @param {string} id An identifier.
         * @param {CodePathSegment[]} allPrevSegments An array of the previous segments.
         * @returns {CodePathSegment} The created segment.
         */
        static newDisconnected(id, allPrevSegments) {
            return new CodePathSegment(id, [], allPrevSegments.some(isReachable));
        }
        /**
         * Makes a given segment being used.
         *
         * And this function registers the segment into the previous segments as a next.
         * @param {CodePathSegment} segment A segment to mark.
         * @returns {void}
         */
        static markUsed(segment) {
            if (segment.internal.used) {
                return;
            }
            segment.internal.used = true;
            let i;
            if (segment.reachable) {
                for (i = 0; i < segment.allPrevSegments.length; ++i) {
                    const prevSegment = segment.allPrevSegments[i];
                    prevSegment.allNextSegments.push(segment);
                    prevSegment.nextSegments.push(segment);
                }
            }
            else {
                for (i = 0; i < segment.allPrevSegments.length; ++i) {
                    segment.allPrevSegments[i].allNextSegments.push(segment);
                }
            }
        }
        /**
         * Marks a previous segment as looped.
         * @param {CodePathSegment} segment A segment.
         * @param {CodePathSegment} prevSegment A previous segment to mark.
         * @returns {void}
         */
        static markPrevSegmentAsLooped(segment, prevSegment) {
            segment.internal.loopedPrevSegments.push(prevSegment);
        }
        /**
         * Replaces unused segments with the previous segments of each unused segment.
         * @param {CodePathSegment[]} segments An array of segments to replace.
         * @returns {CodePathSegment[]} The replaced array.
         */
        static flattenUnusedSegments(segments) {
            const done = Object.create(null);
            const retv = [];
            for (let i = 0; i < segments.length; ++i) {
                const segment = segments[i];
                // Ignores duplicated.
                if (done[segment.id]) {
                    continue;
                }
                // Use previous segments if unused.
                if (!segment.internal.used) {
                    for (let j = 0; j < segment.allPrevSegments.length; ++j) {
                        const prevSegment = segment.allPrevSegments[j];
                        if (!done[prevSegment.id]) {
                            done[prevSegment.id] = true;
                            retv.push(prevSegment);
                        }
                    }
                }
                else {
                    done[segment.id] = true;
                    retv.push(segment);
                }
            }
            return retv;
        }
    }
    module.exports = CodePathSegment;
},
/* eslint/lib/linter/code-path-analysis/debug-helpers.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Helpers to debug for code path analysis.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const debug = require(72) /* debug */("eslint:code-path");
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Gets id of a given segment.
     * @param {CodePathSegment} segment A segment to get.
     * @returns {string} Id of the segment.
     */
    /* c8 ignore next */
    function getId(segment) {
        return segment.id + (segment.reachable ? "" : "!");
    }
    /**
     * Get string for the given node and operation.
     * @param {ASTNode} node The node to convert.
     * @param {"enter" | "exit" | undefined} label The operation label.
     * @returns {string} The string representation.
     */
    function nodeToString(node, label) {
        const suffix = label ? `:${label}` : "";
        switch (node.type) {
            case "Identifier": return `${node.type}${suffix} (${node.name})`;
            case "Literal": return `${node.type}${suffix} (${node.value})`;
            default: return `${node.type}${suffix}`;
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = {
        /**
         * A flag that debug dumping is enabled or not.
         * @type {boolean}
         */
        enabled: debug.enabled,
        /**
         * Dumps given objects.
         * @param {...any} args objects to dump.
         * @returns {void}
         */
        dump: debug,
        /**
         * Dumps the current analyzing state.
         * @param {ASTNode} node A node to dump.
         * @param {CodePathState} state A state to dump.
         * @param {boolean} leaving A flag whether or not it's leaving
         * @returns {void}
         */
        dumpState: !debug.enabled ? debug : /* c8 ignore next */ function (node, state, leaving) {
            for (let i = 0; i < state.currentSegments.length; ++i) {
                const segInternal = state.currentSegments[i].internal;
                if (leaving) {
                    const last = segInternal.nodes.length - 1;
                    if (last >= 0 && segInternal.nodes[last] === nodeToString(node, "enter")) {
                        segInternal.nodes[last] = nodeToString(node, void 0);
                    }
                    else {
                        segInternal.nodes.push(nodeToString(node, "exit"));
                    }
                }
                else {
                    segInternal.nodes.push(nodeToString(node, "enter"));
                }
            }
            debug([
                `${state.currentSegments.map(getId).join(",")})`,
                `${node.type}${leaving ? ":exit" : ""}`
            ].join(" "));
        },
        /**
         * Dumps a DOT code of a given code path.
         * The DOT code can be visualized with Graphvis.
         * @param {CodePath} codePath A code path to dump.
         * @returns {void}
         * @see http://www.graphviz.org
         * @see http://www.webgraphviz.com
         */
        dumpDot: !debug.enabled ? debug : /* c8 ignore next */ function (codePath) {
            let text = "\n" +
                "digraph {\n" +
                "node[shape=box,style=\"rounded,filled\",fillcolor=white];\n" +
                "initial[label=\"\",shape=circle,style=filled,fillcolor=black,width=0.25,height=0.25];\n";
            if (codePath.returnedSegments.length > 0) {
                text += "final[label=\"\",shape=doublecircle,style=filled,fillcolor=black,width=0.25,height=0.25];\n";
            }
            if (codePath.thrownSegments.length > 0) {
                text += "thrown[label=\"✘\",shape=circle,width=0.3,height=0.3,fixedsize];\n";
            }
            const traceMap = Object.create(null);
            const arrows = this.makeDotArrows(codePath, traceMap);
            for (const id in traceMap) { // eslint-disable-line guard-for-in -- Want ability to traverse prototype
                const segment = traceMap[id];
                text += `${id}[`;
                if (segment.reachable) {
                    text += "label=\"";
                }
                else {
                    text += "style=\"rounded,dashed,filled\",fillcolor=\"#FF9800\",label=\"<<unreachable>>\\n";
                }
                if (segment.internal.nodes.length > 0) {
                    text += segment.internal.nodes.join("\\n");
                }
                else {
                    text += "????";
                }
                text += "\"];\n";
            }
            text += `${arrows}\n`;
            text += "}";
            debug("DOT", text);
        },
        /**
         * Makes a DOT code of a given code path.
         * The DOT code can be visualized with Graphvis.
         * @param {CodePath} codePath A code path to make DOT.
         * @param {Object} traceMap Optional. A map to check whether or not segments had been done.
         * @returns {string} A DOT code of the code path.
         */
        makeDotArrows(codePath, traceMap) {
            const stack = [[codePath.initialSegment, 0]];
            const done = traceMap || Object.create(null);
            let lastId = codePath.initialSegment.id;
            let text = `initial->${codePath.initialSegment.id}`;
            while (stack.length > 0) {
                const item = stack.pop();
                const segment = item[0];
                const index = item[1];
                if (done[segment.id] && index === 0) {
                    continue;
                }
                done[segment.id] = segment;
                const nextSegment = segment.allNextSegments[index];
                if (!nextSegment) {
                    continue;
                }
                if (lastId === segment.id) {
                    text += `->${nextSegment.id}`;
                }
                else {
                    text += `;\n${segment.id}->${nextSegment.id}`;
                }
                lastId = nextSegment.id;
                stack.unshift([segment, 1 + index]);
                stack.push([nextSegment, 0]);
            }
            codePath.returnedSegments.forEach(finalSegment => {
                if (lastId === finalSegment.id) {
                    text += "->final";
                }
                else {
                    text += `;\n${finalSegment.id}->final`;
                }
                lastId = null;
            });
            codePath.thrownSegments.forEach(finalSegment => {
                if (lastId === finalSegment.id) {
                    text += "->thrown";
                }
                else {
                    text += `;\n${finalSegment.id}->thrown`;
                }
                lastId = null;
            });
            return `${text};`;
        }
    };
},
/* eslint/lib/linter/code-path-analysis/fork-context.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A class to operate forking.
     *
     * This is state of forking.
     * This has a fork list and manages it.
     *
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const assert = require("assert"), CodePathSegment = require(333) /* ./code-path-segment */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Gets whether or not a given segment is reachable.
     * @param {CodePathSegment} segment A segment to get.
     * @returns {boolean} `true` if the segment is reachable.
     */
    function isReachable(segment) {
        return segment.reachable;
    }
    /**
     * Creates new segments from the specific range of `context.segmentsList`.
     *
     * When `context.segmentsList` is `[[a, b], [c, d], [e, f]]`, `begin` is `0`, and
     * `end` is `-1`, this creates `[g, h]`. This `g` is from `a`, `c`, and `e`.
     * This `h` is from `b`, `d`, and `f`.
     * @param {ForkContext} context An instance.
     * @param {number} begin The first index of the previous segments.
     * @param {number} end The last index of the previous segments.
     * @param {Function} create A factory function of new segments.
     * @returns {CodePathSegment[]} New segments.
     */
    function makeSegments(context, begin, end, create) {
        const list = context.segmentsList;
        const normalizedBegin = begin >= 0 ? begin : list.length + begin;
        const normalizedEnd = end >= 0 ? end : list.length + end;
        const segments = [];
        for (let i = 0; i < context.count; ++i) {
            const allPrevSegments = [];
            for (let j = normalizedBegin; j <= normalizedEnd; ++j) {
                allPrevSegments.push(list[j][i]);
            }
            segments.push(create(context.idGenerator.next(), allPrevSegments));
        }
        return segments;
    }
    /**
     * `segments` becomes doubly in a `finally` block. Then if a code path exits by a
     * control statement (such as `break`, `continue`) from the `finally` block, the
     * destination's segments may be half of the source segments. In that case, this
     * merges segments.
     * @param {ForkContext} context An instance.
     * @param {CodePathSegment[]} segments Segments to merge.
     * @returns {CodePathSegment[]} The merged segments.
     */
    function mergeExtraSegments(context, segments) {
        let currentSegments = segments;
        while (currentSegments.length > context.count) {
            const merged = [];
            for (let i = 0, length = currentSegments.length / 2 | 0; i < length; ++i) {
                merged.push(CodePathSegment.newNext(context.idGenerator.next(), [currentSegments[i], currentSegments[i + length]]));
            }
            currentSegments = merged;
        }
        return currentSegments;
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * A class to manage forking.
     */
    class ForkContext {
        /**
         * @param {IdGenerator} idGenerator An identifier generator for segments.
         * @param {ForkContext|null} upper An upper fork context.
         * @param {number} count A number of parallel segments.
         */
        constructor(idGenerator, upper, count) {
            this.idGenerator = idGenerator;
            this.upper = upper;
            this.count = count;
            this.segmentsList = [];
        }
        /**
         * The head segments.
         * @type {CodePathSegment[]}
         */
        get head() {
            const list = this.segmentsList;
            return list.length === 0 ? [] : list[list.length - 1];
        }
        /**
         * A flag which shows empty.
         * @type {boolean}
         */
        get empty() {
            return this.segmentsList.length === 0;
        }
        /**
         * A flag which shows reachable.
         * @type {boolean}
         */
        get reachable() {
            const segments = this.head;
            return segments.length > 0 && segments.some(isReachable);
        }
        /**
         * Creates new segments from this context.
         * @param {number} begin The first index of previous segments.
         * @param {number} end The last index of previous segments.
         * @returns {CodePathSegment[]} New segments.
         */
        makeNext(begin, end) {
            return makeSegments(this, begin, end, CodePathSegment.newNext);
        }
        /**
         * Creates new segments from this context.
         * The new segments is always unreachable.
         * @param {number} begin The first index of previous segments.
         * @param {number} end The last index of previous segments.
         * @returns {CodePathSegment[]} New segments.
         */
        makeUnreachable(begin, end) {
            return makeSegments(this, begin, end, CodePathSegment.newUnreachable);
        }
        /**
         * Creates new segments from this context.
         * The new segments don't have connections for previous segments.
         * But these inherit the reachable flag from this context.
         * @param {number} begin The first index of previous segments.
         * @param {number} end The last index of previous segments.
         * @returns {CodePathSegment[]} New segments.
         */
        makeDisconnected(begin, end) {
            return makeSegments(this, begin, end, CodePathSegment.newDisconnected);
        }
        /**
         * Adds segments into this context.
         * The added segments become the head.
         * @param {CodePathSegment[]} segments Segments to add.
         * @returns {void}
         */
        add(segments) {
            assert(segments.length >= this.count, `${segments.length} >= ${this.count}`);
            this.segmentsList.push(mergeExtraSegments(this, segments));
        }
        /**
         * Replaces the head segments with given segments.
         * The current head segments are removed.
         * @param {CodePathSegment[]} segments Segments to add.
         * @returns {void}
         */
        replaceHead(segments) {
            assert(segments.length >= this.count, `${segments.length} >= ${this.count}`);
            this.segmentsList.splice(-1, 1, mergeExtraSegments(this, segments));
        }
        /**
         * Adds all segments of a given fork context into this context.
         * @param {ForkContext} context A fork context to add.
         * @returns {void}
         */
        addAll(context) {
            assert(context.count === this.count);
            const source = context.segmentsList;
            for (let i = 0; i < source.length; ++i) {
                this.segmentsList.push(source[i]);
            }
        }
        /**
         * Clears all segments in this context.
         * @returns {void}
         */
        clear() {
            this.segmentsList = [];
        }
        /**
         * Creates the root fork context.
         * @param {IdGenerator} idGenerator An identifier generator for segments.
         * @returns {ForkContext} New fork context.
         */
        static newRoot(idGenerator) {
            const context = new ForkContext(idGenerator, null, 1);
            context.add([CodePathSegment.newRoot(idGenerator.next())]);
            return context;
        }
        /**
         * Creates an empty fork context preceded by a given context.
         * @param {ForkContext} parentContext The parent fork context.
         * @param {boolean} forkLeavingPath A flag which shows inside of `finally` block.
         * @returns {ForkContext} New fork context.
         */
        static newEmpty(parentContext, forkLeavingPath) {
            return new ForkContext(parentContext.idGenerator, parentContext, (forkLeavingPath ? 2 : 1) * parentContext.count);
        }
    }
    module.exports = ForkContext;
},
/* eslint/lib/linter/code-path-analysis/id-generator.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A class of identifiers generator for code path segments.
     *
     * Each rule uses the identifier of code path segments to store additional
     * information of the code path.
     *
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * A generator for unique ids.
     */
    class IdGenerator {
        /**
         * @param {string} prefix Optional. A prefix of generated ids.
         */
        constructor(prefix) {
            this.prefix = String(prefix);
            this.n = 0;
        }
        /**
         * Generates id.
         * @returns {string} A generated id.
         */
        next() {
            this.n = 1 + this.n | 0;
            /* c8 ignore start */
            if (this.n < 0) {
                this.n = 1;
            } /* c8 ignore stop */
            return this.prefix + this.n;
        }
    }
    module.exports = IdGenerator;
},
/* eslint/lib/linter/apply-disable-directives.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A module that filters reported problems based on `eslint-disable` and `eslint-enable` comments
     * @author Teddy Katz
     */
    "use strict";
    const escapeRegExp = require(285) /* escape-string-regexp */;
    /**
     * Compares the locations of two objects in a source file
     * @param {{line: number, column: number}} itemA The first object
     * @param {{line: number, column: number}} itemB The second object
     * @returns {number} A value less than 1 if itemA appears before itemB in the source file, greater than 1 if
     * itemA appears after itemB in the source file, or 0 if itemA and itemB have the same location.
     */
    function compareLocations(itemA, itemB) {
        return itemA.line - itemB.line || itemA.column - itemB.column;
    }
    /**
     * Groups a set of directives into sub-arrays by their parent comment.
     * @param {Directive[]} directives Unused directives to be removed.
     * @returns {Directive[][]} Directives grouped by their parent comment.
     */
    function groupByParentComment(directives) {
        const groups = new Map();
        for (const directive of directives) {
            const { unprocessedDirective: { parentComment } } = directive;
            if (groups.has(parentComment)) {
                groups.get(parentComment).push(directive);
            }
            else {
                groups.set(parentComment, [directive]);
            }
        }
        return [...groups.values()];
    }
    /**
     * Creates removal details for a set of directives within the same comment.
     * @param {Directive[]} directives Unused directives to be removed.
     * @param {Token} commentToken The backing Comment token.
     * @returns {{ description, fix, unprocessedDirective }[]} Details for later creation of output Problems.
     */
    function createIndividualDirectivesRemoval(directives, commentToken) {
        /*
         * `commentToken.value` starts right after `//` or `/*`.
         * All calculated offsets will be relative to this index.
         */
        const commentValueStart = commentToken.range[0] + "//".length;
        // Find where the list of rules starts. `\S+` matches with the directive name (e.g. `eslint-disable-line`)
        const listStartOffset = /^\s*\S+\s+/u.exec(commentToken.value)[0].length;
        /*
         * Get the list text without any surrounding whitespace. In order to preserve the original
         * formatting, we don't want to change that whitespace.
         *
         *     // eslint-disable-line rule-one , rule-two , rule-three -- comment
         *                            ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
         */
        const listText = commentToken.value
            .slice(listStartOffset) // remove directive name and all whitespace before the list
            .split(/\s-{2,}\s/u)[0] // remove `-- comment`, if it exists
            .trimEnd(); // remove all whitespace after the list
        /*
         * We can assume that `listText` contains multiple elements.
         * Otherwise, this function wouldn't be called - if there is
         * only one rule in the list, then the whole comment must be removed.
         */
        return directives.map(directive => {
            const { ruleId } = directive;
            const regex = new RegExp(String.raw `(?:^|\s*,\s*)${escapeRegExp(ruleId)}(?:\s*,\s*|$)`, "u");
            const match = regex.exec(listText);
            const matchedText = match[0];
            const matchStartOffset = listStartOffset + match.index;
            const matchEndOffset = matchStartOffset + matchedText.length;
            const firstIndexOfComma = matchedText.indexOf(",");
            const lastIndexOfComma = matchedText.lastIndexOf(",");
            let removalStartOffset, removalEndOffset;
            if (firstIndexOfComma !== lastIndexOfComma) {
                /*
                 * Since there are two commas, this must one of the elements in the middle of the list.
                 * Matched range starts where the previous rule name ends, and ends where the next rule name starts.
                 *
                 *     // eslint-disable-line rule-one , rule-two , rule-three -- comment
                 *                                    ^^^^^^^^^^^^^^
                 *
                 * We want to remove only the content between the two commas, and also one of the commas.
                 *
                 *     // eslint-disable-line rule-one , rule-two , rule-three -- comment
                 *                                     ^^^^^^^^^^^
                 */
                removalStartOffset = matchStartOffset + firstIndexOfComma;
                removalEndOffset = matchStartOffset + lastIndexOfComma;
            }
            else {
                /*
                 * This is either the first element or the last element.
                 *
                 * If this is the first element, matched range starts where the first rule name starts
                 * and ends where the second rule name starts. This is exactly the range we want
                 * to remove so that the second rule name will start where the first one was starting
                 * and thus preserve the original formatting.
                 *
                 *     // eslint-disable-line rule-one , rule-two , rule-three -- comment
                 *                            ^^^^^^^^^^^
                 *
                 * Similarly, if this is the last element, we've already matched the range we want to
                 * remove. The previous rule name will end where the last one was ending, relative
                 * to the content on the right side.
                 *
                 *     // eslint-disable-line rule-one , rule-two , rule-three -- comment
                 *                                               ^^^^^^^^^^^^^
                 */
                removalStartOffset = matchStartOffset;
                removalEndOffset = matchEndOffset;
            }
            return {
                description: `'${ruleId}'`,
                fix: {
                    range: [
                        commentValueStart + removalStartOffset,
                        commentValueStart + removalEndOffset
                    ],
                    text: ""
                },
                unprocessedDirective: directive.unprocessedDirective
            };
        });
    }
    /**
     * Creates a description of deleting an entire unused disable comment.
     * @param {Directive[]} directives Unused directives to be removed.
     * @param {Token} commentToken The backing Comment token.
     * @returns {{ description, fix, unprocessedDirective }} Details for later creation of an output Problem.
     */
    function createCommentRemoval(directives, commentToken) {
        const { range } = commentToken;
        const ruleIds = directives.filter(directive => directive.ruleId).map(directive => `'${directive.ruleId}'`);
        return {
            description: ruleIds.length <= 2
                ? ruleIds.join(" or ")
                : `${ruleIds.slice(0, ruleIds.length - 1).join(", ")}, or ${ruleIds[ruleIds.length - 1]}`,
            fix: {
                range,
                text: " "
            },
            unprocessedDirective: directives[0].unprocessedDirective
        };
    }
    /**
     * Parses details from directives to create output Problems.
     * @param {Directive[]} allDirectives Unused directives to be removed.
     * @returns {{ description, fix, unprocessedDirective }[]} Details for later creation of output Problems.
     */
    function processUnusedDisableDirectives(allDirectives) {
        const directiveGroups = groupByParentComment(allDirectives);
        return directiveGroups.flatMap(directives => {
            const { parentComment } = directives[0].unprocessedDirective;
            const remainingRuleIds = new Set(parentComment.ruleIds);
            for (const directive of directives) {
                remainingRuleIds.delete(directive.ruleId);
            }
            return remainingRuleIds.size
                ? createIndividualDirectivesRemoval(directives, parentComment.commentToken)
                : [createCommentRemoval(directives, parentComment.commentToken)];
        });
    }
    /**
     * This is the same as the exported function, except that it
     * doesn't handle disable-line and disable-next-line directives, and it always reports unused
     * disable directives.
     * @param {Object} options options for applying directives. This is the same as the options
     * for the exported function, except that `reportUnusedDisableDirectives` is not supported
     * (this function always reports unused disable directives).
     * @returns {{problems: Problem[], unusedDisableDirectives: Problem[]}} An object with a list
     * of problems (including suppressed ones) and unused eslint-disable directives
     */
    function applyDirectives(options) {
        const problems = [];
        const usedDisableDirectives = new Set();
        for (const problem of options.problems) {
            let disableDirectivesForProblem = [];
            let nextDirectiveIndex = 0;
            while (nextDirectiveIndex < options.directives.length &&
                compareLocations(options.directives[nextDirectiveIndex], problem) <= 0) {
                const directive = options.directives[nextDirectiveIndex++];
                if (directive.ruleId === null || directive.ruleId === problem.ruleId) {
                    switch (directive.type) {
                        case "disable":
                            disableDirectivesForProblem.push(directive);
                            break;
                        case "enable":
                            disableDirectivesForProblem = [];
                            break;
                        // no default
                    }
                }
            }
            if (disableDirectivesForProblem.length > 0) {
                const suppressions = disableDirectivesForProblem.map(directive => ({
                    kind: "directive",
                    justification: directive.unprocessedDirective.justification
                }));
                if (problem.suppressions) {
                    problem.suppressions = problem.suppressions.concat(suppressions);
                }
                else {
                    problem.suppressions = suppressions;
                    usedDisableDirectives.add(disableDirectivesForProblem[disableDirectivesForProblem.length - 1]);
                }
            }
            problems.push(problem);
        }
        const unusedDisableDirectivesToReport = options.directives
            .filter(directive => directive.type === "disable" && !usedDisableDirectives.has(directive));
        const processed = processUnusedDisableDirectives(unusedDisableDirectivesToReport);
        const unusedDisableDirectives = processed
            .map(({ description, fix, unprocessedDirective }) => {
            const { parentComment, type, line, column } = unprocessedDirective;
            return {
                ruleId: null,
                message: description
                    ? `Unused eslint-disable directive (no problems were reported from ${description}).`
                    : "Unused eslint-disable directive (no problems were reported).",
                line: type === "disable-next-line" ? parentComment.commentToken.loc.start.line : line,
                column: type === "disable-next-line" ? parentComment.commentToken.loc.start.column + 1 : column,
                severity: options.reportUnusedDisableDirectives === "warn" ? 1 : 2,
                nodeType: null,
                ...options.disableFixes ? {} : { fix }
            };
        });
        return { problems, unusedDisableDirectives };
    }
    /**
     * Given a list of directive comments (i.e. metadata about eslint-disable and eslint-enable comments) and a list
     * of reported problems, adds the suppression information to the problems.
     * @param {Object} options Information about directives and problems
     * @param {{
     *      type: ("disable"|"enable"|"disable-line"|"disable-next-line"),
     *      ruleId: (string|null),
     *      line: number,
     *      column: number,
     *      justification: string
     * }} options.directives Directive comments found in the file, with one-based columns.
     * Two directive comments can only have the same location if they also have the same type (e.g. a single eslint-disable
     * comment for two different rules is represented as two directives).
     * @param {{ruleId: (string|null), line: number, column: number}[]} options.problems
     * A list of problems reported by rules, sorted by increasing location in the file, with one-based columns.
     * @param {"off" | "warn" | "error"} options.reportUnusedDisableDirectives If `"warn"` or `"error"`, adds additional problems for unused directives
     * @param {boolean} options.disableFixes If true, it doesn't make `fix` properties.
     * @returns {{ruleId: (string|null), line: number, column: number, suppressions?: {kind: string, justification: string}}[]}
     * An object with a list of reported problems, the suppressed of which contain the suppression information.
     */
    module.exports = ({ directives, disableFixes, problems, reportUnusedDisableDirectives = "off" }) => {
        const blockDirectives = directives
            .filter(directive => directive.type === "disable" || directive.type === "enable")
            .map(directive => Object.assign({}, directive, { unprocessedDirective: directive }))
            .sort(compareLocations);
        const lineDirectives = directives.flatMap(directive => {
            switch (directive.type) {
                case "disable":
                case "enable":
                    return [];
                case "disable-line":
                    return [
                        { type: "disable", line: directive.line, column: 1, ruleId: directive.ruleId, unprocessedDirective: directive },
                        { type: "enable", line: directive.line + 1, column: 0, ruleId: directive.ruleId, unprocessedDirective: directive }
                    ];
                case "disable-next-line":
                    return [
                        { type: "disable", line: directive.line + 1, column: 1, ruleId: directive.ruleId, unprocessedDirective: directive },
                        { type: "enable", line: directive.line + 2, column: 0, ruleId: directive.ruleId, unprocessedDirective: directive }
                    ];
                default:
                    throw new TypeError(`Unrecognized directive type '${directive.type}'`);
            }
        }).sort(compareLocations);
        const blockDirectivesResult = applyDirectives({
            problems,
            directives: blockDirectives,
            disableFixes,
            reportUnusedDisableDirectives
        });
        const lineDirectivesResult = applyDirectives({
            problems: blockDirectivesResult.problems,
            directives: lineDirectives,
            disableFixes,
            reportUnusedDisableDirectives
        });
        return reportUnusedDisableDirectives !== "off"
            ? lineDirectivesResult.problems
                .concat(blockDirectivesResult.unusedDisableDirectives)
                .concat(lineDirectivesResult.unusedDisableDirectives)
                .sort(compareLocations)
            : lineDirectivesResult.problems;
    };
},
/* eslint/lib/linter/config-comment-parser.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Config Comment Parser
     * @author Nicholas C. Zakas
     */
    /* eslint class-methods-use-this: off -- Methods desired on instance */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const levn = require(339) /* levn */, { Legacy: { ConfigOps } } = require(311) /* @eslint/eslintrc/universal */;
    const debug = require(72) /* debug */("eslint:config-comment-parser");
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * Object to parse ESLint configuration comments inside JavaScript files.
     * @name ConfigCommentParser
     */
    module.exports = class ConfigCommentParser {
        /**
         * Parses a list of "name:string_value" or/and "name" options divided by comma or
         * whitespace. Used for "global" and "exported" comments.
         * @param {string} string The string to parse.
         * @param {Comment} comment The comment node which has the string.
         * @returns {Object} Result map object of names and string values, or null values if no value was provided
         */
        parseStringConfig(string, comment) {
            debug("Parsing String config");
            const items = {};
            // Collapse whitespace around `:` and `,` to make parsing easier
            const trimmedString = string.replace(/\s*([:,])\s*/gu, "$1");
            trimmedString.split(/\s|,+/u).forEach(name => {
                if (!name) {
                    return;
                }
                // value defaults to null (if not provided), e.g: "foo" => ["foo", null]
                const [key, value = null] = name.split(":");
                items[key] = { value, comment };
            });
            return items;
        }
        /**
         * Parses a JSON-like config.
         * @param {string} string The string to parse.
         * @param {Object} location Start line and column of comments for potential error message.
         * @returns {({success: true, config: Object}|{success: false, error: Problem})} Result map object
         */
        parseJsonConfig(string, location) {
            debug("Parsing JSON config");
            let items = {};
            // Parses a JSON-like comment by the same way as parsing CLI option.
            try {
                items = levn.parse("Object", string) || {};
                // Some tests say that it should ignore invalid comments such as `/*eslint no-alert:abc*/`.
                // Also, commaless notations have invalid severity:
                //     "no-alert: 2 no-console: 2" --> {"no-alert": "2 no-console: 2"}
                // Should ignore that case as well.
                if (ConfigOps.isEverySeverityValid(items)) {
                    return {
                        success: true,
                        config: items
                    };
                }
            }
            catch {
                debug("Levn parsing failed; falling back to manual parsing.");
                // ignore to parse the string by a fallback.
            }
            /*
             * Optionator cannot parse commaless notations.
             * But we are supporting that. So this is a fallback for that.
             */
            items = {};
            const normalizedString = string.replace(/([-a-zA-Z0-9/]+):/gu, "\"$1\":").replace(/(\]|[0-9])\s+(?=")/u, "$1,");
            try {
                items = JSON.parse(`{${normalizedString}}`);
            }
            catch (ex) {
                debug("Manual parsing failed.");
                return {
                    success: false,
                    error: {
                        ruleId: null,
                        fatal: true,
                        severity: 2,
                        message: `Failed to parse JSON from '${normalizedString}': ${ex.message}`,
                        line: location.start.line,
                        column: location.start.column + 1
                    }
                };
            }
            return {
                success: true,
                config: items
            };
        }
        /**
         * Parses a config of values separated by comma.
         * @param {string} string The string to parse.
         * @returns {Object} Result map of values and true values
         */
        parseListConfig(string) {
            debug("Parsing list config");
            const items = {};
            string.split(",").forEach(name => {
                const trimmedName = name.trim();
                if (trimmedName) {
                    items[trimmedName] = true;
                }
            });
            return items;
        }
    };
},
/* levn/lib/index.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    (function () {
        var parseString, cast, parseType, VERSION, parsedTypeParse, parse;
        parseString = require(340) /* ./parse-string */;
        cast = require(347) /* ./cast */;
        parseType = require(348) /* type-check */.parseType;
        VERSION = '0.4.1';
        parsedTypeParse = function (parsedType, string, options) {
            options == null && (options = {});
            options.explicit == null && (options.explicit = false);
            options.customTypes == null && (options.customTypes = {});
            return cast(parseString(parsedType, string, options), parsedType, options);
        };
        parse = function (type, string, options) {
            return parsedTypeParse(parseType(type), string, options);
        };
        module.exports = {
            VERSION: VERSION,
            parse: parse,
            parsedTypeParse: parsedTypeParse
        };
    }).call(this);
},
/* levn/lib/parse-string.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    (function () {
        var reject, special, tokenRegex;
        reject = require(341) /* prelude-ls */.reject;
        function consumeOp(tokens, op) {
            if (tokens[0] === op) {
                return tokens.shift();
            }
            else {
                throw new Error("Expected '" + op + "', but got '" + tokens[0] + "' instead in " + JSON.stringify(tokens) + ".");
            }
        }
        function maybeConsumeOp(tokens, op) {
            if (tokens[0] === op) {
                return tokens.shift();
            }
        }
        function consumeList(tokens, arg$, hasDelimiters) {
            var open, close, result, untilTest;
            open = arg$[0], close = arg$[1];
            if (hasDelimiters) {
                consumeOp(tokens, open);
            }
            result = [];
            untilTest = "," + (hasDelimiters ? close : '');
            while (tokens.length && (hasDelimiters && tokens[0] !== close)) {
                result.push(consumeElement(tokens, untilTest));
                maybeConsumeOp(tokens, ',');
            }
            if (hasDelimiters) {
                consumeOp(tokens, close);
            }
            return result;
        }
        function consumeArray(tokens, hasDelimiters) {
            return consumeList(tokens, ['[', ']'], hasDelimiters);
        }
        function consumeTuple(tokens, hasDelimiters) {
            return consumeList(tokens, ['(', ')'], hasDelimiters);
        }
        function consumeFields(tokens, hasDelimiters) {
            var result, untilTest, key;
            if (hasDelimiters) {
                consumeOp(tokens, '{');
            }
            result = {};
            untilTest = "," + (hasDelimiters ? '}' : '');
            while (tokens.length && (!hasDelimiters || tokens[0] !== '}')) {
                key = consumeValue(tokens, ':');
                consumeOp(tokens, ':');
                result[key] = consumeElement(tokens, untilTest);
                maybeConsumeOp(tokens, ',');
            }
            if (hasDelimiters) {
                consumeOp(tokens, '}');
            }
            return result;
        }
        function consumeValue(tokens, untilTest) {
            var out;
            untilTest == null && (untilTest = '');
            out = '';
            while (tokens.length && -1 === untilTest.indexOf(tokens[0])) {
                out += tokens.shift();
            }
            return out;
        }
        function consumeElement(tokens, untilTest) {
            switch (tokens[0]) {
                case '[':
                    return consumeArray(tokens, true);
                case '(':
                    return consumeTuple(tokens, true);
                case '{':
                    return consumeFields(tokens, true);
                default:
                    return consumeValue(tokens, untilTest);
            }
        }
        function consumeTopLevel(tokens, types, options) {
            var ref$, type, structure, origTokens, result, finalResult, x$, y$;
            ref$ = types[0], type = ref$.type, structure = ref$.structure;
            origTokens = tokens.concat();
            if (!options.explicit && types.length === 1 && ((!type && structure) || (type === 'Array' || type === 'Object'))) {
                result = structure === 'array' || type === 'Array'
                    ? consumeArray(tokens, tokens[0] === '[')
                    : structure === 'tuple'
                        ? consumeTuple(tokens, tokens[0] === '(')
                        : consumeFields(tokens, tokens[0] === '{');
                finalResult = tokens.length ? consumeElement(structure === 'array' || type === 'Array'
                    ? (x$ = origTokens, x$.unshift('['), x$.push(']'), x$)
                    : (y$ = origTokens, y$.unshift('('), y$.push(')'), y$)) : result;
            }
            else {
                finalResult = consumeElement(tokens);
            }
            return finalResult;
        }
        special = /\[\]\(\)}{:,/.source;
        tokenRegex = RegExp('("(?:\\\\"|[^"])*")|(\'(?:\\\\\'|[^\'])*\')|(/(?:\\\\/|[^/])*/[a-zA-Z]*)|(#.*#)|([' + special + '])|([^\\s' + special + '](?:\\s*[^\\s' + special + ']+)*)|\\s*');
        module.exports = function (types, string, options) {
            var tokens, node;
            options == null && (options = {});
            if (!options.explicit && types.length === 1 && types[0].type === 'String') {
                return string;
            }
            tokens = reject(not$, string.split(tokenRegex));
            node = consumeTopLevel(tokens, types, options);
            if (!node) {
                throw new Error("Error parsing '" + string + "'.");
            }
            return node;
        };
        function not$(x) { return !x; }
    }).call(this);
},
/* prelude-ls/lib/index.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    var Func, List, Obj, Str, Num, id, isType, replicate, prelude, toString$ = {}.toString;
    Func = require(342) /* ./Func.js */;
    List = require(343) /* ./List.js */;
    Obj = require(344) /* ./Obj.js */;
    Str = require(345) /* ./Str.js */;
    Num = require(346) /* ./Num.js */;
    id = function (x) {
        return x;
    };
    isType = curry$(function (type, x) {
        return toString$.call(x).slice(8, -1) === type;
    });
    replicate = curry$(function (n, x) {
        var i$, results$ = [];
        for (i$ = 0; i$ < n; ++i$) {
            results$.push(x);
        }
        return results$;
    });
    Str.empty = List.empty;
    Str.slice = List.slice;
    Str.take = List.take;
    Str.drop = List.drop;
    Str.splitAt = List.splitAt;
    Str.takeWhile = List.takeWhile;
    Str.dropWhile = List.dropWhile;
    Str.span = List.span;
    Str.breakStr = List.breakList;
    prelude = {
        Func: Func,
        List: List,
        Obj: Obj,
        Str: Str,
        Num: Num,
        id: id,
        isType: isType,
        replicate: replicate
    };
    prelude.each = List.each;
    prelude.map = List.map;
    prelude.filter = List.filter;
    prelude.compact = List.compact;
    prelude.reject = List.reject;
    prelude.partition = List.partition;
    prelude.find = List.find;
    prelude.head = List.head;
    prelude.first = List.first;
    prelude.tail = List.tail;
    prelude.last = List.last;
    prelude.initial = List.initial;
    prelude.empty = List.empty;
    prelude.reverse = List.reverse;
    prelude.difference = List.difference;
    prelude.intersection = List.intersection;
    prelude.union = List.union;
    prelude.countBy = List.countBy;
    prelude.groupBy = List.groupBy;
    prelude.fold = List.fold;
    prelude.foldl = List.foldl;
    prelude.fold1 = List.fold1;
    prelude.foldl1 = List.foldl1;
    prelude.foldr = List.foldr;
    prelude.foldr1 = List.foldr1;
    prelude.unfoldr = List.unfoldr;
    prelude.andList = List.andList;
    prelude.orList = List.orList;
    prelude.any = List.any;
    prelude.all = List.all;
    prelude.unique = List.unique;
    prelude.uniqueBy = List.uniqueBy;
    prelude.sort = List.sort;
    prelude.sortWith = List.sortWith;
    prelude.sortBy = List.sortBy;
    prelude.sum = List.sum;
    prelude.product = List.product;
    prelude.mean = List.mean;
    prelude.average = List.average;
    prelude.concat = List.concat;
    prelude.concatMap = List.concatMap;
    prelude.flatten = List.flatten;
    prelude.maximum = List.maximum;
    prelude.minimum = List.minimum;
    prelude.maximumBy = List.maximumBy;
    prelude.minimumBy = List.minimumBy;
    prelude.scan = List.scan;
    prelude.scanl = List.scanl;
    prelude.scan1 = List.scan1;
    prelude.scanl1 = List.scanl1;
    prelude.scanr = List.scanr;
    prelude.scanr1 = List.scanr1;
    prelude.slice = List.slice;
    prelude.take = List.take;
    prelude.drop = List.drop;
    prelude.splitAt = List.splitAt;
    prelude.takeWhile = List.takeWhile;
    prelude.dropWhile = List.dropWhile;
    prelude.span = List.span;
    prelude.breakList = List.breakList;
    prelude.zip = List.zip;
    prelude.zipWith = List.zipWith;
    prelude.zipAll = List.zipAll;
    prelude.zipAllWith = List.zipAllWith;
    prelude.at = List.at;
    prelude.elemIndex = List.elemIndex;
    prelude.elemIndices = List.elemIndices;
    prelude.findIndex = List.findIndex;
    prelude.findIndices = List.findIndices;
    prelude.apply = Func.apply;
    prelude.curry = Func.curry;
    prelude.flip = Func.flip;
    prelude.fix = Func.fix;
    prelude.over = Func.over;
    prelude.split = Str.split;
    prelude.join = Str.join;
    prelude.lines = Str.lines;
    prelude.unlines = Str.unlines;
    prelude.words = Str.words;
    prelude.unwords = Str.unwords;
    prelude.chars = Str.chars;
    prelude.unchars = Str.unchars;
    prelude.repeat = Str.repeat;
    prelude.capitalize = Str.capitalize;
    prelude.camelize = Str.camelize;
    prelude.dasherize = Str.dasherize;
    prelude.values = Obj.values;
    prelude.keys = Obj.keys;
    prelude.pairsToObj = Obj.pairsToObj;
    prelude.objToPairs = Obj.objToPairs;
    prelude.listsToObj = Obj.listsToObj;
    prelude.objToLists = Obj.objToLists;
    prelude.max = Num.max;
    prelude.min = Num.min;
    prelude.negate = Num.negate;
    prelude.abs = Num.abs;
    prelude.signum = Num.signum;
    prelude.quot = Num.quot;
    prelude.rem = Num.rem;
    prelude.div = Num.div;
    prelude.mod = Num.mod;
    prelude.recip = Num.recip;
    prelude.pi = Num.pi;
    prelude.tau = Num.tau;
    prelude.exp = Num.exp;
    prelude.sqrt = Num.sqrt;
    prelude.ln = Num.ln;
    prelude.pow = Num.pow;
    prelude.sin = Num.sin;
    prelude.tan = Num.tan;
    prelude.cos = Num.cos;
    prelude.acos = Num.acos;
    prelude.asin = Num.asin;
    prelude.atan = Num.atan;
    prelude.atan2 = Num.atan2;
    prelude.truncate = Num.truncate;
    prelude.round = Num.round;
    prelude.ceiling = Num.ceiling;
    prelude.floor = Num.floor;
    prelude.isItNaN = Num.isItNaN;
    prelude.even = Num.even;
    prelude.odd = Num.odd;
    prelude.gcd = Num.gcd;
    prelude.lcm = Num.lcm;
    prelude.VERSION = '1.2.1';
    module.exports = prelude;
    function curry$(f, bound) {
        var context, _curry = function (args) {
            return f.length > 1 ? function () {
                var params = args ? args.concat() : [];
                context = bound ? context || this : this;
                return params.push.apply(params, arguments) <
                    f.length && arguments.length ?
                    _curry.call(context, params) : f.apply(context, params);
            } : f;
        };
        return _curry();
    }
},
/* prelude-ls/lib/Func.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    var apply, curry, flip, fix, over, memoize, toString$ = {}.toString;
    apply = curry$(function (f, list) {
        return f.apply(null, list);
    });
    curry = function (f) {
        return curry$(f);
    };
    flip = curry$(function (f, x, y) {
        return f(y, x);
    });
    fix = function (f) {
        return function (g) {
            return function () {
                return f(g(g)).apply(null, arguments);
            };
        }(function (g) {
            return function () {
                return f(g(g)).apply(null, arguments);
            };
        });
    };
    over = curry$(function (f, g, x, y) {
        return f(g(x), g(y));
    });
    memoize = function (f) {
        var memo;
        memo = {};
        return function () {
            var args, res$, i$, to$, key, arg;
            res$ = [];
            for (i$ = 0, to$ = arguments.length; i$ < to$; ++i$) {
                res$.push(arguments[i$]);
            }
            args = res$;
            key = (function () {
                var i$, ref$, len$, results$ = [];
                for (i$ = 0, len$ = (ref$ = args).length; i$ < len$; ++i$) {
                    arg = ref$[i$];
                    results$.push(arg + toString$.call(arg).slice(8, -1));
                }
                return results$;
            }()).join('');
            return memo[key] = key in memo
                ? memo[key]
                : f.apply(null, args);
        };
    };
    module.exports = {
        curry: curry,
        flip: flip,
        fix: fix,
        apply: apply,
        over: over,
        memoize: memoize
    };
    function curry$(f, bound) {
        var context, _curry = function (args) {
            return f.length > 1 ? function () {
                var params = args ? args.concat() : [];
                context = bound ? context || this : this;
                return params.push.apply(params, arguments) <
                    f.length && arguments.length ?
                    _curry.call(context, params) : f.apply(context, params);
            } : f;
        };
        return _curry();
    }
},
/* prelude-ls/lib/List.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    var each, map, compact, filter, reject, remove, partition, find, head, first, tail, last, initial, empty, reverse, unique, uniqueBy, fold, foldl, fold1, foldl1, foldr, foldr1, unfoldr, concat, concatMap, flatten, difference, intersection, union, countBy, groupBy, andList, orList, any, all, sort, sortWith, sortBy, sum, product, mean, average, maximum, minimum, maximumBy, minimumBy, scan, scanl, scan1, scanl1, scanr, scanr1, slice, take, drop, splitAt, takeWhile, dropWhile, span, breakList, zip, zipWith, zipAll, zipAllWith, at, elemIndex, elemIndices, findIndex, findIndices, toString$ = {}.toString;
    each = curry$(function (f, xs) {
        var i$, len$, x;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            f(x);
        }
        return xs;
    });
    map = curry$(function (f, xs) {
        var i$, len$, x, results$ = [];
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            results$.push(f(x));
        }
        return results$;
    });
    compact = function (xs) {
        var i$, len$, x, results$ = [];
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            if (x) {
                results$.push(x);
            }
        }
        return results$;
    };
    filter = curry$(function (f, xs) {
        var i$, len$, x, results$ = [];
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            if (f(x)) {
                results$.push(x);
            }
        }
        return results$;
    });
    reject = curry$(function (f, xs) {
        var i$, len$, x, results$ = [];
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            if (!f(x)) {
                results$.push(x);
            }
        }
        return results$;
    });
    remove = curry$(function (el, xs) {
        var i, x$;
        i = elemIndex(el, xs);
        x$ = xs.slice();
        if (i != null) {
            x$.splice(i, 1);
        }
        return x$;
    });
    partition = curry$(function (f, xs) {
        var passed, failed, i$, len$, x;
        passed = [];
        failed = [];
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            (f(x) ? passed : failed).push(x);
        }
        return [passed, failed];
    });
    find = curry$(function (f, xs) {
        var i$, len$, x;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            if (f(x)) {
                return x;
            }
        }
    });
    head = first = function (xs) {
        return xs[0];
    };
    tail = function (xs) {
        if (!xs.length) {
            return;
        }
        return xs.slice(1);
    };
    last = function (xs) {
        return xs[xs.length - 1];
    };
    initial = function (xs) {
        if (!xs.length) {
            return;
        }
        return xs.slice(0, -1);
    };
    empty = function (xs) {
        return !xs.length;
    };
    reverse = function (xs) {
        return xs.concat().reverse();
    };
    unique = function (xs) {
        var result, i$, len$, x;
        result = [];
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            if (!in$(x, result)) {
                result.push(x);
            }
        }
        return result;
    };
    uniqueBy = curry$(function (f, xs) {
        var seen, i$, len$, x, val, results$ = [];
        seen = [];
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            val = f(x);
            if (in$(val, seen)) {
                continue;
            }
            seen.push(val);
            results$.push(x);
        }
        return results$;
    });
    fold = foldl = curry$(function (f, memo, xs) {
        var i$, len$, x;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            memo = f(memo, x);
        }
        return memo;
    });
    fold1 = foldl1 = curry$(function (f, xs) {
        return fold(f, xs[0], xs.slice(1));
    });
    foldr = curry$(function (f, memo, xs) {
        var i$, x;
        for (i$ = xs.length - 1; i$ >= 0; --i$) {
            x = xs[i$];
            memo = f(x, memo);
        }
        return memo;
    });
    foldr1 = curry$(function (f, xs) {
        return foldr(f, xs[xs.length - 1], xs.slice(0, -1));
    });
    unfoldr = curry$(function (f, b) {
        var result, x, that;
        result = [];
        x = b;
        while ((that = f(x)) != null) {
            result.push(that[0]);
            x = that[1];
        }
        return result;
    });
    concat = function (xss) {
        return [].concat.apply([], xss);
    };
    concatMap = curry$(function (f, xs) {
        var x;
        return [].concat.apply([], (function () {
            var i$, ref$, len$, results$ = [];
            for (i$ = 0, len$ = (ref$ = xs).length; i$ < len$; ++i$) {
                x = ref$[i$];
                results$.push(f(x));
            }
            return results$;
        }()));
    });
    flatten = function (xs) {
        var x;
        return [].concat.apply([], (function () {
            var i$, ref$, len$, results$ = [];
            for (i$ = 0, len$ = (ref$ = xs).length; i$ < len$; ++i$) {
                x = ref$[i$];
                if (toString$.call(x).slice(8, -1) === 'Array') {
                    results$.push(flatten(x));
                }
                else {
                    results$.push(x);
                }
            }
            return results$;
        }()));
    };
    difference = function (xs) {
        var yss, res$, i$, to$, results, len$, x, j$, len1$, ys;
        res$ = [];
        for (i$ = 1, to$ = arguments.length; i$ < to$; ++i$) {
            res$.push(arguments[i$]);
        }
        yss = res$;
        results = [];
        outer: for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            for (j$ = 0, len1$ = yss.length; j$ < len1$; ++j$) {
                ys = yss[j$];
                if (in$(x, ys)) {
                    continue outer;
                }
            }
            results.push(x);
        }
        return results;
    };
    intersection = function (xs) {
        var yss, res$, i$, to$, results, len$, x, j$, len1$, ys;
        res$ = [];
        for (i$ = 1, to$ = arguments.length; i$ < to$; ++i$) {
            res$.push(arguments[i$]);
        }
        yss = res$;
        results = [];
        outer: for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            for (j$ = 0, len1$ = yss.length; j$ < len1$; ++j$) {
                ys = yss[j$];
                if (!in$(x, ys)) {
                    continue outer;
                }
            }
            results.push(x);
        }
        return results;
    };
    union = function () {
        var xss, res$, i$, to$, results, len$, xs, j$, len1$, x;
        res$ = [];
        for (i$ = 0, to$ = arguments.length; i$ < to$; ++i$) {
            res$.push(arguments[i$]);
        }
        xss = res$;
        results = [];
        for (i$ = 0, len$ = xss.length; i$ < len$; ++i$) {
            xs = xss[i$];
            for (j$ = 0, len1$ = xs.length; j$ < len1$; ++j$) {
                x = xs[j$];
                if (!in$(x, results)) {
                    results.push(x);
                }
            }
        }
        return results;
    };
    countBy = curry$(function (f, xs) {
        var results, i$, len$, x, key;
        results = {};
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            key = f(x);
            if (key in results) {
                results[key] += 1;
            }
            else {
                results[key] = 1;
            }
        }
        return results;
    });
    groupBy = curry$(function (f, xs) {
        var results, i$, len$, x, key;
        results = {};
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            key = f(x);
            if (key in results) {
                results[key].push(x);
            }
            else {
                results[key] = [x];
            }
        }
        return results;
    });
    andList = function (xs) {
        var i$, len$, x;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            if (!x) {
                return false;
            }
        }
        return true;
    };
    orList = function (xs) {
        var i$, len$, x;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            if (x) {
                return true;
            }
        }
        return false;
    };
    any = curry$(function (f, xs) {
        var i$, len$, x;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            if (f(x)) {
                return true;
            }
        }
        return false;
    });
    all = curry$(function (f, xs) {
        var i$, len$, x;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            if (!f(x)) {
                return false;
            }
        }
        return true;
    });
    sort = function (xs) {
        return xs.concat().sort(function (x, y) {
            if (x > y) {
                return 1;
            }
            else if (x < y) {
                return -1;
            }
            else {
                return 0;
            }
        });
    };
    sortWith = curry$(function (f, xs) {
        return xs.concat().sort(f);
    });
    sortBy = curry$(function (f, xs) {
        return xs.concat().sort(function (x, y) {
            if (f(x) > f(y)) {
                return 1;
            }
            else if (f(x) < f(y)) {
                return -1;
            }
            else {
                return 0;
            }
        });
    });
    sum = function (xs) {
        var result, i$, len$, x;
        result = 0;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            result += x;
        }
        return result;
    };
    product = function (xs) {
        var result, i$, len$, x;
        result = 1;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            result *= x;
        }
        return result;
    };
    mean = average = function (xs) {
        var sum, i$, len$, x;
        sum = 0;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            x = xs[i$];
            sum += x;
        }
        return sum / xs.length;
    };
    maximum = function (xs) {
        var max, i$, ref$, len$, x;
        max = xs[0];
        for (i$ = 0, len$ = (ref$ = xs.slice(1)).length; i$ < len$; ++i$) {
            x = ref$[i$];
            if (x > max) {
                max = x;
            }
        }
        return max;
    };
    minimum = function (xs) {
        var min, i$, ref$, len$, x;
        min = xs[0];
        for (i$ = 0, len$ = (ref$ = xs.slice(1)).length; i$ < len$; ++i$) {
            x = ref$[i$];
            if (x < min) {
                min = x;
            }
        }
        return min;
    };
    maximumBy = curry$(function (f, xs) {
        var max, i$, ref$, len$, x;
        max = xs[0];
        for (i$ = 0, len$ = (ref$ = xs.slice(1)).length; i$ < len$; ++i$) {
            x = ref$[i$];
            if (f(x) > f(max)) {
                max = x;
            }
        }
        return max;
    });
    minimumBy = curry$(function (f, xs) {
        var min, i$, ref$, len$, x;
        min = xs[0];
        for (i$ = 0, len$ = (ref$ = xs.slice(1)).length; i$ < len$; ++i$) {
            x = ref$[i$];
            if (f(x) < f(min)) {
                min = x;
            }
        }
        return min;
    });
    scan = scanl = curry$(function (f, memo, xs) {
        var last, x;
        last = memo;
        return [memo].concat((function () {
            var i$, ref$, len$, results$ = [];
            for (i$ = 0, len$ = (ref$ = xs).length; i$ < len$; ++i$) {
                x = ref$[i$];
                results$.push(last = f(last, x));
            }
            return results$;
        }()));
    });
    scan1 = scanl1 = curry$(function (f, xs) {
        if (!xs.length) {
            return;
        }
        return scan(f, xs[0], xs.slice(1));
    });
    scanr = curry$(function (f, memo, xs) {
        xs = xs.concat().reverse();
        return scan(f, memo, xs).reverse();
    });
    scanr1 = curry$(function (f, xs) {
        if (!xs.length) {
            return;
        }
        xs = xs.concat().reverse();
        return scan(f, xs[0], xs.slice(1)).reverse();
    });
    slice = curry$(function (x, y, xs) {
        return xs.slice(x, y);
    });
    take = curry$(function (n, xs) {
        if (n <= 0) {
            return xs.slice(0, 0);
        }
        else {
            return xs.slice(0, n);
        }
    });
    drop = curry$(function (n, xs) {
        if (n <= 0) {
            return xs;
        }
        else {
            return xs.slice(n);
        }
    });
    splitAt = curry$(function (n, xs) {
        return [take(n, xs), drop(n, xs)];
    });
    takeWhile = curry$(function (p, xs) {
        var len, i;
        len = xs.length;
        if (!len) {
            return xs;
        }
        i = 0;
        while (i < len && p(xs[i])) {
            i += 1;
        }
        return xs.slice(0, i);
    });
    dropWhile = curry$(function (p, xs) {
        var len, i;
        len = xs.length;
        if (!len) {
            return xs;
        }
        i = 0;
        while (i < len && p(xs[i])) {
            i += 1;
        }
        return xs.slice(i);
    });
    span = curry$(function (p, xs) {
        return [takeWhile(p, xs), dropWhile(p, xs)];
    });
    breakList = curry$(function (p, xs) {
        return span(compose$(p, not$), xs);
    });
    zip = curry$(function (xs, ys) {
        var result, len, i$, len$, i, x;
        result = [];
        len = ys.length;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            i = i$;
            x = xs[i$];
            if (i === len) {
                break;
            }
            result.push([x, ys[i]]);
        }
        return result;
    });
    zipWith = curry$(function (f, xs, ys) {
        var result, len, i$, len$, i, x;
        result = [];
        len = ys.length;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            i = i$;
            x = xs[i$];
            if (i === len) {
                break;
            }
            result.push(f(x, ys[i]));
        }
        return result;
    });
    zipAll = function () {
        var xss, res$, i$, to$, minLength, len$, xs, ref$, i, lresult$, j$, results$ = [];
        res$ = [];
        for (i$ = 0, to$ = arguments.length; i$ < to$; ++i$) {
            res$.push(arguments[i$]);
        }
        xss = res$;
        minLength = undefined;
        for (i$ = 0, len$ = xss.length; i$ < len$; ++i$) {
            xs = xss[i$];
            minLength <= (ref$ = xs.length) || (minLength = ref$);
        }
        for (i$ = 0; i$ < minLength; ++i$) {
            i = i$;
            lresult$ = [];
            for (j$ = 0, len$ = xss.length; j$ < len$; ++j$) {
                xs = xss[j$];
                lresult$.push(xs[i]);
            }
            results$.push(lresult$);
        }
        return results$;
    };
    zipAllWith = function (f) {
        var xss, res$, i$, to$, minLength, len$, xs, ref$, i, results$ = [];
        res$ = [];
        for (i$ = 1, to$ = arguments.length; i$ < to$; ++i$) {
            res$.push(arguments[i$]);
        }
        xss = res$;
        minLength = undefined;
        for (i$ = 0, len$ = xss.length; i$ < len$; ++i$) {
            xs = xss[i$];
            minLength <= (ref$ = xs.length) || (minLength = ref$);
        }
        for (i$ = 0; i$ < minLength; ++i$) {
            i = i$;
            results$.push(f.apply(null, (fn$())));
        }
        return results$;
        function fn$() {
            var i$, ref$, len$, results$ = [];
            for (i$ = 0, len$ = (ref$ = xss).length; i$ < len$; ++i$) {
                xs = ref$[i$];
                results$.push(xs[i]);
            }
            return results$;
        }
    };
    at = curry$(function (n, xs) {
        if (n < 0) {
            return xs[xs.length + n];
        }
        else {
            return xs[n];
        }
    });
    elemIndex = curry$(function (el, xs) {
        var i$, len$, i, x;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            i = i$;
            x = xs[i$];
            if (x === el) {
                return i;
            }
        }
    });
    elemIndices = curry$(function (el, xs) {
        var i$, len$, i, x, results$ = [];
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            i = i$;
            x = xs[i$];
            if (x === el) {
                results$.push(i);
            }
        }
        return results$;
    });
    findIndex = curry$(function (f, xs) {
        var i$, len$, i, x;
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            i = i$;
            x = xs[i$];
            if (f(x)) {
                return i;
            }
        }
    });
    findIndices = curry$(function (f, xs) {
        var i$, len$, i, x, results$ = [];
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
            i = i$;
            x = xs[i$];
            if (f(x)) {
                results$.push(i);
            }
        }
        return results$;
    });
    module.exports = {
        each: each,
        map: map,
        filter: filter,
        compact: compact,
        reject: reject,
        remove: remove,
        partition: partition,
        find: find,
        head: head,
        first: first,
        tail: tail,
        last: last,
        initial: initial,
        empty: empty,
        reverse: reverse,
        difference: difference,
        intersection: intersection,
        union: union,
        countBy: countBy,
        groupBy: groupBy,
        fold: fold,
        fold1: fold1,
        foldl: foldl,
        foldl1: foldl1,
        foldr: foldr,
        foldr1: foldr1,
        unfoldr: unfoldr,
        andList: andList,
        orList: orList,
        any: any,
        all: all,
        unique: unique,
        uniqueBy: uniqueBy,
        sort: sort,
        sortWith: sortWith,
        sortBy: sortBy,
        sum: sum,
        product: product,
        mean: mean,
        average: average,
        concat: concat,
        concatMap: concatMap,
        flatten: flatten,
        maximum: maximum,
        minimum: minimum,
        maximumBy: maximumBy,
        minimumBy: minimumBy,
        scan: scan,
        scan1: scan1,
        scanl: scanl,
        scanl1: scanl1,
        scanr: scanr,
        scanr1: scanr1,
        slice: slice,
        take: take,
        drop: drop,
        splitAt: splitAt,
        takeWhile: takeWhile,
        dropWhile: dropWhile,
        span: span,
        breakList: breakList,
        zip: zip,
        zipWith: zipWith,
        zipAll: zipAll,
        zipAllWith: zipAllWith,
        at: at,
        elemIndex: elemIndex,
        elemIndices: elemIndices,
        findIndex: findIndex,
        findIndices: findIndices
    };
    function curry$(f, bound) {
        var context, _curry = function (args) {
            return f.length > 1 ? function () {
                var params = args ? args.concat() : [];
                context = bound ? context || this : this;
                return params.push.apply(params, arguments) <
                    f.length && arguments.length ?
                    _curry.call(context, params) : f.apply(context, params);
            } : f;
        };
        return _curry();
    }
    function in$(x, xs) {
        var i = -1, l = xs.length >>> 0;
        while (++i < l)
            if (x === xs[i])
                return true;
        return false;
    }
    function compose$() {
        var functions = arguments;
        return function () {
            var i, result;
            result = functions[0].apply(this, arguments);
            for (i = 1; i < functions.length; ++i) {
                result = functions[i](result);
            }
            return result;
        };
    }
    function not$(x) { return !x; }
},
/* prelude-ls/lib/Obj.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    var values, keys, pairsToObj, objToPairs, listsToObj, objToLists, empty, each, map, compact, filter, reject, partition, find;
    values = function (object) {
        var i$, x, results$ = [];
        for (i$ in object) {
            x = object[i$];
            results$.push(x);
        }
        return results$;
    };
    keys = function (object) {
        var x, results$ = [];
        for (x in object) {
            results$.push(x);
        }
        return results$;
    };
    pairsToObj = function (object) {
        var i$, len$, x, resultObj$ = {};
        for (i$ = 0, len$ = object.length; i$ < len$; ++i$) {
            x = object[i$];
            resultObj$[x[0]] = x[1];
        }
        return resultObj$;
    };
    objToPairs = function (object) {
        var key, value, results$ = [];
        for (key in object) {
            value = object[key];
            results$.push([key, value]);
        }
        return results$;
    };
    listsToObj = curry$(function (keys, values) {
        var i$, len$, i, key, resultObj$ = {};
        for (i$ = 0, len$ = keys.length; i$ < len$; ++i$) {
            i = i$;
            key = keys[i$];
            resultObj$[key] = values[i];
        }
        return resultObj$;
    });
    objToLists = function (object) {
        var keys, values, key, value;
        keys = [];
        values = [];
        for (key in object) {
            value = object[key];
            keys.push(key);
            values.push(value);
        }
        return [keys, values];
    };
    empty = function (object) {
        var x;
        for (x in object) {
            return false;
        }
        return true;
    };
    each = curry$(function (f, object) {
        var i$, x;
        for (i$ in object) {
            x = object[i$];
            f(x);
        }
        return object;
    });
    map = curry$(function (f, object) {
        var k, x, resultObj$ = {};
        for (k in object) {
            x = object[k];
            resultObj$[k] = f(x);
        }
        return resultObj$;
    });
    compact = function (object) {
        var k, x, resultObj$ = {};
        for (k in object) {
            x = object[k];
            if (x) {
                resultObj$[k] = x;
            }
        }
        return resultObj$;
    };
    filter = curry$(function (f, object) {
        var k, x, resultObj$ = {};
        for (k in object) {
            x = object[k];
            if (f(x)) {
                resultObj$[k] = x;
            }
        }
        return resultObj$;
    });
    reject = curry$(function (f, object) {
        var k, x, resultObj$ = {};
        for (k in object) {
            x = object[k];
            if (!f(x)) {
                resultObj$[k] = x;
            }
        }
        return resultObj$;
    });
    partition = curry$(function (f, object) {
        var passed, failed, k, x;
        passed = {};
        failed = {};
        for (k in object) {
            x = object[k];
            (f(x) ? passed : failed)[k] = x;
        }
        return [passed, failed];
    });
    find = curry$(function (f, object) {
        var i$, x;
        for (i$ in object) {
            x = object[i$];
            if (f(x)) {
                return x;
            }
        }
    });
    module.exports = {
        values: values,
        keys: keys,
        pairsToObj: pairsToObj,
        objToPairs: objToPairs,
        listsToObj: listsToObj,
        objToLists: objToLists,
        empty: empty,
        each: each,
        map: map,
        filter: filter,
        compact: compact,
        reject: reject,
        partition: partition,
        find: find
    };
    function curry$(f, bound) {
        var context, _curry = function (args) {
            return f.length > 1 ? function () {
                var params = args ? args.concat() : [];
                context = bound ? context || this : this;
                return params.push.apply(params, arguments) <
                    f.length && arguments.length ?
                    _curry.call(context, params) : f.apply(context, params);
            } : f;
        };
        return _curry();
    }
},
/* prelude-ls/lib/Str.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    var split, join, lines, unlines, words, unwords, chars, unchars, reverse, repeat, capitalize, camelize, dasherize;
    split = curry$(function (sep, str) {
        return str.split(sep);
    });
    join = curry$(function (sep, xs) {
        return xs.join(sep);
    });
    lines = function (str) {
        if (!str.length) {
            return [];
        }
        return str.split('\n');
    };
    unlines = function (it) {
        return it.join('\n');
    };
    words = function (str) {
        if (!str.length) {
            return [];
        }
        return str.split(/[ ]+/);
    };
    unwords = function (it) {
        return it.join(' ');
    };
    chars = function (it) {
        return it.split('');
    };
    unchars = function (it) {
        return it.join('');
    };
    reverse = function (str) {
        return str.split('').reverse().join('');
    };
    repeat = curry$(function (n, str) {
        var result, i$;
        result = '';
        for (i$ = 0; i$ < n; ++i$) {
            result += str;
        }
        return result;
    });
    capitalize = function (str) {
        return str.charAt(0).toUpperCase() + str.slice(1);
    };
    camelize = function (it) {
        return it.replace(/[-_]+(.)?/g, function (arg$, c) {
            return (c != null ? c : '').toUpperCase();
        });
    };
    dasherize = function (str) {
        return str.replace(/([^-A-Z])([A-Z]+)/g, function (arg$, lower, upper) {
            return lower + "-" + (upper.length > 1
                ? upper
                : upper.toLowerCase());
        }).replace(/^([A-Z]+)/, function (arg$, upper) {
            if (upper.length > 1) {
                return upper + "-";
            }
            else {
                return upper.toLowerCase();
            }
        });
    };
    module.exports = {
        split: split,
        join: join,
        lines: lines,
        unlines: unlines,
        words: words,
        unwords: unwords,
        chars: chars,
        unchars: unchars,
        reverse: reverse,
        repeat: repeat,
        capitalize: capitalize,
        camelize: camelize,
        dasherize: dasherize
    };
    function curry$(f, bound) {
        var context, _curry = function (args) {
            return f.length > 1 ? function () {
                var params = args ? args.concat() : [];
                context = bound ? context || this : this;
                return params.push.apply(params, arguments) <
                    f.length && arguments.length ?
                    _curry.call(context, params) : f.apply(context, params);
            } : f;
        };
        return _curry();
    }
},
/* prelude-ls/lib/Num.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    var max, min, negate, abs, signum, quot, rem, div, mod, recip, pi, tau, exp, sqrt, ln, pow, sin, tan, cos, asin, acos, atan, atan2, truncate, round, ceiling, floor, isItNaN, even, odd, gcd, lcm;
    max = curry$(function (x$, y$) {
        return x$ > y$ ? x$ : y$;
    });
    min = curry$(function (x$, y$) {
        return x$ < y$ ? x$ : y$;
    });
    negate = function (x) {
        return -x;
    };
    abs = Math.abs;
    signum = function (x) {
        if (x < 0) {
            return -1;
        }
        else if (x > 0) {
            return 1;
        }
        else {
            return 0;
        }
    };
    quot = curry$(function (x, y) {
        return ~~(x / y);
    });
    rem = curry$(function (x$, y$) {
        return x$ % y$;
    });
    div = curry$(function (x, y) {
        return Math.floor(x / y);
    });
    mod = curry$(function (x$, y$) {
        var ref$;
        return ((x$) % (ref$ = y$) + ref$) % ref$;
    });
    recip = (function (it) {
        return 1 / it;
    });
    pi = Math.PI;
    tau = pi * 2;
    exp = Math.exp;
    sqrt = Math.sqrt;
    ln = Math.log;
    pow = curry$(function (x$, y$) {
        return Math.pow(x$, y$);
    });
    sin = Math.sin;
    tan = Math.tan;
    cos = Math.cos;
    asin = Math.asin;
    acos = Math.acos;
    atan = Math.atan;
    atan2 = curry$(function (x, y) {
        return Math.atan2(x, y);
    });
    truncate = function (x) {
        return ~~x;
    };
    round = Math.round;
    ceiling = Math.ceil;
    floor = Math.floor;
    isItNaN = function (x) {
        return x !== x;
    };
    even = function (x) {
        return x % 2 === 0;
    };
    odd = function (x) {
        return x % 2 !== 0;
    };
    gcd = curry$(function (x, y) {
        var z;
        x = Math.abs(x);
        y = Math.abs(y);
        while (y !== 0) {
            z = x % y;
            x = y;
            y = z;
        }
        return x;
    });
    lcm = curry$(function (x, y) {
        return Math.abs(Math.floor(x / gcd(x, y) * y));
    });
    module.exports = {
        max: max,
        min: min,
        negate: negate,
        abs: abs,
        signum: signum,
        quot: quot,
        rem: rem,
        div: div,
        mod: mod,
        recip: recip,
        pi: pi,
        tau: tau,
        exp: exp,
        sqrt: sqrt,
        ln: ln,
        pow: pow,
        sin: sin,
        tan: tan,
        cos: cos,
        acos: acos,
        asin: asin,
        atan: atan,
        atan2: atan2,
        truncate: truncate,
        round: round,
        ceiling: ceiling,
        floor: floor,
        isItNaN: isItNaN,
        even: even,
        odd: odd,
        gcd: gcd,
        lcm: lcm
    };
    function curry$(f, bound) {
        var context, _curry = function (args) {
            return f.length > 1 ? function () {
                var params = args ? args.concat() : [];
                context = bound ? context || this : this;
                return params.push.apply(params, arguments) <
                    f.length && arguments.length ?
                    _curry.call(context, params) : f.apply(context, params);
            } : f;
        };
        return _curry();
    }
},
/* levn/lib/cast.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    (function () {
        var parsedTypeCheck, types, toString$ = {}.toString;
        parsedTypeCheck = require(348) /* type-check */.parsedTypeCheck;
        types = {
            '*': function (value, options) {
                switch (toString$.call(value).slice(8, -1)) {
                    case 'Array':
                        return typeCast(value, {
                            type: 'Array'
                        }, options);
                    case 'Object':
                        return typeCast(value, {
                            type: 'Object'
                        }, options);
                    default:
                        return {
                            type: 'Just',
                            value: typesCast(value, [
                                {
                                    type: 'Undefined'
                                }, {
                                    type: 'Null'
                                }, {
                                    type: 'NaN'
                                }, {
                                    type: 'Boolean'
                                }, {
                                    type: 'Number'
                                }, {
                                    type: 'Date'
                                }, {
                                    type: 'RegExp'
                                }, {
                                    type: 'Array'
                                }, {
                                    type: 'Object'
                                }, {
                                    type: 'String'
                                }
                            ], (options.explicit = true, options))
                        };
                }
            },
            Undefined: function (it) {
                if (it === 'undefined' || it === void 8) {
                    return {
                        type: 'Just',
                        value: void 8
                    };
                }
                else {
                    return {
                        type: 'Nothing'
                    };
                }
            },
            Null: function (it) {
                if (it === 'null') {
                    return {
                        type: 'Just',
                        value: null
                    };
                }
                else {
                    return {
                        type: 'Nothing'
                    };
                }
            },
            NaN: function (it) {
                if (it === 'NaN') {
                    return {
                        type: 'Just',
                        value: NaN
                    };
                }
                else {
                    return {
                        type: 'Nothing'
                    };
                }
            },
            Boolean: function (it) {
                if (it === 'true') {
                    return {
                        type: 'Just',
                        value: true
                    };
                }
                else if (it === 'false') {
                    return {
                        type: 'Just',
                        value: false
                    };
                }
                else {
                    return {
                        type: 'Nothing'
                    };
                }
            },
            Number: function (it) {
                return {
                    type: 'Just',
                    value: +it
                };
            },
            Int: function (it) {
                return {
                    type: 'Just',
                    value: +it
                };
            },
            Float: function (it) {
                return {
                    type: 'Just',
                    value: +it
                };
            },
            Date: function (value, options) {
                var that;
                if (that = /^\#([\s\S]*)\#$/.exec(value)) {
                    return {
                        type: 'Just',
                        value: new Date(+that[1] || that[1])
                    };
                }
                else if (options.explicit) {
                    return {
                        type: 'Nothing'
                    };
                }
                else {
                    return {
                        type: 'Just',
                        value: new Date(+value || value)
                    };
                }
            },
            RegExp: function (value, options) {
                var that;
                if (that = /^\/([\s\S]*)\/([gimy]*)$/.exec(value)) {
                    return {
                        type: 'Just',
                        value: new RegExp(that[1], that[2])
                    };
                }
                else if (options.explicit) {
                    return {
                        type: 'Nothing'
                    };
                }
                else {
                    return {
                        type: 'Just',
                        value: new RegExp(value)
                    };
                }
            },
            Array: function (value, options) {
                return castArray(value, {
                    of: [{
                            type: '*'
                        }]
                }, options);
            },
            Object: function (value, options) {
                return castFields(value, {
                    of: {}
                }, options);
            },
            String: function (it) {
                var replace, that;
                if (toString$.call(it).slice(8, -1) !== 'String') {
                    return {
                        type: 'Nothing'
                    };
                }
                replace = function (value, quote) {
                    return value.replace(/\\([^u]|u[0-9a-fA-F]{4})/g, function (all, escaped) {
                        switch (escaped[0]) {
                            case quote:
                                return quote;
                            case '\\':
                                return '\\';
                            case 'b':
                                return '\b';
                            case 'f':
                                return '\f';
                            case 'n':
                                return '\n';
                            case 'r':
                                return '\r';
                            case 't':
                                return '\t';
                            case 'u':
                                return JSON.parse("\"" + all + "\"");
                            default:
                                return escaped;
                        }
                    });
                };
                if (that = it.match(/^'([\s\S]*)'$/)) {
                    return {
                        type: 'Just',
                        value: replace(that[1], "'")
                    };
                }
                else if (that = it.match(/^"([\s\S]*)"$/)) {
                    return {
                        type: 'Just',
                        value: replace(that[1], '"')
                    };
                }
                else {
                    return {
                        type: 'Just',
                        value: it
                    };
                }
            }
        };
        function castArray(node, type, options) {
            var typeOf, element;
            if (toString$.call(node).slice(8, -1) !== 'Array') {
                return {
                    type: 'Nothing'
                };
            }
            typeOf = type.of;
            return {
                type: 'Just',
                value: (function () {
                    var i$, ref$, len$, results$ = [];
                    for (i$ = 0, len$ = (ref$ = node).length; i$ < len$; ++i$) {
                        element = ref$[i$];
                        results$.push(typesCast(element, typeOf, options));
                    }
                    return results$;
                }())
            };
        }
        function castTuple(node, type, options) {
            var result, i, i$, ref$, len$, types, cast;
            if (toString$.call(node).slice(8, -1) !== 'Array') {
                return {
                    type: 'Nothing'
                };
            }
            result = [];
            i = 0;
            for (i$ = 0, len$ = (ref$ = type.of).length; i$ < len$; ++i$) {
                types = ref$[i$];
                cast = typesCast(node[i], types, options);
                if (toString$.call(cast).slice(8, -1) !== 'Undefined') {
                    result.push(cast);
                }
                i++;
            }
            if (node.length <= i) {
                return {
                    type: 'Just',
                    value: result
                };
            }
            else {
                return {
                    type: 'Nothing'
                };
            }
        }
        function castFields(node, type, options) {
            var typeOf, key, value;
            if (toString$.call(node).slice(8, -1) !== 'Object') {
                return {
                    type: 'Nothing'
                };
            }
            typeOf = type.of;
            return {
                type: 'Just',
                value: (function () {
                    var ref$, resultObj$ = {};
                    for (key in ref$ = node) {
                        value = ref$[key];
                        resultObj$[typesCast(key, [{
                                type: 'String'
                            }], options)] = typesCast(value, typeOf[key] || [{
                                type: '*'
                            }], options);
                    }
                    return resultObj$;
                }())
            };
        }
        function typeCast(node, typeObj, options) {
            var type, structure, castFunc, ref$;
            type = typeObj.type, structure = typeObj.structure;
            if (type) {
                castFunc = ((ref$ = options.customTypes[type]) != null ? ref$.cast : void 8) || types[type];
                if (!castFunc) {
                    throw new Error("Type not defined: " + type + ".");
                }
                return castFunc(node, options, typesCast);
            }
            else {
                switch (structure) {
                    case 'array':
                        return castArray(node, typeObj, options);
                    case 'tuple':
                        return castTuple(node, typeObj, options);
                    case 'fields':
                        return castFields(node, typeObj, options);
                }
            }
        }
        function typesCast(node, types, options) {
            var i$, len$, type, ref$, valueType, value;
            for (i$ = 0, len$ = types.length; i$ < len$; ++i$) {
                type = types[i$];
                ref$ = typeCast(node, type, options), valueType = ref$.type, value = ref$.value;
                if (valueType === 'Nothing') {
                    continue;
                }
                if (parsedTypeCheck([type], value, {
                    customTypes: options.customTypes
                })) {
                    return value;
                }
            }
            throw new Error("Value " + JSON.stringify(node) + " does not type check against " + JSON.stringify(types) + ".");
        }
        module.exports = function (node, types, options) {
            if (!options.explicit && types.length === 1 && types[0].type === 'String') {
                return node;
            }
            return typesCast(node, types, options);
        };
    }).call(this);
},
/* type-check/lib/index.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    (function () {
        var VERSION, parseType, parsedTypeCheck, typeCheck;
        VERSION = '0.4.0';
        parseType = require(349) /* ./parse-type */;
        parsedTypeCheck = require(350) /* ./check */;
        typeCheck = function (type, input, options) {
            return parsedTypeCheck(parseType(type), input, options);
        };
        module.exports = {
            VERSION: VERSION,
            typeCheck: typeCheck,
            parsedTypeCheck: parsedTypeCheck,
            parseType: parseType
        };
    }).call(this);
},
/* type-check/lib/parse-type.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    (function () {
        var identifierRegex, tokenRegex;
        identifierRegex = /[\$\w]+/;
        function peek(tokens) {
            var token;
            token = tokens[0];
            if (token == null) {
                throw new Error('Unexpected end of input.');
            }
            return token;
        }
        function consumeIdent(tokens) {
            var token;
            token = peek(tokens);
            if (!identifierRegex.test(token)) {
                throw new Error("Expected text, got '" + token + "' instead.");
            }
            return tokens.shift();
        }
        function consumeOp(tokens, op) {
            var token;
            token = peek(tokens);
            if (token !== op) {
                throw new Error("Expected '" + op + "', got '" + token + "' instead.");
            }
            return tokens.shift();
        }
        function maybeConsumeOp(tokens, op) {
            var token;
            token = tokens[0];
            if (token === op) {
                return tokens.shift();
            }
            else {
                return null;
            }
        }
        function consumeArray(tokens) {
            var types;
            consumeOp(tokens, '[');
            if (peek(tokens) === ']') {
                throw new Error("Must specify type of Array - eg. [Type], got [] instead.");
            }
            types = consumeTypes(tokens);
            consumeOp(tokens, ']');
            return {
                structure: 'array',
                of: types
            };
        }
        function consumeTuple(tokens) {
            var components;
            components = [];
            consumeOp(tokens, '(');
            if (peek(tokens) === ')') {
                throw new Error("Tuple must be of at least length 1 - eg. (Type), got () instead.");
            }
            for (;;) {
                components.push(consumeTypes(tokens));
                maybeConsumeOp(tokens, ',');
                if (')' === peek(tokens)) {
                    break;
                }
            }
            consumeOp(tokens, ')');
            return {
                structure: 'tuple',
                of: components
            };
        }
        function consumeFields(tokens) {
            var fields, subset, ref$, key, types;
            fields = {};
            consumeOp(tokens, '{');
            subset = false;
            for (;;) {
                if (maybeConsumeOp(tokens, '...')) {
                    subset = true;
                    break;
                }
                ref$ = consumeField(tokens), key = ref$[0], types = ref$[1];
                fields[key] = types;
                maybeConsumeOp(tokens, ',');
                if ('}' === peek(tokens)) {
                    break;
                }
            }
            consumeOp(tokens, '}');
            return {
                structure: 'fields',
                of: fields,
                subset: subset
            };
        }
        function consumeField(tokens) {
            var key, types;
            key = consumeIdent(tokens);
            consumeOp(tokens, ':');
            types = consumeTypes(tokens);
            return [key, types];
        }
        function maybeConsumeStructure(tokens) {
            switch (tokens[0]) {
                case '[':
                    return consumeArray(tokens);
                case '(':
                    return consumeTuple(tokens);
                case '{':
                    return consumeFields(tokens);
            }
        }
        function consumeType(tokens) {
            var token, wildcard, type, structure;
            token = peek(tokens);
            wildcard = token === '*';
            if (wildcard || identifierRegex.test(token)) {
                type = wildcard
                    ? consumeOp(tokens, '*')
                    : consumeIdent(tokens);
                structure = maybeConsumeStructure(tokens);
                if (structure) {
                    return structure.type = type, structure;
                }
                else {
                    return {
                        type: type
                    };
                }
            }
            else {
                structure = maybeConsumeStructure(tokens);
                if (!structure) {
                    throw new Error("Unexpected character: " + token);
                }
                return structure;
            }
        }
        function consumeTypes(tokens) {
            var lookahead, types, typesSoFar, typeObj, type, structure;
            if ('::' === peek(tokens)) {
                throw new Error("No comment before comment separator '::' found.");
            }
            lookahead = tokens[1];
            if (lookahead != null && lookahead === '::') {
                tokens.shift();
                tokens.shift();
            }
            types = [];
            typesSoFar = {};
            if ('Maybe' === peek(tokens)) {
                tokens.shift();
                types = [
                    {
                        type: 'Undefined'
                    }, {
                        type: 'Null'
                    }
                ];
                typesSoFar = {
                    Undefined: true,
                    Null: true
                };
            }
            for (;;) {
                typeObj = consumeType(tokens), type = typeObj.type, structure = typeObj.structure;
                if (!typesSoFar[type]) {
                    types.push(typeObj);
                }
                if (structure == null) {
                    typesSoFar[type] = true;
                }
                if (!maybeConsumeOp(tokens, '|')) {
                    break;
                }
            }
            return types;
        }
        tokenRegex = RegExp('\\.\\.\\.|::|->|' + identifierRegex.source + '|\\S', 'g');
        module.exports = function (input) {
            var tokens, e;
            if (!input.length) {
                throw new Error('No type specified.');
            }
            tokens = input.match(tokenRegex) || [];
            if (in$('->', tokens)) {
                throw new Error("Function types are not supported.\ To validate that something is a function, you may use 'Function'.");
            }
            try {
                return consumeTypes(tokens);
            }
            catch (e$) {
                e = e$;
                throw new Error(e.message + " - Remaining tokens: " + JSON.stringify(tokens) + " - Initial input: '" + input + "'");
            }
        };
        function in$(x, xs) {
            var i = -1, l = xs.length >>> 0;
            while (++i < l)
                if (x === xs[i])
                    return true;
            return false;
        }
    }).call(this);
},
/* type-check/lib/check.js */ function _(require, module, exports, __esModule, __esExport) {
    // Generated by LiveScript 1.6.0
    (function () {
        var ref$, any, all, isItNaN, types, defaultType, toString$ = {}.toString;
        ref$ = require(341) /* prelude-ls */, any = ref$.any, all = ref$.all, isItNaN = ref$.isItNaN;
        types = {
            Number: {
                typeOf: 'Number',
                validate: function (it) {
                    return !isItNaN(it);
                }
            },
            NaN: {
                typeOf: 'Number',
                validate: isItNaN
            },
            Int: {
                typeOf: 'Number',
                validate: function (it) {
                    return !isItNaN(it) && it % 1 === 0;
                }
            },
            Float: {
                typeOf: 'Number',
                validate: function (it) {
                    return !isItNaN(it);
                }
            },
            Date: {
                typeOf: 'Date',
                validate: function (it) {
                    return !isItNaN(it.getTime());
                }
            }
        };
        defaultType = {
            array: 'Array',
            tuple: 'Array'
        };
        function checkArray(input, type, options) {
            return all(function (it) {
                return checkMultiple(it, type.of, options);
            }, input);
        }
        function checkTuple(input, type, options) {
            var i, i$, ref$, len$, types;
            i = 0;
            for (i$ = 0, len$ = (ref$ = type.of).length; i$ < len$; ++i$) {
                types = ref$[i$];
                if (!checkMultiple(input[i], types, options)) {
                    return false;
                }
                i++;
            }
            return input.length <= i;
        }
        function checkFields(input, type, options) {
            var inputKeys, numInputKeys, k, numOfKeys, key, ref$, types;
            inputKeys = {};
            numInputKeys = 0;
            for (k in input) {
                inputKeys[k] = true;
                numInputKeys++;
            }
            numOfKeys = 0;
            for (key in ref$ = type.of) {
                types = ref$[key];
                if (!checkMultiple(input[key], types, options)) {
                    return false;
                }
                if (inputKeys[key]) {
                    numOfKeys++;
                }
            }
            return type.subset || numInputKeys === numOfKeys;
        }
        function checkStructure(input, type, options) {
            if (!(input instanceof Object)) {
                return false;
            }
            switch (type.structure) {
                case 'fields':
                    return checkFields(input, type, options);
                case 'array':
                    return checkArray(input, type, options);
                case 'tuple':
                    return checkTuple(input, type, options);
            }
        }
        function check(input, typeObj, options) {
            var type, structure, setting, that;
            type = typeObj.type, structure = typeObj.structure;
            if (type) {
                if (type === '*') {
                    return true;
                }
                setting = options.customTypes[type] || types[type];
                if (setting) {
                    return (setting.typeOf === void 8 || setting.typeOf === toString$.call(input).slice(8, -1)) && setting.validate(input);
                }
                else {
                    return type === toString$.call(input).slice(8, -1) && (!structure || checkStructure(input, typeObj, options));
                }
            }
            else if (structure) {
                if (that = defaultType[structure]) {
                    if (that !== toString$.call(input).slice(8, -1)) {
                        return false;
                    }
                }
                return checkStructure(input, typeObj, options);
            }
            else {
                throw new Error("No type defined. Input: " + input + ".");
            }
        }
        function checkMultiple(input, types, options) {
            if (toString$.call(types).slice(8, -1) !== 'Array') {
                throw new Error("Types must be in an array. Input: " + input + ".");
            }
            return any(function (it) {
                return check(input, it, options);
            }, types);
        }
        module.exports = function (parsedType, input, options) {
            options == null && (options = {});
            if (options.customTypes == null) {
                options.customTypes = {};
            }
            return checkMultiple(input, parsedType, options);
        };
    }).call(this);
},
/* eslint/lib/linter/node-event-generator.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview The event generator for AST nodes.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const esquery = require(352) /* esquery */;
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /**
     * An object describing an AST selector
     * @typedef {Object} ASTSelector
     * @property {string} rawSelector The string that was parsed into this selector
     * @property {boolean} isExit `true` if this should be emitted when exiting the node rather than when entering
     * @property {Object} parsedSelector An object (from esquery) describing the matching behavior of the selector
     * @property {string[]|null} listenerTypes A list of node types that could possibly cause the selector to match,
     * or `null` if all node types could cause a match
     * @property {number} attributeCount The total number of classes, pseudo-classes, and attribute queries in this selector
     * @property {number} identifierCount The total number of identifier queries in this selector
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Computes the union of one or more arrays
     * @param {...any[]} arrays One or more arrays to union
     * @returns {any[]} The union of the input arrays
     */
    function union(...arrays) {
        return [...new Set(arrays.flat())];
    }
    /**
     * Computes the intersection of one or more arrays
     * @param {...any[]} arrays One or more arrays to intersect
     * @returns {any[]} The intersection of the input arrays
     */
    function intersection(...arrays) {
        if (arrays.length === 0) {
            return [];
        }
        let result = [...new Set(arrays[0])];
        for (const array of arrays.slice(1)) {
            result = result.filter(x => array.includes(x));
        }
        return result;
    }
    /**
     * Gets the possible types of a selector
     * @param {Object} parsedSelector An object (from esquery) describing the matching behavior of the selector
     * @returns {string[]|null} The node types that could possibly trigger this selector, or `null` if all node types could trigger it
     */
    function getPossibleTypes(parsedSelector) {
        switch (parsedSelector.type) {
            case "identifier":
                return [parsedSelector.value];
            case "matches": {
                const typesForComponents = parsedSelector.selectors.map(getPossibleTypes);
                if (typesForComponents.every(Boolean)) {
                    return union(...typesForComponents);
                }
                return null;
            }
            case "compound": {
                const typesForComponents = parsedSelector.selectors.map(getPossibleTypes).filter(typesForComponent => typesForComponent);
                // If all of the components could match any type, then the compound could also match any type.
                if (!typesForComponents.length) {
                    return null;
                }
                /*
                 * If at least one of the components could only match a particular type, the compound could only match
                 * the intersection of those types.
                 */
                return intersection(...typesForComponents);
            }
            case "child":
            case "descendant":
            case "sibling":
            case "adjacent":
                return getPossibleTypes(parsedSelector.right);
            case "class":
                if (parsedSelector.name === "function") {
                    return ["FunctionDeclaration", "FunctionExpression", "ArrowFunctionExpression"];
                }
                return null;
            default:
                return null;
        }
    }
    /**
     * Counts the number of class, pseudo-class, and attribute queries in this selector
     * @param {Object} parsedSelector An object (from esquery) describing the selector's matching behavior
     * @returns {number} The number of class, pseudo-class, and attribute queries in this selector
     */
    function countClassAttributes(parsedSelector) {
        switch (parsedSelector.type) {
            case "child":
            case "descendant":
            case "sibling":
            case "adjacent":
                return countClassAttributes(parsedSelector.left) + countClassAttributes(parsedSelector.right);
            case "compound":
            case "not":
            case "matches":
                return parsedSelector.selectors.reduce((sum, childSelector) => sum + countClassAttributes(childSelector), 0);
            case "attribute":
            case "field":
            case "nth-child":
            case "nth-last-child":
                return 1;
            default:
                return 0;
        }
    }
    /**
     * Counts the number of identifier queries in this selector
     * @param {Object} parsedSelector An object (from esquery) describing the selector's matching behavior
     * @returns {number} The number of identifier queries
     */
    function countIdentifiers(parsedSelector) {
        switch (parsedSelector.type) {
            case "child":
            case "descendant":
            case "sibling":
            case "adjacent":
                return countIdentifiers(parsedSelector.left) + countIdentifiers(parsedSelector.right);
            case "compound":
            case "not":
            case "matches":
                return parsedSelector.selectors.reduce((sum, childSelector) => sum + countIdentifiers(childSelector), 0);
            case "identifier":
                return 1;
            default:
                return 0;
        }
    }
    /**
     * Compares the specificity of two selector objects, with CSS-like rules.
     * @param {ASTSelector} selectorA An AST selector descriptor
     * @param {ASTSelector} selectorB Another AST selector descriptor
     * @returns {number}
     * a value less than 0 if selectorA is less specific than selectorB
     * a value greater than 0 if selectorA is more specific than selectorB
     * a value less than 0 if selectorA and selectorB have the same specificity, and selectorA <= selectorB alphabetically
     * a value greater than 0 if selectorA and selectorB have the same specificity, and selectorA > selectorB alphabetically
     */
    function compareSpecificity(selectorA, selectorB) {
        return selectorA.attributeCount - selectorB.attributeCount ||
            selectorA.identifierCount - selectorB.identifierCount ||
            (selectorA.rawSelector <= selectorB.rawSelector ? -1 : 1);
    }
    /**
     * Parses a raw selector string, and throws a useful error if parsing fails.
     * @param {string} rawSelector A raw AST selector
     * @returns {Object} An object (from esquery) describing the matching behavior of this selector
     * @throws {Error} An error if the selector is invalid
     */
    function tryParseSelector(rawSelector) {
        try {
            return esquery.parse(rawSelector.replace(/:exit$/u, ""));
        }
        catch (err) {
            if (err.location && err.location.start && typeof err.location.start.offset === "number") {
                throw new SyntaxError(`Syntax error in selector "${rawSelector}" at position ${err.location.start.offset}: ${err.message}`);
            }
            throw err;
        }
    }
    const selectorCache = new Map();
    /**
     * Parses a raw selector string, and returns the parsed selector along with specificity and type information.
     * @param {string} rawSelector A raw AST selector
     * @returns {ASTSelector} A selector descriptor
     */
    function parseSelector(rawSelector) {
        if (selectorCache.has(rawSelector)) {
            return selectorCache.get(rawSelector);
        }
        const parsedSelector = tryParseSelector(rawSelector);
        const result = {
            rawSelector,
            isExit: rawSelector.endsWith(":exit"),
            parsedSelector,
            listenerTypes: getPossibleTypes(parsedSelector),
            attributeCount: countClassAttributes(parsedSelector),
            identifierCount: countIdentifiers(parsedSelector)
        };
        selectorCache.set(rawSelector, result);
        return result;
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * The event generator for AST nodes.
     * This implements below interface.
     *
     * ```ts
     * interface EventGenerator {
     *     emitter: SafeEmitter;
     *     enterNode(node: ASTNode): void;
     *     leaveNode(node: ASTNode): void;
     * }
     * ```
     */
    class NodeEventGenerator {
        /**
         * @param {SafeEmitter} emitter
         * An SafeEmitter which is the destination of events. This emitter must already
         * have registered listeners for all of the events that it needs to listen for.
         * (See lib/linter/safe-emitter.js for more details on `SafeEmitter`.)
         * @param {ESQueryOptions} esqueryOptions `esquery` options for traversing custom nodes.
         * @returns {NodeEventGenerator} new instance
         */
        constructor(emitter, esqueryOptions) {
            this.emitter = emitter;
            this.esqueryOptions = esqueryOptions;
            this.currentAncestry = [];
            this.enterSelectorsByNodeType = new Map();
            this.exitSelectorsByNodeType = new Map();
            this.anyTypeEnterSelectors = [];
            this.anyTypeExitSelectors = [];
            emitter.eventNames().forEach(rawSelector => {
                const selector = parseSelector(rawSelector);
                if (selector.listenerTypes) {
                    const typeMap = selector.isExit ? this.exitSelectorsByNodeType : this.enterSelectorsByNodeType;
                    selector.listenerTypes.forEach(nodeType => {
                        if (!typeMap.has(nodeType)) {
                            typeMap.set(nodeType, []);
                        }
                        typeMap.get(nodeType).push(selector);
                    });
                    return;
                }
                const selectors = selector.isExit ? this.anyTypeExitSelectors : this.anyTypeEnterSelectors;
                selectors.push(selector);
            });
            this.anyTypeEnterSelectors.sort(compareSpecificity);
            this.anyTypeExitSelectors.sort(compareSpecificity);
            this.enterSelectorsByNodeType.forEach(selectorList => selectorList.sort(compareSpecificity));
            this.exitSelectorsByNodeType.forEach(selectorList => selectorList.sort(compareSpecificity));
        }
        /**
         * Checks a selector against a node, and emits it if it matches
         * @param {ASTNode} node The node to check
         * @param {ASTSelector} selector An AST selector descriptor
         * @returns {void}
         */
        applySelector(node, selector) {
            if (esquery.matches(node, selector.parsedSelector, this.currentAncestry, this.esqueryOptions)) {
                this.emitter.emit(selector.rawSelector, node);
            }
        }
        /**
         * Applies all appropriate selectors to a node, in specificity order
         * @param {ASTNode} node The node to check
         * @param {boolean} isExit `false` if the node is currently being entered, `true` if it's currently being exited
         * @returns {void}
         */
        applySelectors(node, isExit) {
            const selectorsByNodeType = (isExit ? this.exitSelectorsByNodeType : this.enterSelectorsByNodeType).get(node.type) || [];
            const anyTypeSelectors = isExit ? this.anyTypeExitSelectors : this.anyTypeEnterSelectors;
            /*
             * selectorsByNodeType and anyTypeSelectors were already sorted by specificity in the constructor.
             * Iterate through each of them, applying selectors in the right order.
             */
            let selectorsByTypeIndex = 0;
            let anyTypeSelectorsIndex = 0;
            while (selectorsByTypeIndex < selectorsByNodeType.length || anyTypeSelectorsIndex < anyTypeSelectors.length) {
                if (selectorsByTypeIndex >= selectorsByNodeType.length ||
                    anyTypeSelectorsIndex < anyTypeSelectors.length &&
                        compareSpecificity(anyTypeSelectors[anyTypeSelectorsIndex], selectorsByNodeType[selectorsByTypeIndex]) < 0) {
                    this.applySelector(node, anyTypeSelectors[anyTypeSelectorsIndex++]);
                }
                else {
                    this.applySelector(node, selectorsByNodeType[selectorsByTypeIndex++]);
                }
            }
        }
        /**
         * Emits an event of entering AST node.
         * @param {ASTNode} node A node which was entered.
         * @returns {void}
         */
        enterNode(node) {
            if (node.parent) {
                this.currentAncestry.unshift(node.parent);
            }
            this.applySelectors(node, false);
        }
        /**
         * Emits an event of leaving AST node.
         * @param {ASTNode} node A node which was left.
         * @returns {void}
         */
        leaveNode(node) {
            this.applySelectors(node, true);
            this.currentAncestry.shift();
        }
    }
    module.exports = NodeEventGenerator;
},
/* esquery/dist/esquery.min.js */ function _(require, module, exports, __esModule, __esExport) {
    !function (e, t) { "object" == typeof exports && "undefined" != typeof module ? module.exports = t() : "function" == typeof define && define.amd ? define(t) : (e = e || self).esquery = t(); }(this, (function () {
        "use strict";
        function e(t) { return (e = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (e) { return typeof e; } : function (e) { return e && "function" == typeof Symbol && e.constructor === Symbol && e !== Symbol.prototype ? "symbol" : typeof e; })(t); }
        function t(e, t) { return function (e) { if (Array.isArray(e))
            return e; }(e) || function (e, t) { var r = null == e ? null : "undefined" != typeof Symbol && e[Symbol.iterator] || e["@@iterator"]; if (null != r) {
            var n, o, a, i, s = [], u = !0, l = !1;
            try {
                if (a = (r = r.call(e)).next, 0 === t) {
                    if (Object(r) !== r)
                        return;
                    u = !1;
                }
                else
                    for (; !(u = (n = a.call(r)).done) && (s.push(n.value), s.length !== t); u = !0)
                        ;
            }
            catch (e) {
                l = !0, o = e;
            }
            finally {
                try {
                    if (!u && null != r.return && (i = r.return(), Object(i) !== i))
                        return;
                }
                finally {
                    if (l)
                        throw o;
                }
            }
            return s;
        } }(e, t) || n(e, t) || function () { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }(); }
        function r(e) { return function (e) { if (Array.isArray(e))
            return o(e); }(e) || function (e) { if ("undefined" != typeof Symbol && null != e[Symbol.iterator] || null != e["@@iterator"])
            return Array.from(e); }(e) || n(e) || function () { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }(); }
        function n(e, t) { if (e) {
            if ("string" == typeof e)
                return o(e, t);
            var r = Object.prototype.toString.call(e).slice(8, -1);
            return "Object" === r && e.constructor && (r = e.constructor.name), "Map" === r || "Set" === r ? Array.from(e) : "Arguments" === r || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r) ? o(e, t) : void 0;
        } }
        function o(e, t) { (null == t || t > e.length) && (t = e.length); for (var r = 0, n = new Array(t); r < t; r++)
            n[r] = e[r]; return n; }
        "undefined" != typeof globalThis ? globalThis : "undefined" != typeof window ? window : "undefined" != typeof global ? global : "undefined" != typeof self && self;
        function a(e, t) { return e(t = { exports: {} }, t.exports), t.exports; }
        var i = a((function (e, t) { !function e(t) { var r, n, o, a, i, s; function u(e) { var t, r, n = {}; for (t in e)
            e.hasOwnProperty(t) && (r = e[t], n[t] = "object" == typeof r && null !== r ? u(r) : r); return n; } function l(e, t) { this.parent = e, this.key = t; } function c(e, t, r, n) { this.node = e, this.path = t, this.wrap = r, this.ref = n; } function f() { } function p(e) { return null != e && ("object" == typeof e && "string" == typeof e.type); } function h(e, t) { return (e === r.ObjectExpression || e === r.ObjectPattern) && "properties" === t; } function y(e, t) { for (var r = e.length - 1; r >= 0; --r)
            if (e[r].node === t)
                return !0; return !1; } function d(e, t) { return (new f).traverse(e, t); } function m(e, t) { var r; return r = function (e, t) { var r, n, o, a; for (n = e.length, o = 0; n;)
            t(e[a = o + (r = n >>> 1)]) ? n = r : (o = a + 1, n -= r + 1); return o; }(t, (function (t) { return t.range[0] > e.range[0]; })), e.extendedRange = [e.range[0], e.range[1]], r !== t.length && (e.extendedRange[1] = t[r].range[0]), (r -= 1) >= 0 && (e.extendedRange[0] = t[r].range[1]), e; } return r = { AssignmentExpression: "AssignmentExpression", AssignmentPattern: "AssignmentPattern", ArrayExpression: "ArrayExpression", ArrayPattern: "ArrayPattern", ArrowFunctionExpression: "ArrowFunctionExpression", AwaitExpression: "AwaitExpression", BlockStatement: "BlockStatement", BinaryExpression: "BinaryExpression", BreakStatement: "BreakStatement", CallExpression: "CallExpression", CatchClause: "CatchClause", ChainExpression: "ChainExpression", ClassBody: "ClassBody", ClassDeclaration: "ClassDeclaration", ClassExpression: "ClassExpression", ComprehensionBlock: "ComprehensionBlock", ComprehensionExpression: "ComprehensionExpression", ConditionalExpression: "ConditionalExpression", ContinueStatement: "ContinueStatement", DebuggerStatement: "DebuggerStatement", DirectiveStatement: "DirectiveStatement", DoWhileStatement: "DoWhileStatement", EmptyStatement: "EmptyStatement", ExportAllDeclaration: "ExportAllDeclaration", ExportDefaultDeclaration: "ExportDefaultDeclaration", ExportNamedDeclaration: "ExportNamedDeclaration", ExportSpecifier: "ExportSpecifier", ExpressionStatement: "ExpressionStatement", ForStatement: "ForStatement", ForInStatement: "ForInStatement", ForOfStatement: "ForOfStatement", FunctionDeclaration: "FunctionDeclaration", FunctionExpression: "FunctionExpression", GeneratorExpression: "GeneratorExpression", Identifier: "Identifier", IfStatement: "IfStatement", ImportExpression: "ImportExpression", ImportDeclaration: "ImportDeclaration", ImportDefaultSpecifier: "ImportDefaultSpecifier", ImportNamespaceSpecifier: "ImportNamespaceSpecifier", ImportSpecifier: "ImportSpecifier", Literal: "Literal", LabeledStatement: "LabeledStatement", LogicalExpression: "LogicalExpression", MemberExpression: "MemberExpression", MetaProperty: "MetaProperty", MethodDefinition: "MethodDefinition", ModuleSpecifier: "ModuleSpecifier", NewExpression: "NewExpression", ObjectExpression: "ObjectExpression", ObjectPattern: "ObjectPattern", PrivateIdentifier: "PrivateIdentifier", Program: "Program", Property: "Property", PropertyDefinition: "PropertyDefinition", RestElement: "RestElement", ReturnStatement: "ReturnStatement", SequenceExpression: "SequenceExpression", SpreadElement: "SpreadElement", Super: "Super", SwitchStatement: "SwitchStatement", SwitchCase: "SwitchCase", TaggedTemplateExpression: "TaggedTemplateExpression", TemplateElement: "TemplateElement", TemplateLiteral: "TemplateLiteral", ThisExpression: "ThisExpression", ThrowStatement: "ThrowStatement", TryStatement: "TryStatement", UnaryExpression: "UnaryExpression", UpdateExpression: "UpdateExpression", VariableDeclaration: "VariableDeclaration", VariableDeclarator: "VariableDeclarator", WhileStatement: "WhileStatement", WithStatement: "WithStatement", YieldExpression: "YieldExpression" }, o = { AssignmentExpression: ["left", "right"], AssignmentPattern: ["left", "right"], ArrayExpression: ["elements"], ArrayPattern: ["elements"], ArrowFunctionExpression: ["params", "body"], AwaitExpression: ["argument"], BlockStatement: ["body"], BinaryExpression: ["left", "right"], BreakStatement: ["label"], CallExpression: ["callee", "arguments"], CatchClause: ["param", "body"], ChainExpression: ["expression"], ClassBody: ["body"], ClassDeclaration: ["id", "superClass", "body"], ClassExpression: ["id", "superClass", "body"], ComprehensionBlock: ["left", "right"], ComprehensionExpression: ["blocks", "filter", "body"], ConditionalExpression: ["test", "consequent", "alternate"], ContinueStatement: ["label"], DebuggerStatement: [], DirectiveStatement: [], DoWhileStatement: ["body", "test"], EmptyStatement: [], ExportAllDeclaration: ["source"], ExportDefaultDeclaration: ["declaration"], ExportNamedDeclaration: ["declaration", "specifiers", "source"], ExportSpecifier: ["exported", "local"], ExpressionStatement: ["expression"], ForStatement: ["init", "test", "update", "body"], ForInStatement: ["left", "right", "body"], ForOfStatement: ["left", "right", "body"], FunctionDeclaration: ["id", "params", "body"], FunctionExpression: ["id", "params", "body"], GeneratorExpression: ["blocks", "filter", "body"], Identifier: [], IfStatement: ["test", "consequent", "alternate"], ImportExpression: ["source"], ImportDeclaration: ["specifiers", "source"], ImportDefaultSpecifier: ["local"], ImportNamespaceSpecifier: ["local"], ImportSpecifier: ["imported", "local"], Literal: [], LabeledStatement: ["label", "body"], LogicalExpression: ["left", "right"], MemberExpression: ["object", "property"], MetaProperty: ["meta", "property"], MethodDefinition: ["key", "value"], ModuleSpecifier: [], NewExpression: ["callee", "arguments"], ObjectExpression: ["properties"], ObjectPattern: ["properties"], PrivateIdentifier: [], Program: ["body"], Property: ["key", "value"], PropertyDefinition: ["key", "value"], RestElement: ["argument"], ReturnStatement: ["argument"], SequenceExpression: ["expressions"], SpreadElement: ["argument"], Super: [], SwitchStatement: ["discriminant", "cases"], SwitchCase: ["test", "consequent"], TaggedTemplateExpression: ["tag", "quasi"], TemplateElement: [], TemplateLiteral: ["quasis", "expressions"], ThisExpression: [], ThrowStatement: ["argument"], TryStatement: ["block", "handler", "finalizer"], UnaryExpression: ["argument"], UpdateExpression: ["argument"], VariableDeclaration: ["declarations"], VariableDeclarator: ["id", "init"], WhileStatement: ["test", "body"], WithStatement: ["object", "body"], YieldExpression: ["argument"] }, n = { Break: a = {}, Skip: i = {}, Remove: s = {} }, l.prototype.replace = function (e) { this.parent[this.key] = e; }, l.prototype.remove = function () { return Array.isArray(this.parent) ? (this.parent.splice(this.key, 1), !0) : (this.replace(null), !1); }, f.prototype.path = function () { var e, t, r, n, o; function a(e, t) { if (Array.isArray(t))
            for (r = 0, n = t.length; r < n; ++r)
                e.push(t[r]);
        else
            e.push(t); } if (!this.__current.path)
            return null; for (o = [], e = 2, t = this.__leavelist.length; e < t; ++e)
            a(o, this.__leavelist[e].path); return a(o, this.__current.path), o; }, f.prototype.type = function () { return this.current().type || this.__current.wrap; }, f.prototype.parents = function () { var e, t, r; for (r = [], e = 1, t = this.__leavelist.length; e < t; ++e)
            r.push(this.__leavelist[e].node); return r; }, f.prototype.current = function () { return this.__current.node; }, f.prototype.__execute = function (e, t) { var r, n; return n = void 0, r = this.__current, this.__current = t, this.__state = null, e && (n = e.call(this, t.node, this.__leavelist[this.__leavelist.length - 1].node)), this.__current = r, n; }, f.prototype.notify = function (e) { this.__state = e; }, f.prototype.skip = function () { this.notify(i); }, f.prototype.break = function () { this.notify(a); }, f.prototype.remove = function () { this.notify(s); }, f.prototype.__initialize = function (e, t) { this.visitor = t, this.root = e, this.__worklist = [], this.__leavelist = [], this.__current = null, this.__state = null, this.__fallback = null, "iteration" === t.fallback ? this.__fallback = Object.keys : "function" == typeof t.fallback && (this.__fallback = t.fallback), this.__keys = o, t.keys && (this.__keys = Object.assign(Object.create(this.__keys), t.keys)); }, f.prototype.traverse = function (e, t) { var r, n, o, s, u, l, f, d, m, x, v, g; for (this.__initialize(e, t), g = {}, r = this.__worklist, n = this.__leavelist, r.push(new c(e, null, null, null)), n.push(new c(null, null, null, null)); r.length;)
            if ((o = r.pop()) !== g) {
                if (o.node) {
                    if (l = this.__execute(t.enter, o), this.__state === a || l === a)
                        return;
                    if (r.push(g), n.push(o), this.__state === i || l === i)
                        continue;
                    if (u = (s = o.node).type || o.wrap, !(x = this.__keys[u])) {
                        if (!this.__fallback)
                            throw new Error("Unknown node type " + u + ".");
                        x = this.__fallback(s);
                    }
                    for (d = x.length; (d -= 1) >= 0;)
                        if (v = s[f = x[d]])
                            if (Array.isArray(v)) {
                                for (m = v.length; (m -= 1) >= 0;)
                                    if (v[m] && !y(n, v[m])) {
                                        if (h(u, x[d]))
                                            o = new c(v[m], [f, m], "Property", null);
                                        else {
                                            if (!p(v[m]))
                                                continue;
                                            o = new c(v[m], [f, m], null, null);
                                        }
                                        r.push(o);
                                    }
                            }
                            else if (p(v)) {
                                if (y(n, v))
                                    continue;
                                r.push(new c(v, f, null, null));
                            }
                }
            }
            else if (o = n.pop(), l = this.__execute(t.leave, o), this.__state === a || l === a)
                return; }, f.prototype.replace = function (e, t) { var r, n, o, u, f, y, d, m, x, v, g, A, E; function b(e) { var t, n, o, a; if (e.ref.remove())
            for (n = e.ref.key, a = e.ref.parent, t = r.length; t--;)
                if ((o = r[t]).ref && o.ref.parent === a) {
                    if (o.ref.key < n)
                        break;
                    --o.ref.key;
                } } for (this.__initialize(e, t), g = {}, r = this.__worklist, n = this.__leavelist, y = new c(e, null, null, new l(A = { root: e }, "root")), r.push(y), n.push(y); r.length;)
            if ((y = r.pop()) !== g) {
                if (void 0 !== (f = this.__execute(t.enter, y)) && f !== a && f !== i && f !== s && (y.ref.replace(f), y.node = f), this.__state !== s && f !== s || (b(y), y.node = null), this.__state === a || f === a)
                    return A.root;
                if ((o = y.node) && (r.push(g), n.push(y), this.__state !== i && f !== i)) {
                    if (u = o.type || y.wrap, !(x = this.__keys[u])) {
                        if (!this.__fallback)
                            throw new Error("Unknown node type " + u + ".");
                        x = this.__fallback(o);
                    }
                    for (d = x.length; (d -= 1) >= 0;)
                        if (v = o[E = x[d]])
                            if (Array.isArray(v)) {
                                for (m = v.length; (m -= 1) >= 0;)
                                    if (v[m]) {
                                        if (h(u, x[d]))
                                            y = new c(v[m], [E, m], "Property", new l(v, m));
                                        else {
                                            if (!p(v[m]))
                                                continue;
                                            y = new c(v[m], [E, m], null, new l(v, m));
                                        }
                                        r.push(y);
                                    }
                            }
                            else
                                p(v) && r.push(new c(v, E, null, new l(o, E)));
                }
            }
            else if (y = n.pop(), void 0 !== (f = this.__execute(t.leave, y)) && f !== a && f !== i && f !== s && y.ref.replace(f), this.__state !== s && f !== s || b(y), this.__state === a || f === a)
                return A.root; return A.root; }, t.Syntax = r, t.traverse = d, t.replace = function (e, t) { return (new f).replace(e, t); }, t.attachComments = function (e, t, r) { var o, a, i, s, l = []; if (!e.range)
            throw new Error("attachComments needs range information"); if (!r.length) {
            if (t.length) {
                for (i = 0, a = t.length; i < a; i += 1)
                    (o = u(t[i])).extendedRange = [0, e.range[0]], l.push(o);
                e.leadingComments = l;
            }
            return e;
        } for (i = 0, a = t.length; i < a; i += 1)
            l.push(m(u(t[i]), r)); return s = 0, d(e, { enter: function (e) { for (var t; s < l.length && !((t = l[s]).extendedRange[1] > e.range[0]);)
                t.extendedRange[1] === e.range[0] ? (e.leadingComments || (e.leadingComments = []), e.leadingComments.push(t), l.splice(s, 1)) : s += 1; return s === l.length ? n.Break : l[s].extendedRange[0] > e.range[1] ? n.Skip : void 0; } }), s = 0, d(e, { leave: function (e) { for (var t; s < l.length && (t = l[s], !(e.range[1] < t.extendedRange[0]));)
                e.range[1] === t.extendedRange[0] ? (e.trailingComments || (e.trailingComments = []), e.trailingComments.push(t), l.splice(s, 1)) : s += 1; return s === l.length ? n.Break : l[s].extendedRange[0] > e.range[1] ? n.Skip : void 0; } }), e; }, t.VisitorKeys = o, t.VisitorOption = n, t.Controller = f, t.cloneEnvironment = function () { return e({}); }, t; }(t); })), s = a((function (e) { e.exports && (e.exports = function () { function e(t, r, n, o) { this.message = t, this.expected = r, this.found = n, this.location = o, this.name = "SyntaxError", "function" == typeof Error.captureStackTrace && Error.captureStackTrace(this, e); } return function (e, t) { function r() { this.constructor = e; } r.prototype = t.prototype, e.prototype = new r; }(e, Error), e.buildMessage = function (e, t) { var r = { literal: function (e) { return '"' + o(e.text) + '"'; }, class: function (e) { var t, r = ""; for (t = 0; t < e.parts.length; t++)
                r += e.parts[t] instanceof Array ? a(e.parts[t][0]) + "-" + a(e.parts[t][1]) : a(e.parts[t]); return "[" + (e.inverted ? "^" : "") + r + "]"; }, any: function (e) { return "any character"; }, end: function (e) { return "end of input"; }, other: function (e) { return e.description; } }; function n(e) { return e.charCodeAt(0).toString(16).toUpperCase(); } function o(e) { return e.replace(/\\/g, "\\\\").replace(/"/g, '\\"').replace(/\0/g, "\\0").replace(/\t/g, "\\t").replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/[\x00-\x0F]/g, (function (e) { return "\\x0" + n(e); })).replace(/[\x10-\x1F\x7F-\x9F]/g, (function (e) { return "\\x" + n(e); })); } function a(e) { return e.replace(/\\/g, "\\\\").replace(/\]/g, "\\]").replace(/\^/g, "\\^").replace(/-/g, "\\-").replace(/\0/g, "\\0").replace(/\t/g, "\\t").replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/[\x00-\x0F]/g, (function (e) { return "\\x0" + n(e); })).replace(/[\x10-\x1F\x7F-\x9F]/g, (function (e) { return "\\x" + n(e); })); } return "Expected " + function (e) { var t, n, o, a = new Array(e.length); for (t = 0; t < e.length; t++)
            a[t] = (o = e[t], r[o.type](o)); if (a.sort(), a.length > 0) {
            for (t = 1, n = 1; t < a.length; t++)
                a[t - 1] !== a[t] && (a[n] = a[t], n++);
            a.length = n;
        } switch (a.length) {
            case 1: return a[0];
            case 2: return a[0] + " or " + a[1];
            default: return a.slice(0, -1).join(", ") + ", or " + a[a.length - 1];
        } }(e) + " but " + function (e) { return e ? '"' + o(e) + '"' : "end of input"; }(t) + " found."; }, { SyntaxError: e, parse: function (t, r) { r = void 0 !== r ? r : {}; var n, o, a, i, s = {}, u = { start: de }, l = de, c = ce(" ", !1), f = /^[^ [\],():#!=><~+.]/, p = fe([" ", "[", "]", ",", "(", ")", ":", "#", "!", "=", ">", "<", "~", "+", "."], !0, !1), h = ce(">", !1), y = ce("~", !1), d = ce("+", !1), m = ce(",", !1), x = ce("!", !1), v = ce("*", !1), g = ce("#", !1), A = ce("[", !1), E = ce("]", !1), b = /^[><!]/, S = fe([">", "<", "!"], !1, !1), _ = ce("=", !1), C = function (e) { return (e || "") + "="; }, w = /^[><]/, P = fe([">", "<"], !1, !1), k = ce(".", !1), D = function (e, t, r) { return { type: "attribute", name: e, operator: t, value: r }; }, I = ce('"', !1), j = /^[^\\"]/, T = fe(["\\", '"'], !0, !1), F = ce("\\", !1), R = { type: "any" }, O = function (e, t) { return e + t; }, L = function (e) { return { type: "literal", value: (t = e.join(""), t.replace(/\\(.)/g, (function (e, t) { switch (t) {
                    case "b": return "\b";
                    case "f": return "\f";
                    case "n": return "\n";
                    case "r": return "\r";
                    case "t": return "\t";
                    case "v": return "\v";
                    default: return t;
                } }))) }; var t; }, M = ce("'", !1), B = /^[^\\']/, U = fe(["\\", "'"], !0, !1), K = /^[0-9]/, W = fe([["0", "9"]], !1, !1), q = ce("type(", !1), V = /^[^ )]/, N = fe([" ", ")"], !0, !1), G = ce(")", !1), z = /^[imsu]/, H = fe(["i", "m", "s", "u"], !1, !1), Y = ce("/", !1), $ = /^[^\/]/, J = fe(["/"], !0, !1), Q = ce(":not(", !1), X = ce(":matches(", !1), Z = ce(":has(", !1), ee = ce(":first-child", !1), te = ce(":last-child", !1), re = ce(":nth-child(", !1), ne = ce(":nth-last-child(", !1), oe = ce(":", !1), ae = 0, ie = [{ line: 1, column: 1 }], se = 0, ue = [], le = {}; if ("startRule" in r) {
                if (!(r.startRule in u))
                    throw new Error("Can't start parsing from rule \"" + r.startRule + '".');
                l = u[r.startRule];
            } function ce(e, t) { return { type: "literal", text: e, ignoreCase: t }; } function fe(e, t, r) { return { type: "class", parts: e, inverted: t, ignoreCase: r }; } function pe(e) { var r, n = ie[e]; if (n)
                return n; for (r = e - 1; !ie[r];)
                r--; for (n = { line: (n = ie[r]).line, column: n.column }; r < e;)
                10 === t.charCodeAt(r) ? (n.line++, n.column = 1) : n.column++, r++; return ie[e] = n, n; } function he(e, t) { var r = pe(e), n = pe(t); return { start: { offset: e, line: r.line, column: r.column }, end: { offset: t, line: n.line, column: n.column } }; } function ye(e) { ae < se || (ae > se && (se = ae, ue = []), ue.push(e)); } function de() { var e, t, r, n, o = 30 * ae + 0, a = le[o]; return a ? (ae = a.nextPos, a.result) : (e = ae, (t = me()) !== s && (r = ge()) !== s && me() !== s ? e = t = 1 === (n = r).length ? n[0] : { type: "matches", selectors: n } : (ae = e, e = s), e === s && (e = ae, (t = me()) !== s && (t = void 0), e = t), le[o] = { nextPos: ae, result: e }, e); } function me() { var e, r, n = 30 * ae + 1, o = le[n]; if (o)
                return ae = o.nextPos, o.result; for (e = [], 32 === t.charCodeAt(ae) ? (r = " ", ae++) : (r = s, ye(c)); r !== s;)
                e.push(r), 32 === t.charCodeAt(ae) ? (r = " ", ae++) : (r = s, ye(c)); return le[n] = { nextPos: ae, result: e }, e; } function xe() { var e, r, n, o = 30 * ae + 2, a = le[o]; if (a)
                return ae = a.nextPos, a.result; if (r = [], f.test(t.charAt(ae)) ? (n = t.charAt(ae), ae++) : (n = s, ye(p)), n !== s)
                for (; n !== s;)
                    r.push(n), f.test(t.charAt(ae)) ? (n = t.charAt(ae), ae++) : (n = s, ye(p));
            else
                r = s; return r !== s && (r = r.join("")), e = r, le[o] = { nextPos: ae, result: e }, e; } function ve() { var e, r, n, o = 30 * ae + 3, a = le[o]; return a ? (ae = a.nextPos, a.result) : (e = ae, (r = me()) !== s ? (62 === t.charCodeAt(ae) ? (n = ">", ae++) : (n = s, ye(h)), n !== s && me() !== s ? e = r = "child" : (ae = e, e = s)) : (ae = e, e = s), e === s && (e = ae, (r = me()) !== s ? (126 === t.charCodeAt(ae) ? (n = "~", ae++) : (n = s, ye(y)), n !== s && me() !== s ? e = r = "sibling" : (ae = e, e = s)) : (ae = e, e = s), e === s && (e = ae, (r = me()) !== s ? (43 === t.charCodeAt(ae) ? (n = "+", ae++) : (n = s, ye(d)), n !== s && me() !== s ? e = r = "adjacent" : (ae = e, e = s)) : (ae = e, e = s), e === s && (e = ae, 32 === t.charCodeAt(ae) ? (r = " ", ae++) : (r = s, ye(c)), r !== s && (n = me()) !== s ? e = r = "descendant" : (ae = e, e = s)))), le[o] = { nextPos: ae, result: e }, e); } function ge() { var e, r, n, o, a, i, u, l, c = 30 * ae + 4, f = le[c]; if (f)
                return ae = f.nextPos, f.result; if (e = ae, (r = Ae()) !== s) {
                for (n = [], o = ae, (a = me()) !== s ? (44 === t.charCodeAt(ae) ? (i = ",", ae++) : (i = s, ye(m)), i !== s && (u = me()) !== s && (l = Ae()) !== s ? o = a = [a, i, u, l] : (ae = o, o = s)) : (ae = o, o = s); o !== s;)
                    n.push(o), o = ae, (a = me()) !== s ? (44 === t.charCodeAt(ae) ? (i = ",", ae++) : (i = s, ye(m)), i !== s && (u = me()) !== s && (l = Ae()) !== s ? o = a = [a, i, u, l] : (ae = o, o = s)) : (ae = o, o = s);
                n !== s ? e = r = [r].concat(n.map((function (e) { return e[3]; }))) : (ae = e, e = s);
            }
            else
                ae = e, e = s; return le[c] = { nextPos: ae, result: e }, e; } function Ae() { var e, t, r, n, o, a, i, u = 30 * ae + 5, l = le[u]; if (l)
                return ae = l.nextPos, l.result; if (e = ae, (t = Ee()) !== s) {
                for (r = [], n = ae, (o = ve()) !== s && (a = Ee()) !== s ? n = o = [o, a] : (ae = n, n = s); n !== s;)
                    r.push(n), n = ae, (o = ve()) !== s && (a = Ee()) !== s ? n = o = [o, a] : (ae = n, n = s);
                r !== s ? (i = t, e = t = r.reduce((function (e, t) { return { type: t[0], left: e, right: t[1] }; }), i)) : (ae = e, e = s);
            }
            else
                ae = e, e = s; return le[u] = { nextPos: ae, result: e }, e; } function Ee() { var e, r, n, o, a, i, u, l = 30 * ae + 6, c = le[l]; if (c)
                return ae = c.nextPos, c.result; if (e = ae, 33 === t.charCodeAt(ae) ? (r = "!", ae++) : (r = s, ye(x)), r === s && (r = null), r !== s) {
                if (n = [], (o = be()) !== s)
                    for (; o !== s;)
                        n.push(o), o = be();
                else
                    n = s;
                n !== s ? (a = r, u = 1 === (i = n).length ? i[0] : { type: "compound", selectors: i }, a && (u.subject = !0), e = r = u) : (ae = e, e = s);
            }
            else
                ae = e, e = s; return le[l] = { nextPos: ae, result: e }, e; } function be() { var e, r = 30 * ae + 7, n = le[r]; return n ? (ae = n.nextPos, n.result) : ((e = function () { var e, r, n = 30 * ae + 8, o = le[n]; return o ? (ae = o.nextPos, o.result) : (42 === t.charCodeAt(ae) ? (r = "*", ae++) : (r = s, ye(v)), r !== s && (r = { type: "wildcard", value: r }), e = r, le[n] = { nextPos: ae, result: e }, e); }()) === s && (e = function () { var e, r, n, o = 30 * ae + 9, a = le[o]; return a ? (ae = a.nextPos, a.result) : (e = ae, 35 === t.charCodeAt(ae) ? (r = "#", ae++) : (r = s, ye(g)), r === s && (r = null), r !== s && (n = xe()) !== s ? e = r = { type: "identifier", value: n } : (ae = e, e = s), le[o] = { nextPos: ae, result: e }, e); }()) === s && (e = function () { var e, r, n, o, a = 30 * ae + 10, i = le[a]; return i ? (ae = i.nextPos, i.result) : (e = ae, 91 === t.charCodeAt(ae) ? (r = "[", ae++) : (r = s, ye(A)), r !== s && me() !== s && (n = function () { var e, r, n, o, a = 30 * ae + 14, i = le[a]; return i ? (ae = i.nextPos, i.result) : (e = ae, (r = Se()) !== s && me() !== s && (n = function () { var e, r, n, o = 30 * ae + 12, a = le[o]; return a ? (ae = a.nextPos, a.result) : (e = ae, 33 === t.charCodeAt(ae) ? (r = "!", ae++) : (r = s, ye(x)), r === s && (r = null), r !== s ? (61 === t.charCodeAt(ae) ? (n = "=", ae++) : (n = s, ye(_)), n !== s ? (r = C(r), e = r) : (ae = e, e = s)) : (ae = e, e = s), le[o] = { nextPos: ae, result: e }, e); }()) !== s && me() !== s ? ((o = function () { var e, r, n, o, a, i = 30 * ae + 18, u = le[i]; if (u)
                return ae = u.nextPos, u.result; if (e = ae, "type(" === t.substr(ae, 5) ? (r = "type(", ae += 5) : (r = s, ye(q)), r !== s)
                if (me() !== s) {
                    if (n = [], V.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(N)), o !== s)
                        for (; o !== s;)
                            n.push(o), V.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(N));
                    else
                        n = s;
                    n !== s && (o = me()) !== s ? (41 === t.charCodeAt(ae) ? (a = ")", ae++) : (a = s, ye(G)), a !== s ? (r = { type: "type", value: n.join("") }, e = r) : (ae = e, e = s)) : (ae = e, e = s);
                }
                else
                    ae = e, e = s;
            else
                ae = e, e = s; return le[i] = { nextPos: ae, result: e }, e; }()) === s && (o = function () { var e, r, n, o, a, i, u = 30 * ae + 20, l = le[u]; if (l)
                return ae = l.nextPos, l.result; if (e = ae, 47 === t.charCodeAt(ae) ? (r = "/", ae++) : (r = s, ye(Y)), r !== s) {
                if (n = [], $.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(J)), o !== s)
                    for (; o !== s;)
                        n.push(o), $.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(J));
                else
                    n = s;
                n !== s ? (47 === t.charCodeAt(ae) ? (o = "/", ae++) : (o = s, ye(Y)), o !== s ? ((a = function () { var e, r, n = 30 * ae + 19, o = le[n]; if (o)
                    return ae = o.nextPos, o.result; if (e = [], z.test(t.charAt(ae)) ? (r = t.charAt(ae), ae++) : (r = s, ye(H)), r !== s)
                    for (; r !== s;)
                        e.push(r), z.test(t.charAt(ae)) ? (r = t.charAt(ae), ae++) : (r = s, ye(H));
                else
                    e = s; return le[n] = { nextPos: ae, result: e }, e; }()) === s && (a = null), a !== s ? (i = a, r = { type: "regexp", value: new RegExp(n.join(""), i ? i.join("") : "") }, e = r) : (ae = e, e = s)) : (ae = e, e = s)) : (ae = e, e = s);
            }
            else
                ae = e, e = s; return le[u] = { nextPos: ae, result: e }, e; }()), o !== s ? (r = D(r, n, o), e = r) : (ae = e, e = s)) : (ae = e, e = s), e === s && (e = ae, (r = Se()) !== s && me() !== s && (n = function () { var e, r, n, o = 30 * ae + 11, a = le[o]; return a ? (ae = a.nextPos, a.result) : (e = ae, b.test(t.charAt(ae)) ? (r = t.charAt(ae), ae++) : (r = s, ye(S)), r === s && (r = null), r !== s ? (61 === t.charCodeAt(ae) ? (n = "=", ae++) : (n = s, ye(_)), n !== s ? (r = C(r), e = r) : (ae = e, e = s)) : (ae = e, e = s), e === s && (w.test(t.charAt(ae)) ? (e = t.charAt(ae), ae++) : (e = s, ye(P))), le[o] = { nextPos: ae, result: e }, e); }()) !== s && me() !== s ? ((o = function () { var e, r, n, o, a, i, u = 30 * ae + 15, l = le[u]; if (l)
                return ae = l.nextPos, l.result; if (e = ae, 34 === t.charCodeAt(ae) ? (r = '"', ae++) : (r = s, ye(I)), r !== s) {
                for (n = [], j.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(T)), o === s && (o = ae, 92 === t.charCodeAt(ae) ? (a = "\\", ae++) : (a = s, ye(F)), a !== s ? (t.length > ae ? (i = t.charAt(ae), ae++) : (i = s, ye(R)), i !== s ? (a = O(a, i), o = a) : (ae = o, o = s)) : (ae = o, o = s)); o !== s;)
                    n.push(o), j.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(T)), o === s && (o = ae, 92 === t.charCodeAt(ae) ? (a = "\\", ae++) : (a = s, ye(F)), a !== s ? (t.length > ae ? (i = t.charAt(ae), ae++) : (i = s, ye(R)), i !== s ? (a = O(a, i), o = a) : (ae = o, o = s)) : (ae = o, o = s));
                n !== s ? (34 === t.charCodeAt(ae) ? (o = '"', ae++) : (o = s, ye(I)), o !== s ? (r = L(n), e = r) : (ae = e, e = s)) : (ae = e, e = s);
            }
            else
                ae = e, e = s; if (e === s)
                if (e = ae, 39 === t.charCodeAt(ae) ? (r = "'", ae++) : (r = s, ye(M)), r !== s) {
                    for (n = [], B.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(U)), o === s && (o = ae, 92 === t.charCodeAt(ae) ? (a = "\\", ae++) : (a = s, ye(F)), a !== s ? (t.length > ae ? (i = t.charAt(ae), ae++) : (i = s, ye(R)), i !== s ? (a = O(a, i), o = a) : (ae = o, o = s)) : (ae = o, o = s)); o !== s;)
                        n.push(o), B.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(U)), o === s && (o = ae, 92 === t.charCodeAt(ae) ? (a = "\\", ae++) : (a = s, ye(F)), a !== s ? (t.length > ae ? (i = t.charAt(ae), ae++) : (i = s, ye(R)), i !== s ? (a = O(a, i), o = a) : (ae = o, o = s)) : (ae = o, o = s));
                    n !== s ? (39 === t.charCodeAt(ae) ? (o = "'", ae++) : (o = s, ye(M)), o !== s ? (r = L(n), e = r) : (ae = e, e = s)) : (ae = e, e = s);
                }
                else
                    ae = e, e = s; return le[u] = { nextPos: ae, result: e }, e; }()) === s && (o = function () { var e, r, n, o, a, i, u, l = 30 * ae + 16, c = le[l]; if (c)
                return ae = c.nextPos, c.result; for (e = ae, r = ae, n = [], K.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(W)); o !== s;)
                n.push(o), K.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(W)); if (n !== s ? (46 === t.charCodeAt(ae) ? (o = ".", ae++) : (o = s, ye(k)), o !== s ? r = n = [n, o] : (ae = r, r = s)) : (ae = r, r = s), r === s && (r = null), r !== s) {
                if (n = [], K.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(W)), o !== s)
                    for (; o !== s;)
                        n.push(o), K.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(W));
                else
                    n = s;
                n !== s ? (i = n, u = (a = r) ? [].concat.apply([], a).join("") : "", r = { type: "literal", value: parseFloat(u + i.join("")) }, e = r) : (ae = e, e = s);
            }
            else
                ae = e, e = s; return le[l] = { nextPos: ae, result: e }, e; }()) === s && (o = function () { var e, t, r = 30 * ae + 17, n = le[r]; return n ? (ae = n.nextPos, n.result) : ((t = xe()) !== s && (t = { type: "literal", value: t }), e = t, le[r] = { nextPos: ae, result: e }, e); }()), o !== s ? (r = D(r, n, o), e = r) : (ae = e, e = s)) : (ae = e, e = s), e === s && (e = ae, (r = Se()) !== s && (r = { type: "attribute", name: r }), e = r)), le[a] = { nextPos: ae, result: e }, e); }()) !== s && me() !== s ? (93 === t.charCodeAt(ae) ? (o = "]", ae++) : (o = s, ye(E)), o !== s ? e = r = n : (ae = e, e = s)) : (ae = e, e = s), le[a] = { nextPos: ae, result: e }, e); }()) === s && (e = function () { var e, r, n, o, a, i, u, l, c = 30 * ae + 21, f = le[c]; if (f)
                return ae = f.nextPos, f.result; if (e = ae, 46 === t.charCodeAt(ae) ? (r = ".", ae++) : (r = s, ye(k)), r !== s)
                if ((n = xe()) !== s) {
                    for (o = [], a = ae, 46 === t.charCodeAt(ae) ? (i = ".", ae++) : (i = s, ye(k)), i !== s && (u = xe()) !== s ? a = i = [i, u] : (ae = a, a = s); a !== s;)
                        o.push(a), a = ae, 46 === t.charCodeAt(ae) ? (i = ".", ae++) : (i = s, ye(k)), i !== s && (u = xe()) !== s ? a = i = [i, u] : (ae = a, a = s);
                    o !== s ? (l = n, r = { type: "field", name: o.reduce((function (e, t) { return e + t[0] + t[1]; }), l) }, e = r) : (ae = e, e = s);
                }
                else
                    ae = e, e = s;
            else
                ae = e, e = s; return le[c] = { nextPos: ae, result: e }, e; }()) === s && (e = function () { var e, r, n, o, a = 30 * ae + 22, i = le[a]; return i ? (ae = i.nextPos, i.result) : (e = ae, ":not(" === t.substr(ae, 5) ? (r = ":not(", ae += 5) : (r = s, ye(Q)), r !== s && me() !== s && (n = ge()) !== s && me() !== s ? (41 === t.charCodeAt(ae) ? (o = ")", ae++) : (o = s, ye(G)), o !== s ? e = r = { type: "not", selectors: n } : (ae = e, e = s)) : (ae = e, e = s), le[a] = { nextPos: ae, result: e }, e); }()) === s && (e = function () { var e, r, n, o, a = 30 * ae + 23, i = le[a]; return i ? (ae = i.nextPos, i.result) : (e = ae, ":matches(" === t.substr(ae, 9) ? (r = ":matches(", ae += 9) : (r = s, ye(X)), r !== s && me() !== s && (n = ge()) !== s && me() !== s ? (41 === t.charCodeAt(ae) ? (o = ")", ae++) : (o = s, ye(G)), o !== s ? e = r = { type: "matches", selectors: n } : (ae = e, e = s)) : (ae = e, e = s), le[a] = { nextPos: ae, result: e }, e); }()) === s && (e = function () { var e, r, n, o, a = 30 * ae + 24, i = le[a]; return i ? (ae = i.nextPos, i.result) : (e = ae, ":has(" === t.substr(ae, 5) ? (r = ":has(", ae += 5) : (r = s, ye(Z)), r !== s && me() !== s && (n = ge()) !== s && me() !== s ? (41 === t.charCodeAt(ae) ? (o = ")", ae++) : (o = s, ye(G)), o !== s ? e = r = { type: "has", selectors: n } : (ae = e, e = s)) : (ae = e, e = s), le[a] = { nextPos: ae, result: e }, e); }()) === s && (e = function () { var e, r, n = 30 * ae + 25, o = le[n]; return o ? (ae = o.nextPos, o.result) : (":first-child" === t.substr(ae, 12) ? (r = ":first-child", ae += 12) : (r = s, ye(ee)), r !== s && (r = _e(1)), e = r, le[n] = { nextPos: ae, result: e }, e); }()) === s && (e = function () { var e, r, n = 30 * ae + 26, o = le[n]; return o ? (ae = o.nextPos, o.result) : (":last-child" === t.substr(ae, 11) ? (r = ":last-child", ae += 11) : (r = s, ye(te)), r !== s && (r = Ce(1)), e = r, le[n] = { nextPos: ae, result: e }, e); }()) === s && (e = function () { var e, r, n, o, a, i = 30 * ae + 27, u = le[i]; if (u)
                return ae = u.nextPos, u.result; if (e = ae, ":nth-child(" === t.substr(ae, 11) ? (r = ":nth-child(", ae += 11) : (r = s, ye(re)), r !== s)
                if (me() !== s) {
                    if (n = [], K.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(W)), o !== s)
                        for (; o !== s;)
                            n.push(o), K.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(W));
                    else
                        n = s;
                    n !== s && (o = me()) !== s ? (41 === t.charCodeAt(ae) ? (a = ")", ae++) : (a = s, ye(G)), a !== s ? (r = _e(parseInt(n.join(""), 10)), e = r) : (ae = e, e = s)) : (ae = e, e = s);
                }
                else
                    ae = e, e = s;
            else
                ae = e, e = s; return le[i] = { nextPos: ae, result: e }, e; }()) === s && (e = function () { var e, r, n, o, a, i = 30 * ae + 28, u = le[i]; if (u)
                return ae = u.nextPos, u.result; if (e = ae, ":nth-last-child(" === t.substr(ae, 16) ? (r = ":nth-last-child(", ae += 16) : (r = s, ye(ne)), r !== s)
                if (me() !== s) {
                    if (n = [], K.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(W)), o !== s)
                        for (; o !== s;)
                            n.push(o), K.test(t.charAt(ae)) ? (o = t.charAt(ae), ae++) : (o = s, ye(W));
                    else
                        n = s;
                    n !== s && (o = me()) !== s ? (41 === t.charCodeAt(ae) ? (a = ")", ae++) : (a = s, ye(G)), a !== s ? (r = Ce(parseInt(n.join(""), 10)), e = r) : (ae = e, e = s)) : (ae = e, e = s);
                }
                else
                    ae = e, e = s;
            else
                ae = e, e = s; return le[i] = { nextPos: ae, result: e }, e; }()) === s && (e = function () { var e, r, n, o = 30 * ae + 29, a = le[o]; return a ? (ae = a.nextPos, a.result) : (e = ae, 58 === t.charCodeAt(ae) ? (r = ":", ae++) : (r = s, ye(oe)), r !== s && (n = xe()) !== s ? e = r = { type: "class", name: n } : (ae = e, e = s), le[o] = { nextPos: ae, result: e }, e); }()), le[r] = { nextPos: ae, result: e }, e); } function Se() { var e, r, n, o, a, i, u, l, c = 30 * ae + 13, f = le[c]; if (f)
                return ae = f.nextPos, f.result; if (e = ae, (r = xe()) !== s) {
                for (n = [], o = ae, 46 === t.charCodeAt(ae) ? (a = ".", ae++) : (a = s, ye(k)), a !== s && (i = xe()) !== s ? o = a = [a, i] : (ae = o, o = s); o !== s;)
                    n.push(o), o = ae, 46 === t.charCodeAt(ae) ? (a = ".", ae++) : (a = s, ye(k)), a !== s && (i = xe()) !== s ? o = a = [a, i] : (ae = o, o = s);
                n !== s ? (u = r, l = n, e = r = [].concat.apply([u], l).join("")) : (ae = e, e = s);
            }
            else
                ae = e, e = s; return le[c] = { nextPos: ae, result: e }, e; } function _e(e) { return { type: "nth-child", index: { type: "literal", value: e } }; } function Ce(e) { return { type: "nth-last-child", index: { type: "literal", value: e } }; } if ((n = l()) !== s && ae === t.length)
                return n; throw n !== s && ae < t.length && ye({ type: "end" }), o = ue, a = se < t.length ? t.charAt(se) : null, i = se < t.length ? he(se, se + 1) : he(se, se), new e(e.buildMessage(o, a), o, a, i); } }; }()); }));
        function u(e, t) { for (var r = 0; r < t.length; ++r) {
            if (null == e)
                return e;
            e = e[t[r]];
        } return e; }
        var l = "function" == typeof WeakMap ? new WeakMap : null;
        function c(e) { if (null == e)
            return function () { return !0; }; if (null != l) {
            var t = l.get(e);
            return null != t || (t = f(e), l.set(e, t)), t;
        } return f(e); }
        function f(t) { switch (t.type) {
            case "wildcard": return function () { return !0; };
            case "identifier":
                var r = t.value.toLowerCase();
                return function (e, t, n) { var o = n && n.nodeTypeKey || "type"; return r === e[o].toLowerCase(); };
            case "field":
                var n = t.name.split(".");
                return function (e, t) { return function e(t, r, n, o) { for (var a = r, i = o; i < n.length; ++i) {
                    if (null == a)
                        return !1;
                    var s = a[n[i]];
                    if (Array.isArray(s)) {
                        for (var u = 0; u < s.length; ++u)
                            if (e(t, s[u], n, i + 1))
                                return !0;
                        return !1;
                    }
                    a = s;
                } return t === a; }(e, t[n.length - 1], n, 0); };
            case "matches":
                var o = t.selectors.map(c);
                return function (e, t, r) { for (var n = 0; n < o.length; ++n)
                    if (o[n](e, t, r))
                        return !0; return !1; };
            case "compound":
                var a = t.selectors.map(c);
                return function (e, t, r) { for (var n = 0; n < a.length; ++n)
                    if (!a[n](e, t, r))
                        return !1; return !0; };
            case "not":
                var s = t.selectors.map(c);
                return function (e, t, r) { for (var n = 0; n < s.length; ++n)
                    if (s[n](e, t, r))
                        return !1; return !0; };
            case "has":
                var l = t.selectors.map(c);
                return function (e, t, r) { var n = !1, o = []; return i.traverse(e, { enter: function (e, t) { null != t && o.unshift(t); for (var a = 0; a < l.length; ++a)
                        if (l[a](e, o, r))
                            return n = !0, void this.break(); }, leave: function () { o.shift(); }, keys: r && r.visitorKeys, fallback: r && r.fallback || "iteration" }), n; };
            case "child":
                var f = c(t.left), p = c(t.right);
                return function (e, t, r) { return !!(t.length > 0 && p(e, t, r)) && f(t[0], t.slice(1), r); };
            case "descendant":
                var h = c(t.left), x = c(t.right);
                return function (e, t, r) { if (x(e, t, r))
                    for (var n = 0, o = t.length; n < o; ++n)
                        if (h(t[n], t.slice(n + 1), r))
                            return !0; return !1; };
            case "attribute":
                var v = t.name.split(".");
                switch (t.operator) {
                    case void 0: return function (e) { return null != u(e, v); };
                    case "=":
                        switch (t.value.type) {
                            case "regexp": return function (e) { var r = u(e, v); return "string" == typeof r && t.value.value.test(r); };
                            case "literal":
                                var g = "".concat(t.value.value);
                                return function (e) { return g === "".concat(u(e, v)); };
                            case "type": return function (r) { return t.value.value === e(u(r, v)); };
                        }
                        throw new Error("Unknown selector value type: ".concat(t.value.type));
                    case "!=":
                        switch (t.value.type) {
                            case "regexp": return function (e) { return !t.value.value.test(u(e, v)); };
                            case "literal":
                                var A = "".concat(t.value.value);
                                return function (e) { return A !== "".concat(u(e, v)); };
                            case "type": return function (r) { return t.value.value !== e(u(r, v)); };
                        }
                        throw new Error("Unknown selector value type: ".concat(t.value.type));
                    case "<=": return function (e) { return u(e, v) <= t.value.value; };
                    case "<": return function (e) { return u(e, v) < t.value.value; };
                    case ">": return function (e) { return u(e, v) > t.value.value; };
                    case ">=": return function (e) { return u(e, v) >= t.value.value; };
                }
                throw new Error("Unknown operator: ".concat(t.operator));
            case "sibling":
                var E = c(t.left), b = c(t.right);
                return function (e, r, n) { return b(e, r, n) && y(e, E, r, "LEFT_SIDE", n) || t.left.subject && E(e, r, n) && y(e, b, r, "RIGHT_SIDE", n); };
            case "adjacent":
                var S = c(t.left), _ = c(t.right);
                return function (e, r, n) { return _(e, r, n) && d(e, S, r, "LEFT_SIDE", n) || t.right.subject && S(e, r, n) && d(e, _, r, "RIGHT_SIDE", n); };
            case "nth-child":
                var C = t.index.value, w = c(t.right);
                return function (e, t, r) { return w(e, t, r) && m(e, t, C, r); };
            case "nth-last-child":
                var P = -t.index.value, k = c(t.right);
                return function (e, t, r) { return k(e, t, r) && m(e, t, P, r); };
            case "class": return function (e, r, n) { if (n && n.matchClass)
                return n.matchClass(t.name, e, r); if (n && n.nodeTypeKey)
                return !1; switch (t.name.toLowerCase()) {
                case "statement": if ("Statement" === e.type.slice(-9))
                    return !0;
                case "declaration": return "Declaration" === e.type.slice(-11);
                case "pattern": if ("Pattern" === e.type.slice(-7))
                    return !0;
                case "expression": return "Expression" === e.type.slice(-10) || "Literal" === e.type.slice(-7) || "Identifier" === e.type && (0 === r.length || "MetaProperty" !== r[0].type) || "MetaProperty" === e.type;
                case "function": return "FunctionDeclaration" === e.type || "FunctionExpression" === e.type || "ArrowFunctionExpression" === e.type;
            } throw new Error("Unknown class name: ".concat(t.name)); };
        } throw new Error("Unknown selector type: ".concat(t.type)); }
        function p(e, t) { var r = t && t.nodeTypeKey || "type", n = e[r]; return t && t.visitorKeys && t.visitorKeys[n] ? t.visitorKeys[n] : i.VisitorKeys[n] ? i.VisitorKeys[n] : t && "function" == typeof t.fallback ? t.fallback(e) : Object.keys(e).filter((function (e) { return e !== r; })); }
        function h(t, r) { var n = r && r.nodeTypeKey || "type"; return null !== t && "object" === e(t) && "string" == typeof t[n]; }
        function y(e, r, n, o, a) { var i = t(n, 1)[0]; if (!i)
            return !1; for (var s = p(i, a), u = 0; u < s.length; ++u) {
            var l = i[s[u]];
            if (Array.isArray(l)) {
                var c = l.indexOf(e);
                if (c < 0)
                    continue;
                var f = void 0, y = void 0;
                "LEFT_SIDE" === o ? (f = 0, y = c) : (f = c + 1, y = l.length);
                for (var d = f; d < y; ++d)
                    if (h(l[d], a) && r(l[d], n, a))
                        return !0;
            }
        } return !1; }
        function d(e, r, n, o, a) { var i = t(n, 1)[0]; if (!i)
            return !1; for (var s = p(i, a), u = 0; u < s.length; ++u) {
            var l = i[s[u]];
            if (Array.isArray(l)) {
                var c = l.indexOf(e);
                if (c < 0)
                    continue;
                if ("LEFT_SIDE" === o && c > 0 && h(l[c - 1], a) && r(l[c - 1], n, a))
                    return !0;
                if ("RIGHT_SIDE" === o && c < l.length - 1 && h(l[c + 1], a) && r(l[c + 1], n, a))
                    return !0;
            }
        } return !1; }
        function m(e, r, n, o) { if (0 === n)
            return !1; var a = t(r, 1)[0]; if (!a)
            return !1; for (var i = p(a, o), s = 0; s < i.length; ++s) {
            var u = a[i[s]];
            if (Array.isArray(u)) {
                var l = n < 0 ? u.length + n : n - 1;
                if (l >= 0 && l < u.length && u[l] === e)
                    return !0;
            }
        } return !1; }
        function x(t, n, o, a) { if (n) {
            var s = [], u = c(n), l = function t(n, o) { if (null == n || "object" != e(n))
                return []; null == o && (o = n); for (var a = n.subject ? [o] : [], i = Object.keys(n), s = 0; s < i.length; ++s) {
                var u = i[s], l = n[u];
                a.push.apply(a, r(t(l, "left" === u ? l : o)));
            } return a; }(n).map(c);
            i.traverse(t, { enter: function (e, t) { if (null != t && s.unshift(t), u(e, s, a))
                    if (l.length)
                        for (var r = 0, n = l.length; r < n; ++r) {
                            l[r](e, s, a) && o(e, t, s);
                            for (var i = 0, c = s.length; i < c; ++i) {
                                var f = s.slice(i + 1);
                                l[r](s[i], f, a) && o(s[i], t, f);
                            }
                        }
                    else
                        o(e, t, s); }, leave: function () { s.shift(); }, keys: a && a.visitorKeys, fallback: a && a.fallback || "iteration" });
        } }
        function v(e, t, r) { var n = []; return x(e, t, (function (e) { n.push(e); }), r), n; }
        function g(e) { return s.parse(e); }
        function A(e, t, r) { return v(e, g(t), r); }
        return A.parse = g, A.match = v, A.traverse = x, A.matches = function (e, t, r, n) { return !t || !!e && (r || (r = []), c(t)(e, r, n)); }, A.query = A, A;
    }));
    
},
/* eslint/lib/linter/report-translator.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A helper that translates context.report() calls from the rule API into generic problem objects
     * @author Teddy Katz
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const assert = require("assert");
    const ruleFixer = require(354) /* ./rule-fixer */;
    const interpolate = require(355) /* ./interpolate */;
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /**
     * An error message description
     * @typedef {Object} MessageDescriptor
     * @property {ASTNode} [node] The reported node
     * @property {Location} loc The location of the problem.
     * @property {string} message The problem message.
     * @property {Object} [data] Optional data to use to fill in placeholders in the
     *      message.
     * @property {Function} [fix] The function to call that creates a fix command.
     * @property {Array<{desc?: string, messageId?: string, fix: Function}>} suggest Suggestion descriptions and functions to create a the associated fixes.
     */
    /**
     * Information about the report
     * @typedef {Object} ReportInfo
     * @property {string} ruleId The rule ID
     * @property {(0|1|2)} severity Severity of the error
     * @property {(string|undefined)} message The message
     * @property {(string|undefined)} [messageId] The message ID
     * @property {number} line The line number
     * @property {number} column The column number
     * @property {(number|undefined)} [endLine] The ending line number
     * @property {(number|undefined)} [endColumn] The ending column number
     * @property {(string|null)} nodeType Type of node
     * @property {string} source Source text
     * @property {({text: string, range: (number[]|null)}|null)} [fix] The fix object
     * @property {Array<{text: string, range: (number[]|null)}|null>} [suggestions] Suggestion info
     */
    //------------------------------------------------------------------------------
    // Module Definition
    //------------------------------------------------------------------------------
    /**
     * Translates a multi-argument context.report() call into a single object argument call
     * @param {...*} args A list of arguments passed to `context.report`
     * @returns {MessageDescriptor} A normalized object containing report information
     */
    function normalizeMultiArgReportCall(...args) {
        // If there is one argument, it is considered to be a new-style call already.
        if (args.length === 1) {
            // Shallow clone the object to avoid surprises if reusing the descriptor
            return Object.assign({}, args[0]);
        }
        // If the second argument is a string, the arguments are interpreted as [node, message, data, fix].
        if (typeof args[1] === "string") {
            return {
                node: args[0],
                message: args[1],
                data: args[2],
                fix: args[3]
            };
        }
        // Otherwise, the arguments are interpreted as [node, loc, message, data, fix].
        return {
            node: args[0],
            loc: args[1],
            message: args[2],
            data: args[3],
            fix: args[4]
        };
    }
    /**
     * Asserts that either a loc or a node was provided, and the node is valid if it was provided.
     * @param {MessageDescriptor} descriptor A descriptor to validate
     * @returns {void}
     * @throws AssertionError if neither a node nor a loc was provided, or if the node is not an object
     */
    function assertValidNodeInfo(descriptor) {
        if (descriptor.node) {
            assert(typeof descriptor.node === "object", "Node must be an object");
        }
        else {
            assert(descriptor.loc, "Node must be provided when reporting error if location is not provided");
        }
    }
    /**
     * Normalizes a MessageDescriptor to always have a `loc` with `start` and `end` properties
     * @param {MessageDescriptor} descriptor A descriptor for the report from a rule.
     * @returns {{start: Location, end: (Location|null)}} An updated location that infers the `start` and `end` properties
     * from the `node` of the original descriptor, or infers the `start` from the `loc` of the original descriptor.
     */
    function normalizeReportLoc(descriptor) {
        if (descriptor.loc) {
            if (descriptor.loc.start) {
                return descriptor.loc;
            }
            return { start: descriptor.loc, end: null };
        }
        return descriptor.node.loc;
    }
    /**
     * Check that a fix has a valid range.
     * @param {Fix|null} fix The fix to validate.
     * @returns {void}
     */
    function assertValidFix(fix) {
        if (fix) {
            assert(fix.range && typeof fix.range[0] === "number" && typeof fix.range[1] === "number", `Fix has invalid range: ${JSON.stringify(fix, null, 2)}`);
        }
    }
    /**
     * Compares items in a fixes array by range.
     * @param {Fix} a The first message.
     * @param {Fix} b The second message.
     * @returns {int} -1 if a comes before b, 1 if a comes after b, 0 if equal.
     * @private
     */
    function compareFixesByRange(a, b) {
        return a.range[0] - b.range[0] || a.range[1] - b.range[1];
    }
    /**
     * Merges the given fixes array into one.
     * @param {Fix[]} fixes The fixes to merge.
     * @param {SourceCode} sourceCode The source code object to get the text between fixes.
     * @returns {{text: string, range: number[]}} The merged fixes
     */
    function mergeFixes(fixes, sourceCode) {
        for (const fix of fixes) {
            assertValidFix(fix);
        }
        if (fixes.length === 0) {
            return null;
        }
        if (fixes.length === 1) {
            return fixes[0];
        }
        fixes.sort(compareFixesByRange);
        const originalText = sourceCode.text;
        const start = fixes[0].range[0];
        const end = fixes[fixes.length - 1].range[1];
        let text = "";
        let lastPos = Number.MIN_SAFE_INTEGER;
        for (const fix of fixes) {
            assert(fix.range[0] >= lastPos, "Fix objects must not be overlapped in a report.");
            if (fix.range[0] >= 0) {
                text += originalText.slice(Math.max(0, start, lastPos), fix.range[0]);
            }
            text += fix.text;
            lastPos = fix.range[1];
        }
        text += originalText.slice(Math.max(0, start, lastPos), end);
        return { range: [start, end], text };
    }
    /**
     * Gets one fix object from the given descriptor.
     * If the descriptor retrieves multiple fixes, this merges those to one.
     * @param {MessageDescriptor} descriptor The report descriptor.
     * @param {SourceCode} sourceCode The source code object to get text between fixes.
     * @returns {({text: string, range: number[]}|null)} The fix for the descriptor
     */
    function normalizeFixes(descriptor, sourceCode) {
        if (typeof descriptor.fix !== "function") {
            return null;
        }
        // @type {null | Fix | Fix[] | IterableIterator<Fix>}
        const fix = descriptor.fix(ruleFixer);
        // Merge to one.
        if (fix && Symbol.iterator in fix) {
            return mergeFixes(Array.from(fix), sourceCode);
        }
        assertValidFix(fix);
        return fix;
    }
    /**
     * Gets an array of suggestion objects from the given descriptor.
     * @param {MessageDescriptor} descriptor The report descriptor.
     * @param {SourceCode} sourceCode The source code object to get text between fixes.
     * @param {Object} messages Object of meta messages for the rule.
     * @returns {Array<SuggestionResult>} The suggestions for the descriptor
     */
    function mapSuggestions(descriptor, sourceCode, messages) {
        if (!descriptor.suggest || !Array.isArray(descriptor.suggest)) {
            return [];
        }
        return descriptor.suggest
            .map(suggestInfo => {
            const computedDesc = suggestInfo.desc || messages[suggestInfo.messageId];
            return {
                ...suggestInfo,
                desc: interpolate(computedDesc, suggestInfo.data),
                fix: normalizeFixes(suggestInfo, sourceCode)
            };
        })
            // Remove suggestions that didn't provide a fix
            .filter(({ fix }) => fix);
    }
    /**
     * Creates information about the report from a descriptor
     * @param {Object} options Information about the problem
     * @param {string} options.ruleId Rule ID
     * @param {(0|1|2)} options.severity Rule severity
     * @param {(ASTNode|null)} options.node Node
     * @param {string} options.message Error message
     * @param {string} [options.messageId] The error message ID.
     * @param {{start: SourceLocation, end: (SourceLocation|null)}} options.loc Start and end location
     * @param {{text: string, range: (number[]|null)}} options.fix The fix object
     * @param {Array<{text: string, range: (number[]|null)}>} options.suggestions The array of suggestions objects
     * @returns {function(...args): ReportInfo} Function that returns information about the report
     */
    function createProblem(options) {
        const problem = {
            ruleId: options.ruleId,
            severity: options.severity,
            message: options.message,
            line: options.loc.start.line,
            column: options.loc.start.column + 1,
            nodeType: options.node && options.node.type || null
        };
        /*
         * If this isn’t in the conditional, some of the tests fail
         * because `messageId` is present in the problem object
         */
        if (options.messageId) {
            problem.messageId = options.messageId;
        }
        if (options.loc.end) {
            problem.endLine = options.loc.end.line;
            problem.endColumn = options.loc.end.column + 1;
        }
        if (options.fix) {
            problem.fix = options.fix;
        }
        if (options.suggestions && options.suggestions.length > 0) {
            problem.suggestions = options.suggestions;
        }
        return problem;
    }
    /**
     * Validates that suggestions are properly defined. Throws if an error is detected.
     * @param {Array<{ desc?: string, messageId?: string }>} suggest The incoming suggest data.
     * @param {Object} messages Object of meta messages for the rule.
     * @returns {void}
     */
    function validateSuggestions(suggest, messages) {
        if (suggest && Array.isArray(suggest)) {
            suggest.forEach(suggestion => {
                if (suggestion.messageId) {
                    const { messageId } = suggestion;
                    if (!messages) {
                        throw new TypeError(`context.report() called with a suggest option with a messageId '${messageId}', but no messages were present in the rule metadata.`);
                    }
                    if (!messages[messageId]) {
                        throw new TypeError(`context.report() called with a suggest option with a messageId '${messageId}' which is not present in the 'messages' config: ${JSON.stringify(messages, null, 2)}`);
                    }
                    if (suggestion.desc) {
                        throw new TypeError("context.report() called with a suggest option that defines both a 'messageId' and an 'desc'. Please only pass one.");
                    }
                }
                else if (!suggestion.desc) {
                    throw new TypeError("context.report() called with a suggest option that doesn't have either a `desc` or `messageId`");
                }
                if (typeof suggestion.fix !== "function") {
                    throw new TypeError(`context.report() called with a suggest option without a fix function. See: ${suggestion}`);
                }
            });
        }
    }
    /**
     * Returns a function that converts the arguments of a `context.report` call from a rule into a reported
     * problem for the Node.js API.
     * @param {{ruleId: string, severity: number, sourceCode: SourceCode, messageIds: Object, disableFixes: boolean}} metadata Metadata for the reported problem
     * @param {SourceCode} sourceCode The `SourceCode` instance for the text being linted
     * @returns {function(...args): ReportInfo} Function that returns information about the report
     */
    module.exports = function createReportTranslator(metadata) {
        /*
         * `createReportTranslator` gets called once per enabled rule per file. It needs to be very performant.
         * The report translator itself (i.e. the function that `createReportTranslator` returns) gets
         * called every time a rule reports a problem, which happens much less frequently (usually, the vast
         * majority of rules don't report any problems for a given file).
         */
        return (...args) => {
            const descriptor = normalizeMultiArgReportCall(...args);
            const messages = metadata.messageIds;
            assertValidNodeInfo(descriptor);
            let computedMessage;
            if (descriptor.messageId) {
                if (!messages) {
                    throw new TypeError("context.report() called with a messageId, but no messages were present in the rule metadata.");
                }
                const id = descriptor.messageId;
                if (descriptor.message) {
                    throw new TypeError("context.report() called with a message and a messageId. Please only pass one.");
                }
                if (!messages || !Object.prototype.hasOwnProperty.call(messages, id)) {
                    throw new TypeError(`context.report() called with a messageId of '${id}' which is not present in the 'messages' config: ${JSON.stringify(messages, null, 2)}`);
                }
                computedMessage = messages[id];
            }
            else if (descriptor.message) {
                computedMessage = descriptor.message;
            }
            else {
                throw new TypeError("Missing `message` property in report() call; add a message that describes the linting problem.");
            }
            validateSuggestions(descriptor.suggest, messages);
            return createProblem({
                ruleId: metadata.ruleId,
                severity: metadata.severity,
                node: descriptor.node,
                message: interpolate(computedMessage, descriptor.data),
                messageId: descriptor.messageId,
                loc: normalizeReportLoc(descriptor),
                fix: metadata.disableFixes ? null : normalizeFixes(descriptor, metadata.sourceCode),
                suggestions: metadata.disableFixes ? [] : mapSuggestions(descriptor, metadata.sourceCode, messages)
            });
        };
    };
},
/* eslint/lib/linter/rule-fixer.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview An object that creates fix commands for rules.
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    // none!
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Creates a fix command that inserts text at the specified index in the source text.
     * @param {int} index The 0-based index at which to insert the new text.
     * @param {string} text The text to insert.
     * @returns {Object} The fix command.
     * @private
     */
    function insertTextAt(index, text) {
        return {
            range: [index, index],
            text
        };
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * Creates code fixing commands for rules.
     */
    const ruleFixer = Object.freeze({
        /**
         * Creates a fix command that inserts text after the given node or token.
         * The fix is not applied until applyFixes() is called.
         * @param {ASTNode|Token} nodeOrToken The node or token to insert after.
         * @param {string} text The text to insert.
         * @returns {Object} The fix command.
         */
        insertTextAfter(nodeOrToken, text) {
            return this.insertTextAfterRange(nodeOrToken.range, text);
        },
        /**
         * Creates a fix command that inserts text after the specified range in the source text.
         * The fix is not applied until applyFixes() is called.
         * @param {int[]} range The range to replace, first item is start of range, second
         *      is end of range.
         * @param {string} text The text to insert.
         * @returns {Object} The fix command.
         */
        insertTextAfterRange(range, text) {
            return insertTextAt(range[1], text);
        },
        /**
         * Creates a fix command that inserts text before the given node or token.
         * The fix is not applied until applyFixes() is called.
         * @param {ASTNode|Token} nodeOrToken The node or token to insert before.
         * @param {string} text The text to insert.
         * @returns {Object} The fix command.
         */
        insertTextBefore(nodeOrToken, text) {
            return this.insertTextBeforeRange(nodeOrToken.range, text);
        },
        /**
         * Creates a fix command that inserts text before the specified range in the source text.
         * The fix is not applied until applyFixes() is called.
         * @param {int[]} range The range to replace, first item is start of range, second
         *      is end of range.
         * @param {string} text The text to insert.
         * @returns {Object} The fix command.
         */
        insertTextBeforeRange(range, text) {
            return insertTextAt(range[0], text);
        },
        /**
         * Creates a fix command that replaces text at the node or token.
         * The fix is not applied until applyFixes() is called.
         * @param {ASTNode|Token} nodeOrToken The node or token to remove.
         * @param {string} text The text to insert.
         * @returns {Object} The fix command.
         */
        replaceText(nodeOrToken, text) {
            return this.replaceTextRange(nodeOrToken.range, text);
        },
        /**
         * Creates a fix command that replaces text at the specified range in the source text.
         * The fix is not applied until applyFixes() is called.
         * @param {int[]} range The range to replace, first item is start of range, second
         *      is end of range.
         * @param {string} text The text to insert.
         * @returns {Object} The fix command.
         */
        replaceTextRange(range, text) {
            return {
                range,
                text
            };
        },
        /**
         * Creates a fix command that removes the node or token from the source.
         * The fix is not applied until applyFixes() is called.
         * @param {ASTNode|Token} nodeOrToken The node or token to remove.
         * @returns {Object} The fix command.
         */
        remove(nodeOrToken) {
            return this.removeRange(nodeOrToken.range);
        },
        /**
         * Creates a fix command that removes the specified range of text from the source.
         * The fix is not applied until applyFixes() is called.
         * @param {int[]} range The range to remove, first item is start of range, second
         *      is end of range.
         * @returns {Object} The fix command.
         */
        removeRange(range) {
            return {
                range,
                text: ""
            };
        }
    });
    module.exports = ruleFixer;
},
/* eslint/lib/linter/interpolate.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Interpolate keys from an object into a string with {{ }} markers.
     * @author Jed Fox
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = (text, data) => {
        if (!data) {
            return text;
        }
        // Substitution content for any {{ }} markers.
        return text.replace(/\{\{([^{}]+?)\}\}/gu, (fullMatch, termWithWhitespace) => {
            const term = termWithWhitespace.trim();
            if (term in data) {
                return data[term];
            }
            // Preserve old behavior: If parameter name not provided, don't replace it.
            return fullMatch;
        });
    };
},
/* eslint/lib/linter/rules.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Defines a storage for rules.
     * @author Nicholas C. Zakas
     * @author aladdin-add
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const builtInRules = require(357) /* ../rules */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Normalizes a rule module to the new-style API
     * @param {(Function|{create: Function})} rule A rule object, which can either be a function
     * ("old-style") or an object with a `create` method ("new-style")
     * @returns {{create: Function}} A new-style rule.
     */
    function normalizeRule(rule) {
        return typeof rule === "function" ? Object.assign({ create: rule }, rule) : rule;
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * A storage for rules.
     */
    class Rules {
        constructor() {
            this._rules = Object.create(null);
        }
        /**
         * Registers a rule module for rule id in storage.
         * @param {string} ruleId Rule id (file name).
         * @param {Function} ruleModule Rule handler.
         * @returns {void}
         */
        define(ruleId, ruleModule) {
            this._rules[ruleId] = normalizeRule(ruleModule);
        }
        /**
         * Access rule handler by id (file name).
         * @param {string} ruleId Rule id (file name).
         * @returns {{create: Function, schema: JsonSchema[]}}
         * A rule. This is normalized to always have the new-style shape with a `create` method.
         */
        get(ruleId) {
            if (typeof this._rules[ruleId] === "string") {
                this.define(ruleId, require(this._rules[ruleId]));
            }
            if (this._rules[ruleId]) {
                return this._rules[ruleId];
            }
            if (builtInRules.has(ruleId)) {
                return builtInRules.get(ruleId);
            }
            return null;
        }
        *[Symbol.iterator]() {
            yield* builtInRules;
            for (const ruleId of Object.keys(this._rules)) {
                yield [ruleId, this.get(ruleId)];
            }
        }
    }
    module.exports = Rules;
},
/* eslint/lib/rules/index.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Collects the built-in rules into a map structure so that they can be imported all at once and without
     * using the file-system directly.
     * @author Peter (Somogyvari) Metz
     */
    "use strict";
    /* eslint sort-keys: ["error", "asc"] -- More readable for long list */
    const { LazyLoadingRuleMap } = require(358) /* ./utils/lazy-loading-rule-map */;
    /** @type {Map<string, import("../shared/types").Rule>} */
    module.exports = new LazyLoadingRuleMap(Object.entries({
        "accessor-pairs": () => require(359) /* ./accessor-pairs */,
        "array-bracket-newline": () => require(365) /* ./array-bracket-newline */,
        "array-bracket-spacing": () => require(366) /* ./array-bracket-spacing */,
        "array-callback-return": () => require(367) /* ./array-callback-return */,
        "array-element-newline": () => require(368) /* ./array-element-newline */,
        "arrow-body-style": () => require(369) /* ./arrow-body-style */,
        "arrow-parens": () => require(370) /* ./arrow-parens */,
        "arrow-spacing": () => require(371) /* ./arrow-spacing */,
        "block-scoped-var": () => require(372) /* ./block-scoped-var */,
        "block-spacing": () => require(373) /* ./block-spacing */,
        "brace-style": () => require(374) /* ./brace-style */,
        "callback-return": () => require(375) /* ./callback-return */,
        camelcase: () => require(376) /* ./camelcase */,
        "capitalized-comments": () => require(377) /* ./capitalized-comments */,
        "class-methods-use-this": () => require(379) /* ./class-methods-use-this */,
        "comma-dangle": () => require(380) /* ./comma-dangle */,
        "comma-spacing": () => require(381) /* ./comma-spacing */,
        "comma-style": () => require(382) /* ./comma-style */,
        complexity: () => require(383) /* ./complexity */,
        "computed-property-spacing": () => require(385) /* ./computed-property-spacing */,
        "consistent-return": () => require(386) /* ./consistent-return */,
        "consistent-this": () => require(387) /* ./consistent-this */,
        "constructor-super": () => require(388) /* ./constructor-super */,
        curly: () => require(389) /* ./curly */,
        "default-case": () => require(390) /* ./default-case */,
        "default-case-last": () => require(391) /* ./default-case-last */,
        "default-param-last": () => require(392) /* ./default-param-last */,
        "dot-location": () => require(393) /* ./dot-location */,
        "dot-notation": () => require(394) /* ./dot-notation */,
        "eol-last": () => require(396) /* ./eol-last */,
        eqeqeq: () => require(397) /* ./eqeqeq */,
        "for-direction": () => require(398) /* ./for-direction */,
        "func-call-spacing": () => require(399) /* ./func-call-spacing */,
        "func-name-matching": () => require(400) /* ./func-name-matching */,
        "func-names": () => require(401) /* ./func-names */,
        "func-style": () => require(402) /* ./func-style */,
        "function-call-argument-newline": () => require(403) /* ./function-call-argument-newline */,
        "function-paren-newline": () => require(404) /* ./function-paren-newline */,
        "generator-star-spacing": () => require(405) /* ./generator-star-spacing */,
        "getter-return": () => require(406) /* ./getter-return */,
        "global-require": () => require(407) /* ./global-require */,
        "grouped-accessor-pairs": () => require(408) /* ./grouped-accessor-pairs */,
        "guard-for-in": () => require(409) /* ./guard-for-in */,
        "handle-callback-err": () => require(410) /* ./handle-callback-err */,
        "id-blacklist": () => require(411) /* ./id-blacklist */,
        "id-denylist": () => require(412) /* ./id-denylist */,
        "id-length": () => require(413) /* ./id-length */,
        "id-match": () => require(415) /* ./id-match */,
        "implicit-arrow-linebreak": () => require(416) /* ./implicit-arrow-linebreak */,
        indent: () => require(417) /* ./indent */,
        "indent-legacy": () => require(438) /* ./indent-legacy */,
        "init-declarations": () => require(439) /* ./init-declarations */,
        "jsx-quotes": () => require(440) /* ./jsx-quotes */,
        "key-spacing": () => require(441) /* ./key-spacing */,
        "keyword-spacing": () => require(442) /* ./keyword-spacing */,
        "line-comment-position": () => require(443) /* ./line-comment-position */,
        "linebreak-style": () => require(444) /* ./linebreak-style */,
        "lines-around-comment": () => require(445) /* ./lines-around-comment */,
        "lines-around-directive": () => require(446) /* ./lines-around-directive */,
        "lines-between-class-members": () => require(447) /* ./lines-between-class-members */,
        "logical-assignment-operators": () => require(448) /* ./logical-assignment-operators */,
        "max-classes-per-file": () => require(449) /* ./max-classes-per-file */,
        "max-depth": () => require(450) /* ./max-depth */,
        "max-len": () => require(451) /* ./max-len */,
        "max-lines": () => require(452) /* ./max-lines */,
        "max-lines-per-function": () => require(453) /* ./max-lines-per-function */,
        "max-nested-callbacks": () => require(454) /* ./max-nested-callbacks */,
        "max-params": () => require(455) /* ./max-params */,
        "max-statements": () => require(456) /* ./max-statements */,
        "max-statements-per-line": () => require(457) /* ./max-statements-per-line */,
        "multiline-comment-style": () => require(458) /* ./multiline-comment-style */,
        "multiline-ternary": () => require(459) /* ./multiline-ternary */,
        "new-cap": () => require(460) /* ./new-cap */,
        "new-parens": () => require(461) /* ./new-parens */,
        "newline-after-var": () => require(462) /* ./newline-after-var */,
        "newline-before-return": () => require(463) /* ./newline-before-return */,
        "newline-per-chained-call": () => require(464) /* ./newline-per-chained-call */,
        "no-alert": () => require(465) /* ./no-alert */,
        "no-array-constructor": () => require(466) /* ./no-array-constructor */,
        "no-async-promise-executor": () => require(467) /* ./no-async-promise-executor */,
        "no-await-in-loop": () => require(468) /* ./no-await-in-loop */,
        "no-bitwise": () => require(469) /* ./no-bitwise */,
        "no-buffer-constructor": () => require(470) /* ./no-buffer-constructor */,
        "no-caller": () => require(471) /* ./no-caller */,
        "no-case-declarations": () => require(472) /* ./no-case-declarations */,
        "no-catch-shadow": () => require(473) /* ./no-catch-shadow */,
        "no-class-assign": () => require(474) /* ./no-class-assign */,
        "no-compare-neg-zero": () => require(475) /* ./no-compare-neg-zero */,
        "no-cond-assign": () => require(476) /* ./no-cond-assign */,
        "no-confusing-arrow": () => require(477) /* ./no-confusing-arrow */,
        "no-console": () => require(478) /* ./no-console */,
        "no-const-assign": () => require(479) /* ./no-const-assign */,
        "no-constant-binary-expression": () => require(480) /* ./no-constant-binary-expression */,
        "no-constant-condition": () => require(481) /* ./no-constant-condition */,
        "no-constructor-return": () => require(482) /* ./no-constructor-return */,
        "no-continue": () => require(483) /* ./no-continue */,
        "no-control-regex": () => require(484) /* ./no-control-regex */,
        "no-debugger": () => require(486) /* ./no-debugger */,
        "no-delete-var": () => require(487) /* ./no-delete-var */,
        "no-div-regex": () => require(488) /* ./no-div-regex */,
        "no-dupe-args": () => require(489) /* ./no-dupe-args */,
        "no-dupe-class-members": () => require(490) /* ./no-dupe-class-members */,
        "no-dupe-else-if": () => require(491) /* ./no-dupe-else-if */,
        "no-dupe-keys": () => require(492) /* ./no-dupe-keys */,
        "no-duplicate-case": () => require(493) /* ./no-duplicate-case */,
        "no-duplicate-imports": () => require(494) /* ./no-duplicate-imports */,
        "no-else-return": () => require(495) /* ./no-else-return */,
        "no-empty": () => require(497) /* ./no-empty */,
        "no-empty-character-class": () => require(498) /* ./no-empty-character-class */,
        "no-empty-function": () => require(499) /* ./no-empty-function */,
        "no-empty-pattern": () => require(500) /* ./no-empty-pattern */,
        "no-empty-static-block": () => require(501) /* ./no-empty-static-block */,
        "no-eq-null": () => require(502) /* ./no-eq-null */,
        "no-eval": () => require(503) /* ./no-eval */,
        "no-ex-assign": () => require(504) /* ./no-ex-assign */,
        "no-extend-native": () => require(505) /* ./no-extend-native */,
        "no-extra-bind": () => require(506) /* ./no-extra-bind */,
        "no-extra-boolean-cast": () => require(507) /* ./no-extra-boolean-cast */,
        "no-extra-label": () => require(508) /* ./no-extra-label */,
        "no-extra-parens": () => require(509) /* ./no-extra-parens */,
        "no-extra-semi": () => require(510) /* ./no-extra-semi */,
        "no-fallthrough": () => require(511) /* ./no-fallthrough */,
        "no-floating-decimal": () => require(512) /* ./no-floating-decimal */,
        "no-func-assign": () => require(513) /* ./no-func-assign */,
        "no-global-assign": () => require(514) /* ./no-global-assign */,
        "no-implicit-coercion": () => require(515) /* ./no-implicit-coercion */,
        "no-implicit-globals": () => require(516) /* ./no-implicit-globals */,
        "no-implied-eval": () => require(517) /* ./no-implied-eval */,
        "no-import-assign": () => require(518) /* ./no-import-assign */,
        "no-inline-comments": () => require(519) /* ./no-inline-comments */,
        "no-inner-declarations": () => require(520) /* ./no-inner-declarations */,
        "no-invalid-regexp": () => require(521) /* ./no-invalid-regexp */,
        "no-invalid-this": () => require(522) /* ./no-invalid-this */,
        "no-irregular-whitespace": () => require(523) /* ./no-irregular-whitespace */,
        "no-iterator": () => require(524) /* ./no-iterator */,
        "no-label-var": () => require(525) /* ./no-label-var */,
        "no-labels": () => require(526) /* ./no-labels */,
        "no-lone-blocks": () => require(527) /* ./no-lone-blocks */,
        "no-lonely-if": () => require(528) /* ./no-lonely-if */,
        "no-loop-func": () => require(529) /* ./no-loop-func */,
        "no-loss-of-precision": () => require(530) /* ./no-loss-of-precision */,
        "no-magic-numbers": () => require(531) /* ./no-magic-numbers */,
        "no-misleading-character-class": () => require(532) /* ./no-misleading-character-class */,
        "no-mixed-operators": () => require(538) /* ./no-mixed-operators */,
        "no-mixed-requires": () => require(539) /* ./no-mixed-requires */,
        "no-mixed-spaces-and-tabs": () => require(540) /* ./no-mixed-spaces-and-tabs */,
        "no-multi-assign": () => require(541) /* ./no-multi-assign */,
        "no-multi-spaces": () => require(542) /* ./no-multi-spaces */,
        "no-multi-str": () => require(543) /* ./no-multi-str */,
        "no-multiple-empty-lines": () => require(544) /* ./no-multiple-empty-lines */,
        "no-native-reassign": () => require(545) /* ./no-native-reassign */,
        "no-negated-condition": () => require(546) /* ./no-negated-condition */,
        "no-negated-in-lhs": () => require(547) /* ./no-negated-in-lhs */,
        "no-nested-ternary": () => require(548) /* ./no-nested-ternary */,
        "no-new": () => require(549) /* ./no-new */,
        "no-new-func": () => require(550) /* ./no-new-func */,
        "no-new-native-nonconstructor": () => require(551) /* ./no-new-native-nonconstructor */,
        "no-new-object": () => require(552) /* ./no-new-object */,
        "no-new-require": () => require(553) /* ./no-new-require */,
        "no-new-symbol": () => require(554) /* ./no-new-symbol */,
        "no-new-wrappers": () => require(555) /* ./no-new-wrappers */,
        "no-nonoctal-decimal-escape": () => require(556) /* ./no-nonoctal-decimal-escape */,
        "no-obj-calls": () => require(557) /* ./no-obj-calls */,
        "no-octal": () => require(558) /* ./no-octal */,
        "no-octal-escape": () => require(559) /* ./no-octal-escape */,
        "no-param-reassign": () => require(560) /* ./no-param-reassign */,
        "no-path-concat": () => require(561) /* ./no-path-concat */,
        "no-plusplus": () => require(562) /* ./no-plusplus */,
        "no-process-env": () => require(563) /* ./no-process-env */,
        "no-process-exit": () => require(564) /* ./no-process-exit */,
        "no-promise-executor-return": () => require(565) /* ./no-promise-executor-return */,
        "no-proto": () => require(566) /* ./no-proto */,
        "no-prototype-builtins": () => require(567) /* ./no-prototype-builtins */,
        "no-redeclare": () => require(568) /* ./no-redeclare */,
        "no-regex-spaces": () => require(569) /* ./no-regex-spaces */,
        "no-restricted-exports": () => require(570) /* ./no-restricted-exports */,
        "no-restricted-globals": () => require(571) /* ./no-restricted-globals */,
        "no-restricted-imports": () => require(572) /* ./no-restricted-imports */,
        "no-restricted-modules": () => require(573) /* ./no-restricted-modules */,
        "no-restricted-properties": () => require(574) /* ./no-restricted-properties */,
        "no-restricted-syntax": () => require(575) /* ./no-restricted-syntax */,
        "no-return-assign": () => require(576) /* ./no-return-assign */,
        "no-return-await": () => require(577) /* ./no-return-await */,
        "no-script-url": () => require(578) /* ./no-script-url */,
        "no-self-assign": () => require(579) /* ./no-self-assign */,
        "no-self-compare": () => require(580) /* ./no-self-compare */,
        "no-sequences": () => require(581) /* ./no-sequences */,
        "no-setter-return": () => require(582) /* ./no-setter-return */,
        "no-shadow": () => require(583) /* ./no-shadow */,
        "no-shadow-restricted-names": () => require(584) /* ./no-shadow-restricted-names */,
        "no-spaced-func": () => require(585) /* ./no-spaced-func */,
        "no-sparse-arrays": () => require(586) /* ./no-sparse-arrays */,
        "no-sync": () => require(587) /* ./no-sync */,
        "no-tabs": () => require(588) /* ./no-tabs */,
        "no-template-curly-in-string": () => require(589) /* ./no-template-curly-in-string */,
        "no-ternary": () => require(590) /* ./no-ternary */,
        "no-this-before-super": () => require(591) /* ./no-this-before-super */,
        "no-throw-literal": () => require(592) /* ./no-throw-literal */,
        "no-trailing-spaces": () => require(593) /* ./no-trailing-spaces */,
        "no-undef": () => require(594) /* ./no-undef */,
        "no-undef-init": () => require(595) /* ./no-undef-init */,
        "no-undefined": () => require(596) /* ./no-undefined */,
        "no-underscore-dangle": () => require(597) /* ./no-underscore-dangle */,
        "no-unexpected-multiline": () => require(598) /* ./no-unexpected-multiline */,
        "no-unmodified-loop-condition": () => require(599) /* ./no-unmodified-loop-condition */,
        "no-unneeded-ternary": () => require(600) /* ./no-unneeded-ternary */,
        "no-unreachable": () => require(601) /* ./no-unreachable */,
        "no-unreachable-loop": () => require(602) /* ./no-unreachable-loop */,
        "no-unsafe-finally": () => require(603) /* ./no-unsafe-finally */,
        "no-unsafe-negation": () => require(604) /* ./no-unsafe-negation */,
        "no-unsafe-optional-chaining": () => require(605) /* ./no-unsafe-optional-chaining */,
        "no-unused-expressions": () => require(606) /* ./no-unused-expressions */,
        "no-unused-labels": () => require(607) /* ./no-unused-labels */,
        "no-unused-private-class-members": () => require(608) /* ./no-unused-private-class-members */,
        "no-unused-vars": () => require(609) /* ./no-unused-vars */,
        "no-use-before-define": () => require(610) /* ./no-use-before-define */,
        "no-useless-backreference": () => require(611) /* ./no-useless-backreference */,
        "no-useless-call": () => require(612) /* ./no-useless-call */,
        "no-useless-catch": () => require(613) /* ./no-useless-catch */,
        "no-useless-computed-key": () => require(614) /* ./no-useless-computed-key */,
        "no-useless-concat": () => require(615) /* ./no-useless-concat */,
        "no-useless-constructor": () => require(616) /* ./no-useless-constructor */,
        "no-useless-escape": () => require(617) /* ./no-useless-escape */,
        "no-useless-rename": () => require(618) /* ./no-useless-rename */,
        "no-useless-return": () => require(619) /* ./no-useless-return */,
        "no-var": () => require(620) /* ./no-var */,
        "no-void": () => require(621) /* ./no-void */,
        "no-warning-comments": () => require(622) /* ./no-warning-comments */,
        "no-whitespace-before-property": () => require(623) /* ./no-whitespace-before-property */,
        "no-with": () => require(624) /* ./no-with */,
        "nonblock-statement-body-position": () => require(625) /* ./nonblock-statement-body-position */,
        "object-curly-newline": () => require(626) /* ./object-curly-newline */,
        "object-curly-spacing": () => require(627) /* ./object-curly-spacing */,
        "object-property-newline": () => require(628) /* ./object-property-newline */,
        "object-shorthand": () => require(629) /* ./object-shorthand */,
        "one-var": () => require(630) /* ./one-var */,
        "one-var-declaration-per-line": () => require(631) /* ./one-var-declaration-per-line */,
        "operator-assignment": () => require(632) /* ./operator-assignment */,
        "operator-linebreak": () => require(633) /* ./operator-linebreak */,
        "padded-blocks": () => require(634) /* ./padded-blocks */,
        "padding-line-between-statements": () => require(635) /* ./padding-line-between-statements */,
        "prefer-arrow-callback": () => require(636) /* ./prefer-arrow-callback */,
        "prefer-const": () => require(637) /* ./prefer-const */,
        "prefer-destructuring": () => require(638) /* ./prefer-destructuring */,
        "prefer-exponentiation-operator": () => require(639) /* ./prefer-exponentiation-operator */,
        "prefer-named-capture-group": () => require(640) /* ./prefer-named-capture-group */,
        "prefer-numeric-literals": () => require(641) /* ./prefer-numeric-literals */,
        "prefer-object-has-own": () => require(642) /* ./prefer-object-has-own */,
        "prefer-object-spread": () => require(643) /* ./prefer-object-spread */,
        "prefer-promise-reject-errors": () => require(644) /* ./prefer-promise-reject-errors */,
        "prefer-reflect": () => require(645) /* ./prefer-reflect */,
        "prefer-regex-literals": () => require(646) /* ./prefer-regex-literals */,
        "prefer-rest-params": () => require(647) /* ./prefer-rest-params */,
        "prefer-spread": () => require(648) /* ./prefer-spread */,
        "prefer-template": () => require(649) /* ./prefer-template */,
        "quote-props": () => require(650) /* ./quote-props */,
        quotes: () => require(651) /* ./quotes */,
        radix: () => require(652) /* ./radix */,
        "require-atomic-updates": () => require(653) /* ./require-atomic-updates */,
        "require-await": () => require(654) /* ./require-await */,
        "require-jsdoc": () => require(655) /* ./require-jsdoc */,
        "require-unicode-regexp": () => require(656) /* ./require-unicode-regexp */,
        "require-yield": () => require(657) /* ./require-yield */,
        "rest-spread-spacing": () => require(658) /* ./rest-spread-spacing */,
        semi: () => require(659) /* ./semi */,
        "semi-spacing": () => require(660) /* ./semi-spacing */,
        "semi-style": () => require(661) /* ./semi-style */,
        "sort-imports": () => require(662) /* ./sort-imports */,
        "sort-keys": () => require(663) /* ./sort-keys */,
        "sort-vars": () => require(665) /* ./sort-vars */,
        "space-before-blocks": () => require(666) /* ./space-before-blocks */,
        "space-before-function-paren": () => require(667) /* ./space-before-function-paren */,
        "space-in-parens": () => require(668) /* ./space-in-parens */,
        "space-infix-ops": () => require(669) /* ./space-infix-ops */,
        "space-unary-ops": () => require(670) /* ./space-unary-ops */,
        "spaced-comment": () => require(671) /* ./spaced-comment */,
        strict: () => require(672) /* ./strict */,
        "switch-colon-spacing": () => require(673) /* ./switch-colon-spacing */,
        "symbol-description": () => require(674) /* ./symbol-description */,
        "template-curly-spacing": () => require(675) /* ./template-curly-spacing */,
        "template-tag-spacing": () => require(676) /* ./template-tag-spacing */,
        "unicode-bom": () => require(677) /* ./unicode-bom */,
        "use-isnan": () => require(678) /* ./use-isnan */,
        "valid-jsdoc": () => require(679) /* ./valid-jsdoc */,
        "valid-typeof": () => require(684) /* ./valid-typeof */,
        "vars-on-top": () => require(685) /* ./vars-on-top */,
        "wrap-iife": () => require(686) /* ./wrap-iife */,
        "wrap-regex": () => require(687) /* ./wrap-regex */,
        "yield-star-spacing": () => require(688) /* ./yield-star-spacing */,
        yoda: () => require(689) /* ./yoda */
    }));
},
/* eslint/lib/rules/utils/lazy-loading-rule-map.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview `Map` to load rules lazily.
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    const debug = require(72) /* debug */("eslint:rules");
    /** @typedef {import("./types").Rule} Rule */
    /**
     * The `Map` object that loads each rule when it's accessed.
     * @example
     * const rules = new LazyLoadingRuleMap([
     *     ["eqeqeq", () => require("eqeqeq")],
     *     ["semi", () => require("semi")],
     *     ["no-unused-vars", () => require("no-unused-vars")]
     * ]);
     *
     * rules.get("semi"); // call `() => require("semi")` here.
     *
     * @extends {Map<string, () => Rule>}
     */
    class LazyLoadingRuleMap extends Map {
        /**
         * Initialize this map.
         * @param {Array<[string, function(): Rule]>} loaders The rule loaders.
         */
        constructor(loaders) {
            let remaining = loaders.length;
            super(debug.enabled
                ? loaders.map(([ruleId, load]) => {
                    let cache = null;
                    return [
                        ruleId,
                        () => {
                            if (!cache) {
                                debug("Loading rule %o (remaining=%d)", ruleId, --remaining);
                                cache = load();
                            }
                            return cache;
                        }
                    ];
                })
                : loaders);
            // `super(...iterable)` uses `this.set()`, so disable it here.
            Object.defineProperty(LazyLoadingRuleMap.prototype, "set", {
                configurable: true,
                value: void 0
            });
        }
        /**
         * Get a rule.
         * Each rule will be loaded on the first access.
         * @param {string} ruleId The rule ID to get.
         * @returns {Rule|undefined} The rule.
         */
        get(ruleId) {
            const load = super.get(ruleId);
            return load && load();
        }
        /**
         * Iterate rules.
         * @returns {IterableIterator<Rule>} Rules.
         */
        *values() {
            for (const load of super.values()) {
                yield load();
            }
        }
        /**
         * Iterate rules.
         * @returns {IterableIterator<[string, Rule]>} Rules.
         */
        *entries() {
            for (const [ruleId, load] of super.entries()) {
                yield [ruleId, load()];
            }
        }
        /**
         * Call a function with each rule.
         * @param {Function} callbackFn The callback function.
         * @param {any} [thisArg] The object to pass to `this` of the callback function.
         * @returns {void}
         */
        forEach(callbackFn, thisArg) {
            for (const [ruleId, load] of super.entries()) {
                callbackFn.call(thisArg, load(), ruleId, this);
            }
        }
    }
    // Forbid mutation.
    Object.defineProperties(LazyLoadingRuleMap.prototype, {
        clear: { configurable: true, value: void 0 },
        delete: { configurable: true, value: void 0 },
        [Symbol.iterator]: {
            configurable: true,
            writable: true,
            value: LazyLoadingRuleMap.prototype.entries
        }
    });
    module.exports = { LazyLoadingRuleMap };
},
/* eslint/lib/rules/accessor-pairs.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce getter and setter pairs in objects and classes.
     * @author Gyandeep Singh
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /**
     * Property name if it can be computed statically, otherwise the list of the tokens of the key node.
     * @typedef {string|Token[]} Key
     */
    /**
     * Accessor nodes with the same key.
     * @typedef {Object} AccessorData
     * @property {Key} key Accessor's key
     * @property {ASTNode[]} getters List of getter nodes.
     * @property {ASTNode[]} setters List of setter nodes.
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not the given lists represent the equal tokens in the same order.
     * Tokens are compared by their properties, not by instance.
     * @param {Token[]} left First list of tokens.
     * @param {Token[]} right Second list of tokens.
     * @returns {boolean} `true` if the lists have same tokens.
     */
    function areEqualTokenLists(left, right) {
        if (left.length !== right.length) {
            return false;
        }
        for (let i = 0; i < left.length; i++) {
            const leftToken = left[i], rightToken = right[i];
            if (leftToken.type !== rightToken.type || leftToken.value !== rightToken.value) {
                return false;
            }
        }
        return true;
    }
    /**
     * Checks whether or not the given keys are equal.
     * @param {Key} left First key.
     * @param {Key} right Second key.
     * @returns {boolean} `true` if the keys are equal.
     */
    function areEqualKeys(left, right) {
        if (typeof left === "string" && typeof right === "string") {
            // Statically computed names.
            return left === right;
        }
        if (Array.isArray(left) && Array.isArray(right)) {
            // Token lists.
            return areEqualTokenLists(left, right);
        }
        return false;
    }
    /**
     * Checks whether or not a given node is of an accessor kind ('get' or 'set').
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node is of an accessor kind.
     */
    function isAccessorKind(node) {
        return node.kind === "get" || node.kind === "set";
    }
    /**
     * Checks whether or not a given node is an argument of a specified method call.
     * @param {ASTNode} node A node to check.
     * @param {number} index An expected index of the node in arguments.
     * @param {string} object An expected name of the object of the method.
     * @param {string} property An expected name of the method.
     * @returns {boolean} `true` if the node is an argument of the specified method call.
     */
    function isArgumentOfMethodCall(node, index, object, property) {
        const parent = node.parent;
        return (parent.type === "CallExpression" &&
            astUtils.isSpecificMemberAccess(parent.callee, object, property) &&
            parent.arguments[index] === node);
    }
    /**
     * Checks whether or not a given node is a property descriptor.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node is a property descriptor.
     */
    function isPropertyDescriptor(node) {
        // Object.defineProperty(obj, "foo", {set: ...})
        if (isArgumentOfMethodCall(node, 2, "Object", "defineProperty") ||
            isArgumentOfMethodCall(node, 2, "Reflect", "defineProperty")) {
            return true;
        }
        /*
         * Object.defineProperties(obj, {foo: {set: ...}})
         * Object.create(proto, {foo: {set: ...}})
         */
        const grandparent = node.parent.parent;
        return grandparent.type === "ObjectExpression" && (isArgumentOfMethodCall(grandparent, 1, "Object", "create") ||
            isArgumentOfMethodCall(grandparent, 1, "Object", "defineProperties"));
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce getter and setter pairs in objects and classes",
                recommended: false,
                url: "https://eslint.org/docs/rules/accessor-pairs"
            },
            schema: [{
                    type: "object",
                    properties: {
                        getWithoutSet: {
                            type: "boolean",
                            default: false
                        },
                        setWithoutGet: {
                            type: "boolean",
                            default: true
                        },
                        enforceForClassMembers: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                missingGetterInPropertyDescriptor: "Getter is not present in property descriptor.",
                missingSetterInPropertyDescriptor: "Setter is not present in property descriptor.",
                missingGetterInObjectLiteral: "Getter is not present for {{ name }}.",
                missingSetterInObjectLiteral: "Setter is not present for {{ name }}.",
                missingGetterInClass: "Getter is not present for class {{ name }}.",
                missingSetterInClass: "Setter is not present for class {{ name }}."
            }
        },
        create(context) {
            const config = context.options[0] || {};
            const checkGetWithoutSet = config.getWithoutSet === true;
            const checkSetWithoutGet = config.setWithoutGet !== false;
            const enforceForClassMembers = config.enforceForClassMembers !== false;
            const sourceCode = context.getSourceCode();
            /**
             * Reports the given node.
             * @param {ASTNode} node The node to report.
             * @param {string} messageKind "missingGetter" or "missingSetter".
             * @returns {void}
             * @private
             */
            function report(node, messageKind) {
                if (node.type === "Property") {
                    context.report({
                        node,
                        messageId: `${messageKind}InObjectLiteral`,
                        loc: astUtils.getFunctionHeadLoc(node.value, sourceCode),
                        data: { name: astUtils.getFunctionNameWithKind(node.value) }
                    });
                }
                else if (node.type === "MethodDefinition") {
                    context.report({
                        node,
                        messageId: `${messageKind}InClass`,
                        loc: astUtils.getFunctionHeadLoc(node.value, sourceCode),
                        data: { name: astUtils.getFunctionNameWithKind(node.value) }
                    });
                }
                else {
                    context.report({
                        node,
                        messageId: `${messageKind}InPropertyDescriptor`
                    });
                }
            }
            /**
             * Reports each of the nodes in the given list using the same messageId.
             * @param {ASTNode[]} nodes Nodes to report.
             * @param {string} messageKind "missingGetter" or "missingSetter".
             * @returns {void}
             * @private
             */
            function reportList(nodes, messageKind) {
                for (const node of nodes) {
                    report(node, messageKind);
                }
            }
            /**
             * Creates a new `AccessorData` object for the given getter or setter node.
             * @param {ASTNode} node A getter or setter node.
             * @returns {AccessorData} New `AccessorData` object that contains the given node.
             * @private
             */
            function createAccessorData(node) {
                const name = astUtils.getStaticPropertyName(node);
                const key = (name !== null) ? name : sourceCode.getTokens(node.key);
                return {
                    key,
                    getters: node.kind === "get" ? [node] : [],
                    setters: node.kind === "set" ? [node] : []
                };
            }
            /**
             * Merges the given `AccessorData` object into the given accessors list.
             * @param {AccessorData[]} accessors The list to merge into.
             * @param {AccessorData} accessorData The object to merge.
             * @returns {AccessorData[]} The same instance with the merged object.
             * @private
             */
            function mergeAccessorData(accessors, accessorData) {
                const equalKeyElement = accessors.find(a => areEqualKeys(a.key, accessorData.key));
                if (equalKeyElement) {
                    equalKeyElement.getters.push(...accessorData.getters);
                    equalKeyElement.setters.push(...accessorData.setters);
                }
                else {
                    accessors.push(accessorData);
                }
                return accessors;
            }
            /**
             * Checks accessor pairs in the given list of nodes.
             * @param {ASTNode[]} nodes The list to check.
             * @returns {void}
             * @private
             */
            function checkList(nodes) {
                const accessors = nodes
                    .filter(isAccessorKind)
                    .map(createAccessorData)
                    .reduce(mergeAccessorData, []);
                for (const { getters, setters } of accessors) {
                    if (checkSetWithoutGet && setters.length && !getters.length) {
                        reportList(setters, "missingGetter");
                    }
                    if (checkGetWithoutSet && getters.length && !setters.length) {
                        reportList(getters, "missingSetter");
                    }
                }
            }
            /**
             * Checks accessor pairs in an object literal.
             * @param {ASTNode} node `ObjectExpression` node to check.
             * @returns {void}
             * @private
             */
            function checkObjectLiteral(node) {
                checkList(node.properties.filter(p => p.type === "Property"));
            }
            /**
             * Checks accessor pairs in a property descriptor.
             * @param {ASTNode} node Property descriptor `ObjectExpression` node to check.
             * @returns {void}
             * @private
             */
            function checkPropertyDescriptor(node) {
                const namesToCheck = new Set(node.properties
                    .filter(p => p.type === "Property" && p.kind === "init" && !p.computed)
                    .map(({ key }) => key.name));
                const hasGetter = namesToCheck.has("get");
                const hasSetter = namesToCheck.has("set");
                if (checkSetWithoutGet && hasSetter && !hasGetter) {
                    report(node, "missingGetter");
                }
                if (checkGetWithoutSet && hasGetter && !hasSetter) {
                    report(node, "missingSetter");
                }
            }
            /**
             * Checks the given object expression as an object literal and as a possible property descriptor.
             * @param {ASTNode} node `ObjectExpression` node to check.
             * @returns {void}
             * @private
             */
            function checkObjectExpression(node) {
                checkObjectLiteral(node);
                if (isPropertyDescriptor(node)) {
                    checkPropertyDescriptor(node);
                }
            }
            /**
             * Checks the given class body.
             * @param {ASTNode} node `ClassBody` node to check.
             * @returns {void}
             * @private
             */
            function checkClassBody(node) {
                const methodDefinitions = node.body.filter(m => m.type === "MethodDefinition");
                checkList(methodDefinitions.filter(m => m.static));
                checkList(methodDefinitions.filter(m => !m.static));
            }
            const listeners = {};
            if (checkSetWithoutGet || checkGetWithoutSet) {
                listeners.ObjectExpression = checkObjectExpression;
                if (enforceForClassMembers) {
                    listeners.ClassBody = checkClassBody;
                }
            }
            return listeners;
        }
    };
},
/* eslint/lib/rules/utils/ast-utils.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Common utils for AST.
     * @author Gyandeep Singh
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const esutils = require(361) /* esutils */;
    const espree = require(305) /* espree */;
    const escapeRegExp = require(285) /* escape-string-regexp */;
    const { breakableTypePattern, createGlobalLinebreakMatcher, lineBreakPattern, shebangPattern } = require(309) /* ../../shared/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const anyFunctionPattern = /^(?:Function(?:Declaration|Expression)|ArrowFunctionExpression)$/u;
    const anyLoopPattern = /^(?:DoWhile|For|ForIn|ForOf|While)Statement$/u;
    const arrayOrTypedArrayPattern = /Array$/u;
    const arrayMethodPattern = /^(?:every|filter|find|findIndex|forEach|map|some)$/u;
    const bindOrCallOrApplyPattern = /^(?:bind|call|apply)$/u;
    const thisTagPattern = /^[\s*]*@this/mu;
    const COMMENTS_IGNORE_PATTERN = /^\s*(?:eslint|jshint\s+|jslint\s+|istanbul\s+|globals?\s+|exported\s+|jscs)/u;
    const ESLINT_DIRECTIVE_PATTERN = /^(?:eslint[- ]|(?:globals?|exported) )/u;
    const LINEBREAKS = new Set(["\r\n", "\r", "\n", "\u2028", "\u2029"]);
    // A set of node types that can contain a list of statements
    const STATEMENT_LIST_PARENTS = new Set(["Program", "BlockStatement", "StaticBlock", "SwitchCase"]);
    const DECIMAL_INTEGER_PATTERN = /^(?:0|0[0-7]*[89]\d*|[1-9](?:_?\d)*)$/u;
    // Tests the presence of at least one LegacyOctalEscapeSequence or NonOctalDecimalEscapeSequence in a raw string
    const OCTAL_OR_NON_OCTAL_DECIMAL_ESCAPE_PATTERN = /^(?:[^\\]|\\.)*\\(?:[1-9]|0[0-9])/su;
    const LOGICAL_ASSIGNMENT_OPERATORS = new Set(["&&=", "||=", "??="]);
    /**
     * Checks reference if is non initializer and writable.
     * @param {Reference} reference A reference to check.
     * @param {int} index The index of the reference in the references.
     * @param {Reference[]} references The array that the reference belongs to.
     * @returns {boolean} Success/Failure
     * @private
     */
    function isModifyingReference(reference, index, references) {
        const identifier = reference.identifier;
        /*
         * Destructuring assignments can have multiple default value, so
         * possibly there are multiple writeable references for the same
         * identifier.
         */
        const modifyingDifferentIdentifier = index === 0 ||
            references[index - 1].identifier !== identifier;
        return (identifier &&
            reference.init === false &&
            reference.isWrite() &&
            modifyingDifferentIdentifier);
    }
    /**
     * Checks whether the given string starts with uppercase or not.
     * @param {string} s The string to check.
     * @returns {boolean} `true` if the string starts with uppercase.
     */
    function startsWithUpperCase(s) {
        return s[0] !== s[0].toLocaleLowerCase();
    }
    /**
     * Checks whether or not a node is a constructor.
     * @param {ASTNode} node A function node to check.
     * @returns {boolean} Whether or not a node is a constructor.
     */
    function isES5Constructor(node) {
        return (node.id && startsWithUpperCase(node.id.name));
    }
    /**
     * Finds a function node from ancestors of a node.
     * @param {ASTNode} node A start node to find.
     * @returns {Node|null} A found function node.
     */
    function getUpperFunction(node) {
        for (let currentNode = node; currentNode; currentNode = currentNode.parent) {
            if (anyFunctionPattern.test(currentNode.type)) {
                return currentNode;
            }
        }
        return null;
    }
    /**
     * Checks whether a given node is a function node or not.
     * The following types are function nodes:
     *
     * - ArrowFunctionExpression
     * - FunctionDeclaration
     * - FunctionExpression
     * @param {ASTNode|null} node A node to check.
     * @returns {boolean} `true` if the node is a function node.
     */
    function isFunction(node) {
        return Boolean(node && anyFunctionPattern.test(node.type));
    }
    /**
     * Checks whether a given node is a loop node or not.
     * The following types are loop nodes:
     *
     * - DoWhileStatement
     * - ForInStatement
     * - ForOfStatement
     * - ForStatement
     * - WhileStatement
     * @param {ASTNode|null} node A node to check.
     * @returns {boolean} `true` if the node is a loop node.
     */
    function isLoop(node) {
        return Boolean(node && anyLoopPattern.test(node.type));
    }
    /**
     * Checks whether the given node is in a loop or not.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is in a loop.
     */
    function isInLoop(node) {
        for (let currentNode = node; currentNode && !isFunction(currentNode); currentNode = currentNode.parent) {
            if (isLoop(currentNode)) {
                return true;
            }
        }
        return false;
    }
    /**
     * Determines whether the given node is a `null` literal.
     * @param {ASTNode} node The node to check
     * @returns {boolean} `true` if the node is a `null` literal
     */
    function isNullLiteral(node) {
        /*
         * Checking `node.value === null` does not guarantee that a literal is a null literal.
         * When parsing values that cannot be represented in the current environment (e.g. unicode
         * regexes in Node 4), `node.value` is set to `null` because it wouldn't be possible to
         * set `node.value` to a unicode regex. To make sure a literal is actually `null`, check
         * `node.regex` instead. Also see: https://github.com/eslint/eslint/issues/8020
         */
        return node.type === "Literal" && node.value === null && !node.regex && !node.bigint;
    }
    /**
     * Checks whether or not a node is `null` or `undefined`.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} Whether or not the node is a `null` or `undefined`.
     * @public
     */
    function isNullOrUndefined(node) {
        return (isNullLiteral(node) ||
            (node.type === "Identifier" && node.name === "undefined") ||
            (node.type === "UnaryExpression" && node.operator === "void"));
    }
    /**
     * Checks whether or not a node is callee.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} Whether or not the node is callee.
     */
    function isCallee(node) {
        return node.parent.type === "CallExpression" && node.parent.callee === node;
    }
    /**
     * Returns the result of the string conversion applied to the evaluated value of the given expression node,
     * if it can be determined statically.
     *
     * This function returns a `string` value for all `Literal` nodes and simple `TemplateLiteral` nodes only.
     * In all other cases, this function returns `null`.
     * @param {ASTNode} node Expression node.
     * @returns {string|null} String value if it can be determined. Otherwise, `null`.
     */
    function getStaticStringValue(node) {
        switch (node.type) {
            case "Literal":
                if (node.value === null) {
                    if (isNullLiteral(node)) {
                        return String(node.value); // "null"
                    }
                    if (node.regex) {
                        return `/${node.regex.pattern}/${node.regex.flags}`;
                    }
                    if (node.bigint) {
                        return node.bigint;
                    }
                    // Otherwise, this is an unknown literal. The function will return null.
                }
                else {
                    return String(node.value);
                }
                break;
            case "TemplateLiteral":
                if (node.expressions.length === 0 && node.quasis.length === 1) {
                    return node.quasis[0].value.cooked;
                }
                break;
            // no default
        }
        return null;
    }
    /**
     * Gets the property name of a given node.
     * The node can be a MemberExpression, a Property, or a MethodDefinition.
     *
     * If the name is dynamic, this returns `null`.
     *
     * For examples:
     *
     *     a.b           // => "b"
     *     a["b"]        // => "b"
     *     a['b']        // => "b"
     *     a[`b`]        // => "b"
     *     a[100]        // => "100"
     *     a[b]          // => null
     *     a["a" + "b"]  // => null
     *     a[tag`b`]     // => null
     *     a[`${b}`]     // => null
     *
     *     let a = {b: 1}            // => "b"
     *     let a = {["b"]: 1}        // => "b"
     *     let a = {['b']: 1}        // => "b"
     *     let a = {[`b`]: 1}        // => "b"
     *     let a = {[100]: 1}        // => "100"
     *     let a = {[b]: 1}          // => null
     *     let a = {["a" + "b"]: 1}  // => null
     *     let a = {[tag`b`]: 1}     // => null
     *     let a = {[`${b}`]: 1}     // => null
     * @param {ASTNode} node The node to get.
     * @returns {string|null} The property name if static. Otherwise, null.
     */
    function getStaticPropertyName(node) {
        let prop;
        switch (node && node.type) {
            case "ChainExpression":
                return getStaticPropertyName(node.expression);
            case "Property":
            case "PropertyDefinition":
            case "MethodDefinition":
                prop = node.key;
                break;
            case "MemberExpression":
                prop = node.property;
                break;
            // no default
        }
        if (prop) {
            if (prop.type === "Identifier" && !node.computed) {
                return prop.name;
            }
            return getStaticStringValue(prop);
        }
        return null;
    }
    /**
     * Retrieve `ChainExpression#expression` value if the given node a `ChainExpression` node. Otherwise, pass through it.
     * @param {ASTNode} node The node to address.
     * @returns {ASTNode} The `ChainExpression#expression` value if the node is a `ChainExpression` node. Otherwise, the node.
     */
    function skipChainExpression(node) {
        return node && node.type === "ChainExpression" ? node.expression : node;
    }
    /**
     * Check if the `actual` is an expected value.
     * @param {string} actual The string value to check.
     * @param {string | RegExp} expected The expected string value or pattern.
     * @returns {boolean} `true` if the `actual` is an expected value.
     */
    function checkText(actual, expected) {
        return typeof expected === "string"
            ? actual === expected
            : expected.test(actual);
    }
    /**
     * Check if a given node is an Identifier node with a given name.
     * @param {ASTNode} node The node to check.
     * @param {string | RegExp} name The expected name or the expected pattern of the object name.
     * @returns {boolean} `true` if the node is an Identifier node with the name.
     */
    function isSpecificId(node, name) {
        return node.type === "Identifier" && checkText(node.name, name);
    }
    /**
     * Check if a given node is member access with a given object name and property name pair.
     * This is regardless of optional or not.
     * @param {ASTNode} node The node to check.
     * @param {string | RegExp | null} objectName The expected name or the expected pattern of the object name. If this is nullish, this method doesn't check object.
     * @param {string | RegExp | null} propertyName The expected name or the expected pattern of the property name. If this is nullish, this method doesn't check property.
     * @returns {boolean} `true` if the node is member access with the object name and property name pair.
     * The node is a `MemberExpression` or `ChainExpression`.
     */
    function isSpecificMemberAccess(node, objectName, propertyName) {
        const checkNode = skipChainExpression(node);
        if (checkNode.type !== "MemberExpression") {
            return false;
        }
        if (objectName && !isSpecificId(checkNode.object, objectName)) {
            return false;
        }
        if (propertyName) {
            const actualPropertyName = getStaticPropertyName(checkNode);
            if (typeof actualPropertyName !== "string" || !checkText(actualPropertyName, propertyName)) {
                return false;
            }
        }
        return true;
    }
    /**
     * Check if two literal nodes are the same value.
     * @param {ASTNode} left The Literal node to compare.
     * @param {ASTNode} right The other Literal node to compare.
     * @returns {boolean} `true` if the two literal nodes are the same value.
     */
    function equalLiteralValue(left, right) {
        // RegExp literal.
        if (left.regex || right.regex) {
            return Boolean(left.regex &&
                right.regex &&
                left.regex.pattern === right.regex.pattern &&
                left.regex.flags === right.regex.flags);
        }
        // BigInt literal.
        if (left.bigint || right.bigint) {
            return left.bigint === right.bigint;
        }
        return left.value === right.value;
    }
    /**
     * Check if two expressions reference the same value. For example:
     *     a = a
     *     a.b = a.b
     *     a[0] = a[0]
     *     a['b'] = a['b']
     * @param {ASTNode} left The left side of the comparison.
     * @param {ASTNode} right The right side of the comparison.
     * @param {boolean} [disableStaticComputedKey] Don't address `a.b` and `a["b"]` are the same if `true`. For backward compatibility.
     * @returns {boolean} `true` if both sides match and reference the same value.
     */
    function isSameReference(left, right, disableStaticComputedKey = false) {
        if (left.type !== right.type) {
            // Handle `a.b` and `a?.b` are samely.
            if (left.type === "ChainExpression") {
                return isSameReference(left.expression, right, disableStaticComputedKey);
            }
            if (right.type === "ChainExpression") {
                return isSameReference(left, right.expression, disableStaticComputedKey);
            }
            return false;
        }
        switch (left.type) {
            case "Super":
            case "ThisExpression":
                return true;
            case "Identifier":
            case "PrivateIdentifier":
                return left.name === right.name;
            case "Literal":
                return equalLiteralValue(left, right);
            case "ChainExpression":
                return isSameReference(left.expression, right.expression, disableStaticComputedKey);
            case "MemberExpression": {
                if (!disableStaticComputedKey) {
                    const nameA = getStaticPropertyName(left);
                    // x.y = x["y"]
                    if (nameA !== null) {
                        return (isSameReference(left.object, right.object, disableStaticComputedKey) &&
                            nameA === getStaticPropertyName(right));
                    }
                }
                /*
                 * x[0] = x[0]
                 * x[y] = x[y]
                 * x.y = x.y
                 */
                return (left.computed === right.computed &&
                    isSameReference(left.object, right.object, disableStaticComputedKey) &&
                    isSameReference(left.property, right.property, disableStaticComputedKey));
            }
            default:
                return false;
        }
    }
    /**
     * Checks whether or not a node is `Reflect.apply`.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} Whether or not the node is a `Reflect.apply`.
     */
    function isReflectApply(node) {
        return isSpecificMemberAccess(node, "Reflect", "apply");
    }
    /**
     * Checks whether or not a node is `Array.from`.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} Whether or not the node is a `Array.from`.
     */
    function isArrayFromMethod(node) {
        return isSpecificMemberAccess(node, arrayOrTypedArrayPattern, "from");
    }
    /**
     * Checks whether or not a node is a method which has `thisArg`.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} Whether or not the node is a method which has `thisArg`.
     */
    function isMethodWhichHasThisArg(node) {
        return isSpecificMemberAccess(node, null, arrayMethodPattern);
    }
    /**
     * Creates the negate function of the given function.
     * @param {Function} f The function to negate.
     * @returns {Function} Negated function.
     */
    function negate(f) {
        return token => !f(token);
    }
    /**
     * Checks whether or not a node has a `@this` tag in its comments.
     * @param {ASTNode} node A node to check.
     * @param {SourceCode} sourceCode A SourceCode instance to get comments.
     * @returns {boolean} Whether or not the node has a `@this` tag in its comments.
     */
    function hasJSDocThisTag(node, sourceCode) {
        const jsdocComment = sourceCode.getJSDocComment(node);
        if (jsdocComment && thisTagPattern.test(jsdocComment.value)) {
            return true;
        }
        // Checks `@this` in its leading comments for callbacks,
        // because callbacks don't have its JSDoc comment.
        // e.g.
        //     sinon.test(/* @this sinon.Sandbox */function() { this.spy(); });
        return sourceCode.getCommentsBefore(node).some(comment => thisTagPattern.test(comment.value));
    }
    /**
     * Determines if a node is surrounded by parentheses.
     * @param {SourceCode} sourceCode The ESLint source code object
     * @param {ASTNode} node The node to be checked.
     * @returns {boolean} True if the node is parenthesised.
     * @private
     */
    function isParenthesised(sourceCode, node) {
        const previousToken = sourceCode.getTokenBefore(node), nextToken = sourceCode.getTokenAfter(node);
        return Boolean(previousToken && nextToken) &&
            previousToken.value === "(" && previousToken.range[1] <= node.range[0] &&
            nextToken.value === ")" && nextToken.range[0] >= node.range[1];
    }
    /**
     * Checks if the given token is a `=` token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a `=` token.
     */
    function isEqToken(token) {
        return token.value === "=" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is an arrow token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is an arrow token.
     */
    function isArrowToken(token) {
        return token.value === "=>" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is a comma token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a comma token.
     */
    function isCommaToken(token) {
        return token.value === "," && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is a dot token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a dot token.
     */
    function isDotToken(token) {
        return token.value === "." && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is a `?.` token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a `?.` token.
     */
    function isQuestionDotToken(token) {
        return token.value === "?." && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is a semicolon token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a semicolon token.
     */
    function isSemicolonToken(token) {
        return token.value === ";" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is a colon token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a colon token.
     */
    function isColonToken(token) {
        return token.value === ":" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is an opening parenthesis token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is an opening parenthesis token.
     */
    function isOpeningParenToken(token) {
        return token.value === "(" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is a closing parenthesis token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a closing parenthesis token.
     */
    function isClosingParenToken(token) {
        return token.value === ")" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is an opening square bracket token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is an opening square bracket token.
     */
    function isOpeningBracketToken(token) {
        return token.value === "[" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is a closing square bracket token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a closing square bracket token.
     */
    function isClosingBracketToken(token) {
        return token.value === "]" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is an opening brace token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is an opening brace token.
     */
    function isOpeningBraceToken(token) {
        return token.value === "{" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is a closing brace token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a closing brace token.
     */
    function isClosingBraceToken(token) {
        return token.value === "}" && token.type === "Punctuator";
    }
    /**
     * Checks if the given token is a comment token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a comment token.
     */
    function isCommentToken(token) {
        return token.type === "Line" || token.type === "Block" || token.type === "Shebang";
    }
    /**
     * Checks if the given token is a keyword token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a keyword token.
     */
    function isKeywordToken(token) {
        return token.type === "Keyword";
    }
    /**
     * Gets the `(` token of the given function node.
     * @param {ASTNode} node The function node to get.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {Token} `(` token.
     */
    function getOpeningParenOfParams(node, sourceCode) {
        // If the node is an arrow function and doesn't have parens, this returns the identifier of the first param.
        if (node.type === "ArrowFunctionExpression" && node.params.length === 1) {
            const argToken = sourceCode.getFirstToken(node.params[0]);
            const maybeParenToken = sourceCode.getTokenBefore(argToken);
            return isOpeningParenToken(maybeParenToken) ? maybeParenToken : argToken;
        }
        // Otherwise, returns paren.
        return node.id
            ? sourceCode.getTokenAfter(node.id, isOpeningParenToken)
            : sourceCode.getFirstToken(node, isOpeningParenToken);
    }
    /**
     * Checks whether or not the tokens of two given nodes are same.
     * @param {ASTNode} left A node 1 to compare.
     * @param {ASTNode} right A node 2 to compare.
     * @param {SourceCode} sourceCode The ESLint source code object.
     * @returns {boolean} the source code for the given node.
     */
    function equalTokens(left, right, sourceCode) {
        const tokensL = sourceCode.getTokens(left);
        const tokensR = sourceCode.getTokens(right);
        if (tokensL.length !== tokensR.length) {
            return false;
        }
        for (let i = 0; i < tokensL.length; ++i) {
            if (tokensL[i].type !== tokensR[i].type ||
                tokensL[i].value !== tokensR[i].value) {
                return false;
            }
        }
        return true;
    }
    /**
     * Check if the given node is a true logical expression or not.
     *
     * The three binary expressions logical-or (`||`), logical-and (`&&`), and
     * coalesce (`??`) are known as `ShortCircuitExpression`.
     * But ESTree represents those by `LogicalExpression` node.
     *
     * This function rejects coalesce expressions of `LogicalExpression` node.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is `&&` or `||`.
     * @see https://tc39.es/ecma262/#prod-ShortCircuitExpression
     */
    function isLogicalExpression(node) {
        return (node.type === "LogicalExpression" &&
            (node.operator === "&&" || node.operator === "||"));
    }
    /**
     * Check if the given node is a nullish coalescing expression or not.
     *
     * The three binary expressions logical-or (`||`), logical-and (`&&`), and
     * coalesce (`??`) are known as `ShortCircuitExpression`.
     * But ESTree represents those by `LogicalExpression` node.
     *
     * This function finds only coalesce expressions of `LogicalExpression` node.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is `??`.
     */
    function isCoalesceExpression(node) {
        return node.type === "LogicalExpression" && node.operator === "??";
    }
    /**
     * Check if given two nodes are the pair of a logical expression and a coalesce expression.
     * @param {ASTNode} left A node to check.
     * @param {ASTNode} right Another node to check.
     * @returns {boolean} `true` if the two nodes are the pair of a logical expression and a coalesce expression.
     */
    function isMixedLogicalAndCoalesceExpressions(left, right) {
        return ((isLogicalExpression(left) && isCoalesceExpression(right)) ||
            (isCoalesceExpression(left) && isLogicalExpression(right)));
    }
    /**
     * Checks if the given operator is a logical assignment operator.
     * @param {string} operator The operator to check.
     * @returns {boolean} `true` if the operator is a logical assignment operator.
     */
    function isLogicalAssignmentOperator(operator) {
        return LOGICAL_ASSIGNMENT_OPERATORS.has(operator);
    }
    /**
     * Get the colon token of the given SwitchCase node.
     * @param {ASTNode} node The SwitchCase node to get.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {Token} The colon token of the node.
     */
    function getSwitchCaseColonToken(node, sourceCode) {
        if (node.test) {
            return sourceCode.getTokenAfter(node.test, isColonToken);
        }
        return sourceCode.getFirstToken(node, 1);
    }
    /**
     * Gets ESM module export name represented by the given node.
     * @param {ASTNode} node `Identifier` or string `Literal` node in a position
     * that represents a module export name:
     *   - `ImportSpecifier#imported`
     *   - `ExportSpecifier#local` (if it is a re-export from another module)
     *   - `ExportSpecifier#exported`
     *   - `ExportAllDeclaration#exported`
     * @returns {string} The module export name.
     */
    function getModuleExportName(node) {
        if (node.type === "Identifier") {
            return node.name;
        }
        // string literal
        return node.value;
    }
    /**
     * Returns literal's value converted to the Boolean type
     * @param {ASTNode} node any `Literal` node
     * @returns {boolean | null} `true` when node is truthy, `false` when node is falsy,
     *  `null` when it cannot be determined.
     */
    function getBooleanValue(node) {
        if (node.value === null) {
            /*
             * it might be a null literal or bigint/regex literal in unsupported environments .
             * https://github.com/estree/estree/blob/14df8a024956ea289bd55b9c2226a1d5b8a473ee/es5.md#regexpliteral
             * https://github.com/estree/estree/blob/14df8a024956ea289bd55b9c2226a1d5b8a473ee/es2020.md#bigintliteral
             */
            if (node.raw === "null") {
                return false;
            }
            // regex is always truthy
            if (typeof node.regex === "object") {
                return true;
            }
            return null;
        }
        return !!node.value;
    }
    /**
     * Checks if a branch node of LogicalExpression short circuits the whole condition
     * @param {ASTNode} node The branch of main condition which needs to be checked
     * @param {string} operator The operator of the main LogicalExpression.
     * @returns {boolean} true when condition short circuits whole condition
     */
    function isLogicalIdentity(node, operator) {
        switch (node.type) {
            case "Literal":
                return (operator === "||" && getBooleanValue(node) === true) ||
                    (operator === "&&" && getBooleanValue(node) === false);
            case "UnaryExpression":
                return (operator === "&&" && node.operator === "void");
            case "LogicalExpression":
                /*
                 * handles `a && false || b`
                 * `false` is an identity element of `&&` but not `||`
                 */
                return operator === node.operator &&
                    (isLogicalIdentity(node.left, operator) ||
                        isLogicalIdentity(node.right, operator));
            case "AssignmentExpression":
                return ["||=", "&&="].includes(node.operator) &&
                    operator === node.operator.slice(0, -1) &&
                    isLogicalIdentity(node.right, operator);
            // no default
        }
        return false;
    }
    /**
     * Checks if an identifier is a reference to a global variable.
     * @param {Scope} scope The scope in which the identifier is referenced.
     * @param {ASTNode} node An identifier node to check.
     * @returns {boolean} `true` if the identifier is a reference to a global variable.
     */
    function isReferenceToGlobalVariable(scope, node) {
        const reference = scope.references.find(ref => ref.identifier === node);
        return Boolean(reference &&
            reference.resolved &&
            reference.resolved.scope.type === "global" &&
            reference.resolved.defs.length === 0);
    }
    /**
     * Checks if a  node has a constant truthiness value.
     * @param {Scope} scope Scope in which the node appears.
     * @param {ASTNode} node The AST node to check.
     * @param {boolean} inBooleanPosition `true` if checking the test of a
     * condition. `false` in all other cases. When `false`, checks if -- for
     * both string and number -- if coerced to that type, the value will
     * be constant.
     * @returns {boolean} true when node's truthiness is constant
     * @private
     */
    function isConstant(scope, node, inBooleanPosition) {
        // node.elements can return null values in the case of sparse arrays ex. [,]
        if (!node) {
            return true;
        }
        switch (node.type) {
            case "Literal":
            case "ArrowFunctionExpression":
            case "FunctionExpression":
                return true;
            case "ClassExpression":
            case "ObjectExpression":
                /**
                 * In theory objects like:
                 *
                 * `{toString: () => a}`
                 * `{valueOf: () => a}`
                 *
                 * Or a classes like:
                 *
                 * `class { static toString() { return a } }`
                 * `class { static valueOf() { return a } }`
                 *
                 * Are not constant verifiably when `inBooleanPosition` is
                 * false, but it's an edge case we've opted not to handle.
                 */
                return true;
            case "TemplateLiteral":
                return (inBooleanPosition && node.quasis.some(quasi => quasi.value.cooked.length)) ||
                    node.expressions.every(exp => isConstant(scope, exp, false));
            case "ArrayExpression": {
                if (!inBooleanPosition) {
                    return node.elements.every(element => isConstant(scope, element, false));
                }
                return true;
            }
            case "UnaryExpression":
                if (node.operator === "void" ||
                    node.operator === "typeof" && inBooleanPosition) {
                    return true;
                }
                if (node.operator === "!") {
                    return isConstant(scope, node.argument, true);
                }
                return isConstant(scope, node.argument, false);
            case "BinaryExpression":
                return isConstant(scope, node.left, false) &&
                    isConstant(scope, node.right, false) &&
                    node.operator !== "in";
            case "LogicalExpression": {
                const isLeftConstant = isConstant(scope, node.left, inBooleanPosition);
                const isRightConstant = isConstant(scope, node.right, inBooleanPosition);
                const isLeftShortCircuit = (isLeftConstant && isLogicalIdentity(node.left, node.operator));
                const isRightShortCircuit = (inBooleanPosition && isRightConstant && isLogicalIdentity(node.right, node.operator));
                return (isLeftConstant && isRightConstant) ||
                    isLeftShortCircuit ||
                    isRightShortCircuit;
            }
            case "NewExpression":
                return inBooleanPosition;
            case "AssignmentExpression":
                if (node.operator === "=") {
                    return isConstant(scope, node.right, inBooleanPosition);
                }
                if (["||=", "&&="].includes(node.operator) && inBooleanPosition) {
                    return isLogicalIdentity(node.right, node.operator.slice(0, -1));
                }
                return false;
            case "SequenceExpression":
                return isConstant(scope, node.expressions[node.expressions.length - 1], inBooleanPosition);
            case "SpreadElement":
                return isConstant(scope, node.argument, inBooleanPosition);
            case "CallExpression":
                if (node.callee.type === "Identifier" && node.callee.name === "Boolean") {
                    if (node.arguments.length === 0 || isConstant(scope, node.arguments[0], true)) {
                        return isReferenceToGlobalVariable(scope, node.callee);
                    }
                }
                return false;
            case "Identifier":
                return node.name === "undefined" && isReferenceToGlobalVariable(scope, node);
            // no default
        }
        return false;
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = {
        COMMENTS_IGNORE_PATTERN,
        LINEBREAKS,
        LINEBREAK_MATCHER: lineBreakPattern,
        SHEBANG_MATCHER: shebangPattern,
        STATEMENT_LIST_PARENTS,
        /**
         * Determines whether two adjacent tokens are on the same line.
         * @param {Object} left The left token object.
         * @param {Object} right The right token object.
         * @returns {boolean} Whether or not the tokens are on the same line.
         * @public
         */
        isTokenOnSameLine(left, right) {
            return left.loc.end.line === right.loc.start.line;
        },
        isNullOrUndefined,
        isCallee,
        isES5Constructor,
        getUpperFunction,
        isFunction,
        isLoop,
        isInLoop,
        isArrayFromMethod,
        isParenthesised,
        createGlobalLinebreakMatcher,
        equalTokens,
        isArrowToken,
        isClosingBraceToken,
        isClosingBracketToken,
        isClosingParenToken,
        isColonToken,
        isCommaToken,
        isCommentToken,
        isDotToken,
        isQuestionDotToken,
        isKeywordToken,
        isNotClosingBraceToken: negate(isClosingBraceToken),
        isNotClosingBracketToken: negate(isClosingBracketToken),
        isNotClosingParenToken: negate(isClosingParenToken),
        isNotColonToken: negate(isColonToken),
        isNotCommaToken: negate(isCommaToken),
        isNotDotToken: negate(isDotToken),
        isNotQuestionDotToken: negate(isQuestionDotToken),
        isNotOpeningBraceToken: negate(isOpeningBraceToken),
        isNotOpeningBracketToken: negate(isOpeningBracketToken),
        isNotOpeningParenToken: negate(isOpeningParenToken),
        isNotSemicolonToken: negate(isSemicolonToken),
        isOpeningBraceToken,
        isOpeningBracketToken,
        isOpeningParenToken,
        isSemicolonToken,
        isEqToken,
        /**
         * Checks whether or not a given node is a string literal.
         * @param {ASTNode} node A node to check.
         * @returns {boolean} `true` if the node is a string literal.
         */
        isStringLiteral(node) {
            return ((node.type === "Literal" && typeof node.value === "string") ||
                node.type === "TemplateLiteral");
        },
        /**
         * Checks whether a given node is a breakable statement or not.
         * The node is breakable if the node is one of the following type:
         *
         * - DoWhileStatement
         * - ForInStatement
         * - ForOfStatement
         * - ForStatement
         * - SwitchStatement
         * - WhileStatement
         * @param {ASTNode} node A node to check.
         * @returns {boolean} `true` if the node is breakable.
         */
        isBreakableStatement(node) {
            return breakableTypePattern.test(node.type);
        },
        /**
         * Gets references which are non initializer and writable.
         * @param {Reference[]} references An array of references.
         * @returns {Reference[]} An array of only references which are non initializer and writable.
         * @public
         */
        getModifyingReferences(references) {
            return references.filter(isModifyingReference);
        },
        /**
         * Validate that a string passed in is surrounded by the specified character
         * @param {string} val The text to check.
         * @param {string} character The character to see if it's surrounded by.
         * @returns {boolean} True if the text is surrounded by the character, false if not.
         * @private
         */
        isSurroundedBy(val, character) {
            return val[0] === character && val[val.length - 1] === character;
        },
        /**
         * Returns whether the provided node is an ESLint directive comment or not
         * @param {Line|Block} node The comment token to be checked
         * @returns {boolean} `true` if the node is an ESLint directive comment
         */
        isDirectiveComment(node) {
            const comment = node.value.trim();
            return (node.type === "Line" && comment.startsWith("eslint-") ||
                node.type === "Block" && ESLINT_DIRECTIVE_PATTERN.test(comment));
        },
        /**
         * Gets the trailing statement of a given node.
         *
         *     if (code)
         *         consequent;
         *
         * When taking this `IfStatement`, returns `consequent;` statement.
         * @param {ASTNode} A node to get.
         * @returns {ASTNode|null} The trailing statement's node.
         */
        getTrailingStatement: esutils.ast.trailingStatement,
        /**
         * Finds the variable by a given name in a given scope and its upper scopes.
         * @param {eslint-scope.Scope} initScope A scope to start find.
         * @param {string} name A variable name to find.
         * @returns {eslint-scope.Variable|null} A found variable or `null`.
         */
        getVariableByName(initScope, name) {
            let scope = initScope;
            while (scope) {
                const variable = scope.set.get(name);
                if (variable) {
                    return variable;
                }
                scope = scope.upper;
            }
            return null;
        },
        /**
         * Checks whether or not a given function node is the default `this` binding.
         *
         * First, this checks the node:
         *
         * - The given node is not in `PropertyDefinition#value` position.
         * - The given node is not `StaticBlock`.
         * - The function name does not start with uppercase. It's a convention to capitalize the names
         *   of constructor functions. This check is not performed if `capIsConstructor` is set to `false`.
         * - The function does not have a JSDoc comment that has a @this tag.
         *
         * Next, this checks the location of the node.
         * If the location is below, this judges `this` is valid.
         *
         * - The location is not on an object literal.
         * - The location is not assigned to a variable which starts with an uppercase letter. Applies to anonymous
         *   functions only, as the name of the variable is considered to be the name of the function in this case.
         *   This check is not performed if `capIsConstructor` is set to `false`.
         * - The location is not on an ES2015 class.
         * - Its `bind`/`call`/`apply` method is not called directly.
         * - The function is not a callback of array methods (such as `.forEach()`) if `thisArg` is given.
         * @param {ASTNode} node A function node to check. It also can be an implicit function, like `StaticBlock`
         * or any expression that is `PropertyDefinition#value` node.
         * @param {SourceCode} sourceCode A SourceCode instance to get comments.
         * @param {boolean} [capIsConstructor = true] `false` disables the assumption that functions which name starts
         * with an uppercase or are assigned to a variable which name starts with an uppercase are constructors.
         * @returns {boolean} The function node is the default `this` binding.
         */
        isDefaultThisBinding(node, sourceCode, { capIsConstructor = true } = {}) {
            /*
             * Class field initializers are implicit functions, but ESTree doesn't have the AST node of field initializers.
             * Therefore, A expression node at `PropertyDefinition#value` is a function.
             * In this case, `this` is always not default binding.
             */
            if (node.parent.type === "PropertyDefinition" && node.parent.value === node) {
                return false;
            }
            // Class static blocks are implicit functions. In this case, `this` is always not default binding.
            if (node.type === "StaticBlock") {
                return false;
            }
            if ((capIsConstructor && isES5Constructor(node)) ||
                hasJSDocThisTag(node, sourceCode)) {
                return false;
            }
            const isAnonymous = node.id === null;
            let currentNode = node;
            while (currentNode) {
                const parent = currentNode.parent;
                switch (parent.type) {
                    /*
                     * Looks up the destination.
                     * e.g., obj.foo = nativeFoo || function foo() { ... };
                     */
                    case "LogicalExpression":
                    case "ConditionalExpression":
                    case "ChainExpression":
                        currentNode = parent;
                        break;
                    /*
                     * If the upper function is IIFE, checks the destination of the return value.
                     * e.g.
                     *   obj.foo = (function() {
                     *     // setup...
                     *     return function foo() { ... };
                     *   })();
                     *   obj.foo = (() =>
                     *     function foo() { ... }
                     *   )();
                     */
                    case "ReturnStatement": {
                        const func = getUpperFunction(parent);
                        if (func === null || !isCallee(func)) {
                            return true;
                        }
                        currentNode = func.parent;
                        break;
                    }
                    case "ArrowFunctionExpression":
                        if (currentNode !== parent.body || !isCallee(parent)) {
                            return true;
                        }
                        currentNode = parent.parent;
                        break;
                    /*
                     * e.g.
                     *   var obj = { foo() { ... } };
                     *   var obj = { foo: function() { ... } };
                     *   class A { constructor() { ... } }
                     *   class A { foo() { ... } }
                     *   class A { get foo() { ... } }
                     *   class A { set foo() { ... } }
                     *   class A { static foo() { ... } }
                     *   class A { foo = function() { ... } }
                     */
                    case "Property":
                    case "PropertyDefinition":
                    case "MethodDefinition":
                        return parent.value !== currentNode;
                    /*
                     * e.g.
                     *   obj.foo = function foo() { ... };
                     *   Foo = function() { ... };
                     *   [obj.foo = function foo() { ... }] = a;
                     *   [Foo = function() { ... }] = a;
                     */
                    case "AssignmentExpression":
                    case "AssignmentPattern":
                        if (parent.left.type === "MemberExpression") {
                            return false;
                        }
                        if (capIsConstructor &&
                            isAnonymous &&
                            parent.left.type === "Identifier" &&
                            startsWithUpperCase(parent.left.name)) {
                            return false;
                        }
                        return true;
                    /*
                     * e.g.
                     *   var Foo = function() { ... };
                     */
                    case "VariableDeclarator":
                        return !(capIsConstructor &&
                            isAnonymous &&
                            parent.init === currentNode &&
                            parent.id.type === "Identifier" &&
                            startsWithUpperCase(parent.id.name));
                    /*
                     * e.g.
                     *   var foo = function foo() { ... }.bind(obj);
                     *   (function foo() { ... }).call(obj);
                     *   (function foo() { ... }).apply(obj, []);
                     */
                    case "MemberExpression":
                        if (parent.object === currentNode &&
                            isSpecificMemberAccess(parent, null, bindOrCallOrApplyPattern)) {
                            const maybeCalleeNode = parent.parent.type === "ChainExpression"
                                ? parent.parent
                                : parent;
                            return !(isCallee(maybeCalleeNode) &&
                                maybeCalleeNode.parent.arguments.length >= 1 &&
                                !isNullOrUndefined(maybeCalleeNode.parent.arguments[0]));
                        }
                        return true;
                    /*
                     * e.g.
                     *   Reflect.apply(function() {}, obj, []);
                     *   Array.from([], function() {}, obj);
                     *   list.forEach(function() {}, obj);
                     */
                    case "CallExpression":
                        if (isReflectApply(parent.callee)) {
                            return (parent.arguments.length !== 3 ||
                                parent.arguments[0] !== currentNode ||
                                isNullOrUndefined(parent.arguments[1]));
                        }
                        if (isArrayFromMethod(parent.callee)) {
                            return (parent.arguments.length !== 3 ||
                                parent.arguments[1] !== currentNode ||
                                isNullOrUndefined(parent.arguments[2]));
                        }
                        if (isMethodWhichHasThisArg(parent.callee)) {
                            return (parent.arguments.length !== 2 ||
                                parent.arguments[0] !== currentNode ||
                                isNullOrUndefined(parent.arguments[1]));
                        }
                        return true;
                    // Otherwise `this` is default.
                    default:
                        return true;
                }
            }
            /* c8 ignore next */
            return true;
        },
        /**
         * Get the precedence level based on the node type
         * @param {ASTNode} node node to evaluate
         * @returns {int} precedence level
         * @private
         */
        getPrecedence(node) {
            switch (node.type) {
                case "SequenceExpression":
                    return 0;
                case "AssignmentExpression":
                case "ArrowFunctionExpression":
                case "YieldExpression":
                    return 1;
                case "ConditionalExpression":
                    return 3;
                case "LogicalExpression":
                    switch (node.operator) {
                        case "||":
                        case "??":
                            return 4;
                        case "&&":
                            return 5;
                        // no default
                    }
                /* falls through */
                case "BinaryExpression":
                    switch (node.operator) {
                        case "|":
                            return 6;
                        case "^":
                            return 7;
                        case "&":
                            return 8;
                        case "==":
                        case "!=":
                        case "===":
                        case "!==":
                            return 9;
                        case "<":
                        case "<=":
                        case ">":
                        case ">=":
                        case "in":
                        case "instanceof":
                            return 10;
                        case "<<":
                        case ">>":
                        case ">>>":
                            return 11;
                        case "+":
                        case "-":
                            return 12;
                        case "*":
                        case "/":
                        case "%":
                            return 13;
                        case "**":
                            return 15;
                        // no default
                    }
                /* falls through */
                case "UnaryExpression":
                case "AwaitExpression":
                    return 16;
                case "UpdateExpression":
                    return 17;
                case "CallExpression":
                case "ChainExpression":
                case "ImportExpression":
                    return 18;
                case "NewExpression":
                    return 19;
                default:
                    return 20;
            }
        },
        /**
         * Checks whether the given node is an empty block node or not.
         * @param {ASTNode|null} node The node to check.
         * @returns {boolean} `true` if the node is an empty block.
         */
        isEmptyBlock(node) {
            return Boolean(node && node.type === "BlockStatement" && node.body.length === 0);
        },
        /**
         * Checks whether the given node is an empty function node or not.
         * @param {ASTNode|null} node The node to check.
         * @returns {boolean} `true` if the node is an empty function.
         */
        isEmptyFunction(node) {
            return isFunction(node) && module.exports.isEmptyBlock(node.body);
        },
        /**
         * Get directives from directive prologue of a Program or Function node.
         * @param {ASTNode} node The node to check.
         * @returns {ASTNode[]} The directives found in the directive prologue.
         */
        getDirectivePrologue(node) {
            const directives = [];
            // Directive prologues only occur at the top of files or functions.
            if (node.type === "Program" ||
                node.type === "FunctionDeclaration" ||
                node.type === "FunctionExpression" ||
                /*
                 * Do not check arrow functions with implicit return.
                 * `() => "use strict";` returns the string `"use strict"`.
                 */
                (node.type === "ArrowFunctionExpression" && node.body.type === "BlockStatement")) {
                const statements = node.type === "Program" ? node.body : node.body.body;
                for (const statement of statements) {
                    if (statement.type === "ExpressionStatement" &&
                        statement.expression.type === "Literal") {
                        directives.push(statement);
                    }
                    else {
                        break;
                    }
                }
            }
            return directives;
        },
        /**
         * Determines whether this node is a decimal integer literal. If a node is a decimal integer literal, a dot added
         * after the node will be parsed as a decimal point, rather than a property-access dot.
         * @param {ASTNode} node The node to check.
         * @returns {boolean} `true` if this node is a decimal integer.
         * @example
         *
         * 0         // true
         * 5         // true
         * 50        // true
         * 5_000     // true
         * 1_234_56  // true
         * 08        // true
         * 0192      // true
         * 5.        // false
         * .5        // false
         * 5.0       // false
         * 5.00_00   // false
         * 05        // false
         * 0x5       // false
         * 0b101     // false
         * 0b11_01   // false
         * 0o5       // false
         * 5e0       // false
         * 5e1_000   // false
         * 5n        // false
         * 1_000n    // false
         * "5"       // false
         *
         */
        isDecimalInteger(node) {
            return node.type === "Literal" && typeof node.value === "number" &&
                DECIMAL_INTEGER_PATTERN.test(node.raw);
        },
        /**
         * Determines whether this token is a decimal integer numeric token.
         * This is similar to isDecimalInteger(), but for tokens.
         * @param {Token} token The token to check.
         * @returns {boolean} `true` if this token is a decimal integer.
         */
        isDecimalIntegerNumericToken(token) {
            return token.type === "Numeric" && DECIMAL_INTEGER_PATTERN.test(token.value);
        },
        /**
         * Gets the name and kind of the given function node.
         *
         * - `function foo() {}`  .................... `function 'foo'`
         * - `(function foo() {})`  .................. `function 'foo'`
         * - `(function() {})`  ...................... `function`
         * - `function* foo() {}`  ................... `generator function 'foo'`
         * - `(function* foo() {})`  ................. `generator function 'foo'`
         * - `(function*() {})`  ..................... `generator function`
         * - `() => {}`  ............................. `arrow function`
         * - `async () => {}`  ....................... `async arrow function`
         * - `({ foo: function foo() {} })`  ......... `method 'foo'`
         * - `({ foo: function() {} })`  ............. `method 'foo'`
         * - `({ ['foo']: function() {} })`  ......... `method 'foo'`
         * - `({ [foo]: function() {} })`  ........... `method`
         * - `({ foo() {} })`  ....................... `method 'foo'`
         * - `({ foo: function* foo() {} })`  ........ `generator method 'foo'`
         * - `({ foo: function*() {} })`  ............ `generator method 'foo'`
         * - `({ ['foo']: function*() {} })`  ........ `generator method 'foo'`
         * - `({ [foo]: function*() {} })`  .......... `generator method`
         * - `({ *foo() {} })`  ...................... `generator method 'foo'`
         * - `({ foo: async function foo() {} })`  ... `async method 'foo'`
         * - `({ foo: async function() {} })`  ....... `async method 'foo'`
         * - `({ ['foo']: async function() {} })`  ... `async method 'foo'`
         * - `({ [foo]: async function() {} })`  ..... `async method`
         * - `({ async foo() {} })`  ................. `async method 'foo'`
         * - `({ get foo() {} })`  ................... `getter 'foo'`
         * - `({ set foo(a) {} })`  .................. `setter 'foo'`
         * - `class A { constructor() {} }`  ......... `constructor`
         * - `class A { foo() {} }`  ................. `method 'foo'`
         * - `class A { *foo() {} }`  ................ `generator method 'foo'`
         * - `class A { async foo() {} }`  ........... `async method 'foo'`
         * - `class A { ['foo']() {} }`  ............. `method 'foo'`
         * - `class A { *['foo']() {} }`  ............ `generator method 'foo'`
         * - `class A { async ['foo']() {} }`  ....... `async method 'foo'`
         * - `class A { [foo]() {} }`  ............... `method`
         * - `class A { *[foo]() {} }`  .............. `generator method`
         * - `class A { async [foo]() {} }`  ......... `async method`
         * - `class A { get foo() {} }`  ............. `getter 'foo'`
         * - `class A { set foo(a) {} }`  ............ `setter 'foo'`
         * - `class A { static foo() {} }`  .......... `static method 'foo'`
         * - `class A { static *foo() {} }`  ......... `static generator method 'foo'`
         * - `class A { static async foo() {} }`  .... `static async method 'foo'`
         * - `class A { static get foo() {} }`  ...... `static getter 'foo'`
         * - `class A { static set foo(a) {} }`  ..... `static setter 'foo'`
         * - `class A { foo = () => {}; }`  .......... `method 'foo'`
         * - `class A { foo = function() {}; }`  ..... `method 'foo'`
         * - `class A { foo = function bar() {}; }`  . `method 'foo'`
         * - `class A { static foo = () => {}; }`  ... `static method 'foo'`
         * - `class A { '#foo' = () => {}; }`  ....... `method '#foo'`
         * - `class A { #foo = () => {}; }`  ......... `private method #foo`
         * - `class A { static #foo = () => {}; }`  .. `static private method #foo`
         * - `class A { '#foo'() {} }`  .............. `method '#foo'`
         * - `class A { #foo() {} }`  ................ `private method #foo`
         * - `class A { static #foo() {} }`  ......... `static private method #foo`
         * @param {ASTNode} node The function node to get.
         * @returns {string} The name and kind of the function node.
         */
        getFunctionNameWithKind(node) {
            const parent = node.parent;
            const tokens = [];
            if (parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
                // The proposal uses `static` word consistently before visibility words: https://github.com/tc39/proposal-static-class-features
                if (parent.static) {
                    tokens.push("static");
                }
                if (!parent.computed && parent.key.type === "PrivateIdentifier") {
                    tokens.push("private");
                }
            }
            if (node.async) {
                tokens.push("async");
            }
            if (node.generator) {
                tokens.push("generator");
            }
            if (parent.type === "Property" || parent.type === "MethodDefinition") {
                if (parent.kind === "constructor") {
                    return "constructor";
                }
                if (parent.kind === "get") {
                    tokens.push("getter");
                }
                else if (parent.kind === "set") {
                    tokens.push("setter");
                }
                else {
                    tokens.push("method");
                }
            }
            else if (parent.type === "PropertyDefinition") {
                tokens.push("method");
            }
            else {
                if (node.type === "ArrowFunctionExpression") {
                    tokens.push("arrow");
                }
                tokens.push("function");
            }
            if (parent.type === "Property" || parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
                if (!parent.computed && parent.key.type === "PrivateIdentifier") {
                    tokens.push(`#${parent.key.name}`);
                }
                else {
                    const name = getStaticPropertyName(parent);
                    if (name !== null) {
                        tokens.push(`'${name}'`);
                    }
                    else if (node.id) {
                        tokens.push(`'${node.id.name}'`);
                    }
                }
            }
            else if (node.id) {
                tokens.push(`'${node.id.name}'`);
            }
            return tokens.join(" ");
        },
        /**
         * Gets the location of the given function node for reporting.
         *
         * - `function foo() {}`
         *    ^^^^^^^^^^^^
         * - `(function foo() {})`
         *     ^^^^^^^^^^^^
         * - `(function() {})`
         *     ^^^^^^^^
         * - `function* foo() {}`
         *    ^^^^^^^^^^^^^
         * - `(function* foo() {})`
         *     ^^^^^^^^^^^^^
         * - `(function*() {})`
         *     ^^^^^^^^^
         * - `() => {}`
         *       ^^
         * - `async () => {}`
         *             ^^
         * - `({ foo: function foo() {} })`
         *       ^^^^^^^^^^^^^^^^^
         * - `({ foo: function() {} })`
         *       ^^^^^^^^^^^^^
         * - `({ ['foo']: function() {} })`
         *       ^^^^^^^^^^^^^^^^^
         * - `({ [foo]: function() {} })`
         *       ^^^^^^^^^^^^^^^
         * - `({ foo() {} })`
         *       ^^^
         * - `({ foo: function* foo() {} })`
         *       ^^^^^^^^^^^^^^^^^^
         * - `({ foo: function*() {} })`
         *       ^^^^^^^^^^^^^^
         * - `({ ['foo']: function*() {} })`
         *       ^^^^^^^^^^^^^^^^^^
         * - `({ [foo]: function*() {} })`
         *       ^^^^^^^^^^^^^^^^
         * - `({ *foo() {} })`
         *       ^^^^
         * - `({ foo: async function foo() {} })`
         *       ^^^^^^^^^^^^^^^^^^^^^^^
         * - `({ foo: async function() {} })`
         *       ^^^^^^^^^^^^^^^^^^^
         * - `({ ['foo']: async function() {} })`
         *       ^^^^^^^^^^^^^^^^^^^^^^^
         * - `({ [foo]: async function() {} })`
         *       ^^^^^^^^^^^^^^^^^^^^^
         * - `({ async foo() {} })`
         *       ^^^^^^^^^
         * - `({ get foo() {} })`
         *       ^^^^^^^
         * - `({ set foo(a) {} })`
         *       ^^^^^^^
         * - `class A { constructor() {} }`
         *              ^^^^^^^^^^^
         * - `class A { foo() {} }`
         *              ^^^
         * - `class A { *foo() {} }`
         *              ^^^^
         * - `class A { async foo() {} }`
         *              ^^^^^^^^^
         * - `class A { ['foo']() {} }`
         *              ^^^^^^^
         * - `class A { *['foo']() {} }`
         *              ^^^^^^^^
         * - `class A { async ['foo']() {} }`
         *              ^^^^^^^^^^^^^
         * - `class A { [foo]() {} }`
         *              ^^^^^
         * - `class A { *[foo]() {} }`
         *              ^^^^^^
         * - `class A { async [foo]() {} }`
         *              ^^^^^^^^^^^
         * - `class A { get foo() {} }`
         *              ^^^^^^^
         * - `class A { set foo(a) {} }`
         *              ^^^^^^^
         * - `class A { static foo() {} }`
         *              ^^^^^^^^^^
         * - `class A { static *foo() {} }`
         *              ^^^^^^^^^^^
         * - `class A { static async foo() {} }`
         *              ^^^^^^^^^^^^^^^^
         * - `class A { static get foo() {} }`
         *              ^^^^^^^^^^^^^^
         * - `class A { static set foo(a) {} }`
         *              ^^^^^^^^^^^^^^
         * - `class A { foo = function() {} }`
         *              ^^^^^^^^^^^^^^
         * - `class A { static foo = function() {} }`
         *              ^^^^^^^^^^^^^^^^^^^^^
         * - `class A { foo = (a, b) => {} }`
         *              ^^^^^^
         * @param {ASTNode} node The function node to get.
         * @param {SourceCode} sourceCode The source code object to get tokens.
         * @returns {string} The location of the function node for reporting.
         */
        getFunctionHeadLoc(node, sourceCode) {
            const parent = node.parent;
            let start = null;
            let end = null;
            if (parent.type === "Property" || parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
                start = parent.loc.start;
                end = getOpeningParenOfParams(node, sourceCode).loc.start;
            }
            else if (node.type === "ArrowFunctionExpression") {
                const arrowToken = sourceCode.getTokenBefore(node.body, isArrowToken);
                start = arrowToken.loc.start;
                end = arrowToken.loc.end;
            }
            else {
                start = node.loc.start;
                end = getOpeningParenOfParams(node, sourceCode).loc.start;
            }
            return {
                start: Object.assign({}, start),
                end: Object.assign({}, end)
            };
        },
        /**
         * Gets next location when the result is not out of bound, otherwise returns null.
         *
         * Assumptions:
         *
         * - The given location represents a valid location in the given source code.
         * - Columns are 0-based.
         * - Lines are 1-based.
         * - Column immediately after the last character in a line (not incl. linebreaks) is considered to be a valid location.
         * - If the source code ends with a linebreak, `sourceCode.lines` array will have an extra element (empty string) at the end.
         *   The start (column 0) of that extra line is considered to be a valid location.
         *
         * Examples of successive locations (line, column):
         *
         * code: foo
         * locations: (1, 0) -> (1, 1) -> (1, 2) -> (1, 3) -> null
         *
         * code: foo<LF>
         * locations: (1, 0) -> (1, 1) -> (1, 2) -> (1, 3) -> (2, 0) -> null
         *
         * code: foo<CR><LF>
         * locations: (1, 0) -> (1, 1) -> (1, 2) -> (1, 3) -> (2, 0) -> null
         *
         * code: a<LF>b
         * locations: (1, 0) -> (1, 1) -> (2, 0) -> (2, 1) -> null
         *
         * code: a<LF>b<LF>
         * locations: (1, 0) -> (1, 1) -> (2, 0) -> (2, 1) -> (3, 0) -> null
         *
         * code: a<CR><LF>b<CR><LF>
         * locations: (1, 0) -> (1, 1) -> (2, 0) -> (2, 1) -> (3, 0) -> null
         *
         * code: a<LF><LF>
         * locations: (1, 0) -> (1, 1) -> (2, 0) -> (3, 0) -> null
         *
         * code: <LF>
         * locations: (1, 0) -> (2, 0) -> null
         *
         * code:
         * locations: (1, 0) -> null
         * @param {SourceCode} sourceCode The sourceCode
         * @param {{line: number, column: number}} location The location
         * @returns {{line: number, column: number} | null} Next location
         */
        getNextLocation(sourceCode, { line, column }) {
            if (column < sourceCode.lines[line - 1].length) {
                return {
                    line,
                    column: column + 1
                };
            }
            if (line < sourceCode.lines.length) {
                return {
                    line: line + 1,
                    column: 0
                };
            }
            return null;
        },
        /**
         * Gets the parenthesized text of a node. This is similar to sourceCode.getText(node), but it also includes any parentheses
         * surrounding the node.
         * @param {SourceCode} sourceCode The source code object
         * @param {ASTNode} node An expression node
         * @returns {string} The text representing the node, with all surrounding parentheses included
         */
        getParenthesisedText(sourceCode, node) {
            let leftToken = sourceCode.getFirstToken(node);
            let rightToken = sourceCode.getLastToken(node);
            while (sourceCode.getTokenBefore(leftToken) &&
                sourceCode.getTokenBefore(leftToken).type === "Punctuator" &&
                sourceCode.getTokenBefore(leftToken).value === "(" &&
                sourceCode.getTokenAfter(rightToken) &&
                sourceCode.getTokenAfter(rightToken).type === "Punctuator" &&
                sourceCode.getTokenAfter(rightToken).value === ")") {
                leftToken = sourceCode.getTokenBefore(leftToken);
                rightToken = sourceCode.getTokenAfter(rightToken);
            }
            return sourceCode.getText().slice(leftToken.range[0], rightToken.range[1]);
        },
        /**
         * Determine if a node has a possibility to be an Error object
         * @param {ASTNode} node ASTNode to check
         * @returns {boolean} True if there is a chance it contains an Error obj
         */
        couldBeError(node) {
            switch (node.type) {
                case "Identifier":
                case "CallExpression":
                case "NewExpression":
                case "MemberExpression":
                case "TaggedTemplateExpression":
                case "YieldExpression":
                case "AwaitExpression":
                case "ChainExpression":
                    return true; // possibly an error object.
                case "AssignmentExpression":
                    if (["=", "&&="].includes(node.operator)) {
                        return module.exports.couldBeError(node.right);
                    }
                    if (["||=", "??="].includes(node.operator)) {
                        return module.exports.couldBeError(node.left) || module.exports.couldBeError(node.right);
                    }
                    /**
                     * All other assignment operators are mathematical assignment operators (arithmetic or bitwise).
                     * An assignment expression with a mathematical operator can either evaluate to a primitive value,
                     * or throw, depending on the operands. Thus, it cannot evaluate to an `Error` object.
                     */
                    return false;
                case "SequenceExpression": {
                    const exprs = node.expressions;
                    return exprs.length !== 0 && module.exports.couldBeError(exprs[exprs.length - 1]);
                }
                case "LogicalExpression":
                    /*
                     * If the && operator short-circuits, the left side was falsy and therefore not an error, and if it
                     * doesn't short-circuit, it takes the value from the right side, so the right side must always be
                     * a plausible error. A future improvement could verify that the left side could be truthy by
                     * excluding falsy literals.
                     */
                    if (node.operator === "&&") {
                        return module.exports.couldBeError(node.right);
                    }
                    return module.exports.couldBeError(node.left) || module.exports.couldBeError(node.right);
                case "ConditionalExpression":
                    return module.exports.couldBeError(node.consequent) || module.exports.couldBeError(node.alternate);
                default:
                    return false;
            }
        },
        /**
         * Check if a given node is a numeric literal or not.
         * @param {ASTNode} node The node to check.
         * @returns {boolean} `true` if the node is a number or bigint literal.
         */
        isNumericLiteral(node) {
            return (node.type === "Literal" &&
                (typeof node.value === "number" || Boolean(node.bigint)));
        },
        /**
         * Determines whether two tokens can safely be placed next to each other without merging into a single token
         * @param {Token|string} leftValue The left token. If this is a string, it will be tokenized and the last token will be used.
         * @param {Token|string} rightValue The right token. If this is a string, it will be tokenized and the first token will be used.
         * @returns {boolean} If the tokens cannot be safely placed next to each other, returns `false`. If the tokens can be placed
         * next to each other, behavior is undefined (although it should return `true` in most cases).
         */
        canTokensBeAdjacent(leftValue, rightValue) {
            const espreeOptions = {
                ecmaVersion: espree.latestEcmaVersion,
                comment: true,
                range: true
            };
            let leftToken;
            if (typeof leftValue === "string") {
                let tokens;
                try {
                    tokens = espree.tokenize(leftValue, espreeOptions);
                }
                catch {
                    return false;
                }
                const comments = tokens.comments;
                leftToken = tokens[tokens.length - 1];
                if (comments.length) {
                    const lastComment = comments[comments.length - 1];
                    if (!leftToken || lastComment.range[0] > leftToken.range[0]) {
                        leftToken = lastComment;
                    }
                }
            }
            else {
                leftToken = leftValue;
            }
            /*
             * If a hashbang comment was passed as a token object from SourceCode,
             * its type will be "Shebang" because of the way ESLint itself handles hashbangs.
             * If a hashbang comment was passed in a string and then tokenized in this function,
             * its type will be "Hashbang" because of the way Espree tokenizes hashbangs.
             */
            if (leftToken.type === "Shebang" || leftToken.type === "Hashbang") {
                return false;
            }
            let rightToken;
            if (typeof rightValue === "string") {
                let tokens;
                try {
                    tokens = espree.tokenize(rightValue, espreeOptions);
                }
                catch {
                    return false;
                }
                const comments = tokens.comments;
                rightToken = tokens[0];
                if (comments.length) {
                    const firstComment = comments[0];
                    if (!rightToken || firstComment.range[0] < rightToken.range[0]) {
                        rightToken = firstComment;
                    }
                }
            }
            else {
                rightToken = rightValue;
            }
            if (leftToken.type === "Punctuator" || rightToken.type === "Punctuator") {
                if (leftToken.type === "Punctuator" && rightToken.type === "Punctuator") {
                    const PLUS_TOKENS = new Set(["+", "++"]);
                    const MINUS_TOKENS = new Set(["-", "--"]);
                    return !(PLUS_TOKENS.has(leftToken.value) && PLUS_TOKENS.has(rightToken.value) ||
                        MINUS_TOKENS.has(leftToken.value) && MINUS_TOKENS.has(rightToken.value));
                }
                if (leftToken.type === "Punctuator" && leftToken.value === "/") {
                    return !["Block", "Line", "RegularExpression"].includes(rightToken.type);
                }
                return true;
            }
            if (leftToken.type === "String" || rightToken.type === "String" ||
                leftToken.type === "Template" || rightToken.type === "Template") {
                return true;
            }
            if (leftToken.type !== "Numeric" && rightToken.type === "Numeric" && rightToken.value.startsWith(".")) {
                return true;
            }
            if (leftToken.type === "Block" || rightToken.type === "Block" || rightToken.type === "Line") {
                return true;
            }
            if (rightToken.type === "PrivateIdentifier") {
                return true;
            }
            return false;
        },
        /**
         * Get the `loc` object of a given name in a `/*globals` directive comment.
         * @param {SourceCode} sourceCode The source code to convert index to loc.
         * @param {Comment} comment The `/*globals` directive comment which include the name.
         * @param {string} name The name to find.
         * @returns {SourceLocation} The `loc` object.
         */
        getNameLocationInGlobalDirectiveComment(sourceCode, comment, name) {
            const namePattern = new RegExp(`[\\s,]${escapeRegExp(name)}(?:$|[\\s,:])`, "gu");
            // To ignore the first text "global".
            namePattern.lastIndex = comment.value.indexOf("global") + 6;
            // Search a given variable name.
            const match = namePattern.exec(comment.value);
            // Convert the index to loc.
            const start = sourceCode.getLocFromIndex(comment.range[0] +
                "/*".length +
                (match ? match.index + 1 : 0));
            const end = {
                line: start.line,
                column: start.column + (match ? name.length : 1)
            };
            return { start, end };
        },
        /**
         * Determines whether the given raw string contains an octal escape sequence
         * or a non-octal decimal escape sequence ("\8", "\9").
         *
         * "\1", "\2" ... "\7", "\8", "\9"
         * "\00", "\01" ... "\07", "\08", "\09"
         *
         * "\0", when not followed by a digit, is not an octal escape sequence.
         * @param {string} rawString A string in its raw representation.
         * @returns {boolean} `true` if the string contains at least one octal escape sequence
         * or at least one non-octal decimal escape sequence.
         */
        hasOctalOrNonOctalDecimalEscapeSequence(rawString) {
            return OCTAL_OR_NON_OCTAL_DECIMAL_ESCAPE_PATTERN.test(rawString);
        },
        isReferenceToGlobalVariable,
        isLogicalExpression,
        isCoalesceExpression,
        isMixedLogicalAndCoalesceExpressions,
        isNullLiteral,
        getStaticStringValue,
        getStaticPropertyName,
        skipChainExpression,
        isSpecificId,
        isSpecificMemberAccess,
        equalLiteralValue,
        isSameReference,
        isLogicalAssignmentOperator,
        getSwitchCaseColonToken,
        getModuleExportName,
        isConstant
    };
},
/* esutils/lib/utils.js */ function _(require, module, exports, __esModule, __esExport) {/*
      Copyright (C) 2013 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    (function () {
        'use strict';
        exports.ast = require(362) /* ./ast */;
        exports.code = require(363) /* ./code */;
        exports.keyword = require(364) /* ./keyword */;
    }());
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* esutils/lib/ast.js */ function _(require, module, exports, __esModule, __esExport) {/*
      Copyright (C) 2013 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 'AS IS'
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    (function () {
        'use strict';
        function isExpression(node) {
            if (node == null) {
                return false;
            }
            switch (node.type) {
                case 'ArrayExpression':
                case 'AssignmentExpression':
                case 'BinaryExpression':
                case 'CallExpression':
                case 'ConditionalExpression':
                case 'FunctionExpression':
                case 'Identifier':
                case 'Literal':
                case 'LogicalExpression':
                case 'MemberExpression':
                case 'NewExpression':
                case 'ObjectExpression':
                case 'SequenceExpression':
                case 'ThisExpression':
                case 'UnaryExpression':
                case 'UpdateExpression':
                    return true;
            }
            return false;
        }
        function isIterationStatement(node) {
            if (node == null) {
                return false;
            }
            switch (node.type) {
                case 'DoWhileStatement':
                case 'ForInStatement':
                case 'ForStatement':
                case 'WhileStatement':
                    return true;
            }
            return false;
        }
        function isStatement(node) {
            if (node == null) {
                return false;
            }
            switch (node.type) {
                case 'BlockStatement':
                case 'BreakStatement':
                case 'ContinueStatement':
                case 'DebuggerStatement':
                case 'DoWhileStatement':
                case 'EmptyStatement':
                case 'ExpressionStatement':
                case 'ForInStatement':
                case 'ForStatement':
                case 'IfStatement':
                case 'LabeledStatement':
                case 'ReturnStatement':
                case 'SwitchStatement':
                case 'ThrowStatement':
                case 'TryStatement':
                case 'VariableDeclaration':
                case 'WhileStatement':
                case 'WithStatement':
                    return true;
            }
            return false;
        }
        function isSourceElement(node) {
            return isStatement(node) || node != null && node.type === 'FunctionDeclaration';
        }
        function trailingStatement(node) {
            switch (node.type) {
                case 'IfStatement':
                    if (node.alternate != null) {
                        return node.alternate;
                    }
                    return node.consequent;
                case 'LabeledStatement':
                case 'ForStatement':
                case 'ForInStatement':
                case 'WhileStatement':
                case 'WithStatement':
                    return node.body;
            }
            return null;
        }
        function isProblematicIfStatement(node) {
            var current;
            if (node.type !== 'IfStatement') {
                return false;
            }
            if (node.alternate == null) {
                return false;
            }
            current = node.consequent;
            do {
                if (current.type === 'IfStatement') {
                    if (current.alternate == null) {
                        return true;
                    }
                }
                current = trailingStatement(current);
            } while (current);
            return false;
        }
        module.exports = {
            isExpression: isExpression,
            isStatement: isStatement,
            isIterationStatement: isIterationStatement,
            isSourceElement: isSourceElement,
            isProblematicIfStatement: isProblematicIfStatement,
            trailingStatement: trailingStatement
        };
    }());
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* esutils/lib/code.js */ function _(require, module, exports, __esModule, __esExport) {/*
      Copyright (C) 2013-2014 Yusuke Suzuki <utatane.tea@gmail.com>
      Copyright (C) 2014 Ivan Nikulin <ifaaan@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    (function () {
        'use strict';
        var ES6Regex, ES5Regex, NON_ASCII_WHITESPACES, IDENTIFIER_START, IDENTIFIER_PART, ch;
        // See `tools/generate-identifier-regex.js`.
        ES5Regex = {
            // ECMAScript 5.1/Unicode v9.0.0 NonAsciiIdentifierStart:
            NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]/,
            // ECMAScript 5.1/Unicode v9.0.0 NonAsciiIdentifierPart:
            NonAsciiIdentifierPart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19D9\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u2E2F\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099\u309A\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]/
        };
        ES6Regex = {
            // ECMAScript 6/Unicode v9.0.0 NonAsciiIdentifierStart:
            NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]/,
            // ECMAScript 6/Unicode v9.0.0 NonAsciiIdentifierPart:
            NonAsciiIdentifierPart: /[\xAA\xB5\xB7\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1369-\u1371\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE3E\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC00-\uDC4A\uDC50-\uDC59\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC36\uDC38-\uDC40\uDC50-\uDC59\uDC72-\uDC8F\uDC92-\uDCA7\uDCA9-\uDCB6]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F\uDFE0]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD838[\uDC00-\uDC06\uDC08-\uDC18\uDC1B-\uDC21\uDC23\uDC24\uDC26-\uDC2A]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6\uDD00-\uDD4A\uDD50-\uDD59]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/
        };
        function isDecimalDigit(ch) {
            return 0x30 <= ch && ch <= 0x39; // 0..9
        }
        function isHexDigit(ch) {
            return 0x30 <= ch && ch <= 0x39 || // 0..9
                0x61 <= ch && ch <= 0x66 || // a..f
                0x41 <= ch && ch <= 0x46; // A..F
        }
        function isOctalDigit(ch) {
            return ch >= 0x30 && ch <= 0x37; // 0..7
        }
        // 7.2 White Space
        NON_ASCII_WHITESPACES = [
            0x1680,
            0x2000, 0x2001, 0x2002, 0x2003, 0x2004, 0x2005, 0x2006, 0x2007, 0x2008, 0x2009, 0x200A,
            0x202F, 0x205F,
            0x3000,
            0xFEFF
        ];
        function isWhiteSpace(ch) {
            return ch === 0x20 || ch === 0x09 || ch === 0x0B || ch === 0x0C || ch === 0xA0 ||
                ch >= 0x1680 && NON_ASCII_WHITESPACES.indexOf(ch) >= 0;
        }
        // 7.3 Line Terminators
        function isLineTerminator(ch) {
            return ch === 0x0A || ch === 0x0D || ch === 0x2028 || ch === 0x2029;
        }
        // 7.6 Identifier Names and Identifiers
        function fromCodePoint(cp) {
            if (cp <= 0xFFFF) {
                return String.fromCharCode(cp);
            }
            var cu1 = String.fromCharCode(Math.floor((cp - 0x10000) / 0x400) + 0xD800);
            var cu2 = String.fromCharCode(((cp - 0x10000) % 0x400) + 0xDC00);
            return cu1 + cu2;
        }
        IDENTIFIER_START = new Array(0x80);
        for (ch = 0; ch < 0x80; ++ch) {
            IDENTIFIER_START[ch] =
                ch >= 0x61 && ch <= 0x7A || // a..z
                    ch >= 0x41 && ch <= 0x5A || // A..Z
                    ch === 0x24 || ch === 0x5F; // $ (dollar) and _ (underscore)
        }
        IDENTIFIER_PART = new Array(0x80);
        for (ch = 0; ch < 0x80; ++ch) {
            IDENTIFIER_PART[ch] =
                ch >= 0x61 && ch <= 0x7A || // a..z
                    ch >= 0x41 && ch <= 0x5A || // A..Z
                    ch >= 0x30 && ch <= 0x39 || // 0..9
                    ch === 0x24 || ch === 0x5F; // $ (dollar) and _ (underscore)
        }
        function isIdentifierStartES5(ch) {
            return ch < 0x80 ? IDENTIFIER_START[ch] : ES5Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch));
        }
        function isIdentifierPartES5(ch) {
            return ch < 0x80 ? IDENTIFIER_PART[ch] : ES5Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch));
        }
        function isIdentifierStartES6(ch) {
            return ch < 0x80 ? IDENTIFIER_START[ch] : ES6Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch));
        }
        function isIdentifierPartES6(ch) {
            return ch < 0x80 ? IDENTIFIER_PART[ch] : ES6Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch));
        }
        module.exports = {
            isDecimalDigit: isDecimalDigit,
            isHexDigit: isHexDigit,
            isOctalDigit: isOctalDigit,
            isWhiteSpace: isWhiteSpace,
            isLineTerminator: isLineTerminator,
            isIdentifierStartES5: isIdentifierStartES5,
            isIdentifierPartES5: isIdentifierPartES5,
            isIdentifierStartES6: isIdentifierStartES6,
            isIdentifierPartES6: isIdentifierPartES6
        };
    }());
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* esutils/lib/keyword.js */ function _(require, module, exports, __esModule, __esExport) {/*
      Copyright (C) 2013 Yusuke Suzuki <utatane.tea@gmail.com>
    
      Redistribution and use in source and binary forms, with or without
      modification, are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright
          notice, this list of conditions and the following disclaimer in the
          documentation and/or other materials provided with the distribution.
    
      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
      DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
      (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
      LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
      ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
      THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    */
    (function () {
        'use strict';
        var code = require(363) /* ./code */;
        function isStrictModeReservedWordES6(id) {
            switch (id) {
                case 'implements':
                case 'interface':
                case 'package':
                case 'private':
                case 'protected':
                case 'public':
                case 'static':
                case 'let':
                    return true;
                default:
                    return false;
            }
        }
        function isKeywordES5(id, strict) {
            // yield should not be treated as keyword under non-strict mode.
            if (!strict && id === 'yield') {
                return false;
            }
            return isKeywordES6(id, strict);
        }
        function isKeywordES6(id, strict) {
            if (strict && isStrictModeReservedWordES6(id)) {
                return true;
            }
            switch (id.length) {
                case 2:
                    return (id === 'if') || (id === 'in') || (id === 'do');
                case 3:
                    return (id === 'var') || (id === 'for') || (id === 'new') || (id === 'try');
                case 4:
                    return (id === 'this') || (id === 'else') || (id === 'case') ||
                        (id === 'void') || (id === 'with') || (id === 'enum');
                case 5:
                    return (id === 'while') || (id === 'break') || (id === 'catch') ||
                        (id === 'throw') || (id === 'const') || (id === 'yield') ||
                        (id === 'class') || (id === 'super');
                case 6:
                    return (id === 'return') || (id === 'typeof') || (id === 'delete') ||
                        (id === 'switch') || (id === 'export') || (id === 'import');
                case 7:
                    return (id === 'default') || (id === 'finally') || (id === 'extends');
                case 8:
                    return (id === 'function') || (id === 'continue') || (id === 'debugger');
                case 10:
                    return (id === 'instanceof');
                default:
                    return false;
            }
        }
        function isReservedWordES5(id, strict) {
            return id === 'null' || id === 'true' || id === 'false' || isKeywordES5(id, strict);
        }
        function isReservedWordES6(id, strict) {
            return id === 'null' || id === 'true' || id === 'false' || isKeywordES6(id, strict);
        }
        function isRestrictedWord(id) {
            return id === 'eval' || id === 'arguments';
        }
        function isIdentifierNameES5(id) {
            var i, iz, ch;
            if (id.length === 0) {
                return false;
            }
            ch = id.charCodeAt(0);
            if (!code.isIdentifierStartES5(ch)) {
                return false;
            }
            for (i = 1, iz = id.length; i < iz; ++i) {
                ch = id.charCodeAt(i);
                if (!code.isIdentifierPartES5(ch)) {
                    return false;
                }
            }
            return true;
        }
        function decodeUtf16(lead, trail) {
            return (lead - 0xD800) * 0x400 + (trail - 0xDC00) + 0x10000;
        }
        function isIdentifierNameES6(id) {
            var i, iz, ch, lowCh, check;
            if (id.length === 0) {
                return false;
            }
            check = code.isIdentifierStartES6;
            for (i = 0, iz = id.length; i < iz; ++i) {
                ch = id.charCodeAt(i);
                if (0xD800 <= ch && ch <= 0xDBFF) {
                    ++i;
                    if (i >= iz) {
                        return false;
                    }
                    lowCh = id.charCodeAt(i);
                    if (!(0xDC00 <= lowCh && lowCh <= 0xDFFF)) {
                        return false;
                    }
                    ch = decodeUtf16(ch, lowCh);
                }
                if (!check(ch)) {
                    return false;
                }
                check = code.isIdentifierPartES6;
            }
            return true;
        }
        function isIdentifierES5(id, strict) {
            return isIdentifierNameES5(id) && !isReservedWordES5(id, strict);
        }
        function isIdentifierES6(id, strict) {
            return isIdentifierNameES6(id) && !isReservedWordES6(id, strict);
        }
        module.exports = {
            isKeywordES5: isKeywordES5,
            isKeywordES6: isKeywordES6,
            isReservedWordES5: isReservedWordES5,
            isReservedWordES6: isReservedWordES6,
            isRestrictedWord: isRestrictedWord,
            isIdentifierNameES5: isIdentifierNameES5,
            isIdentifierNameES6: isIdentifierNameES6,
            isIdentifierES5: isIdentifierES5,
            isIdentifierES6: isIdentifierES6
        };
    }());
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* eslint/lib/rules/array-bracket-newline.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce linebreaks after open and before close array brackets
     * @author Jan Peer Stöcklmair <https://github.com/JPeer264>
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce linebreaks after opening and before closing array brackets",
                recommended: false,
                url: "https://eslint.org/docs/rules/array-bracket-newline"
            },
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["always", "never", "consistent"]
                        },
                        {
                            type: "object",
                            properties: {
                                multiline: {
                                    type: "boolean"
                                },
                                minItems: {
                                    type: ["integer", "null"],
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                unexpectedOpeningLinebreak: "There should be no linebreak after '['.",
                unexpectedClosingLinebreak: "There should be no linebreak before ']'.",
                missingOpeningLinebreak: "A linebreak is required after '['.",
                missingClosingLinebreak: "A linebreak is required before ']'."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            //----------------------------------------------------------------------
            // Helpers
            //----------------------------------------------------------------------
            /**
             * Normalizes a given option value.
             * @param {string|Object|undefined} option An option value to parse.
             * @returns {{multiline: boolean, minItems: number}} Normalized option object.
             */
            function normalizeOptionValue(option) {
                let consistent = false;
                let multiline = false;
                let minItems = 0;
                if (option) {
                    if (option === "consistent") {
                        consistent = true;
                        minItems = Number.POSITIVE_INFINITY;
                    }
                    else if (option === "always" || option.minItems === 0) {
                        minItems = 0;
                    }
                    else if (option === "never") {
                        minItems = Number.POSITIVE_INFINITY;
                    }
                    else {
                        multiline = Boolean(option.multiline);
                        minItems = option.minItems || Number.POSITIVE_INFINITY;
                    }
                }
                else {
                    consistent = false;
                    multiline = true;
                    minItems = Number.POSITIVE_INFINITY;
                }
                return { consistent, multiline, minItems };
            }
            /**
             * Normalizes a given option value.
             * @param {string|Object|undefined} options An option value to parse.
             * @returns {{ArrayExpression: {multiline: boolean, minItems: number}, ArrayPattern: {multiline: boolean, minItems: number}}} Normalized option object.
             */
            function normalizeOptions(options) {
                const value = normalizeOptionValue(options);
                return { ArrayExpression: value, ArrayPattern: value };
            }
            /**
             * Reports that there shouldn't be a linebreak after the first token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportNoBeginningLinebreak(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "unexpectedOpeningLinebreak",
                    fix(fixer) {
                        const nextToken = sourceCode.getTokenAfter(token, { includeComments: true });
                        if (astUtils.isCommentToken(nextToken)) {
                            return null;
                        }
                        return fixer.removeRange([token.range[1], nextToken.range[0]]);
                    }
                });
            }
            /**
             * Reports that there shouldn't be a linebreak before the last token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportNoEndingLinebreak(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "unexpectedClosingLinebreak",
                    fix(fixer) {
                        const previousToken = sourceCode.getTokenBefore(token, { includeComments: true });
                        if (astUtils.isCommentToken(previousToken)) {
                            return null;
                        }
                        return fixer.removeRange([previousToken.range[1], token.range[0]]);
                    }
                });
            }
            /**
             * Reports that there should be a linebreak after the first token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportRequiredBeginningLinebreak(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "missingOpeningLinebreak",
                    fix(fixer) {
                        return fixer.insertTextAfter(token, "\n");
                    }
                });
            }
            /**
             * Reports that there should be a linebreak before the last token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportRequiredEndingLinebreak(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "missingClosingLinebreak",
                    fix(fixer) {
                        return fixer.insertTextBefore(token, "\n");
                    }
                });
            }
            /**
             * Reports a given node if it violated this rule.
             * @param {ASTNode} node A node to check. This is an ArrayExpression node or an ArrayPattern node.
             * @returns {void}
             */
            function check(node) {
                const elements = node.elements;
                const normalizedOptions = normalizeOptions(context.options[0]);
                const options = normalizedOptions[node.type];
                const openBracket = sourceCode.getFirstToken(node);
                const closeBracket = sourceCode.getLastToken(node);
                const firstIncComment = sourceCode.getTokenAfter(openBracket, { includeComments: true });
                const lastIncComment = sourceCode.getTokenBefore(closeBracket, { includeComments: true });
                const first = sourceCode.getTokenAfter(openBracket);
                const last = sourceCode.getTokenBefore(closeBracket);
                const needsLinebreaks = (elements.length >= options.minItems ||
                    (options.multiline &&
                        elements.length > 0 &&
                        firstIncComment.loc.start.line !== lastIncComment.loc.end.line) ||
                    (elements.length === 0 &&
                        firstIncComment.type === "Block" &&
                        firstIncComment.loc.start.line !== lastIncComment.loc.end.line &&
                        firstIncComment === lastIncComment) ||
                    (options.consistent &&
                        openBracket.loc.end.line !== first.loc.start.line));
                /*
                 * Use tokens or comments to check multiline or not.
                 * But use only tokens to check whether linebreaks are needed.
                 * This allows:
                 *     var arr = [ // eslint-disable-line foo
                 *         'a'
                 *     ]
                 */
                if (needsLinebreaks) {
                    if (astUtils.isTokenOnSameLine(openBracket, first)) {
                        reportRequiredBeginningLinebreak(node, openBracket);
                    }
                    if (astUtils.isTokenOnSameLine(last, closeBracket)) {
                        reportRequiredEndingLinebreak(node, closeBracket);
                    }
                }
                else {
                    if (!astUtils.isTokenOnSameLine(openBracket, first)) {
                        reportNoBeginningLinebreak(node, openBracket);
                    }
                    if (!astUtils.isTokenOnSameLine(last, closeBracket)) {
                        reportNoEndingLinebreak(node, closeBracket);
                    }
                }
            }
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                ArrayPattern: check,
                ArrayExpression: check
            };
        }
    };
},
/* eslint/lib/rules/array-bracket-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallows or enforces spaces inside of array brackets.
     * @author Jamund Ferguson
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing inside array brackets",
                recommended: false,
                url: "https://eslint.org/docs/rules/array-bracket-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never"]
                },
                {
                    type: "object",
                    properties: {
                        singleValue: {
                            type: "boolean"
                        },
                        objectsInArrays: {
                            type: "boolean"
                        },
                        arraysInArrays: {
                            type: "boolean"
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedSpaceAfter: "There should be no space after '{{tokenValue}}'.",
                unexpectedSpaceBefore: "There should be no space before '{{tokenValue}}'.",
                missingSpaceAfter: "A space is required after '{{tokenValue}}'.",
                missingSpaceBefore: "A space is required before '{{tokenValue}}'."
            }
        },
        create(context) {
            const spaced = context.options[0] === "always", sourceCode = context.getSourceCode();
            /**
             * Determines whether an option is set, relative to the spacing option.
             * If spaced is "always", then check whether option is set to false.
             * If spaced is "never", then check whether option is set to true.
             * @param {Object} option The option to exclude.
             * @returns {boolean} Whether or not the property is excluded.
             */
            function isOptionSet(option) {
                return context.options[1] ? context.options[1][option] === !spaced : false;
            }
            const options = {
                spaced,
                singleElementException: isOptionSet("singleValue"),
                objectsInArraysException: isOptionSet("objectsInArrays"),
                arraysInArraysException: isOptionSet("arraysInArrays")
            };
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Reports that there shouldn't be a space after the first token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportNoBeginningSpace(node, token) {
                const nextToken = sourceCode.getTokenAfter(token);
                context.report({
                    node,
                    loc: { start: token.loc.end, end: nextToken.loc.start },
                    messageId: "unexpectedSpaceAfter",
                    data: {
                        tokenValue: token.value
                    },
                    fix(fixer) {
                        return fixer.removeRange([token.range[1], nextToken.range[0]]);
                    }
                });
            }
            /**
             * Reports that there shouldn't be a space before the last token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportNoEndingSpace(node, token) {
                const previousToken = sourceCode.getTokenBefore(token);
                context.report({
                    node,
                    loc: { start: previousToken.loc.end, end: token.loc.start },
                    messageId: "unexpectedSpaceBefore",
                    data: {
                        tokenValue: token.value
                    },
                    fix(fixer) {
                        return fixer.removeRange([previousToken.range[1], token.range[0]]);
                    }
                });
            }
            /**
             * Reports that there should be a space after the first token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportRequiredBeginningSpace(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "missingSpaceAfter",
                    data: {
                        tokenValue: token.value
                    },
                    fix(fixer) {
                        return fixer.insertTextAfter(token, " ");
                    }
                });
            }
            /**
             * Reports that there should be a space before the last token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportRequiredEndingSpace(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "missingSpaceBefore",
                    data: {
                        tokenValue: token.value
                    },
                    fix(fixer) {
                        return fixer.insertTextBefore(token, " ");
                    }
                });
            }
            /**
             * Determines if a node is an object type
             * @param {ASTNode} node The node to check.
             * @returns {boolean} Whether or not the node is an object type.
             */
            function isObjectType(node) {
                return node && (node.type === "ObjectExpression" || node.type === "ObjectPattern");
            }
            /**
             * Determines if a node is an array type
             * @param {ASTNode} node The node to check.
             * @returns {boolean} Whether or not the node is an array type.
             */
            function isArrayType(node) {
                return node && (node.type === "ArrayExpression" || node.type === "ArrayPattern");
            }
            /**
             * Validates the spacing around array brackets
             * @param {ASTNode} node The node we're checking for spacing
             * @returns {void}
             */
            function validateArraySpacing(node) {
                if (options.spaced && node.elements.length === 0) {
                    return;
                }
                const first = sourceCode.getFirstToken(node), second = sourceCode.getFirstToken(node, 1), last = node.typeAnnotation
                    ? sourceCode.getTokenBefore(node.typeAnnotation)
                    : sourceCode.getLastToken(node), penultimate = sourceCode.getTokenBefore(last), firstElement = node.elements[0], lastElement = node.elements[node.elements.length - 1];
                const openingBracketMustBeSpaced = options.objectsInArraysException && isObjectType(firstElement) ||
                    options.arraysInArraysException && isArrayType(firstElement) ||
                    options.singleElementException && node.elements.length === 1
                    ? !options.spaced : options.spaced;
                const closingBracketMustBeSpaced = options.objectsInArraysException && isObjectType(lastElement) ||
                    options.arraysInArraysException && isArrayType(lastElement) ||
                    options.singleElementException && node.elements.length === 1
                    ? !options.spaced : options.spaced;
                if (astUtils.isTokenOnSameLine(first, second)) {
                    if (openingBracketMustBeSpaced && !sourceCode.isSpaceBetweenTokens(first, second)) {
                        reportRequiredBeginningSpace(node, first);
                    }
                    if (!openingBracketMustBeSpaced && sourceCode.isSpaceBetweenTokens(first, second)) {
                        reportNoBeginningSpace(node, first);
                    }
                }
                if (first !== penultimate && astUtils.isTokenOnSameLine(penultimate, last)) {
                    if (closingBracketMustBeSpaced && !sourceCode.isSpaceBetweenTokens(penultimate, last)) {
                        reportRequiredEndingSpace(node, last);
                    }
                    if (!closingBracketMustBeSpaced && sourceCode.isSpaceBetweenTokens(penultimate, last)) {
                        reportNoEndingSpace(node, last);
                    }
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                ArrayPattern: validateArraySpacing,
                ArrayExpression: validateArraySpacing
            };
        }
    };
},
/* eslint/lib/rules/array-callback-return.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce return statements in callbacks of array's methods
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const TARGET_NODE_TYPE = /^(?:Arrow)?FunctionExpression$/u;
    const TARGET_METHODS = /^(?:every|filter|find(?:Last)?(?:Index)?|flatMap|forEach|map|reduce(?:Right)?|some|sort|toSorted)$/u;
    /**
     * Checks a given code path segment is reachable.
     * @param {CodePathSegment} segment A segment to check.
     * @returns {boolean} `true` if the segment is reachable.
     */
    function isReachable(segment) {
        return segment.reachable;
    }
    /**
     * Checks a given node is a member access which has the specified name's
     * property.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node is a member access which has
     *      the specified name's property. The node may be a `(Chain|Member)Expression` node.
     */
    function isTargetMethod(node) {
        return astUtils.isSpecificMemberAccess(node, null, TARGET_METHODS);
    }
    /**
     * Returns a human-legible description of an array method
     * @param {string} arrayMethodName A method name to fully qualify
     * @returns {string} the method name prefixed with `Array.` if it is a class method,
     *      or else `Array.prototype.` if it is an instance method.
     */
    function fullMethodName(arrayMethodName) {
        if (["from", "of", "isArray"].includes(arrayMethodName)) {
            return "Array.".concat(arrayMethodName);
        }
        return "Array.prototype.".concat(arrayMethodName);
    }
    /**
     * Checks whether or not a given node is a function expression which is the
     * callback of an array method, returning the method name.
     * @param {ASTNode} node A node to check. This is one of
     *      FunctionExpression or ArrowFunctionExpression.
     * @returns {string} The method name if the node is a callback method,
     *      null otherwise.
     */
    function getArrayMethodName(node) {
        let currentNode = node;
        while (currentNode) {
            const parent = currentNode.parent;
            switch (parent.type) {
                /*
                 * Looks up the destination. e.g.,
                 * foo.every(nativeFoo || function foo() { ... });
                 */
                case "LogicalExpression":
                case "ConditionalExpression":
                case "ChainExpression":
                    currentNode = parent;
                    break;
                /*
                 * If the upper function is IIFE, checks the destination of the return value.
                 * e.g.
                 *   foo.every((function() {
                 *     // setup...
                 *     return function callback() { ... };
                 *   })());
                 */
                case "ReturnStatement": {
                    const func = astUtils.getUpperFunction(parent);
                    if (func === null || !astUtils.isCallee(func)) {
                        return null;
                    }
                    currentNode = func.parent;
                    break;
                }
                /*
                 * e.g.
                 *   Array.from([], function() {});
                 *   list.every(function() {});
                 */
                case "CallExpression":
                    if (astUtils.isArrayFromMethod(parent.callee)) {
                        if (parent.arguments.length >= 2 &&
                            parent.arguments[1] === currentNode) {
                            return "from";
                        }
                    }
                    if (isTargetMethod(parent.callee)) {
                        if (parent.arguments.length >= 1 &&
                            parent.arguments[0] === currentNode) {
                            return astUtils.getStaticPropertyName(parent.callee);
                        }
                    }
                    return null;
                // Otherwise this node is not target.
                default:
                    return null;
            }
        }
        /* c8 ignore next */
        return null;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Enforce `return` statements in callbacks of array methods",
                recommended: false,
                url: "https://eslint.org/docs/rules/array-callback-return"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowImplicit: {
                            type: "boolean",
                            default: false
                        },
                        checkForEach: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                expectedAtEnd: "{{arrayMethodName}}() expects a value to be returned at the end of {{name}}.",
                expectedInside: "{{arrayMethodName}}() expects a return value from {{name}}.",
                expectedReturnValue: "{{arrayMethodName}}() expects a return value from {{name}}.",
                expectedNoReturnValue: "{{arrayMethodName}}() expects no useless return value from {{name}}."
            }
        },
        create(context) {
            const options = context.options[0] || { allowImplicit: false, checkForEach: false };
            const sourceCode = context.getSourceCode();
            let funcInfo = {
                arrayMethodName: null,
                upper: null,
                codePath: null,
                hasReturn: false,
                shouldCheck: false,
                node: null
            };
            /**
             * Checks whether or not the last code path segment is reachable.
             * Then reports this function if the segment is reachable.
             *
             * If the last code path segment is reachable, there are paths which are not
             * returned or thrown.
             * @param {ASTNode} node A node to check.
             * @returns {void}
             */
            function checkLastSegment(node) {
                if (!funcInfo.shouldCheck) {
                    return;
                }
                let messageId = null;
                if (funcInfo.arrayMethodName === "forEach") {
                    if (options.checkForEach && node.type === "ArrowFunctionExpression" && node.expression) {
                        messageId = "expectedNoReturnValue";
                    }
                }
                else {
                    if (node.body.type === "BlockStatement" && funcInfo.codePath.currentSegments.some(isReachable)) {
                        messageId = funcInfo.hasReturn ? "expectedAtEnd" : "expectedInside";
                    }
                }
                if (messageId) {
                    const name = astUtils.getFunctionNameWithKind(node);
                    context.report({
                        node,
                        loc: astUtils.getFunctionHeadLoc(node, sourceCode),
                        messageId,
                        data: { name, arrayMethodName: fullMethodName(funcInfo.arrayMethodName) }
                    });
                }
            }
            return {
                // Stacks this function's information.
                onCodePathStart(codePath, node) {
                    let methodName = null;
                    if (TARGET_NODE_TYPE.test(node.type)) {
                        methodName = getArrayMethodName(node);
                    }
                    funcInfo = {
                        arrayMethodName: methodName,
                        upper: funcInfo,
                        codePath,
                        hasReturn: false,
                        shouldCheck: methodName &&
                            !node.async &&
                            !node.generator,
                        node
                    };
                },
                // Pops this function's information.
                onCodePathEnd() {
                    funcInfo = funcInfo.upper;
                },
                // Checks the return statement is valid.
                ReturnStatement(node) {
                    if (!funcInfo.shouldCheck) {
                        return;
                    }
                    funcInfo.hasReturn = true;
                    let messageId = null;
                    if (funcInfo.arrayMethodName === "forEach") {
                        // if checkForEach: true, returning a value at any path inside a forEach is not allowed
                        if (options.checkForEach && node.argument) {
                            messageId = "expectedNoReturnValue";
                        }
                    }
                    else {
                        // if allowImplicit: false, should also check node.argument
                        if (!options.allowImplicit && !node.argument) {
                            messageId = "expectedReturnValue";
                        }
                    }
                    if (messageId) {
                        context.report({
                            node,
                            messageId,
                            data: {
                                name: astUtils.getFunctionNameWithKind(funcInfo.node),
                                arrayMethodName: fullMethodName(funcInfo.arrayMethodName)
                            }
                        });
                    }
                },
                // Reports a given function if the last path is reachable.
                "FunctionExpression:exit": checkLastSegment,
                "ArrowFunctionExpression:exit": checkLastSegment
            };
        }
    };
},
/* eslint/lib/rules/array-element-newline.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce line breaks after each array element
     * @author Jan Peer Stöcklmair <https://github.com/JPeer264>
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce line breaks after each array element",
                recommended: false,
                url: "https://eslint.org/docs/rules/array-element-newline"
            },
            fixable: "whitespace",
            schema: {
                definitions: {
                    basicConfig: {
                        oneOf: [
                            {
                                enum: ["always", "never", "consistent"]
                            },
                            {
                                type: "object",
                                properties: {
                                    multiline: {
                                        type: "boolean"
                                    },
                                    minItems: {
                                        type: ["integer", "null"],
                                        minimum: 0
                                    }
                                },
                                additionalProperties: false
                            }
                        ]
                    }
                },
                type: "array",
                items: [
                    {
                        oneOf: [
                            {
                                $ref: "#/definitions/basicConfig"
                            },
                            {
                                type: "object",
                                properties: {
                                    ArrayExpression: {
                                        $ref: "#/definitions/basicConfig"
                                    },
                                    ArrayPattern: {
                                        $ref: "#/definitions/basicConfig"
                                    }
                                },
                                additionalProperties: false,
                                minProperties: 1
                            }
                        ]
                    }
                ]
            },
            messages: {
                unexpectedLineBreak: "There should be no linebreak here.",
                missingLineBreak: "There should be a linebreak after this element."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            //----------------------------------------------------------------------
            // Helpers
            //----------------------------------------------------------------------
            /**
             * Normalizes a given option value.
             * @param {string|Object|undefined} providedOption An option value to parse.
             * @returns {{multiline: boolean, minItems: number}} Normalized option object.
             */
            function normalizeOptionValue(providedOption) {
                let consistent = false;
                let multiline = false;
                let minItems;
                const option = providedOption || "always";
                if (!option || option === "always" || option.minItems === 0) {
                    minItems = 0;
                }
                else if (option === "never") {
                    minItems = Number.POSITIVE_INFINITY;
                }
                else if (option === "consistent") {
                    consistent = true;
                    minItems = Number.POSITIVE_INFINITY;
                }
                else {
                    multiline = Boolean(option.multiline);
                    minItems = option.minItems || Number.POSITIVE_INFINITY;
                }
                return { consistent, multiline, minItems };
            }
            /**
             * Normalizes a given option value.
             * @param {string|Object|undefined} options An option value to parse.
             * @returns {{ArrayExpression: {multiline: boolean, minItems: number}, ArrayPattern: {multiline: boolean, minItems: number}}} Normalized option object.
             */
            function normalizeOptions(options) {
                if (options && (options.ArrayExpression || options.ArrayPattern)) {
                    let expressionOptions, patternOptions;
                    if (options.ArrayExpression) {
                        expressionOptions = normalizeOptionValue(options.ArrayExpression);
                    }
                    if (options.ArrayPattern) {
                        patternOptions = normalizeOptionValue(options.ArrayPattern);
                    }
                    return { ArrayExpression: expressionOptions, ArrayPattern: patternOptions };
                }
                const value = normalizeOptionValue(options);
                return { ArrayExpression: value, ArrayPattern: value };
            }
            /**
             * Reports that there shouldn't be a line break after the first token
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportNoLineBreak(token) {
                const tokenBefore = sourceCode.getTokenBefore(token, { includeComments: true });
                context.report({
                    loc: {
                        start: tokenBefore.loc.end,
                        end: token.loc.start
                    },
                    messageId: "unexpectedLineBreak",
                    fix(fixer) {
                        if (astUtils.isCommentToken(tokenBefore)) {
                            return null;
                        }
                        if (!astUtils.isTokenOnSameLine(tokenBefore, token)) {
                            return fixer.replaceTextRange([tokenBefore.range[1], token.range[0]], " ");
                        }
                        /*
                         * This will check if the comma is on the same line as the next element
                         * Following array:
                         * [
                         *     1
                         *     , 2
                         *     , 3
                         * ]
                         *
                         * will be fixed to:
                         * [
                         *     1, 2, 3
                         * ]
                         */
                        const twoTokensBefore = sourceCode.getTokenBefore(tokenBefore, { includeComments: true });
                        if (astUtils.isCommentToken(twoTokensBefore)) {
                            return null;
                        }
                        return fixer.replaceTextRange([twoTokensBefore.range[1], tokenBefore.range[0]], "");
                    }
                });
            }
            /**
             * Reports that there should be a line break after the first token
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportRequiredLineBreak(token) {
                const tokenBefore = sourceCode.getTokenBefore(token, { includeComments: true });
                context.report({
                    loc: {
                        start: tokenBefore.loc.end,
                        end: token.loc.start
                    },
                    messageId: "missingLineBreak",
                    fix(fixer) {
                        return fixer.replaceTextRange([tokenBefore.range[1], token.range[0]], "\n");
                    }
                });
            }
            /**
             * Reports a given node if it violated this rule.
             * @param {ASTNode} node A node to check. This is an ObjectExpression node or an ObjectPattern node.
             * @returns {void}
             */
            function check(node) {
                const elements = node.elements;
                const normalizedOptions = normalizeOptions(context.options[0]);
                const options = normalizedOptions[node.type];
                if (!options) {
                    return;
                }
                let elementBreak = false;
                /*
                 * MULTILINE: true
                 * loop through every element and check
                 * if at least one element has linebreaks inside
                 * this ensures that following is not valid (due to elements are on the same line):
                 *
                 * [
                 *      1,
                 *      2,
                 *      3
                 * ]
                 */
                if (options.multiline) {
                    elementBreak = elements
                        .filter(element => element !== null)
                        .some(element => element.loc.start.line !== element.loc.end.line);
                }
                const linebreaksCount = node.elements.map((element, i) => {
                    const previousElement = elements[i - 1];
                    if (i === 0 || element === null || previousElement === null) {
                        return false;
                    }
                    const commaToken = sourceCode.getFirstTokenBetween(previousElement, element, astUtils.isCommaToken);
                    const lastTokenOfPreviousElement = sourceCode.getTokenBefore(commaToken);
                    const firstTokenOfCurrentElement = sourceCode.getTokenAfter(commaToken);
                    return !astUtils.isTokenOnSameLine(lastTokenOfPreviousElement, firstTokenOfCurrentElement);
                }).filter(isBreak => isBreak === true).length;
                const needsLinebreaks = (elements.length >= options.minItems ||
                    (options.multiline &&
                        elementBreak) ||
                    (options.consistent &&
                        linebreaksCount > 0 &&
                        linebreaksCount < node.elements.length));
                elements.forEach((element, i) => {
                    const previousElement = elements[i - 1];
                    if (i === 0 || element === null || previousElement === null) {
                        return;
                    }
                    const commaToken = sourceCode.getFirstTokenBetween(previousElement, element, astUtils.isCommaToken);
                    const lastTokenOfPreviousElement = sourceCode.getTokenBefore(commaToken);
                    const firstTokenOfCurrentElement = sourceCode.getTokenAfter(commaToken);
                    if (needsLinebreaks) {
                        if (astUtils.isTokenOnSameLine(lastTokenOfPreviousElement, firstTokenOfCurrentElement)) {
                            reportRequiredLineBreak(firstTokenOfCurrentElement);
                        }
                    }
                    else {
                        if (!astUtils.isTokenOnSameLine(lastTokenOfPreviousElement, firstTokenOfCurrentElement)) {
                            reportNoLineBreak(firstTokenOfCurrentElement);
                        }
                    }
                });
            }
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                ArrayPattern: check,
                ArrayExpression: check
            };
        }
    };
},
/* eslint/lib/rules/arrow-body-style.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to require braces in arrow function body.
     * @author Alberto Rodríguez
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require braces around arrow function bodies",
                recommended: false,
                url: "https://eslint.org/docs/rules/arrow-body-style"
            },
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always", "never"]
                            }
                        ],
                        minItems: 0,
                        maxItems: 1
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["as-needed"]
                            },
                            {
                                type: "object",
                                properties: {
                                    requireReturnForObjectLiteral: { type: "boolean" }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    }
                ]
            },
            fixable: "code",
            messages: {
                unexpectedOtherBlock: "Unexpected block statement surrounding arrow body.",
                unexpectedEmptyBlock: "Unexpected block statement surrounding arrow body; put a value of `undefined` immediately after the `=>`.",
                unexpectedObjectBlock: "Unexpected block statement surrounding arrow body; parenthesize the returned value and move it immediately after the `=>`.",
                unexpectedSingleBlock: "Unexpected block statement surrounding arrow body; move the returned value immediately after the `=>`.",
                expectedBlock: "Expected block statement surrounding arrow body."
            }
        },
        create(context) {
            const options = context.options;
            const always = options[0] === "always";
            const asNeeded = !options[0] || options[0] === "as-needed";
            const never = options[0] === "never";
            const requireReturnForObjectLiteral = options[1] && options[1].requireReturnForObjectLiteral;
            const sourceCode = context.getSourceCode();
            let funcInfo = null;
            /**
             * Checks whether the given node has ASI problem or not.
             * @param {Token} token The token to check.
             * @returns {boolean} `true` if it changes semantics if `;` or `}` followed by the token are removed.
             */
            function hasASIProblem(token) {
                return token && token.type === "Punctuator" && /^[([/`+-]/u.test(token.value);
            }
            /**
             * Gets the closing parenthesis by the given node.
             * @param {ASTNode} node first node after an opening parenthesis.
             * @returns {Token} The found closing parenthesis token.
             */
            function findClosingParen(node) {
                let nodeToCheck = node;
                while (!astUtils.isParenthesised(sourceCode, nodeToCheck)) {
                    nodeToCheck = nodeToCheck.parent;
                }
                return sourceCode.getTokenAfter(nodeToCheck);
            }
            /**
             * Check whether the node is inside of a for loop's init
             * @param {ASTNode} node node is inside for loop
             * @returns {boolean} `true` if the node is inside of a for loop, else `false`
             */
            function isInsideForLoopInitializer(node) {
                if (node && node.parent) {
                    if (node.parent.type === "ForStatement" && node.parent.init === node) {
                        return true;
                    }
                    return isInsideForLoopInitializer(node.parent);
                }
                return false;
            }
            /**
             * Determines whether a arrow function body needs braces
             * @param {ASTNode} node The arrow function node.
             * @returns {void}
             */
            function validate(node) {
                const arrowBody = node.body;
                if (arrowBody.type === "BlockStatement") {
                    const blockBody = arrowBody.body;
                    if (blockBody.length !== 1 && !never) {
                        return;
                    }
                    if (asNeeded && requireReturnForObjectLiteral && blockBody[0].type === "ReturnStatement" &&
                        blockBody[0].argument && blockBody[0].argument.type === "ObjectExpression") {
                        return;
                    }
                    if (never || asNeeded && blockBody[0].type === "ReturnStatement") {
                        let messageId;
                        if (blockBody.length === 0) {
                            messageId = "unexpectedEmptyBlock";
                        }
                        else if (blockBody.length > 1) {
                            messageId = "unexpectedOtherBlock";
                        }
                        else if (blockBody[0].argument === null) {
                            messageId = "unexpectedSingleBlock";
                        }
                        else if (astUtils.isOpeningBraceToken(sourceCode.getFirstToken(blockBody[0], { skip: 1 }))) {
                            messageId = "unexpectedObjectBlock";
                        }
                        else {
                            messageId = "unexpectedSingleBlock";
                        }
                        context.report({
                            node,
                            loc: arrowBody.loc,
                            messageId,
                            fix(fixer) {
                                const fixes = [];
                                if (blockBody.length !== 1 ||
                                    blockBody[0].type !== "ReturnStatement" ||
                                    !blockBody[0].argument ||
                                    hasASIProblem(sourceCode.getTokenAfter(arrowBody))) {
                                    return fixes;
                                }
                                const openingBrace = sourceCode.getFirstToken(arrowBody);
                                const closingBrace = sourceCode.getLastToken(arrowBody);
                                const firstValueToken = sourceCode.getFirstToken(blockBody[0], 1);
                                const lastValueToken = sourceCode.getLastToken(blockBody[0]);
                                const commentsExist = sourceCode.commentsExistBetween(openingBrace, firstValueToken) ||
                                    sourceCode.commentsExistBetween(lastValueToken, closingBrace);
                                /*
                                 * Remove tokens around the return value.
                                 * If comments don't exist, remove extra spaces as well.
                                 */
                                if (commentsExist) {
                                    fixes.push(fixer.remove(openingBrace), fixer.remove(closingBrace), fixer.remove(sourceCode.getTokenAfter(openingBrace)) // return keyword
                                    );
                                }
                                else {
                                    fixes.push(fixer.removeRange([openingBrace.range[0], firstValueToken.range[0]]), fixer.removeRange([lastValueToken.range[1], closingBrace.range[1]]));
                                }
                                /*
                                 * If the first token of the return value is `{` or the return value is a sequence expression,
                                 * enclose the return value by parentheses to avoid syntax error.
                                 */
                                if (astUtils.isOpeningBraceToken(firstValueToken) || blockBody[0].argument.type === "SequenceExpression" || (funcInfo.hasInOperator && isInsideForLoopInitializer(node))) {
                                    if (!astUtils.isParenthesised(sourceCode, blockBody[0].argument)) {
                                        fixes.push(fixer.insertTextBefore(firstValueToken, "("), fixer.insertTextAfter(lastValueToken, ")"));
                                    }
                                }
                                /*
                                 * If the last token of the return statement is semicolon, remove it.
                                 * Non-block arrow body is an expression, not a statement.
                                 */
                                if (astUtils.isSemicolonToken(lastValueToken)) {
                                    fixes.push(fixer.remove(lastValueToken));
                                }
                                return fixes;
                            }
                        });
                    }
                }
                else {
                    if (always || (asNeeded && requireReturnForObjectLiteral && arrowBody.type === "ObjectExpression")) {
                        context.report({
                            node,
                            loc: arrowBody.loc,
                            messageId: "expectedBlock",
                            fix(fixer) {
                                const fixes = [];
                                const arrowToken = sourceCode.getTokenBefore(arrowBody, astUtils.isArrowToken);
                                const [firstTokenAfterArrow, secondTokenAfterArrow] = sourceCode.getTokensAfter(arrowToken, { count: 2 });
                                const lastToken = sourceCode.getLastToken(node);
                                let parenthesisedObjectLiteral = null;
                                if (astUtils.isOpeningParenToken(firstTokenAfterArrow) &&
                                    astUtils.isOpeningBraceToken(secondTokenAfterArrow)) {
                                    const braceNode = sourceCode.getNodeByRangeIndex(secondTokenAfterArrow.range[0]);
                                    if (braceNode.type === "ObjectExpression") {
                                        parenthesisedObjectLiteral = braceNode;
                                    }
                                }
                                // If the value is object literal, remove parentheses which were forced by syntax.
                                if (parenthesisedObjectLiteral) {
                                    const openingParenToken = firstTokenAfterArrow;
                                    const openingBraceToken = secondTokenAfterArrow;
                                    if (astUtils.isTokenOnSameLine(openingParenToken, openingBraceToken)) {
                                        fixes.push(fixer.replaceText(openingParenToken, "{return "));
                                    }
                                    else {
                                        // Avoid ASI
                                        fixes.push(fixer.replaceText(openingParenToken, "{"), fixer.insertTextBefore(openingBraceToken, "return "));
                                    }
                                    // Closing paren for the object doesn't have to be lastToken, e.g.: () => ({}).foo()
                                    fixes.push(fixer.remove(findClosingParen(parenthesisedObjectLiteral)));
                                    fixes.push(fixer.insertTextAfter(lastToken, "}"));
                                }
                                else {
                                    fixes.push(fixer.insertTextBefore(firstTokenAfterArrow, "{return "));
                                    fixes.push(fixer.insertTextAfter(lastToken, "}"));
                                }
                                return fixes;
                            }
                        });
                    }
                }
            }
            return {
                "BinaryExpression[operator='in']"() {
                    let info = funcInfo;
                    while (info) {
                        info.hasInOperator = true;
                        info = info.upper;
                    }
                },
                ArrowFunctionExpression() {
                    funcInfo = {
                        upper: funcInfo,
                        hasInOperator: false
                    };
                },
                "ArrowFunctionExpression:exit"(node) {
                    validate(node);
                    funcInfo = funcInfo.upper;
                }
            };
        }
    };
},
/* eslint/lib/rules/arrow-parens.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to require parens in arrow function arguments.
     * @author Jxck
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Determines if the given arrow function has block body.
     * @param {ASTNode} node `ArrowFunctionExpression` node.
     * @returns {boolean} `true` if the function has block body.
     */
    function hasBlockBody(node) {
        return node.body.type === "BlockStatement";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require parentheses around arrow function arguments",
                recommended: false,
                url: "https://eslint.org/docs/rules/arrow-parens"
            },
            fixable: "code",
            schema: [
                {
                    enum: ["always", "as-needed"]
                },
                {
                    type: "object",
                    properties: {
                        requireForBlockBody: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedParens: "Unexpected parentheses around single function argument.",
                expectedParens: "Expected parentheses around arrow function argument.",
                unexpectedParensInline: "Unexpected parentheses around single function argument having a body with no curly braces.",
                expectedParensBlock: "Expected parentheses around arrow function argument having a body with curly braces."
            }
        },
        create(context) {
            const asNeeded = context.options[0] === "as-needed";
            const requireForBlockBody = asNeeded && context.options[1] && context.options[1].requireForBlockBody === true;
            const sourceCode = context.getSourceCode();
            /**
             * Finds opening paren of parameters for the given arrow function, if it exists.
             * It is assumed that the given arrow function has exactly one parameter.
             * @param {ASTNode} node `ArrowFunctionExpression` node.
             * @returns {Token|null} the opening paren, or `null` if the given arrow function doesn't have parens of parameters.
             */
            function findOpeningParenOfParams(node) {
                const tokenBeforeParams = sourceCode.getTokenBefore(node.params[0]);
                if (tokenBeforeParams &&
                    astUtils.isOpeningParenToken(tokenBeforeParams) &&
                    node.range[0] <= tokenBeforeParams.range[0]) {
                    return tokenBeforeParams;
                }
                return null;
            }
            /**
             * Finds closing paren of parameters for the given arrow function.
             * It is assumed that the given arrow function has parens of parameters and that it has exactly one parameter.
             * @param {ASTNode} node `ArrowFunctionExpression` node.
             * @returns {Token} the closing paren of parameters.
             */
            function getClosingParenOfParams(node) {
                return sourceCode.getTokenAfter(node.params[0], astUtils.isClosingParenToken);
            }
            /**
             * Determines whether the given arrow function has comments inside parens of parameters.
             * It is assumed that the given arrow function has parens of parameters.
             * @param {ASTNode} node `ArrowFunctionExpression` node.
             * @param {Token} openingParen Opening paren of parameters.
             * @returns {boolean} `true` if the function has at least one comment inside of parens of parameters.
             */
            function hasCommentsInParensOfParams(node, openingParen) {
                return sourceCode.commentsExistBetween(openingParen, getClosingParenOfParams(node));
            }
            /**
             * Determines whether the given arrow function has unexpected tokens before opening paren of parameters,
             * in which case it will be assumed that the existing parens of parameters are necessary.
             * Only tokens within the range of the arrow function (tokens that are part of the arrow function) are taken into account.
             * Example: <T>(a) => b
             * @param {ASTNode} node `ArrowFunctionExpression` node.
             * @param {Token} openingParen Opening paren of parameters.
             * @returns {boolean} `true` if the function has at least one unexpected token.
             */
            function hasUnexpectedTokensBeforeOpeningParen(node, openingParen) {
                const expectedCount = node.async ? 1 : 0;
                return sourceCode.getFirstToken(node, { skip: expectedCount }) !== openingParen;
            }
            return {
                "ArrowFunctionExpression[params.length=1]"(node) {
                    const shouldHaveParens = !asNeeded || requireForBlockBody && hasBlockBody(node);
                    const openingParen = findOpeningParenOfParams(node);
                    const hasParens = openingParen !== null;
                    const [param] = node.params;
                    if (shouldHaveParens && !hasParens) {
                        context.report({
                            node,
                            messageId: requireForBlockBody ? "expectedParensBlock" : "expectedParens",
                            loc: param.loc,
                            *fix(fixer) {
                                yield fixer.insertTextBefore(param, "(");
                                yield fixer.insertTextAfter(param, ")");
                            }
                        });
                    }
                    if (!shouldHaveParens &&
                        hasParens &&
                        param.type === "Identifier" &&
                        !param.typeAnnotation &&
                        !node.returnType &&
                        !hasCommentsInParensOfParams(node, openingParen) &&
                        !hasUnexpectedTokensBeforeOpeningParen(node, openingParen)) {
                        context.report({
                            node,
                            messageId: requireForBlockBody ? "unexpectedParensInline" : "unexpectedParens",
                            loc: param.loc,
                            *fix(fixer) {
                                const tokenBeforeOpeningParen = sourceCode.getTokenBefore(openingParen);
                                const closingParen = getClosingParenOfParams(node);
                                if (tokenBeforeOpeningParen &&
                                    tokenBeforeOpeningParen.range[1] === openingParen.range[0] &&
                                    !astUtils.canTokensBeAdjacent(tokenBeforeOpeningParen, sourceCode.getFirstToken(param))) {
                                    yield fixer.insertTextBefore(openingParen, " ");
                                }
                                // remove parens, whitespace inside parens, and possible trailing comma
                                yield fixer.removeRange([openingParen.range[0], param.range[0]]);
                                yield fixer.removeRange([param.range[1], closingParen.range[1]]);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/arrow-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to define spacing before/after arrow function's arrow.
     * @author Jxck
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing before and after the arrow in arrow functions",
                recommended: false,
                url: "https://eslint.org/docs/rules/arrow-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        before: {
                            type: "boolean",
                            default: true
                        },
                        after: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                expectedBefore: "Missing space before =>.",
                unexpectedBefore: "Unexpected space before =>.",
                expectedAfter: "Missing space after =>.",
                unexpectedAfter: "Unexpected space after =>."
            }
        },
        create(context) {
            // merge rules with default
            const rule = Object.assign({}, context.options[0]);
            rule.before = rule.before !== false;
            rule.after = rule.after !== false;
            const sourceCode = context.getSourceCode();
            /**
             * Get tokens of arrow(`=>`) and before/after arrow.
             * @param {ASTNode} node The arrow function node.
             * @returns {Object} Tokens of arrow and before/after arrow.
             */
            function getTokens(node) {
                const arrow = sourceCode.getTokenBefore(node.body, astUtils.isArrowToken);
                return {
                    before: sourceCode.getTokenBefore(arrow),
                    arrow,
                    after: sourceCode.getTokenAfter(arrow)
                };
            }
            /**
             * Count spaces before/after arrow(`=>`) token.
             * @param {Object} tokens Tokens before/after arrow.
             * @returns {Object} count of space before/after arrow.
             */
            function countSpaces(tokens) {
                const before = tokens.arrow.range[0] - tokens.before.range[1];
                const after = tokens.after.range[0] - tokens.arrow.range[1];
                return { before, after };
            }
            /**
             * Determines whether space(s) before after arrow(`=>`) is satisfy rule.
             * if before/after value is `true`, there should be space(s).
             * if before/after value is `false`, there should be no space.
             * @param {ASTNode} node The arrow function node.
             * @returns {void}
             */
            function spaces(node) {
                const tokens = getTokens(node);
                const countSpace = countSpaces(tokens);
                if (rule.before) {
                    // should be space(s) before arrow
                    if (countSpace.before === 0) {
                        context.report({
                            node: tokens.before,
                            messageId: "expectedBefore",
                            fix(fixer) {
                                return fixer.insertTextBefore(tokens.arrow, " ");
                            }
                        });
                    }
                }
                else {
                    // should be no space before arrow
                    if (countSpace.before > 0) {
                        context.report({
                            node: tokens.before,
                            messageId: "unexpectedBefore",
                            fix(fixer) {
                                return fixer.removeRange([tokens.before.range[1], tokens.arrow.range[0]]);
                            }
                        });
                    }
                }
                if (rule.after) {
                    // should be space(s) after arrow
                    if (countSpace.after === 0) {
                        context.report({
                            node: tokens.after,
                            messageId: "expectedAfter",
                            fix(fixer) {
                                return fixer.insertTextAfter(tokens.arrow, " ");
                            }
                        });
                    }
                }
                else {
                    // should be no space after arrow
                    if (countSpace.after > 0) {
                        context.report({
                            node: tokens.after,
                            messageId: "unexpectedAfter",
                            fix(fixer) {
                                return fixer.removeRange([tokens.arrow.range[1], tokens.after.range[0]]);
                            }
                        });
                    }
                }
            }
            return {
                ArrowFunctionExpression: spaces
            };
        }
    };
},
/* eslint/lib/rules/block-scoped-var.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to check for "block scoped" variables by binding context
     * @author Matt DuVall <http://www.mattduvall.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce the use of variables within the scope they are defined",
                recommended: false,
                url: "https://eslint.org/docs/rules/block-scoped-var"
            },
            schema: [],
            messages: {
                outOfScope: "'{{name}}' used outside of binding context."
            }
        },
        create(context) {
            let stack = [];
            /**
             * Makes a block scope.
             * @param {ASTNode} node A node of a scope.
             * @returns {void}
             */
            function enterScope(node) {
                stack.push(node.range);
            }
            /**
             * Pops the last block scope.
             * @returns {void}
             */
            function exitScope() {
                stack.pop();
            }
            /**
             * Reports a given reference.
             * @param {eslint-scope.Reference} reference A reference to report.
             * @returns {void}
             */
            function report(reference) {
                const identifier = reference.identifier;
                context.report({ node: identifier, messageId: "outOfScope", data: { name: identifier.name } });
            }
            /**
             * Finds and reports references which are outside of valid scopes.
             * @param {ASTNode} node A node to get variables.
             * @returns {void}
             */
            function checkForVariables(node) {
                if (node.kind !== "var") {
                    return;
                }
                // Defines a predicate to check whether or not a given reference is outside of valid scope.
                const scopeRange = stack[stack.length - 1];
                /**
                 * Check if a reference is out of scope
                 * @param {ASTNode} reference node to examine
                 * @returns {boolean} True is its outside the scope
                 * @private
                 */
                function isOutsideOfScope(reference) {
                    const idRange = reference.identifier.range;
                    return idRange[0] < scopeRange[0] || idRange[1] > scopeRange[1];
                }
                // Gets declared variables, and checks its references.
                const variables = context.getDeclaredVariables(node);
                for (let i = 0; i < variables.length; ++i) {
                    // Reports.
                    variables[i]
                        .references
                        .filter(isOutsideOfScope)
                        .forEach(report);
                }
            }
            return {
                Program(node) {
                    stack = [node.range];
                },
                // Manages scopes.
                BlockStatement: enterScope,
                "BlockStatement:exit": exitScope,
                ForStatement: enterScope,
                "ForStatement:exit": exitScope,
                ForInStatement: enterScope,
                "ForInStatement:exit": exitScope,
                ForOfStatement: enterScope,
                "ForOfStatement:exit": exitScope,
                SwitchStatement: enterScope,
                "SwitchStatement:exit": exitScope,
                CatchClause: enterScope,
                "CatchClause:exit": exitScope,
                StaticBlock: enterScope,
                "StaticBlock:exit": exitScope,
                // Finds and reports references which are outside of valid scope.
                VariableDeclaration: checkForVariables
            };
        }
    };
},
/* eslint/lib/rules/block-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow or enforce spaces inside of single line blocks.
     * @author Toru Nagashima
     */
    "use strict";
    const util = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Disallow or enforce spaces inside of blocks after opening block and before closing block",
                recommended: false,
                url: "https://eslint.org/docs/rules/block-spacing"
            },
            fixable: "whitespace",
            schema: [
                { enum: ["always", "never"] }
            ],
            messages: {
                missing: "Requires a space {{location}} '{{token}}'.",
                extra: "Unexpected space(s) {{location}} '{{token}}'."
            }
        },
        create(context) {
            const always = (context.options[0] !== "never"), messageId = always ? "missing" : "extra", sourceCode = context.getSourceCode();
            /**
             * Gets the open brace token from a given node.
             * @param {ASTNode} node A BlockStatement/StaticBlock/SwitchStatement node to get.
             * @returns {Token} The token of the open brace.
             */
            function getOpenBrace(node) {
                if (node.type === "SwitchStatement") {
                    if (node.cases.length > 0) {
                        return sourceCode.getTokenBefore(node.cases[0]);
                    }
                    return sourceCode.getLastToken(node, 1);
                }
                if (node.type === "StaticBlock") {
                    return sourceCode.getFirstToken(node, { skip: 1 }); // skip the `static` token
                }
                // "BlockStatement"
                return sourceCode.getFirstToken(node);
            }
            /**
             * Checks whether or not:
             *   - given tokens are on same line.
             *   - there is/isn't a space between given tokens.
             * @param {Token} left A token to check.
             * @param {Token} right The token which is next to `left`.
             * @returns {boolean}
             *    When the option is `"always"`, `true` if there are one or more spaces between given tokens.
             *    When the option is `"never"`, `true` if there are not any spaces between given tokens.
             *    If given tokens are not on same line, it's always `true`.
             */
            function isValid(left, right) {
                return (!util.isTokenOnSameLine(left, right) ||
                    sourceCode.isSpaceBetweenTokens(left, right) === always);
            }
            /**
             * Checks and reports invalid spacing style inside braces.
             * @param {ASTNode} node A BlockStatement/StaticBlock/SwitchStatement node to check.
             * @returns {void}
             */
            function checkSpacingInsideBraces(node) {
                // Gets braces and the first/last token of content.
                const openBrace = getOpenBrace(node);
                const closeBrace = sourceCode.getLastToken(node);
                const firstToken = sourceCode.getTokenAfter(openBrace, { includeComments: true });
                const lastToken = sourceCode.getTokenBefore(closeBrace, { includeComments: true });
                // Skip if the node is invalid or empty.
                if (openBrace.type !== "Punctuator" ||
                    openBrace.value !== "{" ||
                    closeBrace.type !== "Punctuator" ||
                    closeBrace.value !== "}" ||
                    firstToken === closeBrace) {
                    return;
                }
                // Skip line comments for option never
                if (!always && firstToken.type === "Line") {
                    return;
                }
                // Check.
                if (!isValid(openBrace, firstToken)) {
                    let loc = openBrace.loc;
                    if (messageId === "extra") {
                        loc = {
                            start: openBrace.loc.end,
                            end: firstToken.loc.start
                        };
                    }
                    context.report({
                        node,
                        loc,
                        messageId,
                        data: {
                            location: "after",
                            token: openBrace.value
                        },
                        fix(fixer) {
                            if (always) {
                                return fixer.insertTextBefore(firstToken, " ");
                            }
                            return fixer.removeRange([openBrace.range[1], firstToken.range[0]]);
                        }
                    });
                }
                if (!isValid(lastToken, closeBrace)) {
                    let loc = closeBrace.loc;
                    if (messageId === "extra") {
                        loc = {
                            start: lastToken.loc.end,
                            end: closeBrace.loc.start
                        };
                    }
                    context.report({
                        node,
                        loc,
                        messageId,
                        data: {
                            location: "before",
                            token: closeBrace.value
                        },
                        fix(fixer) {
                            if (always) {
                                return fixer.insertTextAfter(lastToken, " ");
                            }
                            return fixer.removeRange([lastToken.range[1], closeBrace.range[0]]);
                        }
                    });
                }
            }
            return {
                BlockStatement: checkSpacingInsideBraces,
                StaticBlock: checkSpacingInsideBraces,
                SwitchStatement: checkSpacingInsideBraces
            };
        }
    };
},
/* eslint/lib/rules/brace-style.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag block statements that do not use the one true brace style
     * @author Ian Christian Myers
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent brace style for blocks",
                recommended: false,
                url: "https://eslint.org/docs/rules/brace-style"
            },
            schema: [
                {
                    enum: ["1tbs", "stroustrup", "allman"]
                },
                {
                    type: "object",
                    properties: {
                        allowSingleLine: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "whitespace",
            messages: {
                nextLineOpen: "Opening curly brace does not appear on the same line as controlling statement.",
                sameLineOpen: "Opening curly brace appears on the same line as controlling statement.",
                blockSameLine: "Statement inside of curly braces should be on next line.",
                nextLineClose: "Closing curly brace does not appear on the same line as the subsequent block.",
                singleLineClose: "Closing curly brace should be on the same line as opening curly brace or on the line after the previous block.",
                sameLineClose: "Closing curly brace appears on the same line as the subsequent block."
            }
        },
        create(context) {
            const style = context.options[0] || "1tbs", params = context.options[1] || {}, sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Fixes a place where a newline unexpectedly appears
             * @param {Token} firstToken The token before the unexpected newline
             * @param {Token} secondToken The token after the unexpected newline
             * @returns {Function} A fixer function to remove the newlines between the tokens
             */
            function removeNewlineBetween(firstToken, secondToken) {
                const textRange = [firstToken.range[1], secondToken.range[0]];
                const textBetween = sourceCode.text.slice(textRange[0], textRange[1]);
                // Don't do a fix if there is a comment between the tokens
                if (textBetween.trim()) {
                    return null;
                }
                return fixer => fixer.replaceTextRange(textRange, " ");
            }
            /**
             * Validates a pair of curly brackets based on the user's config
             * @param {Token} openingCurly The opening curly bracket
             * @param {Token} closingCurly The closing curly bracket
             * @returns {void}
             */
            function validateCurlyPair(openingCurly, closingCurly) {
                const tokenBeforeOpeningCurly = sourceCode.getTokenBefore(openingCurly);
                const tokenAfterOpeningCurly = sourceCode.getTokenAfter(openingCurly);
                const tokenBeforeClosingCurly = sourceCode.getTokenBefore(closingCurly);
                const singleLineException = params.allowSingleLine && astUtils.isTokenOnSameLine(openingCurly, closingCurly);
                if (style !== "allman" && !astUtils.isTokenOnSameLine(tokenBeforeOpeningCurly, openingCurly)) {
                    context.report({
                        node: openingCurly,
                        messageId: "nextLineOpen",
                        fix: removeNewlineBetween(tokenBeforeOpeningCurly, openingCurly)
                    });
                }
                if (style === "allman" && astUtils.isTokenOnSameLine(tokenBeforeOpeningCurly, openingCurly) && !singleLineException) {
                    context.report({
                        node: openingCurly,
                        messageId: "sameLineOpen",
                        fix: fixer => fixer.insertTextBefore(openingCurly, "\n")
                    });
                }
                if (astUtils.isTokenOnSameLine(openingCurly, tokenAfterOpeningCurly) && tokenAfterOpeningCurly !== closingCurly && !singleLineException) {
                    context.report({
                        node: openingCurly,
                        messageId: "blockSameLine",
                        fix: fixer => fixer.insertTextAfter(openingCurly, "\n")
                    });
                }
                if (tokenBeforeClosingCurly !== openingCurly && !singleLineException && astUtils.isTokenOnSameLine(tokenBeforeClosingCurly, closingCurly)) {
                    context.report({
                        node: closingCurly,
                        messageId: "singleLineClose",
                        fix: fixer => fixer.insertTextBefore(closingCurly, "\n")
                    });
                }
            }
            /**
             * Validates the location of a token that appears before a keyword (e.g. a newline before `else`)
             * @param {Token} curlyToken The closing curly token. This is assumed to precede a keyword token (such as `else` or `finally`).
             * @returns {void}
             */
            function validateCurlyBeforeKeyword(curlyToken) {
                const keywordToken = sourceCode.getTokenAfter(curlyToken);
                if (style === "1tbs" && !astUtils.isTokenOnSameLine(curlyToken, keywordToken)) {
                    context.report({
                        node: curlyToken,
                        messageId: "nextLineClose",
                        fix: removeNewlineBetween(curlyToken, keywordToken)
                    });
                }
                if (style !== "1tbs" && astUtils.isTokenOnSameLine(curlyToken, keywordToken)) {
                    context.report({
                        node: curlyToken,
                        messageId: "sameLineClose",
                        fix: fixer => fixer.insertTextAfter(curlyToken, "\n")
                    });
                }
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                BlockStatement(node) {
                    if (!astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type)) {
                        validateCurlyPair(sourceCode.getFirstToken(node), sourceCode.getLastToken(node));
                    }
                },
                StaticBlock(node) {
                    validateCurlyPair(sourceCode.getFirstToken(node, { skip: 1 }), // skip the `static` token
                    sourceCode.getLastToken(node));
                },
                ClassBody(node) {
                    validateCurlyPair(sourceCode.getFirstToken(node), sourceCode.getLastToken(node));
                },
                SwitchStatement(node) {
                    const closingCurly = sourceCode.getLastToken(node);
                    const openingCurly = sourceCode.getTokenBefore(node.cases.length ? node.cases[0] : closingCurly);
                    validateCurlyPair(openingCurly, closingCurly);
                },
                IfStatement(node) {
                    if (node.consequent.type === "BlockStatement" && node.alternate) {
                        // Handle the keyword after the `if` block (before `else`)
                        validateCurlyBeforeKeyword(sourceCode.getLastToken(node.consequent));
                    }
                },
                TryStatement(node) {
                    // Handle the keyword after the `try` block (before `catch` or `finally`)
                    validateCurlyBeforeKeyword(sourceCode.getLastToken(node.block));
                    if (node.handler && node.finalizer) {
                        // Handle the keyword after the `catch` block (before `finally`)
                        validateCurlyBeforeKeyword(sourceCode.getLastToken(node.handler.body));
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/callback-return.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Enforce return after a callback.
     * @author Jamund Ferguson
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Require `return` statements after callbacks",
                recommended: false,
                url: "https://eslint.org/docs/rules/callback-return"
            },
            schema: [{
                    type: "array",
                    items: { type: "string" }
                }],
            messages: {
                missingReturn: "Expected return with your callback function."
            }
        },
        create(context) {
            const callbacks = context.options[0] || ["callback", "cb", "next"], sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Find the closest parent matching a list of types.
             * @param {ASTNode} node The node whose parents we are searching
             * @param {Array} types The node types to match
             * @returns {ASTNode} The matched node or undefined.
             */
            function findClosestParentOfType(node, types) {
                if (!node.parent) {
                    return null;
                }
                if (!types.includes(node.parent.type)) {
                    return findClosestParentOfType(node.parent, types);
                }
                return node.parent;
            }
            /**
             * Check to see if a node contains only identifiers
             * @param {ASTNode} node The node to check
             * @returns {boolean} Whether or not the node contains only identifiers
             */
            function containsOnlyIdentifiers(node) {
                if (node.type === "Identifier") {
                    return true;
                }
                if (node.type === "MemberExpression") {
                    if (node.object.type === "Identifier") {
                        return true;
                    }
                    if (node.object.type === "MemberExpression") {
                        return containsOnlyIdentifiers(node.object);
                    }
                }
                return false;
            }
            /**
             * Check to see if a CallExpression is in our callback list.
             * @param {ASTNode} node The node to check against our callback names list.
             * @returns {boolean} Whether or not this function matches our callback name.
             */
            function isCallback(node) {
                return containsOnlyIdentifiers(node.callee) && callbacks.includes(sourceCode.getText(node.callee));
            }
            /**
             * Determines whether or not the callback is part of a callback expression.
             * @param {ASTNode} node The callback node
             * @param {ASTNode} parentNode The expression node
             * @returns {boolean} Whether or not this is part of a callback expression
             */
            function isCallbackExpression(node, parentNode) {
                // ensure the parent node exists and is an expression
                if (!parentNode || parentNode.type !== "ExpressionStatement") {
                    return false;
                }
                // cb()
                if (parentNode.expression === node) {
                    return true;
                }
                // special case for cb && cb() and similar
                if (parentNode.expression.type === "BinaryExpression" || parentNode.expression.type === "LogicalExpression") {
                    if (parentNode.expression.right === node) {
                        return true;
                    }
                }
                return false;
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                CallExpression(node) {
                    // if we're not a callback we can return
                    if (!isCallback(node)) {
                        return;
                    }
                    // find the closest block, return or loop
                    const closestBlock = findClosestParentOfType(node, ["BlockStatement", "ReturnStatement", "ArrowFunctionExpression"]) || {};
                    // if our parent is a return we know we're ok
                    if (closestBlock.type === "ReturnStatement") {
                        return;
                    }
                    // arrow functions don't always have blocks and implicitly return
                    if (closestBlock.type === "ArrowFunctionExpression") {
                        return;
                    }
                    // block statements are part of functions and most if statements
                    if (closestBlock.type === "BlockStatement") {
                        // find the last item in the block
                        const lastItem = closestBlock.body[closestBlock.body.length - 1];
                        // if the callback is the last thing in a block that might be ok
                        if (isCallbackExpression(node, lastItem)) {
                            const parentType = closestBlock.parent.type;
                            // but only if the block is part of a function
                            if (parentType === "FunctionExpression" ||
                                parentType === "FunctionDeclaration" ||
                                parentType === "ArrowFunctionExpression") {
                                return;
                            }
                        }
                        // ending a block with a return is also ok
                        if (lastItem.type === "ReturnStatement") {
                            // but only if the callback is immediately before
                            if (isCallbackExpression(node, closestBlock.body[closestBlock.body.length - 2])) {
                                return;
                            }
                        }
                    }
                    // as long as you're the child of a function at this point you should be asked to return
                    if (findClosestParentOfType(node, ["FunctionDeclaration", "FunctionExpression", "ArrowFunctionExpression"])) {
                        context.report({ node, messageId: "missingReturn" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/camelcase.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag non-camelcased identifiers
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce camelcase naming convention",
                recommended: false,
                url: "https://eslint.org/docs/rules/camelcase"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        ignoreDestructuring: {
                            type: "boolean",
                            default: false
                        },
                        ignoreImports: {
                            type: "boolean",
                            default: false
                        },
                        ignoreGlobals: {
                            type: "boolean",
                            default: false
                        },
                        properties: {
                            enum: ["always", "never"]
                        },
                        allow: {
                            type: "array",
                            items: [
                                {
                                    type: "string"
                                }
                            ],
                            minItems: 0,
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                notCamelCase: "Identifier '{{name}}' is not in camel case.",
                notCamelCasePrivate: "#{{name}} is not in camel case."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const properties = options.properties === "never" ? "never" : "always";
            const ignoreDestructuring = options.ignoreDestructuring;
            const ignoreImports = options.ignoreImports;
            const ignoreGlobals = options.ignoreGlobals;
            const allow = options.allow || [];
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            // contains reported nodes to avoid reporting twice on destructuring with shorthand notation
            const reported = new Set();
            /**
             * Checks if a string contains an underscore and isn't all upper-case
             * @param {string} name The string to check.
             * @returns {boolean} if the string is underscored
             * @private
             */
            function isUnderscored(name) {
                const nameBody = name.replace(/^_+|_+$/gu, "");
                // if there's an underscore, it might be A_CONSTANT, which is okay
                return nameBody.includes("_") && nameBody !== nameBody.toUpperCase();
            }
            /**
             * Checks if a string match the ignore list
             * @param {string} name The string to check.
             * @returns {boolean} if the string is ignored
             * @private
             */
            function isAllowed(name) {
                return allow.some(entry => name === entry || name.match(new RegExp(entry, "u")));
            }
            /**
             * Checks if a given name is good or not.
             * @param {string} name The name to check.
             * @returns {boolean} `true` if the name is good.
             * @private
             */
            function isGoodName(name) {
                return !isUnderscored(name) || isAllowed(name);
            }
            /**
             * Checks if a given identifier reference or member expression is an assignment
             * target.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} `true` if the node is an assignment target.
             */
            function isAssignmentTarget(node) {
                const parent = node.parent;
                switch (parent.type) {
                    case "AssignmentExpression":
                    case "AssignmentPattern":
                        return parent.left === node;
                    case "Property":
                        return (parent.parent.type === "ObjectPattern" &&
                            parent.value === node);
                    case "ArrayPattern":
                    case "RestElement":
                        return true;
                    default:
                        return false;
                }
            }
            /**
             * Checks if a given binding identifier uses the original name as-is.
             * - If it's in object destructuring or object expression, the original name is its property name.
             * - If it's in import declaration, the original name is its exported name.
             * @param {ASTNode} node The `Identifier` node to check.
             * @returns {boolean} `true` if the identifier uses the original name as-is.
             */
            function equalsToOriginalName(node) {
                const localName = node.name;
                const valueNode = node.parent.type === "AssignmentPattern"
                    ? node.parent
                    : node;
                const parent = valueNode.parent;
                switch (parent.type) {
                    case "Property":
                        return ((parent.parent.type === "ObjectPattern" || parent.parent.type === "ObjectExpression") &&
                            parent.value === valueNode &&
                            !parent.computed &&
                            parent.key.type === "Identifier" &&
                            parent.key.name === localName);
                    case "ImportSpecifier":
                        return (parent.local === node &&
                            astUtils.getModuleExportName(parent.imported) === localName);
                    default:
                        return false;
                }
            }
            /**
             * Reports an AST node as a rule violation.
             * @param {ASTNode} node The node to report.
             * @returns {void}
             * @private
             */
            function report(node) {
                if (reported.has(node.range[0])) {
                    return;
                }
                reported.add(node.range[0]);
                // Report it.
                context.report({
                    node,
                    messageId: node.type === "PrivateIdentifier"
                        ? "notCamelCasePrivate"
                        : "notCamelCase",
                    data: { name: node.name }
                });
            }
            /**
             * Reports an identifier reference or a binding identifier.
             * @param {ASTNode} node The `Identifier` node to report.
             * @returns {void}
             */
            function reportReferenceId(node) {
                /*
                 * For backward compatibility, if it's in callings then ignore it.
                 * Not sure why it is.
                 */
                if (node.parent.type === "CallExpression" ||
                    node.parent.type === "NewExpression") {
                    return;
                }
                /*
                 * For backward compatibility, if it's a default value of
                 * destructuring/parameters then ignore it.
                 * Not sure why it is.
                 */
                if (node.parent.type === "AssignmentPattern" &&
                    node.parent.right === node) {
                    return;
                }
                /*
                 * The `ignoreDestructuring` flag skips the identifiers that uses
                 * the property name as-is.
                 */
                if (ignoreDestructuring && equalsToOriginalName(node)) {
                    return;
                }
                report(node);
            }
            return {
                // Report camelcase of global variable references ------------------
                Program() {
                    const scope = context.getScope();
                    if (!ignoreGlobals) {
                        // Defined globals in config files or directive comments.
                        for (const variable of scope.variables) {
                            if (variable.identifiers.length > 0 ||
                                isGoodName(variable.name)) {
                                continue;
                            }
                            for (const reference of variable.references) {
                                /*
                                 * For backward compatibility, this rule reports read-only
                                 * references as well.
                                 */
                                reportReferenceId(reference.identifier);
                            }
                        }
                    }
                    // Undefined globals.
                    for (const reference of scope.through) {
                        const id = reference.identifier;
                        if (isGoodName(id.name)) {
                            continue;
                        }
                        /*
                         * For backward compatibility, this rule reports read-only
                         * references as well.
                         */
                        reportReferenceId(id);
                    }
                },
                // Report camelcase of declared variables --------------------------
                [[
                    "VariableDeclaration",
                    "FunctionDeclaration",
                    "FunctionExpression",
                    "ArrowFunctionExpression",
                    "ClassDeclaration",
                    "ClassExpression",
                    "CatchClause"
                ]](node) {
                    for (const variable of context.getDeclaredVariables(node)) {
                        if (isGoodName(variable.name)) {
                            continue;
                        }
                        const id = variable.identifiers[0];
                        // Report declaration.
                        if (!(ignoreDestructuring && equalsToOriginalName(id))) {
                            report(id);
                        }
                        /*
                         * For backward compatibility, report references as well.
                         * It looks unnecessary because declarations are reported.
                         */
                        for (const reference of variable.references) {
                            if (reference.init) {
                                continue; // Skip the write references of initializers.
                            }
                            reportReferenceId(reference.identifier);
                        }
                    }
                },
                // Report camelcase in properties ----------------------------------
                [[
                    "ObjectExpression > Property[computed!=true] > Identifier.key",
                    "MethodDefinition[computed!=true] > Identifier.key",
                    "PropertyDefinition[computed!=true] > Identifier.key",
                    "MethodDefinition > PrivateIdentifier.key",
                    "PropertyDefinition > PrivateIdentifier.key"
                ]](node) {
                    if (properties === "never" || isGoodName(node.name)) {
                        return;
                    }
                    report(node);
                },
                "MemberExpression[computed!=true] > Identifier.property"(node) {
                    if (properties === "never" ||
                        !isAssignmentTarget(node.parent) || // ← ignore read-only references.
                        isGoodName(node.name)) {
                        return;
                    }
                    report(node);
                },
                // Report camelcase in import --------------------------------------
                ImportDeclaration(node) {
                    for (const variable of context.getDeclaredVariables(node)) {
                        if (isGoodName(variable.name)) {
                            continue;
                        }
                        const id = variable.identifiers[0];
                        // Report declaration.
                        if (!(ignoreImports && equalsToOriginalName(id))) {
                            report(id);
                        }
                        /*
                         * For backward compatibility, report references as well.
                         * It looks unnecessary because declarations are reported.
                         */
                        for (const reference of variable.references) {
                            reportReferenceId(reference.identifier);
                        }
                    }
                },
                // Report camelcase in re-export -----------------------------------
                [[
                    "ExportAllDeclaration > Identifier.exported",
                    "ExportSpecifier > Identifier.exported"
                ]](node) {
                    if (isGoodName(node.name)) {
                        return;
                    }
                    report(node);
                },
                // Report camelcase in labels --------------------------------------
                [[
                    "LabeledStatement > Identifier.label",
                    /*
                     * For backward compatibility, report references as well.
                     * It looks unnecessary because declarations are reported.
                     */
                    "BreakStatement > Identifier.label",
                    "ContinueStatement > Identifier.label"
                ]](node) {
                    if (isGoodName(node.name)) {
                        return;
                    }
                    report(node);
                }
            };
        }
    };
},
/* eslint/lib/rules/capitalized-comments.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview enforce or disallow capitalization of the first letter of a comment
     * @author Kevin Partington
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const LETTER_PATTERN = require(378) /* ./utils/patterns/letters */;
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const DEFAULT_IGNORE_PATTERN = astUtils.COMMENTS_IGNORE_PATTERN, WHITESPACE = /\s/gu, MAYBE_URL = /^\s*[^:/?#\s]+:\/\/[^?#]/u; // TODO: Combine w/ max-len pattern?
    /*
     * Base schema body for defining the basic capitalization rule, ignorePattern,
     * and ignoreInlineComments values.
     * This can be used in a few different ways in the actual schema.
     */
    const SCHEMA_BODY = {
        type: "object",
        properties: {
            ignorePattern: {
                type: "string"
            },
            ignoreInlineComments: {
                type: "boolean"
            },
            ignoreConsecutiveComments: {
                type: "boolean"
            }
        },
        additionalProperties: false
    };
    const DEFAULTS = {
        ignorePattern: "",
        ignoreInlineComments: false,
        ignoreConsecutiveComments: false
    };
    /**
     * Get normalized options for either block or line comments from the given
     * user-provided options.
     * - If the user-provided options is just a string, returns a normalized
     *   set of options using default values for all other options.
     * - If the user-provided options is an object, then a normalized option
     *   set is returned. Options specified in overrides will take priority
     *   over options specified in the main options object, which will in
     *   turn take priority over the rule's defaults.
     * @param {Object|string} rawOptions The user-provided options.
     * @param {string} which Either "line" or "block".
     * @returns {Object} The normalized options.
     */
    function getNormalizedOptions(rawOptions, which) {
        return Object.assign({}, DEFAULTS, rawOptions[which] || rawOptions);
    }
    /**
     * Get normalized options for block and line comments.
     * @param {Object|string} rawOptions The user-provided options.
     * @returns {Object} An object with "Line" and "Block" keys and corresponding
     * normalized options objects.
     */
    function getAllNormalizedOptions(rawOptions = {}) {
        return {
            Line: getNormalizedOptions(rawOptions, "line"),
            Block: getNormalizedOptions(rawOptions, "block")
        };
    }
    /**
     * Creates a regular expression for each ignorePattern defined in the rule
     * options.
     *
     * This is done in order to avoid invoking the RegExp constructor repeatedly.
     * @param {Object} normalizedOptions The normalized rule options.
     * @returns {void}
     */
    function createRegExpForIgnorePatterns(normalizedOptions) {
        Object.keys(normalizedOptions).forEach(key => {
            const ignorePatternStr = normalizedOptions[key].ignorePattern;
            if (ignorePatternStr) {
                const regExp = RegExp(`^\\s*(?:${ignorePatternStr})`, "u");
                normalizedOptions[key].ignorePatternRegExp = regExp;
            }
        });
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce or disallow capitalization of the first letter of a comment",
                recommended: false,
                url: "https://eslint.org/docs/rules/capitalized-comments"
            },
            fixable: "code",
            schema: [
                { enum: ["always", "never"] },
                {
                    oneOf: [
                        SCHEMA_BODY,
                        {
                            type: "object",
                            properties: {
                                line: SCHEMA_BODY,
                                block: SCHEMA_BODY
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                unexpectedLowercaseComment: "Comments should not begin with a lowercase character.",
                unexpectedUppercaseComment: "Comments should not begin with an uppercase character."
            }
        },
        create(context) {
            const capitalize = context.options[0] || "always", normalizedOptions = getAllNormalizedOptions(context.options[1]), sourceCode = context.getSourceCode();
            createRegExpForIgnorePatterns(normalizedOptions);
            //----------------------------------------------------------------------
            // Helpers
            //----------------------------------------------------------------------
            /**
             * Checks whether a comment is an inline comment.
             *
             * For the purpose of this rule, a comment is inline if:
             * 1. The comment is preceded by a token on the same line; and
             * 2. The command is followed by a token on the same line.
             *
             * Note that the comment itself need not be single-line!
             *
             * Also, it follows from this definition that only block comments can
             * be considered as possibly inline. This is because line comments
             * would consume any following tokens on the same line as the comment.
             * @param {ASTNode} comment The comment node to check.
             * @returns {boolean} True if the comment is an inline comment, false
             * otherwise.
             */
            function isInlineComment(comment) {
                const previousToken = sourceCode.getTokenBefore(comment, { includeComments: true }), nextToken = sourceCode.getTokenAfter(comment, { includeComments: true });
                return Boolean(previousToken &&
                    nextToken &&
                    comment.loc.start.line === previousToken.loc.end.line &&
                    comment.loc.end.line === nextToken.loc.start.line);
            }
            /**
             * Determine if a comment follows another comment.
             * @param {ASTNode} comment The comment to check.
             * @returns {boolean} True if the comment follows a valid comment.
             */
            function isConsecutiveComment(comment) {
                const previousTokenOrComment = sourceCode.getTokenBefore(comment, { includeComments: true });
                return Boolean(previousTokenOrComment &&
                    ["Block", "Line"].includes(previousTokenOrComment.type));
            }
            /**
             * Check a comment to determine if it is valid for this rule.
             * @param {ASTNode} comment The comment node to process.
             * @param {Object} options The options for checking this comment.
             * @returns {boolean} True if the comment is valid, false otherwise.
             */
            function isCommentValid(comment, options) {
                // 1. Check for default ignore pattern.
                if (DEFAULT_IGNORE_PATTERN.test(comment.value)) {
                    return true;
                }
                // 2. Check for custom ignore pattern.
                const commentWithoutAsterisks = comment.value
                    .replace(/\*/gu, "");
                if (options.ignorePatternRegExp && options.ignorePatternRegExp.test(commentWithoutAsterisks)) {
                    return true;
                }
                // 3. Check for inline comments.
                if (options.ignoreInlineComments && isInlineComment(comment)) {
                    return true;
                }
                // 4. Is this a consecutive comment (and are we tolerating those)?
                if (options.ignoreConsecutiveComments && isConsecutiveComment(comment)) {
                    return true;
                }
                // 5. Does the comment start with a possible URL?
                if (MAYBE_URL.test(commentWithoutAsterisks)) {
                    return true;
                }
                // 6. Is the initial word character a letter?
                const commentWordCharsOnly = commentWithoutAsterisks
                    .replace(WHITESPACE, "");
                if (commentWordCharsOnly.length === 0) {
                    return true;
                }
                const firstWordChar = commentWordCharsOnly[0];
                if (!LETTER_PATTERN.test(firstWordChar)) {
                    return true;
                }
                // 7. Check the case of the initial word character.
                const isUppercase = firstWordChar !== firstWordChar.toLocaleLowerCase(), isLowercase = firstWordChar !== firstWordChar.toLocaleUpperCase();
                if (capitalize === "always" && isLowercase) {
                    return false;
                }
                if (capitalize === "never" && isUppercase) {
                    return false;
                }
                return true;
            }
            /**
             * Process a comment to determine if it needs to be reported.
             * @param {ASTNode} comment The comment node to process.
             * @returns {void}
             */
            function processComment(comment) {
                const options = normalizedOptions[comment.type], commentValid = isCommentValid(comment, options);
                if (!commentValid) {
                    const messageId = capitalize === "always"
                        ? "unexpectedLowercaseComment"
                        : "unexpectedUppercaseComment";
                    context.report({
                        node: null,
                        loc: comment.loc,
                        messageId,
                        fix(fixer) {
                            const match = comment.value.match(LETTER_PATTERN);
                            return fixer.replaceTextRange(
                            // Offset match.index by 2 to account for the first 2 characters that start the comment (// or /*)
                            [comment.range[0] + match.index + 2, comment.range[0] + match.index + 3], capitalize === "always" ? match[0].toLocaleUpperCase() : match[0].toLocaleLowerCase());
                        }
                    });
                }
            }
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                Program() {
                    const comments = sourceCode.getAllComments();
                    comments.filter(token => token.type !== "Shebang").forEach(processComment);
                }
            };
        }
    };
},
/* eslint/lib/rules/utils/patterns/letters.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Pattern for detecting any letter (even letters outside of ASCII).
     * NOTE: This file was generated using this script in JSCS based on the Unicode 7.0.0 standard: https://github.com/jscs-dev/node-jscs/blob/f5ed14427deb7e7aac84f3056a5aab2d9f3e563e/publish/helpers/generate-patterns.js
     * Do not edit this file by hand-- please use https://github.com/mathiasbynens/regenerate to regenerate the regular expression exported from this file.
     * @author Kevin Partington
     * @license MIT License (from JSCS). See below.
     */
    /*
     * The MIT License (MIT)
     *
     * Copyright 2013-2016 Dulin Marat and other contributors
     *
     * Permission is hereby granted, free of charge, to any person obtaining
     * a copy of this software and associated documentation files (the
     * "Software"), to deal in the Software without restriction, including
     * without limitation the rights to use, copy, modify, merge, publish,
     * distribute, sublicense, and/or sell copies of the Software, and to
     * permit persons to whom the Software is furnished to do so, subject to
     * the following conditions:
     *
     * The above copyright notice and this permission notice shall be
     * included in all copies or substantial portions of the Software.
     *
     * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
     * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
     * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
     * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
     * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
     * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
     * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
     */
    "use strict";
    module.exports = /[A-Za-z\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B2\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16F1-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA7AD\uA7B0\uA7B1\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB5F\uAB64\uAB65\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF40\uDF42-\uDF49\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF]|\uD801[\uDC00-\uDC9D\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDE00-\uDE11\uDE13-\uDE2B\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF5D-\uDF61]|\uD805[\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDE00-\uDE2F\uDE44\uDE80-\uDEAA]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF98]|[\uD80C\uD840-\uD868\uD86A-\uD86C][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D]|\uD87E[\uDC00-\uDE1D]/u;
},
/* eslint/lib/rules/class-methods-use-this.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce that all class methods use 'this'.
     * @author Patrick Williams
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce that class methods utilize `this`",
                recommended: false,
                url: "https://eslint.org/docs/rules/class-methods-use-this"
            },
            schema: [{
                    type: "object",
                    properties: {
                        exceptMethods: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        },
                        enforceForClassFields: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                missingThis: "Expected 'this' to be used by class {{name}}."
            }
        },
        create(context) {
            const config = Object.assign({}, context.options[0]);
            const enforceForClassFields = config.enforceForClassFields !== false;
            const exceptMethods = new Set(config.exceptMethods || []);
            const stack = [];
            /**
             * Push `this` used flag initialized with `false` onto the stack.
             * @returns {void}
             */
            function pushContext() {
                stack.push(false);
            }
            /**
             * Pop `this` used flag from the stack.
             * @returns {boolean | undefined} `this` used flag
             */
            function popContext() {
                return stack.pop();
            }
            /**
             * Initializes the current context to false and pushes it onto the stack.
             * These booleans represent whether 'this' has been used in the context.
             * @returns {void}
             * @private
             */
            function enterFunction() {
                pushContext();
            }
            /**
             * Check if the node is an instance method
             * @param {ASTNode} node node to check
             * @returns {boolean} True if its an instance method
             * @private
             */
            function isInstanceMethod(node) {
                switch (node.type) {
                    case "MethodDefinition":
                        return !node.static && node.kind !== "constructor";
                    case "PropertyDefinition":
                        return !node.static && enforceForClassFields;
                    default:
                        return false;
                }
            }
            /**
             * Check if the node is an instance method not excluded by config
             * @param {ASTNode} node node to check
             * @returns {boolean} True if it is an instance method, and not excluded by config
             * @private
             */
            function isIncludedInstanceMethod(node) {
                if (isInstanceMethod(node)) {
                    if (node.computed) {
                        return true;
                    }
                    const hashIfNeeded = node.key.type === "PrivateIdentifier" ? "#" : "";
                    const name = node.key.type === "Literal"
                        ? astUtils.getStaticStringValue(node.key)
                        : (node.key.name || "");
                    return !exceptMethods.has(hashIfNeeded + name);
                }
                return false;
            }
            /**
             * Checks if we are leaving a function that is a method, and reports if 'this' has not been used.
             * Static methods and the constructor are exempt.
             * Then pops the context off the stack.
             * @param {ASTNode} node A function node that was entered.
             * @returns {void}
             * @private
             */
            function exitFunction(node) {
                const methodUsesThis = popContext();
                if (isIncludedInstanceMethod(node.parent) && !methodUsesThis) {
                    context.report({
                        node,
                        loc: astUtils.getFunctionHeadLoc(node, context.getSourceCode()),
                        messageId: "missingThis",
                        data: {
                            name: astUtils.getFunctionNameWithKind(node)
                        }
                    });
                }
            }
            /**
             * Mark the current context as having used 'this'.
             * @returns {void}
             * @private
             */
            function markThisUsed() {
                if (stack.length) {
                    stack[stack.length - 1] = true;
                }
            }
            return {
                FunctionDeclaration: enterFunction,
                "FunctionDeclaration:exit": exitFunction,
                FunctionExpression: enterFunction,
                "FunctionExpression:exit": exitFunction,
                /*
                 * Class field value are implicit functions.
                 */
                "PropertyDefinition > *.key:exit": pushContext,
                "PropertyDefinition:exit": popContext,
                /*
                 * Class static blocks are implicit functions. They aren't required to use `this`,
                 * but we have to push context so that it captures any use of `this` in the static block
                 * separately from enclosing contexts, because static blocks have their own `this` and it
                 * shouldn't count as used `this` in enclosing contexts.
                 */
                StaticBlock: pushContext,
                "StaticBlock:exit": popContext,
                ThisExpression: markThisUsed,
                Super: markThisUsed,
                ...(enforceForClassFields && {
                    "PropertyDefinition > ArrowFunctionExpression.value": enterFunction,
                    "PropertyDefinition > ArrowFunctionExpression.value:exit": exitFunction
                })
            };
        }
    };
},
/* eslint/lib/rules/comma-dangle.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to forbid or enforce dangling commas.
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const DEFAULT_OPTIONS = Object.freeze({
        arrays: "never",
        objects: "never",
        imports: "never",
        exports: "never",
        functions: "never"
    });
    /**
     * Checks whether or not a trailing comma is allowed in a given node.
     * If the `lastItem` is `RestElement` or `RestProperty`, it disallows trailing commas.
     * @param {ASTNode} lastItem The node of the last element in the given node.
     * @returns {boolean} `true` if a trailing comma is allowed.
     */
    function isTrailingCommaAllowed(lastItem) {
        return !(lastItem.type === "RestElement" ||
            lastItem.type === "RestProperty" ||
            lastItem.type === "ExperimentalRestProperty");
    }
    /**
     * Normalize option value.
     * @param {string|Object|undefined} optionValue The 1st option value to normalize.
     * @param {number} ecmaVersion The normalized ECMAScript version.
     * @returns {Object} The normalized option value.
     */
    function normalizeOptions(optionValue, ecmaVersion) {
        if (typeof optionValue === "string") {
            return {
                arrays: optionValue,
                objects: optionValue,
                imports: optionValue,
                exports: optionValue,
                functions: ecmaVersion < 2017 ? "ignore" : optionValue
            };
        }
        if (typeof optionValue === "object" && optionValue !== null) {
            return {
                arrays: optionValue.arrays || DEFAULT_OPTIONS.arrays,
                objects: optionValue.objects || DEFAULT_OPTIONS.objects,
                imports: optionValue.imports || DEFAULT_OPTIONS.imports,
                exports: optionValue.exports || DEFAULT_OPTIONS.exports,
                functions: optionValue.functions || DEFAULT_OPTIONS.functions
            };
        }
        return DEFAULT_OPTIONS;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow trailing commas",
                recommended: false,
                url: "https://eslint.org/docs/rules/comma-dangle"
            },
            fixable: "code",
            schema: {
                definitions: {
                    value: {
                        enum: [
                            "always-multiline",
                            "always",
                            "never",
                            "only-multiline"
                        ]
                    },
                    valueWithIgnore: {
                        enum: [
                            "always-multiline",
                            "always",
                            "ignore",
                            "never",
                            "only-multiline"
                        ]
                    }
                },
                type: "array",
                items: [
                    {
                        oneOf: [
                            {
                                $ref: "#/definitions/value"
                            },
                            {
                                type: "object",
                                properties: {
                                    arrays: { $ref: "#/definitions/valueWithIgnore" },
                                    objects: { $ref: "#/definitions/valueWithIgnore" },
                                    imports: { $ref: "#/definitions/valueWithIgnore" },
                                    exports: { $ref: "#/definitions/valueWithIgnore" },
                                    functions: { $ref: "#/definitions/valueWithIgnore" }
                                },
                                additionalProperties: false
                            }
                        ]
                    }
                ],
                additionalItems: false
            },
            messages: {
                unexpected: "Unexpected trailing comma.",
                missing: "Missing trailing comma."
            }
        },
        create(context) {
            const options = normalizeOptions(context.options[0], context.languageOptions.ecmaVersion);
            const sourceCode = context.getSourceCode();
            /**
             * Gets the last item of the given node.
             * @param {ASTNode} node The node to get.
             * @returns {ASTNode|null} The last node or null.
             */
            function getLastItem(node) {
                /**
                 * Returns the last element of an array
                 * @param {any[]} array The input array
                 * @returns {any} The last element
                 */
                function last(array) {
                    return array[array.length - 1];
                }
                switch (node.type) {
                    case "ObjectExpression":
                    case "ObjectPattern":
                        return last(node.properties);
                    case "ArrayExpression":
                    case "ArrayPattern":
                        return last(node.elements);
                    case "ImportDeclaration":
                    case "ExportNamedDeclaration":
                        return last(node.specifiers);
                    case "FunctionDeclaration":
                    case "FunctionExpression":
                    case "ArrowFunctionExpression":
                        return last(node.params);
                    case "CallExpression":
                    case "NewExpression":
                        return last(node.arguments);
                    default:
                        return null;
                }
            }
            /**
             * Gets the trailing comma token of the given node.
             * If the trailing comma does not exist, this returns the token which is
             * the insertion point of the trailing comma token.
             * @param {ASTNode} node The node to get.
             * @param {ASTNode} lastItem The last item of the node.
             * @returns {Token} The trailing comma token or the insertion point.
             */
            function getTrailingToken(node, lastItem) {
                switch (node.type) {
                    case "ObjectExpression":
                    case "ArrayExpression":
                    case "CallExpression":
                    case "NewExpression":
                        return sourceCode.getLastToken(node, 1);
                    default: {
                        const nextToken = sourceCode.getTokenAfter(lastItem);
                        if (astUtils.isCommaToken(nextToken)) {
                            return nextToken;
                        }
                        return sourceCode.getLastToken(lastItem);
                    }
                }
            }
            /**
             * Checks whether or not a given node is multiline.
             * This rule handles a given node as multiline when the closing parenthesis
             * and the last element are not on the same line.
             * @param {ASTNode} node A node to check.
             * @returns {boolean} `true` if the node is multiline.
             */
            function isMultiline(node) {
                const lastItem = getLastItem(node);
                if (!lastItem) {
                    return false;
                }
                const penultimateToken = getTrailingToken(node, lastItem);
                const lastToken = sourceCode.getTokenAfter(penultimateToken);
                return lastToken.loc.end.line !== penultimateToken.loc.end.line;
            }
            /**
             * Reports a trailing comma if it exists.
             * @param {ASTNode} node A node to check. Its type is one of
             *   ObjectExpression, ObjectPattern, ArrayExpression, ArrayPattern,
             *   ImportDeclaration, and ExportNamedDeclaration.
             * @returns {void}
             */
            function forbidTrailingComma(node) {
                const lastItem = getLastItem(node);
                if (!lastItem || (node.type === "ImportDeclaration" && lastItem.type !== "ImportSpecifier")) {
                    return;
                }
                const trailingToken = getTrailingToken(node, lastItem);
                if (astUtils.isCommaToken(trailingToken)) {
                    context.report({
                        node: lastItem,
                        loc: trailingToken.loc,
                        messageId: "unexpected",
                        *fix(fixer) {
                            yield fixer.remove(trailingToken);
                            /*
                             * Extend the range of the fix to include surrounding tokens to ensure
                             * that the element after which the comma is removed stays _last_.
                             * This intentionally makes conflicts in fix ranges with rules that may be
                             * adding or removing elements in the same autofix pass.
                             * https://github.com/eslint/eslint/issues/15660
                             */
                            yield fixer.insertTextBefore(sourceCode.getTokenBefore(trailingToken), "");
                            yield fixer.insertTextAfter(sourceCode.getTokenAfter(trailingToken), "");
                        }
                    });
                }
            }
            /**
             * Reports the last element of a given node if it does not have a trailing
             * comma.
             *
             * If a given node is `ArrayPattern` which has `RestElement`, the trailing
             * comma is disallowed, so report if it exists.
             * @param {ASTNode} node A node to check. Its type is one of
             *   ObjectExpression, ObjectPattern, ArrayExpression, ArrayPattern,
             *   ImportDeclaration, and ExportNamedDeclaration.
             * @returns {void}
             */
            function forceTrailingComma(node) {
                const lastItem = getLastItem(node);
                if (!lastItem || (node.type === "ImportDeclaration" && lastItem.type !== "ImportSpecifier")) {
                    return;
                }
                if (!isTrailingCommaAllowed(lastItem)) {
                    forbidTrailingComma(node);
                    return;
                }
                const trailingToken = getTrailingToken(node, lastItem);
                if (trailingToken.value !== ",") {
                    context.report({
                        node: lastItem,
                        loc: {
                            start: trailingToken.loc.end,
                            end: astUtils.getNextLocation(sourceCode, trailingToken.loc.end)
                        },
                        messageId: "missing",
                        *fix(fixer) {
                            yield fixer.insertTextAfter(trailingToken, ",");
                            /*
                             * Extend the range of the fix to include surrounding tokens to ensure
                             * that the element after which the comma is inserted stays _last_.
                             * This intentionally makes conflicts in fix ranges with rules that may be
                             * adding or removing elements in the same autofix pass.
                             * https://github.com/eslint/eslint/issues/15660
                             */
                            yield fixer.insertTextBefore(trailingToken, "");
                            yield fixer.insertTextAfter(sourceCode.getTokenAfter(trailingToken), "");
                        }
                    });
                }
            }
            /**
             * If a given node is multiline, reports the last element of a given node
             * when it does not have a trailing comma.
             * Otherwise, reports a trailing comma if it exists.
             * @param {ASTNode} node A node to check. Its type is one of
             *   ObjectExpression, ObjectPattern, ArrayExpression, ArrayPattern,
             *   ImportDeclaration, and ExportNamedDeclaration.
             * @returns {void}
             */
            function forceTrailingCommaIfMultiline(node) {
                if (isMultiline(node)) {
                    forceTrailingComma(node);
                }
                else {
                    forbidTrailingComma(node);
                }
            }
            /**
             * Only if a given node is not multiline, reports the last element of a given node
             * when it does not have a trailing comma.
             * Otherwise, reports a trailing comma if it exists.
             * @param {ASTNode} node A node to check. Its type is one of
             *   ObjectExpression, ObjectPattern, ArrayExpression, ArrayPattern,
             *   ImportDeclaration, and ExportNamedDeclaration.
             * @returns {void}
             */
            function allowTrailingCommaIfMultiline(node) {
                if (!isMultiline(node)) {
                    forbidTrailingComma(node);
                }
            }
            const predicate = {
                always: forceTrailingComma,
                "always-multiline": forceTrailingCommaIfMultiline,
                "only-multiline": allowTrailingCommaIfMultiline,
                never: forbidTrailingComma,
                ignore() { }
            };
            return {
                ObjectExpression: predicate[options.objects],
                ObjectPattern: predicate[options.objects],
                ArrayExpression: predicate[options.arrays],
                ArrayPattern: predicate[options.arrays],
                ImportDeclaration: predicate[options.imports],
                ExportNamedDeclaration: predicate[options.exports],
                FunctionDeclaration: predicate[options.functions],
                FunctionExpression: predicate[options.functions],
                ArrowFunctionExpression: predicate[options.functions],
                CallExpression: predicate[options.functions],
                NewExpression: predicate[options.functions]
            };
        }
    };
},
/* eslint/lib/rules/comma-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Comma spacing - validates spacing before and after comma
     * @author Vignesh Anand aka vegetableman.
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing before and after commas",
                recommended: false,
                url: "https://eslint.org/docs/rules/comma-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        before: {
                            type: "boolean",
                            default: false
                        },
                        after: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                missing: "A space is required {{loc}} ','.",
                unexpected: "There should be no space {{loc}} ','."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const tokensAndComments = sourceCode.tokensAndComments;
            const options = {
                before: context.options[0] ? context.options[0].before : false,
                after: context.options[0] ? context.options[0].after : true
            };
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            // list of comma tokens to ignore for the check of leading whitespace
            const commaTokensToIgnore = [];
            /**
             * Reports a spacing error with an appropriate message.
             * @param {ASTNode} node The binary expression node to report.
             * @param {string} loc Is the error "before" or "after" the comma?
             * @param {ASTNode} otherNode The node at the left or right of `node`
             * @returns {void}
             * @private
             */
            function report(node, loc, otherNode) {
                context.report({
                    node,
                    fix(fixer) {
                        if (options[loc]) {
                            if (loc === "before") {
                                return fixer.insertTextBefore(node, " ");
                            }
                            return fixer.insertTextAfter(node, " ");
                        }
                        let start, end;
                        const newText = "";
                        if (loc === "before") {
                            start = otherNode.range[1];
                            end = node.range[0];
                        }
                        else {
                            start = node.range[1];
                            end = otherNode.range[0];
                        }
                        return fixer.replaceTextRange([start, end], newText);
                    },
                    messageId: options[loc] ? "missing" : "unexpected",
                    data: {
                        loc
                    }
                });
            }
            /**
             * Adds null elements of the given ArrayExpression or ArrayPattern node to the ignore list.
             * @param {ASTNode} node An ArrayExpression or ArrayPattern node.
             * @returns {void}
             */
            function addNullElementsToIgnoreList(node) {
                let previousToken = sourceCode.getFirstToken(node);
                node.elements.forEach(element => {
                    let token;
                    if (element === null) {
                        token = sourceCode.getTokenAfter(previousToken);
                        if (astUtils.isCommaToken(token)) {
                            commaTokensToIgnore.push(token);
                        }
                    }
                    else {
                        token = sourceCode.getTokenAfter(element);
                    }
                    previousToken = token;
                });
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                "Program:exit"() {
                    tokensAndComments.forEach((token, i) => {
                        if (!astUtils.isCommaToken(token)) {
                            return;
                        }
                        const previousToken = tokensAndComments[i - 1];
                        const nextToken = tokensAndComments[i + 1];
                        if (previousToken &&
                            !astUtils.isCommaToken(previousToken) && // ignore spacing between two commas
                            /*
                             * `commaTokensToIgnore` are ending commas of `null` elements (array holes/elisions).
                             * In addition to spacing between two commas, this can also ignore:
                             *
                             *   - Spacing after `[` (controlled by array-bracket-spacing)
                             *       Example: [ , ]
                             *                 ^
                             *   - Spacing after a comment (for backwards compatibility, this was possibly unintentional)
                             *       Example: [a, /* * / ,]
                             *                          ^
                             */
                            !commaTokensToIgnore.includes(token) &&
                            astUtils.isTokenOnSameLine(previousToken, token) &&
                            options.before !== sourceCode.isSpaceBetweenTokens(previousToken, token)) {
                            report(token, "before", previousToken);
                        }
                        if (nextToken &&
                            !astUtils.isCommaToken(nextToken) && // ignore spacing between two commas
                            !astUtils.isClosingParenToken(nextToken) && // controlled by space-in-parens
                            !astUtils.isClosingBracketToken(nextToken) && // controlled by array-bracket-spacing
                            !astUtils.isClosingBraceToken(nextToken) && // controlled by object-curly-spacing
                            !(!options.after && nextToken.type === "Line") && // special case, allow space before line comment
                            astUtils.isTokenOnSameLine(token, nextToken) &&
                            options.after !== sourceCode.isSpaceBetweenTokens(token, nextToken)) {
                            report(token, "after", nextToken);
                        }
                    });
                },
                ArrayExpression: addNullElementsToIgnoreList,
                ArrayPattern: addNullElementsToIgnoreList
            };
        }
    };
},
/* eslint/lib/rules/comma-style.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Comma style - enforces comma styles of two types: last and first
     * @author Vignesh Anand aka vegetableman
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent comma style",
                recommended: false,
                url: "https://eslint.org/docs/rules/comma-style"
            },
            fixable: "code",
            schema: [
                {
                    enum: ["first", "last"]
                },
                {
                    type: "object",
                    properties: {
                        exceptions: {
                            type: "object",
                            additionalProperties: {
                                type: "boolean"
                            }
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedLineBeforeAndAfterComma: "Bad line breaking before and after ','.",
                expectedCommaFirst: "',' should be placed first.",
                expectedCommaLast: "',' should be placed last."
            }
        },
        create(context) {
            const style = context.options[0] || "last", sourceCode = context.getSourceCode();
            const exceptions = {
                ArrayPattern: true,
                ArrowFunctionExpression: true,
                CallExpression: true,
                FunctionDeclaration: true,
                FunctionExpression: true,
                ImportDeclaration: true,
                ObjectPattern: true,
                NewExpression: true
            };
            if (context.options.length === 2 && Object.prototype.hasOwnProperty.call(context.options[1], "exceptions")) {
                const keys = Object.keys(context.options[1].exceptions);
                for (let i = 0; i < keys.length; i++) {
                    exceptions[keys[i]] = context.options[1].exceptions[keys[i]];
                }
            }
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Modified text based on the style
             * @param {string} styleType Style type
             * @param {string} text Source code text
             * @returns {string} modified text
             * @private
             */
            function getReplacedText(styleType, text) {
                switch (styleType) {
                    case "between":
                        return `,${text.replace(astUtils.LINEBREAK_MATCHER, "")}`;
                    case "first":
                        return `${text},`;
                    case "last":
                        return `,${text}`;
                    default:
                        return "";
                }
            }
            /**
             * Determines the fixer function for a given style.
             * @param {string} styleType comma style
             * @param {ASTNode} previousItemToken The token to check.
             * @param {ASTNode} commaToken The token to check.
             * @param {ASTNode} currentItemToken The token to check.
             * @returns {Function} Fixer function
             * @private
             */
            function getFixerFunction(styleType, previousItemToken, commaToken, currentItemToken) {
                const text = sourceCode.text.slice(previousItemToken.range[1], commaToken.range[0]) +
                    sourceCode.text.slice(commaToken.range[1], currentItemToken.range[0]);
                const range = [previousItemToken.range[1], currentItemToken.range[0]];
                return function (fixer) {
                    return fixer.replaceTextRange(range, getReplacedText(styleType, text));
                };
            }
            /**
             * Validates the spacing around single items in lists.
             * @param {Token} previousItemToken The last token from the previous item.
             * @param {Token} commaToken The token representing the comma.
             * @param {Token} currentItemToken The first token of the current item.
             * @param {Token} reportItem The item to use when reporting an error.
             * @returns {void}
             * @private
             */
            function validateCommaItemSpacing(previousItemToken, commaToken, currentItemToken, reportItem) {
                // if single line
                if (astUtils.isTokenOnSameLine(commaToken, currentItemToken) &&
                    astUtils.isTokenOnSameLine(previousItemToken, commaToken)) {
                    // do nothing.
                }
                else if (!astUtils.isTokenOnSameLine(commaToken, currentItemToken) &&
                    !astUtils.isTokenOnSameLine(previousItemToken, commaToken)) {
                    const comment = sourceCode.getCommentsAfter(commaToken)[0];
                    const styleType = comment && comment.type === "Block" && astUtils.isTokenOnSameLine(commaToken, comment)
                        ? style
                        : "between";
                    // lone comma
                    context.report({
                        node: reportItem,
                        loc: commaToken.loc,
                        messageId: "unexpectedLineBeforeAndAfterComma",
                        fix: getFixerFunction(styleType, previousItemToken, commaToken, currentItemToken)
                    });
                }
                else if (style === "first" && !astUtils.isTokenOnSameLine(commaToken, currentItemToken)) {
                    context.report({
                        node: reportItem,
                        loc: commaToken.loc,
                        messageId: "expectedCommaFirst",
                        fix: getFixerFunction(style, previousItemToken, commaToken, currentItemToken)
                    });
                }
                else if (style === "last" && astUtils.isTokenOnSameLine(commaToken, currentItemToken)) {
                    context.report({
                        node: reportItem,
                        loc: commaToken.loc,
                        messageId: "expectedCommaLast",
                        fix: getFixerFunction(style, previousItemToken, commaToken, currentItemToken)
                    });
                }
            }
            /**
             * Checks the comma placement with regards to a declaration/property/element
             * @param {ASTNode} node The binary expression node to check
             * @param {string} property The property of the node containing child nodes.
             * @private
             * @returns {void}
             */
            function validateComma(node, property) {
                const items = node[property], arrayLiteral = (node.type === "ArrayExpression" || node.type === "ArrayPattern");
                if (items.length > 1 || arrayLiteral) {
                    // seed as opening [
                    let previousItemToken = sourceCode.getFirstToken(node);
                    items.forEach(item => {
                        const commaToken = item ? sourceCode.getTokenBefore(item) : previousItemToken, currentItemToken = item ? sourceCode.getFirstToken(item) : sourceCode.getTokenAfter(commaToken), reportItem = item || currentItemToken;
                        /*
                         * This works by comparing three token locations:
                         * - previousItemToken is the last token of the previous item
                         * - commaToken is the location of the comma before the current item
                         * - currentItemToken is the first token of the current item
                         *
                         * These values get switched around if item is undefined.
                         * previousItemToken will refer to the last token not belonging
                         * to the current item, which could be a comma or an opening
                         * square bracket. currentItemToken could be a comma.
                         *
                         * All comparisons are done based on these tokens directly, so
                         * they are always valid regardless of an undefined item.
                         */
                        if (astUtils.isCommaToken(commaToken)) {
                            validateCommaItemSpacing(previousItemToken, commaToken, currentItemToken, reportItem);
                        }
                        if (item) {
                            const tokenAfterItem = sourceCode.getTokenAfter(item, astUtils.isNotClosingParenToken);
                            previousItemToken = tokenAfterItem
                                ? sourceCode.getTokenBefore(tokenAfterItem)
                                : sourceCode.ast.tokens[sourceCode.ast.tokens.length - 1];
                        }
                        else {
                            previousItemToken = currentItemToken;
                        }
                    });
                    /*
                     * Special case for array literals that have empty last items, such
                     * as [ 1, 2, ]. These arrays only have two items show up in the
                     * AST, so we need to look at the token to verify that there's no
                     * dangling comma.
                     */
                    if (arrayLiteral) {
                        const lastToken = sourceCode.getLastToken(node), nextToLastToken = sourceCode.getTokenBefore(lastToken);
                        if (astUtils.isCommaToken(nextToLastToken)) {
                            validateCommaItemSpacing(sourceCode.getTokenBefore(nextToLastToken), nextToLastToken, lastToken, lastToken);
                        }
                    }
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            const nodes = {};
            if (!exceptions.VariableDeclaration) {
                nodes.VariableDeclaration = function (node) {
                    validateComma(node, "declarations");
                };
            }
            if (!exceptions.ObjectExpression) {
                nodes.ObjectExpression = function (node) {
                    validateComma(node, "properties");
                };
            }
            if (!exceptions.ObjectPattern) {
                nodes.ObjectPattern = function (node) {
                    validateComma(node, "properties");
                };
            }
            if (!exceptions.ArrayExpression) {
                nodes.ArrayExpression = function (node) {
                    validateComma(node, "elements");
                };
            }
            if (!exceptions.ArrayPattern) {
                nodes.ArrayPattern = function (node) {
                    validateComma(node, "elements");
                };
            }
            if (!exceptions.FunctionDeclaration) {
                nodes.FunctionDeclaration = function (node) {
                    validateComma(node, "params");
                };
            }
            if (!exceptions.FunctionExpression) {
                nodes.FunctionExpression = function (node) {
                    validateComma(node, "params");
                };
            }
            if (!exceptions.ArrowFunctionExpression) {
                nodes.ArrowFunctionExpression = function (node) {
                    validateComma(node, "params");
                };
            }
            if (!exceptions.CallExpression) {
                nodes.CallExpression = function (node) {
                    validateComma(node, "arguments");
                };
            }
            if (!exceptions.ImportDeclaration) {
                nodes.ImportDeclaration = function (node) {
                    validateComma(node, "specifiers");
                };
            }
            if (!exceptions.NewExpression) {
                nodes.NewExpression = function (node) {
                    validateComma(node, "arguments");
                };
            }
            return nodes;
        }
    };
},
/* eslint/lib/rules/complexity.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Counts the cyclomatic complexity of each function of the script. See http://en.wikipedia.org/wiki/Cyclomatic_complexity.
     * Counts the number of if, conditional, for, while, try, switch/case,
     * @author Patrick Brosset
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const { upperCaseFirst } = require(384) /* ../shared/string-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce a maximum cyclomatic complexity allowed in a program",
                recommended: false,
                url: "https://eslint.org/docs/rules/complexity"
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: "integer",
                            minimum: 0
                        },
                        {
                            type: "object",
                            properties: {
                                maximum: {
                                    type: "integer",
                                    minimum: 0
                                },
                                max: {
                                    type: "integer",
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                complex: "{{name}} has a complexity of {{complexity}}. Maximum allowed is {{max}}."
            }
        },
        create(context) {
            const option = context.options[0];
            let THRESHOLD = 20;
            if (typeof option === "object" &&
                (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
                THRESHOLD = option.maximum || option.max;
            }
            else if (typeof option === "number") {
                THRESHOLD = option;
            }
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            // Using a stack to store complexity per code path
            const complexities = [];
            /**
             * Increase the complexity of the code path in context
             * @returns {void}
             * @private
             */
            function increaseComplexity() {
                complexities[complexities.length - 1]++;
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                onCodePathStart() {
                    // The initial complexity is 1, representing one execution path in the CodePath
                    complexities.push(1);
                },
                // Each branching in the code adds 1 to the complexity
                CatchClause: increaseComplexity,
                ConditionalExpression: increaseComplexity,
                LogicalExpression: increaseComplexity,
                ForStatement: increaseComplexity,
                ForInStatement: increaseComplexity,
                ForOfStatement: increaseComplexity,
                IfStatement: increaseComplexity,
                WhileStatement: increaseComplexity,
                DoWhileStatement: increaseComplexity,
                // Avoid `default`
                "SwitchCase[test]": increaseComplexity,
                // Logical assignment operators have short-circuiting behavior
                AssignmentExpression(node) {
                    if (astUtils.isLogicalAssignmentOperator(node.operator)) {
                        increaseComplexity();
                    }
                },
                onCodePathEnd(codePath, node) {
                    const complexity = complexities.pop();
                    /*
                     * This rule only evaluates complexity of functions, so "program" is excluded.
                     * Class field initializers and class static blocks are implicit functions. Therefore,
                     * they shouldn't contribute to the enclosing function's complexity, but their
                     * own complexity should be evaluated.
                     */
                    if (codePath.origin !== "function" &&
                        codePath.origin !== "class-field-initializer" &&
                        codePath.origin !== "class-static-block") {
                        return;
                    }
                    if (complexity > THRESHOLD) {
                        let name;
                        if (codePath.origin === "class-field-initializer") {
                            name = "class field initializer";
                        }
                        else if (codePath.origin === "class-static-block") {
                            name = "class static block";
                        }
                        else {
                            name = astUtils.getFunctionNameWithKind(node);
                        }
                        context.report({
                            node,
                            messageId: "complex",
                            data: {
                                name: upperCaseFirst(name),
                                complexity,
                                max: THRESHOLD
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/shared/string-utils.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Utilities to operate on strings.
     * @author Stephen Wade
     */
    "use strict";
    /**
     * Converts the first letter of a string to uppercase.
     * @param {string} string The string to operate on
     * @returns {string} The converted string
     */
    function upperCaseFirst(string) {
        if (string.length <= 1) {
            return string.toUpperCase();
        }
        return string[0].toUpperCase() + string.slice(1);
    }
    module.exports = {
        upperCaseFirst
    };
},
/* eslint/lib/rules/computed-property-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallows or enforces spaces inside computed properties.
     * @author Jamund Ferguson
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing inside computed property brackets",
                recommended: false,
                url: "https://eslint.org/docs/rules/computed-property-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never"]
                },
                {
                    type: "object",
                    properties: {
                        enforceForClassMembers: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedSpaceBefore: "There should be no space before '{{tokenValue}}'.",
                unexpectedSpaceAfter: "There should be no space after '{{tokenValue}}'.",
                missingSpaceBefore: "A space is required before '{{tokenValue}}'.",
                missingSpaceAfter: "A space is required after '{{tokenValue}}'."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const propertyNameMustBeSpaced = context.options[0] === "always"; // default is "never"
            const enforceForClassMembers = !context.options[1] || context.options[1].enforceForClassMembers;
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Reports that there shouldn't be a space after the first token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @param {Token} tokenAfter The token after `token`.
             * @returns {void}
             */
            function reportNoBeginningSpace(node, token, tokenAfter) {
                context.report({
                    node,
                    loc: { start: token.loc.end, end: tokenAfter.loc.start },
                    messageId: "unexpectedSpaceAfter",
                    data: {
                        tokenValue: token.value
                    },
                    fix(fixer) {
                        return fixer.removeRange([token.range[1], tokenAfter.range[0]]);
                    }
                });
            }
            /**
             * Reports that there shouldn't be a space before the last token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @param {Token} tokenBefore The token before `token`.
             * @returns {void}
             */
            function reportNoEndingSpace(node, token, tokenBefore) {
                context.report({
                    node,
                    loc: { start: tokenBefore.loc.end, end: token.loc.start },
                    messageId: "unexpectedSpaceBefore",
                    data: {
                        tokenValue: token.value
                    },
                    fix(fixer) {
                        return fixer.removeRange([tokenBefore.range[1], token.range[0]]);
                    }
                });
            }
            /**
             * Reports that there should be a space after the first token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportRequiredBeginningSpace(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "missingSpaceAfter",
                    data: {
                        tokenValue: token.value
                    },
                    fix(fixer) {
                        return fixer.insertTextAfter(token, " ");
                    }
                });
            }
            /**
             * Reports that there should be a space before the last token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportRequiredEndingSpace(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "missingSpaceBefore",
                    data: {
                        tokenValue: token.value
                    },
                    fix(fixer) {
                        return fixer.insertTextBefore(token, " ");
                    }
                });
            }
            /**
             * Returns a function that checks the spacing of a node on the property name
             * that was passed in.
             * @param {string} propertyName The property on the node to check for spacing
             * @returns {Function} A function that will check spacing on a node
             */
            function checkSpacing(propertyName) {
                return function (node) {
                    if (!node.computed) {
                        return;
                    }
                    const property = node[propertyName];
                    const before = sourceCode.getTokenBefore(property, astUtils.isOpeningBracketToken), first = sourceCode.getTokenAfter(before, { includeComments: true }), after = sourceCode.getTokenAfter(property, astUtils.isClosingBracketToken), last = sourceCode.getTokenBefore(after, { includeComments: true });
                    if (astUtils.isTokenOnSameLine(before, first)) {
                        if (propertyNameMustBeSpaced) {
                            if (!sourceCode.isSpaceBetweenTokens(before, first) && astUtils.isTokenOnSameLine(before, first)) {
                                reportRequiredBeginningSpace(node, before);
                            }
                        }
                        else {
                            if (sourceCode.isSpaceBetweenTokens(before, first)) {
                                reportNoBeginningSpace(node, before, first);
                            }
                        }
                    }
                    if (astUtils.isTokenOnSameLine(last, after)) {
                        if (propertyNameMustBeSpaced) {
                            if (!sourceCode.isSpaceBetweenTokens(last, after) && astUtils.isTokenOnSameLine(last, after)) {
                                reportRequiredEndingSpace(node, after);
                            }
                        }
                        else {
                            if (sourceCode.isSpaceBetweenTokens(last, after)) {
                                reportNoEndingSpace(node, after, last);
                            }
                        }
                    }
                };
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            const listeners = {
                Property: checkSpacing("key"),
                MemberExpression: checkSpacing("property")
            };
            if (enforceForClassMembers) {
                listeners.MethodDefinition =
                    listeners.PropertyDefinition = listeners.Property;
            }
            return listeners;
        }
    };
},
/* eslint/lib/rules/consistent-return.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag consistent return values
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const { upperCaseFirst } = require(384) /* ../shared/string-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a given code path segment is unreachable.
     * @param {CodePathSegment} segment A CodePathSegment to check.
     * @returns {boolean} `true` if the segment is unreachable.
     */
    function isUnreachable(segment) {
        return !segment.reachable;
    }
    /**
     * Checks whether a given node is a `constructor` method in an ES6 class
     * @param {ASTNode} node A node to check
     * @returns {boolean} `true` if the node is a `constructor` method
     */
    function isClassConstructor(node) {
        return node.type === "FunctionExpression" &&
            node.parent &&
            node.parent.type === "MethodDefinition" &&
            node.parent.kind === "constructor";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require `return` statements to either always or never specify values",
                recommended: false,
                url: "https://eslint.org/docs/rules/consistent-return"
            },
            schema: [{
                    type: "object",
                    properties: {
                        treatUndefinedAsUnspecified: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                missingReturn: "Expected to return a value at the end of {{name}}.",
                missingReturnValue: "{{name}} expected a return value.",
                unexpectedReturnValue: "{{name}} expected no return value."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const treatUndefinedAsUnspecified = options.treatUndefinedAsUnspecified === true;
            let funcInfo = null;
            /**
             * Checks whether of not the implicit returning is consistent if the last
             * code path segment is reachable.
             * @param {ASTNode} node A program/function node to check.
             * @returns {void}
             */
            function checkLastSegment(node) {
                let loc, name;
                /*
                 * Skip if it expected no return value or unreachable.
                 * When unreachable, all paths are returned or thrown.
                 */
                if (!funcInfo.hasReturnValue ||
                    funcInfo.codePath.currentSegments.every(isUnreachable) ||
                    astUtils.isES5Constructor(node) ||
                    isClassConstructor(node)) {
                    return;
                }
                // Adjust a location and a message.
                if (node.type === "Program") {
                    // The head of program.
                    loc = { line: 1, column: 0 };
                    name = "program";
                }
                else if (node.type === "ArrowFunctionExpression") {
                    // `=>` token
                    loc = context.getSourceCode().getTokenBefore(node.body, astUtils.isArrowToken).loc;
                }
                else if (node.parent.type === "MethodDefinition" ||
                    (node.parent.type === "Property" && node.parent.method)) {
                    // Method name.
                    loc = node.parent.key.loc;
                }
                else {
                    // Function name or `function` keyword.
                    loc = (node.id || context.getSourceCode().getFirstToken(node)).loc;
                }
                if (!name) {
                    name = astUtils.getFunctionNameWithKind(node);
                }
                // Reports.
                context.report({
                    node,
                    loc,
                    messageId: "missingReturn",
                    data: { name }
                });
            }
            return {
                // Initializes/Disposes state of each code path.
                onCodePathStart(codePath, node) {
                    funcInfo = {
                        upper: funcInfo,
                        codePath,
                        hasReturn: false,
                        hasReturnValue: false,
                        messageId: "",
                        node
                    };
                },
                onCodePathEnd() {
                    funcInfo = funcInfo.upper;
                },
                // Reports a given return statement if it's inconsistent.
                ReturnStatement(node) {
                    const argument = node.argument;
                    let hasReturnValue = Boolean(argument);
                    if (treatUndefinedAsUnspecified && hasReturnValue) {
                        hasReturnValue = !astUtils.isSpecificId(argument, "undefined") && argument.operator !== "void";
                    }
                    if (!funcInfo.hasReturn) {
                        funcInfo.hasReturn = true;
                        funcInfo.hasReturnValue = hasReturnValue;
                        funcInfo.messageId = hasReturnValue ? "missingReturnValue" : "unexpectedReturnValue";
                        funcInfo.data = {
                            name: funcInfo.node.type === "Program"
                                ? "Program"
                                : upperCaseFirst(astUtils.getFunctionNameWithKind(funcInfo.node))
                        };
                    }
                    else if (funcInfo.hasReturnValue !== hasReturnValue) {
                        context.report({
                            node,
                            messageId: funcInfo.messageId,
                            data: funcInfo.data
                        });
                    }
                },
                // Reports a given program/function if the implicit returning is not consistent.
                "Program:exit": checkLastSegment,
                "FunctionDeclaration:exit": checkLastSegment,
                "FunctionExpression:exit": checkLastSegment,
                "ArrowFunctionExpression:exit": checkLastSegment
            };
        }
    };
},
/* eslint/lib/rules/consistent-this.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to enforce consistent naming of "this" context variables
     * @author Raphael Pigulla
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce consistent naming when capturing the current execution context",
                recommended: false,
                url: "https://eslint.org/docs/rules/consistent-this"
            },
            schema: {
                type: "array",
                items: {
                    type: "string",
                    minLength: 1
                },
                uniqueItems: true
            },
            messages: {
                aliasNotAssignedToThis: "Designated alias '{{name}}' is not assigned to 'this'.",
                unexpectedAlias: "Unexpected alias '{{name}}' for 'this'."
            }
        },
        create(context) {
            let aliases = [];
            if (context.options.length === 0) {
                aliases.push("that");
            }
            else {
                aliases = context.options;
            }
            /**
             * Reports that a variable declarator or assignment expression is assigning
             * a non-'this' value to the specified alias.
             * @param {ASTNode} node The assigning node.
             * @param {string} name the name of the alias that was incorrectly used.
             * @returns {void}
             */
            function reportBadAssignment(node, name) {
                context.report({ node, messageId: "aliasNotAssignedToThis", data: { name } });
            }
            /**
             * Checks that an assignment to an identifier only assigns 'this' to the
             * appropriate alias, and the alias is only assigned to 'this'.
             * @param {ASTNode} node The assigning node.
             * @param {Identifier} name The name of the variable assigned to.
             * @param {Expression} value The value of the assignment.
             * @returns {void}
             */
            function checkAssignment(node, name, value) {
                const isThis = value.type === "ThisExpression";
                if (aliases.includes(name)) {
                    if (!isThis || node.operator && node.operator !== "=") {
                        reportBadAssignment(node, name);
                    }
                }
                else if (isThis) {
                    context.report({ node, messageId: "unexpectedAlias", data: { name } });
                }
            }
            /**
             * Ensures that a variable declaration of the alias in a program or function
             * is assigned to the correct value.
             * @param {string} alias alias the check the assignment of.
             * @param {Object} scope scope of the current code we are checking.
             * @private
             * @returns {void}
             */
            function checkWasAssigned(alias, scope) {
                const variable = scope.set.get(alias);
                if (!variable) {
                    return;
                }
                if (variable.defs.some(def => def.node.type === "VariableDeclarator" &&
                    def.node.init !== null)) {
                    return;
                }
                /*
                 * The alias has been declared and not assigned: check it was
                 * assigned later in the same scope.
                 */
                if (!variable.references.some(reference => {
                    const write = reference.writeExpr;
                    return (reference.from === scope &&
                        write && write.type === "ThisExpression" &&
                        write.parent.operator === "=");
                })) {
                    variable.defs.map(def => def.node).forEach(node => {
                        reportBadAssignment(node, alias);
                    });
                }
            }
            /**
             * Check each alias to ensure that is was assigned to the correct value.
             * @returns {void}
             */
            function ensureWasAssigned() {
                const scope = context.getScope();
                aliases.forEach(alias => {
                    checkWasAssigned(alias, scope);
                });
            }
            return {
                "Program:exit": ensureWasAssigned,
                "FunctionExpression:exit": ensureWasAssigned,
                "FunctionDeclaration:exit": ensureWasAssigned,
                VariableDeclarator(node) {
                    const id = node.id;
                    const isDestructuring = id.type === "ArrayPattern" || id.type === "ObjectPattern";
                    if (node.init !== null && !isDestructuring) {
                        checkAssignment(node, id.name, node.init);
                    }
                },
                AssignmentExpression(node) {
                    if (node.left.type === "Identifier") {
                        checkAssignment(node, node.left.name, node.right);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/constructor-super.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to verify `super()` callings in constructor.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether a given code path segment is reachable or not.
     * @param {CodePathSegment} segment A code path segment to check.
     * @returns {boolean} `true` if the segment is reachable.
     */
    function isReachable(segment) {
        return segment.reachable;
    }
    /**
     * Checks whether or not a given node is a constructor.
     * @param {ASTNode} node A node to check. This node type is one of
     *   `Program`, `FunctionDeclaration`, `FunctionExpression`, and
     *   `ArrowFunctionExpression`.
     * @returns {boolean} `true` if the node is a constructor.
     */
    function isConstructorFunction(node) {
        return (node.type === "FunctionExpression" &&
            node.parent.type === "MethodDefinition" &&
            node.parent.kind === "constructor");
    }
    /**
     * Checks whether a given node can be a constructor or not.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node can be a constructor.
     */
    function isPossibleConstructor(node) {
        if (!node) {
            return false;
        }
        switch (node.type) {
            case "ClassExpression":
            case "FunctionExpression":
            case "ThisExpression":
            case "MemberExpression":
            case "CallExpression":
            case "NewExpression":
            case "ChainExpression":
            case "YieldExpression":
            case "TaggedTemplateExpression":
            case "MetaProperty":
                return true;
            case "Identifier":
                return node.name !== "undefined";
            case "AssignmentExpression":
                if (["=", "&&="].includes(node.operator)) {
                    return isPossibleConstructor(node.right);
                }
                if (["||=", "??="].includes(node.operator)) {
                    return (isPossibleConstructor(node.left) ||
                        isPossibleConstructor(node.right));
                }
                /**
                 * All other assignment operators are mathematical assignment operators (arithmetic or bitwise).
                 * An assignment expression with a mathematical operator can either evaluate to a primitive value,
                 * or throw, depending on the operands. Thus, it cannot evaluate to a constructor function.
                 */
                return false;
            case "LogicalExpression":
                /*
                 * If the && operator short-circuits, the left side was falsy and therefore not a constructor, and if
                 * it doesn't short-circuit, it takes the value from the right side, so the right side must always be a
                 * possible constructor. A future improvement could verify that the left side could be truthy by
                 * excluding falsy literals.
                 */
                if (node.operator === "&&") {
                    return isPossibleConstructor(node.right);
                }
                return (isPossibleConstructor(node.left) ||
                    isPossibleConstructor(node.right));
            case "ConditionalExpression":
                return (isPossibleConstructor(node.alternate) ||
                    isPossibleConstructor(node.consequent));
            case "SequenceExpression": {
                const lastExpression = node.expressions[node.expressions.length - 1];
                return isPossibleConstructor(lastExpression);
            }
            default:
                return false;
        }
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Require `super()` calls in constructors",
                recommended: true,
                url: "https://eslint.org/docs/rules/constructor-super"
            },
            schema: [],
            messages: {
                missingSome: "Lacked a call of 'super()' in some code paths.",
                missingAll: "Expected to call 'super()'.",
                duplicate: "Unexpected duplicate 'super()'.",
                badSuper: "Unexpected 'super()' because 'super' is not a constructor.",
                unexpected: "Unexpected 'super()'."
            }
        },
        create(context) {
            /*
             * {{hasExtends: boolean, scope: Scope, codePath: CodePath}[]}
             * Information for each constructor.
             * - upper:      Information of the upper constructor.
             * - hasExtends: A flag which shows whether own class has a valid `extends`
             *               part.
             * - scope:      The scope of own class.
             * - codePath:   The code path object of the constructor.
             */
            let funcInfo = null;
            /*
             * {Map<string, {calledInSomePaths: boolean, calledInEveryPaths: boolean}>}
             * Information for each code path segment.
             * - calledInSomePaths:  A flag of be called `super()` in some code paths.
             * - calledInEveryPaths: A flag of be called `super()` in all code paths.
             * - validNodes:
             */
            let segInfoMap = Object.create(null);
            /**
             * Gets the flag which shows `super()` is called in some paths.
             * @param {CodePathSegment} segment A code path segment to get.
             * @returns {boolean} The flag which shows `super()` is called in some paths
             */
            function isCalledInSomePath(segment) {
                return segment.reachable && segInfoMap[segment.id].calledInSomePaths;
            }
            /**
             * Gets the flag which shows `super()` is called in all paths.
             * @param {CodePathSegment} segment A code path segment to get.
             * @returns {boolean} The flag which shows `super()` is called in all paths.
             */
            function isCalledInEveryPath(segment) {
                /*
                 * If specific segment is the looped segment of the current segment,
                 * skip the segment.
                 * If not skipped, this never becomes true after a loop.
                 */
                if (segment.nextSegments.length === 1 &&
                    segment.nextSegments[0].isLoopedPrevSegment(segment)) {
                    return true;
                }
                return segment.reachable && segInfoMap[segment.id].calledInEveryPaths;
            }
            return {
                /**
                 * Stacks a constructor information.
                 * @param {CodePath} codePath A code path which was started.
                 * @param {ASTNode} node The current node.
                 * @returns {void}
                 */
                onCodePathStart(codePath, node) {
                    if (isConstructorFunction(node)) {
                        // Class > ClassBody > MethodDefinition > FunctionExpression
                        const classNode = node.parent.parent.parent;
                        const superClass = classNode.superClass;
                        funcInfo = {
                            upper: funcInfo,
                            isConstructor: true,
                            hasExtends: Boolean(superClass),
                            superIsConstructor: isPossibleConstructor(superClass),
                            codePath
                        };
                    }
                    else {
                        funcInfo = {
                            upper: funcInfo,
                            isConstructor: false,
                            hasExtends: false,
                            superIsConstructor: false,
                            codePath
                        };
                    }
                },
                /**
                 * Pops a constructor information.
                 * And reports if `super()` lacked.
                 * @param {CodePath} codePath A code path which was ended.
                 * @param {ASTNode} node The current node.
                 * @returns {void}
                 */
                onCodePathEnd(codePath, node) {
                    const hasExtends = funcInfo.hasExtends;
                    // Pop.
                    funcInfo = funcInfo.upper;
                    if (!hasExtends) {
                        return;
                    }
                    // Reports if `super()` lacked.
                    const segments = codePath.returnedSegments;
                    const calledInEveryPaths = segments.every(isCalledInEveryPath);
                    const calledInSomePaths = segments.some(isCalledInSomePath);
                    if (!calledInEveryPaths) {
                        context.report({
                            messageId: calledInSomePaths
                                ? "missingSome"
                                : "missingAll",
                            node: node.parent
                        });
                    }
                },
                /**
                 * Initialize information of a given code path segment.
                 * @param {CodePathSegment} segment A code path segment to initialize.
                 * @returns {void}
                 */
                onCodePathSegmentStart(segment) {
                    if (!(funcInfo && funcInfo.isConstructor && funcInfo.hasExtends)) {
                        return;
                    }
                    // Initialize info.
                    const info = segInfoMap[segment.id] = {
                        calledInSomePaths: false,
                        calledInEveryPaths: false,
                        validNodes: []
                    };
                    // When there are previous segments, aggregates these.
                    const prevSegments = segment.prevSegments;
                    if (prevSegments.length > 0) {
                        info.calledInSomePaths = prevSegments.some(isCalledInSomePath);
                        info.calledInEveryPaths = prevSegments.every(isCalledInEveryPath);
                    }
                },
                /**
                 * Update information of the code path segment when a code path was
                 * looped.
                 * @param {CodePathSegment} fromSegment The code path segment of the
                 *      end of a loop.
                 * @param {CodePathSegment} toSegment A code path segment of the head
                 *      of a loop.
                 * @returns {void}
                 */
                onCodePathSegmentLoop(fromSegment, toSegment) {
                    if (!(funcInfo && funcInfo.isConstructor && funcInfo.hasExtends)) {
                        return;
                    }
                    // Update information inside of the loop.
                    const isRealLoop = toSegment.prevSegments.length >= 2;
                    funcInfo.codePath.traverseSegments({ first: toSegment, last: fromSegment }, segment => {
                        const info = segInfoMap[segment.id];
                        const prevSegments = segment.prevSegments;
                        // Updates flags.
                        info.calledInSomePaths = prevSegments.some(isCalledInSomePath);
                        info.calledInEveryPaths = prevSegments.every(isCalledInEveryPath);
                        // If flags become true anew, reports the valid nodes.
                        if (info.calledInSomePaths || isRealLoop) {
                            const nodes = info.validNodes;
                            info.validNodes = [];
                            for (let i = 0; i < nodes.length; ++i) {
                                const node = nodes[i];
                                context.report({
                                    messageId: "duplicate",
                                    node
                                });
                            }
                        }
                    });
                },
                /**
                 * Checks for a call of `super()`.
                 * @param {ASTNode} node A CallExpression node to check.
                 * @returns {void}
                 */
                "CallExpression:exit"(node) {
                    if (!(funcInfo && funcInfo.isConstructor)) {
                        return;
                    }
                    // Skips except `super()`.
                    if (node.callee.type !== "Super") {
                        return;
                    }
                    // Reports if needed.
                    if (funcInfo.hasExtends) {
                        const segments = funcInfo.codePath.currentSegments;
                        let duplicate = false;
                        let info = null;
                        for (let i = 0; i < segments.length; ++i) {
                            const segment = segments[i];
                            if (segment.reachable) {
                                info = segInfoMap[segment.id];
                                duplicate = duplicate || info.calledInSomePaths;
                                info.calledInSomePaths = info.calledInEveryPaths = true;
                            }
                        }
                        if (info) {
                            if (duplicate) {
                                context.report({
                                    messageId: "duplicate",
                                    node
                                });
                            }
                            else if (!funcInfo.superIsConstructor) {
                                context.report({
                                    messageId: "badSuper",
                                    node
                                });
                            }
                            else {
                                info.validNodes.push(node);
                            }
                        }
                    }
                    else if (funcInfo.codePath.currentSegments.some(isReachable)) {
                        context.report({
                            messageId: "unexpected",
                            node
                        });
                    }
                },
                /**
                 * Set the mark to the returned path as `super()` was called.
                 * @param {ASTNode} node A ReturnStatement node to check.
                 * @returns {void}
                 */
                ReturnStatement(node) {
                    if (!(funcInfo && funcInfo.isConstructor && funcInfo.hasExtends)) {
                        return;
                    }
                    // Skips if no argument.
                    if (!node.argument) {
                        return;
                    }
                    // Returning argument is a substitute of 'super()'.
                    const segments = funcInfo.codePath.currentSegments;
                    for (let i = 0; i < segments.length; ++i) {
                        const segment = segments[i];
                        if (segment.reachable) {
                            const info = segInfoMap[segment.id];
                            info.calledInSomePaths = info.calledInEveryPaths = true;
                        }
                    }
                },
                /**
                 * Resets state.
                 * @returns {void}
                 */
                "Program:exit"() {
                    segInfoMap = Object.create(null);
                }
            };
        }
    };
},
/* eslint/lib/rules/curly.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag statements without curly braces
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce consistent brace style for all control statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/curly"
            },
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["all"]
                            }
                        ],
                        minItems: 0,
                        maxItems: 1
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["multi", "multi-line", "multi-or-nest"]
                            },
                            {
                                enum: ["consistent"]
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    }
                ]
            },
            fixable: "code",
            messages: {
                missingCurlyAfter: "Expected { after '{{name}}'.",
                missingCurlyAfterCondition: "Expected { after '{{name}}' condition.",
                unexpectedCurlyAfter: "Unnecessary { after '{{name}}'.",
                unexpectedCurlyAfterCondition: "Unnecessary { after '{{name}}' condition."
            }
        },
        create(context) {
            const multiOnly = (context.options[0] === "multi");
            const multiLine = (context.options[0] === "multi-line");
            const multiOrNest = (context.options[0] === "multi-or-nest");
            const consistent = (context.options[1] === "consistent");
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Determines if a given node is a one-liner that's on the same line as it's preceding code.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} True if the node is a one-liner that's on the same line as it's preceding code.
             * @private
             */
            function isCollapsedOneLiner(node) {
                const before = sourceCode.getTokenBefore(node);
                const last = sourceCode.getLastToken(node);
                const lastExcludingSemicolon = astUtils.isSemicolonToken(last) ? sourceCode.getTokenBefore(last) : last;
                return before.loc.start.line === lastExcludingSemicolon.loc.end.line;
            }
            /**
             * Determines if a given node is a one-liner.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} True if the node is a one-liner.
             * @private
             */
            function isOneLiner(node) {
                if (node.type === "EmptyStatement") {
                    return true;
                }
                const first = sourceCode.getFirstToken(node);
                const last = sourceCode.getLastToken(node);
                const lastExcludingSemicolon = astUtils.isSemicolonToken(last) ? sourceCode.getTokenBefore(last) : last;
                return first.loc.start.line === lastExcludingSemicolon.loc.end.line;
            }
            /**
             * Determines if the given node is a lexical declaration (let, const, function, or class)
             * @param {ASTNode} node The node to check
             * @returns {boolean} True if the node is a lexical declaration
             * @private
             */
            function isLexicalDeclaration(node) {
                if (node.type === "VariableDeclaration") {
                    return node.kind === "const" || node.kind === "let";
                }
                return node.type === "FunctionDeclaration" || node.type === "ClassDeclaration";
            }
            /**
             * Checks if the given token is an `else` token or not.
             * @param {Token} token The token to check.
             * @returns {boolean} `true` if the token is an `else` token.
             */
            function isElseKeywordToken(token) {
                return token.value === "else" && token.type === "Keyword";
            }
            /**
             * Determines whether the given node has an `else` keyword token as the first token after.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} `true` if the node is followed by an `else` keyword token.
             */
            function isFollowedByElseKeyword(node) {
                const nextToken = sourceCode.getTokenAfter(node);
                return Boolean(nextToken) && isElseKeywordToken(nextToken);
            }
            /**
             * Determines if a semicolon needs to be inserted after removing a set of curly brackets, in order to avoid a SyntaxError.
             * @param {Token} closingBracket The } token
             * @returns {boolean} `true` if a semicolon needs to be inserted after the last statement in the block.
             */
            function needsSemicolon(closingBracket) {
                const tokenBefore = sourceCode.getTokenBefore(closingBracket);
                const tokenAfter = sourceCode.getTokenAfter(closingBracket);
                const lastBlockNode = sourceCode.getNodeByRangeIndex(tokenBefore.range[0]);
                if (astUtils.isSemicolonToken(tokenBefore)) {
                    // If the last statement already has a semicolon, don't add another one.
                    return false;
                }
                if (!tokenAfter) {
                    // If there are no statements after this block, there is no need to add a semicolon.
                    return false;
                }
                if (lastBlockNode.type === "BlockStatement" && lastBlockNode.parent.type !== "FunctionExpression" && lastBlockNode.parent.type !== "ArrowFunctionExpression") {
                    /*
                     * If the last node surrounded by curly brackets is a BlockStatement (other than a FunctionExpression or an ArrowFunctionExpression),
                     * don't insert a semicolon. Otherwise, the semicolon would be parsed as a separate statement, which would cause
                     * a SyntaxError if it was followed by `else`.
                     */
                    return false;
                }
                if (tokenBefore.loc.end.line === tokenAfter.loc.start.line) {
                    // If the next token is on the same line, insert a semicolon.
                    return true;
                }
                if (/^[([/`+-]/u.test(tokenAfter.value)) {
                    // If the next token starts with a character that would disrupt ASI, insert a semicolon.
                    return true;
                }
                if (tokenBefore.type === "Punctuator" && (tokenBefore.value === "++" || tokenBefore.value === "--")) {
                    // If the last token is ++ or --, insert a semicolon to avoid disrupting ASI.
                    return true;
                }
                // Otherwise, do not insert a semicolon.
                return false;
            }
            /**
             * Determines whether the code represented by the given node contains an `if` statement
             * that would become associated with an `else` keyword directly appended to that code.
             *
             * Examples where it returns `true`:
             *
             *    if (a)
             *        foo();
             *
             *    if (a) {
             *        foo();
             *    }
             *
             *    if (a)
             *        foo();
             *    else if (b)
             *        bar();
             *
             *    while (a)
             *        if (b)
             *            if(c)
             *                foo();
             *            else
             *                bar();
             *
             * Examples where it returns `false`:
             *
             *    if (a)
             *        foo();
             *    else
             *        bar();
             *
             *    while (a) {
             *        if (b)
             *            if(c)
             *                foo();
             *            else
             *                bar();
             *    }
             *
             *    while (a)
             *        if (b) {
             *            if(c)
             *                foo();
             *        }
             *        else
             *            bar();
             * @param {ASTNode} node Node representing the code to check.
             * @returns {boolean} `true` if an `if` statement within the code would become associated with an `else` appended to that code.
             */
            function hasUnsafeIf(node) {
                switch (node.type) {
                    case "IfStatement":
                        if (!node.alternate) {
                            return true;
                        }
                        return hasUnsafeIf(node.alternate);
                    case "ForStatement":
                    case "ForInStatement":
                    case "ForOfStatement":
                    case "LabeledStatement":
                    case "WithStatement":
                    case "WhileStatement":
                        return hasUnsafeIf(node.body);
                    default:
                        return false;
                }
            }
            /**
             * Determines whether the existing curly braces around the single statement are necessary to preserve the semantics of the code.
             * The braces, which make the given block body, are necessary in either of the following situations:
             *
             * 1. The statement is a lexical declaration.
             * 2. Without the braces, an `if` within the statement would become associated with an `else` after the closing brace:
             *
             *     if (a) {
             *         if (b)
             *             foo();
             *     }
             *     else
             *         bar();
             *
             *     if (a)
             *         while (b)
             *             while (c) {
             *                 while (d)
             *                     if (e)
             *                         while(f)
             *                             foo();
             *            }
             *     else
             *         bar();
             * @param {ASTNode} node `BlockStatement` body with exactly one statement directly inside. The statement can have its own nested statements.
             * @returns {boolean} `true` if the braces are necessary - removing them (replacing the given `BlockStatement` body with its single statement content)
             * would change the semantics of the code or produce a syntax error.
             */
            function areBracesNecessary(node) {
                const statement = node.body[0];
                return isLexicalDeclaration(statement) ||
                    hasUnsafeIf(statement) && isFollowedByElseKeyword(node);
            }
            /**
             * Prepares to check the body of a node to see if it's a block statement.
             * @param {ASTNode} node The node to report if there's a problem.
             * @param {ASTNode} body The body node to check for blocks.
             * @param {string} name The name to report if there's a problem.
             * @param {{ condition: boolean }} opts Options to pass to the report functions
             * @returns {Object} a prepared check object, with "actual", "expected", "check" properties.
             *   "actual" will be `true` or `false` whether the body is already a block statement.
             *   "expected" will be `true` or `false` if the body should be a block statement or not, or
             *   `null` if it doesn't matter, depending on the rule options. It can be modified to change
             *   the final behavior of "check".
             *   "check" will be a function reporting appropriate problems depending on the other
             *   properties.
             */
            function prepareCheck(node, body, name, opts) {
                const hasBlock = (body.type === "BlockStatement");
                let expected = null;
                if (hasBlock && (body.body.length !== 1 || areBracesNecessary(body))) {
                    expected = true;
                }
                else if (multiOnly) {
                    expected = false;
                }
                else if (multiLine) {
                    if (!isCollapsedOneLiner(body)) {
                        expected = true;
                    }
                    // otherwise, the body is allowed to have braces or not to have braces
                }
                else if (multiOrNest) {
                    if (hasBlock) {
                        const statement = body.body[0];
                        const leadingCommentsInBlock = sourceCode.getCommentsBefore(statement);
                        expected = !isOneLiner(statement) || leadingCommentsInBlock.length > 0;
                    }
                    else {
                        expected = !isOneLiner(body);
                    }
                }
                else {
                    // default "all"
                    expected = true;
                }
                return {
                    actual: hasBlock,
                    expected,
                    check() {
                        if (this.expected !== null && this.expected !== this.actual) {
                            if (this.expected) {
                                context.report({
                                    node,
                                    loc: body.loc,
                                    messageId: opts && opts.condition ? "missingCurlyAfterCondition" : "missingCurlyAfter",
                                    data: {
                                        name
                                    },
                                    fix: fixer => fixer.replaceText(body, `{${sourceCode.getText(body)}}`)
                                });
                            }
                            else {
                                context.report({
                                    node,
                                    loc: body.loc,
                                    messageId: opts && opts.condition ? "unexpectedCurlyAfterCondition" : "unexpectedCurlyAfter",
                                    data: {
                                        name
                                    },
                                    fix(fixer) {
                                        /*
                                         * `do while` expressions sometimes need a space to be inserted after `do`.
                                         * e.g. `do{foo()} while (bar)` should be corrected to `do foo() while (bar)`
                                         */
                                        const needsPrecedingSpace = node.type === "DoWhileStatement" &&
                                            sourceCode.getTokenBefore(body).range[1] === body.range[0] &&
                                            !astUtils.canTokensBeAdjacent("do", sourceCode.getFirstToken(body, { skip: 1 }));
                                        const openingBracket = sourceCode.getFirstToken(body);
                                        const closingBracket = sourceCode.getLastToken(body);
                                        const lastTokenInBlock = sourceCode.getTokenBefore(closingBracket);
                                        if (needsSemicolon(closingBracket)) {
                                            /*
                                             * If removing braces would cause a SyntaxError due to multiple statements on the same line (or
                                             * change the semantics of the code due to ASI), don't perform a fix.
                                             */
                                            return null;
                                        }
                                        const resultingBodyText = sourceCode.getText().slice(openingBracket.range[1], lastTokenInBlock.range[0]) +
                                            sourceCode.getText(lastTokenInBlock) +
                                            sourceCode.getText().slice(lastTokenInBlock.range[1], closingBracket.range[0]);
                                        return fixer.replaceText(body, (needsPrecedingSpace ? " " : "") + resultingBodyText);
                                    }
                                });
                            }
                        }
                    }
                };
            }
            /**
             * Prepares to check the bodies of a "if", "else if" and "else" chain.
             * @param {ASTNode} node The first IfStatement node of the chain.
             * @returns {Object[]} prepared checks for each body of the chain. See `prepareCheck` for more
             *   information.
             */
            function prepareIfChecks(node) {
                const preparedChecks = [];
                for (let currentNode = node; currentNode; currentNode = currentNode.alternate) {
                    preparedChecks.push(prepareCheck(currentNode, currentNode.consequent, "if", { condition: true }));
                    if (currentNode.alternate && currentNode.alternate.type !== "IfStatement") {
                        preparedChecks.push(prepareCheck(currentNode, currentNode.alternate, "else"));
                        break;
                    }
                }
                if (consistent) {
                    /*
                     * If any node should have or already have braces, make sure they
                     * all have braces.
                     * If all nodes shouldn't have braces, make sure they don't.
                     */
                    const expected = preparedChecks.some(preparedCheck => {
                        if (preparedCheck.expected !== null) {
                            return preparedCheck.expected;
                        }
                        return preparedCheck.actual;
                    });
                    preparedChecks.forEach(preparedCheck => {
                        preparedCheck.expected = expected;
                    });
                }
                return preparedChecks;
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                IfStatement(node) {
                    const parent = node.parent;
                    const isElseIf = parent.type === "IfStatement" && parent.alternate === node;
                    if (!isElseIf) {
                        // This is a top `if`, check the whole `if-else-if` chain
                        prepareIfChecks(node).forEach(preparedCheck => {
                            preparedCheck.check();
                        });
                    }
                    // Skip `else if`, it's already checked (when the top `if` was visited)
                },
                WhileStatement(node) {
                    prepareCheck(node, node.body, "while", { condition: true }).check();
                },
                DoWhileStatement(node) {
                    prepareCheck(node, node.body, "do").check();
                },
                ForStatement(node) {
                    prepareCheck(node, node.body, "for", { condition: true }).check();
                },
                ForInStatement(node) {
                    prepareCheck(node, node.body, "for-in").check();
                },
                ForOfStatement(node) {
                    prepareCheck(node, node.body, "for-of").check();
                }
            };
        }
    };
},
/* eslint/lib/rules/default-case.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview require default case in switch statements
     * @author Aliaksei Shytkin
     */
    "use strict";
    const DEFAULT_COMMENT_PATTERN = /^no default$/iu;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require `default` cases in `switch` statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/default-case"
            },
            schema: [{
                    type: "object",
                    properties: {
                        commentPattern: {
                            type: "string"
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                missingDefaultCase: "Expected a default case."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const commentPattern = options.commentPattern
                ? new RegExp(options.commentPattern, "u")
                : DEFAULT_COMMENT_PATTERN;
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Shortcut to get last element of array
             * @param {*[]} collection Array
             * @returns {any} Last element
             */
            function last(collection) {
                return collection[collection.length - 1];
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                SwitchStatement(node) {
                    if (!node.cases.length) {
                        /*
                         * skip check of empty switch because there is no easy way
                         * to extract comments inside it now
                         */
                        return;
                    }
                    const hasDefault = node.cases.some(v => v.test === null);
                    if (!hasDefault) {
                        let comment;
                        const lastCase = last(node.cases);
                        const comments = sourceCode.getCommentsAfter(lastCase);
                        if (comments.length) {
                            comment = last(comments);
                        }
                        if (!comment || !commentPattern.test(comment.value.trim())) {
                            context.report({ node, messageId: "missingDefaultCase" });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/default-case-last.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce default clauses in switch statements to be last
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce default clauses in switch statements to be last",
                recommended: false,
                url: "https://eslint.org/docs/rules/default-case-last"
            },
            schema: [],
            messages: {
                notLast: "Default clause should be the last clause."
            }
        },
        create(context) {
            return {
                SwitchStatement(node) {
                    const cases = node.cases, indexOfDefault = cases.findIndex(c => c.test === null);
                    if (indexOfDefault !== -1 && indexOfDefault !== cases.length - 1) {
                        const defaultClause = cases[indexOfDefault];
                        context.report({ node: defaultClause, messageId: "notLast" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/default-param-last.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview enforce default parameters to be last
     * @author Chiawen Chen
     */
    "use strict";
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce default parameters to be last",
                recommended: false,
                url: "https://eslint.org/docs/rules/default-param-last"
            },
            schema: [],
            messages: {
                shouldBeLast: "Default parameters should be last."
            }
        },
        create(context) {
            /**
             * Handler for function contexts.
             * @param {ASTNode} node function node
             * @returns {void}
             */
            function handleFunction(node) {
                let hasSeenPlainParam = false;
                for (let i = node.params.length - 1; i >= 0; i -= 1) {
                    const param = node.params[i];
                    if (param.type !== "AssignmentPattern" &&
                        param.type !== "RestElement") {
                        hasSeenPlainParam = true;
                        continue;
                    }
                    if (hasSeenPlainParam && param.type === "AssignmentPattern") {
                        context.report({
                            node: param,
                            messageId: "shouldBeLast"
                        });
                    }
                }
            }
            return {
                FunctionDeclaration: handleFunction,
                FunctionExpression: handleFunction,
                ArrowFunctionExpression: handleFunction
            };
        }
    };
},
/* eslint/lib/rules/dot-location.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Validates newlines before and after dots
     * @author Greg Cochard
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent newlines before and after dots",
                recommended: false,
                url: "https://eslint.org/docs/rules/dot-location"
            },
            schema: [
                {
                    enum: ["object", "property"]
                }
            ],
            fixable: "code",
            messages: {
                expectedDotAfterObject: "Expected dot to be on same line as object.",
                expectedDotBeforeProperty: "Expected dot to be on same line as property."
            }
        },
        create(context) {
            const config = context.options[0];
            // default to onObject if no preference is passed
            const onObject = config === "object" || !config;
            const sourceCode = context.getSourceCode();
            /**
             * Reports if the dot between object and property is on the correct location.
             * @param {ASTNode} node The `MemberExpression` node.
             * @returns {void}
             */
            function checkDotLocation(node) {
                const property = node.property;
                const dotToken = sourceCode.getTokenBefore(property);
                if (onObject) {
                    // `obj` expression can be parenthesized, but those paren tokens are not a part of the `obj` node.
                    const tokenBeforeDot = sourceCode.getTokenBefore(dotToken);
                    if (!astUtils.isTokenOnSameLine(tokenBeforeDot, dotToken)) {
                        context.report({
                            node,
                            loc: dotToken.loc,
                            messageId: "expectedDotAfterObject",
                            *fix(fixer) {
                                if (dotToken.value.startsWith(".") && astUtils.isDecimalIntegerNumericToken(tokenBeforeDot)) {
                                    yield fixer.insertTextAfter(tokenBeforeDot, ` ${dotToken.value}`);
                                }
                                else {
                                    yield fixer.insertTextAfter(tokenBeforeDot, dotToken.value);
                                }
                                yield fixer.remove(dotToken);
                            }
                        });
                    }
                }
                else if (!astUtils.isTokenOnSameLine(dotToken, property)) {
                    context.report({
                        node,
                        loc: dotToken.loc,
                        messageId: "expectedDotBeforeProperty",
                        *fix(fixer) {
                            yield fixer.remove(dotToken);
                            yield fixer.insertTextBefore(property, dotToken.value);
                        }
                    });
                }
            }
            /**
             * Checks the spacing of the dot within a member expression.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             */
            function checkNode(node) {
                if (!node.computed) {
                    checkDotLocation(node);
                }
            }
            return {
                MemberExpression: checkNode
            };
        }
    };
},
/* eslint/lib/rules/dot-notation.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to warn about using dot notation instead of square bracket notation when possible.
     * @author Josh Perez
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const keywords = require(395) /* ./utils/keywords */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const validIdentifier = /^[a-zA-Z_$][a-zA-Z0-9_$]*$/u;
    // `null` literal must be handled separately.
    const literalTypesToCheck = new Set(["string", "boolean"]);
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce dot notation whenever possible",
                recommended: false,
                url: "https://eslint.org/docs/rules/dot-notation"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowKeywords: {
                            type: "boolean",
                            default: true
                        },
                        allowPattern: {
                            type: "string",
                            default: ""
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "code",
            messages: {
                useDot: "[{{key}}] is better written in dot notation.",
                useBrackets: ".{{key}} is a syntax error."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const allowKeywords = options.allowKeywords === void 0 || options.allowKeywords;
            const sourceCode = context.getSourceCode();
            let allowPattern;
            if (options.allowPattern) {
                allowPattern = new RegExp(options.allowPattern, "u");
            }
            /**
             * Check if the property is valid dot notation
             * @param {ASTNode} node The dot notation node
             * @param {string} value Value which is to be checked
             * @returns {void}
             */
            function checkComputedProperty(node, value) {
                if (validIdentifier.test(value) &&
                    (allowKeywords || !keywords.includes(String(value))) &&
                    !(allowPattern && allowPattern.test(value))) {
                    const formattedValue = node.property.type === "Literal" ? JSON.stringify(value) : `\`${value}\``;
                    context.report({
                        node: node.property,
                        messageId: "useDot",
                        data: {
                            key: formattedValue
                        },
                        *fix(fixer) {
                            const leftBracket = sourceCode.getTokenAfter(node.object, astUtils.isOpeningBracketToken);
                            const rightBracket = sourceCode.getLastToken(node);
                            const nextToken = sourceCode.getTokenAfter(node);
                            // Don't perform any fixes if there are comments inside the brackets.
                            if (sourceCode.commentsExistBetween(leftBracket, rightBracket)) {
                                return;
                            }
                            // Replace the brackets by an identifier.
                            if (!node.optional) {
                                yield fixer.insertTextBefore(leftBracket, astUtils.isDecimalInteger(node.object) ? " ." : ".");
                            }
                            yield fixer.replaceTextRange([leftBracket.range[0], rightBracket.range[1]], value);
                            // Insert a space after the property if it will be connected to the next token.
                            if (nextToken &&
                                rightBracket.range[1] === nextToken.range[0] &&
                                !astUtils.canTokensBeAdjacent(String(value), nextToken)) {
                                yield fixer.insertTextAfter(node, " ");
                            }
                        }
                    });
                }
            }
            return {
                MemberExpression(node) {
                    if (node.computed &&
                        node.property.type === "Literal" &&
                        (literalTypesToCheck.has(typeof node.property.value) || astUtils.isNullLiteral(node.property))) {
                        checkComputedProperty(node, node.property.value);
                    }
                    if (node.computed &&
                        node.property.type === "TemplateLiteral" &&
                        node.property.expressions.length === 0) {
                        checkComputedProperty(node, node.property.quasis[0].value.cooked);
                    }
                    if (!allowKeywords &&
                        !node.computed &&
                        node.property.type === "Identifier" &&
                        keywords.includes(String(node.property.name))) {
                        context.report({
                            node: node.property,
                            messageId: "useBrackets",
                            data: {
                                key: node.property.name
                            },
                            *fix(fixer) {
                                const dotToken = sourceCode.getTokenBefore(node.property);
                                // A statement that starts with `let[` is parsed as a destructuring variable declaration, not a MemberExpression.
                                if (node.object.type === "Identifier" && node.object.name === "let" && !node.optional) {
                                    return;
                                }
                                // Don't perform any fixes if there are comments between the dot and the property name.
                                if (sourceCode.commentsExistBetween(dotToken, node.property)) {
                                    return;
                                }
                                // Replace the identifier to brackets.
                                if (!node.optional) {
                                    yield fixer.remove(dotToken);
                                }
                                yield fixer.replaceText(node.property, `["${node.property.name}"]`);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/utils/keywords.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview A shared list of ES3 keywords.
     * @author Josh Perez
     */
    "use strict";
    module.exports = [
        "abstract",
        "boolean",
        "break",
        "byte",
        "case",
        "catch",
        "char",
        "class",
        "const",
        "continue",
        "debugger",
        "default",
        "delete",
        "do",
        "double",
        "else",
        "enum",
        "export",
        "extends",
        "false",
        "final",
        "finally",
        "float",
        "for",
        "function",
        "goto",
        "if",
        "implements",
        "import",
        "in",
        "instanceof",
        "int",
        "interface",
        "long",
        "native",
        "new",
        "null",
        "package",
        "private",
        "protected",
        "public",
        "return",
        "short",
        "static",
        "super",
        "switch",
        "synchronized",
        "this",
        "throw",
        "throws",
        "transient",
        "true",
        "try",
        "typeof",
        "var",
        "void",
        "volatile",
        "while",
        "with"
    ];
},
/* eslint/lib/rules/eol-last.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Require or disallow newline at the end of files
     * @author Nodeca Team <https://github.com/nodeca>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow newline at the end of files",
                recommended: false,
                url: "https://eslint.org/docs/rules/eol-last"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never", "unix", "windows"]
                }
            ],
            messages: {
                missing: "Newline required at end of file but not found.",
                unexpected: "Newline not allowed at end of file."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program: function checkBadEOF(node) {
                    const sourceCode = context.getSourceCode(), src = sourceCode.getText(), lastLine = sourceCode.lines[sourceCode.lines.length - 1], location = {
                        column: lastLine.length,
                        line: sourceCode.lines.length
                    }, LF = "\n", CRLF = `\r${LF}`, endsWithNewline = src.endsWith(LF);
                    /*
                     * Empty source is always valid: No content in file so we don't
                     * need to lint for a newline on the last line of content.
                     */
                    if (!src.length) {
                        return;
                    }
                    let mode = context.options[0] || "always", appendCRLF = false;
                    if (mode === "unix") {
                        // `"unix"` should behave exactly as `"always"`
                        mode = "always";
                    }
                    if (mode === "windows") {
                        // `"windows"` should behave exactly as `"always"`, but append CRLF in the fixer for backwards compatibility
                        mode = "always";
                        appendCRLF = true;
                    }
                    if (mode === "always" && !endsWithNewline) {
                        // File is not newline-terminated, but should be
                        context.report({
                            node,
                            loc: location,
                            messageId: "missing",
                            fix(fixer) {
                                return fixer.insertTextAfterRange([0, src.length], appendCRLF ? CRLF : LF);
                            }
                        });
                    }
                    else if (mode === "never" && endsWithNewline) {
                        const secondLastLine = sourceCode.lines[sourceCode.lines.length - 2];
                        // File is newline-terminated, but shouldn't be
                        context.report({
                            node,
                            loc: {
                                start: { line: sourceCode.lines.length - 1, column: secondLastLine.length },
                                end: { line: sourceCode.lines.length, column: 0 }
                            },
                            messageId: "unexpected",
                            fix(fixer) {
                                const finalEOLs = /(?:\r?\n)+$/u, match = finalEOLs.exec(sourceCode.text), start = match.index, end = sourceCode.text.length;
                                return fixer.replaceTextRange([start, end], "");
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/eqeqeq.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag statements that use != and == instead of !== and ===
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require the use of `===` and `!==`",
                recommended: false,
                url: "https://eslint.org/docs/rules/eqeqeq"
            },
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always"]
                            },
                            {
                                type: "object",
                                properties: {
                                    null: {
                                        enum: ["always", "never", "ignore"]
                                    }
                                },
                                additionalProperties: false
                            }
                        ],
                        additionalItems: false
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["smart", "allow-null"]
                            }
                        ],
                        additionalItems: false
                    }
                ]
            },
            fixable: "code",
            messages: {
                unexpected: "Expected '{{expectedOperator}}' and instead saw '{{actualOperator}}'."
            }
        },
        create(context) {
            const config = context.options[0] || "always";
            const options = context.options[1] || {};
            const sourceCode = context.getSourceCode();
            const nullOption = (config === "always")
                ? options.null || "always"
                : "ignore";
            const enforceRuleForNull = (nullOption === "always");
            const enforceInverseRuleForNull = (nullOption === "never");
            /**
             * Checks if an expression is a typeof expression
             * @param {ASTNode} node The node to check
             * @returns {boolean} if the node is a typeof expression
             */
            function isTypeOf(node) {
                return node.type === "UnaryExpression" && node.operator === "typeof";
            }
            /**
             * Checks if either operand of a binary expression is a typeof operation
             * @param {ASTNode} node The node to check
             * @returns {boolean} if one of the operands is typeof
             * @private
             */
            function isTypeOfBinary(node) {
                return isTypeOf(node.left) || isTypeOf(node.right);
            }
            /**
             * Checks if operands are literals of the same type (via typeof)
             * @param {ASTNode} node The node to check
             * @returns {boolean} if operands are of same type
             * @private
             */
            function areLiteralsAndSameType(node) {
                return node.left.type === "Literal" && node.right.type === "Literal" &&
                    typeof node.left.value === typeof node.right.value;
            }
            /**
             * Checks if one of the operands is a literal null
             * @param {ASTNode} node The node to check
             * @returns {boolean} if operands are null
             * @private
             */
            function isNullCheck(node) {
                return astUtils.isNullLiteral(node.right) || astUtils.isNullLiteral(node.left);
            }
            /**
             * Reports a message for this rule.
             * @param {ASTNode} node The binary expression node that was checked
             * @param {string} expectedOperator The operator that was expected (either '==', '!=', '===', or '!==')
             * @returns {void}
             * @private
             */
            function report(node, expectedOperator) {
                const operatorToken = sourceCode.getFirstTokenBetween(node.left, node.right, token => token.value === node.operator);
                context.report({
                    node,
                    loc: operatorToken.loc,
                    messageId: "unexpected",
                    data: { expectedOperator, actualOperator: node.operator },
                    fix(fixer) {
                        // If the comparison is a `typeof` comparison or both sides are literals with the same type, then it's safe to fix.
                        if (isTypeOfBinary(node) || areLiteralsAndSameType(node)) {
                            return fixer.replaceText(operatorToken, expectedOperator);
                        }
                        return null;
                    }
                });
            }
            return {
                BinaryExpression(node) {
                    const isNull = isNullCheck(node);
                    if (node.operator !== "==" && node.operator !== "!=") {
                        if (enforceInverseRuleForNull && isNull) {
                            report(node, node.operator.slice(0, -1));
                        }
                        return;
                    }
                    if (config === "smart" && (isTypeOfBinary(node) ||
                        areLiteralsAndSameType(node) || isNull)) {
                        return;
                    }
                    if (!enforceRuleForNull && isNull) {
                        return;
                    }
                    report(node, `${node.operator}=`);
                }
            };
        }
    };
},
/* eslint/lib/rules/for-direction.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview enforce "for" loop update clause moving the counter in the right direction.(for-direction)
     * @author Aladdin-ADD<hh_2013@foxmail.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Enforce \"for\" loop update clause moving the counter in the right direction",
                recommended: true,
                url: "https://eslint.org/docs/rules/for-direction"
            },
            fixable: null,
            schema: [],
            messages: {
                incorrectDirection: "The update clause in this loop moves the variable in the wrong direction."
            }
        },
        create(context) {
            /**
             * report an error.
             * @param {ASTNode} node the node to report.
             * @returns {void}
             */
            function report(node) {
                context.report({
                    node,
                    messageId: "incorrectDirection"
                });
            }
            /**
             * check the right side of the assignment
             * @param {ASTNode} update UpdateExpression to check
             * @param {int} dir expected direction that could either be turned around or invalidated
             * @returns {int} return dir, the negated dir or zero if it's not clear for identifiers
             */
            function getRightDirection(update, dir) {
                if (update.right.type === "UnaryExpression") {
                    if (update.right.operator === "-") {
                        return -dir;
                    }
                }
                else if (update.right.type === "Identifier") {
                    return 0;
                }
                return dir;
            }
            /**
             * check UpdateExpression add/sub the counter
             * @param {ASTNode} update UpdateExpression to check
             * @param {string} counter variable name to check
             * @returns {int} if add return 1, if sub return -1, if nochange, return 0
             */
            function getUpdateDirection(update, counter) {
                if (update.argument.type === "Identifier" && update.argument.name === counter) {
                    if (update.operator === "++") {
                        return 1;
                    }
                    if (update.operator === "--") {
                        return -1;
                    }
                }
                return 0;
            }
            /**
             * check AssignmentExpression add/sub the counter
             * @param {ASTNode} update AssignmentExpression to check
             * @param {string} counter variable name to check
             * @returns {int} if add return 1, if sub return -1, if nochange, return 0
             */
            function getAssignmentDirection(update, counter) {
                if (update.left.name === counter) {
                    if (update.operator === "+=") {
                        return getRightDirection(update, 1);
                    }
                    if (update.operator === "-=") {
                        return getRightDirection(update, -1);
                    }
                }
                return 0;
            }
            return {
                ForStatement(node) {
                    if (node.test && node.test.type === "BinaryExpression" && node.test.left.type === "Identifier" && node.update) {
                        const counter = node.test.left.name;
                        const operator = node.test.operator;
                        const update = node.update;
                        let wrongDirection;
                        if (operator === "<" || operator === "<=") {
                            wrongDirection = -1;
                        }
                        else if (operator === ">" || operator === ">=") {
                            wrongDirection = 1;
                        }
                        else {
                            return;
                        }
                        if (update.type === "UpdateExpression") {
                            if (getUpdateDirection(update, counter) === wrongDirection) {
                                report(node);
                            }
                        }
                        else if (update.type === "AssignmentExpression" && getAssignmentDirection(update, counter) === wrongDirection) {
                            report(node);
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/func-call-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to control spacing within function calls
     * @author Matt DuVall <http://www.mattduvall.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow spacing between function identifiers and their invocations",
                recommended: false,
                url: "https://eslint.org/docs/rules/func-call-spacing"
            },
            fixable: "whitespace",
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["never"]
                            }
                        ],
                        minItems: 0,
                        maxItems: 1
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always"]
                            },
                            {
                                type: "object",
                                properties: {
                                    allowNewlines: {
                                        type: "boolean"
                                    }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    }
                ]
            },
            messages: {
                unexpectedWhitespace: "Unexpected whitespace between function name and paren.",
                unexpectedNewline: "Unexpected newline between function name and paren.",
                missing: "Missing space between function name and paren."
            }
        },
        create(context) {
            const never = context.options[0] !== "always";
            const allowNewlines = !never && context.options[1] && context.options[1].allowNewlines;
            const sourceCode = context.getSourceCode();
            const text = sourceCode.getText();
            /**
             * Check if open space is present in a function name
             * @param {ASTNode} node node to evaluate
             * @param {Token} leftToken The last token of the callee. This may be the closing parenthesis that encloses the callee.
             * @param {Token} rightToken Tha first token of the arguments. this is the opening parenthesis that encloses the arguments.
             * @returns {void}
             * @private
             */
            function checkSpacing(node, leftToken, rightToken) {
                const textBetweenTokens = text.slice(leftToken.range[1], rightToken.range[0]).replace(/\/\*.*?\*\//gu, "");
                const hasWhitespace = /\s/u.test(textBetweenTokens);
                const hasNewline = hasWhitespace && astUtils.LINEBREAK_MATCHER.test(textBetweenTokens);
                /*
                 * never allowNewlines hasWhitespace hasNewline message
                 * F     F             F             F          Missing space between function name and paren.
                 * F     F             F             T          (Invalid `!hasWhitespace && hasNewline`)
                 * F     F             T             T          Unexpected newline between function name and paren.
                 * F     F             T             F          (OK)
                 * F     T             T             F          (OK)
                 * F     T             T             T          (OK)
                 * F     T             F             T          (Invalid `!hasWhitespace && hasNewline`)
                 * F     T             F             F          Missing space between function name and paren.
                 * T     T             F             F          (Invalid `never && allowNewlines`)
                 * T     T             F             T          (Invalid `!hasWhitespace && hasNewline`)
                 * T     T             T             T          (Invalid `never && allowNewlines`)
                 * T     T             T             F          (Invalid `never && allowNewlines`)
                 * T     F             T             F          Unexpected space between function name and paren.
                 * T     F             T             T          Unexpected space between function name and paren.
                 * T     F             F             T          (Invalid `!hasWhitespace && hasNewline`)
                 * T     F             F             F          (OK)
                 *
                 * T                   T                        Unexpected space between function name and paren.
                 * F                   F                        Missing space between function name and paren.
                 * F     F                           T          Unexpected newline between function name and paren.
                 */
                if (never && hasWhitespace) {
                    context.report({
                        node,
                        loc: {
                            start: leftToken.loc.end,
                            end: {
                                line: rightToken.loc.start.line,
                                column: rightToken.loc.start.column - 1
                            }
                        },
                        messageId: "unexpectedWhitespace",
                        fix(fixer) {
                            // Don't remove comments.
                            if (sourceCode.commentsExistBetween(leftToken, rightToken)) {
                                return null;
                            }
                            // If `?.` exists, it doesn't hide no-unexpected-multiline errors
                            if (node.optional) {
                                return fixer.replaceTextRange([leftToken.range[1], rightToken.range[0]], "?.");
                            }
                            /*
                             * Only autofix if there is no newline
                             * https://github.com/eslint/eslint/issues/7787
                             */
                            if (hasNewline) {
                                return null;
                            }
                            return fixer.removeRange([leftToken.range[1], rightToken.range[0]]);
                        }
                    });
                }
                else if (!never && !hasWhitespace) {
                    context.report({
                        node,
                        loc: {
                            start: {
                                line: leftToken.loc.end.line,
                                column: leftToken.loc.end.column - 1
                            },
                            end: rightToken.loc.start
                        },
                        messageId: "missing",
                        fix(fixer) {
                            if (node.optional) {
                                return null; // Not sure if inserting a space to either before/after `?.` token.
                            }
                            return fixer.insertTextBefore(rightToken, " ");
                        }
                    });
                }
                else if (!never && !allowNewlines && hasNewline) {
                    context.report({
                        node,
                        loc: {
                            start: leftToken.loc.end,
                            end: rightToken.loc.start
                        },
                        messageId: "unexpectedNewline",
                        fix(fixer) {
                            /*
                             * Only autofix if there is no newline
                             * https://github.com/eslint/eslint/issues/7787
                             * But if `?.` exists, it doesn't hide no-unexpected-multiline errors
                             */
                            if (!node.optional) {
                                return null;
                            }
                            // Don't remove comments.
                            if (sourceCode.commentsExistBetween(leftToken, rightToken)) {
                                return null;
                            }
                            const range = [leftToken.range[1], rightToken.range[0]];
                            const qdToken = sourceCode.getTokenAfter(leftToken);
                            if (qdToken.range[0] === leftToken.range[1]) {
                                return fixer.replaceTextRange(range, "?. ");
                            }
                            if (qdToken.range[1] === rightToken.range[0]) {
                                return fixer.replaceTextRange(range, " ?.");
                            }
                            return fixer.replaceTextRange(range, " ?. ");
                        }
                    });
                }
            }
            return {
                "CallExpression, NewExpression"(node) {
                    const lastToken = sourceCode.getLastToken(node);
                    const lastCalleeToken = sourceCode.getLastToken(node.callee);
                    const parenToken = sourceCode.getFirstTokenBetween(lastCalleeToken, lastToken, astUtils.isOpeningParenToken);
                    const prevToken = parenToken && sourceCode.getTokenBefore(parenToken, astUtils.isNotQuestionDotToken);
                    // Parens in NewExpression are optional
                    if (!(parenToken && parenToken.range[1] < node.range[1])) {
                        return;
                    }
                    checkSpacing(node, prevToken, parenToken);
                },
                ImportExpression(node) {
                    const leftToken = sourceCode.getFirstToken(node);
                    const rightToken = sourceCode.getTokenAfter(leftToken);
                    checkSpacing(node, leftToken, rightToken);
                }
            };
        }
    };
},
/* eslint/lib/rules/func-name-matching.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to require function names to match the name of the variable or property to which they are assigned.
     * @author Annie Zhang, Pavel Strashkin
     */
    "use strict";
    //--------------------------------------------------------------------------
    // Requirements
    //--------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const esutils = require(361) /* esutils */;
    //--------------------------------------------------------------------------
    // Helpers
    //--------------------------------------------------------------------------
    /**
     * Determines if a pattern is `module.exports` or `module["exports"]`
     * @param {ASTNode} pattern The left side of the AssignmentExpression
     * @returns {boolean} True if the pattern is `module.exports` or `module["exports"]`
     */
    function isModuleExports(pattern) {
        if (pattern.type === "MemberExpression" && pattern.object.type === "Identifier" && pattern.object.name === "module") {
            // module.exports
            if (pattern.property.type === "Identifier" && pattern.property.name === "exports") {
                return true;
            }
            // module["exports"]
            if (pattern.property.type === "Literal" && pattern.property.value === "exports") {
                return true;
            }
        }
        return false;
    }
    /**
     * Determines if a string name is a valid identifier
     * @param {string} name The string to be checked
     * @param {int} ecmaVersion The ECMAScript version if specified in the parserOptions config
     * @returns {boolean} True if the string is a valid identifier
     */
    function isIdentifier(name, ecmaVersion) {
        if (ecmaVersion >= 2015) {
            return esutils.keyword.isIdentifierES6(name);
        }
        return esutils.keyword.isIdentifierES5(name);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const alwaysOrNever = { enum: ["always", "never"] };
    const optionsObject = {
        type: "object",
        properties: {
            considerPropertyDescriptor: {
                type: "boolean"
            },
            includeCommonJSModuleExports: {
                type: "boolean"
            }
        },
        additionalProperties: false
    };
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require function names to match the name of the variable or property to which they are assigned",
                recommended: false,
                url: "https://eslint.org/docs/rules/func-name-matching"
            },
            schema: {
                anyOf: [{
                        type: "array",
                        additionalItems: false,
                        items: [alwaysOrNever, optionsObject]
                    }, {
                        type: "array",
                        additionalItems: false,
                        items: [optionsObject]
                    }]
            },
            messages: {
                matchProperty: "Function name `{{funcName}}` should match property name `{{name}}`.",
                matchVariable: "Function name `{{funcName}}` should match variable name `{{name}}`.",
                notMatchProperty: "Function name `{{funcName}}` should not match property name `{{name}}`.",
                notMatchVariable: "Function name `{{funcName}}` should not match variable name `{{name}}`."
            }
        },
        create(context) {
            const options = (typeof context.options[0] === "object" ? context.options[0] : context.options[1]) || {};
            const nameMatches = typeof context.options[0] === "string" ? context.options[0] : "always";
            const considerPropertyDescriptor = options.considerPropertyDescriptor;
            const includeModuleExports = options.includeCommonJSModuleExports;
            const ecmaVersion = context.languageOptions.ecmaVersion;
            /**
             * Check whether node is a certain CallExpression.
             * @param {string} objName object name
             * @param {string} funcName function name
             * @param {ASTNode} node The node to check
             * @returns {boolean} `true` if node matches CallExpression
             */
            function isPropertyCall(objName, funcName, node) {
                if (!node) {
                    return false;
                }
                return node.type === "CallExpression" && astUtils.isSpecificMemberAccess(node.callee, objName, funcName);
            }
            /**
             * Compares identifiers based on the nameMatches option
             * @param {string} x the first identifier
             * @param {string} y the second identifier
             * @returns {boolean} whether the two identifiers should warn.
             */
            function shouldWarn(x, y) {
                return (nameMatches === "always" && x !== y) || (nameMatches === "never" && x === y);
            }
            /**
             * Reports
             * @param {ASTNode} node The node to report
             * @param {string} name The variable or property name
             * @param {string} funcName The function name
             * @param {boolean} isProp True if the reported node is a property assignment
             * @returns {void}
             */
            function report(node, name, funcName, isProp) {
                let messageId;
                if (nameMatches === "always" && isProp) {
                    messageId = "matchProperty";
                }
                else if (nameMatches === "always") {
                    messageId = "matchVariable";
                }
                else if (isProp) {
                    messageId = "notMatchProperty";
                }
                else {
                    messageId = "notMatchVariable";
                }
                context.report({
                    node,
                    messageId,
                    data: {
                        name,
                        funcName
                    }
                });
            }
            /**
             * Determines whether a given node is a string literal
             * @param {ASTNode} node The node to check
             * @returns {boolean} `true` if the node is a string literal
             */
            function isStringLiteral(node) {
                return node.type === "Literal" && typeof node.value === "string";
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                VariableDeclarator(node) {
                    if (!node.init || node.init.type !== "FunctionExpression" || node.id.type !== "Identifier") {
                        return;
                    }
                    if (node.init.id && shouldWarn(node.id.name, node.init.id.name)) {
                        report(node, node.id.name, node.init.id.name, false);
                    }
                },
                AssignmentExpression(node) {
                    if (node.right.type !== "FunctionExpression" ||
                        (node.left.computed && node.left.property.type !== "Literal") ||
                        (!includeModuleExports && isModuleExports(node.left)) ||
                        (node.left.type !== "Identifier" && node.left.type !== "MemberExpression")) {
                        return;
                    }
                    const isProp = node.left.type === "MemberExpression";
                    const name = isProp ? astUtils.getStaticPropertyName(node.left) : node.left.name;
                    if (node.right.id && name && isIdentifier(name) && shouldWarn(name, node.right.id.name)) {
                        report(node, name, node.right.id.name, isProp);
                    }
                },
                "Property, PropertyDefinition[value]"(node) {
                    if (!(node.value.type === "FunctionExpression" && node.value.id)) {
                        return;
                    }
                    if (node.key.type === "Identifier" && !node.computed) {
                        const functionName = node.value.id.name;
                        let propertyName = node.key.name;
                        if (considerPropertyDescriptor &&
                            propertyName === "value" &&
                            node.parent.type === "ObjectExpression") {
                            if (isPropertyCall("Object", "defineProperty", node.parent.parent) || isPropertyCall("Reflect", "defineProperty", node.parent.parent)) {
                                const property = node.parent.parent.arguments[1];
                                if (isStringLiteral(property) && shouldWarn(property.value, functionName)) {
                                    report(node, property.value, functionName, true);
                                }
                            }
                            else if (isPropertyCall("Object", "defineProperties", node.parent.parent.parent.parent)) {
                                propertyName = node.parent.parent.key.name;
                                if (!node.parent.parent.computed && shouldWarn(propertyName, functionName)) {
                                    report(node, propertyName, functionName, true);
                                }
                            }
                            else if (isPropertyCall("Object", "create", node.parent.parent.parent.parent)) {
                                propertyName = node.parent.parent.key.name;
                                if (!node.parent.parent.computed && shouldWarn(propertyName, functionName)) {
                                    report(node, propertyName, functionName, true);
                                }
                            }
                            else if (shouldWarn(propertyName, functionName)) {
                                report(node, propertyName, functionName, true);
                            }
                        }
                        else if (shouldWarn(propertyName, functionName)) {
                            report(node, propertyName, functionName, true);
                        }
                        return;
                    }
                    if (isStringLiteral(node.key) &&
                        isIdentifier(node.key.value, ecmaVersion) &&
                        shouldWarn(node.key.value, node.value.id.name)) {
                        report(node, node.key.value, node.value.id.name, true);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/func-names.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to warn when a function expression does not have a name.
     * @author Kyle T. Nunery
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    /**
     * Checks whether or not a given variable is a function name.
     * @param {eslint-scope.Variable} variable A variable to check.
     * @returns {boolean} `true` if the variable is a function name.
     */
    function isFunctionName(variable) {
        return variable && variable.defs[0].type === "FunctionName";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require or disallow named `function` expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/func-names"
            },
            schema: {
                definitions: {
                    value: {
                        enum: [
                            "always",
                            "as-needed",
                            "never"
                        ]
                    }
                },
                items: [
                    {
                        $ref: "#/definitions/value"
                    },
                    {
                        type: "object",
                        properties: {
                            generators: {
                                $ref: "#/definitions/value"
                            }
                        },
                        additionalProperties: false
                    }
                ]
            },
            messages: {
                unnamed: "Unexpected unnamed {{name}}.",
                named: "Unexpected named {{name}}."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Returns the config option for the given node.
             * @param {ASTNode} node A node to get the config for.
             * @returns {string} The config option.
             */
            function getConfigForNode(node) {
                if (node.generator &&
                    context.options.length > 1 &&
                    context.options[1].generators) {
                    return context.options[1].generators;
                }
                return context.options[0] || "always";
            }
            /**
             * Determines whether the current FunctionExpression node is a get, set, or
             * shorthand method in an object literal or a class.
             * @param {ASTNode} node A node to check.
             * @returns {boolean} True if the node is a get, set, or shorthand method.
             */
            function isObjectOrClassMethod(node) {
                const parent = node.parent;
                return (parent.type === "MethodDefinition" || (parent.type === "Property" && (parent.method ||
                    parent.kind === "get" ||
                    parent.kind === "set")));
            }
            /**
             * Determines whether the current FunctionExpression node has a name that would be
             * inferred from context in a conforming ES6 environment.
             * @param {ASTNode} node A node to check.
             * @returns {boolean} True if the node would have a name assigned automatically.
             */
            function hasInferredName(node) {
                const parent = node.parent;
                return isObjectOrClassMethod(node) ||
                    (parent.type === "VariableDeclarator" && parent.id.type === "Identifier" && parent.init === node) ||
                    (parent.type === "Property" && parent.value === node) ||
                    (parent.type === "PropertyDefinition" && parent.value === node) ||
                    (parent.type === "AssignmentExpression" && parent.left.type === "Identifier" && parent.right === node) ||
                    (parent.type === "AssignmentPattern" && parent.left.type === "Identifier" && parent.right === node);
            }
            /**
             * Reports that an unnamed function should be named
             * @param {ASTNode} node The node to report in the event of an error.
             * @returns {void}
             */
            function reportUnexpectedUnnamedFunction(node) {
                context.report({
                    node,
                    messageId: "unnamed",
                    loc: astUtils.getFunctionHeadLoc(node, sourceCode),
                    data: { name: astUtils.getFunctionNameWithKind(node) }
                });
            }
            /**
             * Reports that a named function should be unnamed
             * @param {ASTNode} node The node to report in the event of an error.
             * @returns {void}
             */
            function reportUnexpectedNamedFunction(node) {
                context.report({
                    node,
                    messageId: "named",
                    loc: astUtils.getFunctionHeadLoc(node, sourceCode),
                    data: { name: astUtils.getFunctionNameWithKind(node) }
                });
            }
            /**
             * The listener for function nodes.
             * @param {ASTNode} node function node
             * @returns {void}
             */
            function handleFunction(node) {
                // Skip recursive functions.
                const nameVar = context.getDeclaredVariables(node)[0];
                if (isFunctionName(nameVar) && nameVar.references.length > 0) {
                    return;
                }
                const hasName = Boolean(node.id && node.id.name);
                const config = getConfigForNode(node);
                if (config === "never") {
                    if (hasName && node.type !== "FunctionDeclaration") {
                        reportUnexpectedNamedFunction(node);
                    }
                }
                else if (config === "as-needed") {
                    if (!hasName && !hasInferredName(node)) {
                        reportUnexpectedUnnamedFunction(node);
                    }
                }
                else {
                    if (!hasName && !isObjectOrClassMethod(node)) {
                        reportUnexpectedUnnamedFunction(node);
                    }
                }
            }
            return {
                "FunctionExpression:exit": handleFunction,
                "ExportDefaultDeclaration > FunctionDeclaration": handleFunction
            };
        }
    };
},
/* eslint/lib/rules/func-style.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to enforce a particular function style
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce the consistent use of either `function` declarations or expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/func-style"
            },
            schema: [
                {
                    enum: ["declaration", "expression"]
                },
                {
                    type: "object",
                    properties: {
                        allowArrowFunctions: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                expression: "Expected a function expression.",
                declaration: "Expected a function declaration."
            }
        },
        create(context) {
            const style = context.options[0], allowArrowFunctions = context.options[1] && context.options[1].allowArrowFunctions, enforceDeclarations = (style === "declaration"), stack = [];
            const nodesToCheck = {
                FunctionDeclaration(node) {
                    stack.push(false);
                    if (!enforceDeclarations && node.parent.type !== "ExportDefaultDeclaration") {
                        context.report({ node, messageId: "expression" });
                    }
                },
                "FunctionDeclaration:exit"() {
                    stack.pop();
                },
                FunctionExpression(node) {
                    stack.push(false);
                    if (enforceDeclarations && node.parent.type === "VariableDeclarator") {
                        context.report({ node: node.parent, messageId: "declaration" });
                    }
                },
                "FunctionExpression:exit"() {
                    stack.pop();
                },
                ThisExpression() {
                    if (stack.length > 0) {
                        stack[stack.length - 1] = true;
                    }
                }
            };
            if (!allowArrowFunctions) {
                nodesToCheck.ArrowFunctionExpression = function () {
                    stack.push(false);
                };
                nodesToCheck["ArrowFunctionExpression:exit"] = function (node) {
                    const hasThisExpr = stack.pop();
                    if (enforceDeclarations && !hasThisExpr && node.parent.type === "VariableDeclarator") {
                        context.report({ node: node.parent, messageId: "declaration" });
                    }
                };
            }
            return nodesToCheck;
        }
    };
},
/* eslint/lib/rules/function-call-argument-newline.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce line breaks between arguments of a function call
     * @author Alexey Gonchar <https://github.com/finico>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce line breaks between arguments of a function call",
                recommended: false,
                url: "https://eslint.org/docs/rules/function-call-argument-newline"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never", "consistent"]
                }
            ],
            messages: {
                unexpectedLineBreak: "There should be no line break here.",
                missingLineBreak: "There should be a line break after this argument."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const checkers = {
                unexpected: {
                    messageId: "unexpectedLineBreak",
                    check: (prevToken, currentToken) => prevToken.loc.end.line !== currentToken.loc.start.line,
                    createFix: (token, tokenBefore) => fixer => fixer.replaceTextRange([tokenBefore.range[1], token.range[0]], " ")
                },
                missing: {
                    messageId: "missingLineBreak",
                    check: (prevToken, currentToken) => prevToken.loc.end.line === currentToken.loc.start.line,
                    createFix: (token, tokenBefore) => fixer => fixer.replaceTextRange([tokenBefore.range[1], token.range[0]], "\n")
                }
            };
            /**
             * Check all arguments for line breaks in the CallExpression
             * @param {CallExpression} node node to evaluate
             * @param {{ messageId: string, check: Function }} checker selected checker
             * @returns {void}
             * @private
             */
            function checkArguments(node, checker) {
                for (let i = 1; i < node.arguments.length; i++) {
                    const prevArgToken = sourceCode.getLastToken(node.arguments[i - 1]);
                    const currentArgToken = sourceCode.getFirstToken(node.arguments[i]);
                    if (checker.check(prevArgToken, currentArgToken)) {
                        const tokenBefore = sourceCode.getTokenBefore(currentArgToken, { includeComments: true });
                        const hasLineCommentBefore = tokenBefore.type === "Line";
                        context.report({
                            node,
                            loc: {
                                start: tokenBefore.loc.end,
                                end: currentArgToken.loc.start
                            },
                            messageId: checker.messageId,
                            fix: hasLineCommentBefore ? null : checker.createFix(currentArgToken, tokenBefore)
                        });
                    }
                }
            }
            /**
             * Check if open space is present in a function name
             * @param {CallExpression} node node to evaluate
             * @returns {void}
             * @private
             */
            function check(node) {
                if (node.arguments.length < 2) {
                    return;
                }
                const option = context.options[0] || "always";
                if (option === "never") {
                    checkArguments(node, checkers.unexpected);
                }
                else if (option === "always") {
                    checkArguments(node, checkers.missing);
                }
                else if (option === "consistent") {
                    const firstArgToken = sourceCode.getLastToken(node.arguments[0]);
                    const secondArgToken = sourceCode.getFirstToken(node.arguments[1]);
                    if (firstArgToken.loc.end.line === secondArgToken.loc.start.line) {
                        checkArguments(node, checkers.unexpected);
                    }
                    else {
                        checkArguments(node, checkers.missing);
                    }
                }
            }
            return {
                CallExpression: check,
                NewExpression: check
            };
        }
    };
},
/* eslint/lib/rules/function-paren-newline.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview enforce consistent line breaks inside function parentheses
     * @author Teddy Katz
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent line breaks inside function parentheses",
                recommended: false,
                url: "https://eslint.org/docs/rules/function-paren-newline"
            },
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["always", "never", "consistent", "multiline", "multiline-arguments"]
                        },
                        {
                            type: "object",
                            properties: {
                                minItems: {
                                    type: "integer",
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                expectedBefore: "Expected newline before ')'.",
                expectedAfter: "Expected newline after '('.",
                expectedBetween: "Expected newline between arguments/params.",
                unexpectedBefore: "Unexpected newline before ')'.",
                unexpectedAfter: "Unexpected newline after '('."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const rawOption = context.options[0] || "multiline";
            const multilineOption = rawOption === "multiline";
            const multilineArgumentsOption = rawOption === "multiline-arguments";
            const consistentOption = rawOption === "consistent";
            let minItems;
            if (typeof rawOption === "object") {
                minItems = rawOption.minItems;
            }
            else if (rawOption === "always") {
                minItems = 0;
            }
            else if (rawOption === "never") {
                minItems = Infinity;
            }
            else {
                minItems = null;
            }
            //----------------------------------------------------------------------
            // Helpers
            //----------------------------------------------------------------------
            /**
             * Determines whether there should be newlines inside function parens
             * @param {ASTNode[]} elements The arguments or parameters in the list
             * @param {boolean} hasLeftNewline `true` if the left paren has a newline in the current code.
             * @returns {boolean} `true` if there should be newlines inside the function parens
             */
            function shouldHaveNewlines(elements, hasLeftNewline) {
                if (multilineArgumentsOption && elements.length === 1) {
                    return hasLeftNewline;
                }
                if (multilineOption || multilineArgumentsOption) {
                    return elements.some((element, index) => index !== elements.length - 1 && element.loc.end.line !== elements[index + 1].loc.start.line);
                }
                if (consistentOption) {
                    return hasLeftNewline;
                }
                return elements.length >= minItems;
            }
            /**
             * Validates parens
             * @param {Object} parens An object with keys `leftParen` for the left paren token, and `rightParen` for the right paren token
             * @param {ASTNode[]} elements The arguments or parameters in the list
             * @returns {void}
             */
            function validateParens(parens, elements) {
                const leftParen = parens.leftParen;
                const rightParen = parens.rightParen;
                const tokenAfterLeftParen = sourceCode.getTokenAfter(leftParen);
                const tokenBeforeRightParen = sourceCode.getTokenBefore(rightParen);
                const hasLeftNewline = !astUtils.isTokenOnSameLine(leftParen, tokenAfterLeftParen);
                const hasRightNewline = !astUtils.isTokenOnSameLine(tokenBeforeRightParen, rightParen);
                const needsNewlines = shouldHaveNewlines(elements, hasLeftNewline);
                if (hasLeftNewline && !needsNewlines) {
                    context.report({
                        node: leftParen,
                        messageId: "unexpectedAfter",
                        fix(fixer) {
                            return sourceCode.getText().slice(leftParen.range[1], tokenAfterLeftParen.range[0]).trim()
                                // If there is a comment between the ( and the first element, don't do a fix.
                                ? null
                                : fixer.removeRange([leftParen.range[1], tokenAfterLeftParen.range[0]]);
                        }
                    });
                }
                else if (!hasLeftNewline && needsNewlines) {
                    context.report({
                        node: leftParen,
                        messageId: "expectedAfter",
                        fix: fixer => fixer.insertTextAfter(leftParen, "\n")
                    });
                }
                if (hasRightNewline && !needsNewlines) {
                    context.report({
                        node: rightParen,
                        messageId: "unexpectedBefore",
                        fix(fixer) {
                            return sourceCode.getText().slice(tokenBeforeRightParen.range[1], rightParen.range[0]).trim()
                                // If there is a comment between the last element and the ), don't do a fix.
                                ? null
                                : fixer.removeRange([tokenBeforeRightParen.range[1], rightParen.range[0]]);
                        }
                    });
                }
                else if (!hasRightNewline && needsNewlines) {
                    context.report({
                        node: rightParen,
                        messageId: "expectedBefore",
                        fix: fixer => fixer.insertTextBefore(rightParen, "\n")
                    });
                }
            }
            /**
             * Validates a list of arguments or parameters
             * @param {Object} parens An object with keys `leftParen` for the left paren token, and `rightParen` for the right paren token
             * @param {ASTNode[]} elements The arguments or parameters in the list
             * @returns {void}
             */
            function validateArguments(parens, elements) {
                const leftParen = parens.leftParen;
                const tokenAfterLeftParen = sourceCode.getTokenAfter(leftParen);
                const hasLeftNewline = !astUtils.isTokenOnSameLine(leftParen, tokenAfterLeftParen);
                const needsNewlines = shouldHaveNewlines(elements, hasLeftNewline);
                for (let i = 0; i <= elements.length - 2; i++) {
                    const currentElement = elements[i];
                    const nextElement = elements[i + 1];
                    const hasNewLine = currentElement.loc.end.line !== nextElement.loc.start.line;
                    if (!hasNewLine && needsNewlines) {
                        context.report({
                            node: currentElement,
                            messageId: "expectedBetween",
                            fix: fixer => fixer.insertTextBefore(nextElement, "\n")
                        });
                    }
                }
            }
            /**
             * Gets the left paren and right paren tokens of a node.
             * @param {ASTNode} node The node with parens
             * @throws {TypeError} Unexpected node type.
             * @returns {Object} An object with keys `leftParen` for the left paren token, and `rightParen` for the right paren token.
             * Can also return `null` if an expression has no parens (e.g. a NewExpression with no arguments, or an ArrowFunctionExpression
             * with a single parameter)
             */
            function getParenTokens(node) {
                switch (node.type) {
                    case "NewExpression":
                        if (!node.arguments.length &&
                            !(astUtils.isOpeningParenToken(sourceCode.getLastToken(node, { skip: 1 })) &&
                                astUtils.isClosingParenToken(sourceCode.getLastToken(node)) &&
                                node.callee.range[1] < node.range[1])) {
                            // If the NewExpression does not have parens (e.g. `new Foo`), return null.
                            return null;
                        }
                    // falls through
                    case "CallExpression":
                        return {
                            leftParen: sourceCode.getTokenAfter(node.callee, astUtils.isOpeningParenToken),
                            rightParen: sourceCode.getLastToken(node)
                        };
                    case "FunctionDeclaration":
                    case "FunctionExpression": {
                        const leftParen = sourceCode.getFirstToken(node, astUtils.isOpeningParenToken);
                        const rightParen = node.params.length
                            ? sourceCode.getTokenAfter(node.params[node.params.length - 1], astUtils.isClosingParenToken)
                            : sourceCode.getTokenAfter(leftParen);
                        return { leftParen, rightParen };
                    }
                    case "ArrowFunctionExpression": {
                        const firstToken = sourceCode.getFirstToken(node, { skip: (node.async ? 1 : 0) });
                        if (!astUtils.isOpeningParenToken(firstToken)) {
                            // If the ArrowFunctionExpression has a single param without parens, return null.
                            return null;
                        }
                        const rightParen = node.params.length
                            ? sourceCode.getTokenAfter(node.params[node.params.length - 1], astUtils.isClosingParenToken)
                            : sourceCode.getTokenAfter(firstToken);
                        return {
                            leftParen: firstToken,
                            rightParen
                        };
                    }
                    case "ImportExpression": {
                        const leftParen = sourceCode.getFirstToken(node, 1);
                        const rightParen = sourceCode.getLastToken(node);
                        return { leftParen, rightParen };
                    }
                    default:
                        throw new TypeError(`unexpected node with type ${node.type}`);
                }
            }
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                [[
                    "ArrowFunctionExpression",
                    "CallExpression",
                    "FunctionDeclaration",
                    "FunctionExpression",
                    "ImportExpression",
                    "NewExpression"
                ]](node) {
                    const parens = getParenTokens(node);
                    let params;
                    if (node.type === "ImportExpression") {
                        params = [node.source];
                    }
                    else if (astUtils.isFunction(node)) {
                        params = node.params;
                    }
                    else {
                        params = node.arguments;
                    }
                    if (parens) {
                        validateParens(parens, params);
                        if (multilineArgumentsOption) {
                            validateArguments(parens, params);
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/generator-star-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check the spacing around the * in generator functions.
     * @author Jamund Ferguson
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const OVERRIDE_SCHEMA = {
        oneOf: [
            {
                enum: ["before", "after", "both", "neither"]
            },
            {
                type: "object",
                properties: {
                    before: { type: "boolean" },
                    after: { type: "boolean" }
                },
                additionalProperties: false
            }
        ]
    };
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing around `*` operators in generator functions",
                recommended: false,
                url: "https://eslint.org/docs/rules/generator-star-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["before", "after", "both", "neither"]
                        },
                        {
                            type: "object",
                            properties: {
                                before: { type: "boolean" },
                                after: { type: "boolean" },
                                named: OVERRIDE_SCHEMA,
                                anonymous: OVERRIDE_SCHEMA,
                                method: OVERRIDE_SCHEMA
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                missingBefore: "Missing space before *.",
                missingAfter: "Missing space after *.",
                unexpectedBefore: "Unexpected space before *.",
                unexpectedAfter: "Unexpected space after *."
            }
        },
        create(context) {
            const optionDefinitions = {
                before: { before: true, after: false },
                after: { before: false, after: true },
                both: { before: true, after: true },
                neither: { before: false, after: false }
            };
            /**
             * Returns resolved option definitions based on an option and defaults
             * @param {any} option The option object or string value
             * @param {Object} defaults The defaults to use if options are not present
             * @returns {Object} the resolved object definition
             */
            function optionToDefinition(option, defaults) {
                if (!option) {
                    return defaults;
                }
                return typeof option === "string"
                    ? optionDefinitions[option]
                    : Object.assign({}, defaults, option);
            }
            const modes = (function (option) {
                const defaults = optionToDefinition(option, optionDefinitions.before);
                return {
                    named: optionToDefinition(option.named, defaults),
                    anonymous: optionToDefinition(option.anonymous, defaults),
                    method: optionToDefinition(option.method, defaults)
                };
            }(context.options[0] || {}));
            const sourceCode = context.getSourceCode();
            /**
             * Checks if the given token is a star token or not.
             * @param {Token} token The token to check.
             * @returns {boolean} `true` if the token is a star token.
             */
            function isStarToken(token) {
                return token.value === "*" && token.type === "Punctuator";
            }
            /**
             * Gets the generator star token of the given function node.
             * @param {ASTNode} node The function node to get.
             * @returns {Token} Found star token.
             */
            function getStarToken(node) {
                return sourceCode.getFirstToken((node.parent.method || node.parent.type === "MethodDefinition") ? node.parent : node, isStarToken);
            }
            /**
             * capitalize a given string.
             * @param {string} str the given string.
             * @returns {string} the capitalized string.
             */
            function capitalize(str) {
                return str[0].toUpperCase() + str.slice(1);
            }
            /**
             * Checks the spacing between two tokens before or after the star token.
             * @param {string} kind Either "named", "anonymous", or "method"
             * @param {string} side Either "before" or "after".
             * @param {Token} leftToken `function` keyword token if side is "before", or
             *     star token if side is "after".
             * @param {Token} rightToken Star token if side is "before", or identifier
             *     token if side is "after".
             * @returns {void}
             */
            function checkSpacing(kind, side, leftToken, rightToken) {
                if (!!(rightToken.range[0] - leftToken.range[1]) !== modes[kind][side]) {
                    const after = leftToken.value === "*";
                    const spaceRequired = modes[kind][side];
                    const node = after ? leftToken : rightToken;
                    const messageId = `${spaceRequired ? "missing" : "unexpected"}${capitalize(side)}`;
                    context.report({
                        node,
                        messageId,
                        fix(fixer) {
                            if (spaceRequired) {
                                if (after) {
                                    return fixer.insertTextAfter(node, " ");
                                }
                                return fixer.insertTextBefore(node, " ");
                            }
                            return fixer.removeRange([leftToken.range[1], rightToken.range[0]]);
                        }
                    });
                }
            }
            /**
             * Enforces the spacing around the star if node is a generator function.
             * @param {ASTNode} node A function expression or declaration node.
             * @returns {void}
             */
            function checkFunction(node) {
                if (!node.generator) {
                    return;
                }
                const starToken = getStarToken(node);
                const prevToken = sourceCode.getTokenBefore(starToken);
                const nextToken = sourceCode.getTokenAfter(starToken);
                let kind = "named";
                if (node.parent.type === "MethodDefinition" || (node.parent.type === "Property" && node.parent.method)) {
                    kind = "method";
                }
                else if (!node.id) {
                    kind = "anonymous";
                }
                // Only check before when preceded by `function`|`static` keyword
                if (!(kind === "method" && starToken === sourceCode.getFirstToken(node.parent))) {
                    checkSpacing(kind, "before", prevToken, starToken);
                }
                checkSpacing(kind, "after", starToken, nextToken);
            }
            return {
                FunctionDeclaration: checkFunction,
                FunctionExpression: checkFunction
            };
        }
    };
},
/* eslint/lib/rules/getter-return.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Enforces that a return statement is present in property getters.
     * @author Aladdin-ADD(hh_2013@foxmail.com)
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const TARGET_NODE_TYPE = /^(?:Arrow)?FunctionExpression$/u;
    /**
     * Checks a given code path segment is reachable.
     * @param {CodePathSegment} segment A segment to check.
     * @returns {boolean} `true` if the segment is reachable.
     */
    function isReachable(segment) {
        return segment.reachable;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Enforce `return` statements in getters",
                recommended: true,
                url: "https://eslint.org/docs/rules/getter-return"
            },
            fixable: null,
            schema: [
                {
                    type: "object",
                    properties: {
                        allowImplicit: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                expected: "Expected to return a value in {{name}}.",
                expectedAlways: "Expected {{name}} to always return a value."
            }
        },
        create(context) {
            const options = context.options[0] || { allowImplicit: false };
            const sourceCode = context.getSourceCode();
            let funcInfo = {
                upper: null,
                codePath: null,
                hasReturn: false,
                shouldCheck: false,
                node: null
            };
            /**
             * Checks whether or not the last code path segment is reachable.
             * Then reports this function if the segment is reachable.
             *
             * If the last code path segment is reachable, there are paths which are not
             * returned or thrown.
             * @param {ASTNode} node A node to check.
             * @returns {void}
             */
            function checkLastSegment(node) {
                if (funcInfo.shouldCheck &&
                    funcInfo.codePath.currentSegments.some(isReachable)) {
                    context.report({
                        node,
                        loc: astUtils.getFunctionHeadLoc(node, sourceCode),
                        messageId: funcInfo.hasReturn ? "expectedAlways" : "expected",
                        data: {
                            name: astUtils.getFunctionNameWithKind(funcInfo.node)
                        }
                    });
                }
            }
            /**
             * Checks whether a node means a getter function.
             * @param {ASTNode} node a node to check.
             * @returns {boolean} if node means a getter, return true; else return false.
             */
            function isGetter(node) {
                const parent = node.parent;
                if (TARGET_NODE_TYPE.test(node.type) && node.body.type === "BlockStatement") {
                    if (parent.kind === "get") {
                        return true;
                    }
                    if (parent.type === "Property" && astUtils.getStaticPropertyName(parent) === "get" && parent.parent.type === "ObjectExpression") {
                        // Object.defineProperty() or Reflect.defineProperty()
                        if (parent.parent.parent.type === "CallExpression") {
                            const callNode = parent.parent.parent.callee;
                            if (astUtils.isSpecificMemberAccess(callNode, "Object", "defineProperty") ||
                                astUtils.isSpecificMemberAccess(callNode, "Reflect", "defineProperty")) {
                                return true;
                            }
                        }
                        // Object.defineProperties() or Object.create()
                        if (parent.parent.parent.type === "Property" &&
                            parent.parent.parent.parent.type === "ObjectExpression" &&
                            parent.parent.parent.parent.parent.type === "CallExpression") {
                            const callNode = parent.parent.parent.parent.parent.callee;
                            return astUtils.isSpecificMemberAccess(callNode, "Object", "defineProperties") ||
                                astUtils.isSpecificMemberAccess(callNode, "Object", "create");
                        }
                    }
                }
                return false;
            }
            return {
                // Stacks this function's information.
                onCodePathStart(codePath, node) {
                    funcInfo = {
                        upper: funcInfo,
                        codePath,
                        hasReturn: false,
                        shouldCheck: isGetter(node),
                        node
                    };
                },
                // Pops this function's information.
                onCodePathEnd() {
                    funcInfo = funcInfo.upper;
                },
                // Checks the return statement is valid.
                ReturnStatement(node) {
                    if (funcInfo.shouldCheck) {
                        funcInfo.hasReturn = true;
                        // if allowImplicit: false, should also check node.argument
                        if (!options.allowImplicit && !node.argument) {
                            context.report({
                                node,
                                messageId: "expected",
                                data: {
                                    name: astUtils.getFunctionNameWithKind(funcInfo.node)
                                }
                            });
                        }
                    }
                },
                // Reports a given function if the last path is reachable.
                "FunctionExpression:exit": checkLastSegment,
                "ArrowFunctionExpression:exit": checkLastSegment
            };
        }
    };
},
/* eslint/lib/rules/global-require.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule for disallowing require() outside of the top-level module context
     * @author Jamund Ferguson
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    const ACCEPTABLE_PARENTS = new Set([
        "AssignmentExpression",
        "VariableDeclarator",
        "MemberExpression",
        "ExpressionStatement",
        "CallExpression",
        "ConditionalExpression",
        "Program",
        "VariableDeclaration",
        "ChainExpression"
    ]);
    /**
     * Finds the eslint-scope reference in the given scope.
     * @param {Object} scope The scope to search.
     * @param {ASTNode} node The identifier node.
     * @returns {Reference|null} Returns the found reference or null if none were found.
     */
    function findReference(scope, node) {
        const references = scope.references.filter(reference => reference.identifier.range[0] === node.range[0] &&
            reference.identifier.range[1] === node.range[1]);
        if (references.length === 1) {
            return references[0];
        }
        /* c8 ignore next */
        return null;
    }
    /**
     * Checks if the given identifier node is shadowed in the given scope.
     * @param {Object} scope The current scope.
     * @param {ASTNode} node The identifier node to check.
     * @returns {boolean} Whether or not the name is shadowed.
     */
    function isShadowed(scope, node) {
        const reference = findReference(scope, node);
        return reference && reference.resolved && reference.resolved.defs.length > 0;
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Require `require()` calls to be placed at top-level module scope",
                recommended: false,
                url: "https://eslint.org/docs/rules/global-require"
            },
            schema: [],
            messages: {
                unexpected: "Unexpected require()."
            }
        },
        create(context) {
            return {
                CallExpression(node) {
                    const currentScope = context.getScope();
                    if (node.callee.name === "require" && !isShadowed(currentScope, node.callee)) {
                        const isGoodRequire = context.getAncestors().every(parent => ACCEPTABLE_PARENTS.has(parent.type));
                        if (!isGoodRequire) {
                            context.report({ node, messageId: "unexpected" });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/grouped-accessor-pairs.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to require grouped accessor pairs in object literals and classes
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /**
     * Property name if it can be computed statically, otherwise the list of the tokens of the key node.
     * @typedef {string|Token[]} Key
     */
    /**
     * Accessor nodes with the same key.
     * @typedef {Object} AccessorData
     * @property {Key} key Accessor's key
     * @property {ASTNode[]} getters List of getter nodes.
     * @property {ASTNode[]} setters List of setter nodes.
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not the given lists represent the equal tokens in the same order.
     * Tokens are compared by their properties, not by instance.
     * @param {Token[]} left First list of tokens.
     * @param {Token[]} right Second list of tokens.
     * @returns {boolean} `true` if the lists have same tokens.
     */
    function areEqualTokenLists(left, right) {
        if (left.length !== right.length) {
            return false;
        }
        for (let i = 0; i < left.length; i++) {
            const leftToken = left[i], rightToken = right[i];
            if (leftToken.type !== rightToken.type || leftToken.value !== rightToken.value) {
                return false;
            }
        }
        return true;
    }
    /**
     * Checks whether or not the given keys are equal.
     * @param {Key} left First key.
     * @param {Key} right Second key.
     * @returns {boolean} `true` if the keys are equal.
     */
    function areEqualKeys(left, right) {
        if (typeof left === "string" && typeof right === "string") {
            // Statically computed names.
            return left === right;
        }
        if (Array.isArray(left) && Array.isArray(right)) {
            // Token lists.
            return areEqualTokenLists(left, right);
        }
        return false;
    }
    /**
     * Checks whether or not a given node is of an accessor kind ('get' or 'set').
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node is of an accessor kind.
     */
    function isAccessorKind(node) {
        return node.kind === "get" || node.kind === "set";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require grouped accessor pairs in object literals and classes",
                recommended: false,
                url: "https://eslint.org/docs/rules/grouped-accessor-pairs"
            },
            schema: [
                {
                    enum: ["anyOrder", "getBeforeSet", "setBeforeGet"]
                }
            ],
            messages: {
                notGrouped: "Accessor pair {{ formerName }} and {{ latterName }} should be grouped.",
                invalidOrder: "Expected {{ latterName }} to be before {{ formerName }}."
            }
        },
        create(context) {
            const order = context.options[0] || "anyOrder";
            const sourceCode = context.getSourceCode();
            /**
             * Reports the given accessor pair.
             * @param {string} messageId messageId to report.
             * @param {ASTNode} formerNode getter/setter node that is defined before `latterNode`.
             * @param {ASTNode} latterNode getter/setter node that is defined after `formerNode`.
             * @returns {void}
             * @private
             */
            function report(messageId, formerNode, latterNode) {
                context.report({
                    node: latterNode,
                    messageId,
                    loc: astUtils.getFunctionHeadLoc(latterNode.value, sourceCode),
                    data: {
                        formerName: astUtils.getFunctionNameWithKind(formerNode.value),
                        latterName: astUtils.getFunctionNameWithKind(latterNode.value)
                    }
                });
            }
            /**
             * Creates a new `AccessorData` object for the given getter or setter node.
             * @param {ASTNode} node A getter or setter node.
             * @returns {AccessorData} New `AccessorData` object that contains the given node.
             * @private
             */
            function createAccessorData(node) {
                const name = astUtils.getStaticPropertyName(node);
                const key = (name !== null) ? name : sourceCode.getTokens(node.key);
                return {
                    key,
                    getters: node.kind === "get" ? [node] : [],
                    setters: node.kind === "set" ? [node] : []
                };
            }
            /**
             * Merges the given `AccessorData` object into the given accessors list.
             * @param {AccessorData[]} accessors The list to merge into.
             * @param {AccessorData} accessorData The object to merge.
             * @returns {AccessorData[]} The same instance with the merged object.
             * @private
             */
            function mergeAccessorData(accessors, accessorData) {
                const equalKeyElement = accessors.find(a => areEqualKeys(a.key, accessorData.key));
                if (equalKeyElement) {
                    equalKeyElement.getters.push(...accessorData.getters);
                    equalKeyElement.setters.push(...accessorData.setters);
                }
                else {
                    accessors.push(accessorData);
                }
                return accessors;
            }
            /**
             * Checks accessor pairs in the given list of nodes.
             * @param {ASTNode[]} nodes The list to check.
             * @param {Function} shouldCheck – Predicate that returns `true` if the node should be checked.
             * @returns {void}
             * @private
             */
            function checkList(nodes, shouldCheck) {
                const accessors = nodes
                    .filter(shouldCheck)
                    .filter(isAccessorKind)
                    .map(createAccessorData)
                    .reduce(mergeAccessorData, []);
                for (const { getters, setters } of accessors) {
                    // Don't report accessor properties that have duplicate getters or setters.
                    if (getters.length === 1 && setters.length === 1) {
                        const [getter] = getters, [setter] = setters, getterIndex = nodes.indexOf(getter), setterIndex = nodes.indexOf(setter), formerNode = getterIndex < setterIndex ? getter : setter, latterNode = getterIndex < setterIndex ? setter : getter;
                        if (Math.abs(getterIndex - setterIndex) > 1) {
                            report("notGrouped", formerNode, latterNode);
                        }
                        else if ((order === "getBeforeSet" && getterIndex > setterIndex) ||
                            (order === "setBeforeGet" && getterIndex < setterIndex)) {
                            report("invalidOrder", formerNode, latterNode);
                        }
                    }
                }
            }
            return {
                ObjectExpression(node) {
                    checkList(node.properties, n => n.type === "Property");
                },
                ClassBody(node) {
                    checkList(node.body, n => n.type === "MethodDefinition" && !n.static);
                    checkList(node.body, n => n.type === "MethodDefinition" && n.static);
                }
            };
        }
    };
},
/* eslint/lib/rules/guard-for-in.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag for-in loops without if statements inside
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require `for-in` loops to include an `if` statement",
                recommended: false,
                url: "https://eslint.org/docs/rules/guard-for-in"
            },
            schema: [],
            messages: {
                wrap: "The body of a for-in should be wrapped in an if statement to filter unwanted properties from the prototype."
            }
        },
        create(context) {
            return {
                ForInStatement(node) {
                    const body = node.body;
                    // empty statement
                    if (body.type === "EmptyStatement") {
                        return;
                    }
                    // if statement
                    if (body.type === "IfStatement") {
                        return;
                    }
                    // empty block
                    if (body.type === "BlockStatement" && body.body.length === 0) {
                        return;
                    }
                    // block with just if statement
                    if (body.type === "BlockStatement" && body.body.length === 1 && body.body[0].type === "IfStatement") {
                        return;
                    }
                    // block that starts with if statement
                    if (body.type === "BlockStatement" && body.body.length >= 1 && body.body[0].type === "IfStatement") {
                        const i = body.body[0];
                        // ... whose consequent is a continue
                        if (i.consequent.type === "ContinueStatement") {
                            return;
                        }
                        // ... whose consequent is a block that contains only a continue
                        if (i.consequent.type === "BlockStatement" && i.consequent.body.length === 1 && i.consequent.body[0].type === "ContinueStatement") {
                            return;
                        }
                    }
                    context.report({ node, messageId: "wrap" });
                }
            };
        }
    };
},
/* eslint/lib/rules/handle-callback-err.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Ensure handling of errors when we know they exist.
     * @author Jamund Ferguson
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Require error handling in callbacks",
                recommended: false,
                url: "https://eslint.org/docs/rules/handle-callback-err"
            },
            schema: [
                {
                    type: "string"
                }
            ],
            messages: {
                expected: "Expected error to be handled."
            }
        },
        create(context) {
            const errorArgument = context.options[0] || "err";
            /**
             * Checks if the given argument should be interpreted as a regexp pattern.
             * @param {string} stringToCheck The string which should be checked.
             * @returns {boolean} Whether or not the string should be interpreted as a pattern.
             */
            function isPattern(stringToCheck) {
                const firstChar = stringToCheck[0];
                return firstChar === "^";
            }
            /**
             * Checks if the given name matches the configured error argument.
             * @param {string} name The name which should be compared.
             * @returns {boolean} Whether or not the given name matches the configured error variable name.
             */
            function matchesConfiguredErrorName(name) {
                if (isPattern(errorArgument)) {
                    const regexp = new RegExp(errorArgument, "u");
                    return regexp.test(name);
                }
                return name === errorArgument;
            }
            /**
             * Get the parameters of a given function scope.
             * @param {Object} scope The function scope.
             * @returns {Array} All parameters of the given scope.
             */
            function getParameters(scope) {
                return scope.variables.filter(variable => variable.defs[0] && variable.defs[0].type === "Parameter");
            }
            /**
             * Check to see if we're handling the error object properly.
             * @param {ASTNode} node The AST node to check.
             * @returns {void}
             */
            function checkForError(node) {
                const scope = context.getScope(), parameters = getParameters(scope), firstParameter = parameters[0];
                if (firstParameter && matchesConfiguredErrorName(firstParameter.name)) {
                    if (firstParameter.references.length === 0) {
                        context.report({ node, messageId: "expected" });
                    }
                }
            }
            return {
                FunctionDeclaration: checkForError,
                FunctionExpression: checkForError,
                ArrowFunctionExpression: checkForError
            };
        }
    };
},
/* eslint/lib/rules/id-blacklist.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule that warns when identifier names that are
     * specified in the configuration are used.
     * @author Keith Cirkel (http://keithcirkel.co.uk)
     * @deprecated in ESLint v7.5.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether the given node represents assignment target in a normal assignment or destructuring.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is assignment target.
     */
    function isAssignmentTarget(node) {
        const parent = node.parent;
        return (
        // normal assignment
        (parent.type === "AssignmentExpression" &&
            parent.left === node) ||
            // destructuring
            parent.type === "ArrayPattern" ||
            parent.type === "RestElement" ||
            (parent.type === "Property" &&
                parent.value === node &&
                parent.parent.type === "ObjectPattern") ||
            (parent.type === "AssignmentPattern" &&
                parent.left === node));
    }
    /**
     * Checks whether the given node represents an imported name that is renamed in the same import/export specifier.
     *
     * Examples:
     * import { a as b } from 'mod'; // node `a` is renamed import
     * export { a as b } from 'mod'; // node `a` is renamed import
     * @param {ASTNode} node `Identifier` node to check.
     * @returns {boolean} `true` if the node is a renamed import.
     */
    function isRenamedImport(node) {
        const parent = node.parent;
        return ((parent.type === "ImportSpecifier" &&
            parent.imported !== parent.local &&
            parent.imported === node) ||
            (parent.type === "ExportSpecifier" &&
                parent.parent.source && // re-export
                parent.local !== parent.exported &&
                parent.local === node));
    }
    /**
     * Checks whether the given node is a renamed identifier node in an ObjectPattern destructuring.
     *
     * Examples:
     * const { a : b } = foo; // node `a` is renamed node.
     * @param {ASTNode} node `Identifier` node to check.
     * @returns {boolean} `true` if the node is a renamed node in an ObjectPattern destructuring.
     */
    function isRenamedInDestructuring(node) {
        const parent = node.parent;
        return ((!parent.computed &&
            parent.type === "Property" &&
            parent.parent.type === "ObjectPattern" &&
            parent.value !== node &&
            parent.key === node));
    }
    /**
     * Checks whether the given node represents shorthand definition of a property in an object literal.
     * @param {ASTNode} node `Identifier` node to check.
     * @returns {boolean} `true` if the node is a shorthand property definition.
     */
    function isShorthandPropertyDefinition(node) {
        const parent = node.parent;
        return (parent.type === "Property" &&
            parent.parent.type === "ObjectExpression" &&
            parent.shorthand);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: ["id-denylist"],
            type: "suggestion",
            docs: {
                description: "Disallow specified identifiers",
                recommended: false,
                url: "https://eslint.org/docs/rules/id-blacklist"
            },
            schema: {
                type: "array",
                items: {
                    type: "string"
                },
                uniqueItems: true
            },
            messages: {
                restricted: "Identifier '{{name}}' is restricted."
            }
        },
        create(context) {
            const denyList = new Set(context.options);
            const reportedNodes = new Set();
            let globalScope;
            /**
             * Checks whether the given name is restricted.
             * @param {string} name The name to check.
             * @returns {boolean} `true` if the name is restricted.
             * @private
             */
            function isRestricted(name) {
                return denyList.has(name);
            }
            /**
             * Checks whether the given node represents a reference to a global variable that is not declared in the source code.
             * These identifiers will be allowed, as it is assumed that user has no control over the names of external global variables.
             * @param {ASTNode} node `Identifier` node to check.
             * @returns {boolean} `true` if the node is a reference to a global variable.
             */
            function isReferenceToGlobalVariable(node) {
                const variable = globalScope.set.get(node.name);
                return variable && variable.defs.length === 0 &&
                    variable.references.some(ref => ref.identifier === node);
            }
            /**
             * Determines whether the given node should be checked.
             * @param {ASTNode} node `Identifier` node.
             * @returns {boolean} `true` if the node should be checked.
             */
            function shouldCheck(node) {
                const parent = node.parent;
                /*
                 * Member access has special rules for checking property names.
                 * Read access to a property with a restricted name is allowed, because it can be on an object that user has no control over.
                 * Write access isn't allowed, because it potentially creates a new property with a restricted name.
                 */
                if (parent.type === "MemberExpression" &&
                    parent.property === node &&
                    !parent.computed) {
                    return isAssignmentTarget(parent);
                }
                return (parent.type !== "CallExpression" &&
                    parent.type !== "NewExpression" &&
                    !isRenamedImport(node) &&
                    !isRenamedInDestructuring(node) &&
                    !(isReferenceToGlobalVariable(node) &&
                        !isShorthandPropertyDefinition(node)));
            }
            /**
             * Reports an AST node as a rule violation.
             * @param {ASTNode} node The node to report.
             * @returns {void}
             * @private
             */
            function report(node) {
                /*
                 * We used the range instead of the node because it's possible
                 * for the same identifier to be represented by two different
                 * nodes, with the most clear example being shorthand properties:
                 * { foo }
                 * In this case, "foo" is represented by one node for the name
                 * and one for the value. The only way to know they are the same
                 * is to look at the range.
                 */
                if (!reportedNodes.has(node.range.toString())) {
                    context.report({
                        node,
                        messageId: "restricted",
                        data: {
                            name: node.name
                        }
                    });
                    reportedNodes.add(node.range.toString());
                }
            }
            return {
                Program() {
                    globalScope = context.getScope();
                },
                Identifier(node) {
                    if (isRestricted(node.name) && shouldCheck(node)) {
                        report(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/id-denylist.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule that warns when identifier names that are
     * specified in the configuration are used.
     * @author Keith Cirkel (http://keithcirkel.co.uk)
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether the given node represents assignment target in a normal assignment or destructuring.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is assignment target.
     */
    function isAssignmentTarget(node) {
        const parent = node.parent;
        return (
        // normal assignment
        (parent.type === "AssignmentExpression" &&
            parent.left === node) ||
            // destructuring
            parent.type === "ArrayPattern" ||
            parent.type === "RestElement" ||
            (parent.type === "Property" &&
                parent.value === node &&
                parent.parent.type === "ObjectPattern") ||
            (parent.type === "AssignmentPattern" &&
                parent.left === node));
    }
    /**
     * Checks whether the given node represents an imported name that is renamed in the same import/export specifier.
     *
     * Examples:
     * import { a as b } from 'mod'; // node `a` is renamed import
     * export { a as b } from 'mod'; // node `a` is renamed import
     * @param {ASTNode} node `Identifier` node to check.
     * @returns {boolean} `true` if the node is a renamed import.
     */
    function isRenamedImport(node) {
        const parent = node.parent;
        return ((parent.type === "ImportSpecifier" &&
            parent.imported !== parent.local &&
            parent.imported === node) ||
            (parent.type === "ExportSpecifier" &&
                parent.parent.source && // re-export
                parent.local !== parent.exported &&
                parent.local === node));
    }
    /**
     * Checks whether the given node is an ObjectPattern destructuring.
     *
     * Examples:
     * const { a : b } = foo;
     * @param {ASTNode} node `Identifier` node to check.
     * @returns {boolean} `true` if the node is in an ObjectPattern destructuring.
     */
    function isPropertyNameInDestructuring(node) {
        const parent = node.parent;
        return ((!parent.computed &&
            parent.type === "Property" &&
            parent.parent.type === "ObjectPattern" &&
            parent.key === node));
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow specified identifiers",
                recommended: false,
                url: "https://eslint.org/docs/rules/id-denylist"
            },
            schema: {
                type: "array",
                items: {
                    type: "string"
                },
                uniqueItems: true
            },
            messages: {
                restricted: "Identifier '{{name}}' is restricted.",
                restrictedPrivate: "Identifier '#{{name}}' is restricted."
            }
        },
        create(context) {
            const denyList = new Set(context.options);
            const reportedNodes = new Set();
            let globalScope;
            /**
             * Checks whether the given name is restricted.
             * @param {string} name The name to check.
             * @returns {boolean} `true` if the name is restricted.
             * @private
             */
            function isRestricted(name) {
                return denyList.has(name);
            }
            /**
             * Checks whether the given node represents a reference to a global variable that is not declared in the source code.
             * These identifiers will be allowed, as it is assumed that user has no control over the names of external global variables.
             * @param {ASTNode} node `Identifier` node to check.
             * @returns {boolean} `true` if the node is a reference to a global variable.
             */
            function isReferenceToGlobalVariable(node) {
                const variable = globalScope.set.get(node.name);
                return variable && variable.defs.length === 0 &&
                    variable.references.some(ref => ref.identifier === node);
            }
            /**
             * Determines whether the given node should be checked.
             * @param {ASTNode} node `Identifier` node.
             * @returns {boolean} `true` if the node should be checked.
             */
            function shouldCheck(node) {
                const parent = node.parent;
                /*
                 * Member access has special rules for checking property names.
                 * Read access to a property with a restricted name is allowed, because it can be on an object that user has no control over.
                 * Write access isn't allowed, because it potentially creates a new property with a restricted name.
                 */
                if (parent.type === "MemberExpression" &&
                    parent.property === node &&
                    !parent.computed) {
                    return isAssignmentTarget(parent);
                }
                return (parent.type !== "CallExpression" &&
                    parent.type !== "NewExpression" &&
                    !isRenamedImport(node) &&
                    !isPropertyNameInDestructuring(node) &&
                    !isReferenceToGlobalVariable(node));
            }
            /**
             * Reports an AST node as a rule violation.
             * @param {ASTNode} node The node to report.
             * @returns {void}
             * @private
             */
            function report(node) {
                /*
                 * We used the range instead of the node because it's possible
                 * for the same identifier to be represented by two different
                 * nodes, with the most clear example being shorthand properties:
                 * { foo }
                 * In this case, "foo" is represented by one node for the name
                 * and one for the value. The only way to know they are the same
                 * is to look at the range.
                 */
                if (!reportedNodes.has(node.range.toString())) {
                    const isPrivate = node.type === "PrivateIdentifier";
                    context.report({
                        node,
                        messageId: isPrivate ? "restrictedPrivate" : "restricted",
                        data: {
                            name: node.name
                        }
                    });
                    reportedNodes.add(node.range.toString());
                }
            }
            return {
                Program() {
                    globalScope = context.getScope();
                },
                [[
                    "Identifier",
                    "PrivateIdentifier"
                ]](node) {
                    if (isRestricted(node.name) && shouldCheck(node)) {
                        report(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/id-length.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule that warns when identifier names are shorter or longer
     * than the values provided in configuration.
     * @author Burak Yigit Kaya aka BYK
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const GraphemeSplitter = require(414) /* grapheme-splitter */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks if the string given as argument is ASCII or not.
     * @param {string} value A string that you want to know if it is ASCII or not.
     * @returns {boolean} `true` if `value` is ASCII string.
     */
    function isASCII(value) {
        if (typeof value !== "string") {
            return false;
        }
        return /^[\u0020-\u007f]*$/u.test(value);
    }
    /** @type {GraphemeSplitter | undefined} */
    let splitter;
    /**
     * Gets the length of the string. If the string is not in ASCII, counts graphemes.
     * @param {string} value A string that you want to get the length.
     * @returns {number} The length of `value`.
     */
    function getStringLength(value) {
        if (isASCII(value)) {
            return value.length;
        }
        if (!splitter) {
            splitter = new GraphemeSplitter();
        }
        return splitter.countGraphemes(value);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce minimum and maximum identifier lengths",
                recommended: false,
                url: "https://eslint.org/docs/rules/id-length"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        min: {
                            type: "integer",
                            default: 2
                        },
                        max: {
                            type: "integer"
                        },
                        exceptions: {
                            type: "array",
                            uniqueItems: true,
                            items: {
                                type: "string"
                            }
                        },
                        exceptionPatterns: {
                            type: "array",
                            uniqueItems: true,
                            items: {
                                type: "string"
                            }
                        },
                        properties: {
                            enum: ["always", "never"]
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                tooShort: "Identifier name '{{name}}' is too short (< {{min}}).",
                tooShortPrivate: "Identifier name '#{{name}}' is too short (< {{min}}).",
                tooLong: "Identifier name '{{name}}' is too long (> {{max}}).",
                tooLongPrivate: "Identifier name #'{{name}}' is too long (> {{max}})."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const minLength = typeof options.min !== "undefined" ? options.min : 2;
            const maxLength = typeof options.max !== "undefined" ? options.max : Infinity;
            const properties = options.properties !== "never";
            const exceptions = new Set(options.exceptions);
            const exceptionPatterns = (options.exceptionPatterns || []).map(pattern => new RegExp(pattern, "u"));
            const reportedNodes = new Set();
            /**
             * Checks if a string matches the provided exception patterns
             * @param {string} name The string to check.
             * @returns {boolean} if the string is a match
             * @private
             */
            function matchesExceptionPattern(name) {
                return exceptionPatterns.some(pattern => pattern.test(name));
            }
            const SUPPORTED_EXPRESSIONS = {
                MemberExpression: properties && function (parent) {
                    return !parent.computed && (
                    // regular property assignment
                    (parent.parent.left === parent && parent.parent.type === "AssignmentExpression" ||
                        // or the last identifier in an ObjectPattern destructuring
                        parent.parent.type === "Property" && parent.parent.value === parent &&
                            parent.parent.parent.type === "ObjectPattern" && parent.parent.parent.parent.left === parent.parent.parent));
                },
                AssignmentPattern(parent, node) {
                    return parent.left === node;
                },
                VariableDeclarator(parent, node) {
                    return parent.id === node;
                },
                Property(parent, node) {
                    if (parent.parent.type === "ObjectPattern") {
                        const isKeyAndValueSame = parent.value.name === parent.key.name;
                        return (!isKeyAndValueSame && parent.value === node ||
                            isKeyAndValueSame && parent.key === node && properties);
                    }
                    return properties && !parent.computed && parent.key.name === node.name;
                },
                ImportDefaultSpecifier: true,
                RestElement: true,
                FunctionExpression: true,
                ArrowFunctionExpression: true,
                ClassDeclaration: true,
                FunctionDeclaration: true,
                MethodDefinition: true,
                PropertyDefinition: true,
                CatchClause: true,
                ArrayPattern: true
            };
            return {
                [[
                    "Identifier",
                    "PrivateIdentifier"
                ]](node) {
                    const name = node.name;
                    const parent = node.parent;
                    const nameLength = getStringLength(name);
                    const isShort = nameLength < minLength;
                    const isLong = nameLength > maxLength;
                    if (!(isShort || isLong) || exceptions.has(name) || matchesExceptionPattern(name)) {
                        return; // Nothing to report
                    }
                    const isValidExpression = SUPPORTED_EXPRESSIONS[parent.type];
                    /*
                     * We used the range instead of the node because it's possible
                     * for the same identifier to be represented by two different
                     * nodes, with the most clear example being shorthand properties:
                     * { foo }
                     * In this case, "foo" is represented by one node for the name
                     * and one for the value. The only way to know they are the same
                     * is to look at the range.
                     */
                    if (isValidExpression && !reportedNodes.has(node.range.toString()) && (isValidExpression === true || isValidExpression(parent, node))) {
                        reportedNodes.add(node.range.toString());
                        let messageId = isShort ? "tooShort" : "tooLong";
                        if (node.type === "PrivateIdentifier") {
                            messageId += "Private";
                        }
                        context.report({
                            node,
                            messageId,
                            data: { name, min: minLength, max: maxLength }
                        });
                    }
                }
            };
        }
    };
},
/* grapheme-splitter/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
    Breaks a Javascript string into individual user-perceived "characters"
    called extended grapheme clusters by implementing the Unicode UAX-29 standard, version 10.0.0
    
    Usage:
    var splitter = new GraphemeSplitter();
    //returns an array of strings, one string for each grapheme cluster
    var graphemes = splitter.splitGraphemes(string);
    
    */
    function GraphemeSplitter() {
        var CR = 0, LF = 1, Control = 2, Extend = 3, Regional_Indicator = 4, SpacingMark = 5, L = 6, V = 7, T = 8, LV = 9, LVT = 10, Other = 11, Prepend = 12, E_Base = 13, E_Modifier = 14, ZWJ = 15, Glue_After_Zwj = 16, E_Base_GAZ = 17;
        // BreakTypes
        var NotBreak = 0, BreakStart = 1, Break = 2, BreakLastRegional = 3, BreakPenultimateRegional = 4;
        function isSurrogate(str, pos) {
            return 0xd800 <= str.charCodeAt(pos) && str.charCodeAt(pos) <= 0xdbff &&
                0xdc00 <= str.charCodeAt(pos + 1) && str.charCodeAt(pos + 1) <= 0xdfff;
        }
        // Private function, gets a Unicode code point from a JavaScript UTF-16 string
        // handling surrogate pairs appropriately
        function codePointAt(str, idx) {
            if (idx === undefined) {
                idx = 0;
            }
            var code = str.charCodeAt(idx);
            // if a high surrogate
            if (0xD800 <= code && code <= 0xDBFF &&
                idx < str.length - 1) {
                var hi = code;
                var low = str.charCodeAt(idx + 1);
                if (0xDC00 <= low && low <= 0xDFFF) {
                    return ((hi - 0xD800) * 0x400) + (low - 0xDC00) + 0x10000;
                }
                return hi;
            }
            // if a low surrogate
            if (0xDC00 <= code && code <= 0xDFFF &&
                idx >= 1) {
                var hi = str.charCodeAt(idx - 1);
                var low = code;
                if (0xD800 <= hi && hi <= 0xDBFF) {
                    return ((hi - 0xD800) * 0x400) + (low - 0xDC00) + 0x10000;
                }
                return low;
            }
            //just return the char if an unmatched surrogate half or a 
            //single-char codepoint
            return code;
        }
        // Private function, returns whether a break is allowed between the 
        // two given grapheme breaking classes
        function shouldBreak(start, mid, end) {
            var all = [start].concat(mid).concat([end]);
            var previous = all[all.length - 2];
            var next = end;
            // Lookahead termintor for:
            // GB10. (E_Base | EBG) Extend* ?	E_Modifier
            var eModifierIndex = all.lastIndexOf(E_Modifier);
            if (eModifierIndex > 1 &&
                all.slice(1, eModifierIndex).every(function (c) { return c == Extend; }) &&
                [Extend, E_Base, E_Base_GAZ].indexOf(start) == -1) {
                return Break;
            }
            // Lookahead termintor for:
            // GB12. ^ (RI RI)* RI	?	RI
            // GB13. [^RI] (RI RI)* RI	?	RI
            var rIIndex = all.lastIndexOf(Regional_Indicator);
            if (rIIndex > 0 &&
                all.slice(1, rIIndex).every(function (c) { return c == Regional_Indicator; }) &&
                [Prepend, Regional_Indicator].indexOf(previous) == -1) {
                if (all.filter(function (c) { return c == Regional_Indicator; }).length % 2 == 1) {
                    return BreakLastRegional;
                }
                else {
                    return BreakPenultimateRegional;
                }
            }
            // GB3. CR X LF
            if (previous == CR && next == LF) {
                return NotBreak;
            }
            // GB4. (Control|CR|LF) ÷
            else if (previous == Control || previous == CR || previous == LF) {
                if (next == E_Modifier && mid.every(function (c) { return c == Extend; })) {
                    return Break;
                }
                else {
                    return BreakStart;
                }
            }
            // GB5. ÷ (Control|CR|LF)
            else if (next == Control || next == CR || next == LF) {
                return BreakStart;
            }
            // GB6. L X (L|V|LV|LVT)
            else if (previous == L &&
                (next == L || next == V || next == LV || next == LVT)) {
                return NotBreak;
            }
            // GB7. (LV|V) X (V|T)
            else if ((previous == LV || previous == V) &&
                (next == V || next == T)) {
                return NotBreak;
            }
            // GB8. (LVT|T) X (T)
            else if ((previous == LVT || previous == T) &&
                next == T) {
                return NotBreak;
            }
            // GB9. X (Extend|ZWJ)
            else if (next == Extend || next == ZWJ) {
                return NotBreak;
            }
            // GB9a. X SpacingMark
            else if (next == SpacingMark) {
                return NotBreak;
            }
            // GB9b. Prepend X
            else if (previous == Prepend) {
                return NotBreak;
            }
            // GB10. (E_Base | EBG) Extend* ?	E_Modifier
            var previousNonExtendIndex = all.indexOf(Extend) != -1 ? all.lastIndexOf(Extend) - 1 : all.length - 2;
            if ([E_Base, E_Base_GAZ].indexOf(all[previousNonExtendIndex]) != -1 &&
                all.slice(previousNonExtendIndex + 1, -1).every(function (c) { return c == Extend; }) &&
                next == E_Modifier) {
                return NotBreak;
            }
            // GB11. ZWJ ? (Glue_After_Zwj | EBG)
            if (previous == ZWJ && [Glue_After_Zwj, E_Base_GAZ].indexOf(next) != -1) {
                return NotBreak;
            }
            // GB12. ^ (RI RI)* RI ? RI
            // GB13. [^RI] (RI RI)* RI ? RI
            if (mid.indexOf(Regional_Indicator) != -1) {
                return Break;
            }
            if (previous == Regional_Indicator && next == Regional_Indicator) {
                return NotBreak;
            }
            // GB999. Any ? Any
            return BreakStart;
        }
        // Returns the next grapheme break in the string after the given index
        this.nextBreak = function (string, index) {
            if (index === undefined) {
                index = 0;
            }
            if (index < 0) {
                return 0;
            }
            if (index >= string.length - 1) {
                return string.length;
            }
            var prev = getGraphemeBreakProperty(codePointAt(string, index));
            var mid = [];
            for (var i = index + 1; i < string.length; i++) {
                // check for already processed low surrogates
                if (isSurrogate(string, i - 1)) {
                    continue;
                }
                var next = getGraphemeBreakProperty(codePointAt(string, i));
                if (shouldBreak(prev, mid, next)) {
                    return i;
                }
                mid.push(next);
            }
            return string.length;
        };
        // Breaks the given string into an array of grapheme cluster strings
        this.splitGraphemes = function (str) {
            var res = [];
            var index = 0;
            var brk;
            while ((brk = this.nextBreak(str, index)) < str.length) {
                res.push(str.slice(index, brk));
                index = brk;
            }
            if (index < str.length) {
                res.push(str.slice(index));
            }
            return res;
        };
        // Returns the iterator of grapheme clusters there are in the given string
        this.iterateGraphemes = function (str) {
            var index = 0;
            var res = {
                next: (function () {
                    var value;
                    var brk;
                    if ((brk = this.nextBreak(str, index)) < str.length) {
                        value = str.slice(index, brk);
                        index = brk;
                        return { value: value, done: false };
                    }
                    if (index < str.length) {
                        value = str.slice(index);
                        index = str.length;
                        return { value: value, done: false };
                    }
                    return { value: undefined, done: true };
                }).bind(this)
            };
            // ES2015 @@iterator method (iterable) for spread syntax and for...of statement
            if (typeof Symbol !== 'undefined' && Symbol.iterator) {
                res[Symbol.iterator] = function () { return res; };
            }
            return res;
        };
        // Returns the number of grapheme clusters there are in the given string
        this.countGraphemes = function (str) {
            var count = 0;
            var index = 0;
            var brk;
            while ((brk = this.nextBreak(str, index)) < str.length) {
                index = brk;
                count++;
            }
            if (index < str.length) {
                count++;
            }
            return count;
        };
        //given a Unicode code point, determines this symbol's grapheme break property
        function getGraphemeBreakProperty(code) {
            //grapheme break property for Unicode 10.0.0, 
            //taken from http://www.unicode.org/Public/10.0.0/ucd/auxiliary/GraphemeBreakProperty.txt
            //and adapted to JavaScript rules
            if ((0x0600 <= code && code <= 0x0605) || // Cf   [6] ARABIC NUMBER SIGN..ARABIC NUMBER MARK ABOVE
                0x06DD == code || // Cf       ARABIC END OF AYAH
                0x070F == code || // Cf       SYRIAC ABBREVIATION MARK
                0x08E2 == code || // Cf       ARABIC DISPUTED END OF AYAH
                0x0D4E == code || // Lo       MALAYALAM LETTER DOT REPH
                0x110BD == code || // Cf       KAITHI NUMBER SIGN
                (0x111C2 <= code && code <= 0x111C3) || // Lo   [2] SHARADA SIGN JIHVAMULIYA..SHARADA SIGN UPADHMANIYA
                0x11A3A == code || // Lo       ZANABAZAR SQUARE CLUSTER-INITIAL LETTER RA
                (0x11A86 <= code && code <= 0x11A89) || // Lo   [4] SOYOMBO CLUSTER-INITIAL LETTER RA..SOYOMBO CLUSTER-INITIAL LETTER SA
                0x11D46 == code // Lo       MASARAM GONDI REPHA
            ) {
                return Prepend;
            }
            if (0x000D == code // Cc       <control-000D>
            ) {
                return CR;
            }
            if (0x000A == code // Cc       <control-000A>
            ) {
                return LF;
            }
            if ((0x0000 <= code && code <= 0x0009) || // Cc  [10] <control-0000>..<control-0009>
                (0x000B <= code && code <= 0x000C) || // Cc   [2] <control-000B>..<control-000C>
                (0x000E <= code && code <= 0x001F) || // Cc  [18] <control-000E>..<control-001F>
                (0x007F <= code && code <= 0x009F) || // Cc  [33] <control-007F>..<control-009F>
                0x00AD == code || // Cf       SOFT HYPHEN
                0x061C == code || // Cf       ARABIC LETTER MARK
                0x180E == code || // Cf       MONGOLIAN VOWEL SEPARATOR
                0x200B == code || // Cf       ZERO WIDTH SPACE
                (0x200E <= code && code <= 0x200F) || // Cf   [2] LEFT-TO-RIGHT MARK..RIGHT-TO-LEFT MARK
                0x2028 == code || // Zl       LINE SEPARATOR
                0x2029 == code || // Zp       PARAGRAPH SEPARATOR
                (0x202A <= code && code <= 0x202E) || // Cf   [5] LEFT-TO-RIGHT EMBEDDING..RIGHT-TO-LEFT OVERRIDE
                (0x2060 <= code && code <= 0x2064) || // Cf   [5] WORD JOINER..INVISIBLE PLUS
                0x2065 == code || // Cn       <reserved-2065>
                (0x2066 <= code && code <= 0x206F) || // Cf  [10] LEFT-TO-RIGHT ISOLATE..NOMINAL DIGIT SHAPES
                (0xD800 <= code && code <= 0xDFFF) || // Cs [2048] <surrogate-D800>..<surrogate-DFFF>
                0xFEFF == code || // Cf       ZERO WIDTH NO-BREAK SPACE
                (0xFFF0 <= code && code <= 0xFFF8) || // Cn   [9] <reserved-FFF0>..<reserved-FFF8>
                (0xFFF9 <= code && code <= 0xFFFB) || // Cf   [3] INTERLINEAR ANNOTATION ANCHOR..INTERLINEAR ANNOTATION TERMINATOR
                (0x1BCA0 <= code && code <= 0x1BCA3) || // Cf   [4] SHORTHAND FORMAT LETTER OVERLAP..SHORTHAND FORMAT UP STEP
                (0x1D173 <= code && code <= 0x1D17A) || // Cf   [8] MUSICAL SYMBOL BEGIN BEAM..MUSICAL SYMBOL END PHRASE
                0xE0000 == code || // Cn       <reserved-E0000>
                0xE0001 == code || // Cf       LANGUAGE TAG
                (0xE0002 <= code && code <= 0xE001F) || // Cn  [30] <reserved-E0002>..<reserved-E001F>
                (0xE0080 <= code && code <= 0xE00FF) || // Cn [128] <reserved-E0080>..<reserved-E00FF>
                (0xE01F0 <= code && code <= 0xE0FFF) // Cn [3600] <reserved-E01F0>..<reserved-E0FFF>
            ) {
                return Control;
            }
            if ((0x0300 <= code && code <= 0x036F) || // Mn [112] COMBINING GRAVE ACCENT..COMBINING LATIN SMALL LETTER X
                (0x0483 <= code && code <= 0x0487) || // Mn   [5] COMBINING CYRILLIC TITLO..COMBINING CYRILLIC POKRYTIE
                (0x0488 <= code && code <= 0x0489) || // Me   [2] COMBINING CYRILLIC HUNDRED THOUSANDS SIGN..COMBINING CYRILLIC MILLIONS SIGN
                (0x0591 <= code && code <= 0x05BD) || // Mn  [45] HEBREW ACCENT ETNAHTA..HEBREW POINT METEG
                0x05BF == code || // Mn       HEBREW POINT RAFE
                (0x05C1 <= code && code <= 0x05C2) || // Mn   [2] HEBREW POINT SHIN DOT..HEBREW POINT SIN DOT
                (0x05C4 <= code && code <= 0x05C5) || // Mn   [2] HEBREW MARK UPPER DOT..HEBREW MARK LOWER DOT
                0x05C7 == code || // Mn       HEBREW POINT QAMATS QATAN
                (0x0610 <= code && code <= 0x061A) || // Mn  [11] ARABIC SIGN SALLALLAHOU ALAYHE WASSALLAM..ARABIC SMALL KASRA
                (0x064B <= code && code <= 0x065F) || // Mn  [21] ARABIC FATHATAN..ARABIC WAVY HAMZA BELOW
                0x0670 == code || // Mn       ARABIC LETTER SUPERSCRIPT ALEF
                (0x06D6 <= code && code <= 0x06DC) || // Mn   [7] ARABIC SMALL HIGH LIGATURE SAD WITH LAM WITH ALEF MAKSURA..ARABIC SMALL HIGH SEEN
                (0x06DF <= code && code <= 0x06E4) || // Mn   [6] ARABIC SMALL HIGH ROUNDED ZERO..ARABIC SMALL HIGH MADDA
                (0x06E7 <= code && code <= 0x06E8) || // Mn   [2] ARABIC SMALL HIGH YEH..ARABIC SMALL HIGH NOON
                (0x06EA <= code && code <= 0x06ED) || // Mn   [4] ARABIC EMPTY CENTRE LOW STOP..ARABIC SMALL LOW MEEM
                0x0711 == code || // Mn       SYRIAC LETTER SUPERSCRIPT ALAPH
                (0x0730 <= code && code <= 0x074A) || // Mn  [27] SYRIAC PTHAHA ABOVE..SYRIAC BARREKH
                (0x07A6 <= code && code <= 0x07B0) || // Mn  [11] THAANA ABAFILI..THAANA SUKUN
                (0x07EB <= code && code <= 0x07F3) || // Mn   [9] NKO COMBINING SHORT HIGH TONE..NKO COMBINING DOUBLE DOT ABOVE
                (0x0816 <= code && code <= 0x0819) || // Mn   [4] SAMARITAN MARK IN..SAMARITAN MARK DAGESH
                (0x081B <= code && code <= 0x0823) || // Mn   [9] SAMARITAN MARK EPENTHETIC YUT..SAMARITAN VOWEL SIGN A
                (0x0825 <= code && code <= 0x0827) || // Mn   [3] SAMARITAN VOWEL SIGN SHORT A..SAMARITAN VOWEL SIGN U
                (0x0829 <= code && code <= 0x082D) || // Mn   [5] SAMARITAN VOWEL SIGN LONG I..SAMARITAN MARK NEQUDAA
                (0x0859 <= code && code <= 0x085B) || // Mn   [3] MANDAIC AFFRICATION MARK..MANDAIC GEMINATION MARK
                (0x08D4 <= code && code <= 0x08E1) || // Mn  [14] ARABIC SMALL HIGH WORD AR-RUB..ARABIC SMALL HIGH SIGN SAFHA
                (0x08E3 <= code && code <= 0x0902) || // Mn  [32] ARABIC TURNED DAMMA BELOW..DEVANAGARI SIGN ANUSVARA
                0x093A == code || // Mn       DEVANAGARI VOWEL SIGN OE
                0x093C == code || // Mn       DEVANAGARI SIGN NUKTA
                (0x0941 <= code && code <= 0x0948) || // Mn   [8] DEVANAGARI VOWEL SIGN U..DEVANAGARI VOWEL SIGN AI
                0x094D == code || // Mn       DEVANAGARI SIGN VIRAMA
                (0x0951 <= code && code <= 0x0957) || // Mn   [7] DEVANAGARI STRESS SIGN UDATTA..DEVANAGARI VOWEL SIGN UUE
                (0x0962 <= code && code <= 0x0963) || // Mn   [2] DEVANAGARI VOWEL SIGN VOCALIC L..DEVANAGARI VOWEL SIGN VOCALIC LL
                0x0981 == code || // Mn       BENGALI SIGN CANDRABINDU
                0x09BC == code || // Mn       BENGALI SIGN NUKTA
                0x09BE == code || // Mc       BENGALI VOWEL SIGN AA
                (0x09C1 <= code && code <= 0x09C4) || // Mn   [4] BENGALI VOWEL SIGN U..BENGALI VOWEL SIGN VOCALIC RR
                0x09CD == code || // Mn       BENGALI SIGN VIRAMA
                0x09D7 == code || // Mc       BENGALI AU LENGTH MARK
                (0x09E2 <= code && code <= 0x09E3) || // Mn   [2] BENGALI VOWEL SIGN VOCALIC L..BENGALI VOWEL SIGN VOCALIC LL
                (0x0A01 <= code && code <= 0x0A02) || // Mn   [2] GURMUKHI SIGN ADAK BINDI..GURMUKHI SIGN BINDI
                0x0A3C == code || // Mn       GURMUKHI SIGN NUKTA
                (0x0A41 <= code && code <= 0x0A42) || // Mn   [2] GURMUKHI VOWEL SIGN U..GURMUKHI VOWEL SIGN UU
                (0x0A47 <= code && code <= 0x0A48) || // Mn   [2] GURMUKHI VOWEL SIGN EE..GURMUKHI VOWEL SIGN AI
                (0x0A4B <= code && code <= 0x0A4D) || // Mn   [3] GURMUKHI VOWEL SIGN OO..GURMUKHI SIGN VIRAMA
                0x0A51 == code || // Mn       GURMUKHI SIGN UDAAT
                (0x0A70 <= code && code <= 0x0A71) || // Mn   [2] GURMUKHI TIPPI..GURMUKHI ADDAK
                0x0A75 == code || // Mn       GURMUKHI SIGN YAKASH
                (0x0A81 <= code && code <= 0x0A82) || // Mn   [2] GUJARATI SIGN CANDRABINDU..GUJARATI SIGN ANUSVARA
                0x0ABC == code || // Mn       GUJARATI SIGN NUKTA
                (0x0AC1 <= code && code <= 0x0AC5) || // Mn   [5] GUJARATI VOWEL SIGN U..GUJARATI VOWEL SIGN CANDRA E
                (0x0AC7 <= code && code <= 0x0AC8) || // Mn   [2] GUJARATI VOWEL SIGN E..GUJARATI VOWEL SIGN AI
                0x0ACD == code || // Mn       GUJARATI SIGN VIRAMA
                (0x0AE2 <= code && code <= 0x0AE3) || // Mn   [2] GUJARATI VOWEL SIGN VOCALIC L..GUJARATI VOWEL SIGN VOCALIC LL
                (0x0AFA <= code && code <= 0x0AFF) || // Mn   [6] GUJARATI SIGN SUKUN..GUJARATI SIGN TWO-CIRCLE NUKTA ABOVE
                0x0B01 == code || // Mn       ORIYA SIGN CANDRABINDU
                0x0B3C == code || // Mn       ORIYA SIGN NUKTA
                0x0B3E == code || // Mc       ORIYA VOWEL SIGN AA
                0x0B3F == code || // Mn       ORIYA VOWEL SIGN I
                (0x0B41 <= code && code <= 0x0B44) || // Mn   [4] ORIYA VOWEL SIGN U..ORIYA VOWEL SIGN VOCALIC RR
                0x0B4D == code || // Mn       ORIYA SIGN VIRAMA
                0x0B56 == code || // Mn       ORIYA AI LENGTH MARK
                0x0B57 == code || // Mc       ORIYA AU LENGTH MARK
                (0x0B62 <= code && code <= 0x0B63) || // Mn   [2] ORIYA VOWEL SIGN VOCALIC L..ORIYA VOWEL SIGN VOCALIC LL
                0x0B82 == code || // Mn       TAMIL SIGN ANUSVARA
                0x0BBE == code || // Mc       TAMIL VOWEL SIGN AA
                0x0BC0 == code || // Mn       TAMIL VOWEL SIGN II
                0x0BCD == code || // Mn       TAMIL SIGN VIRAMA
                0x0BD7 == code || // Mc       TAMIL AU LENGTH MARK
                0x0C00 == code || // Mn       TELUGU SIGN COMBINING CANDRABINDU ABOVE
                (0x0C3E <= code && code <= 0x0C40) || // Mn   [3] TELUGU VOWEL SIGN AA..TELUGU VOWEL SIGN II
                (0x0C46 <= code && code <= 0x0C48) || // Mn   [3] TELUGU VOWEL SIGN E..TELUGU VOWEL SIGN AI
                (0x0C4A <= code && code <= 0x0C4D) || // Mn   [4] TELUGU VOWEL SIGN O..TELUGU SIGN VIRAMA
                (0x0C55 <= code && code <= 0x0C56) || // Mn   [2] TELUGU LENGTH MARK..TELUGU AI LENGTH MARK
                (0x0C62 <= code && code <= 0x0C63) || // Mn   [2] TELUGU VOWEL SIGN VOCALIC L..TELUGU VOWEL SIGN VOCALIC LL
                0x0C81 == code || // Mn       KANNADA SIGN CANDRABINDU
                0x0CBC == code || // Mn       KANNADA SIGN NUKTA
                0x0CBF == code || // Mn       KANNADA VOWEL SIGN I
                0x0CC2 == code || // Mc       KANNADA VOWEL SIGN UU
                0x0CC6 == code || // Mn       KANNADA VOWEL SIGN E
                (0x0CCC <= code && code <= 0x0CCD) || // Mn   [2] KANNADA VOWEL SIGN AU..KANNADA SIGN VIRAMA
                (0x0CD5 <= code && code <= 0x0CD6) || // Mc   [2] KANNADA LENGTH MARK..KANNADA AI LENGTH MARK
                (0x0CE2 <= code && code <= 0x0CE3) || // Mn   [2] KANNADA VOWEL SIGN VOCALIC L..KANNADA VOWEL SIGN VOCALIC LL
                (0x0D00 <= code && code <= 0x0D01) || // Mn   [2] MALAYALAM SIGN COMBINING ANUSVARA ABOVE..MALAYALAM SIGN CANDRABINDU
                (0x0D3B <= code && code <= 0x0D3C) || // Mn   [2] MALAYALAM SIGN VERTICAL BAR VIRAMA..MALAYALAM SIGN CIRCULAR VIRAMA
                0x0D3E == code || // Mc       MALAYALAM VOWEL SIGN AA
                (0x0D41 <= code && code <= 0x0D44) || // Mn   [4] MALAYALAM VOWEL SIGN U..MALAYALAM VOWEL SIGN VOCALIC RR
                0x0D4D == code || // Mn       MALAYALAM SIGN VIRAMA
                0x0D57 == code || // Mc       MALAYALAM AU LENGTH MARK
                (0x0D62 <= code && code <= 0x0D63) || // Mn   [2] MALAYALAM VOWEL SIGN VOCALIC L..MALAYALAM VOWEL SIGN VOCALIC LL
                0x0DCA == code || // Mn       SINHALA SIGN AL-LAKUNA
                0x0DCF == code || // Mc       SINHALA VOWEL SIGN AELA-PILLA
                (0x0DD2 <= code && code <= 0x0DD4) || // Mn   [3] SINHALA VOWEL SIGN KETTI IS-PILLA..SINHALA VOWEL SIGN KETTI PAA-PILLA
                0x0DD6 == code || // Mn       SINHALA VOWEL SIGN DIGA PAA-PILLA
                0x0DDF == code || // Mc       SINHALA VOWEL SIGN GAYANUKITTA
                0x0E31 == code || // Mn       THAI CHARACTER MAI HAN-AKAT
                (0x0E34 <= code && code <= 0x0E3A) || // Mn   [7] THAI CHARACTER SARA I..THAI CHARACTER PHINTHU
                (0x0E47 <= code && code <= 0x0E4E) || // Mn   [8] THAI CHARACTER MAITAIKHU..THAI CHARACTER YAMAKKAN
                0x0EB1 == code || // Mn       LAO VOWEL SIGN MAI KAN
                (0x0EB4 <= code && code <= 0x0EB9) || // Mn   [6] LAO VOWEL SIGN I..LAO VOWEL SIGN UU
                (0x0EBB <= code && code <= 0x0EBC) || // Mn   [2] LAO VOWEL SIGN MAI KON..LAO SEMIVOWEL SIGN LO
                (0x0EC8 <= code && code <= 0x0ECD) || // Mn   [6] LAO TONE MAI EK..LAO NIGGAHITA
                (0x0F18 <= code && code <= 0x0F19) || // Mn   [2] TIBETAN ASTROLOGICAL SIGN -KHYUD PA..TIBETAN ASTROLOGICAL SIGN SDONG TSHUGS
                0x0F35 == code || // Mn       TIBETAN MARK NGAS BZUNG NYI ZLA
                0x0F37 == code || // Mn       TIBETAN MARK NGAS BZUNG SGOR RTAGS
                0x0F39 == code || // Mn       TIBETAN MARK TSA -PHRU
                (0x0F71 <= code && code <= 0x0F7E) || // Mn  [14] TIBETAN VOWEL SIGN AA..TIBETAN SIGN RJES SU NGA RO
                (0x0F80 <= code && code <= 0x0F84) || // Mn   [5] TIBETAN VOWEL SIGN REVERSED I..TIBETAN MARK HALANTA
                (0x0F86 <= code && code <= 0x0F87) || // Mn   [2] TIBETAN SIGN LCI RTAGS..TIBETAN SIGN YANG RTAGS
                (0x0F8D <= code && code <= 0x0F97) || // Mn  [11] TIBETAN SUBJOINED SIGN LCE TSA CAN..TIBETAN SUBJOINED LETTER JA
                (0x0F99 <= code && code <= 0x0FBC) || // Mn  [36] TIBETAN SUBJOINED LETTER NYA..TIBETAN SUBJOINED LETTER FIXED-FORM RA
                0x0FC6 == code || // Mn       TIBETAN SYMBOL PADMA GDAN
                (0x102D <= code && code <= 0x1030) || // Mn   [4] MYANMAR VOWEL SIGN I..MYANMAR VOWEL SIGN UU
                (0x1032 <= code && code <= 0x1037) || // Mn   [6] MYANMAR VOWEL SIGN AI..MYANMAR SIGN DOT BELOW
                (0x1039 <= code && code <= 0x103A) || // Mn   [2] MYANMAR SIGN VIRAMA..MYANMAR SIGN ASAT
                (0x103D <= code && code <= 0x103E) || // Mn   [2] MYANMAR CONSONANT SIGN MEDIAL WA..MYANMAR CONSONANT SIGN MEDIAL HA
                (0x1058 <= code && code <= 0x1059) || // Mn   [2] MYANMAR VOWEL SIGN VOCALIC L..MYANMAR VOWEL SIGN VOCALIC LL
                (0x105E <= code && code <= 0x1060) || // Mn   [3] MYANMAR CONSONANT SIGN MON MEDIAL NA..MYANMAR CONSONANT SIGN MON MEDIAL LA
                (0x1071 <= code && code <= 0x1074) || // Mn   [4] MYANMAR VOWEL SIGN GEBA KAREN I..MYANMAR VOWEL SIGN KAYAH EE
                0x1082 == code || // Mn       MYANMAR CONSONANT SIGN SHAN MEDIAL WA
                (0x1085 <= code && code <= 0x1086) || // Mn   [2] MYANMAR VOWEL SIGN SHAN E ABOVE..MYANMAR VOWEL SIGN SHAN FINAL Y
                0x108D == code || // Mn       MYANMAR SIGN SHAN COUNCIL EMPHATIC TONE
                0x109D == code || // Mn       MYANMAR VOWEL SIGN AITON AI
                (0x135D <= code && code <= 0x135F) || // Mn   [3] ETHIOPIC COMBINING GEMINATION AND VOWEL LENGTH MARK..ETHIOPIC COMBINING GEMINATION MARK
                (0x1712 <= code && code <= 0x1714) || // Mn   [3] TAGALOG VOWEL SIGN I..TAGALOG SIGN VIRAMA
                (0x1732 <= code && code <= 0x1734) || // Mn   [3] HANUNOO VOWEL SIGN I..HANUNOO SIGN PAMUDPOD
                (0x1752 <= code && code <= 0x1753) || // Mn   [2] BUHID VOWEL SIGN I..BUHID VOWEL SIGN U
                (0x1772 <= code && code <= 0x1773) || // Mn   [2] TAGBANWA VOWEL SIGN I..TAGBANWA VOWEL SIGN U
                (0x17B4 <= code && code <= 0x17B5) || // Mn   [2] KHMER VOWEL INHERENT AQ..KHMER VOWEL INHERENT AA
                (0x17B7 <= code && code <= 0x17BD) || // Mn   [7] KHMER VOWEL SIGN I..KHMER VOWEL SIGN UA
                0x17C6 == code || // Mn       KHMER SIGN NIKAHIT
                (0x17C9 <= code && code <= 0x17D3) || // Mn  [11] KHMER SIGN MUUSIKATOAN..KHMER SIGN BATHAMASAT
                0x17DD == code || // Mn       KHMER SIGN ATTHACAN
                (0x180B <= code && code <= 0x180D) || // Mn   [3] MONGOLIAN FREE VARIATION SELECTOR ONE..MONGOLIAN FREE VARIATION SELECTOR THREE
                (0x1885 <= code && code <= 0x1886) || // Mn   [2] MONGOLIAN LETTER ALI GALI BALUDA..MONGOLIAN LETTER ALI GALI THREE BALUDA
                0x18A9 == code || // Mn       MONGOLIAN LETTER ALI GALI DAGALGA
                (0x1920 <= code && code <= 0x1922) || // Mn   [3] LIMBU VOWEL SIGN A..LIMBU VOWEL SIGN U
                (0x1927 <= code && code <= 0x1928) || // Mn   [2] LIMBU VOWEL SIGN E..LIMBU VOWEL SIGN O
                0x1932 == code || // Mn       LIMBU SMALL LETTER ANUSVARA
                (0x1939 <= code && code <= 0x193B) || // Mn   [3] LIMBU SIGN MUKPHRENG..LIMBU SIGN SA-I
                (0x1A17 <= code && code <= 0x1A18) || // Mn   [2] BUGINESE VOWEL SIGN I..BUGINESE VOWEL SIGN U
                0x1A1B == code || // Mn       BUGINESE VOWEL SIGN AE
                0x1A56 == code || // Mn       TAI THAM CONSONANT SIGN MEDIAL LA
                (0x1A58 <= code && code <= 0x1A5E) || // Mn   [7] TAI THAM SIGN MAI KANG LAI..TAI THAM CONSONANT SIGN SA
                0x1A60 == code || // Mn       TAI THAM SIGN SAKOT
                0x1A62 == code || // Mn       TAI THAM VOWEL SIGN MAI SAT
                (0x1A65 <= code && code <= 0x1A6C) || // Mn   [8] TAI THAM VOWEL SIGN I..TAI THAM VOWEL SIGN OA BELOW
                (0x1A73 <= code && code <= 0x1A7C) || // Mn  [10] TAI THAM VOWEL SIGN OA ABOVE..TAI THAM SIGN KHUEN-LUE KARAN
                0x1A7F == code || // Mn       TAI THAM COMBINING CRYPTOGRAMMIC DOT
                (0x1AB0 <= code && code <= 0x1ABD) || // Mn  [14] COMBINING DOUBLED CIRCUMFLEX ACCENT..COMBINING PARENTHESES BELOW
                0x1ABE == code || // Me       COMBINING PARENTHESES OVERLAY
                (0x1B00 <= code && code <= 0x1B03) || // Mn   [4] BALINESE SIGN ULU RICEM..BALINESE SIGN SURANG
                0x1B34 == code || // Mn       BALINESE SIGN REREKAN
                (0x1B36 <= code && code <= 0x1B3A) || // Mn   [5] BALINESE VOWEL SIGN ULU..BALINESE VOWEL SIGN RA REPA
                0x1B3C == code || // Mn       BALINESE VOWEL SIGN LA LENGA
                0x1B42 == code || // Mn       BALINESE VOWEL SIGN PEPET
                (0x1B6B <= code && code <= 0x1B73) || // Mn   [9] BALINESE MUSICAL SYMBOL COMBINING TEGEH..BALINESE MUSICAL SYMBOL COMBINING GONG
                (0x1B80 <= code && code <= 0x1B81) || // Mn   [2] SUNDANESE SIGN PANYECEK..SUNDANESE SIGN PANGLAYAR
                (0x1BA2 <= code && code <= 0x1BA5) || // Mn   [4] SUNDANESE CONSONANT SIGN PANYAKRA..SUNDANESE VOWEL SIGN PANYUKU
                (0x1BA8 <= code && code <= 0x1BA9) || // Mn   [2] SUNDANESE VOWEL SIGN PAMEPET..SUNDANESE VOWEL SIGN PANEULEUNG
                (0x1BAB <= code && code <= 0x1BAD) || // Mn   [3] SUNDANESE SIGN VIRAMA..SUNDANESE CONSONANT SIGN PASANGAN WA
                0x1BE6 == code || // Mn       BATAK SIGN TOMPI
                (0x1BE8 <= code && code <= 0x1BE9) || // Mn   [2] BATAK VOWEL SIGN PAKPAK E..BATAK VOWEL SIGN EE
                0x1BED == code || // Mn       BATAK VOWEL SIGN KARO O
                (0x1BEF <= code && code <= 0x1BF1) || // Mn   [3] BATAK VOWEL SIGN U FOR SIMALUNGUN SA..BATAK CONSONANT SIGN H
                (0x1C2C <= code && code <= 0x1C33) || // Mn   [8] LEPCHA VOWEL SIGN E..LEPCHA CONSONANT SIGN T
                (0x1C36 <= code && code <= 0x1C37) || // Mn   [2] LEPCHA SIGN RAN..LEPCHA SIGN NUKTA
                (0x1CD0 <= code && code <= 0x1CD2) || // Mn   [3] VEDIC TONE KARSHANA..VEDIC TONE PRENKHA
                (0x1CD4 <= code && code <= 0x1CE0) || // Mn  [13] VEDIC SIGN YAJURVEDIC MIDLINE SVARITA..VEDIC TONE RIGVEDIC KASHMIRI INDEPENDENT SVARITA
                (0x1CE2 <= code && code <= 0x1CE8) || // Mn   [7] VEDIC SIGN VISARGA SVARITA..VEDIC SIGN VISARGA ANUDATTA WITH TAIL
                0x1CED == code || // Mn       VEDIC SIGN TIRYAK
                0x1CF4 == code || // Mn       VEDIC TONE CANDRA ABOVE
                (0x1CF8 <= code && code <= 0x1CF9) || // Mn   [2] VEDIC TONE RING ABOVE..VEDIC TONE DOUBLE RING ABOVE
                (0x1DC0 <= code && code <= 0x1DF9) || // Mn  [58] COMBINING DOTTED GRAVE ACCENT..COMBINING WIDE INVERTED BRIDGE BELOW
                (0x1DFB <= code && code <= 0x1DFF) || // Mn   [5] COMBINING DELETION MARK..COMBINING RIGHT ARROWHEAD AND DOWN ARROWHEAD BELOW
                0x200C == code || // Cf       ZERO WIDTH NON-JOINER
                (0x20D0 <= code && code <= 0x20DC) || // Mn  [13] COMBINING LEFT HARPOON ABOVE..COMBINING FOUR DOTS ABOVE
                (0x20DD <= code && code <= 0x20E0) || // Me   [4] COMBINING ENCLOSING CIRCLE..COMBINING ENCLOSING CIRCLE BACKSLASH
                0x20E1 == code || // Mn       COMBINING LEFT RIGHT ARROW ABOVE
                (0x20E2 <= code && code <= 0x20E4) || // Me   [3] COMBINING ENCLOSING SCREEN..COMBINING ENCLOSING UPWARD POINTING TRIANGLE
                (0x20E5 <= code && code <= 0x20F0) || // Mn  [12] COMBINING REVERSE SOLIDUS OVERLAY..COMBINING ASTERISK ABOVE
                (0x2CEF <= code && code <= 0x2CF1) || // Mn   [3] COPTIC COMBINING NI ABOVE..COPTIC COMBINING SPIRITUS LENIS
                0x2D7F == code || // Mn       TIFINAGH CONSONANT JOINER
                (0x2DE0 <= code && code <= 0x2DFF) || // Mn  [32] COMBINING CYRILLIC LETTER BE..COMBINING CYRILLIC LETTER IOTIFIED BIG YUS
                (0x302A <= code && code <= 0x302D) || // Mn   [4] IDEOGRAPHIC LEVEL TONE MARK..IDEOGRAPHIC ENTERING TONE MARK
                (0x302E <= code && code <= 0x302F) || // Mc   [2] HANGUL SINGLE DOT TONE MARK..HANGUL DOUBLE DOT TONE MARK
                (0x3099 <= code && code <= 0x309A) || // Mn   [2] COMBINING KATAKANA-HIRAGANA VOICED SOUND MARK..COMBINING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
                0xA66F == code || // Mn       COMBINING CYRILLIC VZMET
                (0xA670 <= code && code <= 0xA672) || // Me   [3] COMBINING CYRILLIC TEN MILLIONS SIGN..COMBINING CYRILLIC THOUSAND MILLIONS SIGN
                (0xA674 <= code && code <= 0xA67D) || // Mn  [10] COMBINING CYRILLIC LETTER UKRAINIAN IE..COMBINING CYRILLIC PAYEROK
                (0xA69E <= code && code <= 0xA69F) || // Mn   [2] COMBINING CYRILLIC LETTER EF..COMBINING CYRILLIC LETTER IOTIFIED E
                (0xA6F0 <= code && code <= 0xA6F1) || // Mn   [2] BAMUM COMBINING MARK KOQNDON..BAMUM COMBINING MARK TUKWENTIS
                0xA802 == code || // Mn       SYLOTI NAGRI SIGN DVISVARA
                0xA806 == code || // Mn       SYLOTI NAGRI SIGN HASANTA
                0xA80B == code || // Mn       SYLOTI NAGRI SIGN ANUSVARA
                (0xA825 <= code && code <= 0xA826) || // Mn   [2] SYLOTI NAGRI VOWEL SIGN U..SYLOTI NAGRI VOWEL SIGN E
                (0xA8C4 <= code && code <= 0xA8C5) || // Mn   [2] SAURASHTRA SIGN VIRAMA..SAURASHTRA SIGN CANDRABINDU
                (0xA8E0 <= code && code <= 0xA8F1) || // Mn  [18] COMBINING DEVANAGARI DIGIT ZERO..COMBINING DEVANAGARI SIGN AVAGRAHA
                (0xA926 <= code && code <= 0xA92D) || // Mn   [8] KAYAH LI VOWEL UE..KAYAH LI TONE CALYA PLOPHU
                (0xA947 <= code && code <= 0xA951) || // Mn  [11] REJANG VOWEL SIGN I..REJANG CONSONANT SIGN R
                (0xA980 <= code && code <= 0xA982) || // Mn   [3] JAVANESE SIGN PANYANGGA..JAVANESE SIGN LAYAR
                0xA9B3 == code || // Mn       JAVANESE SIGN CECAK TELU
                (0xA9B6 <= code && code <= 0xA9B9) || // Mn   [4] JAVANESE VOWEL SIGN WULU..JAVANESE VOWEL SIGN SUKU MENDUT
                0xA9BC == code || // Mn       JAVANESE VOWEL SIGN PEPET
                0xA9E5 == code || // Mn       MYANMAR SIGN SHAN SAW
                (0xAA29 <= code && code <= 0xAA2E) || // Mn   [6] CHAM VOWEL SIGN AA..CHAM VOWEL SIGN OE
                (0xAA31 <= code && code <= 0xAA32) || // Mn   [2] CHAM VOWEL SIGN AU..CHAM VOWEL SIGN UE
                (0xAA35 <= code && code <= 0xAA36) || // Mn   [2] CHAM CONSONANT SIGN LA..CHAM CONSONANT SIGN WA
                0xAA43 == code || // Mn       CHAM CONSONANT SIGN FINAL NG
                0xAA4C == code || // Mn       CHAM CONSONANT SIGN FINAL M
                0xAA7C == code || // Mn       MYANMAR SIGN TAI LAING TONE-2
                0xAAB0 == code || // Mn       TAI VIET MAI KANG
                (0xAAB2 <= code && code <= 0xAAB4) || // Mn   [3] TAI VIET VOWEL I..TAI VIET VOWEL U
                (0xAAB7 <= code && code <= 0xAAB8) || // Mn   [2] TAI VIET MAI KHIT..TAI VIET VOWEL IA
                (0xAABE <= code && code <= 0xAABF) || // Mn   [2] TAI VIET VOWEL AM..TAI VIET TONE MAI EK
                0xAAC1 == code || // Mn       TAI VIET TONE MAI THO
                (0xAAEC <= code && code <= 0xAAED) || // Mn   [2] MEETEI MAYEK VOWEL SIGN UU..MEETEI MAYEK VOWEL SIGN AAI
                0xAAF6 == code || // Mn       MEETEI MAYEK VIRAMA
                0xABE5 == code || // Mn       MEETEI MAYEK VOWEL SIGN ANAP
                0xABE8 == code || // Mn       MEETEI MAYEK VOWEL SIGN UNAP
                0xABED == code || // Mn       MEETEI MAYEK APUN IYEK
                0xFB1E == code || // Mn       HEBREW POINT JUDEO-SPANISH VARIKA
                (0xFE00 <= code && code <= 0xFE0F) || // Mn  [16] VARIATION SELECTOR-1..VARIATION SELECTOR-16
                (0xFE20 <= code && code <= 0xFE2F) || // Mn  [16] COMBINING LIGATURE LEFT HALF..COMBINING CYRILLIC TITLO RIGHT HALF
                (0xFF9E <= code && code <= 0xFF9F) || // Lm   [2] HALFWIDTH KATAKANA VOICED SOUND MARK..HALFWIDTH KATAKANA SEMI-VOICED SOUND MARK
                0x101FD == code || // Mn       PHAISTOS DISC SIGN COMBINING OBLIQUE STROKE
                0x102E0 == code || // Mn       COPTIC EPACT THOUSANDS MARK
                (0x10376 <= code && code <= 0x1037A) || // Mn   [5] COMBINING OLD PERMIC LETTER AN..COMBINING OLD PERMIC LETTER SII
                (0x10A01 <= code && code <= 0x10A03) || // Mn   [3] KHAROSHTHI VOWEL SIGN I..KHAROSHTHI VOWEL SIGN VOCALIC R
                (0x10A05 <= code && code <= 0x10A06) || // Mn   [2] KHAROSHTHI VOWEL SIGN E..KHAROSHTHI VOWEL SIGN O
                (0x10A0C <= code && code <= 0x10A0F) || // Mn   [4] KHAROSHTHI VOWEL LENGTH MARK..KHAROSHTHI SIGN VISARGA
                (0x10A38 <= code && code <= 0x10A3A) || // Mn   [3] KHAROSHTHI SIGN BAR ABOVE..KHAROSHTHI SIGN DOT BELOW
                0x10A3F == code || // Mn       KHAROSHTHI VIRAMA
                (0x10AE5 <= code && code <= 0x10AE6) || // Mn   [2] MANICHAEAN ABBREVIATION MARK ABOVE..MANICHAEAN ABBREVIATION MARK BELOW
                0x11001 == code || // Mn       BRAHMI SIGN ANUSVARA
                (0x11038 <= code && code <= 0x11046) || // Mn  [15] BRAHMI VOWEL SIGN AA..BRAHMI VIRAMA
                (0x1107F <= code && code <= 0x11081) || // Mn   [3] BRAHMI NUMBER JOINER..KAITHI SIGN ANUSVARA
                (0x110B3 <= code && code <= 0x110B6) || // Mn   [4] KAITHI VOWEL SIGN U..KAITHI VOWEL SIGN AI
                (0x110B9 <= code && code <= 0x110BA) || // Mn   [2] KAITHI SIGN VIRAMA..KAITHI SIGN NUKTA
                (0x11100 <= code && code <= 0x11102) || // Mn   [3] CHAKMA SIGN CANDRABINDU..CHAKMA SIGN VISARGA
                (0x11127 <= code && code <= 0x1112B) || // Mn   [5] CHAKMA VOWEL SIGN A..CHAKMA VOWEL SIGN UU
                (0x1112D <= code && code <= 0x11134) || // Mn   [8] CHAKMA VOWEL SIGN AI..CHAKMA MAAYYAA
                0x11173 == code || // Mn       MAHAJANI SIGN NUKTA
                (0x11180 <= code && code <= 0x11181) || // Mn   [2] SHARADA SIGN CANDRABINDU..SHARADA SIGN ANUSVARA
                (0x111B6 <= code && code <= 0x111BE) || // Mn   [9] SHARADA VOWEL SIGN U..SHARADA VOWEL SIGN O
                (0x111CA <= code && code <= 0x111CC) || // Mn   [3] SHARADA SIGN NUKTA..SHARADA EXTRA SHORT VOWEL MARK
                (0x1122F <= code && code <= 0x11231) || // Mn   [3] KHOJKI VOWEL SIGN U..KHOJKI VOWEL SIGN AI
                0x11234 == code || // Mn       KHOJKI SIGN ANUSVARA
                (0x11236 <= code && code <= 0x11237) || // Mn   [2] KHOJKI SIGN NUKTA..KHOJKI SIGN SHADDA
                0x1123E == code || // Mn       KHOJKI SIGN SUKUN
                0x112DF == code || // Mn       KHUDAWADI SIGN ANUSVARA
                (0x112E3 <= code && code <= 0x112EA) || // Mn   [8] KHUDAWADI VOWEL SIGN U..KHUDAWADI SIGN VIRAMA
                (0x11300 <= code && code <= 0x11301) || // Mn   [2] GRANTHA SIGN COMBINING ANUSVARA ABOVE..GRANTHA SIGN CANDRABINDU
                0x1133C == code || // Mn       GRANTHA SIGN NUKTA
                0x1133E == code || // Mc       GRANTHA VOWEL SIGN AA
                0x11340 == code || // Mn       GRANTHA VOWEL SIGN II
                0x11357 == code || // Mc       GRANTHA AU LENGTH MARK
                (0x11366 <= code && code <= 0x1136C) || // Mn   [7] COMBINING GRANTHA DIGIT ZERO..COMBINING GRANTHA DIGIT SIX
                (0x11370 <= code && code <= 0x11374) || // Mn   [5] COMBINING GRANTHA LETTER A..COMBINING GRANTHA LETTER PA
                (0x11438 <= code && code <= 0x1143F) || // Mn   [8] NEWA VOWEL SIGN U..NEWA VOWEL SIGN AI
                (0x11442 <= code && code <= 0x11444) || // Mn   [3] NEWA SIGN VIRAMA..NEWA SIGN ANUSVARA
                0x11446 == code || // Mn       NEWA SIGN NUKTA
                0x114B0 == code || // Mc       TIRHUTA VOWEL SIGN AA
                (0x114B3 <= code && code <= 0x114B8) || // Mn   [6] TIRHUTA VOWEL SIGN U..TIRHUTA VOWEL SIGN VOCALIC LL
                0x114BA == code || // Mn       TIRHUTA VOWEL SIGN SHORT E
                0x114BD == code || // Mc       TIRHUTA VOWEL SIGN SHORT O
                (0x114BF <= code && code <= 0x114C0) || // Mn   [2] TIRHUTA SIGN CANDRABINDU..TIRHUTA SIGN ANUSVARA
                (0x114C2 <= code && code <= 0x114C3) || // Mn   [2] TIRHUTA SIGN VIRAMA..TIRHUTA SIGN NUKTA
                0x115AF == code || // Mc       SIDDHAM VOWEL SIGN AA
                (0x115B2 <= code && code <= 0x115B5) || // Mn   [4] SIDDHAM VOWEL SIGN U..SIDDHAM VOWEL SIGN VOCALIC RR
                (0x115BC <= code && code <= 0x115BD) || // Mn   [2] SIDDHAM SIGN CANDRABINDU..SIDDHAM SIGN ANUSVARA
                (0x115BF <= code && code <= 0x115C0) || // Mn   [2] SIDDHAM SIGN VIRAMA..SIDDHAM SIGN NUKTA
                (0x115DC <= code && code <= 0x115DD) || // Mn   [2] SIDDHAM VOWEL SIGN ALTERNATE U..SIDDHAM VOWEL SIGN ALTERNATE UU
                (0x11633 <= code && code <= 0x1163A) || // Mn   [8] MODI VOWEL SIGN U..MODI VOWEL SIGN AI
                0x1163D == code || // Mn       MODI SIGN ANUSVARA
                (0x1163F <= code && code <= 0x11640) || // Mn   [2] MODI SIGN VIRAMA..MODI SIGN ARDHACANDRA
                0x116AB == code || // Mn       TAKRI SIGN ANUSVARA
                0x116AD == code || // Mn       TAKRI VOWEL SIGN AA
                (0x116B0 <= code && code <= 0x116B5) || // Mn   [6] TAKRI VOWEL SIGN U..TAKRI VOWEL SIGN AU
                0x116B7 == code || // Mn       TAKRI SIGN NUKTA
                (0x1171D <= code && code <= 0x1171F) || // Mn   [3] AHOM CONSONANT SIGN MEDIAL LA..AHOM CONSONANT SIGN MEDIAL LIGATING RA
                (0x11722 <= code && code <= 0x11725) || // Mn   [4] AHOM VOWEL SIGN I..AHOM VOWEL SIGN UU
                (0x11727 <= code && code <= 0x1172B) || // Mn   [5] AHOM VOWEL SIGN AW..AHOM SIGN KILLER
                (0x11A01 <= code && code <= 0x11A06) || // Mn   [6] ZANABAZAR SQUARE VOWEL SIGN I..ZANABAZAR SQUARE VOWEL SIGN O
                (0x11A09 <= code && code <= 0x11A0A) || // Mn   [2] ZANABAZAR SQUARE VOWEL SIGN REVERSED I..ZANABAZAR SQUARE VOWEL LENGTH MARK
                (0x11A33 <= code && code <= 0x11A38) || // Mn   [6] ZANABAZAR SQUARE FINAL CONSONANT MARK..ZANABAZAR SQUARE SIGN ANUSVARA
                (0x11A3B <= code && code <= 0x11A3E) || // Mn   [4] ZANABAZAR SQUARE CLUSTER-FINAL LETTER YA..ZANABAZAR SQUARE CLUSTER-FINAL LETTER VA
                0x11A47 == code || // Mn       ZANABAZAR SQUARE SUBJOINER
                (0x11A51 <= code && code <= 0x11A56) || // Mn   [6] SOYOMBO VOWEL SIGN I..SOYOMBO VOWEL SIGN OE
                (0x11A59 <= code && code <= 0x11A5B) || // Mn   [3] SOYOMBO VOWEL SIGN VOCALIC R..SOYOMBO VOWEL LENGTH MARK
                (0x11A8A <= code && code <= 0x11A96) || // Mn  [13] SOYOMBO FINAL CONSONANT SIGN G..SOYOMBO SIGN ANUSVARA
                (0x11A98 <= code && code <= 0x11A99) || // Mn   [2] SOYOMBO GEMINATION MARK..SOYOMBO SUBJOINER
                (0x11C30 <= code && code <= 0x11C36) || // Mn   [7] BHAIKSUKI VOWEL SIGN I..BHAIKSUKI VOWEL SIGN VOCALIC L
                (0x11C38 <= code && code <= 0x11C3D) || // Mn   [6] BHAIKSUKI VOWEL SIGN E..BHAIKSUKI SIGN ANUSVARA
                0x11C3F == code || // Mn       BHAIKSUKI SIGN VIRAMA
                (0x11C92 <= code && code <= 0x11CA7) || // Mn  [22] MARCHEN SUBJOINED LETTER KA..MARCHEN SUBJOINED LETTER ZA
                (0x11CAA <= code && code <= 0x11CB0) || // Mn   [7] MARCHEN SUBJOINED LETTER RA..MARCHEN VOWEL SIGN AA
                (0x11CB2 <= code && code <= 0x11CB3) || // Mn   [2] MARCHEN VOWEL SIGN U..MARCHEN VOWEL SIGN E
                (0x11CB5 <= code && code <= 0x11CB6) || // Mn   [2] MARCHEN SIGN ANUSVARA..MARCHEN SIGN CANDRABINDU
                (0x11D31 <= code && code <= 0x11D36) || // Mn   [6] MASARAM GONDI VOWEL SIGN AA..MASARAM GONDI VOWEL SIGN VOCALIC R
                0x11D3A == code || // Mn       MASARAM GONDI VOWEL SIGN E
                (0x11D3C <= code && code <= 0x11D3D) || // Mn   [2] MASARAM GONDI VOWEL SIGN AI..MASARAM GONDI VOWEL SIGN O
                (0x11D3F <= code && code <= 0x11D45) || // Mn   [7] MASARAM GONDI VOWEL SIGN AU..MASARAM GONDI VIRAMA
                0x11D47 == code || // Mn       MASARAM GONDI RA-KARA
                (0x16AF0 <= code && code <= 0x16AF4) || // Mn   [5] BASSA VAH COMBINING HIGH TONE..BASSA VAH COMBINING HIGH-LOW TONE
                (0x16B30 <= code && code <= 0x16B36) || // Mn   [7] PAHAWH HMONG MARK CIM TUB..PAHAWH HMONG MARK CIM TAUM
                (0x16F8F <= code && code <= 0x16F92) || // Mn   [4] MIAO TONE RIGHT..MIAO TONE BELOW
                (0x1BC9D <= code && code <= 0x1BC9E) || // Mn   [2] DUPLOYAN THICK LETTER SELECTOR..DUPLOYAN DOUBLE MARK
                0x1D165 == code || // Mc       MUSICAL SYMBOL COMBINING STEM
                (0x1D167 <= code && code <= 0x1D169) || // Mn   [3] MUSICAL SYMBOL COMBINING TREMOLO-1..MUSICAL SYMBOL COMBINING TREMOLO-3
                (0x1D16E <= code && code <= 0x1D172) || // Mc   [5] MUSICAL SYMBOL COMBINING FLAG-1..MUSICAL SYMBOL COMBINING FLAG-5
                (0x1D17B <= code && code <= 0x1D182) || // Mn   [8] MUSICAL SYMBOL COMBINING ACCENT..MUSICAL SYMBOL COMBINING LOURE
                (0x1D185 <= code && code <= 0x1D18B) || // Mn   [7] MUSICAL SYMBOL COMBINING DOIT..MUSICAL SYMBOL COMBINING TRIPLE TONGUE
                (0x1D1AA <= code && code <= 0x1D1AD) || // Mn   [4] MUSICAL SYMBOL COMBINING DOWN BOW..MUSICAL SYMBOL COMBINING SNAP PIZZICATO
                (0x1D242 <= code && code <= 0x1D244) || // Mn   [3] COMBINING GREEK MUSICAL TRISEME..COMBINING GREEK MUSICAL PENTASEME
                (0x1DA00 <= code && code <= 0x1DA36) || // Mn  [55] SIGNWRITING HEAD RIM..SIGNWRITING AIR SUCKING IN
                (0x1DA3B <= code && code <= 0x1DA6C) || // Mn  [50] SIGNWRITING MOUTH CLOSED NEUTRAL..SIGNWRITING EXCITEMENT
                0x1DA75 == code || // Mn       SIGNWRITING UPPER BODY TILTING FROM HIP JOINTS
                0x1DA84 == code || // Mn       SIGNWRITING LOCATION HEAD NECK
                (0x1DA9B <= code && code <= 0x1DA9F) || // Mn   [5] SIGNWRITING FILL MODIFIER-2..SIGNWRITING FILL MODIFIER-6
                (0x1DAA1 <= code && code <= 0x1DAAF) || // Mn  [15] SIGNWRITING ROTATION MODIFIER-2..SIGNWRITING ROTATION MODIFIER-16
                (0x1E000 <= code && code <= 0x1E006) || // Mn   [7] COMBINING GLAGOLITIC LETTER AZU..COMBINING GLAGOLITIC LETTER ZHIVETE
                (0x1E008 <= code && code <= 0x1E018) || // Mn  [17] COMBINING GLAGOLITIC LETTER ZEMLJA..COMBINING GLAGOLITIC LETTER HERU
                (0x1E01B <= code && code <= 0x1E021) || // Mn   [7] COMBINING GLAGOLITIC LETTER SHTA..COMBINING GLAGOLITIC LETTER YATI
                (0x1E023 <= code && code <= 0x1E024) || // Mn   [2] COMBINING GLAGOLITIC LETTER YU..COMBINING GLAGOLITIC LETTER SMALL YUS
                (0x1E026 <= code && code <= 0x1E02A) || // Mn   [5] COMBINING GLAGOLITIC LETTER YO..COMBINING GLAGOLITIC LETTER FITA
                (0x1E8D0 <= code && code <= 0x1E8D6) || // Mn   [7] MENDE KIKAKUI COMBINING NUMBER TEENS..MENDE KIKAKUI COMBINING NUMBER MILLIONS
                (0x1E944 <= code && code <= 0x1E94A) || // Mn   [7] ADLAM ALIF LENGTHENER..ADLAM NUKTA
                (0xE0020 <= code && code <= 0xE007F) || // Cf  [96] TAG SPACE..CANCEL TAG
                (0xE0100 <= code && code <= 0xE01EF) // Mn [240] VARIATION SELECTOR-17..VARIATION SELECTOR-256
            ) {
                return Extend;
            }
            if ((0x1F1E6 <= code && code <= 0x1F1FF) // So  [26] REGIONAL INDICATOR SYMBOL LETTER A..REGIONAL INDICATOR SYMBOL LETTER Z
            ) {
                return Regional_Indicator;
            }
            if (0x0903 == code || // Mc       DEVANAGARI SIGN VISARGA
                0x093B == code || // Mc       DEVANAGARI VOWEL SIGN OOE
                (0x093E <= code && code <= 0x0940) || // Mc   [3] DEVANAGARI VOWEL SIGN AA..DEVANAGARI VOWEL SIGN II
                (0x0949 <= code && code <= 0x094C) || // Mc   [4] DEVANAGARI VOWEL SIGN CANDRA O..DEVANAGARI VOWEL SIGN AU
                (0x094E <= code && code <= 0x094F) || // Mc   [2] DEVANAGARI VOWEL SIGN PRISHTHAMATRA E..DEVANAGARI VOWEL SIGN AW
                (0x0982 <= code && code <= 0x0983) || // Mc   [2] BENGALI SIGN ANUSVARA..BENGALI SIGN VISARGA
                (0x09BF <= code && code <= 0x09C0) || // Mc   [2] BENGALI VOWEL SIGN I..BENGALI VOWEL SIGN II
                (0x09C7 <= code && code <= 0x09C8) || // Mc   [2] BENGALI VOWEL SIGN E..BENGALI VOWEL SIGN AI
                (0x09CB <= code && code <= 0x09CC) || // Mc   [2] BENGALI VOWEL SIGN O..BENGALI VOWEL SIGN AU
                0x0A03 == code || // Mc       GURMUKHI SIGN VISARGA
                (0x0A3E <= code && code <= 0x0A40) || // Mc   [3] GURMUKHI VOWEL SIGN AA..GURMUKHI VOWEL SIGN II
                0x0A83 == code || // Mc       GUJARATI SIGN VISARGA
                (0x0ABE <= code && code <= 0x0AC0) || // Mc   [3] GUJARATI VOWEL SIGN AA..GUJARATI VOWEL SIGN II
                0x0AC9 == code || // Mc       GUJARATI VOWEL SIGN CANDRA O
                (0x0ACB <= code && code <= 0x0ACC) || // Mc   [2] GUJARATI VOWEL SIGN O..GUJARATI VOWEL SIGN AU
                (0x0B02 <= code && code <= 0x0B03) || // Mc   [2] ORIYA SIGN ANUSVARA..ORIYA SIGN VISARGA
                0x0B40 == code || // Mc       ORIYA VOWEL SIGN II
                (0x0B47 <= code && code <= 0x0B48) || // Mc   [2] ORIYA VOWEL SIGN E..ORIYA VOWEL SIGN AI
                (0x0B4B <= code && code <= 0x0B4C) || // Mc   [2] ORIYA VOWEL SIGN O..ORIYA VOWEL SIGN AU
                0x0BBF == code || // Mc       TAMIL VOWEL SIGN I
                (0x0BC1 <= code && code <= 0x0BC2) || // Mc   [2] TAMIL VOWEL SIGN U..TAMIL VOWEL SIGN UU
                (0x0BC6 <= code && code <= 0x0BC8) || // Mc   [3] TAMIL VOWEL SIGN E..TAMIL VOWEL SIGN AI
                (0x0BCA <= code && code <= 0x0BCC) || // Mc   [3] TAMIL VOWEL SIGN O..TAMIL VOWEL SIGN AU
                (0x0C01 <= code && code <= 0x0C03) || // Mc   [3] TELUGU SIGN CANDRABINDU..TELUGU SIGN VISARGA
                (0x0C41 <= code && code <= 0x0C44) || // Mc   [4] TELUGU VOWEL SIGN U..TELUGU VOWEL SIGN VOCALIC RR
                (0x0C82 <= code && code <= 0x0C83) || // Mc   [2] KANNADA SIGN ANUSVARA..KANNADA SIGN VISARGA
                0x0CBE == code || // Mc       KANNADA VOWEL SIGN AA
                (0x0CC0 <= code && code <= 0x0CC1) || // Mc   [2] KANNADA VOWEL SIGN II..KANNADA VOWEL SIGN U
                (0x0CC3 <= code && code <= 0x0CC4) || // Mc   [2] KANNADA VOWEL SIGN VOCALIC R..KANNADA VOWEL SIGN VOCALIC RR
                (0x0CC7 <= code && code <= 0x0CC8) || // Mc   [2] KANNADA VOWEL SIGN EE..KANNADA VOWEL SIGN AI
                (0x0CCA <= code && code <= 0x0CCB) || // Mc   [2] KANNADA VOWEL SIGN O..KANNADA VOWEL SIGN OO
                (0x0D02 <= code && code <= 0x0D03) || // Mc   [2] MALAYALAM SIGN ANUSVARA..MALAYALAM SIGN VISARGA
                (0x0D3F <= code && code <= 0x0D40) || // Mc   [2] MALAYALAM VOWEL SIGN I..MALAYALAM VOWEL SIGN II
                (0x0D46 <= code && code <= 0x0D48) || // Mc   [3] MALAYALAM VOWEL SIGN E..MALAYALAM VOWEL SIGN AI
                (0x0D4A <= code && code <= 0x0D4C) || // Mc   [3] MALAYALAM VOWEL SIGN O..MALAYALAM VOWEL SIGN AU
                (0x0D82 <= code && code <= 0x0D83) || // Mc   [2] SINHALA SIGN ANUSVARAYA..SINHALA SIGN VISARGAYA
                (0x0DD0 <= code && code <= 0x0DD1) || // Mc   [2] SINHALA VOWEL SIGN KETTI AEDA-PILLA..SINHALA VOWEL SIGN DIGA AEDA-PILLA
                (0x0DD8 <= code && code <= 0x0DDE) || // Mc   [7] SINHALA VOWEL SIGN GAETTA-PILLA..SINHALA VOWEL SIGN KOMBUVA HAA GAYANUKITTA
                (0x0DF2 <= code && code <= 0x0DF3) || // Mc   [2] SINHALA VOWEL SIGN DIGA GAETTA-PILLA..SINHALA VOWEL SIGN DIGA GAYANUKITTA
                0x0E33 == code || // Lo       THAI CHARACTER SARA AM
                0x0EB3 == code || // Lo       LAO VOWEL SIGN AM
                (0x0F3E <= code && code <= 0x0F3F) || // Mc   [2] TIBETAN SIGN YAR TSHES..TIBETAN SIGN MAR TSHES
                0x0F7F == code || // Mc       TIBETAN SIGN RNAM BCAD
                0x1031 == code || // Mc       MYANMAR VOWEL SIGN E
                (0x103B <= code && code <= 0x103C) || // Mc   [2] MYANMAR CONSONANT SIGN MEDIAL YA..MYANMAR CONSONANT SIGN MEDIAL RA
                (0x1056 <= code && code <= 0x1057) || // Mc   [2] MYANMAR VOWEL SIGN VOCALIC R..MYANMAR VOWEL SIGN VOCALIC RR
                0x1084 == code || // Mc       MYANMAR VOWEL SIGN SHAN E
                0x17B6 == code || // Mc       KHMER VOWEL SIGN AA
                (0x17BE <= code && code <= 0x17C5) || // Mc   [8] KHMER VOWEL SIGN OE..KHMER VOWEL SIGN AU
                (0x17C7 <= code && code <= 0x17C8) || // Mc   [2] KHMER SIGN REAHMUK..KHMER SIGN YUUKALEAPINTU
                (0x1923 <= code && code <= 0x1926) || // Mc   [4] LIMBU VOWEL SIGN EE..LIMBU VOWEL SIGN AU
                (0x1929 <= code && code <= 0x192B) || // Mc   [3] LIMBU SUBJOINED LETTER YA..LIMBU SUBJOINED LETTER WA
                (0x1930 <= code && code <= 0x1931) || // Mc   [2] LIMBU SMALL LETTER KA..LIMBU SMALL LETTER NGA
                (0x1933 <= code && code <= 0x1938) || // Mc   [6] LIMBU SMALL LETTER TA..LIMBU SMALL LETTER LA
                (0x1A19 <= code && code <= 0x1A1A) || // Mc   [2] BUGINESE VOWEL SIGN E..BUGINESE VOWEL SIGN O
                0x1A55 == code || // Mc       TAI THAM CONSONANT SIGN MEDIAL RA
                0x1A57 == code || // Mc       TAI THAM CONSONANT SIGN LA TANG LAI
                (0x1A6D <= code && code <= 0x1A72) || // Mc   [6] TAI THAM VOWEL SIGN OY..TAI THAM VOWEL SIGN THAM AI
                0x1B04 == code || // Mc       BALINESE SIGN BISAH
                0x1B35 == code || // Mc       BALINESE VOWEL SIGN TEDUNG
                0x1B3B == code || // Mc       BALINESE VOWEL SIGN RA REPA TEDUNG
                (0x1B3D <= code && code <= 0x1B41) || // Mc   [5] BALINESE VOWEL SIGN LA LENGA TEDUNG..BALINESE VOWEL SIGN TALING REPA TEDUNG
                (0x1B43 <= code && code <= 0x1B44) || // Mc   [2] BALINESE VOWEL SIGN PEPET TEDUNG..BALINESE ADEG ADEG
                0x1B82 == code || // Mc       SUNDANESE SIGN PANGWISAD
                0x1BA1 == code || // Mc       SUNDANESE CONSONANT SIGN PAMINGKAL
                (0x1BA6 <= code && code <= 0x1BA7) || // Mc   [2] SUNDANESE VOWEL SIGN PANAELAENG..SUNDANESE VOWEL SIGN PANOLONG
                0x1BAA == code || // Mc       SUNDANESE SIGN PAMAAEH
                0x1BE7 == code || // Mc       BATAK VOWEL SIGN E
                (0x1BEA <= code && code <= 0x1BEC) || // Mc   [3] BATAK VOWEL SIGN I..BATAK VOWEL SIGN O
                0x1BEE == code || // Mc       BATAK VOWEL SIGN U
                (0x1BF2 <= code && code <= 0x1BF3) || // Mc   [2] BATAK PANGOLAT..BATAK PANONGONAN
                (0x1C24 <= code && code <= 0x1C2B) || // Mc   [8] LEPCHA SUBJOINED LETTER YA..LEPCHA VOWEL SIGN UU
                (0x1C34 <= code && code <= 0x1C35) || // Mc   [2] LEPCHA CONSONANT SIGN NYIN-DO..LEPCHA CONSONANT SIGN KANG
                0x1CE1 == code || // Mc       VEDIC TONE ATHARVAVEDIC INDEPENDENT SVARITA
                (0x1CF2 <= code && code <= 0x1CF3) || // Mc   [2] VEDIC SIGN ARDHAVISARGA..VEDIC SIGN ROTATED ARDHAVISARGA
                0x1CF7 == code || // Mc       VEDIC SIGN ATIKRAMA
                (0xA823 <= code && code <= 0xA824) || // Mc   [2] SYLOTI NAGRI VOWEL SIGN A..SYLOTI NAGRI VOWEL SIGN I
                0xA827 == code || // Mc       SYLOTI NAGRI VOWEL SIGN OO
                (0xA880 <= code && code <= 0xA881) || // Mc   [2] SAURASHTRA SIGN ANUSVARA..SAURASHTRA SIGN VISARGA
                (0xA8B4 <= code && code <= 0xA8C3) || // Mc  [16] SAURASHTRA CONSONANT SIGN HAARU..SAURASHTRA VOWEL SIGN AU
                (0xA952 <= code && code <= 0xA953) || // Mc   [2] REJANG CONSONANT SIGN H..REJANG VIRAMA
                0xA983 == code || // Mc       JAVANESE SIGN WIGNYAN
                (0xA9B4 <= code && code <= 0xA9B5) || // Mc   [2] JAVANESE VOWEL SIGN TARUNG..JAVANESE VOWEL SIGN TOLONG
                (0xA9BA <= code && code <= 0xA9BB) || // Mc   [2] JAVANESE VOWEL SIGN TALING..JAVANESE VOWEL SIGN DIRGA MURE
                (0xA9BD <= code && code <= 0xA9C0) || // Mc   [4] JAVANESE CONSONANT SIGN KERET..JAVANESE PANGKON
                (0xAA2F <= code && code <= 0xAA30) || // Mc   [2] CHAM VOWEL SIGN O..CHAM VOWEL SIGN AI
                (0xAA33 <= code && code <= 0xAA34) || // Mc   [2] CHAM CONSONANT SIGN YA..CHAM CONSONANT SIGN RA
                0xAA4D == code || // Mc       CHAM CONSONANT SIGN FINAL H
                0xAAEB == code || // Mc       MEETEI MAYEK VOWEL SIGN II
                (0xAAEE <= code && code <= 0xAAEF) || // Mc   [2] MEETEI MAYEK VOWEL SIGN AU..MEETEI MAYEK VOWEL SIGN AAU
                0xAAF5 == code || // Mc       MEETEI MAYEK VOWEL SIGN VISARGA
                (0xABE3 <= code && code <= 0xABE4) || // Mc   [2] MEETEI MAYEK VOWEL SIGN ONAP..MEETEI MAYEK VOWEL SIGN INAP
                (0xABE6 <= code && code <= 0xABE7) || // Mc   [2] MEETEI MAYEK VOWEL SIGN YENAP..MEETEI MAYEK VOWEL SIGN SOUNAP
                (0xABE9 <= code && code <= 0xABEA) || // Mc   [2] MEETEI MAYEK VOWEL SIGN CHEINAP..MEETEI MAYEK VOWEL SIGN NUNG
                0xABEC == code || // Mc       MEETEI MAYEK LUM IYEK
                0x11000 == code || // Mc       BRAHMI SIGN CANDRABINDU
                0x11002 == code || // Mc       BRAHMI SIGN VISARGA
                0x11082 == code || // Mc       KAITHI SIGN VISARGA
                (0x110B0 <= code && code <= 0x110B2) || // Mc   [3] KAITHI VOWEL SIGN AA..KAITHI VOWEL SIGN II
                (0x110B7 <= code && code <= 0x110B8) || // Mc   [2] KAITHI VOWEL SIGN O..KAITHI VOWEL SIGN AU
                0x1112C == code || // Mc       CHAKMA VOWEL SIGN E
                0x11182 == code || // Mc       SHARADA SIGN VISARGA
                (0x111B3 <= code && code <= 0x111B5) || // Mc   [3] SHARADA VOWEL SIGN AA..SHARADA VOWEL SIGN II
                (0x111BF <= code && code <= 0x111C0) || // Mc   [2] SHARADA VOWEL SIGN AU..SHARADA SIGN VIRAMA
                (0x1122C <= code && code <= 0x1122E) || // Mc   [3] KHOJKI VOWEL SIGN AA..KHOJKI VOWEL SIGN II
                (0x11232 <= code && code <= 0x11233) || // Mc   [2] KHOJKI VOWEL SIGN O..KHOJKI VOWEL SIGN AU
                0x11235 == code || // Mc       KHOJKI SIGN VIRAMA
                (0x112E0 <= code && code <= 0x112E2) || // Mc   [3] KHUDAWADI VOWEL SIGN AA..KHUDAWADI VOWEL SIGN II
                (0x11302 <= code && code <= 0x11303) || // Mc   [2] GRANTHA SIGN ANUSVARA..GRANTHA SIGN VISARGA
                0x1133F == code || // Mc       GRANTHA VOWEL SIGN I
                (0x11341 <= code && code <= 0x11344) || // Mc   [4] GRANTHA VOWEL SIGN U..GRANTHA VOWEL SIGN VOCALIC RR
                (0x11347 <= code && code <= 0x11348) || // Mc   [2] GRANTHA VOWEL SIGN EE..GRANTHA VOWEL SIGN AI
                (0x1134B <= code && code <= 0x1134D) || // Mc   [3] GRANTHA VOWEL SIGN OO..GRANTHA SIGN VIRAMA
                (0x11362 <= code && code <= 0x11363) || // Mc   [2] GRANTHA VOWEL SIGN VOCALIC L..GRANTHA VOWEL SIGN VOCALIC LL
                (0x11435 <= code && code <= 0x11437) || // Mc   [3] NEWA VOWEL SIGN AA..NEWA VOWEL SIGN II
                (0x11440 <= code && code <= 0x11441) || // Mc   [2] NEWA VOWEL SIGN O..NEWA VOWEL SIGN AU
                0x11445 == code || // Mc       NEWA SIGN VISARGA
                (0x114B1 <= code && code <= 0x114B2) || // Mc   [2] TIRHUTA VOWEL SIGN I..TIRHUTA VOWEL SIGN II
                0x114B9 == code || // Mc       TIRHUTA VOWEL SIGN E
                (0x114BB <= code && code <= 0x114BC) || // Mc   [2] TIRHUTA VOWEL SIGN AI..TIRHUTA VOWEL SIGN O
                0x114BE == code || // Mc       TIRHUTA VOWEL SIGN AU
                0x114C1 == code || // Mc       TIRHUTA SIGN VISARGA
                (0x115B0 <= code && code <= 0x115B1) || // Mc   [2] SIDDHAM VOWEL SIGN I..SIDDHAM VOWEL SIGN II
                (0x115B8 <= code && code <= 0x115BB) || // Mc   [4] SIDDHAM VOWEL SIGN E..SIDDHAM VOWEL SIGN AU
                0x115BE == code || // Mc       SIDDHAM SIGN VISARGA
                (0x11630 <= code && code <= 0x11632) || // Mc   [3] MODI VOWEL SIGN AA..MODI VOWEL SIGN II
                (0x1163B <= code && code <= 0x1163C) || // Mc   [2] MODI VOWEL SIGN O..MODI VOWEL SIGN AU
                0x1163E == code || // Mc       MODI SIGN VISARGA
                0x116AC == code || // Mc       TAKRI SIGN VISARGA
                (0x116AE <= code && code <= 0x116AF) || // Mc   [2] TAKRI VOWEL SIGN I..TAKRI VOWEL SIGN II
                0x116B6 == code || // Mc       TAKRI SIGN VIRAMA
                (0x11720 <= code && code <= 0x11721) || // Mc   [2] AHOM VOWEL SIGN A..AHOM VOWEL SIGN AA
                0x11726 == code || // Mc       AHOM VOWEL SIGN E
                (0x11A07 <= code && code <= 0x11A08) || // Mc   [2] ZANABAZAR SQUARE VOWEL SIGN AI..ZANABAZAR SQUARE VOWEL SIGN AU
                0x11A39 == code || // Mc       ZANABAZAR SQUARE SIGN VISARGA
                (0x11A57 <= code && code <= 0x11A58) || // Mc   [2] SOYOMBO VOWEL SIGN AI..SOYOMBO VOWEL SIGN AU
                0x11A97 == code || // Mc       SOYOMBO SIGN VISARGA
                0x11C2F == code || // Mc       BHAIKSUKI VOWEL SIGN AA
                0x11C3E == code || // Mc       BHAIKSUKI SIGN VISARGA
                0x11CA9 == code || // Mc       MARCHEN SUBJOINED LETTER YA
                0x11CB1 == code || // Mc       MARCHEN VOWEL SIGN I
                0x11CB4 == code || // Mc       MARCHEN VOWEL SIGN O
                (0x16F51 <= code && code <= 0x16F7E) || // Mc  [46] MIAO SIGN ASPIRATION..MIAO VOWEL SIGN NG
                0x1D166 == code || // Mc       MUSICAL SYMBOL COMBINING SPRECHGESANG STEM
                0x1D16D == code // Mc       MUSICAL SYMBOL COMBINING AUGMENTATION DOT
            ) {
                return SpacingMark;
            }
            if ((0x1100 <= code && code <= 0x115F) || // Lo  [96] HANGUL CHOSEONG KIYEOK..HANGUL CHOSEONG FILLER
                (0xA960 <= code && code <= 0xA97C) // Lo  [29] HANGUL CHOSEONG TIKEUT-MIEUM..HANGUL CHOSEONG SSANGYEORINHIEUH
            ) {
                return L;
            }
            if ((0x1160 <= code && code <= 0x11A7) || // Lo  [72] HANGUL JUNGSEONG FILLER..HANGUL JUNGSEONG O-YAE
                (0xD7B0 <= code && code <= 0xD7C6) // Lo  [23] HANGUL JUNGSEONG O-YEO..HANGUL JUNGSEONG ARAEA-E
            ) {
                return V;
            }
            if ((0x11A8 <= code && code <= 0x11FF) || // Lo  [88] HANGUL JONGSEONG KIYEOK..HANGUL JONGSEONG SSANGNIEUN
                (0xD7CB <= code && code <= 0xD7FB) // Lo  [49] HANGUL JONGSEONG NIEUN-RIEUL..HANGUL JONGSEONG PHIEUPH-THIEUTH
            ) {
                return T;
            }
            if (0xAC00 == code || // Lo       HANGUL SYLLABLE GA
                0xAC1C == code || // Lo       HANGUL SYLLABLE GAE
                0xAC38 == code || // Lo       HANGUL SYLLABLE GYA
                0xAC54 == code || // Lo       HANGUL SYLLABLE GYAE
                0xAC70 == code || // Lo       HANGUL SYLLABLE GEO
                0xAC8C == code || // Lo       HANGUL SYLLABLE GE
                0xACA8 == code || // Lo       HANGUL SYLLABLE GYEO
                0xACC4 == code || // Lo       HANGUL SYLLABLE GYE
                0xACE0 == code || // Lo       HANGUL SYLLABLE GO
                0xACFC == code || // Lo       HANGUL SYLLABLE GWA
                0xAD18 == code || // Lo       HANGUL SYLLABLE GWAE
                0xAD34 == code || // Lo       HANGUL SYLLABLE GOE
                0xAD50 == code || // Lo       HANGUL SYLLABLE GYO
                0xAD6C == code || // Lo       HANGUL SYLLABLE GU
                0xAD88 == code || // Lo       HANGUL SYLLABLE GWEO
                0xADA4 == code || // Lo       HANGUL SYLLABLE GWE
                0xADC0 == code || // Lo       HANGUL SYLLABLE GWI
                0xADDC == code || // Lo       HANGUL SYLLABLE GYU
                0xADF8 == code || // Lo       HANGUL SYLLABLE GEU
                0xAE14 == code || // Lo       HANGUL SYLLABLE GYI
                0xAE30 == code || // Lo       HANGUL SYLLABLE GI
                0xAE4C == code || // Lo       HANGUL SYLLABLE GGA
                0xAE68 == code || // Lo       HANGUL SYLLABLE GGAE
                0xAE84 == code || // Lo       HANGUL SYLLABLE GGYA
                0xAEA0 == code || // Lo       HANGUL SYLLABLE GGYAE
                0xAEBC == code || // Lo       HANGUL SYLLABLE GGEO
                0xAED8 == code || // Lo       HANGUL SYLLABLE GGE
                0xAEF4 == code || // Lo       HANGUL SYLLABLE GGYEO
                0xAF10 == code || // Lo       HANGUL SYLLABLE GGYE
                0xAF2C == code || // Lo       HANGUL SYLLABLE GGO
                0xAF48 == code || // Lo       HANGUL SYLLABLE GGWA
                0xAF64 == code || // Lo       HANGUL SYLLABLE GGWAE
                0xAF80 == code || // Lo       HANGUL SYLLABLE GGOE
                0xAF9C == code || // Lo       HANGUL SYLLABLE GGYO
                0xAFB8 == code || // Lo       HANGUL SYLLABLE GGU
                0xAFD4 == code || // Lo       HANGUL SYLLABLE GGWEO
                0xAFF0 == code || // Lo       HANGUL SYLLABLE GGWE
                0xB00C == code || // Lo       HANGUL SYLLABLE GGWI
                0xB028 == code || // Lo       HANGUL SYLLABLE GGYU
                0xB044 == code || // Lo       HANGUL SYLLABLE GGEU
                0xB060 == code || // Lo       HANGUL SYLLABLE GGYI
                0xB07C == code || // Lo       HANGUL SYLLABLE GGI
                0xB098 == code || // Lo       HANGUL SYLLABLE NA
                0xB0B4 == code || // Lo       HANGUL SYLLABLE NAE
                0xB0D0 == code || // Lo       HANGUL SYLLABLE NYA
                0xB0EC == code || // Lo       HANGUL SYLLABLE NYAE
                0xB108 == code || // Lo       HANGUL SYLLABLE NEO
                0xB124 == code || // Lo       HANGUL SYLLABLE NE
                0xB140 == code || // Lo       HANGUL SYLLABLE NYEO
                0xB15C == code || // Lo       HANGUL SYLLABLE NYE
                0xB178 == code || // Lo       HANGUL SYLLABLE NO
                0xB194 == code || // Lo       HANGUL SYLLABLE NWA
                0xB1B0 == code || // Lo       HANGUL SYLLABLE NWAE
                0xB1CC == code || // Lo       HANGUL SYLLABLE NOE
                0xB1E8 == code || // Lo       HANGUL SYLLABLE NYO
                0xB204 == code || // Lo       HANGUL SYLLABLE NU
                0xB220 == code || // Lo       HANGUL SYLLABLE NWEO
                0xB23C == code || // Lo       HANGUL SYLLABLE NWE
                0xB258 == code || // Lo       HANGUL SYLLABLE NWI
                0xB274 == code || // Lo       HANGUL SYLLABLE NYU
                0xB290 == code || // Lo       HANGUL SYLLABLE NEU
                0xB2AC == code || // Lo       HANGUL SYLLABLE NYI
                0xB2C8 == code || // Lo       HANGUL SYLLABLE NI
                0xB2E4 == code || // Lo       HANGUL SYLLABLE DA
                0xB300 == code || // Lo       HANGUL SYLLABLE DAE
                0xB31C == code || // Lo       HANGUL SYLLABLE DYA
                0xB338 == code || // Lo       HANGUL SYLLABLE DYAE
                0xB354 == code || // Lo       HANGUL SYLLABLE DEO
                0xB370 == code || // Lo       HANGUL SYLLABLE DE
                0xB38C == code || // Lo       HANGUL SYLLABLE DYEO
                0xB3A8 == code || // Lo       HANGUL SYLLABLE DYE
                0xB3C4 == code || // Lo       HANGUL SYLLABLE DO
                0xB3E0 == code || // Lo       HANGUL SYLLABLE DWA
                0xB3FC == code || // Lo       HANGUL SYLLABLE DWAE
                0xB418 == code || // Lo       HANGUL SYLLABLE DOE
                0xB434 == code || // Lo       HANGUL SYLLABLE DYO
                0xB450 == code || // Lo       HANGUL SYLLABLE DU
                0xB46C == code || // Lo       HANGUL SYLLABLE DWEO
                0xB488 == code || // Lo       HANGUL SYLLABLE DWE
                0xB4A4 == code || // Lo       HANGUL SYLLABLE DWI
                0xB4C0 == code || // Lo       HANGUL SYLLABLE DYU
                0xB4DC == code || // Lo       HANGUL SYLLABLE DEU
                0xB4F8 == code || // Lo       HANGUL SYLLABLE DYI
                0xB514 == code || // Lo       HANGUL SYLLABLE DI
                0xB530 == code || // Lo       HANGUL SYLLABLE DDA
                0xB54C == code || // Lo       HANGUL SYLLABLE DDAE
                0xB568 == code || // Lo       HANGUL SYLLABLE DDYA
                0xB584 == code || // Lo       HANGUL SYLLABLE DDYAE
                0xB5A0 == code || // Lo       HANGUL SYLLABLE DDEO
                0xB5BC == code || // Lo       HANGUL SYLLABLE DDE
                0xB5D8 == code || // Lo       HANGUL SYLLABLE DDYEO
                0xB5F4 == code || // Lo       HANGUL SYLLABLE DDYE
                0xB610 == code || // Lo       HANGUL SYLLABLE DDO
                0xB62C == code || // Lo       HANGUL SYLLABLE DDWA
                0xB648 == code || // Lo       HANGUL SYLLABLE DDWAE
                0xB664 == code || // Lo       HANGUL SYLLABLE DDOE
                0xB680 == code || // Lo       HANGUL SYLLABLE DDYO
                0xB69C == code || // Lo       HANGUL SYLLABLE DDU
                0xB6B8 == code || // Lo       HANGUL SYLLABLE DDWEO
                0xB6D4 == code || // Lo       HANGUL SYLLABLE DDWE
                0xB6F0 == code || // Lo       HANGUL SYLLABLE DDWI
                0xB70C == code || // Lo       HANGUL SYLLABLE DDYU
                0xB728 == code || // Lo       HANGUL SYLLABLE DDEU
                0xB744 == code || // Lo       HANGUL SYLLABLE DDYI
                0xB760 == code || // Lo       HANGUL SYLLABLE DDI
                0xB77C == code || // Lo       HANGUL SYLLABLE RA
                0xB798 == code || // Lo       HANGUL SYLLABLE RAE
                0xB7B4 == code || // Lo       HANGUL SYLLABLE RYA
                0xB7D0 == code || // Lo       HANGUL SYLLABLE RYAE
                0xB7EC == code || // Lo       HANGUL SYLLABLE REO
                0xB808 == code || // Lo       HANGUL SYLLABLE RE
                0xB824 == code || // Lo       HANGUL SYLLABLE RYEO
                0xB840 == code || // Lo       HANGUL SYLLABLE RYE
                0xB85C == code || // Lo       HANGUL SYLLABLE RO
                0xB878 == code || // Lo       HANGUL SYLLABLE RWA
                0xB894 == code || // Lo       HANGUL SYLLABLE RWAE
                0xB8B0 == code || // Lo       HANGUL SYLLABLE ROE
                0xB8CC == code || // Lo       HANGUL SYLLABLE RYO
                0xB8E8 == code || // Lo       HANGUL SYLLABLE RU
                0xB904 == code || // Lo       HANGUL SYLLABLE RWEO
                0xB920 == code || // Lo       HANGUL SYLLABLE RWE
                0xB93C == code || // Lo       HANGUL SYLLABLE RWI
                0xB958 == code || // Lo       HANGUL SYLLABLE RYU
                0xB974 == code || // Lo       HANGUL SYLLABLE REU
                0xB990 == code || // Lo       HANGUL SYLLABLE RYI
                0xB9AC == code || // Lo       HANGUL SYLLABLE RI
                0xB9C8 == code || // Lo       HANGUL SYLLABLE MA
                0xB9E4 == code || // Lo       HANGUL SYLLABLE MAE
                0xBA00 == code || // Lo       HANGUL SYLLABLE MYA
                0xBA1C == code || // Lo       HANGUL SYLLABLE MYAE
                0xBA38 == code || // Lo       HANGUL SYLLABLE MEO
                0xBA54 == code || // Lo       HANGUL SYLLABLE ME
                0xBA70 == code || // Lo       HANGUL SYLLABLE MYEO
                0xBA8C == code || // Lo       HANGUL SYLLABLE MYE
                0xBAA8 == code || // Lo       HANGUL SYLLABLE MO
                0xBAC4 == code || // Lo       HANGUL SYLLABLE MWA
                0xBAE0 == code || // Lo       HANGUL SYLLABLE MWAE
                0xBAFC == code || // Lo       HANGUL SYLLABLE MOE
                0xBB18 == code || // Lo       HANGUL SYLLABLE MYO
                0xBB34 == code || // Lo       HANGUL SYLLABLE MU
                0xBB50 == code || // Lo       HANGUL SYLLABLE MWEO
                0xBB6C == code || // Lo       HANGUL SYLLABLE MWE
                0xBB88 == code || // Lo       HANGUL SYLLABLE MWI
                0xBBA4 == code || // Lo       HANGUL SYLLABLE MYU
                0xBBC0 == code || // Lo       HANGUL SYLLABLE MEU
                0xBBDC == code || // Lo       HANGUL SYLLABLE MYI
                0xBBF8 == code || // Lo       HANGUL SYLLABLE MI
                0xBC14 == code || // Lo       HANGUL SYLLABLE BA
                0xBC30 == code || // Lo       HANGUL SYLLABLE BAE
                0xBC4C == code || // Lo       HANGUL SYLLABLE BYA
                0xBC68 == code || // Lo       HANGUL SYLLABLE BYAE
                0xBC84 == code || // Lo       HANGUL SYLLABLE BEO
                0xBCA0 == code || // Lo       HANGUL SYLLABLE BE
                0xBCBC == code || // Lo       HANGUL SYLLABLE BYEO
                0xBCD8 == code || // Lo       HANGUL SYLLABLE BYE
                0xBCF4 == code || // Lo       HANGUL SYLLABLE BO
                0xBD10 == code || // Lo       HANGUL SYLLABLE BWA
                0xBD2C == code || // Lo       HANGUL SYLLABLE BWAE
                0xBD48 == code || // Lo       HANGUL SYLLABLE BOE
                0xBD64 == code || // Lo       HANGUL SYLLABLE BYO
                0xBD80 == code || // Lo       HANGUL SYLLABLE BU
                0xBD9C == code || // Lo       HANGUL SYLLABLE BWEO
                0xBDB8 == code || // Lo       HANGUL SYLLABLE BWE
                0xBDD4 == code || // Lo       HANGUL SYLLABLE BWI
                0xBDF0 == code || // Lo       HANGUL SYLLABLE BYU
                0xBE0C == code || // Lo       HANGUL SYLLABLE BEU
                0xBE28 == code || // Lo       HANGUL SYLLABLE BYI
                0xBE44 == code || // Lo       HANGUL SYLLABLE BI
                0xBE60 == code || // Lo       HANGUL SYLLABLE BBA
                0xBE7C == code || // Lo       HANGUL SYLLABLE BBAE
                0xBE98 == code || // Lo       HANGUL SYLLABLE BBYA
                0xBEB4 == code || // Lo       HANGUL SYLLABLE BBYAE
                0xBED0 == code || // Lo       HANGUL SYLLABLE BBEO
                0xBEEC == code || // Lo       HANGUL SYLLABLE BBE
                0xBF08 == code || // Lo       HANGUL SYLLABLE BBYEO
                0xBF24 == code || // Lo       HANGUL SYLLABLE BBYE
                0xBF40 == code || // Lo       HANGUL SYLLABLE BBO
                0xBF5C == code || // Lo       HANGUL SYLLABLE BBWA
                0xBF78 == code || // Lo       HANGUL SYLLABLE BBWAE
                0xBF94 == code || // Lo       HANGUL SYLLABLE BBOE
                0xBFB0 == code || // Lo       HANGUL SYLLABLE BBYO
                0xBFCC == code || // Lo       HANGUL SYLLABLE BBU
                0xBFE8 == code || // Lo       HANGUL SYLLABLE BBWEO
                0xC004 == code || // Lo       HANGUL SYLLABLE BBWE
                0xC020 == code || // Lo       HANGUL SYLLABLE BBWI
                0xC03C == code || // Lo       HANGUL SYLLABLE BBYU
                0xC058 == code || // Lo       HANGUL SYLLABLE BBEU
                0xC074 == code || // Lo       HANGUL SYLLABLE BBYI
                0xC090 == code || // Lo       HANGUL SYLLABLE BBI
                0xC0AC == code || // Lo       HANGUL SYLLABLE SA
                0xC0C8 == code || // Lo       HANGUL SYLLABLE SAE
                0xC0E4 == code || // Lo       HANGUL SYLLABLE SYA
                0xC100 == code || // Lo       HANGUL SYLLABLE SYAE
                0xC11C == code || // Lo       HANGUL SYLLABLE SEO
                0xC138 == code || // Lo       HANGUL SYLLABLE SE
                0xC154 == code || // Lo       HANGUL SYLLABLE SYEO
                0xC170 == code || // Lo       HANGUL SYLLABLE SYE
                0xC18C == code || // Lo       HANGUL SYLLABLE SO
                0xC1A8 == code || // Lo       HANGUL SYLLABLE SWA
                0xC1C4 == code || // Lo       HANGUL SYLLABLE SWAE
                0xC1E0 == code || // Lo       HANGUL SYLLABLE SOE
                0xC1FC == code || // Lo       HANGUL SYLLABLE SYO
                0xC218 == code || // Lo       HANGUL SYLLABLE SU
                0xC234 == code || // Lo       HANGUL SYLLABLE SWEO
                0xC250 == code || // Lo       HANGUL SYLLABLE SWE
                0xC26C == code || // Lo       HANGUL SYLLABLE SWI
                0xC288 == code || // Lo       HANGUL SYLLABLE SYU
                0xC2A4 == code || // Lo       HANGUL SYLLABLE SEU
                0xC2C0 == code || // Lo       HANGUL SYLLABLE SYI
                0xC2DC == code || // Lo       HANGUL SYLLABLE SI
                0xC2F8 == code || // Lo       HANGUL SYLLABLE SSA
                0xC314 == code || // Lo       HANGUL SYLLABLE SSAE
                0xC330 == code || // Lo       HANGUL SYLLABLE SSYA
                0xC34C == code || // Lo       HANGUL SYLLABLE SSYAE
                0xC368 == code || // Lo       HANGUL SYLLABLE SSEO
                0xC384 == code || // Lo       HANGUL SYLLABLE SSE
                0xC3A0 == code || // Lo       HANGUL SYLLABLE SSYEO
                0xC3BC == code || // Lo       HANGUL SYLLABLE SSYE
                0xC3D8 == code || // Lo       HANGUL SYLLABLE SSO
                0xC3F4 == code || // Lo       HANGUL SYLLABLE SSWA
                0xC410 == code || // Lo       HANGUL SYLLABLE SSWAE
                0xC42C == code || // Lo       HANGUL SYLLABLE SSOE
                0xC448 == code || // Lo       HANGUL SYLLABLE SSYO
                0xC464 == code || // Lo       HANGUL SYLLABLE SSU
                0xC480 == code || // Lo       HANGUL SYLLABLE SSWEO
                0xC49C == code || // Lo       HANGUL SYLLABLE SSWE
                0xC4B8 == code || // Lo       HANGUL SYLLABLE SSWI
                0xC4D4 == code || // Lo       HANGUL SYLLABLE SSYU
                0xC4F0 == code || // Lo       HANGUL SYLLABLE SSEU
                0xC50C == code || // Lo       HANGUL SYLLABLE SSYI
                0xC528 == code || // Lo       HANGUL SYLLABLE SSI
                0xC544 == code || // Lo       HANGUL SYLLABLE A
                0xC560 == code || // Lo       HANGUL SYLLABLE AE
                0xC57C == code || // Lo       HANGUL SYLLABLE YA
                0xC598 == code || // Lo       HANGUL SYLLABLE YAE
                0xC5B4 == code || // Lo       HANGUL SYLLABLE EO
                0xC5D0 == code || // Lo       HANGUL SYLLABLE E
                0xC5EC == code || // Lo       HANGUL SYLLABLE YEO
                0xC608 == code || // Lo       HANGUL SYLLABLE YE
                0xC624 == code || // Lo       HANGUL SYLLABLE O
                0xC640 == code || // Lo       HANGUL SYLLABLE WA
                0xC65C == code || // Lo       HANGUL SYLLABLE WAE
                0xC678 == code || // Lo       HANGUL SYLLABLE OE
                0xC694 == code || // Lo       HANGUL SYLLABLE YO
                0xC6B0 == code || // Lo       HANGUL SYLLABLE U
                0xC6CC == code || // Lo       HANGUL SYLLABLE WEO
                0xC6E8 == code || // Lo       HANGUL SYLLABLE WE
                0xC704 == code || // Lo       HANGUL SYLLABLE WI
                0xC720 == code || // Lo       HANGUL SYLLABLE YU
                0xC73C == code || // Lo       HANGUL SYLLABLE EU
                0xC758 == code || // Lo       HANGUL SYLLABLE YI
                0xC774 == code || // Lo       HANGUL SYLLABLE I
                0xC790 == code || // Lo       HANGUL SYLLABLE JA
                0xC7AC == code || // Lo       HANGUL SYLLABLE JAE
                0xC7C8 == code || // Lo       HANGUL SYLLABLE JYA
                0xC7E4 == code || // Lo       HANGUL SYLLABLE JYAE
                0xC800 == code || // Lo       HANGUL SYLLABLE JEO
                0xC81C == code || // Lo       HANGUL SYLLABLE JE
                0xC838 == code || // Lo       HANGUL SYLLABLE JYEO
                0xC854 == code || // Lo       HANGUL SYLLABLE JYE
                0xC870 == code || // Lo       HANGUL SYLLABLE JO
                0xC88C == code || // Lo       HANGUL SYLLABLE JWA
                0xC8A8 == code || // Lo       HANGUL SYLLABLE JWAE
                0xC8C4 == code || // Lo       HANGUL SYLLABLE JOE
                0xC8E0 == code || // Lo       HANGUL SYLLABLE JYO
                0xC8FC == code || // Lo       HANGUL SYLLABLE JU
                0xC918 == code || // Lo       HANGUL SYLLABLE JWEO
                0xC934 == code || // Lo       HANGUL SYLLABLE JWE
                0xC950 == code || // Lo       HANGUL SYLLABLE JWI
                0xC96C == code || // Lo       HANGUL SYLLABLE JYU
                0xC988 == code || // Lo       HANGUL SYLLABLE JEU
                0xC9A4 == code || // Lo       HANGUL SYLLABLE JYI
                0xC9C0 == code || // Lo       HANGUL SYLLABLE JI
                0xC9DC == code || // Lo       HANGUL SYLLABLE JJA
                0xC9F8 == code || // Lo       HANGUL SYLLABLE JJAE
                0xCA14 == code || // Lo       HANGUL SYLLABLE JJYA
                0xCA30 == code || // Lo       HANGUL SYLLABLE JJYAE
                0xCA4C == code || // Lo       HANGUL SYLLABLE JJEO
                0xCA68 == code || // Lo       HANGUL SYLLABLE JJE
                0xCA84 == code || // Lo       HANGUL SYLLABLE JJYEO
                0xCAA0 == code || // Lo       HANGUL SYLLABLE JJYE
                0xCABC == code || // Lo       HANGUL SYLLABLE JJO
                0xCAD8 == code || // Lo       HANGUL SYLLABLE JJWA
                0xCAF4 == code || // Lo       HANGUL SYLLABLE JJWAE
                0xCB10 == code || // Lo       HANGUL SYLLABLE JJOE
                0xCB2C == code || // Lo       HANGUL SYLLABLE JJYO
                0xCB48 == code || // Lo       HANGUL SYLLABLE JJU
                0xCB64 == code || // Lo       HANGUL SYLLABLE JJWEO
                0xCB80 == code || // Lo       HANGUL SYLLABLE JJWE
                0xCB9C == code || // Lo       HANGUL SYLLABLE JJWI
                0xCBB8 == code || // Lo       HANGUL SYLLABLE JJYU
                0xCBD4 == code || // Lo       HANGUL SYLLABLE JJEU
                0xCBF0 == code || // Lo       HANGUL SYLLABLE JJYI
                0xCC0C == code || // Lo       HANGUL SYLLABLE JJI
                0xCC28 == code || // Lo       HANGUL SYLLABLE CA
                0xCC44 == code || // Lo       HANGUL SYLLABLE CAE
                0xCC60 == code || // Lo       HANGUL SYLLABLE CYA
                0xCC7C == code || // Lo       HANGUL SYLLABLE CYAE
                0xCC98 == code || // Lo       HANGUL SYLLABLE CEO
                0xCCB4 == code || // Lo       HANGUL SYLLABLE CE
                0xCCD0 == code || // Lo       HANGUL SYLLABLE CYEO
                0xCCEC == code || // Lo       HANGUL SYLLABLE CYE
                0xCD08 == code || // Lo       HANGUL SYLLABLE CO
                0xCD24 == code || // Lo       HANGUL SYLLABLE CWA
                0xCD40 == code || // Lo       HANGUL SYLLABLE CWAE
                0xCD5C == code || // Lo       HANGUL SYLLABLE COE
                0xCD78 == code || // Lo       HANGUL SYLLABLE CYO
                0xCD94 == code || // Lo       HANGUL SYLLABLE CU
                0xCDB0 == code || // Lo       HANGUL SYLLABLE CWEO
                0xCDCC == code || // Lo       HANGUL SYLLABLE CWE
                0xCDE8 == code || // Lo       HANGUL SYLLABLE CWI
                0xCE04 == code || // Lo       HANGUL SYLLABLE CYU
                0xCE20 == code || // Lo       HANGUL SYLLABLE CEU
                0xCE3C == code || // Lo       HANGUL SYLLABLE CYI
                0xCE58 == code || // Lo       HANGUL SYLLABLE CI
                0xCE74 == code || // Lo       HANGUL SYLLABLE KA
                0xCE90 == code || // Lo       HANGUL SYLLABLE KAE
                0xCEAC == code || // Lo       HANGUL SYLLABLE KYA
                0xCEC8 == code || // Lo       HANGUL SYLLABLE KYAE
                0xCEE4 == code || // Lo       HANGUL SYLLABLE KEO
                0xCF00 == code || // Lo       HANGUL SYLLABLE KE
                0xCF1C == code || // Lo       HANGUL SYLLABLE KYEO
                0xCF38 == code || // Lo       HANGUL SYLLABLE KYE
                0xCF54 == code || // Lo       HANGUL SYLLABLE KO
                0xCF70 == code || // Lo       HANGUL SYLLABLE KWA
                0xCF8C == code || // Lo       HANGUL SYLLABLE KWAE
                0xCFA8 == code || // Lo       HANGUL SYLLABLE KOE
                0xCFC4 == code || // Lo       HANGUL SYLLABLE KYO
                0xCFE0 == code || // Lo       HANGUL SYLLABLE KU
                0xCFFC == code || // Lo       HANGUL SYLLABLE KWEO
                0xD018 == code || // Lo       HANGUL SYLLABLE KWE
                0xD034 == code || // Lo       HANGUL SYLLABLE KWI
                0xD050 == code || // Lo       HANGUL SYLLABLE KYU
                0xD06C == code || // Lo       HANGUL SYLLABLE KEU
                0xD088 == code || // Lo       HANGUL SYLLABLE KYI
                0xD0A4 == code || // Lo       HANGUL SYLLABLE KI
                0xD0C0 == code || // Lo       HANGUL SYLLABLE TA
                0xD0DC == code || // Lo       HANGUL SYLLABLE TAE
                0xD0F8 == code || // Lo       HANGUL SYLLABLE TYA
                0xD114 == code || // Lo       HANGUL SYLLABLE TYAE
                0xD130 == code || // Lo       HANGUL SYLLABLE TEO
                0xD14C == code || // Lo       HANGUL SYLLABLE TE
                0xD168 == code || // Lo       HANGUL SYLLABLE TYEO
                0xD184 == code || // Lo       HANGUL SYLLABLE TYE
                0xD1A0 == code || // Lo       HANGUL SYLLABLE TO
                0xD1BC == code || // Lo       HANGUL SYLLABLE TWA
                0xD1D8 == code || // Lo       HANGUL SYLLABLE TWAE
                0xD1F4 == code || // Lo       HANGUL SYLLABLE TOE
                0xD210 == code || // Lo       HANGUL SYLLABLE TYO
                0xD22C == code || // Lo       HANGUL SYLLABLE TU
                0xD248 == code || // Lo       HANGUL SYLLABLE TWEO
                0xD264 == code || // Lo       HANGUL SYLLABLE TWE
                0xD280 == code || // Lo       HANGUL SYLLABLE TWI
                0xD29C == code || // Lo       HANGUL SYLLABLE TYU
                0xD2B8 == code || // Lo       HANGUL SYLLABLE TEU
                0xD2D4 == code || // Lo       HANGUL SYLLABLE TYI
                0xD2F0 == code || // Lo       HANGUL SYLLABLE TI
                0xD30C == code || // Lo       HANGUL SYLLABLE PA
                0xD328 == code || // Lo       HANGUL SYLLABLE PAE
                0xD344 == code || // Lo       HANGUL SYLLABLE PYA
                0xD360 == code || // Lo       HANGUL SYLLABLE PYAE
                0xD37C == code || // Lo       HANGUL SYLLABLE PEO
                0xD398 == code || // Lo       HANGUL SYLLABLE PE
                0xD3B4 == code || // Lo       HANGUL SYLLABLE PYEO
                0xD3D0 == code || // Lo       HANGUL SYLLABLE PYE
                0xD3EC == code || // Lo       HANGUL SYLLABLE PO
                0xD408 == code || // Lo       HANGUL SYLLABLE PWA
                0xD424 == code || // Lo       HANGUL SYLLABLE PWAE
                0xD440 == code || // Lo       HANGUL SYLLABLE POE
                0xD45C == code || // Lo       HANGUL SYLLABLE PYO
                0xD478 == code || // Lo       HANGUL SYLLABLE PU
                0xD494 == code || // Lo       HANGUL SYLLABLE PWEO
                0xD4B0 == code || // Lo       HANGUL SYLLABLE PWE
                0xD4CC == code || // Lo       HANGUL SYLLABLE PWI
                0xD4E8 == code || // Lo       HANGUL SYLLABLE PYU
                0xD504 == code || // Lo       HANGUL SYLLABLE PEU
                0xD520 == code || // Lo       HANGUL SYLLABLE PYI
                0xD53C == code || // Lo       HANGUL SYLLABLE PI
                0xD558 == code || // Lo       HANGUL SYLLABLE HA
                0xD574 == code || // Lo       HANGUL SYLLABLE HAE
                0xD590 == code || // Lo       HANGUL SYLLABLE HYA
                0xD5AC == code || // Lo       HANGUL SYLLABLE HYAE
                0xD5C8 == code || // Lo       HANGUL SYLLABLE HEO
                0xD5E4 == code || // Lo       HANGUL SYLLABLE HE
                0xD600 == code || // Lo       HANGUL SYLLABLE HYEO
                0xD61C == code || // Lo       HANGUL SYLLABLE HYE
                0xD638 == code || // Lo       HANGUL SYLLABLE HO
                0xD654 == code || // Lo       HANGUL SYLLABLE HWA
                0xD670 == code || // Lo       HANGUL SYLLABLE HWAE
                0xD68C == code || // Lo       HANGUL SYLLABLE HOE
                0xD6A8 == code || // Lo       HANGUL SYLLABLE HYO
                0xD6C4 == code || // Lo       HANGUL SYLLABLE HU
                0xD6E0 == code || // Lo       HANGUL SYLLABLE HWEO
                0xD6FC == code || // Lo       HANGUL SYLLABLE HWE
                0xD718 == code || // Lo       HANGUL SYLLABLE HWI
                0xD734 == code || // Lo       HANGUL SYLLABLE HYU
                0xD750 == code || // Lo       HANGUL SYLLABLE HEU
                0xD76C == code || // Lo       HANGUL SYLLABLE HYI
                0xD788 == code // Lo       HANGUL SYLLABLE HI
            ) {
                return LV;
            }
            if ((0xAC01 <= code && code <= 0xAC1B) || // Lo  [27] HANGUL SYLLABLE GAG..HANGUL SYLLABLE GAH
                (0xAC1D <= code && code <= 0xAC37) || // Lo  [27] HANGUL SYLLABLE GAEG..HANGUL SYLLABLE GAEH
                (0xAC39 <= code && code <= 0xAC53) || // Lo  [27] HANGUL SYLLABLE GYAG..HANGUL SYLLABLE GYAH
                (0xAC55 <= code && code <= 0xAC6F) || // Lo  [27] HANGUL SYLLABLE GYAEG..HANGUL SYLLABLE GYAEH
                (0xAC71 <= code && code <= 0xAC8B) || // Lo  [27] HANGUL SYLLABLE GEOG..HANGUL SYLLABLE GEOH
                (0xAC8D <= code && code <= 0xACA7) || // Lo  [27] HANGUL SYLLABLE GEG..HANGUL SYLLABLE GEH
                (0xACA9 <= code && code <= 0xACC3) || // Lo  [27] HANGUL SYLLABLE GYEOG..HANGUL SYLLABLE GYEOH
                (0xACC5 <= code && code <= 0xACDF) || // Lo  [27] HANGUL SYLLABLE GYEG..HANGUL SYLLABLE GYEH
                (0xACE1 <= code && code <= 0xACFB) || // Lo  [27] HANGUL SYLLABLE GOG..HANGUL SYLLABLE GOH
                (0xACFD <= code && code <= 0xAD17) || // Lo  [27] HANGUL SYLLABLE GWAG..HANGUL SYLLABLE GWAH
                (0xAD19 <= code && code <= 0xAD33) || // Lo  [27] HANGUL SYLLABLE GWAEG..HANGUL SYLLABLE GWAEH
                (0xAD35 <= code && code <= 0xAD4F) || // Lo  [27] HANGUL SYLLABLE GOEG..HANGUL SYLLABLE GOEH
                (0xAD51 <= code && code <= 0xAD6B) || // Lo  [27] HANGUL SYLLABLE GYOG..HANGUL SYLLABLE GYOH
                (0xAD6D <= code && code <= 0xAD87) || // Lo  [27] HANGUL SYLLABLE GUG..HANGUL SYLLABLE GUH
                (0xAD89 <= code && code <= 0xADA3) || // Lo  [27] HANGUL SYLLABLE GWEOG..HANGUL SYLLABLE GWEOH
                (0xADA5 <= code && code <= 0xADBF) || // Lo  [27] HANGUL SYLLABLE GWEG..HANGUL SYLLABLE GWEH
                (0xADC1 <= code && code <= 0xADDB) || // Lo  [27] HANGUL SYLLABLE GWIG..HANGUL SYLLABLE GWIH
                (0xADDD <= code && code <= 0xADF7) || // Lo  [27] HANGUL SYLLABLE GYUG..HANGUL SYLLABLE GYUH
                (0xADF9 <= code && code <= 0xAE13) || // Lo  [27] HANGUL SYLLABLE GEUG..HANGUL SYLLABLE GEUH
                (0xAE15 <= code && code <= 0xAE2F) || // Lo  [27] HANGUL SYLLABLE GYIG..HANGUL SYLLABLE GYIH
                (0xAE31 <= code && code <= 0xAE4B) || // Lo  [27] HANGUL SYLLABLE GIG..HANGUL SYLLABLE GIH
                (0xAE4D <= code && code <= 0xAE67) || // Lo  [27] HANGUL SYLLABLE GGAG..HANGUL SYLLABLE GGAH
                (0xAE69 <= code && code <= 0xAE83) || // Lo  [27] HANGUL SYLLABLE GGAEG..HANGUL SYLLABLE GGAEH
                (0xAE85 <= code && code <= 0xAE9F) || // Lo  [27] HANGUL SYLLABLE GGYAG..HANGUL SYLLABLE GGYAH
                (0xAEA1 <= code && code <= 0xAEBB) || // Lo  [27] HANGUL SYLLABLE GGYAEG..HANGUL SYLLABLE GGYAEH
                (0xAEBD <= code && code <= 0xAED7) || // Lo  [27] HANGUL SYLLABLE GGEOG..HANGUL SYLLABLE GGEOH
                (0xAED9 <= code && code <= 0xAEF3) || // Lo  [27] HANGUL SYLLABLE GGEG..HANGUL SYLLABLE GGEH
                (0xAEF5 <= code && code <= 0xAF0F) || // Lo  [27] HANGUL SYLLABLE GGYEOG..HANGUL SYLLABLE GGYEOH
                (0xAF11 <= code && code <= 0xAF2B) || // Lo  [27] HANGUL SYLLABLE GGYEG..HANGUL SYLLABLE GGYEH
                (0xAF2D <= code && code <= 0xAF47) || // Lo  [27] HANGUL SYLLABLE GGOG..HANGUL SYLLABLE GGOH
                (0xAF49 <= code && code <= 0xAF63) || // Lo  [27] HANGUL SYLLABLE GGWAG..HANGUL SYLLABLE GGWAH
                (0xAF65 <= code && code <= 0xAF7F) || // Lo  [27] HANGUL SYLLABLE GGWAEG..HANGUL SYLLABLE GGWAEH
                (0xAF81 <= code && code <= 0xAF9B) || // Lo  [27] HANGUL SYLLABLE GGOEG..HANGUL SYLLABLE GGOEH
                (0xAF9D <= code && code <= 0xAFB7) || // Lo  [27] HANGUL SYLLABLE GGYOG..HANGUL SYLLABLE GGYOH
                (0xAFB9 <= code && code <= 0xAFD3) || // Lo  [27] HANGUL SYLLABLE GGUG..HANGUL SYLLABLE GGUH
                (0xAFD5 <= code && code <= 0xAFEF) || // Lo  [27] HANGUL SYLLABLE GGWEOG..HANGUL SYLLABLE GGWEOH
                (0xAFF1 <= code && code <= 0xB00B) || // Lo  [27] HANGUL SYLLABLE GGWEG..HANGUL SYLLABLE GGWEH
                (0xB00D <= code && code <= 0xB027) || // Lo  [27] HANGUL SYLLABLE GGWIG..HANGUL SYLLABLE GGWIH
                (0xB029 <= code && code <= 0xB043) || // Lo  [27] HANGUL SYLLABLE GGYUG..HANGUL SYLLABLE GGYUH
                (0xB045 <= code && code <= 0xB05F) || // Lo  [27] HANGUL SYLLABLE GGEUG..HANGUL SYLLABLE GGEUH
                (0xB061 <= code && code <= 0xB07B) || // Lo  [27] HANGUL SYLLABLE GGYIG..HANGUL SYLLABLE GGYIH
                (0xB07D <= code && code <= 0xB097) || // Lo  [27] HANGUL SYLLABLE GGIG..HANGUL SYLLABLE GGIH
                (0xB099 <= code && code <= 0xB0B3) || // Lo  [27] HANGUL SYLLABLE NAG..HANGUL SYLLABLE NAH
                (0xB0B5 <= code && code <= 0xB0CF) || // Lo  [27] HANGUL SYLLABLE NAEG..HANGUL SYLLABLE NAEH
                (0xB0D1 <= code && code <= 0xB0EB) || // Lo  [27] HANGUL SYLLABLE NYAG..HANGUL SYLLABLE NYAH
                (0xB0ED <= code && code <= 0xB107) || // Lo  [27] HANGUL SYLLABLE NYAEG..HANGUL SYLLABLE NYAEH
                (0xB109 <= code && code <= 0xB123) || // Lo  [27] HANGUL SYLLABLE NEOG..HANGUL SYLLABLE NEOH
                (0xB125 <= code && code <= 0xB13F) || // Lo  [27] HANGUL SYLLABLE NEG..HANGUL SYLLABLE NEH
                (0xB141 <= code && code <= 0xB15B) || // Lo  [27] HANGUL SYLLABLE NYEOG..HANGUL SYLLABLE NYEOH
                (0xB15D <= code && code <= 0xB177) || // Lo  [27] HANGUL SYLLABLE NYEG..HANGUL SYLLABLE NYEH
                (0xB179 <= code && code <= 0xB193) || // Lo  [27] HANGUL SYLLABLE NOG..HANGUL SYLLABLE NOH
                (0xB195 <= code && code <= 0xB1AF) || // Lo  [27] HANGUL SYLLABLE NWAG..HANGUL SYLLABLE NWAH
                (0xB1B1 <= code && code <= 0xB1CB) || // Lo  [27] HANGUL SYLLABLE NWAEG..HANGUL SYLLABLE NWAEH
                (0xB1CD <= code && code <= 0xB1E7) || // Lo  [27] HANGUL SYLLABLE NOEG..HANGUL SYLLABLE NOEH
                (0xB1E9 <= code && code <= 0xB203) || // Lo  [27] HANGUL SYLLABLE NYOG..HANGUL SYLLABLE NYOH
                (0xB205 <= code && code <= 0xB21F) || // Lo  [27] HANGUL SYLLABLE NUG..HANGUL SYLLABLE NUH
                (0xB221 <= code && code <= 0xB23B) || // Lo  [27] HANGUL SYLLABLE NWEOG..HANGUL SYLLABLE NWEOH
                (0xB23D <= code && code <= 0xB257) || // Lo  [27] HANGUL SYLLABLE NWEG..HANGUL SYLLABLE NWEH
                (0xB259 <= code && code <= 0xB273) || // Lo  [27] HANGUL SYLLABLE NWIG..HANGUL SYLLABLE NWIH
                (0xB275 <= code && code <= 0xB28F) || // Lo  [27] HANGUL SYLLABLE NYUG..HANGUL SYLLABLE NYUH
                (0xB291 <= code && code <= 0xB2AB) || // Lo  [27] HANGUL SYLLABLE NEUG..HANGUL SYLLABLE NEUH
                (0xB2AD <= code && code <= 0xB2C7) || // Lo  [27] HANGUL SYLLABLE NYIG..HANGUL SYLLABLE NYIH
                (0xB2C9 <= code && code <= 0xB2E3) || // Lo  [27] HANGUL SYLLABLE NIG..HANGUL SYLLABLE NIH
                (0xB2E5 <= code && code <= 0xB2FF) || // Lo  [27] HANGUL SYLLABLE DAG..HANGUL SYLLABLE DAH
                (0xB301 <= code && code <= 0xB31B) || // Lo  [27] HANGUL SYLLABLE DAEG..HANGUL SYLLABLE DAEH
                (0xB31D <= code && code <= 0xB337) || // Lo  [27] HANGUL SYLLABLE DYAG..HANGUL SYLLABLE DYAH
                (0xB339 <= code && code <= 0xB353) || // Lo  [27] HANGUL SYLLABLE DYAEG..HANGUL SYLLABLE DYAEH
                (0xB355 <= code && code <= 0xB36F) || // Lo  [27] HANGUL SYLLABLE DEOG..HANGUL SYLLABLE DEOH
                (0xB371 <= code && code <= 0xB38B) || // Lo  [27] HANGUL SYLLABLE DEG..HANGUL SYLLABLE DEH
                (0xB38D <= code && code <= 0xB3A7) || // Lo  [27] HANGUL SYLLABLE DYEOG..HANGUL SYLLABLE DYEOH
                (0xB3A9 <= code && code <= 0xB3C3) || // Lo  [27] HANGUL SYLLABLE DYEG..HANGUL SYLLABLE DYEH
                (0xB3C5 <= code && code <= 0xB3DF) || // Lo  [27] HANGUL SYLLABLE DOG..HANGUL SYLLABLE DOH
                (0xB3E1 <= code && code <= 0xB3FB) || // Lo  [27] HANGUL SYLLABLE DWAG..HANGUL SYLLABLE DWAH
                (0xB3FD <= code && code <= 0xB417) || // Lo  [27] HANGUL SYLLABLE DWAEG..HANGUL SYLLABLE DWAEH
                (0xB419 <= code && code <= 0xB433) || // Lo  [27] HANGUL SYLLABLE DOEG..HANGUL SYLLABLE DOEH
                (0xB435 <= code && code <= 0xB44F) || // Lo  [27] HANGUL SYLLABLE DYOG..HANGUL SYLLABLE DYOH
                (0xB451 <= code && code <= 0xB46B) || // Lo  [27] HANGUL SYLLABLE DUG..HANGUL SYLLABLE DUH
                (0xB46D <= code && code <= 0xB487) || // Lo  [27] HANGUL SYLLABLE DWEOG..HANGUL SYLLABLE DWEOH
                (0xB489 <= code && code <= 0xB4A3) || // Lo  [27] HANGUL SYLLABLE DWEG..HANGUL SYLLABLE DWEH
                (0xB4A5 <= code && code <= 0xB4BF) || // Lo  [27] HANGUL SYLLABLE DWIG..HANGUL SYLLABLE DWIH
                (0xB4C1 <= code && code <= 0xB4DB) || // Lo  [27] HANGUL SYLLABLE DYUG..HANGUL SYLLABLE DYUH
                (0xB4DD <= code && code <= 0xB4F7) || // Lo  [27] HANGUL SYLLABLE DEUG..HANGUL SYLLABLE DEUH
                (0xB4F9 <= code && code <= 0xB513) || // Lo  [27] HANGUL SYLLABLE DYIG..HANGUL SYLLABLE DYIH
                (0xB515 <= code && code <= 0xB52F) || // Lo  [27] HANGUL SYLLABLE DIG..HANGUL SYLLABLE DIH
                (0xB531 <= code && code <= 0xB54B) || // Lo  [27] HANGUL SYLLABLE DDAG..HANGUL SYLLABLE DDAH
                (0xB54D <= code && code <= 0xB567) || // Lo  [27] HANGUL SYLLABLE DDAEG..HANGUL SYLLABLE DDAEH
                (0xB569 <= code && code <= 0xB583) || // Lo  [27] HANGUL SYLLABLE DDYAG..HANGUL SYLLABLE DDYAH
                (0xB585 <= code && code <= 0xB59F) || // Lo  [27] HANGUL SYLLABLE DDYAEG..HANGUL SYLLABLE DDYAEH
                (0xB5A1 <= code && code <= 0xB5BB) || // Lo  [27] HANGUL SYLLABLE DDEOG..HANGUL SYLLABLE DDEOH
                (0xB5BD <= code && code <= 0xB5D7) || // Lo  [27] HANGUL SYLLABLE DDEG..HANGUL SYLLABLE DDEH
                (0xB5D9 <= code && code <= 0xB5F3) || // Lo  [27] HANGUL SYLLABLE DDYEOG..HANGUL SYLLABLE DDYEOH
                (0xB5F5 <= code && code <= 0xB60F) || // Lo  [27] HANGUL SYLLABLE DDYEG..HANGUL SYLLABLE DDYEH
                (0xB611 <= code && code <= 0xB62B) || // Lo  [27] HANGUL SYLLABLE DDOG..HANGUL SYLLABLE DDOH
                (0xB62D <= code && code <= 0xB647) || // Lo  [27] HANGUL SYLLABLE DDWAG..HANGUL SYLLABLE DDWAH
                (0xB649 <= code && code <= 0xB663) || // Lo  [27] HANGUL SYLLABLE DDWAEG..HANGUL SYLLABLE DDWAEH
                (0xB665 <= code && code <= 0xB67F) || // Lo  [27] HANGUL SYLLABLE DDOEG..HANGUL SYLLABLE DDOEH
                (0xB681 <= code && code <= 0xB69B) || // Lo  [27] HANGUL SYLLABLE DDYOG..HANGUL SYLLABLE DDYOH
                (0xB69D <= code && code <= 0xB6B7) || // Lo  [27] HANGUL SYLLABLE DDUG..HANGUL SYLLABLE DDUH
                (0xB6B9 <= code && code <= 0xB6D3) || // Lo  [27] HANGUL SYLLABLE DDWEOG..HANGUL SYLLABLE DDWEOH
                (0xB6D5 <= code && code <= 0xB6EF) || // Lo  [27] HANGUL SYLLABLE DDWEG..HANGUL SYLLABLE DDWEH
                (0xB6F1 <= code && code <= 0xB70B) || // Lo  [27] HANGUL SYLLABLE DDWIG..HANGUL SYLLABLE DDWIH
                (0xB70D <= code && code <= 0xB727) || // Lo  [27] HANGUL SYLLABLE DDYUG..HANGUL SYLLABLE DDYUH
                (0xB729 <= code && code <= 0xB743) || // Lo  [27] HANGUL SYLLABLE DDEUG..HANGUL SYLLABLE DDEUH
                (0xB745 <= code && code <= 0xB75F) || // Lo  [27] HANGUL SYLLABLE DDYIG..HANGUL SYLLABLE DDYIH
                (0xB761 <= code && code <= 0xB77B) || // Lo  [27] HANGUL SYLLABLE DDIG..HANGUL SYLLABLE DDIH
                (0xB77D <= code && code <= 0xB797) || // Lo  [27] HANGUL SYLLABLE RAG..HANGUL SYLLABLE RAH
                (0xB799 <= code && code <= 0xB7B3) || // Lo  [27] HANGUL SYLLABLE RAEG..HANGUL SYLLABLE RAEH
                (0xB7B5 <= code && code <= 0xB7CF) || // Lo  [27] HANGUL SYLLABLE RYAG..HANGUL SYLLABLE RYAH
                (0xB7D1 <= code && code <= 0xB7EB) || // Lo  [27] HANGUL SYLLABLE RYAEG..HANGUL SYLLABLE RYAEH
                (0xB7ED <= code && code <= 0xB807) || // Lo  [27] HANGUL SYLLABLE REOG..HANGUL SYLLABLE REOH
                (0xB809 <= code && code <= 0xB823) || // Lo  [27] HANGUL SYLLABLE REG..HANGUL SYLLABLE REH
                (0xB825 <= code && code <= 0xB83F) || // Lo  [27] HANGUL SYLLABLE RYEOG..HANGUL SYLLABLE RYEOH
                (0xB841 <= code && code <= 0xB85B) || // Lo  [27] HANGUL SYLLABLE RYEG..HANGUL SYLLABLE RYEH
                (0xB85D <= code && code <= 0xB877) || // Lo  [27] HANGUL SYLLABLE ROG..HANGUL SYLLABLE ROH
                (0xB879 <= code && code <= 0xB893) || // Lo  [27] HANGUL SYLLABLE RWAG..HANGUL SYLLABLE RWAH
                (0xB895 <= code && code <= 0xB8AF) || // Lo  [27] HANGUL SYLLABLE RWAEG..HANGUL SYLLABLE RWAEH
                (0xB8B1 <= code && code <= 0xB8CB) || // Lo  [27] HANGUL SYLLABLE ROEG..HANGUL SYLLABLE ROEH
                (0xB8CD <= code && code <= 0xB8E7) || // Lo  [27] HANGUL SYLLABLE RYOG..HANGUL SYLLABLE RYOH
                (0xB8E9 <= code && code <= 0xB903) || // Lo  [27] HANGUL SYLLABLE RUG..HANGUL SYLLABLE RUH
                (0xB905 <= code && code <= 0xB91F) || // Lo  [27] HANGUL SYLLABLE RWEOG..HANGUL SYLLABLE RWEOH
                (0xB921 <= code && code <= 0xB93B) || // Lo  [27] HANGUL SYLLABLE RWEG..HANGUL SYLLABLE RWEH
                (0xB93D <= code && code <= 0xB957) || // Lo  [27] HANGUL SYLLABLE RWIG..HANGUL SYLLABLE RWIH
                (0xB959 <= code && code <= 0xB973) || // Lo  [27] HANGUL SYLLABLE RYUG..HANGUL SYLLABLE RYUH
                (0xB975 <= code && code <= 0xB98F) || // Lo  [27] HANGUL SYLLABLE REUG..HANGUL SYLLABLE REUH
                (0xB991 <= code && code <= 0xB9AB) || // Lo  [27] HANGUL SYLLABLE RYIG..HANGUL SYLLABLE RYIH
                (0xB9AD <= code && code <= 0xB9C7) || // Lo  [27] HANGUL SYLLABLE RIG..HANGUL SYLLABLE RIH
                (0xB9C9 <= code && code <= 0xB9E3) || // Lo  [27] HANGUL SYLLABLE MAG..HANGUL SYLLABLE MAH
                (0xB9E5 <= code && code <= 0xB9FF) || // Lo  [27] HANGUL SYLLABLE MAEG..HANGUL SYLLABLE MAEH
                (0xBA01 <= code && code <= 0xBA1B) || // Lo  [27] HANGUL SYLLABLE MYAG..HANGUL SYLLABLE MYAH
                (0xBA1D <= code && code <= 0xBA37) || // Lo  [27] HANGUL SYLLABLE MYAEG..HANGUL SYLLABLE MYAEH
                (0xBA39 <= code && code <= 0xBA53) || // Lo  [27] HANGUL SYLLABLE MEOG..HANGUL SYLLABLE MEOH
                (0xBA55 <= code && code <= 0xBA6F) || // Lo  [27] HANGUL SYLLABLE MEG..HANGUL SYLLABLE MEH
                (0xBA71 <= code && code <= 0xBA8B) || // Lo  [27] HANGUL SYLLABLE MYEOG..HANGUL SYLLABLE MYEOH
                (0xBA8D <= code && code <= 0xBAA7) || // Lo  [27] HANGUL SYLLABLE MYEG..HANGUL SYLLABLE MYEH
                (0xBAA9 <= code && code <= 0xBAC3) || // Lo  [27] HANGUL SYLLABLE MOG..HANGUL SYLLABLE MOH
                (0xBAC5 <= code && code <= 0xBADF) || // Lo  [27] HANGUL SYLLABLE MWAG..HANGUL SYLLABLE MWAH
                (0xBAE1 <= code && code <= 0xBAFB) || // Lo  [27] HANGUL SYLLABLE MWAEG..HANGUL SYLLABLE MWAEH
                (0xBAFD <= code && code <= 0xBB17) || // Lo  [27] HANGUL SYLLABLE MOEG..HANGUL SYLLABLE MOEH
                (0xBB19 <= code && code <= 0xBB33) || // Lo  [27] HANGUL SYLLABLE MYOG..HANGUL SYLLABLE MYOH
                (0xBB35 <= code && code <= 0xBB4F) || // Lo  [27] HANGUL SYLLABLE MUG..HANGUL SYLLABLE MUH
                (0xBB51 <= code && code <= 0xBB6B) || // Lo  [27] HANGUL SYLLABLE MWEOG..HANGUL SYLLABLE MWEOH
                (0xBB6D <= code && code <= 0xBB87) || // Lo  [27] HANGUL SYLLABLE MWEG..HANGUL SYLLABLE MWEH
                (0xBB89 <= code && code <= 0xBBA3) || // Lo  [27] HANGUL SYLLABLE MWIG..HANGUL SYLLABLE MWIH
                (0xBBA5 <= code && code <= 0xBBBF) || // Lo  [27] HANGUL SYLLABLE MYUG..HANGUL SYLLABLE MYUH
                (0xBBC1 <= code && code <= 0xBBDB) || // Lo  [27] HANGUL SYLLABLE MEUG..HANGUL SYLLABLE MEUH
                (0xBBDD <= code && code <= 0xBBF7) || // Lo  [27] HANGUL SYLLABLE MYIG..HANGUL SYLLABLE MYIH
                (0xBBF9 <= code && code <= 0xBC13) || // Lo  [27] HANGUL SYLLABLE MIG..HANGUL SYLLABLE MIH
                (0xBC15 <= code && code <= 0xBC2F) || // Lo  [27] HANGUL SYLLABLE BAG..HANGUL SYLLABLE BAH
                (0xBC31 <= code && code <= 0xBC4B) || // Lo  [27] HANGUL SYLLABLE BAEG..HANGUL SYLLABLE BAEH
                (0xBC4D <= code && code <= 0xBC67) || // Lo  [27] HANGUL SYLLABLE BYAG..HANGUL SYLLABLE BYAH
                (0xBC69 <= code && code <= 0xBC83) || // Lo  [27] HANGUL SYLLABLE BYAEG..HANGUL SYLLABLE BYAEH
                (0xBC85 <= code && code <= 0xBC9F) || // Lo  [27] HANGUL SYLLABLE BEOG..HANGUL SYLLABLE BEOH
                (0xBCA1 <= code && code <= 0xBCBB) || // Lo  [27] HANGUL SYLLABLE BEG..HANGUL SYLLABLE BEH
                (0xBCBD <= code && code <= 0xBCD7) || // Lo  [27] HANGUL SYLLABLE BYEOG..HANGUL SYLLABLE BYEOH
                (0xBCD9 <= code && code <= 0xBCF3) || // Lo  [27] HANGUL SYLLABLE BYEG..HANGUL SYLLABLE BYEH
                (0xBCF5 <= code && code <= 0xBD0F) || // Lo  [27] HANGUL SYLLABLE BOG..HANGUL SYLLABLE BOH
                (0xBD11 <= code && code <= 0xBD2B) || // Lo  [27] HANGUL SYLLABLE BWAG..HANGUL SYLLABLE BWAH
                (0xBD2D <= code && code <= 0xBD47) || // Lo  [27] HANGUL SYLLABLE BWAEG..HANGUL SYLLABLE BWAEH
                (0xBD49 <= code && code <= 0xBD63) || // Lo  [27] HANGUL SYLLABLE BOEG..HANGUL SYLLABLE BOEH
                (0xBD65 <= code && code <= 0xBD7F) || // Lo  [27] HANGUL SYLLABLE BYOG..HANGUL SYLLABLE BYOH
                (0xBD81 <= code && code <= 0xBD9B) || // Lo  [27] HANGUL SYLLABLE BUG..HANGUL SYLLABLE BUH
                (0xBD9D <= code && code <= 0xBDB7) || // Lo  [27] HANGUL SYLLABLE BWEOG..HANGUL SYLLABLE BWEOH
                (0xBDB9 <= code && code <= 0xBDD3) || // Lo  [27] HANGUL SYLLABLE BWEG..HANGUL SYLLABLE BWEH
                (0xBDD5 <= code && code <= 0xBDEF) || // Lo  [27] HANGUL SYLLABLE BWIG..HANGUL SYLLABLE BWIH
                (0xBDF1 <= code && code <= 0xBE0B) || // Lo  [27] HANGUL SYLLABLE BYUG..HANGUL SYLLABLE BYUH
                (0xBE0D <= code && code <= 0xBE27) || // Lo  [27] HANGUL SYLLABLE BEUG..HANGUL SYLLABLE BEUH
                (0xBE29 <= code && code <= 0xBE43) || // Lo  [27] HANGUL SYLLABLE BYIG..HANGUL SYLLABLE BYIH
                (0xBE45 <= code && code <= 0xBE5F) || // Lo  [27] HANGUL SYLLABLE BIG..HANGUL SYLLABLE BIH
                (0xBE61 <= code && code <= 0xBE7B) || // Lo  [27] HANGUL SYLLABLE BBAG..HANGUL SYLLABLE BBAH
                (0xBE7D <= code && code <= 0xBE97) || // Lo  [27] HANGUL SYLLABLE BBAEG..HANGUL SYLLABLE BBAEH
                (0xBE99 <= code && code <= 0xBEB3) || // Lo  [27] HANGUL SYLLABLE BBYAG..HANGUL SYLLABLE BBYAH
                (0xBEB5 <= code && code <= 0xBECF) || // Lo  [27] HANGUL SYLLABLE BBYAEG..HANGUL SYLLABLE BBYAEH
                (0xBED1 <= code && code <= 0xBEEB) || // Lo  [27] HANGUL SYLLABLE BBEOG..HANGUL SYLLABLE BBEOH
                (0xBEED <= code && code <= 0xBF07) || // Lo  [27] HANGUL SYLLABLE BBEG..HANGUL SYLLABLE BBEH
                (0xBF09 <= code && code <= 0xBF23) || // Lo  [27] HANGUL SYLLABLE BBYEOG..HANGUL SYLLABLE BBYEOH
                (0xBF25 <= code && code <= 0xBF3F) || // Lo  [27] HANGUL SYLLABLE BBYEG..HANGUL SYLLABLE BBYEH
                (0xBF41 <= code && code <= 0xBF5B) || // Lo  [27] HANGUL SYLLABLE BBOG..HANGUL SYLLABLE BBOH
                (0xBF5D <= code && code <= 0xBF77) || // Lo  [27] HANGUL SYLLABLE BBWAG..HANGUL SYLLABLE BBWAH
                (0xBF79 <= code && code <= 0xBF93) || // Lo  [27] HANGUL SYLLABLE BBWAEG..HANGUL SYLLABLE BBWAEH
                (0xBF95 <= code && code <= 0xBFAF) || // Lo  [27] HANGUL SYLLABLE BBOEG..HANGUL SYLLABLE BBOEH
                (0xBFB1 <= code && code <= 0xBFCB) || // Lo  [27] HANGUL SYLLABLE BBYOG..HANGUL SYLLABLE BBYOH
                (0xBFCD <= code && code <= 0xBFE7) || // Lo  [27] HANGUL SYLLABLE BBUG..HANGUL SYLLABLE BBUH
                (0xBFE9 <= code && code <= 0xC003) || // Lo  [27] HANGUL SYLLABLE BBWEOG..HANGUL SYLLABLE BBWEOH
                (0xC005 <= code && code <= 0xC01F) || // Lo  [27] HANGUL SYLLABLE BBWEG..HANGUL SYLLABLE BBWEH
                (0xC021 <= code && code <= 0xC03B) || // Lo  [27] HANGUL SYLLABLE BBWIG..HANGUL SYLLABLE BBWIH
                (0xC03D <= code && code <= 0xC057) || // Lo  [27] HANGUL SYLLABLE BBYUG..HANGUL SYLLABLE BBYUH
                (0xC059 <= code && code <= 0xC073) || // Lo  [27] HANGUL SYLLABLE BBEUG..HANGUL SYLLABLE BBEUH
                (0xC075 <= code && code <= 0xC08F) || // Lo  [27] HANGUL SYLLABLE BBYIG..HANGUL SYLLABLE BBYIH
                (0xC091 <= code && code <= 0xC0AB) || // Lo  [27] HANGUL SYLLABLE BBIG..HANGUL SYLLABLE BBIH
                (0xC0AD <= code && code <= 0xC0C7) || // Lo  [27] HANGUL SYLLABLE SAG..HANGUL SYLLABLE SAH
                (0xC0C9 <= code && code <= 0xC0E3) || // Lo  [27] HANGUL SYLLABLE SAEG..HANGUL SYLLABLE SAEH
                (0xC0E5 <= code && code <= 0xC0FF) || // Lo  [27] HANGUL SYLLABLE SYAG..HANGUL SYLLABLE SYAH
                (0xC101 <= code && code <= 0xC11B) || // Lo  [27] HANGUL SYLLABLE SYAEG..HANGUL SYLLABLE SYAEH
                (0xC11D <= code && code <= 0xC137) || // Lo  [27] HANGUL SYLLABLE SEOG..HANGUL SYLLABLE SEOH
                (0xC139 <= code && code <= 0xC153) || // Lo  [27] HANGUL SYLLABLE SEG..HANGUL SYLLABLE SEH
                (0xC155 <= code && code <= 0xC16F) || // Lo  [27] HANGUL SYLLABLE SYEOG..HANGUL SYLLABLE SYEOH
                (0xC171 <= code && code <= 0xC18B) || // Lo  [27] HANGUL SYLLABLE SYEG..HANGUL SYLLABLE SYEH
                (0xC18D <= code && code <= 0xC1A7) || // Lo  [27] HANGUL SYLLABLE SOG..HANGUL SYLLABLE SOH
                (0xC1A9 <= code && code <= 0xC1C3) || // Lo  [27] HANGUL SYLLABLE SWAG..HANGUL SYLLABLE SWAH
                (0xC1C5 <= code && code <= 0xC1DF) || // Lo  [27] HANGUL SYLLABLE SWAEG..HANGUL SYLLABLE SWAEH
                (0xC1E1 <= code && code <= 0xC1FB) || // Lo  [27] HANGUL SYLLABLE SOEG..HANGUL SYLLABLE SOEH
                (0xC1FD <= code && code <= 0xC217) || // Lo  [27] HANGUL SYLLABLE SYOG..HANGUL SYLLABLE SYOH
                (0xC219 <= code && code <= 0xC233) || // Lo  [27] HANGUL SYLLABLE SUG..HANGUL SYLLABLE SUH
                (0xC235 <= code && code <= 0xC24F) || // Lo  [27] HANGUL SYLLABLE SWEOG..HANGUL SYLLABLE SWEOH
                (0xC251 <= code && code <= 0xC26B) || // Lo  [27] HANGUL SYLLABLE SWEG..HANGUL SYLLABLE SWEH
                (0xC26D <= code && code <= 0xC287) || // Lo  [27] HANGUL SYLLABLE SWIG..HANGUL SYLLABLE SWIH
                (0xC289 <= code && code <= 0xC2A3) || // Lo  [27] HANGUL SYLLABLE SYUG..HANGUL SYLLABLE SYUH
                (0xC2A5 <= code && code <= 0xC2BF) || // Lo  [27] HANGUL SYLLABLE SEUG..HANGUL SYLLABLE SEUH
                (0xC2C1 <= code && code <= 0xC2DB) || // Lo  [27] HANGUL SYLLABLE SYIG..HANGUL SYLLABLE SYIH
                (0xC2DD <= code && code <= 0xC2F7) || // Lo  [27] HANGUL SYLLABLE SIG..HANGUL SYLLABLE SIH
                (0xC2F9 <= code && code <= 0xC313) || // Lo  [27] HANGUL SYLLABLE SSAG..HANGUL SYLLABLE SSAH
                (0xC315 <= code && code <= 0xC32F) || // Lo  [27] HANGUL SYLLABLE SSAEG..HANGUL SYLLABLE SSAEH
                (0xC331 <= code && code <= 0xC34B) || // Lo  [27] HANGUL SYLLABLE SSYAG..HANGUL SYLLABLE SSYAH
                (0xC34D <= code && code <= 0xC367) || // Lo  [27] HANGUL SYLLABLE SSYAEG..HANGUL SYLLABLE SSYAEH
                (0xC369 <= code && code <= 0xC383) || // Lo  [27] HANGUL SYLLABLE SSEOG..HANGUL SYLLABLE SSEOH
                (0xC385 <= code && code <= 0xC39F) || // Lo  [27] HANGUL SYLLABLE SSEG..HANGUL SYLLABLE SSEH
                (0xC3A1 <= code && code <= 0xC3BB) || // Lo  [27] HANGUL SYLLABLE SSYEOG..HANGUL SYLLABLE SSYEOH
                (0xC3BD <= code && code <= 0xC3D7) || // Lo  [27] HANGUL SYLLABLE SSYEG..HANGUL SYLLABLE SSYEH
                (0xC3D9 <= code && code <= 0xC3F3) || // Lo  [27] HANGUL SYLLABLE SSOG..HANGUL SYLLABLE SSOH
                (0xC3F5 <= code && code <= 0xC40F) || // Lo  [27] HANGUL SYLLABLE SSWAG..HANGUL SYLLABLE SSWAH
                (0xC411 <= code && code <= 0xC42B) || // Lo  [27] HANGUL SYLLABLE SSWAEG..HANGUL SYLLABLE SSWAEH
                (0xC42D <= code && code <= 0xC447) || // Lo  [27] HANGUL SYLLABLE SSOEG..HANGUL SYLLABLE SSOEH
                (0xC449 <= code && code <= 0xC463) || // Lo  [27] HANGUL SYLLABLE SSYOG..HANGUL SYLLABLE SSYOH
                (0xC465 <= code && code <= 0xC47F) || // Lo  [27] HANGUL SYLLABLE SSUG..HANGUL SYLLABLE SSUH
                (0xC481 <= code && code <= 0xC49B) || // Lo  [27] HANGUL SYLLABLE SSWEOG..HANGUL SYLLABLE SSWEOH
                (0xC49D <= code && code <= 0xC4B7) || // Lo  [27] HANGUL SYLLABLE SSWEG..HANGUL SYLLABLE SSWEH
                (0xC4B9 <= code && code <= 0xC4D3) || // Lo  [27] HANGUL SYLLABLE SSWIG..HANGUL SYLLABLE SSWIH
                (0xC4D5 <= code && code <= 0xC4EF) || // Lo  [27] HANGUL SYLLABLE SSYUG..HANGUL SYLLABLE SSYUH
                (0xC4F1 <= code && code <= 0xC50B) || // Lo  [27] HANGUL SYLLABLE SSEUG..HANGUL SYLLABLE SSEUH
                (0xC50D <= code && code <= 0xC527) || // Lo  [27] HANGUL SYLLABLE SSYIG..HANGUL SYLLABLE SSYIH
                (0xC529 <= code && code <= 0xC543) || // Lo  [27] HANGUL SYLLABLE SSIG..HANGUL SYLLABLE SSIH
                (0xC545 <= code && code <= 0xC55F) || // Lo  [27] HANGUL SYLLABLE AG..HANGUL SYLLABLE AH
                (0xC561 <= code && code <= 0xC57B) || // Lo  [27] HANGUL SYLLABLE AEG..HANGUL SYLLABLE AEH
                (0xC57D <= code && code <= 0xC597) || // Lo  [27] HANGUL SYLLABLE YAG..HANGUL SYLLABLE YAH
                (0xC599 <= code && code <= 0xC5B3) || // Lo  [27] HANGUL SYLLABLE YAEG..HANGUL SYLLABLE YAEH
                (0xC5B5 <= code && code <= 0xC5CF) || // Lo  [27] HANGUL SYLLABLE EOG..HANGUL SYLLABLE EOH
                (0xC5D1 <= code && code <= 0xC5EB) || // Lo  [27] HANGUL SYLLABLE EG..HANGUL SYLLABLE EH
                (0xC5ED <= code && code <= 0xC607) || // Lo  [27] HANGUL SYLLABLE YEOG..HANGUL SYLLABLE YEOH
                (0xC609 <= code && code <= 0xC623) || // Lo  [27] HANGUL SYLLABLE YEG..HANGUL SYLLABLE YEH
                (0xC625 <= code && code <= 0xC63F) || // Lo  [27] HANGUL SYLLABLE OG..HANGUL SYLLABLE OH
                (0xC641 <= code && code <= 0xC65B) || // Lo  [27] HANGUL SYLLABLE WAG..HANGUL SYLLABLE WAH
                (0xC65D <= code && code <= 0xC677) || // Lo  [27] HANGUL SYLLABLE WAEG..HANGUL SYLLABLE WAEH
                (0xC679 <= code && code <= 0xC693) || // Lo  [27] HANGUL SYLLABLE OEG..HANGUL SYLLABLE OEH
                (0xC695 <= code && code <= 0xC6AF) || // Lo  [27] HANGUL SYLLABLE YOG..HANGUL SYLLABLE YOH
                (0xC6B1 <= code && code <= 0xC6CB) || // Lo  [27] HANGUL SYLLABLE UG..HANGUL SYLLABLE UH
                (0xC6CD <= code && code <= 0xC6E7) || // Lo  [27] HANGUL SYLLABLE WEOG..HANGUL SYLLABLE WEOH
                (0xC6E9 <= code && code <= 0xC703) || // Lo  [27] HANGUL SYLLABLE WEG..HANGUL SYLLABLE WEH
                (0xC705 <= code && code <= 0xC71F) || // Lo  [27] HANGUL SYLLABLE WIG..HANGUL SYLLABLE WIH
                (0xC721 <= code && code <= 0xC73B) || // Lo  [27] HANGUL SYLLABLE YUG..HANGUL SYLLABLE YUH
                (0xC73D <= code && code <= 0xC757) || // Lo  [27] HANGUL SYLLABLE EUG..HANGUL SYLLABLE EUH
                (0xC759 <= code && code <= 0xC773) || // Lo  [27] HANGUL SYLLABLE YIG..HANGUL SYLLABLE YIH
                (0xC775 <= code && code <= 0xC78F) || // Lo  [27] HANGUL SYLLABLE IG..HANGUL SYLLABLE IH
                (0xC791 <= code && code <= 0xC7AB) || // Lo  [27] HANGUL SYLLABLE JAG..HANGUL SYLLABLE JAH
                (0xC7AD <= code && code <= 0xC7C7) || // Lo  [27] HANGUL SYLLABLE JAEG..HANGUL SYLLABLE JAEH
                (0xC7C9 <= code && code <= 0xC7E3) || // Lo  [27] HANGUL SYLLABLE JYAG..HANGUL SYLLABLE JYAH
                (0xC7E5 <= code && code <= 0xC7FF) || // Lo  [27] HANGUL SYLLABLE JYAEG..HANGUL SYLLABLE JYAEH
                (0xC801 <= code && code <= 0xC81B) || // Lo  [27] HANGUL SYLLABLE JEOG..HANGUL SYLLABLE JEOH
                (0xC81D <= code && code <= 0xC837) || // Lo  [27] HANGUL SYLLABLE JEG..HANGUL SYLLABLE JEH
                (0xC839 <= code && code <= 0xC853) || // Lo  [27] HANGUL SYLLABLE JYEOG..HANGUL SYLLABLE JYEOH
                (0xC855 <= code && code <= 0xC86F) || // Lo  [27] HANGUL SYLLABLE JYEG..HANGUL SYLLABLE JYEH
                (0xC871 <= code && code <= 0xC88B) || // Lo  [27] HANGUL SYLLABLE JOG..HANGUL SYLLABLE JOH
                (0xC88D <= code && code <= 0xC8A7) || // Lo  [27] HANGUL SYLLABLE JWAG..HANGUL SYLLABLE JWAH
                (0xC8A9 <= code && code <= 0xC8C3) || // Lo  [27] HANGUL SYLLABLE JWAEG..HANGUL SYLLABLE JWAEH
                (0xC8C5 <= code && code <= 0xC8DF) || // Lo  [27] HANGUL SYLLABLE JOEG..HANGUL SYLLABLE JOEH
                (0xC8E1 <= code && code <= 0xC8FB) || // Lo  [27] HANGUL SYLLABLE JYOG..HANGUL SYLLABLE JYOH
                (0xC8FD <= code && code <= 0xC917) || // Lo  [27] HANGUL SYLLABLE JUG..HANGUL SYLLABLE JUH
                (0xC919 <= code && code <= 0xC933) || // Lo  [27] HANGUL SYLLABLE JWEOG..HANGUL SYLLABLE JWEOH
                (0xC935 <= code && code <= 0xC94F) || // Lo  [27] HANGUL SYLLABLE JWEG..HANGUL SYLLABLE JWEH
                (0xC951 <= code && code <= 0xC96B) || // Lo  [27] HANGUL SYLLABLE JWIG..HANGUL SYLLABLE JWIH
                (0xC96D <= code && code <= 0xC987) || // Lo  [27] HANGUL SYLLABLE JYUG..HANGUL SYLLABLE JYUH
                (0xC989 <= code && code <= 0xC9A3) || // Lo  [27] HANGUL SYLLABLE JEUG..HANGUL SYLLABLE JEUH
                (0xC9A5 <= code && code <= 0xC9BF) || // Lo  [27] HANGUL SYLLABLE JYIG..HANGUL SYLLABLE JYIH
                (0xC9C1 <= code && code <= 0xC9DB) || // Lo  [27] HANGUL SYLLABLE JIG..HANGUL SYLLABLE JIH
                (0xC9DD <= code && code <= 0xC9F7) || // Lo  [27] HANGUL SYLLABLE JJAG..HANGUL SYLLABLE JJAH
                (0xC9F9 <= code && code <= 0xCA13) || // Lo  [27] HANGUL SYLLABLE JJAEG..HANGUL SYLLABLE JJAEH
                (0xCA15 <= code && code <= 0xCA2F) || // Lo  [27] HANGUL SYLLABLE JJYAG..HANGUL SYLLABLE JJYAH
                (0xCA31 <= code && code <= 0xCA4B) || // Lo  [27] HANGUL SYLLABLE JJYAEG..HANGUL SYLLABLE JJYAEH
                (0xCA4D <= code && code <= 0xCA67) || // Lo  [27] HANGUL SYLLABLE JJEOG..HANGUL SYLLABLE JJEOH
                (0xCA69 <= code && code <= 0xCA83) || // Lo  [27] HANGUL SYLLABLE JJEG..HANGUL SYLLABLE JJEH
                (0xCA85 <= code && code <= 0xCA9F) || // Lo  [27] HANGUL SYLLABLE JJYEOG..HANGUL SYLLABLE JJYEOH
                (0xCAA1 <= code && code <= 0xCABB) || // Lo  [27] HANGUL SYLLABLE JJYEG..HANGUL SYLLABLE JJYEH
                (0xCABD <= code && code <= 0xCAD7) || // Lo  [27] HANGUL SYLLABLE JJOG..HANGUL SYLLABLE JJOH
                (0xCAD9 <= code && code <= 0xCAF3) || // Lo  [27] HANGUL SYLLABLE JJWAG..HANGUL SYLLABLE JJWAH
                (0xCAF5 <= code && code <= 0xCB0F) || // Lo  [27] HANGUL SYLLABLE JJWAEG..HANGUL SYLLABLE JJWAEH
                (0xCB11 <= code && code <= 0xCB2B) || // Lo  [27] HANGUL SYLLABLE JJOEG..HANGUL SYLLABLE JJOEH
                (0xCB2D <= code && code <= 0xCB47) || // Lo  [27] HANGUL SYLLABLE JJYOG..HANGUL SYLLABLE JJYOH
                (0xCB49 <= code && code <= 0xCB63) || // Lo  [27] HANGUL SYLLABLE JJUG..HANGUL SYLLABLE JJUH
                (0xCB65 <= code && code <= 0xCB7F) || // Lo  [27] HANGUL SYLLABLE JJWEOG..HANGUL SYLLABLE JJWEOH
                (0xCB81 <= code && code <= 0xCB9B) || // Lo  [27] HANGUL SYLLABLE JJWEG..HANGUL SYLLABLE JJWEH
                (0xCB9D <= code && code <= 0xCBB7) || // Lo  [27] HANGUL SYLLABLE JJWIG..HANGUL SYLLABLE JJWIH
                (0xCBB9 <= code && code <= 0xCBD3) || // Lo  [27] HANGUL SYLLABLE JJYUG..HANGUL SYLLABLE JJYUH
                (0xCBD5 <= code && code <= 0xCBEF) || // Lo  [27] HANGUL SYLLABLE JJEUG..HANGUL SYLLABLE JJEUH
                (0xCBF1 <= code && code <= 0xCC0B) || // Lo  [27] HANGUL SYLLABLE JJYIG..HANGUL SYLLABLE JJYIH
                (0xCC0D <= code && code <= 0xCC27) || // Lo  [27] HANGUL SYLLABLE JJIG..HANGUL SYLLABLE JJIH
                (0xCC29 <= code && code <= 0xCC43) || // Lo  [27] HANGUL SYLLABLE CAG..HANGUL SYLLABLE CAH
                (0xCC45 <= code && code <= 0xCC5F) || // Lo  [27] HANGUL SYLLABLE CAEG..HANGUL SYLLABLE CAEH
                (0xCC61 <= code && code <= 0xCC7B) || // Lo  [27] HANGUL SYLLABLE CYAG..HANGUL SYLLABLE CYAH
                (0xCC7D <= code && code <= 0xCC97) || // Lo  [27] HANGUL SYLLABLE CYAEG..HANGUL SYLLABLE CYAEH
                (0xCC99 <= code && code <= 0xCCB3) || // Lo  [27] HANGUL SYLLABLE CEOG..HANGUL SYLLABLE CEOH
                (0xCCB5 <= code && code <= 0xCCCF) || // Lo  [27] HANGUL SYLLABLE CEG..HANGUL SYLLABLE CEH
                (0xCCD1 <= code && code <= 0xCCEB) || // Lo  [27] HANGUL SYLLABLE CYEOG..HANGUL SYLLABLE CYEOH
                (0xCCED <= code && code <= 0xCD07) || // Lo  [27] HANGUL SYLLABLE CYEG..HANGUL SYLLABLE CYEH
                (0xCD09 <= code && code <= 0xCD23) || // Lo  [27] HANGUL SYLLABLE COG..HANGUL SYLLABLE COH
                (0xCD25 <= code && code <= 0xCD3F) || // Lo  [27] HANGUL SYLLABLE CWAG..HANGUL SYLLABLE CWAH
                (0xCD41 <= code && code <= 0xCD5B) || // Lo  [27] HANGUL SYLLABLE CWAEG..HANGUL SYLLABLE CWAEH
                (0xCD5D <= code && code <= 0xCD77) || // Lo  [27] HANGUL SYLLABLE COEG..HANGUL SYLLABLE COEH
                (0xCD79 <= code && code <= 0xCD93) || // Lo  [27] HANGUL SYLLABLE CYOG..HANGUL SYLLABLE CYOH
                (0xCD95 <= code && code <= 0xCDAF) || // Lo  [27] HANGUL SYLLABLE CUG..HANGUL SYLLABLE CUH
                (0xCDB1 <= code && code <= 0xCDCB) || // Lo  [27] HANGUL SYLLABLE CWEOG..HANGUL SYLLABLE CWEOH
                (0xCDCD <= code && code <= 0xCDE7) || // Lo  [27] HANGUL SYLLABLE CWEG..HANGUL SYLLABLE CWEH
                (0xCDE9 <= code && code <= 0xCE03) || // Lo  [27] HANGUL SYLLABLE CWIG..HANGUL SYLLABLE CWIH
                (0xCE05 <= code && code <= 0xCE1F) || // Lo  [27] HANGUL SYLLABLE CYUG..HANGUL SYLLABLE CYUH
                (0xCE21 <= code && code <= 0xCE3B) || // Lo  [27] HANGUL SYLLABLE CEUG..HANGUL SYLLABLE CEUH
                (0xCE3D <= code && code <= 0xCE57) || // Lo  [27] HANGUL SYLLABLE CYIG..HANGUL SYLLABLE CYIH
                (0xCE59 <= code && code <= 0xCE73) || // Lo  [27] HANGUL SYLLABLE CIG..HANGUL SYLLABLE CIH
                (0xCE75 <= code && code <= 0xCE8F) || // Lo  [27] HANGUL SYLLABLE KAG..HANGUL SYLLABLE KAH
                (0xCE91 <= code && code <= 0xCEAB) || // Lo  [27] HANGUL SYLLABLE KAEG..HANGUL SYLLABLE KAEH
                (0xCEAD <= code && code <= 0xCEC7) || // Lo  [27] HANGUL SYLLABLE KYAG..HANGUL SYLLABLE KYAH
                (0xCEC9 <= code && code <= 0xCEE3) || // Lo  [27] HANGUL SYLLABLE KYAEG..HANGUL SYLLABLE KYAEH
                (0xCEE5 <= code && code <= 0xCEFF) || // Lo  [27] HANGUL SYLLABLE KEOG..HANGUL SYLLABLE KEOH
                (0xCF01 <= code && code <= 0xCF1B) || // Lo  [27] HANGUL SYLLABLE KEG..HANGUL SYLLABLE KEH
                (0xCF1D <= code && code <= 0xCF37) || // Lo  [27] HANGUL SYLLABLE KYEOG..HANGUL SYLLABLE KYEOH
                (0xCF39 <= code && code <= 0xCF53) || // Lo  [27] HANGUL SYLLABLE KYEG..HANGUL SYLLABLE KYEH
                (0xCF55 <= code && code <= 0xCF6F) || // Lo  [27] HANGUL SYLLABLE KOG..HANGUL SYLLABLE KOH
                (0xCF71 <= code && code <= 0xCF8B) || // Lo  [27] HANGUL SYLLABLE KWAG..HANGUL SYLLABLE KWAH
                (0xCF8D <= code && code <= 0xCFA7) || // Lo  [27] HANGUL SYLLABLE KWAEG..HANGUL SYLLABLE KWAEH
                (0xCFA9 <= code && code <= 0xCFC3) || // Lo  [27] HANGUL SYLLABLE KOEG..HANGUL SYLLABLE KOEH
                (0xCFC5 <= code && code <= 0xCFDF) || // Lo  [27] HANGUL SYLLABLE KYOG..HANGUL SYLLABLE KYOH
                (0xCFE1 <= code && code <= 0xCFFB) || // Lo  [27] HANGUL SYLLABLE KUG..HANGUL SYLLABLE KUH
                (0xCFFD <= code && code <= 0xD017) || // Lo  [27] HANGUL SYLLABLE KWEOG..HANGUL SYLLABLE KWEOH
                (0xD019 <= code && code <= 0xD033) || // Lo  [27] HANGUL SYLLABLE KWEG..HANGUL SYLLABLE KWEH
                (0xD035 <= code && code <= 0xD04F) || // Lo  [27] HANGUL SYLLABLE KWIG..HANGUL SYLLABLE KWIH
                (0xD051 <= code && code <= 0xD06B) || // Lo  [27] HANGUL SYLLABLE KYUG..HANGUL SYLLABLE KYUH
                (0xD06D <= code && code <= 0xD087) || // Lo  [27] HANGUL SYLLABLE KEUG..HANGUL SYLLABLE KEUH
                (0xD089 <= code && code <= 0xD0A3) || // Lo  [27] HANGUL SYLLABLE KYIG..HANGUL SYLLABLE KYIH
                (0xD0A5 <= code && code <= 0xD0BF) || // Lo  [27] HANGUL SYLLABLE KIG..HANGUL SYLLABLE KIH
                (0xD0C1 <= code && code <= 0xD0DB) || // Lo  [27] HANGUL SYLLABLE TAG..HANGUL SYLLABLE TAH
                (0xD0DD <= code && code <= 0xD0F7) || // Lo  [27] HANGUL SYLLABLE TAEG..HANGUL SYLLABLE TAEH
                (0xD0F9 <= code && code <= 0xD113) || // Lo  [27] HANGUL SYLLABLE TYAG..HANGUL SYLLABLE TYAH
                (0xD115 <= code && code <= 0xD12F) || // Lo  [27] HANGUL SYLLABLE TYAEG..HANGUL SYLLABLE TYAEH
                (0xD131 <= code && code <= 0xD14B) || // Lo  [27] HANGUL SYLLABLE TEOG..HANGUL SYLLABLE TEOH
                (0xD14D <= code && code <= 0xD167) || // Lo  [27] HANGUL SYLLABLE TEG..HANGUL SYLLABLE TEH
                (0xD169 <= code && code <= 0xD183) || // Lo  [27] HANGUL SYLLABLE TYEOG..HANGUL SYLLABLE TYEOH
                (0xD185 <= code && code <= 0xD19F) || // Lo  [27] HANGUL SYLLABLE TYEG..HANGUL SYLLABLE TYEH
                (0xD1A1 <= code && code <= 0xD1BB) || // Lo  [27] HANGUL SYLLABLE TOG..HANGUL SYLLABLE TOH
                (0xD1BD <= code && code <= 0xD1D7) || // Lo  [27] HANGUL SYLLABLE TWAG..HANGUL SYLLABLE TWAH
                (0xD1D9 <= code && code <= 0xD1F3) || // Lo  [27] HANGUL SYLLABLE TWAEG..HANGUL SYLLABLE TWAEH
                (0xD1F5 <= code && code <= 0xD20F) || // Lo  [27] HANGUL SYLLABLE TOEG..HANGUL SYLLABLE TOEH
                (0xD211 <= code && code <= 0xD22B) || // Lo  [27] HANGUL SYLLABLE TYOG..HANGUL SYLLABLE TYOH
                (0xD22D <= code && code <= 0xD247) || // Lo  [27] HANGUL SYLLABLE TUG..HANGUL SYLLABLE TUH
                (0xD249 <= code && code <= 0xD263) || // Lo  [27] HANGUL SYLLABLE TWEOG..HANGUL SYLLABLE TWEOH
                (0xD265 <= code && code <= 0xD27F) || // Lo  [27] HANGUL SYLLABLE TWEG..HANGUL SYLLABLE TWEH
                (0xD281 <= code && code <= 0xD29B) || // Lo  [27] HANGUL SYLLABLE TWIG..HANGUL SYLLABLE TWIH
                (0xD29D <= code && code <= 0xD2B7) || // Lo  [27] HANGUL SYLLABLE TYUG..HANGUL SYLLABLE TYUH
                (0xD2B9 <= code && code <= 0xD2D3) || // Lo  [27] HANGUL SYLLABLE TEUG..HANGUL SYLLABLE TEUH
                (0xD2D5 <= code && code <= 0xD2EF) || // Lo  [27] HANGUL SYLLABLE TYIG..HANGUL SYLLABLE TYIH
                (0xD2F1 <= code && code <= 0xD30B) || // Lo  [27] HANGUL SYLLABLE TIG..HANGUL SYLLABLE TIH
                (0xD30D <= code && code <= 0xD327) || // Lo  [27] HANGUL SYLLABLE PAG..HANGUL SYLLABLE PAH
                (0xD329 <= code && code <= 0xD343) || // Lo  [27] HANGUL SYLLABLE PAEG..HANGUL SYLLABLE PAEH
                (0xD345 <= code && code <= 0xD35F) || // Lo  [27] HANGUL SYLLABLE PYAG..HANGUL SYLLABLE PYAH
                (0xD361 <= code && code <= 0xD37B) || // Lo  [27] HANGUL SYLLABLE PYAEG..HANGUL SYLLABLE PYAEH
                (0xD37D <= code && code <= 0xD397) || // Lo  [27] HANGUL SYLLABLE PEOG..HANGUL SYLLABLE PEOH
                (0xD399 <= code && code <= 0xD3B3) || // Lo  [27] HANGUL SYLLABLE PEG..HANGUL SYLLABLE PEH
                (0xD3B5 <= code && code <= 0xD3CF) || // Lo  [27] HANGUL SYLLABLE PYEOG..HANGUL SYLLABLE PYEOH
                (0xD3D1 <= code && code <= 0xD3EB) || // Lo  [27] HANGUL SYLLABLE PYEG..HANGUL SYLLABLE PYEH
                (0xD3ED <= code && code <= 0xD407) || // Lo  [27] HANGUL SYLLABLE POG..HANGUL SYLLABLE POH
                (0xD409 <= code && code <= 0xD423) || // Lo  [27] HANGUL SYLLABLE PWAG..HANGUL SYLLABLE PWAH
                (0xD425 <= code && code <= 0xD43F) || // Lo  [27] HANGUL SYLLABLE PWAEG..HANGUL SYLLABLE PWAEH
                (0xD441 <= code && code <= 0xD45B) || // Lo  [27] HANGUL SYLLABLE POEG..HANGUL SYLLABLE POEH
                (0xD45D <= code && code <= 0xD477) || // Lo  [27] HANGUL SYLLABLE PYOG..HANGUL SYLLABLE PYOH
                (0xD479 <= code && code <= 0xD493) || // Lo  [27] HANGUL SYLLABLE PUG..HANGUL SYLLABLE PUH
                (0xD495 <= code && code <= 0xD4AF) || // Lo  [27] HANGUL SYLLABLE PWEOG..HANGUL SYLLABLE PWEOH
                (0xD4B1 <= code && code <= 0xD4CB) || // Lo  [27] HANGUL SYLLABLE PWEG..HANGUL SYLLABLE PWEH
                (0xD4CD <= code && code <= 0xD4E7) || // Lo  [27] HANGUL SYLLABLE PWIG..HANGUL SYLLABLE PWIH
                (0xD4E9 <= code && code <= 0xD503) || // Lo  [27] HANGUL SYLLABLE PYUG..HANGUL SYLLABLE PYUH
                (0xD505 <= code && code <= 0xD51F) || // Lo  [27] HANGUL SYLLABLE PEUG..HANGUL SYLLABLE PEUH
                (0xD521 <= code && code <= 0xD53B) || // Lo  [27] HANGUL SYLLABLE PYIG..HANGUL SYLLABLE PYIH
                (0xD53D <= code && code <= 0xD557) || // Lo  [27] HANGUL SYLLABLE PIG..HANGUL SYLLABLE PIH
                (0xD559 <= code && code <= 0xD573) || // Lo  [27] HANGUL SYLLABLE HAG..HANGUL SYLLABLE HAH
                (0xD575 <= code && code <= 0xD58F) || // Lo  [27] HANGUL SYLLABLE HAEG..HANGUL SYLLABLE HAEH
                (0xD591 <= code && code <= 0xD5AB) || // Lo  [27] HANGUL SYLLABLE HYAG..HANGUL SYLLABLE HYAH
                (0xD5AD <= code && code <= 0xD5C7) || // Lo  [27] HANGUL SYLLABLE HYAEG..HANGUL SYLLABLE HYAEH
                (0xD5C9 <= code && code <= 0xD5E3) || // Lo  [27] HANGUL SYLLABLE HEOG..HANGUL SYLLABLE HEOH
                (0xD5E5 <= code && code <= 0xD5FF) || // Lo  [27] HANGUL SYLLABLE HEG..HANGUL SYLLABLE HEH
                (0xD601 <= code && code <= 0xD61B) || // Lo  [27] HANGUL SYLLABLE HYEOG..HANGUL SYLLABLE HYEOH
                (0xD61D <= code && code <= 0xD637) || // Lo  [27] HANGUL SYLLABLE HYEG..HANGUL SYLLABLE HYEH
                (0xD639 <= code && code <= 0xD653) || // Lo  [27] HANGUL SYLLABLE HOG..HANGUL SYLLABLE HOH
                (0xD655 <= code && code <= 0xD66F) || // Lo  [27] HANGUL SYLLABLE HWAG..HANGUL SYLLABLE HWAH
                (0xD671 <= code && code <= 0xD68B) || // Lo  [27] HANGUL SYLLABLE HWAEG..HANGUL SYLLABLE HWAEH
                (0xD68D <= code && code <= 0xD6A7) || // Lo  [27] HANGUL SYLLABLE HOEG..HANGUL SYLLABLE HOEH
                (0xD6A9 <= code && code <= 0xD6C3) || // Lo  [27] HANGUL SYLLABLE HYOG..HANGUL SYLLABLE HYOH
                (0xD6C5 <= code && code <= 0xD6DF) || // Lo  [27] HANGUL SYLLABLE HUG..HANGUL SYLLABLE HUH
                (0xD6E1 <= code && code <= 0xD6FB) || // Lo  [27] HANGUL SYLLABLE HWEOG..HANGUL SYLLABLE HWEOH
                (0xD6FD <= code && code <= 0xD717) || // Lo  [27] HANGUL SYLLABLE HWEG..HANGUL SYLLABLE HWEH
                (0xD719 <= code && code <= 0xD733) || // Lo  [27] HANGUL SYLLABLE HWIG..HANGUL SYLLABLE HWIH
                (0xD735 <= code && code <= 0xD74F) || // Lo  [27] HANGUL SYLLABLE HYUG..HANGUL SYLLABLE HYUH
                (0xD751 <= code && code <= 0xD76B) || // Lo  [27] HANGUL SYLLABLE HEUG..HANGUL SYLLABLE HEUH
                (0xD76D <= code && code <= 0xD787) || // Lo  [27] HANGUL SYLLABLE HYIG..HANGUL SYLLABLE HYIH
                (0xD789 <= code && code <= 0xD7A3) // Lo  [27] HANGUL SYLLABLE HIG..HANGUL SYLLABLE HIH
            ) {
                return LVT;
            }
            if (0x261D == code || // So       WHITE UP POINTING INDEX
                0x26F9 == code || // So       PERSON WITH BALL
                (0x270A <= code && code <= 0x270D) || // So   [4] RAISED FIST..WRITING HAND
                0x1F385 == code || // So       FATHER CHRISTMAS
                (0x1F3C2 <= code && code <= 0x1F3C4) || // So   [3] SNOWBOARDER..SURFER
                0x1F3C7 == code || // So       HORSE RACING
                (0x1F3CA <= code && code <= 0x1F3CC) || // So   [3] SWIMMER..GOLFER
                (0x1F442 <= code && code <= 0x1F443) || // So   [2] EAR..NOSE
                (0x1F446 <= code && code <= 0x1F450) || // So  [11] WHITE UP POINTING BACKHAND INDEX..OPEN HANDS SIGN
                0x1F46E == code || // So       POLICE OFFICER
                (0x1F470 <= code && code <= 0x1F478) || // So   [9] BRIDE WITH VEIL..PRINCESS
                0x1F47C == code || // So       BABY ANGEL
                (0x1F481 <= code && code <= 0x1F483) || // So   [3] INFORMATION DESK PERSON..DANCER
                (0x1F485 <= code && code <= 0x1F487) || // So   [3] NAIL POLISH..HAIRCUT
                0x1F4AA == code || // So       FLEXED BICEPS
                (0x1F574 <= code && code <= 0x1F575) || // So   [2] MAN IN BUSINESS SUIT LEVITATING..SLEUTH OR SPY
                0x1F57A == code || // So       MAN DANCING
                0x1F590 == code || // So       RAISED HAND WITH FINGERS SPLAYED
                (0x1F595 <= code && code <= 0x1F596) || // So   [2] REVERSED HAND WITH MIDDLE FINGER EXTENDED..RAISED HAND WITH PART BETWEEN MIDDLE AND RING FINGERS
                (0x1F645 <= code && code <= 0x1F647) || // So   [3] FACE WITH NO GOOD GESTURE..PERSON BOWING DEEPLY
                (0x1F64B <= code && code <= 0x1F64F) || // So   [5] HAPPY PERSON RAISING ONE HAND..PERSON WITH FOLDED HANDS
                0x1F6A3 == code || // So       ROWBOAT
                (0x1F6B4 <= code && code <= 0x1F6B6) || // So   [3] BICYCLIST..PEDESTRIAN
                0x1F6C0 == code || // So       BATH
                0x1F6CC == code || // So       SLEEPING ACCOMMODATION
                (0x1F918 <= code && code <= 0x1F91C) || // So   [5] SIGN OF THE HORNS..RIGHT-FACING FIST
                (0x1F91E <= code && code <= 0x1F91F) || // So   [2] HAND WITH INDEX AND MIDDLE FINGERS CROSSED..I LOVE YOU HAND SIGN
                0x1F926 == code || // So       FACE PALM
                (0x1F930 <= code && code <= 0x1F939) || // So  [10] PREGNANT WOMAN..JUGGLING
                (0x1F93D <= code && code <= 0x1F93E) || // So   [2] WATER POLO..HANDBALL
                (0x1F9D1 <= code && code <= 0x1F9DD) // So  [13] ADULT..ELF
            ) {
                return E_Base;
            }
            if ((0x1F3FB <= code && code <= 0x1F3FF) // Sk   [5] EMOJI MODIFIER FITZPATRICK TYPE-1-2..EMOJI MODIFIER FITZPATRICK TYPE-6
            ) {
                return E_Modifier;
            }
            if (0x200D == code // Cf       ZERO WIDTH JOINER
            ) {
                return ZWJ;
            }
            if (0x2640 == code || // So       FEMALE SIGN
                0x2642 == code || // So       MALE SIGN
                (0x2695 <= code && code <= 0x2696) || // So   [2] STAFF OF AESCULAPIUS..SCALES
                0x2708 == code || // So       AIRPLANE
                0x2764 == code || // So       HEAVY BLACK HEART
                0x1F308 == code || // So       RAINBOW
                0x1F33E == code || // So       EAR OF RICE
                0x1F373 == code || // So       COOKING
                0x1F393 == code || // So       GRADUATION CAP
                0x1F3A4 == code || // So       MICROPHONE
                0x1F3A8 == code || // So       ARTIST PALETTE
                0x1F3EB == code || // So       SCHOOL
                0x1F3ED == code || // So       FACTORY
                0x1F48B == code || // So       KISS MARK
                (0x1F4BB <= code && code <= 0x1F4BC) || // So   [2] PERSONAL COMPUTER..BRIEFCASE
                0x1F527 == code || // So       WRENCH
                0x1F52C == code || // So       MICROSCOPE
                0x1F5E8 == code || // So       LEFT SPEECH BUBBLE
                0x1F680 == code || // So       ROCKET
                0x1F692 == code // So       FIRE ENGINE
            ) {
                return Glue_After_Zwj;
            }
            if ((0x1F466 <= code && code <= 0x1F469) // So   [4] BOY..WOMAN
            ) {
                return E_Base_GAZ;
            }
            //all unlisted characters have a grapheme break property of "Other"
            return Other;
        }
        return this;
    }
    if (typeof module != 'undefined' && module.exports) {
        module.exports = GraphemeSplitter;
    }
},
/* eslint/lib/rules/id-match.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag non-matching identifiers
     * @author Matthieu Larcher
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require identifiers to match a specified regular expression",
                recommended: false,
                url: "https://eslint.org/docs/rules/id-match"
            },
            schema: [
                {
                    type: "string"
                },
                {
                    type: "object",
                    properties: {
                        properties: {
                            type: "boolean",
                            default: false
                        },
                        classFields: {
                            type: "boolean",
                            default: false
                        },
                        onlyDeclarations: {
                            type: "boolean",
                            default: false
                        },
                        ignoreDestructuring: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                notMatch: "Identifier '{{name}}' does not match the pattern '{{pattern}}'.",
                notMatchPrivate: "Identifier '#{{name}}' does not match the pattern '{{pattern}}'."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Options
            //--------------------------------------------------------------------------
            const pattern = context.options[0] || "^.+$", regexp = new RegExp(pattern, "u");
            const options = context.options[1] || {}, checkProperties = !!options.properties, checkClassFields = !!options.classFields, onlyDeclarations = !!options.onlyDeclarations, ignoreDestructuring = !!options.ignoreDestructuring;
            let globalScope;
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            // contains reported nodes to avoid reporting twice on destructuring with shorthand notation
            const reportedNodes = new Set();
            const ALLOWED_PARENT_TYPES = new Set(["CallExpression", "NewExpression"]);
            const DECLARATION_TYPES = new Set(["FunctionDeclaration", "VariableDeclarator"]);
            const IMPORT_TYPES = new Set(["ImportSpecifier", "ImportNamespaceSpecifier", "ImportDefaultSpecifier"]);
            /**
             * Checks whether the given node represents a reference to a global variable that is not declared in the source code.
             * These identifiers will be allowed, as it is assumed that user has no control over the names of external global variables.
             * @param {ASTNode} node `Identifier` node to check.
             * @returns {boolean} `true` if the node is a reference to a global variable.
             */
            function isReferenceToGlobalVariable(node) {
                const variable = globalScope.set.get(node.name);
                return variable && variable.defs.length === 0 &&
                    variable.references.some(ref => ref.identifier === node);
            }
            /**
             * Checks if a string matches the provided pattern
             * @param {string} name The string to check.
             * @returns {boolean} if the string is a match
             * @private
             */
            function isInvalid(name) {
                return !regexp.test(name);
            }
            /**
             * Checks if a parent of a node is an ObjectPattern.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} if the node is inside an ObjectPattern
             * @private
             */
            function isInsideObjectPattern(node) {
                let { parent } = node;
                while (parent) {
                    if (parent.type === "ObjectPattern") {
                        return true;
                    }
                    parent = parent.parent;
                }
                return false;
            }
            /**
             * Verifies if we should report an error or not based on the effective
             * parent node and the identifier name.
             * @param {ASTNode} effectiveParent The effective parent node of the node to be reported
             * @param {string} name The identifier name of the identifier node
             * @returns {boolean} whether an error should be reported or not
             */
            function shouldReport(effectiveParent, name) {
                return (!onlyDeclarations || DECLARATION_TYPES.has(effectiveParent.type)) &&
                    !ALLOWED_PARENT_TYPES.has(effectiveParent.type) && isInvalid(name);
            }
            /**
             * Reports an AST node as a rule violation.
             * @param {ASTNode} node The node to report.
             * @returns {void}
             * @private
             */
            function report(node) {
                /*
                 * We used the range instead of the node because it's possible
                 * for the same identifier to be represented by two different
                 * nodes, with the most clear example being shorthand properties:
                 * { foo }
                 * In this case, "foo" is represented by one node for the name
                 * and one for the value. The only way to know they are the same
                 * is to look at the range.
                 */
                if (!reportedNodes.has(node.range.toString())) {
                    const messageId = (node.type === "PrivateIdentifier")
                        ? "notMatchPrivate" : "notMatch";
                    context.report({
                        node,
                        messageId,
                        data: {
                            name: node.name,
                            pattern
                        }
                    });
                    reportedNodes.add(node.range.toString());
                }
            }
            return {
                Program() {
                    globalScope = context.getScope();
                },
                Identifier(node) {
                    const name = node.name, parent = node.parent, effectiveParent = (parent.type === "MemberExpression") ? parent.parent : parent;
                    if (isReferenceToGlobalVariable(node)) {
                        return;
                    }
                    if (parent.type === "MemberExpression") {
                        if (!checkProperties) {
                            return;
                        }
                        // Always check object names
                        if (parent.object.type === "Identifier" &&
                            parent.object.name === name) {
                            if (isInvalid(name)) {
                                report(node);
                            }
                            // Report AssignmentExpressions left side's assigned variable id
                        }
                        else if (effectiveParent.type === "AssignmentExpression" &&
                            effectiveParent.left.type === "MemberExpression" &&
                            effectiveParent.left.property.name === node.name) {
                            if (isInvalid(name)) {
                                report(node);
                            }
                            // Report AssignmentExpressions only if they are the left side of the assignment
                        }
                        else if (effectiveParent.type === "AssignmentExpression" && effectiveParent.right.type !== "MemberExpression") {
                            if (isInvalid(name)) {
                                report(node);
                            }
                        }
                        // For https://github.com/eslint/eslint/issues/15123
                    }
                    else if (parent.type === "Property" &&
                        parent.parent.type === "ObjectExpression" &&
                        parent.key === node &&
                        !parent.computed) {
                        if (checkProperties && isInvalid(name)) {
                            report(node);
                        }
                        /*
                         * Properties have their own rules, and
                         * AssignmentPattern nodes can be treated like Properties:
                         * e.g.: const { no_camelcased = false } = bar;
                         */
                    }
                    else if (parent.type === "Property" || parent.type === "AssignmentPattern") {
                        if (parent.parent && parent.parent.type === "ObjectPattern") {
                            if (!ignoreDestructuring && parent.shorthand && parent.value.left && isInvalid(name)) {
                                report(node);
                            }
                            const assignmentKeyEqualsValue = parent.key.name === parent.value.name;
                            // prevent checking righthand side of destructured object
                            if (!assignmentKeyEqualsValue && parent.key === node) {
                                return;
                            }
                            const valueIsInvalid = parent.value.name && isInvalid(name);
                            // ignore destructuring if the option is set, unless a new identifier is created
                            if (valueIsInvalid && !(assignmentKeyEqualsValue && ignoreDestructuring)) {
                                report(node);
                            }
                        }
                        // never check properties or always ignore destructuring
                        if ((!checkProperties && !parent.computed) || (ignoreDestructuring && isInsideObjectPattern(node))) {
                            return;
                        }
                        // don't check right hand side of AssignmentExpression to prevent duplicate warnings
                        if (parent.right !== node && shouldReport(effectiveParent, name)) {
                            report(node);
                        }
                        // Check if it's an import specifier
                    }
                    else if (IMPORT_TYPES.has(parent.type)) {
                        // Report only if the local imported identifier is invalid
                        if (parent.local && parent.local.name === node.name && isInvalid(name)) {
                            report(node);
                        }
                    }
                    else if (parent.type === "PropertyDefinition") {
                        if (checkClassFields && isInvalid(name)) {
                            report(node);
                        }
                        // Report anything that is invalid that isn't a CallExpression
                    }
                    else if (shouldReport(effectiveParent, name)) {
                        report(node);
                    }
                },
                "PrivateIdentifier"(node) {
                    const isClassField = node.parent.type === "PropertyDefinition";
                    if (isClassField && !checkClassFields) {
                        return;
                    }
                    if (isInvalid(node.name)) {
                        report(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/implicit-arrow-linebreak.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview enforce the location of arrow function bodies
     * @author Sharmila Jesupaul
     */
    "use strict";
    const { isCommentToken, isNotOpeningParenToken } = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce the location of arrow function bodies",
                recommended: false,
                url: "https://eslint.org/docs/rules/implicit-arrow-linebreak"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["beside", "below"]
                }
            ],
            messages: {
                expected: "Expected a linebreak before this expression.",
                unexpected: "Expected no linebreak before this expression."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const option = context.options[0] || "beside";
            /**
             * Validates the location of an arrow function body
             * @param {ASTNode} node The arrow function body
             * @returns {void}
             */
            function validateExpression(node) {
                if (node.body.type === "BlockStatement") {
                    return;
                }
                const arrowToken = sourceCode.getTokenBefore(node.body, isNotOpeningParenToken);
                const firstTokenOfBody = sourceCode.getTokenAfter(arrowToken);
                if (arrowToken.loc.end.line === firstTokenOfBody.loc.start.line && option === "below") {
                    context.report({
                        node: firstTokenOfBody,
                        messageId: "expected",
                        fix: fixer => fixer.insertTextBefore(firstTokenOfBody, "\n")
                    });
                }
                else if (arrowToken.loc.end.line !== firstTokenOfBody.loc.start.line && option === "beside") {
                    context.report({
                        node: firstTokenOfBody,
                        messageId: "unexpected",
                        fix(fixer) {
                            if (sourceCode.getFirstTokenBetween(arrowToken, firstTokenOfBody, { includeComments: true, filter: isCommentToken })) {
                                return null;
                            }
                            return fixer.replaceTextRange([arrowToken.range[1], firstTokenOfBody.range[0]], " ");
                        }
                    });
                }
            }
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                ArrowFunctionExpression: node => validateExpression(node)
            };
        }
    };
},
/* eslint/lib/rules/indent.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview This rule sets a specific indentation style and width for your code
     *
     * @author Teddy Katz
     * @author Vitaly Puzrin
     * @author Gyandeep Singh
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { OrderedMap } = require(418) /* js-sdsl */;
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const KNOWN_NODES = new Set([
        "AssignmentExpression",
        "AssignmentPattern",
        "ArrayExpression",
        "ArrayPattern",
        "ArrowFunctionExpression",
        "AwaitExpression",
        "BlockStatement",
        "BinaryExpression",
        "BreakStatement",
        "CallExpression",
        "CatchClause",
        "ChainExpression",
        "ClassBody",
        "ClassDeclaration",
        "ClassExpression",
        "ConditionalExpression",
        "ContinueStatement",
        "DoWhileStatement",
        "DebuggerStatement",
        "EmptyStatement",
        "ExperimentalRestProperty",
        "ExperimentalSpreadProperty",
        "ExpressionStatement",
        "ForStatement",
        "ForInStatement",
        "ForOfStatement",
        "FunctionDeclaration",
        "FunctionExpression",
        "Identifier",
        "IfStatement",
        "Literal",
        "LabeledStatement",
        "LogicalExpression",
        "MemberExpression",
        "MetaProperty",
        "MethodDefinition",
        "NewExpression",
        "ObjectExpression",
        "ObjectPattern",
        "PrivateIdentifier",
        "Program",
        "Property",
        "PropertyDefinition",
        "RestElement",
        "ReturnStatement",
        "SequenceExpression",
        "SpreadElement",
        "StaticBlock",
        "Super",
        "SwitchCase",
        "SwitchStatement",
        "TaggedTemplateExpression",
        "TemplateElement",
        "TemplateLiteral",
        "ThisExpression",
        "ThrowStatement",
        "TryStatement",
        "UnaryExpression",
        "UpdateExpression",
        "VariableDeclaration",
        "VariableDeclarator",
        "WhileStatement",
        "WithStatement",
        "YieldExpression",
        "JSXFragment",
        "JSXOpeningFragment",
        "JSXClosingFragment",
        "JSXIdentifier",
        "JSXNamespacedName",
        "JSXMemberExpression",
        "JSXEmptyExpression",
        "JSXExpressionContainer",
        "JSXElement",
        "JSXClosingElement",
        "JSXOpeningElement",
        "JSXAttribute",
        "JSXSpreadAttribute",
        "JSXText",
        "ExportDefaultDeclaration",
        "ExportNamedDeclaration",
        "ExportAllDeclaration",
        "ExportSpecifier",
        "ImportDeclaration",
        "ImportSpecifier",
        "ImportDefaultSpecifier",
        "ImportNamespaceSpecifier",
        "ImportExpression"
    ]);
    /*
     * General rule strategy:
     * 1. An OffsetStorage instance stores a map of desired offsets, where each token has a specified offset from another
     *    specified token or to the first column.
     * 2. As the AST is traversed, modify the desired offsets of tokens accordingly. For example, when entering a
     *    BlockStatement, offset all of the tokens in the BlockStatement by 1 indent level from the opening curly
     *    brace of the BlockStatement.
     * 3. After traversing the AST, calculate the expected indentation levels of every token according to the
     *    OffsetStorage container.
     * 4. For each line, compare the expected indentation of the first token to the actual indentation in the file,
     *    and report the token if the two values are not equal.
     */
    /**
     * A mutable balanced binary search tree that stores (key, value) pairs. The keys are numeric, and must be unique.
     * This is intended to be a generic wrapper around a balanced binary search tree library, so that the underlying implementation
     * can easily be swapped out.
     */
    class BinarySearchTree {
        /**
         * Creates an empty tree
         */
        constructor() {
            this._orderedMap = new OrderedMap();
            this._orderedMapEnd = this._orderedMap.end();
        }
        /**
         * Inserts an entry into the tree.
         * @param {number} key The entry's key
         * @param {any} value The entry's value
         * @returns {void}
         */
        insert(key, value) {
            this._orderedMap.setElement(key, value);
        }
        /**
         * Finds the entry with the largest key less than or equal to the provided key
         * @param {number} key The provided key
         * @returns {{key: number, value: *}|null} The found entry, or null if no such entry exists.
         */
        findLe(key) {
            const iterator = this._orderedMap.reverseLowerBound(key);
            if (iterator.equals(this._orderedMapEnd)) {
                return {};
            }
            return { key: iterator.pointer[0], value: iterator.pointer[1] };
        }
        /**
         * Deletes all of the keys in the interval [start, end)
         * @param {number} start The start of the range
         * @param {number} end The end of the range
         * @returns {void}
         */
        deleteRange(start, end) {
            // Exit without traversing the tree if the range has zero size.
            if (start === end) {
                return;
            }
            const iterator = this._orderedMap.lowerBound(start);
            if (iterator.equals(this._orderedMapEnd)) {
                return;
            }
            if (end > this._orderedMap.back()[0]) {
                while (!iterator.equals(this._orderedMapEnd)) {
                    this._orderedMap.eraseElementByIterator(iterator);
                }
            }
            else {
                while (iterator.pointer[0] < end) {
                    this._orderedMap.eraseElementByIterator(iterator);
                }
            }
        }
    }
    /**
     * A helper class to get token-based info related to indentation
     */
    class TokenInfo {
        /**
         * @param {SourceCode} sourceCode A SourceCode object
         */
        constructor(sourceCode) {
            this.sourceCode = sourceCode;
            this.firstTokensByLineNumber = sourceCode.tokensAndComments.reduce((map, token) => {
                if (!map.has(token.loc.start.line)) {
                    map.set(token.loc.start.line, token);
                }
                if (!map.has(token.loc.end.line) && sourceCode.text.slice(token.range[1] - token.loc.end.column, token.range[1]).trim()) {
                    map.set(token.loc.end.line, token);
                }
                return map;
            }, new Map());
        }
        /**
         * Gets the first token on a given token's line
         * @param {Token|ASTNode} token a node or token
         * @returns {Token} The first token on the given line
         */
        getFirstTokenOfLine(token) {
            return this.firstTokensByLineNumber.get(token.loc.start.line);
        }
        /**
         * Determines whether a token is the first token in its line
         * @param {Token} token The token
         * @returns {boolean} `true` if the token is the first on its line
         */
        isFirstTokenOfLine(token) {
            return this.getFirstTokenOfLine(token) === token;
        }
        /**
         * Get the actual indent of a token
         * @param {Token} token Token to examine. This should be the first token on its line.
         * @returns {string} The indentation characters that precede the token
         */
        getTokenIndent(token) {
            return this.sourceCode.text.slice(token.range[0] - token.loc.start.column, token.range[0]);
        }
    }
    /**
     * A class to store information on desired offsets of tokens from each other
     */
    class OffsetStorage {
        /**
         * @param {TokenInfo} tokenInfo a TokenInfo instance
         * @param {number} indentSize The desired size of each indentation level
         * @param {string} indentType The indentation character
         */
        constructor(tokenInfo, indentSize, indentType) {
            this._tokenInfo = tokenInfo;
            this._indentSize = indentSize;
            this._indentType = indentType;
            this._tree = new BinarySearchTree();
            this._tree.insert(0, { offset: 0, from: null, force: false });
            this._lockedFirstTokens = new WeakMap();
            this._desiredIndentCache = new WeakMap();
            this._ignoredTokens = new WeakSet();
        }
        _getOffsetDescriptor(token) {
            return this._tree.findLe(token.range[0]).value;
        }
        /**
         * Sets the offset column of token B to match the offset column of token A.
         * - **WARNING**: This matches a *column*, even if baseToken is not the first token on its line. In
         * most cases, `setDesiredOffset` should be used instead.
         * @param {Token} baseToken The first token
         * @param {Token} offsetToken The second token, whose offset should be matched to the first token
         * @returns {void}
         */
        matchOffsetOf(baseToken, offsetToken) {
            /*
             * lockedFirstTokens is a map from a token whose indentation is controlled by the "first" option to
             * the token that it depends on. For example, with the `ArrayExpression: first` option, the first
             * token of each element in the array after the first will be mapped to the first token of the first
             * element. The desired indentation of each of these tokens is computed based on the desired indentation
             * of the "first" element, rather than through the normal offset mechanism.
             */
            this._lockedFirstTokens.set(offsetToken, baseToken);
        }
        /**
         * Sets the desired offset of a token.
         *
         * This uses a line-based offset collapsing behavior to handle tokens on the same line.
         * For example, consider the following two cases:
         *
         * (
         *     [
         *         bar
         *     ]
         * )
         *
         * ([
         *     bar
         * ])
         *
         * Based on the first case, it's clear that the `bar` token needs to have an offset of 1 indent level (4 spaces) from
         * the `[` token, and the `[` token has to have an offset of 1 indent level from the `(` token. Since the `(` token is
         * the first on its line (with an indent of 0 spaces), the `bar` token needs to be offset by 2 indent levels (8 spaces)
         * from the start of its line.
         *
         * However, in the second case `bar` should only be indented by 4 spaces. This is because the offset of 1 indent level
         * between the `(` and the `[` tokens gets "collapsed" because the two tokens are on the same line. As a result, the
         * `(` token is mapped to the `[` token with an offset of 0, and the rule correctly decides that `bar` should be indented
         * by 1 indent level from the start of the line.
         *
         * This is useful because rule listeners can usually just call `setDesiredOffset` for all the tokens in the node,
         * without needing to check which lines those tokens are on.
         *
         * Note that since collapsing only occurs when two tokens are on the same line, there are a few cases where non-intuitive
         * behavior can occur. For example, consider the following cases:
         *
         * foo(
         * ).
         *     bar(
         *         baz
         *     )
         *
         * foo(
         * ).bar(
         *     baz
         * )
         *
         * Based on the first example, it would seem that `bar` should be offset by 1 indent level from `foo`, and `baz`
         * should be offset by 1 indent level from `bar`. However, this is not correct, because it would result in `baz`
         * being indented by 2 indent levels in the second case (since `foo`, `bar`, and `baz` are all on separate lines, no
         * collapsing would occur).
         *
         * Instead, the correct way would be to offset `baz` by 1 level from `bar`, offset `bar` by 1 level from the `)`, and
         * offset the `)` by 0 levels from `foo`. This ensures that the offset between `bar` and the `)` are correctly collapsed
         * in the second case.
         * @param {Token} token The token
         * @param {Token} fromToken The token that `token` should be offset from
         * @param {number} offset The desired indent level
         * @returns {void}
         */
        setDesiredOffset(token, fromToken, offset) {
            return this.setDesiredOffsets(token.range, fromToken, offset);
        }
        /**
         * Sets the desired offset of all tokens in a range
         * It's common for node listeners in this file to need to apply the same offset to a large, contiguous range of tokens.
         * Moreover, the offset of any given token is usually updated multiple times (roughly once for each node that contains
         * it). This means that the offset of each token is updated O(AST depth) times.
         * It would not be performant to store and update the offsets for each token independently, because the rule would end
         * up having a time complexity of O(number of tokens * AST depth), which is quite slow for large files.
         *
         * Instead, the offset tree is represented as a collection of contiguous offset ranges in a file. For example, the following
         * list could represent the state of the offset tree at a given point:
         *
         * - Tokens starting in the interval [0, 15) are aligned with the beginning of the file
         * - Tokens starting in the interval [15, 30) are offset by 1 indent level from the `bar` token
         * - Tokens starting in the interval [30, 43) are offset by 1 indent level from the `foo` token
         * - Tokens starting in the interval [43, 820) are offset by 2 indent levels from the `bar` token
         * - Tokens starting in the interval [820, ∞) are offset by 1 indent level from the `baz` token
         *
         * The `setDesiredOffsets` methods inserts ranges like the ones above. The third line above would be inserted by using:
         * `setDesiredOffsets([30, 43], fooToken, 1);`
         * @param {[number, number]} range A [start, end] pair. All tokens with range[0] <= token.start < range[1] will have the offset applied.
         * @param {Token} fromToken The token that this is offset from
         * @param {number} offset The desired indent level
         * @param {boolean} force `true` if this offset should not use the normal collapsing behavior. This should almost always be false.
         * @returns {void}
         */
        setDesiredOffsets(range, fromToken, offset, force) {
            /*
             * Offset ranges are stored as a collection of nodes, where each node maps a numeric key to an offset
             * descriptor. The tree for the example above would have the following nodes:
             *
             * * key: 0, value: { offset: 0, from: null }
             * * key: 15, value: { offset: 1, from: barToken }
             * * key: 30, value: { offset: 1, from: fooToken }
             * * key: 43, value: { offset: 2, from: barToken }
             * * key: 820, value: { offset: 1, from: bazToken }
             *
             * To find the offset descriptor for any given token, one needs to find the node with the largest key
             * which is <= token.start. To make this operation fast, the nodes are stored in a balanced binary
             * search tree indexed by key.
             */
            const descriptorToInsert = { offset, from: fromToken, force };
            const descriptorAfterRange = this._tree.findLe(range[1]).value;
            const fromTokenIsInRange = fromToken && fromToken.range[0] >= range[0] && fromToken.range[1] <= range[1];
            const fromTokenDescriptor = fromTokenIsInRange && this._getOffsetDescriptor(fromToken);
            // First, remove any existing nodes in the range from the tree.
            this._tree.deleteRange(range[0] + 1, range[1]);
            // Insert a new node into the tree for this range
            this._tree.insert(range[0], descriptorToInsert);
            /*
             * To avoid circular offset dependencies, keep the `fromToken` token mapped to whatever it was mapped to previously,
             * even if it's in the current range.
             */
            if (fromTokenIsInRange) {
                this._tree.insert(fromToken.range[0], fromTokenDescriptor);
                this._tree.insert(fromToken.range[1], descriptorToInsert);
            }
            /*
             * To avoid modifying the offset of tokens after the range, insert another node to keep the offset of the following
             * tokens the same as it was before.
             */
            this._tree.insert(range[1], descriptorAfterRange);
        }
        /**
         * Gets the desired indent of a token
         * @param {Token} token The token
         * @returns {string} The desired indent of the token
         */
        getDesiredIndent(token) {
            if (!this._desiredIndentCache.has(token)) {
                if (this._ignoredTokens.has(token)) {
                    /*
                     * If the token is ignored, use the actual indent of the token as the desired indent.
                     * This ensures that no errors are reported for this token.
                     */
                    this._desiredIndentCache.set(token, this._tokenInfo.getTokenIndent(token));
                }
                else if (this._lockedFirstTokens.has(token)) {
                    const firstToken = this._lockedFirstTokens.get(token);
                    this._desiredIndentCache.set(token, 
                    // (indentation for the first element's line)
                    this.getDesiredIndent(this._tokenInfo.getFirstTokenOfLine(firstToken)) +
                        // (space between the start of the first element's line and the first element)
                        this._indentType.repeat(firstToken.loc.start.column - this._tokenInfo.getFirstTokenOfLine(firstToken).loc.start.column));
                }
                else {
                    const offsetInfo = this._getOffsetDescriptor(token);
                    const offset = (offsetInfo.from &&
                        offsetInfo.from.loc.start.line === token.loc.start.line &&
                        !/^\s*?\n/u.test(token.value) &&
                        !offsetInfo.force) ? 0 : offsetInfo.offset * this._indentSize;
                    this._desiredIndentCache.set(token, (offsetInfo.from ? this.getDesiredIndent(offsetInfo.from) : "") + this._indentType.repeat(offset));
                }
            }
            return this._desiredIndentCache.get(token);
        }
        /**
         * Ignores a token, preventing it from being reported.
         * @param {Token} token The token
         * @returns {void}
         */
        ignoreToken(token) {
            if (this._tokenInfo.isFirstTokenOfLine(token)) {
                this._ignoredTokens.add(token);
            }
        }
        /**
         * Gets the first token that the given token's indentation is dependent on
         * @param {Token} token The token
         * @returns {Token} The token that the given token depends on, or `null` if the given token is at the top level
         */
        getFirstDependency(token) {
            return this._getOffsetDescriptor(token).from;
        }
    }
    const ELEMENT_LIST_SCHEMA = {
        oneOf: [
            {
                type: "integer",
                minimum: 0
            },
            {
                enum: ["first", "off"]
            }
        ]
    };
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent indentation",
                recommended: false,
                url: "https://eslint.org/docs/rules/indent"
            },
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["tab"]
                        },
                        {
                            type: "integer",
                            minimum: 0
                        }
                    ]
                },
                {
                    type: "object",
                    properties: {
                        SwitchCase: {
                            type: "integer",
                            minimum: 0,
                            default: 0
                        },
                        VariableDeclarator: {
                            oneOf: [
                                ELEMENT_LIST_SCHEMA,
                                {
                                    type: "object",
                                    properties: {
                                        var: ELEMENT_LIST_SCHEMA,
                                        let: ELEMENT_LIST_SCHEMA,
                                        const: ELEMENT_LIST_SCHEMA
                                    },
                                    additionalProperties: false
                                }
                            ]
                        },
                        outerIIFEBody: {
                            oneOf: [
                                {
                                    type: "integer",
                                    minimum: 0
                                },
                                {
                                    enum: ["off"]
                                }
                            ]
                        },
                        MemberExpression: {
                            oneOf: [
                                {
                                    type: "integer",
                                    minimum: 0
                                },
                                {
                                    enum: ["off"]
                                }
                            ]
                        },
                        FunctionDeclaration: {
                            type: "object",
                            properties: {
                                parameters: ELEMENT_LIST_SCHEMA,
                                body: {
                                    type: "integer",
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        },
                        FunctionExpression: {
                            type: "object",
                            properties: {
                                parameters: ELEMENT_LIST_SCHEMA,
                                body: {
                                    type: "integer",
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        },
                        StaticBlock: {
                            type: "object",
                            properties: {
                                body: {
                                    type: "integer",
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        },
                        CallExpression: {
                            type: "object",
                            properties: {
                                arguments: ELEMENT_LIST_SCHEMA
                            },
                            additionalProperties: false
                        },
                        ArrayExpression: ELEMENT_LIST_SCHEMA,
                        ObjectExpression: ELEMENT_LIST_SCHEMA,
                        ImportDeclaration: ELEMENT_LIST_SCHEMA,
                        flatTernaryExpressions: {
                            type: "boolean",
                            default: false
                        },
                        offsetTernaryExpressions: {
                            type: "boolean",
                            default: false
                        },
                        ignoredNodes: {
                            type: "array",
                            items: {
                                type: "string",
                                not: {
                                    pattern: ":exit$"
                                }
                            }
                        },
                        ignoreComments: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                wrongIndentation: "Expected indentation of {{expected}} but found {{actual}}."
            }
        },
        create(context) {
            const DEFAULT_VARIABLE_INDENT = 1;
            const DEFAULT_PARAMETER_INDENT = 1;
            const DEFAULT_FUNCTION_BODY_INDENT = 1;
            let indentType = "space";
            let indentSize = 4;
            const options = {
                SwitchCase: 0,
                VariableDeclarator: {
                    var: DEFAULT_VARIABLE_INDENT,
                    let: DEFAULT_VARIABLE_INDENT,
                    const: DEFAULT_VARIABLE_INDENT
                },
                outerIIFEBody: 1,
                FunctionDeclaration: {
                    parameters: DEFAULT_PARAMETER_INDENT,
                    body: DEFAULT_FUNCTION_BODY_INDENT
                },
                FunctionExpression: {
                    parameters: DEFAULT_PARAMETER_INDENT,
                    body: DEFAULT_FUNCTION_BODY_INDENT
                },
                StaticBlock: {
                    body: DEFAULT_FUNCTION_BODY_INDENT
                },
                CallExpression: {
                    arguments: DEFAULT_PARAMETER_INDENT
                },
                MemberExpression: 1,
                ArrayExpression: 1,
                ObjectExpression: 1,
                ImportDeclaration: 1,
                flatTernaryExpressions: false,
                ignoredNodes: [],
                ignoreComments: false
            };
            if (context.options.length) {
                if (context.options[0] === "tab") {
                    indentSize = 1;
                    indentType = "tab";
                }
                else {
                    indentSize = context.options[0];
                    indentType = "space";
                }
                if (context.options[1]) {
                    Object.assign(options, context.options[1]);
                    if (typeof options.VariableDeclarator === "number" || options.VariableDeclarator === "first") {
                        options.VariableDeclarator = {
                            var: options.VariableDeclarator,
                            let: options.VariableDeclarator,
                            const: options.VariableDeclarator
                        };
                    }
                }
            }
            const sourceCode = context.getSourceCode();
            const tokenInfo = new TokenInfo(sourceCode);
            const offsets = new OffsetStorage(tokenInfo, indentSize, indentType === "space" ? " " : "\t");
            const parameterParens = new WeakSet();
            /**
             * Creates an error message for a line, given the expected/actual indentation.
             * @param {int} expectedAmount The expected amount of indentation characters for this line
             * @param {int} actualSpaces The actual number of indentation spaces that were found on this line
             * @param {int} actualTabs The actual number of indentation tabs that were found on this line
             * @returns {string} An error message for this line
             */
            function createErrorMessageData(expectedAmount, actualSpaces, actualTabs) {
                const expectedStatement = `${expectedAmount} ${indentType}${expectedAmount === 1 ? "" : "s"}`; // e.g. "2 tabs"
                const foundSpacesWord = `space${actualSpaces === 1 ? "" : "s"}`; // e.g. "space"
                const foundTabsWord = `tab${actualTabs === 1 ? "" : "s"}`; // e.g. "tabs"
                let foundStatement;
                if (actualSpaces > 0) {
                    /*
                     * Abbreviate the message if the expected indentation is also spaces.
                     * e.g. 'Expected 4 spaces but found 2' rather than 'Expected 4 spaces but found 2 spaces'
                     */
                    foundStatement = indentType === "space" ? actualSpaces : `${actualSpaces} ${foundSpacesWord}`;
                }
                else if (actualTabs > 0) {
                    foundStatement = indentType === "tab" ? actualTabs : `${actualTabs} ${foundTabsWord}`;
                }
                else {
                    foundStatement = "0";
                }
                return {
                    expected: expectedStatement,
                    actual: foundStatement
                };
            }
            /**
             * Reports a given indent violation
             * @param {Token} token Token violating the indent rule
             * @param {string} neededIndent Expected indentation string
             * @returns {void}
             */
            function report(token, neededIndent) {
                const actualIndent = Array.from(tokenInfo.getTokenIndent(token));
                const numSpaces = actualIndent.filter(char => char === " ").length;
                const numTabs = actualIndent.filter(char => char === "\t").length;
                context.report({
                    node: token,
                    messageId: "wrongIndentation",
                    data: createErrorMessageData(neededIndent.length, numSpaces, numTabs),
                    loc: {
                        start: { line: token.loc.start.line, column: 0 },
                        end: { line: token.loc.start.line, column: token.loc.start.column }
                    },
                    fix(fixer) {
                        const range = [token.range[0] - token.loc.start.column, token.range[0]];
                        const newText = neededIndent;
                        return fixer.replaceTextRange(range, newText);
                    }
                });
            }
            /**
             * Checks if a token's indentation is correct
             * @param {Token} token Token to examine
             * @param {string} desiredIndent Desired indentation of the string
             * @returns {boolean} `true` if the token's indentation is correct
             */
            function validateTokenIndent(token, desiredIndent) {
                const indentation = tokenInfo.getTokenIndent(token);
                return indentation === desiredIndent ||
                    // To avoid conflicts with no-mixed-spaces-and-tabs, don't report mixed spaces and tabs.
                    indentation.includes(" ") && indentation.includes("\t");
            }
            /**
             * Check to see if the node is a file level IIFE
             * @param {ASTNode} node The function node to check.
             * @returns {boolean} True if the node is the outer IIFE
             */
            function isOuterIIFE(node) {
                /*
                 * Verify that the node is an IIFE
                 */
                if (!node.parent || node.parent.type !== "CallExpression" || node.parent.callee !== node) {
                    return false;
                }
                /*
                 * Navigate legal ancestors to determine whether this IIFE is outer.
                 * A "legal ancestor" is an expression or statement that causes the function to get executed immediately.
                 * For example, `!(function(){})()` is an outer IIFE even though it is preceded by a ! operator.
                 */
                let statement = node.parent && node.parent.parent;
                while (statement.type === "UnaryExpression" && ["!", "~", "+", "-"].includes(statement.operator) ||
                    statement.type === "AssignmentExpression" ||
                    statement.type === "LogicalExpression" ||
                    statement.type === "SequenceExpression" ||
                    statement.type === "VariableDeclarator") {
                    statement = statement.parent;
                }
                return (statement.type === "ExpressionStatement" || statement.type === "VariableDeclaration") && statement.parent.type === "Program";
            }
            /**
             * Counts the number of linebreaks that follow the last non-whitespace character in a string
             * @param {string} string The string to check
             * @returns {number} The number of JavaScript linebreaks that follow the last non-whitespace character,
             * or the total number of linebreaks if the string is all whitespace.
             */
            function countTrailingLinebreaks(string) {
                const trailingWhitespace = string.match(/\s*$/u)[0];
                const linebreakMatches = trailingWhitespace.match(astUtils.createGlobalLinebreakMatcher());
                return linebreakMatches === null ? 0 : linebreakMatches.length;
            }
            /**
             * Check indentation for lists of elements (arrays, objects, function params)
             * @param {ASTNode[]} elements List of elements that should be offset
             * @param {Token} startToken The start token of the list that element should be aligned against, e.g. '['
             * @param {Token} endToken The end token of the list, e.g. ']'
             * @param {number|string} offset The amount that the elements should be offset
             * @returns {void}
             */
            function addElementListIndent(elements, startToken, endToken, offset) {
                /**
                 * Gets the first token of a given element, including surrounding parentheses.
                 * @param {ASTNode} element A node in the `elements` list
                 * @returns {Token} The first token of this element
                 */
                function getFirstToken(element) {
                    let token = sourceCode.getTokenBefore(element);
                    while (astUtils.isOpeningParenToken(token) && token !== startToken) {
                        token = sourceCode.getTokenBefore(token);
                    }
                    return sourceCode.getTokenAfter(token);
                }
                // Run through all the tokens in the list, and offset them by one indent level (mainly for comments, other things will end up overridden)
                offsets.setDesiredOffsets([startToken.range[1], endToken.range[0]], startToken, typeof offset === "number" ? offset : 1);
                offsets.setDesiredOffset(endToken, startToken, 0);
                // If the preference is "first" but there is no first element (e.g. sparse arrays w/ empty first slot), fall back to 1 level.
                if (offset === "first" && elements.length && !elements[0]) {
                    return;
                }
                elements.forEach((element, index) => {
                    if (!element) {
                        // Skip holes in arrays
                        return;
                    }
                    if (offset === "off") {
                        // Ignore the first token of every element if the "off" option is used
                        offsets.ignoreToken(getFirstToken(element));
                    }
                    // Offset the following elements correctly relative to the first element
                    if (index === 0) {
                        return;
                    }
                    if (offset === "first" && tokenInfo.isFirstTokenOfLine(getFirstToken(element))) {
                        offsets.matchOffsetOf(getFirstToken(elements[0]), getFirstToken(element));
                    }
                    else {
                        const previousElement = elements[index - 1];
                        const firstTokenOfPreviousElement = previousElement && getFirstToken(previousElement);
                        const previousElementLastToken = previousElement && sourceCode.getLastToken(previousElement);
                        if (previousElement &&
                            previousElementLastToken.loc.end.line - countTrailingLinebreaks(previousElementLastToken.value) > startToken.loc.end.line) {
                            offsets.setDesiredOffsets([previousElement.range[1], element.range[1]], firstTokenOfPreviousElement, 0);
                        }
                    }
                });
            }
            /**
             * Check and decide whether to check for indentation for blockless nodes
             * Scenarios are for or while statements without braces around them
             * @param {ASTNode} node node to examine
             * @returns {void}
             */
            function addBlocklessNodeIndent(node) {
                if (node.type !== "BlockStatement") {
                    const lastParentToken = sourceCode.getTokenBefore(node, astUtils.isNotOpeningParenToken);
                    let firstBodyToken = sourceCode.getFirstToken(node);
                    let lastBodyToken = sourceCode.getLastToken(node);
                    while (astUtils.isOpeningParenToken(sourceCode.getTokenBefore(firstBodyToken)) &&
                        astUtils.isClosingParenToken(sourceCode.getTokenAfter(lastBodyToken))) {
                        firstBodyToken = sourceCode.getTokenBefore(firstBodyToken);
                        lastBodyToken = sourceCode.getTokenAfter(lastBodyToken);
                    }
                    offsets.setDesiredOffsets([firstBodyToken.range[0], lastBodyToken.range[1]], lastParentToken, 1);
                }
            }
            /**
             * Checks the indentation for nodes that are like function calls (`CallExpression` and `NewExpression`)
             * @param {ASTNode} node A CallExpression or NewExpression node
             * @returns {void}
             */
            function addFunctionCallIndent(node) {
                let openingParen;
                if (node.arguments.length) {
                    openingParen = sourceCode.getFirstTokenBetween(node.callee, node.arguments[0], astUtils.isOpeningParenToken);
                }
                else {
                    openingParen = sourceCode.getLastToken(node, 1);
                }
                const closingParen = sourceCode.getLastToken(node);
                parameterParens.add(openingParen);
                parameterParens.add(closingParen);
                /*
                 * If `?.` token exists, set desired offset for that.
                 * This logic is copied from `MemberExpression`'s.
                 */
                if (node.optional) {
                    const dotToken = sourceCode.getTokenAfter(node.callee, astUtils.isQuestionDotToken);
                    const calleeParenCount = sourceCode.getTokensBetween(node.callee, dotToken, { filter: astUtils.isClosingParenToken }).length;
                    const firstTokenOfCallee = calleeParenCount
                        ? sourceCode.getTokenBefore(node.callee, { skip: calleeParenCount - 1 })
                        : sourceCode.getFirstToken(node.callee);
                    const lastTokenOfCallee = sourceCode.getTokenBefore(dotToken);
                    const offsetBase = lastTokenOfCallee.loc.end.line === openingParen.loc.start.line
                        ? lastTokenOfCallee
                        : firstTokenOfCallee;
                    offsets.setDesiredOffset(dotToken, offsetBase, 1);
                }
                const offsetAfterToken = node.callee.type === "TaggedTemplateExpression" ? sourceCode.getFirstToken(node.callee.quasi) : openingParen;
                const offsetToken = sourceCode.getTokenBefore(offsetAfterToken);
                offsets.setDesiredOffset(openingParen, offsetToken, 0);
                addElementListIndent(node.arguments, openingParen, closingParen, options.CallExpression.arguments);
            }
            /**
             * Checks the indentation of parenthesized values, given a list of tokens in a program
             * @param {Token[]} tokens A list of tokens
             * @returns {void}
             */
            function addParensIndent(tokens) {
                const parenStack = [];
                const parenPairs = [];
                tokens.forEach(nextToken => {
                    // Accumulate a list of parenthesis pairs
                    if (astUtils.isOpeningParenToken(nextToken)) {
                        parenStack.push(nextToken);
                    }
                    else if (astUtils.isClosingParenToken(nextToken)) {
                        parenPairs.unshift({ left: parenStack.pop(), right: nextToken });
                    }
                });
                parenPairs.forEach(pair => {
                    const leftParen = pair.left;
                    const rightParen = pair.right;
                    // We only want to handle parens around expressions, so exclude parentheses that are in function parameters and function call arguments.
                    if (!parameterParens.has(leftParen) && !parameterParens.has(rightParen)) {
                        const parenthesizedTokens = new Set(sourceCode.getTokensBetween(leftParen, rightParen));
                        parenthesizedTokens.forEach(token => {
                            if (!parenthesizedTokens.has(offsets.getFirstDependency(token))) {
                                offsets.setDesiredOffset(token, leftParen, 1);
                            }
                        });
                    }
                    offsets.setDesiredOffset(rightParen, leftParen, 0);
                });
            }
            /**
             * Ignore all tokens within an unknown node whose offset do not depend
             * on another token's offset within the unknown node
             * @param {ASTNode} node Unknown Node
             * @returns {void}
             */
            function ignoreNode(node) {
                const unknownNodeTokens = new Set(sourceCode.getTokens(node, { includeComments: true }));
                unknownNodeTokens.forEach(token => {
                    if (!unknownNodeTokens.has(offsets.getFirstDependency(token))) {
                        const firstTokenOfLine = tokenInfo.getFirstTokenOfLine(token);
                        if (token === firstTokenOfLine) {
                            offsets.ignoreToken(token);
                        }
                        else {
                            offsets.setDesiredOffset(token, firstTokenOfLine, 0);
                        }
                    }
                });
            }
            /**
             * Check whether the given token is on the first line of a statement.
             * @param {Token} token The token to check.
             * @param {ASTNode} leafNode The expression node that the token belongs directly.
             * @returns {boolean} `true` if the token is on the first line of a statement.
             */
            function isOnFirstLineOfStatement(token, leafNode) {
                let node = leafNode;
                while (node.parent && !node.parent.type.endsWith("Statement") && !node.parent.type.endsWith("Declaration")) {
                    node = node.parent;
                }
                node = node.parent;
                return !node || node.loc.start.line === token.loc.start.line;
            }
            /**
             * Check whether there are any blank (whitespace-only) lines between
             * two tokens on separate lines.
             * @param {Token} firstToken The first token.
             * @param {Token} secondToken The second token.
             * @returns {boolean} `true` if the tokens are on separate lines and
             *   there exists a blank line between them, `false` otherwise.
             */
            function hasBlankLinesBetween(firstToken, secondToken) {
                const firstTokenLine = firstToken.loc.end.line;
                const secondTokenLine = secondToken.loc.start.line;
                if (firstTokenLine === secondTokenLine || firstTokenLine === secondTokenLine - 1) {
                    return false;
                }
                for (let line = firstTokenLine + 1; line < secondTokenLine; ++line) {
                    if (!tokenInfo.firstTokensByLineNumber.has(line)) {
                        return true;
                    }
                }
                return false;
            }
            const ignoredNodeFirstTokens = new Set();
            const baseOffsetListeners = {
                "ArrayExpression, ArrayPattern"(node) {
                    const openingBracket = sourceCode.getFirstToken(node);
                    const closingBracket = sourceCode.getTokenAfter([...node.elements].reverse().find(_ => _) || openingBracket, astUtils.isClosingBracketToken);
                    addElementListIndent(node.elements, openingBracket, closingBracket, options.ArrayExpression);
                },
                "ObjectExpression, ObjectPattern"(node) {
                    const openingCurly = sourceCode.getFirstToken(node);
                    const closingCurly = sourceCode.getTokenAfter(node.properties.length ? node.properties[node.properties.length - 1] : openingCurly, astUtils.isClosingBraceToken);
                    addElementListIndent(node.properties, openingCurly, closingCurly, options.ObjectExpression);
                },
                ArrowFunctionExpression(node) {
                    const maybeOpeningParen = sourceCode.getFirstToken(node, { skip: node.async ? 1 : 0 });
                    if (astUtils.isOpeningParenToken(maybeOpeningParen)) {
                        const openingParen = maybeOpeningParen;
                        const closingParen = sourceCode.getTokenBefore(node.body, astUtils.isClosingParenToken);
                        parameterParens.add(openingParen);
                        parameterParens.add(closingParen);
                        addElementListIndent(node.params, openingParen, closingParen, options.FunctionExpression.parameters);
                    }
                    addBlocklessNodeIndent(node.body);
                },
                AssignmentExpression(node) {
                    const operator = sourceCode.getFirstTokenBetween(node.left, node.right, token => token.value === node.operator);
                    offsets.setDesiredOffsets([operator.range[0], node.range[1]], sourceCode.getLastToken(node.left), 1);
                    offsets.ignoreToken(operator);
                    offsets.ignoreToken(sourceCode.getTokenAfter(operator));
                },
                "BinaryExpression, LogicalExpression"(node) {
                    const operator = sourceCode.getFirstTokenBetween(node.left, node.right, token => token.value === node.operator);
                    /*
                     * For backwards compatibility, don't check BinaryExpression indents, e.g.
                     * var foo = bar &&
                     *                   baz;
                     */
                    const tokenAfterOperator = sourceCode.getTokenAfter(operator);
                    offsets.ignoreToken(operator);
                    offsets.ignoreToken(tokenAfterOperator);
                    offsets.setDesiredOffset(tokenAfterOperator, operator, 0);
                },
                "BlockStatement, ClassBody"(node) {
                    let blockIndentLevel;
                    if (node.parent && isOuterIIFE(node.parent)) {
                        blockIndentLevel = options.outerIIFEBody;
                    }
                    else if (node.parent && (node.parent.type === "FunctionExpression" || node.parent.type === "ArrowFunctionExpression")) {
                        blockIndentLevel = options.FunctionExpression.body;
                    }
                    else if (node.parent && node.parent.type === "FunctionDeclaration") {
                        blockIndentLevel = options.FunctionDeclaration.body;
                    }
                    else {
                        blockIndentLevel = 1;
                    }
                    /*
                     * For blocks that aren't lone statements, ensure that the opening curly brace
                     * is aligned with the parent.
                     */
                    if (!astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type)) {
                        offsets.setDesiredOffset(sourceCode.getFirstToken(node), sourceCode.getFirstToken(node.parent), 0);
                    }
                    addElementListIndent(node.body, sourceCode.getFirstToken(node), sourceCode.getLastToken(node), blockIndentLevel);
                },
                CallExpression: addFunctionCallIndent,
                "ClassDeclaration[superClass], ClassExpression[superClass]"(node) {
                    const classToken = sourceCode.getFirstToken(node);
                    const extendsToken = sourceCode.getTokenBefore(node.superClass, astUtils.isNotOpeningParenToken);
                    offsets.setDesiredOffsets([extendsToken.range[0], node.body.range[0]], classToken, 1);
                },
                ConditionalExpression(node) {
                    const firstToken = sourceCode.getFirstToken(node);
                    // `flatTernaryExpressions` option is for the following style:
                    // var a =
                    //     foo > 0 ? bar :
                    //     foo < 0 ? baz :
                    //     /*else*/ qiz ;
                    if (!options.flatTernaryExpressions ||
                        !astUtils.isTokenOnSameLine(node.test, node.consequent) ||
                        isOnFirstLineOfStatement(firstToken, node)) {
                        const questionMarkToken = sourceCode.getFirstTokenBetween(node.test, node.consequent, token => token.type === "Punctuator" && token.value === "?");
                        const colonToken = sourceCode.getFirstTokenBetween(node.consequent, node.alternate, token => token.type === "Punctuator" && token.value === ":");
                        const firstConsequentToken = sourceCode.getTokenAfter(questionMarkToken);
                        const lastConsequentToken = sourceCode.getTokenBefore(colonToken);
                        const firstAlternateToken = sourceCode.getTokenAfter(colonToken);
                        offsets.setDesiredOffset(questionMarkToken, firstToken, 1);
                        offsets.setDesiredOffset(colonToken, firstToken, 1);
                        offsets.setDesiredOffset(firstConsequentToken, firstToken, firstConsequentToken.type === "Punctuator" &&
                            options.offsetTernaryExpressions ? 2 : 1);
                        /*
                         * The alternate and the consequent should usually have the same indentation.
                         * If they share part of a line, align the alternate against the first token of the consequent.
                         * This allows the alternate to be indented correctly in cases like this:
                         * foo ? (
                         *   bar
                         * ) : ( // this '(' is aligned with the '(' above, so it's considered to be aligned with `foo`
                         *   baz // as a result, `baz` is offset by 1 rather than 2
                         * )
                         */
                        if (lastConsequentToken.loc.end.line === firstAlternateToken.loc.start.line) {
                            offsets.setDesiredOffset(firstAlternateToken, firstConsequentToken, 0);
                        }
                        else {
                            /**
                             * If the alternate and consequent do not share part of a line, offset the alternate from the first
                             * token of the conditional expression. For example:
                             * foo ? bar
                             *   : baz
                             *
                             * If `baz` were aligned with `bar` rather than being offset by 1 from `foo`, `baz` would end up
                             * having no expected indentation.
                             */
                            offsets.setDesiredOffset(firstAlternateToken, firstToken, firstAlternateToken.type === "Punctuator" &&
                                options.offsetTernaryExpressions ? 2 : 1);
                        }
                    }
                },
                "DoWhileStatement, WhileStatement, ForInStatement, ForOfStatement, WithStatement": node => addBlocklessNodeIndent(node.body),
                ExportNamedDeclaration(node) {
                    if (node.declaration === null) {
                        const closingCurly = sourceCode.getLastToken(node, astUtils.isClosingBraceToken);
                        // Indent the specifiers in `export {foo, bar, baz}`
                        addElementListIndent(node.specifiers, sourceCode.getFirstToken(node, { skip: 1 }), closingCurly, 1);
                        if (node.source) {
                            // Indent everything after and including the `from` token in `export {foo, bar, baz} from 'qux'`
                            offsets.setDesiredOffsets([closingCurly.range[1], node.range[1]], sourceCode.getFirstToken(node), 1);
                        }
                    }
                },
                ForStatement(node) {
                    const forOpeningParen = sourceCode.getFirstToken(node, 1);
                    if (node.init) {
                        offsets.setDesiredOffsets(node.init.range, forOpeningParen, 1);
                    }
                    if (node.test) {
                        offsets.setDesiredOffsets(node.test.range, forOpeningParen, 1);
                    }
                    if (node.update) {
                        offsets.setDesiredOffsets(node.update.range, forOpeningParen, 1);
                    }
                    addBlocklessNodeIndent(node.body);
                },
                "FunctionDeclaration, FunctionExpression"(node) {
                    const closingParen = sourceCode.getTokenBefore(node.body);
                    const openingParen = sourceCode.getTokenBefore(node.params.length ? node.params[0] : closingParen);
                    parameterParens.add(openingParen);
                    parameterParens.add(closingParen);
                    addElementListIndent(node.params, openingParen, closingParen, options[node.type].parameters);
                },
                IfStatement(node) {
                    addBlocklessNodeIndent(node.consequent);
                    if (node.alternate && node.alternate.type !== "IfStatement") {
                        addBlocklessNodeIndent(node.alternate);
                    }
                },
                /*
                 * For blockless nodes with semicolon-first style, don't indent the semicolon.
                 * e.g.
                 * if (foo)
                 *     bar()
                 * ; [1, 2, 3].map(foo)
                 *
                 * Traversal into the node sets indentation of the semicolon, so we need to override it on exit.
                 */
                ":matches(DoWhileStatement, ForStatement, ForInStatement, ForOfStatement, IfStatement, WhileStatement, WithStatement):exit"(node) {
                    let nodesToCheck;
                    if (node.type === "IfStatement") {
                        nodesToCheck = [node.consequent];
                        if (node.alternate) {
                            nodesToCheck.push(node.alternate);
                        }
                    }
                    else {
                        nodesToCheck = [node.body];
                    }
                    for (const nodeToCheck of nodesToCheck) {
                        const lastToken = sourceCode.getLastToken(nodeToCheck);
                        if (astUtils.isSemicolonToken(lastToken)) {
                            const tokenBeforeLast = sourceCode.getTokenBefore(lastToken);
                            const tokenAfterLast = sourceCode.getTokenAfter(lastToken);
                            // override indentation of `;` only if its line looks like a semicolon-first style line
                            if (!astUtils.isTokenOnSameLine(tokenBeforeLast, lastToken) &&
                                tokenAfterLast &&
                                astUtils.isTokenOnSameLine(lastToken, tokenAfterLast)) {
                                offsets.setDesiredOffset(lastToken, sourceCode.getFirstToken(node), 0);
                            }
                        }
                    }
                },
                ImportDeclaration(node) {
                    if (node.specifiers.some(specifier => specifier.type === "ImportSpecifier")) {
                        const openingCurly = sourceCode.getFirstToken(node, astUtils.isOpeningBraceToken);
                        const closingCurly = sourceCode.getLastToken(node, astUtils.isClosingBraceToken);
                        addElementListIndent(node.specifiers.filter(specifier => specifier.type === "ImportSpecifier"), openingCurly, closingCurly, options.ImportDeclaration);
                    }
                    const fromToken = sourceCode.getLastToken(node, token => token.type === "Identifier" && token.value === "from");
                    const sourceToken = sourceCode.getLastToken(node, token => token.type === "String");
                    const semiToken = sourceCode.getLastToken(node, token => token.type === "Punctuator" && token.value === ";");
                    if (fromToken) {
                        const end = semiToken && semiToken.range[1] === sourceToken.range[1] ? node.range[1] : sourceToken.range[1];
                        offsets.setDesiredOffsets([fromToken.range[0], end], sourceCode.getFirstToken(node), 1);
                    }
                },
                ImportExpression(node) {
                    const openingParen = sourceCode.getFirstToken(node, 1);
                    const closingParen = sourceCode.getLastToken(node);
                    parameterParens.add(openingParen);
                    parameterParens.add(closingParen);
                    offsets.setDesiredOffset(openingParen, sourceCode.getTokenBefore(openingParen), 0);
                    addElementListIndent([node.source], openingParen, closingParen, options.CallExpression.arguments);
                },
                "MemberExpression, JSXMemberExpression, MetaProperty"(node) {
                    const object = node.type === "MetaProperty" ? node.meta : node.object;
                    const firstNonObjectToken = sourceCode.getFirstTokenBetween(object, node.property, astUtils.isNotClosingParenToken);
                    const secondNonObjectToken = sourceCode.getTokenAfter(firstNonObjectToken);
                    const objectParenCount = sourceCode.getTokensBetween(object, node.property, { filter: astUtils.isClosingParenToken }).length;
                    const firstObjectToken = objectParenCount
                        ? sourceCode.getTokenBefore(object, { skip: objectParenCount - 1 })
                        : sourceCode.getFirstToken(object);
                    const lastObjectToken = sourceCode.getTokenBefore(firstNonObjectToken);
                    const firstPropertyToken = node.computed ? firstNonObjectToken : secondNonObjectToken;
                    if (node.computed) {
                        // For computed MemberExpressions, match the closing bracket with the opening bracket.
                        offsets.setDesiredOffset(sourceCode.getLastToken(node), firstNonObjectToken, 0);
                        offsets.setDesiredOffsets(node.property.range, firstNonObjectToken, 1);
                    }
                    /*
                     * If the object ends on the same line that the property starts, match against the last token
                     * of the object, to ensure that the MemberExpression is not indented.
                     *
                     * Otherwise, match against the first token of the object, e.g.
                     * foo
                     *   .bar
                     *   .baz // <-- offset by 1 from `foo`
                     */
                    const offsetBase = lastObjectToken.loc.end.line === firstPropertyToken.loc.start.line
                        ? lastObjectToken
                        : firstObjectToken;
                    if (typeof options.MemberExpression === "number") {
                        // Match the dot (for non-computed properties) or the opening bracket (for computed properties) against the object.
                        offsets.setDesiredOffset(firstNonObjectToken, offsetBase, options.MemberExpression);
                        /*
                         * For computed MemberExpressions, match the first token of the property against the opening bracket.
                         * Otherwise, match the first token of the property against the object.
                         */
                        offsets.setDesiredOffset(secondNonObjectToken, node.computed ? firstNonObjectToken : offsetBase, options.MemberExpression);
                    }
                    else {
                        // If the MemberExpression option is off, ignore the dot and the first token of the property.
                        offsets.ignoreToken(firstNonObjectToken);
                        offsets.ignoreToken(secondNonObjectToken);
                        // To ignore the property indentation, ensure that the property tokens depend on the ignored tokens.
                        offsets.setDesiredOffset(firstNonObjectToken, offsetBase, 0);
                        offsets.setDesiredOffset(secondNonObjectToken, firstNonObjectToken, 0);
                    }
                },
                NewExpression(node) {
                    // Only indent the arguments if the NewExpression has parens (e.g. `new Foo(bar)` or `new Foo()`, but not `new Foo`
                    if (node.arguments.length > 0 ||
                        astUtils.isClosingParenToken(sourceCode.getLastToken(node)) &&
                            astUtils.isOpeningParenToken(sourceCode.getLastToken(node, 1))) {
                        addFunctionCallIndent(node);
                    }
                },
                Property(node) {
                    if (!node.shorthand && !node.method && node.kind === "init") {
                        const colon = sourceCode.getFirstTokenBetween(node.key, node.value, astUtils.isColonToken);
                        offsets.ignoreToken(sourceCode.getTokenAfter(colon));
                    }
                },
                PropertyDefinition(node) {
                    const firstToken = sourceCode.getFirstToken(node);
                    const maybeSemicolonToken = sourceCode.getLastToken(node);
                    let keyLastToken = null;
                    // Indent key.
                    if (node.computed) {
                        const bracketTokenL = sourceCode.getTokenBefore(node.key, astUtils.isOpeningBracketToken);
                        const bracketTokenR = keyLastToken = sourceCode.getTokenAfter(node.key, astUtils.isClosingBracketToken);
                        const keyRange = [bracketTokenL.range[1], bracketTokenR.range[0]];
                        if (bracketTokenL !== firstToken) {
                            offsets.setDesiredOffset(bracketTokenL, firstToken, 0);
                        }
                        offsets.setDesiredOffsets(keyRange, bracketTokenL, 1);
                        offsets.setDesiredOffset(bracketTokenR, bracketTokenL, 0);
                    }
                    else {
                        const idToken = keyLastToken = sourceCode.getFirstToken(node.key);
                        if (idToken !== firstToken) {
                            offsets.setDesiredOffset(idToken, firstToken, 1);
                        }
                    }
                    // Indent initializer.
                    if (node.value) {
                        const eqToken = sourceCode.getTokenBefore(node.value, astUtils.isEqToken);
                        const valueToken = sourceCode.getTokenAfter(eqToken);
                        offsets.setDesiredOffset(eqToken, keyLastToken, 1);
                        offsets.setDesiredOffset(valueToken, eqToken, 1);
                        if (astUtils.isSemicolonToken(maybeSemicolonToken)) {
                            offsets.setDesiredOffset(maybeSemicolonToken, eqToken, 1);
                        }
                    }
                    else if (astUtils.isSemicolonToken(maybeSemicolonToken)) {
                        offsets.setDesiredOffset(maybeSemicolonToken, keyLastToken, 1);
                    }
                },
                StaticBlock(node) {
                    const openingCurly = sourceCode.getFirstToken(node, { skip: 1 }); // skip the `static` token
                    const closingCurly = sourceCode.getLastToken(node);
                    addElementListIndent(node.body, openingCurly, closingCurly, options.StaticBlock.body);
                },
                SwitchStatement(node) {
                    const openingCurly = sourceCode.getTokenAfter(node.discriminant, astUtils.isOpeningBraceToken);
                    const closingCurly = sourceCode.getLastToken(node);
                    offsets.setDesiredOffsets([openingCurly.range[1], closingCurly.range[0]], openingCurly, options.SwitchCase);
                    if (node.cases.length) {
                        sourceCode.getTokensBetween(node.cases[node.cases.length - 1], closingCurly, { includeComments: true, filter: astUtils.isCommentToken }).forEach(token => offsets.ignoreToken(token));
                    }
                },
                SwitchCase(node) {
                    if (!(node.consequent.length === 1 && node.consequent[0].type === "BlockStatement")) {
                        const caseKeyword = sourceCode.getFirstToken(node);
                        const tokenAfterCurrentCase = sourceCode.getTokenAfter(node);
                        offsets.setDesiredOffsets([caseKeyword.range[1], tokenAfterCurrentCase.range[0]], caseKeyword, 1);
                    }
                },
                TemplateLiteral(node) {
                    node.expressions.forEach((expression, index) => {
                        const previousQuasi = node.quasis[index];
                        const nextQuasi = node.quasis[index + 1];
                        const tokenToAlignFrom = previousQuasi.loc.start.line === previousQuasi.loc.end.line
                            ? sourceCode.getFirstToken(previousQuasi)
                            : null;
                        offsets.setDesiredOffsets([previousQuasi.range[1], nextQuasi.range[0]], tokenToAlignFrom, 1);
                        offsets.setDesiredOffset(sourceCode.getFirstToken(nextQuasi), tokenToAlignFrom, 0);
                    });
                },
                VariableDeclaration(node) {
                    let variableIndent = Object.prototype.hasOwnProperty.call(options.VariableDeclarator, node.kind)
                        ? options.VariableDeclarator[node.kind]
                        : DEFAULT_VARIABLE_INDENT;
                    const firstToken = sourceCode.getFirstToken(node), lastToken = sourceCode.getLastToken(node);
                    if (options.VariableDeclarator[node.kind] === "first") {
                        if (node.declarations.length > 1) {
                            addElementListIndent(node.declarations, firstToken, lastToken, "first");
                            return;
                        }
                        variableIndent = DEFAULT_VARIABLE_INDENT;
                    }
                    if (node.declarations[node.declarations.length - 1].loc.start.line > node.loc.start.line) {
                        /*
                         * VariableDeclarator indentation is a bit different from other forms of indentation, in that the
                         * indentation of an opening bracket sometimes won't match that of a closing bracket. For example,
                         * the following indentations are correct:
                         *
                         * var foo = {
                         *   ok: true
                         * };
                         *
                         * var foo = {
                         *     ok: true,
                         *   },
                         *   bar = 1;
                         *
                         * Account for when exiting the AST (after indentations have already been set for the nodes in
                         * the declaration) by manually increasing the indentation level of the tokens in this declarator
                         * on the same line as the start of the declaration, provided that there are declarators that
                         * follow this one.
                         */
                        offsets.setDesiredOffsets(node.range, firstToken, variableIndent, true);
                    }
                    else {
                        offsets.setDesiredOffsets(node.range, firstToken, variableIndent);
                    }
                    if (astUtils.isSemicolonToken(lastToken)) {
                        offsets.ignoreToken(lastToken);
                    }
                },
                VariableDeclarator(node) {
                    if (node.init) {
                        const equalOperator = sourceCode.getTokenBefore(node.init, astUtils.isNotOpeningParenToken);
                        const tokenAfterOperator = sourceCode.getTokenAfter(equalOperator);
                        offsets.ignoreToken(equalOperator);
                        offsets.ignoreToken(tokenAfterOperator);
                        offsets.setDesiredOffsets([tokenAfterOperator.range[0], node.range[1]], equalOperator, 1);
                        offsets.setDesiredOffset(equalOperator, sourceCode.getLastToken(node.id), 0);
                    }
                },
                "JSXAttribute[value]"(node) {
                    const equalsToken = sourceCode.getFirstTokenBetween(node.name, node.value, token => token.type === "Punctuator" && token.value === "=");
                    offsets.setDesiredOffsets([equalsToken.range[0], node.value.range[1]], sourceCode.getFirstToken(node.name), 1);
                },
                JSXElement(node) {
                    if (node.closingElement) {
                        addElementListIndent(node.children, sourceCode.getFirstToken(node.openingElement), sourceCode.getFirstToken(node.closingElement), 1);
                    }
                },
                JSXOpeningElement(node) {
                    const firstToken = sourceCode.getFirstToken(node);
                    let closingToken;
                    if (node.selfClosing) {
                        closingToken = sourceCode.getLastToken(node, { skip: 1 });
                        offsets.setDesiredOffset(sourceCode.getLastToken(node), closingToken, 0);
                    }
                    else {
                        closingToken = sourceCode.getLastToken(node);
                    }
                    offsets.setDesiredOffsets(node.name.range, sourceCode.getFirstToken(node));
                    addElementListIndent(node.attributes, firstToken, closingToken, 1);
                },
                JSXClosingElement(node) {
                    const firstToken = sourceCode.getFirstToken(node);
                    offsets.setDesiredOffsets(node.name.range, firstToken, 1);
                },
                JSXFragment(node) {
                    const firstOpeningToken = sourceCode.getFirstToken(node.openingFragment);
                    const firstClosingToken = sourceCode.getFirstToken(node.closingFragment);
                    addElementListIndent(node.children, firstOpeningToken, firstClosingToken, 1);
                },
                JSXOpeningFragment(node) {
                    const firstToken = sourceCode.getFirstToken(node);
                    const closingToken = sourceCode.getLastToken(node);
                    offsets.setDesiredOffsets(node.range, firstToken, 1);
                    offsets.matchOffsetOf(firstToken, closingToken);
                },
                JSXClosingFragment(node) {
                    const firstToken = sourceCode.getFirstToken(node);
                    const slashToken = sourceCode.getLastToken(node, { skip: 1 });
                    const closingToken = sourceCode.getLastToken(node);
                    const tokenToMatch = astUtils.isTokenOnSameLine(slashToken, closingToken) ? slashToken : closingToken;
                    offsets.setDesiredOffsets(node.range, firstToken, 1);
                    offsets.matchOffsetOf(firstToken, tokenToMatch);
                },
                JSXExpressionContainer(node) {
                    const openingCurly = sourceCode.getFirstToken(node);
                    const closingCurly = sourceCode.getLastToken(node);
                    offsets.setDesiredOffsets([openingCurly.range[1], closingCurly.range[0]], openingCurly, 1);
                },
                JSXSpreadAttribute(node) {
                    const openingCurly = sourceCode.getFirstToken(node);
                    const closingCurly = sourceCode.getLastToken(node);
                    offsets.setDesiredOffsets([openingCurly.range[1], closingCurly.range[0]], openingCurly, 1);
                },
                "*"(node) {
                    const firstToken = sourceCode.getFirstToken(node);
                    // Ensure that the children of every node are indented at least as much as the first token.
                    if (firstToken && !ignoredNodeFirstTokens.has(firstToken)) {
                        offsets.setDesiredOffsets(node.range, firstToken, 0);
                    }
                }
            };
            const listenerCallQueue = [];
            /*
             * To ignore the indentation of a node:
             * 1. Don't call the node's listener when entering it (if it has a listener)
             * 2. Don't set any offsets against the first token of the node.
             * 3. Call `ignoreNode` on the node sometime after exiting it and before validating offsets.
             */
            const offsetListeners = {};
            for (const [selector, listener] of Object.entries(baseOffsetListeners)) {
                /*
                 * Offset listener calls are deferred until traversal is finished, and are called as
                 * part of the final `Program:exit` listener. This is necessary because a node might
                 * be matched by multiple selectors.
                 *
                 * Example: Suppose there is an offset listener for `Identifier`, and the user has
                 * specified in configuration that `MemberExpression > Identifier` should be ignored.
                 * Due to selector specificity rules, the `Identifier` listener will get called first. However,
                 * if a given Identifier node is supposed to be ignored, then the `Identifier` offset listener
                 * should not have been called at all. Without doing extra selector matching, we don't know
                 * whether the Identifier matches the `MemberExpression > Identifier` selector until the
                 * `MemberExpression > Identifier` listener is called.
                 *
                 * To avoid this, the `Identifier` listener isn't called until traversal finishes and all
                 * ignored nodes are known.
                 */
                offsetListeners[selector] = node => listenerCallQueue.push({ listener, node });
            }
            // For each ignored node selector, set up a listener to collect it into the `ignoredNodes` set.
            const ignoredNodes = new Set();
            /**
             * Ignores a node
             * @param {ASTNode} node The node to ignore
             * @returns {void}
             */
            function addToIgnoredNodes(node) {
                ignoredNodes.add(node);
                ignoredNodeFirstTokens.add(sourceCode.getFirstToken(node));
            }
            const ignoredNodeListeners = options.ignoredNodes.reduce((listeners, ignoredSelector) => Object.assign(listeners, { [ignoredSelector]: addToIgnoredNodes }), {});
            /*
             * Join the listeners, and add a listener to verify that all tokens actually have the correct indentation
             * at the end.
             *
             * Using Object.assign will cause some offset listeners to be overwritten if the same selector also appears
             * in `ignoredNodeListeners`. This isn't a problem because all of the matching nodes will be ignored,
             * so those listeners wouldn't be called anyway.
             */
            return Object.assign(offsetListeners, ignoredNodeListeners, {
                "*:exit"(node) {
                    // If a node's type is nonstandard, we can't tell how its children should be offset, so ignore it.
                    if (!KNOWN_NODES.has(node.type)) {
                        addToIgnoredNodes(node);
                    }
                },
                "Program:exit"() {
                    // If ignoreComments option is enabled, ignore all comment tokens.
                    if (options.ignoreComments) {
                        sourceCode.getAllComments()
                            .forEach(comment => offsets.ignoreToken(comment));
                    }
                    // Invoke the queued offset listeners for the nodes that aren't ignored.
                    listenerCallQueue
                        .filter(nodeInfo => !ignoredNodes.has(nodeInfo.node))
                        .forEach(nodeInfo => nodeInfo.listener(nodeInfo.node));
                    // Update the offsets for ignored nodes to prevent their child tokens from being reported.
                    ignoredNodes.forEach(ignoreNode);
                    addParensIndent(sourceCode.ast.tokens);
                    /*
                     * Create a Map from (tokenOrComment) => (precedingToken).
                     * This is necessary because sourceCode.getTokenBefore does not handle a comment as an argument correctly.
                     */
                    const precedingTokens = sourceCode.ast.comments.reduce((commentMap, comment) => {
                        const tokenOrCommentBefore = sourceCode.getTokenBefore(comment, { includeComments: true });
                        return commentMap.set(comment, commentMap.has(tokenOrCommentBefore) ? commentMap.get(tokenOrCommentBefore) : tokenOrCommentBefore);
                    }, new WeakMap());
                    sourceCode.lines.forEach((line, lineIndex) => {
                        const lineNumber = lineIndex + 1;
                        if (!tokenInfo.firstTokensByLineNumber.has(lineNumber)) {
                            // Don't check indentation on blank lines
                            return;
                        }
                        const firstTokenOfLine = tokenInfo.firstTokensByLineNumber.get(lineNumber);
                        if (firstTokenOfLine.loc.start.line !== lineNumber) {
                            // Don't check the indentation of multi-line tokens (e.g. template literals or block comments) twice.
                            return;
                        }
                        if (astUtils.isCommentToken(firstTokenOfLine)) {
                            const tokenBefore = precedingTokens.get(firstTokenOfLine);
                            const tokenAfter = tokenBefore ? sourceCode.getTokenAfter(tokenBefore) : sourceCode.ast.tokens[0];
                            const mayAlignWithBefore = tokenBefore && !hasBlankLinesBetween(tokenBefore, firstTokenOfLine);
                            const mayAlignWithAfter = tokenAfter && !hasBlankLinesBetween(firstTokenOfLine, tokenAfter);
                            /*
                             * If a comment precedes a line that begins with a semicolon token, align to that token, i.e.
                             *
                             * let foo
                             * // comment
                             * ;(async () => {})()
                             */
                            if (tokenAfter && astUtils.isSemicolonToken(tokenAfter) && !astUtils.isTokenOnSameLine(firstTokenOfLine, tokenAfter)) {
                                offsets.setDesiredOffset(firstTokenOfLine, tokenAfter, 0);
                            }
                            // If a comment matches the expected indentation of the token immediately before or after, don't report it.
                            if (mayAlignWithBefore && validateTokenIndent(firstTokenOfLine, offsets.getDesiredIndent(tokenBefore)) ||
                                mayAlignWithAfter && validateTokenIndent(firstTokenOfLine, offsets.getDesiredIndent(tokenAfter))) {
                                return;
                            }
                        }
                        // If the token matches the expected indentation, don't report it.
                        if (validateTokenIndent(firstTokenOfLine, offsets.getDesiredIndent(firstTokenOfLine))) {
                            return;
                        }
                        // Otherwise, report the token/comment.
                        report(firstTokenOfLine, offsets.getDesiredIndent(firstTokenOfLine));
                    });
                }
            });
        }
    };
},
/* js-sdsl/dist/cjs/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    Object.defineProperty(exports, "Deque", {
        enumerable: true,
        get: function () {
            return _Deque.default;
        }
    });
    Object.defineProperty(exports, "HashMap", {
        enumerable: true,
        get: function () {
            return _HashMap.default;
        }
    });
    Object.defineProperty(exports, "HashSet", {
        enumerable: true,
        get: function () {
            return _HashSet.default;
        }
    });
    Object.defineProperty(exports, "LinkList", {
        enumerable: true,
        get: function () {
            return _LinkList.default;
        }
    });
    Object.defineProperty(exports, "OrderedMap", {
        enumerable: true,
        get: function () {
            return _OrderedMap.default;
        }
    });
    Object.defineProperty(exports, "OrderedSet", {
        enumerable: true,
        get: function () {
            return _OrderedSet.default;
        }
    });
    Object.defineProperty(exports, "PriorityQueue", {
        enumerable: true,
        get: function () {
            return _PriorityQueue.default;
        }
    });
    Object.defineProperty(exports, "Queue", {
        enumerable: true,
        get: function () {
            return _Queue.default;
        }
    });
    Object.defineProperty(exports, "Stack", {
        enumerable: true,
        get: function () {
            return _Stack.default;
        }
    });
    Object.defineProperty(exports, "Vector", {
        enumerable: true,
        get: function () {
            return _Vector.default;
        }
    });
    var _Stack = _interopRequireDefault(require(419) /* ./container/OtherContainer/Stack */);
    var _Queue = _interopRequireDefault(require(421) /* ./container/OtherContainer/Queue */);
    var _PriorityQueue = _interopRequireDefault(require(422) /* ./container/OtherContainer/PriorityQueue */);
    var _Vector = _interopRequireDefault(require(423) /* ./container/SequentialContainer/Vector */);
    var _LinkList = _interopRequireDefault(require(427) /* ./container/SequentialContainer/LinkList */);
    var _Deque = _interopRequireDefault(require(428) /* ./container/SequentialContainer/Deque */);
    var _OrderedSet = _interopRequireDefault(require(429) /* ./container/TreeContainer/OrderedSet */);
    var _OrderedMap = _interopRequireDefault(require(433) /* ./container/TreeContainer/OrderedMap */);
    var _HashSet = _interopRequireDefault(require(434) /* ./container/HashContainer/HashSet */);
    var _HashMap = _interopRequireDefault(require(437) /* ./container/HashContainer/HashMap */);
    function _interopRequireDefault(e) {
        return e && e.t ? e : {
            default: e
        };
    }
    
},
/* js-sdsl/dist/cjs/container/OtherContainer/Stack.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _ContainerBase = require(420) /* ../ContainerBase */;
    class Stack extends _ContainerBase.Base {
        constructor(t = []) {
            super();
            this.S = [];
            const s = this;
            t.forEach((function (t) {
                s.push(t);
            }));
        }
        clear() {
            this.i = 0;
            this.S = [];
        }
        push(t) {
            this.S.push(t);
            this.i += 1;
            return this.i;
        }
        pop() {
            if (this.i === 0)
                return;
            this.i -= 1;
            return this.S.pop();
        }
        top() {
            return this.S[this.i - 1];
        }
    }
    var _default = Stack;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/ContainerBase/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.ContainerIterator = exports.Container = exports.Base = void 0;
    class ContainerIterator {
        constructor(t = 0) {
            this.iteratorType = t;
        }
        equals(t) {
            return this.o === t.o;
        }
    }
    exports.ContainerIterator = ContainerIterator;
    class Base {
        constructor() {
            this.i = 0;
        }
        get length() {
            return this.i;
        }
        size() {
            return this.i;
        }
        empty() {
            return this.i === 0;
        }
    }
    exports.Base = Base;
    class Container extends Base {
    }
    exports.Container = Container;
    
},
/* js-sdsl/dist/cjs/container/OtherContainer/Queue.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _ContainerBase = require(420) /* ../ContainerBase */;
    class Queue extends _ContainerBase.Base {
        constructor(t = []) {
            super();
            this.j = 0;
            this.q = [];
            const s = this;
            t.forEach((function (t) {
                s.push(t);
            }));
        }
        clear() {
            this.q = [];
            this.i = this.j = 0;
        }
        push(t) {
            const s = this.q.length;
            if (this.j / s > .5 && this.j + this.i >= s && s > 4096) {
                const s = this.i;
                for (let t = 0; t < s; ++t) {
                    this.q[t] = this.q[this.j + t];
                }
                this.j = 0;
                this.q[this.i] = t;
            }
            else
                this.q[this.j + this.i] = t;
            return ++this.i;
        }
        pop() {
            if (this.i === 0)
                return;
            const t = this.q[this.j++];
            this.i -= 1;
            return t;
        }
        front() {
            if (this.i === 0)
                return;
            return this.q[this.j];
        }
    }
    var _default = Queue;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/OtherContainer/PriorityQueue.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _ContainerBase = require(420) /* ../ContainerBase */;
    class PriorityQueue extends _ContainerBase.Base {
        constructor(t = [], s = function (t, s) {
            if (t > s)
                return -1;
            if (t < s)
                return 1;
            return 0;
        }, i = true) {
            super();
            this.v = s;
            if (Array.isArray(t)) {
                this.C = i ? [...t] : t;
            }
            else {
                this.C = [];
                const s = this;
                t.forEach((function (t) {
                    s.C.push(t);
                }));
            }
            this.i = this.C.length;
            const e = this.i >> 1;
            for (let t = this.i - 1 >> 1; t >= 0; --t) {
                this.k(t, e);
            }
        }
        m(t) {
            const s = this.C[t];
            while (t > 0) {
                const i = t - 1 >> 1;
                const e = this.C[i];
                if (this.v(e, s) <= 0)
                    break;
                this.C[t] = e;
                t = i;
            }
            this.C[t] = s;
        }
        k(t, s) {
            const i = this.C[t];
            while (t < s) {
                let s = t << 1 | 1;
                const e = s + 1;
                let h = this.C[s];
                if (e < this.i && this.v(h, this.C[e]) > 0) {
                    s = e;
                    h = this.C[e];
                }
                if (this.v(h, i) >= 0)
                    break;
                this.C[t] = h;
                t = s;
            }
            this.C[t] = i;
        }
        clear() {
            this.i = 0;
            this.C.length = 0;
        }
        push(t) {
            this.C.push(t);
            this.m(this.i);
            this.i += 1;
        }
        pop() {
            if (this.i === 0)
                return;
            const t = this.C[0];
            const s = this.C.pop();
            this.i -= 1;
            if (this.i) {
                this.C[0] = s;
                this.k(0, this.i >> 1);
            }
            return t;
        }
        top() {
            return this.C[0];
        }
        find(t) {
            return this.C.indexOf(t) >= 0;
        }
        remove(t) {
            const s = this.C.indexOf(t);
            if (s < 0)
                return false;
            if (s === 0) {
                this.pop();
            }
            else if (s === this.i - 1) {
                this.C.pop();
                this.i -= 1;
            }
            else {
                this.C.splice(s, 1, this.C.pop());
                this.i -= 1;
                this.m(s);
                this.k(s, this.i >> 1);
            }
            return true;
        }
        updateItem(t) {
            const s = this.C.indexOf(t);
            if (s < 0)
                return false;
            this.m(s);
            this.k(s, this.i >> 1);
            return true;
        }
        toArray() {
            return [...this.C];
        }
    }
    var _default = PriorityQueue;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/SequentialContainer/Vector.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require(424) /* ./Base */);
    var _RandomIterator = require(425) /* ./Base/RandomIterator */;
    function _interopRequireDefault(t) {
        return t && t.t ? t : {
            default: t
        };
    }
    class VectorIterator extends _RandomIterator.RandomIterator {
        constructor(t, r, e) {
            super(t, e);
            this.container = r;
        }
        copy() {
            return new VectorIterator(this.o, this.container, this.iteratorType);
        }
    }
    class Vector extends _Base.default {
        constructor(t = [], r = true) {
            super();
            if (Array.isArray(t)) {
                this.J = r ? [...t] : t;
                this.i = t.length;
            }
            else {
                this.J = [];
                const r = this;
                t.forEach((function (t) {
                    r.pushBack(t);
                }));
            }
        }
        clear() {
            this.i = 0;
            this.J.length = 0;
        }
        begin() {
            return new VectorIterator(0, this);
        }
        end() {
            return new VectorIterator(this.i, this);
        }
        rBegin() {
            return new VectorIterator(this.i - 1, this, 1);
        }
        rEnd() {
            return new VectorIterator(-1, this, 1);
        }
        front() {
            return this.J[0];
        }
        back() {
            return this.J[this.i - 1];
        }
        getElementByPos(t) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            return this.J[t];
        }
        eraseElementByPos(t) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            this.J.splice(t, 1);
            this.i -= 1;
            return this.i;
        }
        eraseElementByValue(t) {
            let r = 0;
            for (let e = 0; e < this.i; ++e) {
                if (this.J[e] !== t) {
                    this.J[r++] = this.J[e];
                }
            }
            this.i = this.J.length = r;
            return this.i;
        }
        eraseElementByIterator(t) {
            const r = t.o;
            t = t.next();
            this.eraseElementByPos(r);
            return t;
        }
        pushBack(t) {
            this.J.push(t);
            this.i += 1;
            return this.i;
        }
        popBack() {
            if (this.i === 0)
                return;
            this.i -= 1;
            return this.J.pop();
        }
        setElementByPos(t, r) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            this.J[t] = r;
        }
        insert(t, r, e = 1) {
            if (t < 0 || t > this.i) {
                throw new RangeError;
            }
            this.J.splice(t, 0, ...new Array(e).fill(r));
            this.i += e;
            return this.i;
        }
        find(t) {
            for (let r = 0; r < this.i; ++r) {
                if (this.J[r] === t) {
                    return new VectorIterator(r, this);
                }
            }
            return this.end();
        }
        reverse() {
            this.J.reverse();
        }
        unique() {
            let t = 1;
            for (let r = 1; r < this.i; ++r) {
                if (this.J[r] !== this.J[r - 1]) {
                    this.J[t++] = this.J[r];
                }
            }
            this.i = this.J.length = t;
            return this.i;
        }
        sort(t) {
            this.J.sort(t);
        }
        forEach(t) {
            for (let r = 0; r < this.i; ++r) {
                t(this.J[r], r, this);
            }
        }
        [Symbol.iterator]() {
            return function* () {
                yield* this.J;
            }.bind(this)();
        }
    }
    var _default = Vector;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/SequentialContainer/Base/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _ContainerBase = require(420) /* ../../ContainerBase */;
    class SequentialContainer extends _ContainerBase.Container {
    }
    var _default = SequentialContainer;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/SequentialContainer/Base/RandomIterator.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.RandomIterator = void 0;
    var _ContainerBase = require(420) /* ../../ContainerBase */;
    var _throwError = require(426) /* ../../../utils/throwError */;
    class RandomIterator extends _ContainerBase.ContainerIterator {
        constructor(t, r) {
            super(r);
            this.o = t;
            if (this.iteratorType === 0) {
                this.pre = function () {
                    if (this.o === 0) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o -= 1;
                    return this;
                };
                this.next = function () {
                    if (this.o === this.container.size()) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o += 1;
                    return this;
                };
            }
            else {
                this.pre = function () {
                    if (this.o === this.container.size() - 1) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o += 1;
                    return this;
                };
                this.next = function () {
                    if (this.o === -1) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o -= 1;
                    return this;
                };
            }
        }
        get pointer() {
            return this.container.getElementByPos(this.o);
        }
        set pointer(t) {
            this.container.setElementByPos(this.o, t);
        }
    }
    exports.RandomIterator = RandomIterator;
    
},
/* js-sdsl/dist/cjs/utils/throwError.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.throwIteratorAccessError = throwIteratorAccessError;
    function throwIteratorAccessError() {
        throw new RangeError("Iterator access denied!");
    }
    
},
/* js-sdsl/dist/cjs/container/SequentialContainer/LinkList.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require(424) /* ./Base */);
    var _ContainerBase = require(420) /* ../ContainerBase */;
    var _throwError = require(426) /* ../../utils/throwError */;
    function _interopRequireDefault(t) {
        return t && t.t ? t : {
            default: t
        };
    }
    class LinkListIterator extends _ContainerBase.ContainerIterator {
        constructor(t, i, s, r) {
            super(r);
            this.o = t;
            this.h = i;
            this.container = s;
            if (this.iteratorType === 0) {
                this.pre = function () {
                    if (this.o.L === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.L;
                    return this;
                };
                this.next = function () {
                    if (this.o === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.B;
                    return this;
                };
            }
            else {
                this.pre = function () {
                    if (this.o.B === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.B;
                    return this;
                };
                this.next = function () {
                    if (this.o === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.L;
                    return this;
                };
            }
        }
        get pointer() {
            if (this.o === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            return this.o.l;
        }
        set pointer(t) {
            if (this.o === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            this.o.l = t;
        }
        copy() {
            return new LinkListIterator(this.o, this.h, this.container, this.iteratorType);
        }
    }
    class LinkList extends _Base.default {
        constructor(t = []) {
            super();
            this.h = {};
            this.p = this._ = this.h.L = this.h.B = this.h;
            const i = this;
            t.forEach((function (t) {
                i.pushBack(t);
            }));
        }
        V(t) {
            const { L: i, B: s } = t;
            i.B = s;
            s.L = i;
            if (t === this.p) {
                this.p = s;
            }
            if (t === this._) {
                this._ = i;
            }
            this.i -= 1;
        }
        G(t, i) {
            const s = i.B;
            const r = {
                l: t,
                L: i,
                B: s
            };
            i.B = r;
            s.L = r;
            if (i === this.h) {
                this.p = r;
            }
            if (s === this.h) {
                this._ = r;
            }
            this.i += 1;
        }
        clear() {
            this.i = 0;
            this.p = this._ = this.h.L = this.h.B = this.h;
        }
        begin() {
            return new LinkListIterator(this.p, this.h, this);
        }
        end() {
            return new LinkListIterator(this.h, this.h, this);
        }
        rBegin() {
            return new LinkListIterator(this._, this.h, this, 1);
        }
        rEnd() {
            return new LinkListIterator(this.h, this.h, this, 1);
        }
        front() {
            return this.p.l;
        }
        back() {
            return this._.l;
        }
        getElementByPos(t) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            let i = this.p;
            while (t--) {
                i = i.B;
            }
            return i.l;
        }
        eraseElementByPos(t) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            let i = this.p;
            while (t--) {
                i = i.B;
            }
            this.V(i);
            return this.i;
        }
        eraseElementByValue(t) {
            let i = this.p;
            while (i !== this.h) {
                if (i.l === t) {
                    this.V(i);
                }
                i = i.B;
            }
            return this.i;
        }
        eraseElementByIterator(t) {
            const i = t.o;
            if (i === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            t = t.next();
            this.V(i);
            return t;
        }
        pushBack(t) {
            this.G(t, this._);
            return this.i;
        }
        popBack() {
            if (this.i === 0)
                return;
            const t = this._.l;
            this.V(this._);
            return t;
        }
        pushFront(t) {
            this.G(t, this.h);
            return this.i;
        }
        popFront() {
            if (this.i === 0)
                return;
            const t = this.p.l;
            this.V(this.p);
            return t;
        }
        setElementByPos(t, i) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            let s = this.p;
            while (t--) {
                s = s.B;
            }
            s.l = i;
        }
        insert(t, i, s = 1) {
            if (t < 0 || t > this.i) {
                throw new RangeError;
            }
            if (s <= 0)
                return this.i;
            if (t === 0) {
                while (s--)
                    this.pushFront(i);
            }
            else if (t === this.i) {
                while (s--)
                    this.pushBack(i);
            }
            else {
                let r = this.p;
                for (let i = 1; i < t; ++i) {
                    r = r.B;
                }
                const e = r.B;
                this.i += s;
                while (s--) {
                    r.B = {
                        l: i,
                        L: r
                    };
                    r.B.L = r;
                    r = r.B;
                }
                r.B = e;
                e.L = r;
            }
            return this.i;
        }
        find(t) {
            let i = this.p;
            while (i !== this.h) {
                if (i.l === t) {
                    return new LinkListIterator(i, this.h, this);
                }
                i = i.B;
            }
            return this.end();
        }
        reverse() {
            if (this.i <= 1)
                return;
            let t = this.p;
            let i = this._;
            let s = 0;
            while (s << 1 < this.i) {
                const r = t.l;
                t.l = i.l;
                i.l = r;
                t = t.B;
                i = i.L;
                s += 1;
            }
        }
        unique() {
            if (this.i <= 1) {
                return this.i;
            }
            let t = this.p;
            while (t !== this.h) {
                let i = t;
                while (i.B !== this.h && i.l === i.B.l) {
                    i = i.B;
                    this.i -= 1;
                }
                t.B = i.B;
                t.B.L = t;
                t = t.B;
            }
            return this.i;
        }
        sort(t) {
            if (this.i <= 1)
                return;
            const i = [];
            this.forEach((function (t) {
                i.push(t);
            }));
            i.sort(t);
            let s = this.p;
            i.forEach((function (t) {
                s.l = t;
                s = s.B;
            }));
        }
        merge(t) {
            const i = this;
            if (this.i === 0) {
                t.forEach((function (t) {
                    i.pushBack(t);
                }));
            }
            else {
                let s = this.p;
                t.forEach((function (t) {
                    while (s !== i.h && s.l <= t) {
                        s = s.B;
                    }
                    i.G(t, s.L);
                }));
            }
            return this.i;
        }
        forEach(t) {
            let i = this.p;
            let s = 0;
            while (i !== this.h) {
                t(i.l, s++, this);
                i = i.B;
            }
        }
        [Symbol.iterator]() {
            return function* () {
                if (this.i === 0)
                    return;
                let t = this.p;
                while (t !== this.h) {
                    yield t.l;
                    t = t.B;
                }
            }.bind(this)();
        }
    }
    var _default = LinkList;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/SequentialContainer/Deque.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require(424) /* ./Base */);
    var _RandomIterator = require(425) /* ./Base/RandomIterator */;
    function _interopRequireDefault(t) {
        return t && t.t ? t : {
            default: t
        };
    }
    class DequeIterator extends _RandomIterator.RandomIterator {
        constructor(t, i, s) {
            super(t, s);
            this.container = i;
        }
        copy() {
            return new DequeIterator(this.o, this.container, this.iteratorType);
        }
    }
    class Deque extends _Base.default {
        constructor(t = [], i = 1 << 12) {
            super();
            this.j = 0;
            this.D = 0;
            this.R = 0;
            this.N = 0;
            this.P = 0;
            this.A = [];
            const s = (() => {
                if (typeof t.length === "number")
                    return t.length;
                if (typeof t.size === "number")
                    return t.size;
                if (typeof t.size === "function")
                    return t.size();
                throw new TypeError("Cannot get the length or size of the container");
            })();
            this.F = i;
            this.P = Math.max(Math.ceil(s / this.F), 1);
            for (let t = 0; t < this.P; ++t) {
                this.A.push(new Array(this.F));
            }
            const h = Math.ceil(s / this.F);
            this.j = this.R = (this.P >> 1) - (h >> 1);
            this.D = this.N = this.F - s % this.F >> 1;
            const e = this;
            t.forEach((function (t) {
                e.pushBack(t);
            }));
        }
        T() {
            const t = [];
            const i = Math.max(this.P >> 1, 1);
            for (let s = 0; s < i; ++s) {
                t[s] = new Array(this.F);
            }
            for (let i = this.j; i < this.P; ++i) {
                t[t.length] = this.A[i];
            }
            for (let i = 0; i < this.R; ++i) {
                t[t.length] = this.A[i];
            }
            t[t.length] = [...this.A[this.R]];
            this.j = i;
            this.R = t.length - 1;
            for (let s = 0; s < i; ++s) {
                t[t.length] = new Array(this.F);
            }
            this.A = t;
            this.P = t.length;
        }
        O(t) {
            const i = this.D + t + 1;
            const s = i % this.F;
            let h = s - 1;
            let e = this.j + (i - s) / this.F;
            if (s === 0)
                e -= 1;
            e %= this.P;
            if (h < 0)
                h += this.F;
            return {
                curNodeBucketIndex: e,
                curNodePointerIndex: h
            };
        }
        clear() {
            this.A = [new Array(this.F)];
            this.P = 1;
            this.j = this.R = this.i = 0;
            this.D = this.N = this.F >> 1;
        }
        begin() {
            return new DequeIterator(0, this);
        }
        end() {
            return new DequeIterator(this.i, this);
        }
        rBegin() {
            return new DequeIterator(this.i - 1, this, 1);
        }
        rEnd() {
            return new DequeIterator(-1, this, 1);
        }
        front() {
            if (this.i === 0)
                return;
            return this.A[this.j][this.D];
        }
        back() {
            if (this.i === 0)
                return;
            return this.A[this.R][this.N];
        }
        pushBack(t) {
            if (this.i) {
                if (this.N < this.F - 1) {
                    this.N += 1;
                }
                else if (this.R < this.P - 1) {
                    this.R += 1;
                    this.N = 0;
                }
                else {
                    this.R = 0;
                    this.N = 0;
                }
                if (this.R === this.j && this.N === this.D)
                    this.T();
            }
            this.i += 1;
            this.A[this.R][this.N] = t;
            return this.i;
        }
        popBack() {
            if (this.i === 0)
                return;
            const t = this.A[this.R][this.N];
            if (this.i !== 1) {
                if (this.N > 0) {
                    this.N -= 1;
                }
                else if (this.R > 0) {
                    this.R -= 1;
                    this.N = this.F - 1;
                }
                else {
                    this.R = this.P - 1;
                    this.N = this.F - 1;
                }
            }
            this.i -= 1;
            return t;
        }
        pushFront(t) {
            if (this.i) {
                if (this.D > 0) {
                    this.D -= 1;
                }
                else if (this.j > 0) {
                    this.j -= 1;
                    this.D = this.F - 1;
                }
                else {
                    this.j = this.P - 1;
                    this.D = this.F - 1;
                }
                if (this.j === this.R && this.D === this.N)
                    this.T();
            }
            this.i += 1;
            this.A[this.j][this.D] = t;
            return this.i;
        }
        popFront() {
            if (this.i === 0)
                return;
            const t = this.A[this.j][this.D];
            if (this.i !== 1) {
                if (this.D < this.F - 1) {
                    this.D += 1;
                }
                else if (this.j < this.P - 1) {
                    this.j += 1;
                    this.D = 0;
                }
                else {
                    this.j = 0;
                    this.D = 0;
                }
            }
            this.i -= 1;
            return t;
        }
        getElementByPos(t) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            const { curNodeBucketIndex: i, curNodePointerIndex: s } = this.O(t);
            return this.A[i][s];
        }
        setElementByPos(t, i) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            const { curNodeBucketIndex: s, curNodePointerIndex: h } = this.O(t);
            this.A[s][h] = i;
        }
        insert(t, i, s = 1) {
            if (t < 0 || t > this.i) {
                throw new RangeError;
            }
            if (t === 0) {
                while (s--)
                    this.pushFront(i);
            }
            else if (t === this.i) {
                while (s--)
                    this.pushBack(i);
            }
            else {
                const h = [];
                for (let i = t; i < this.i; ++i) {
                    h.push(this.getElementByPos(i));
                }
                this.cut(t - 1);
                for (let t = 0; t < s; ++t)
                    this.pushBack(i);
                for (let t = 0; t < h.length; ++t)
                    this.pushBack(h[t]);
            }
            return this.i;
        }
        cut(t) {
            if (t < 0) {
                this.clear();
                return 0;
            }
            const { curNodeBucketIndex: i, curNodePointerIndex: s } = this.O(t);
            this.R = i;
            this.N = s;
            this.i = t + 1;
            return this.i;
        }
        eraseElementByPos(t) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            if (t === 0)
                this.popFront();
            else if (t === this.i - 1)
                this.popBack();
            else {
                const i = [];
                for (let s = t + 1; s < this.i; ++s) {
                    i.push(this.getElementByPos(s));
                }
                this.cut(t);
                this.popBack();
                const s = this;
                i.forEach((function (t) {
                    s.pushBack(t);
                }));
            }
            return this.i;
        }
        eraseElementByValue(t) {
            if (this.i === 0)
                return 0;
            const i = [];
            for (let s = 0; s < this.i; ++s) {
                const h = this.getElementByPos(s);
                if (h !== t)
                    i.push(h);
            }
            const s = i.length;
            for (let t = 0; t < s; ++t)
                this.setElementByPos(t, i[t]);
            return this.cut(s - 1);
        }
        eraseElementByIterator(t) {
            const i = t.o;
            this.eraseElementByPos(i);
            t = t.next();
            return t;
        }
        find(t) {
            for (let i = 0; i < this.i; ++i) {
                if (this.getElementByPos(i) === t) {
                    return new DequeIterator(i, this);
                }
            }
            return this.end();
        }
        reverse() {
            let t = 0;
            let i = this.i - 1;
            while (t < i) {
                const s = this.getElementByPos(t);
                this.setElementByPos(t, this.getElementByPos(i));
                this.setElementByPos(i, s);
                t += 1;
                i -= 1;
            }
        }
        unique() {
            if (this.i <= 1) {
                return this.i;
            }
            let t = 1;
            let i = this.getElementByPos(0);
            for (let s = 1; s < this.i; ++s) {
                const h = this.getElementByPos(s);
                if (h !== i) {
                    i = h;
                    this.setElementByPos(t++, h);
                }
            }
            while (this.i > t)
                this.popBack();
            return this.i;
        }
        sort(t) {
            const i = [];
            for (let t = 0; t < this.i; ++t) {
                i.push(this.getElementByPos(t));
            }
            i.sort(t);
            for (let t = 0; t < this.i; ++t)
                this.setElementByPos(t, i[t]);
        }
        shrinkToFit() {
            if (this.i === 0)
                return;
            const t = [];
            this.forEach((function (i) {
                t.push(i);
            }));
            this.P = Math.max(Math.ceil(this.i / this.F), 1);
            this.i = this.j = this.R = this.D = this.N = 0;
            this.A = [];
            for (let t = 0; t < this.P; ++t) {
                this.A.push(new Array(this.F));
            }
            for (let i = 0; i < t.length; ++i)
                this.pushBack(t[i]);
        }
        forEach(t) {
            for (let i = 0; i < this.i; ++i) {
                t(this.getElementByPos(i), i, this);
            }
        }
        [Symbol.iterator]() {
            return function* () {
                for (let t = 0; t < this.i; ++t) {
                    yield this.getElementByPos(t);
                }
            }.bind(this)();
        }
    }
    var _default = Deque;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/TreeContainer/OrderedSet.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require(430) /* ./Base */);
    var _TreeIterator = _interopRequireDefault(require(432) /* ./Base/TreeIterator */);
    var _throwError = require(426) /* ../../utils/throwError */;
    function _interopRequireDefault(e) {
        return e && e.t ? e : {
            default: e
        };
    }
    class OrderedSetIterator extends _TreeIterator.default {
        constructor(e, t, r, i) {
            super(e, t, i);
            this.container = r;
        }
        get pointer() {
            if (this.o === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            return this.o.u;
        }
        copy() {
            return new OrderedSetIterator(this.o, this.h, this.container, this.iteratorType);
        }
    }
    class OrderedSet extends _Base.default {
        constructor(e = [], t, r) {
            super(t, r);
            const i = this;
            e.forEach((function (e) {
                i.insert(e);
            }));
        }
        *K(e) {
            if (e === undefined)
                return;
            yield* this.K(e.U);
            yield e.u;
            yield* this.K(e.W);
        }
        begin() {
            return new OrderedSetIterator(this.h.U || this.h, this.h, this);
        }
        end() {
            return new OrderedSetIterator(this.h, this.h, this);
        }
        rBegin() {
            return new OrderedSetIterator(this.h.W || this.h, this.h, this, 1);
        }
        rEnd() {
            return new OrderedSetIterator(this.h, this.h, this, 1);
        }
        front() {
            return this.h.U ? this.h.U.u : undefined;
        }
        back() {
            return this.h.W ? this.h.W.u : undefined;
        }
        insert(e, t) {
            return this.M(e, undefined, t);
        }
        find(e) {
            const t = this.I(this.Y, e);
            return new OrderedSetIterator(t, this.h, this);
        }
        lowerBound(e) {
            const t = this.X(this.Y, e);
            return new OrderedSetIterator(t, this.h, this);
        }
        upperBound(e) {
            const t = this.Z(this.Y, e);
            return new OrderedSetIterator(t, this.h, this);
        }
        reverseLowerBound(e) {
            const t = this.$(this.Y, e);
            return new OrderedSetIterator(t, this.h, this);
        }
        reverseUpperBound(e) {
            const t = this.rr(this.Y, e);
            return new OrderedSetIterator(t, this.h, this);
        }
        union(e) {
            const t = this;
            e.forEach((function (e) {
                t.insert(e);
            }));
            return this.i;
        }
        [Symbol.iterator]() {
            return this.K(this.Y);
        }
    }
    var _default = OrderedSet;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/TreeContainer/Base/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _TreeNode = require(431) /* ./TreeNode */;
    var _ContainerBase = require(420) /* ../../ContainerBase */;
    var _throwError = require(426) /* ../../../utils/throwError */;
    class TreeContainer extends _ContainerBase.Container {
        constructor(e = function (e, t) {
            if (e < t)
                return -1;
            if (e > t)
                return 1;
            return 0;
        }, t = false) {
            super();
            this.Y = undefined;
            this.v = e;
            if (t) {
                this.re = _TreeNode.TreeNodeEnableIndex;
                this.M = function (e, t, i) {
                    const s = this.ne(e, t, i);
                    if (s) {
                        let e = s.tt;
                        while (e !== this.h) {
                            e.rt += 1;
                            e = e.tt;
                        }
                        const t = this.he(s);
                        if (t) {
                            const { parentNode: e, grandParent: i, curNode: s } = t;
                            e.ie();
                            i.ie();
                            s.ie();
                        }
                    }
                    return this.i;
                };
                this.V = function (e) {
                    let t = this.fe(e);
                    while (t !== this.h) {
                        t.rt -= 1;
                        t = t.tt;
                    }
                };
            }
            else {
                this.re = _TreeNode.TreeNode;
                this.M = function (e, t, i) {
                    const s = this.ne(e, t, i);
                    if (s)
                        this.he(s);
                    return this.i;
                };
                this.V = this.fe;
            }
            this.h = new this.re;
        }
        X(e, t) {
            let i = this.h;
            while (e) {
                const s = this.v(e.u, t);
                if (s < 0) {
                    e = e.W;
                }
                else if (s > 0) {
                    i = e;
                    e = e.U;
                }
                else
                    return e;
            }
            return i;
        }
        Z(e, t) {
            let i = this.h;
            while (e) {
                const s = this.v(e.u, t);
                if (s <= 0) {
                    e = e.W;
                }
                else {
                    i = e;
                    e = e.U;
                }
            }
            return i;
        }
        $(e, t) {
            let i = this.h;
            while (e) {
                const s = this.v(e.u, t);
                if (s < 0) {
                    i = e;
                    e = e.W;
                }
                else if (s > 0) {
                    e = e.U;
                }
                else
                    return e;
            }
            return i;
        }
        rr(e, t) {
            let i = this.h;
            while (e) {
                const s = this.v(e.u, t);
                if (s < 0) {
                    i = e;
                    e = e.W;
                }
                else {
                    e = e.U;
                }
            }
            return i;
        }
        ue(e) {
            while (true) {
                const t = e.tt;
                if (t === this.h)
                    return;
                if (e.ee === 1) {
                    e.ee = 0;
                    return;
                }
                if (e === t.U) {
                    const i = t.W;
                    if (i.ee === 1) {
                        i.ee = 0;
                        t.ee = 1;
                        if (t === this.Y) {
                            this.Y = t.te();
                        }
                        else
                            t.te();
                    }
                    else {
                        if (i.W && i.W.ee === 1) {
                            i.ee = t.ee;
                            t.ee = 0;
                            i.W.ee = 0;
                            if (t === this.Y) {
                                this.Y = t.te();
                            }
                            else
                                t.te();
                            return;
                        }
                        else if (i.U && i.U.ee === 1) {
                            i.ee = 1;
                            i.U.ee = 0;
                            i.se();
                        }
                        else {
                            i.ee = 1;
                            e = t;
                        }
                    }
                }
                else {
                    const i = t.U;
                    if (i.ee === 1) {
                        i.ee = 0;
                        t.ee = 1;
                        if (t === this.Y) {
                            this.Y = t.se();
                        }
                        else
                            t.se();
                    }
                    else {
                        if (i.U && i.U.ee === 1) {
                            i.ee = t.ee;
                            t.ee = 0;
                            i.U.ee = 0;
                            if (t === this.Y) {
                                this.Y = t.se();
                            }
                            else
                                t.se();
                            return;
                        }
                        else if (i.W && i.W.ee === 1) {
                            i.ee = 1;
                            i.W.ee = 0;
                            i.te();
                        }
                        else {
                            i.ee = 1;
                            e = t;
                        }
                    }
                }
            }
        }
        fe(e) {
            if (this.i === 1) {
                this.clear();
                return this.h;
            }
            let t = e;
            while (t.U || t.W) {
                if (t.W) {
                    t = t.W;
                    while (t.U)
                        t = t.U;
                }
                else {
                    t = t.U;
                }
                [e.u, t.u] = [t.u, e.u];
                [e.l, t.l] = [t.l, e.l];
                e = t;
            }
            if (this.h.U === t) {
                this.h.U = t.tt;
            }
            else if (this.h.W === t) {
                this.h.W = t.tt;
            }
            this.ue(t);
            const i = t.tt;
            if (t === i.U) {
                i.U = undefined;
            }
            else
                i.W = undefined;
            this.i -= 1;
            this.Y.ee = 0;
            return i;
        }
        oe(e, t) {
            if (e === undefined)
                return false;
            const i = this.oe(e.U, t);
            if (i)
                return true;
            if (t(e))
                return true;
            return this.oe(e.W, t);
        }
        he(e) {
            while (true) {
                const t = e.tt;
                if (t.ee === 0)
                    return;
                const i = t.tt;
                if (t === i.U) {
                    const s = i.W;
                    if (s && s.ee === 1) {
                        s.ee = t.ee = 0;
                        if (i === this.Y)
                            return;
                        i.ee = 1;
                        e = i;
                        continue;
                    }
                    else if (e === t.W) {
                        e.ee = 0;
                        if (e.U)
                            e.U.tt = t;
                        if (e.W)
                            e.W.tt = i;
                        t.W = e.U;
                        i.U = e.W;
                        e.U = t;
                        e.W = i;
                        if (i === this.Y) {
                            this.Y = e;
                            this.h.tt = e;
                        }
                        else {
                            const t = i.tt;
                            if (t.U === i) {
                                t.U = e;
                            }
                            else
                                t.W = e;
                        }
                        e.tt = i.tt;
                        t.tt = e;
                        i.tt = e;
                        i.ee = 1;
                        return {
                            parentNode: t,
                            grandParent: i,
                            curNode: e
                        };
                    }
                    else {
                        t.ee = 0;
                        if (i === this.Y) {
                            this.Y = i.se();
                        }
                        else
                            i.se();
                        i.ee = 1;
                    }
                }
                else {
                    const s = i.U;
                    if (s && s.ee === 1) {
                        s.ee = t.ee = 0;
                        if (i === this.Y)
                            return;
                        i.ee = 1;
                        e = i;
                        continue;
                    }
                    else if (e === t.U) {
                        e.ee = 0;
                        if (e.U)
                            e.U.tt = i;
                        if (e.W)
                            e.W.tt = t;
                        i.W = e.U;
                        t.U = e.W;
                        e.U = i;
                        e.W = t;
                        if (i === this.Y) {
                            this.Y = e;
                            this.h.tt = e;
                        }
                        else {
                            const t = i.tt;
                            if (t.U === i) {
                                t.U = e;
                            }
                            else
                                t.W = e;
                        }
                        e.tt = i.tt;
                        t.tt = e;
                        i.tt = e;
                        i.ee = 1;
                        return {
                            parentNode: t,
                            grandParent: i,
                            curNode: e
                        };
                    }
                    else {
                        t.ee = 0;
                        if (i === this.Y) {
                            this.Y = i.te();
                        }
                        else
                            i.te();
                        i.ee = 1;
                    }
                }
                return;
            }
        }
        ne(e, t, i) {
            if (this.Y === undefined) {
                this.i += 1;
                this.Y = new this.re(e, t);
                this.Y.ee = 0;
                this.Y.tt = this.h;
                this.h.tt = this.Y;
                this.h.U = this.Y;
                this.h.W = this.Y;
                return;
            }
            let s;
            const r = this.h.U;
            const n = this.v(r.u, e);
            if (n === 0) {
                r.l = t;
                return;
            }
            else if (n > 0) {
                r.U = new this.re(e, t);
                r.U.tt = r;
                s = r.U;
                this.h.U = s;
            }
            else {
                const r = this.h.W;
                const n = this.v(r.u, e);
                if (n === 0) {
                    r.l = t;
                    return;
                }
                else if (n < 0) {
                    r.W = new this.re(e, t);
                    r.W.tt = r;
                    s = r.W;
                    this.h.W = s;
                }
                else {
                    if (i !== undefined) {
                        const r = i.o;
                        if (r !== this.h) {
                            const i = this.v(r.u, e);
                            if (i === 0) {
                                r.l = t;
                                return;
                            }
                            else if (i > 0) {
                                const i = r.L();
                                const n = this.v(i.u, e);
                                if (n === 0) {
                                    i.l = t;
                                    return;
                                }
                                else if (n < 0) {
                                    s = new this.re(e, t);
                                    if (i.W === undefined) {
                                        i.W = s;
                                        s.tt = i;
                                    }
                                    else {
                                        r.U = s;
                                        s.tt = r;
                                    }
                                }
                            }
                        }
                    }
                    if (s === undefined) {
                        s = this.Y;
                        while (true) {
                            const i = this.v(s.u, e);
                            if (i > 0) {
                                if (s.U === undefined) {
                                    s.U = new this.re(e, t);
                                    s.U.tt = s;
                                    s = s.U;
                                    break;
                                }
                                s = s.U;
                            }
                            else if (i < 0) {
                                if (s.W === undefined) {
                                    s.W = new this.re(e, t);
                                    s.W.tt = s;
                                    s = s.W;
                                    break;
                                }
                                s = s.W;
                            }
                            else {
                                s.l = t;
                                return;
                            }
                        }
                    }
                }
            }
            this.i += 1;
            return s;
        }
        I(e, t) {
            while (e) {
                const i = this.v(e.u, t);
                if (i < 0) {
                    e = e.W;
                }
                else if (i > 0) {
                    e = e.U;
                }
                else
                    return e;
            }
            return e || this.h;
        }
        clear() {
            this.i = 0;
            this.Y = undefined;
            this.h.tt = undefined;
            this.h.U = this.h.W = undefined;
        }
        updateKeyByIterator(e, t) {
            const i = e.o;
            if (i === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            if (this.i === 1) {
                i.u = t;
                return true;
            }
            if (i === this.h.U) {
                if (this.v(i.B().u, t) > 0) {
                    i.u = t;
                    return true;
                }
                return false;
            }
            if (i === this.h.W) {
                if (this.v(i.L().u, t) < 0) {
                    i.u = t;
                    return true;
                }
                return false;
            }
            const s = i.L().u;
            if (this.v(s, t) >= 0)
                return false;
            const r = i.B().u;
            if (this.v(r, t) <= 0)
                return false;
            i.u = t;
            return true;
        }
        eraseElementByPos(e) {
            if (e < 0 || e > this.i - 1) {
                throw new RangeError;
            }
            let t = 0;
            const i = this;
            this.oe(this.Y, (function (s) {
                if (e === t) {
                    i.V(s);
                    return true;
                }
                t += 1;
                return false;
            }));
            return this.i;
        }
        eraseElementByKey(e) {
            if (this.i === 0)
                return false;
            const t = this.I(this.Y, e);
            if (t === this.h)
                return false;
            this.V(t);
            return true;
        }
        eraseElementByIterator(e) {
            const t = e.o;
            if (t === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            const i = t.W === undefined;
            const s = e.iteratorType === 0;
            if (s) {
                if (i)
                    e.next();
            }
            else {
                if (!i || t.U === undefined)
                    e.next();
            }
            this.V(t);
            return e;
        }
        forEach(e) {
            let t = 0;
            for (const i of this)
                e(i, t++, this);
        }
        getElementByPos(e) {
            if (e < 0 || e > this.i - 1) {
                throw new RangeError;
            }
            let t;
            let i = 0;
            for (const s of this) {
                if (i === e) {
                    t = s;
                    break;
                }
                i += 1;
            }
            return t;
        }
        getHeight() {
            if (this.i === 0)
                return 0;
            const traversal = function (e) {
                if (!e)
                    return 0;
                return Math.max(traversal(e.U), traversal(e.W)) + 1;
            };
            return traversal(this.Y);
        }
    }
    var _default = TreeContainer;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/TreeContainer/Base/TreeNode.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.TreeNodeEnableIndex = exports.TreeNode = void 0;
    class TreeNode {
        constructor(e, t) {
            this.ee = 1;
            this.u = undefined;
            this.l = undefined;
            this.U = undefined;
            this.W = undefined;
            this.tt = undefined;
            this.u = e;
            this.l = t;
        }
        L() {
            let e = this;
            if (e.ee === 1 && e.tt.tt === e) {
                e = e.W;
            }
            else if (e.U) {
                e = e.U;
                while (e.W) {
                    e = e.W;
                }
            }
            else {
                let t = e.tt;
                while (t.U === e) {
                    e = t;
                    t = e.tt;
                }
                e = t;
            }
            return e;
        }
        B() {
            let e = this;
            if (e.W) {
                e = e.W;
                while (e.U) {
                    e = e.U;
                }
                return e;
            }
            else {
                let t = e.tt;
                while (t.W === e) {
                    e = t;
                    t = e.tt;
                }
                if (e.W !== t) {
                    return t;
                }
                else
                    return e;
            }
        }
        te() {
            const e = this.tt;
            const t = this.W;
            const s = t.U;
            if (e.tt === this)
                e.tt = t;
            else if (e.U === this)
                e.U = t;
            else
                e.W = t;
            t.tt = e;
            t.U = this;
            this.tt = t;
            this.W = s;
            if (s)
                s.tt = this;
            return t;
        }
        se() {
            const e = this.tt;
            const t = this.U;
            const s = t.W;
            if (e.tt === this)
                e.tt = t;
            else if (e.U === this)
                e.U = t;
            else
                e.W = t;
            t.tt = e;
            t.W = this;
            this.tt = t;
            this.U = s;
            if (s)
                s.tt = this;
            return t;
        }
    }
    exports.TreeNode = TreeNode;
    class TreeNodeEnableIndex extends TreeNode {
        constructor() {
            super(...arguments);
            this.rt = 1;
        }
        te() {
            const e = super.te();
            this.ie();
            e.ie();
            return e;
        }
        se() {
            const e = super.se();
            this.ie();
            e.ie();
            return e;
        }
        ie() {
            this.rt = 1;
            if (this.U) {
                this.rt += this.U.rt;
            }
            if (this.W) {
                this.rt += this.W.rt;
            }
        }
    }
    exports.TreeNodeEnableIndex = TreeNodeEnableIndex;
    
},
/* js-sdsl/dist/cjs/container/TreeContainer/Base/TreeIterator.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _ContainerBase = require(420) /* ../../ContainerBase */;
    var _throwError = require(426) /* ../../../utils/throwError */;
    class TreeIterator extends _ContainerBase.ContainerIterator {
        constructor(t, r, i) {
            super(i);
            this.o = t;
            this.h = r;
            if (this.iteratorType === 0) {
                this.pre = function () {
                    if (this.o === this.h.U) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.L();
                    return this;
                };
                this.next = function () {
                    if (this.o === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.B();
                    return this;
                };
            }
            else {
                this.pre = function () {
                    if (this.o === this.h.W) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.B();
                    return this;
                };
                this.next = function () {
                    if (this.o === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.L();
                    return this;
                };
            }
        }
        get index() {
            let t = this.o;
            const r = this.h.tt;
            if (t === this.h) {
                if (r) {
                    return r.rt - 1;
                }
                return 0;
            }
            let i = 0;
            if (t.U) {
                i += t.U.rt;
            }
            while (t !== r) {
                const r = t.tt;
                if (t === r.W) {
                    i += 1;
                    if (r.U) {
                        i += r.U.rt;
                    }
                }
                t = r;
            }
            return i;
        }
    }
    var _default = TreeIterator;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/TreeContainer/OrderedMap.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require(430) /* ./Base */);
    var _TreeIterator = _interopRequireDefault(require(432) /* ./Base/TreeIterator */);
    var _throwError = require(426) /* ../../utils/throwError */;
    function _interopRequireDefault(r) {
        return r && r.t ? r : {
            default: r
        };
    }
    class OrderedMapIterator extends _TreeIterator.default {
        constructor(r, t, e, s) {
            super(r, t, s);
            this.container = e;
        }
        get pointer() {
            if (this.o === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            const r = this;
            return new Proxy([], {
                get(t, e) {
                    if (e === "0")
                        return r.o.u;
                    else if (e === "1")
                        return r.o.l;
                },
                set(t, e, s) {
                    if (e !== "1") {
                        throw new TypeError("props must be 1");
                    }
                    r.o.l = s;
                    return true;
                }
            });
        }
        copy() {
            return new OrderedMapIterator(this.o, this.h, this.container, this.iteratorType);
        }
    }
    class OrderedMap extends _Base.default {
        constructor(r = [], t, e) {
            super(t, e);
            const s = this;
            r.forEach((function (r) {
                s.setElement(r[0], r[1]);
            }));
        }
        *K(r) {
            if (r === undefined)
                return;
            yield* this.K(r.U);
            yield [r.u, r.l];
            yield* this.K(r.W);
        }
        begin() {
            return new OrderedMapIterator(this.h.U || this.h, this.h, this);
        }
        end() {
            return new OrderedMapIterator(this.h, this.h, this);
        }
        rBegin() {
            return new OrderedMapIterator(this.h.W || this.h, this.h, this, 1);
        }
        rEnd() {
            return new OrderedMapIterator(this.h, this.h, this, 1);
        }
        front() {
            if (this.i === 0)
                return;
            const r = this.h.U;
            return [r.u, r.l];
        }
        back() {
            if (this.i === 0)
                return;
            const r = this.h.W;
            return [r.u, r.l];
        }
        lowerBound(r) {
            const t = this.X(this.Y, r);
            return new OrderedMapIterator(t, this.h, this);
        }
        upperBound(r) {
            const t = this.Z(this.Y, r);
            return new OrderedMapIterator(t, this.h, this);
        }
        reverseLowerBound(r) {
            const t = this.$(this.Y, r);
            return new OrderedMapIterator(t, this.h, this);
        }
        reverseUpperBound(r) {
            const t = this.rr(this.Y, r);
            return new OrderedMapIterator(t, this.h, this);
        }
        setElement(r, t, e) {
            return this.M(r, t, e);
        }
        find(r) {
            const t = this.I(this.Y, r);
            return new OrderedMapIterator(t, this.h, this);
        }
        getElementByKey(r) {
            const t = this.I(this.Y, r);
            return t.l;
        }
        union(r) {
            const t = this;
            r.forEach((function (r) {
                t.setElement(r[0], r[1]);
            }));
            return this.i;
        }
        [Symbol.iterator]() {
            return this.K(this.Y);
        }
    }
    var _default = OrderedMap;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/HashContainer/HashSet.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _Base = require(435) /* ./Base */;
    var _throwError = require(426) /* ../../utils/throwError */;
    class HashSetIterator extends _Base.HashContainerIterator {
        constructor(t, e, r, s) {
            super(t, e, s);
            this.container = r;
        }
        get pointer() {
            if (this.o === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            return this.o.u;
        }
        copy() {
            return new HashSetIterator(this.o, this.h, this.container, this.iteratorType);
        }
    }
    class HashSet extends _Base.HashContainer {
        constructor(t = []) {
            super();
            const e = this;
            t.forEach((function (t) {
                e.insert(t);
            }));
        }
        begin() {
            return new HashSetIterator(this.p, this.h, this);
        }
        end() {
            return new HashSetIterator(this.h, this.h, this);
        }
        rBegin() {
            return new HashSetIterator(this._, this.h, this, 1);
        }
        rEnd() {
            return new HashSetIterator(this.h, this.h, this, 1);
        }
        front() {
            return this.p.u;
        }
        back() {
            return this._.u;
        }
        insert(t, e) {
            return this.M(t, undefined, e);
        }
        getElementByPos(t) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            let e = this.p;
            while (t--) {
                e = e.B;
            }
            return e.u;
        }
        find(t, e) {
            const r = this.I(t, e);
            return new HashSetIterator(r, this.h, this);
        }
        forEach(t) {
            let e = 0;
            let r = this.p;
            while (r !== this.h) {
                t(r.u, e++, this);
                r = r.B;
            }
        }
        [Symbol.iterator]() {
            return function* () {
                let t = this.p;
                while (t !== this.h) {
                    yield t.u;
                    t = t.B;
                }
            }.bind(this)();
        }
    }
    var _default = HashSet;
    exports.default = _default;
    
},
/* js-sdsl/dist/cjs/container/HashContainer/Base/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.HashContainerIterator = exports.HashContainer = void 0;
    var _ContainerBase = require(420) /* ../../ContainerBase */;
    var _checkObject = _interopRequireDefault(require(436) /* ../../../utils/checkObject */);
    var _throwError = require(426) /* ../../../utils/throwError */;
    function _interopRequireDefault(t) {
        return t && t.t ? t : {
            default: t
        };
    }
    class HashContainerIterator extends _ContainerBase.ContainerIterator {
        constructor(t, e, i) {
            super(i);
            this.o = t;
            this.h = e;
            if (this.iteratorType === 0) {
                this.pre = function () {
                    if (this.o.L === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.L;
                    return this;
                };
                this.next = function () {
                    if (this.o === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.B;
                    return this;
                };
            }
            else {
                this.pre = function () {
                    if (this.o.B === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.B;
                    return this;
                };
                this.next = function () {
                    if (this.o === this.h) {
                        (0, _throwError.throwIteratorAccessError)();
                    }
                    this.o = this.o.L;
                    return this;
                };
            }
        }
    }
    exports.HashContainerIterator = HashContainerIterator;
    class HashContainer extends _ContainerBase.Container {
        constructor() {
            super();
            this.H = [];
            this.g = {};
            this.HASH_TAG = Symbol("@@HASH_TAG");
            Object.setPrototypeOf(this.g, null);
            this.h = {};
            this.h.L = this.h.B = this.p = this._ = this.h;
        }
        V(t) {
            const { L: e, B: i } = t;
            e.B = i;
            i.L = e;
            if (t === this.p) {
                this.p = i;
            }
            if (t === this._) {
                this._ = e;
            }
            this.i -= 1;
        }
        M(t, e, i) {
            if (i === undefined)
                i = (0, _checkObject.default)(t);
            let s;
            if (i) {
                const i = t[this.HASH_TAG];
                if (i !== undefined) {
                    this.H[i].l = e;
                    return this.i;
                }
                Object.defineProperty(t, this.HASH_TAG, {
                    value: this.H.length,
                    configurable: true
                });
                s = {
                    u: t,
                    l: e,
                    L: this._,
                    B: this.h
                };
                this.H.push(s);
            }
            else {
                const i = this.g[t];
                if (i) {
                    i.l = e;
                    return this.i;
                }
                s = {
                    u: t,
                    l: e,
                    L: this._,
                    B: this.h
                };
                this.g[t] = s;
            }
            if (this.i === 0) {
                this.p = s;
                this.h.B = s;
            }
            else {
                this._.B = s;
            }
            this._ = s;
            this.h.L = s;
            return ++this.i;
        }
        I(t, e) {
            if (e === undefined)
                e = (0, _checkObject.default)(t);
            if (e) {
                const e = t[this.HASH_TAG];
                if (e === undefined)
                    return this.h;
                return this.H[e];
            }
            else {
                return this.g[t] || this.h;
            }
        }
        clear() {
            const t = this.HASH_TAG;
            this.H.forEach((function (e) {
                delete e.u[t];
            }));
            this.H = [];
            this.g = {};
            Object.setPrototypeOf(this.g, null);
            this.i = 0;
            this.p = this._ = this.h.L = this.h.B = this.h;
        }
        eraseElementByKey(t, e) {
            let i;
            if (e === undefined)
                e = (0, _checkObject.default)(t);
            if (e) {
                const e = t[this.HASH_TAG];
                if (e === undefined)
                    return false;
                delete t[this.HASH_TAG];
                i = this.H[e];
                delete this.H[e];
            }
            else {
                i = this.g[t];
                if (i === undefined)
                    return false;
                delete this.g[t];
            }
            this.V(i);
            return true;
        }
        eraseElementByIterator(t) {
            const e = t.o;
            if (e === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            this.V(e);
            return t.next();
        }
        eraseElementByPos(t) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            let e = this.p;
            while (t--) {
                e = e.B;
            }
            this.V(e);
            return this.i;
        }
    }
    exports.HashContainer = HashContainer;
    
},
/* js-sdsl/dist/cjs/utils/checkObject.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = checkObject;
    function checkObject(e) {
        const t = typeof e;
        return t === "object" && e !== null || t === "function";
    }
    
},
/* js-sdsl/dist/cjs/container/HashContainer/HashMap.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "t", {
        value: true
    });
    exports.default = void 0;
    var _Base = require(435) /* ./Base */;
    var _checkObject = _interopRequireDefault(require(436) /* ../../utils/checkObject */);
    var _throwError = require(426) /* ../../utils/throwError */;
    function _interopRequireDefault(t) {
        return t && t.t ? t : {
            default: t
        };
    }
    class HashMapIterator extends _Base.HashContainerIterator {
        constructor(t, e, r, s) {
            super(t, e, s);
            this.container = r;
        }
        get pointer() {
            if (this.o === this.h) {
                (0, _throwError.throwIteratorAccessError)();
            }
            const t = this;
            return new Proxy([], {
                get(e, r) {
                    if (r === "0")
                        return t.o.u;
                    else if (r === "1")
                        return t.o.l;
                },
                set(e, r, s) {
                    if (r !== "1") {
                        throw new TypeError("props must be 1");
                    }
                    t.o.l = s;
                    return true;
                }
            });
        }
        copy() {
            return new HashMapIterator(this.o, this.h, this.container, this.iteratorType);
        }
    }
    class HashMap extends _Base.HashContainer {
        constructor(t = []) {
            super();
            const e = this;
            t.forEach((function (t) {
                e.setElement(t[0], t[1]);
            }));
        }
        begin() {
            return new HashMapIterator(this.p, this.h, this);
        }
        end() {
            return new HashMapIterator(this.h, this.h, this);
        }
        rBegin() {
            return new HashMapIterator(this._, this.h, this, 1);
        }
        rEnd() {
            return new HashMapIterator(this.h, this.h, this, 1);
        }
        front() {
            if (this.i === 0)
                return;
            return [this.p.u, this.p.l];
        }
        back() {
            if (this.i === 0)
                return;
            return [this._.u, this._.l];
        }
        setElement(t, e, r) {
            return this.M(t, e, r);
        }
        getElementByKey(t, e) {
            if (e === undefined)
                e = (0, _checkObject.default)(t);
            if (e) {
                const e = t[this.HASH_TAG];
                return e !== undefined ? this.H[e].l : undefined;
            }
            const r = this.g[t];
            return r ? r.l : undefined;
        }
        getElementByPos(t) {
            if (t < 0 || t > this.i - 1) {
                throw new RangeError;
            }
            let e = this.p;
            while (t--) {
                e = e.B;
            }
            return [e.u, e.l];
        }
        find(t, e) {
            const r = this.I(t, e);
            return new HashMapIterator(r, this.h, this);
        }
        forEach(t) {
            let e = 0;
            let r = this.p;
            while (r !== this.h) {
                t([r.u, r.l], e++, this);
                r = r.B;
            }
        }
        [Symbol.iterator]() {
            return function* () {
                let t = this.p;
                while (t !== this.h) {
                    yield [t.u, t.l];
                    t = t.B;
                }
            }.bind(this)();
        }
    }
    var _default = HashMap;
    exports.default = _default;
    
},
/* eslint/lib/rules/indent-legacy.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview This option sets a specific tab width for your code
     *
     * This rule has been ported and modified from nodeca.
     * @author Vitaly Puzrin
     * @author Gyandeep Singh
     * @deprecated in ESLint v4.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    // this rule has known coverage issues, but it's deprecated and shouldn't be updated in the future anyway.
    /* c8 ignore next */
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent indentation",
                recommended: false,
                url: "https://eslint.org/docs/rules/indent-legacy"
            },
            deprecated: true,
            replacedBy: ["indent"],
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["tab"]
                        },
                        {
                            type: "integer",
                            minimum: 0
                        }
                    ]
                },
                {
                    type: "object",
                    properties: {
                        SwitchCase: {
                            type: "integer",
                            minimum: 0
                        },
                        VariableDeclarator: {
                            oneOf: [
                                {
                                    type: "integer",
                                    minimum: 0
                                },
                                {
                                    type: "object",
                                    properties: {
                                        var: {
                                            type: "integer",
                                            minimum: 0
                                        },
                                        let: {
                                            type: "integer",
                                            minimum: 0
                                        },
                                        const: {
                                            type: "integer",
                                            minimum: 0
                                        }
                                    }
                                }
                            ]
                        },
                        outerIIFEBody: {
                            type: "integer",
                            minimum: 0
                        },
                        MemberExpression: {
                            type: "integer",
                            minimum: 0
                        },
                        FunctionDeclaration: {
                            type: "object",
                            properties: {
                                parameters: {
                                    oneOf: [
                                        {
                                            type: "integer",
                                            minimum: 0
                                        },
                                        {
                                            enum: ["first"]
                                        }
                                    ]
                                },
                                body: {
                                    type: "integer",
                                    minimum: 0
                                }
                            }
                        },
                        FunctionExpression: {
                            type: "object",
                            properties: {
                                parameters: {
                                    oneOf: [
                                        {
                                            type: "integer",
                                            minimum: 0
                                        },
                                        {
                                            enum: ["first"]
                                        }
                                    ]
                                },
                                body: {
                                    type: "integer",
                                    minimum: 0
                                }
                            }
                        },
                        CallExpression: {
                            type: "object",
                            properties: {
                                parameters: {
                                    oneOf: [
                                        {
                                            type: "integer",
                                            minimum: 0
                                        },
                                        {
                                            enum: ["first"]
                                        }
                                    ]
                                }
                            }
                        },
                        ArrayExpression: {
                            oneOf: [
                                {
                                    type: "integer",
                                    minimum: 0
                                },
                                {
                                    enum: ["first"]
                                }
                            ]
                        },
                        ObjectExpression: {
                            oneOf: [
                                {
                                    type: "integer",
                                    minimum: 0
                                },
                                {
                                    enum: ["first"]
                                }
                            ]
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                expected: "Expected indentation of {{expected}} but found {{actual}}."
            }
        },
        create(context) {
            const DEFAULT_VARIABLE_INDENT = 1;
            const DEFAULT_PARAMETER_INDENT = null; // For backwards compatibility, don't check parameter indentation unless specified in the config
            const DEFAULT_FUNCTION_BODY_INDENT = 1;
            let indentType = "space";
            let indentSize = 4;
            const options = {
                SwitchCase: 0,
                VariableDeclarator: {
                    var: DEFAULT_VARIABLE_INDENT,
                    let: DEFAULT_VARIABLE_INDENT,
                    const: DEFAULT_VARIABLE_INDENT
                },
                outerIIFEBody: null,
                FunctionDeclaration: {
                    parameters: DEFAULT_PARAMETER_INDENT,
                    body: DEFAULT_FUNCTION_BODY_INDENT
                },
                FunctionExpression: {
                    parameters: DEFAULT_PARAMETER_INDENT,
                    body: DEFAULT_FUNCTION_BODY_INDENT
                },
                CallExpression: {
                    arguments: DEFAULT_PARAMETER_INDENT
                },
                ArrayExpression: 1,
                ObjectExpression: 1
            };
            const sourceCode = context.getSourceCode();
            if (context.options.length) {
                if (context.options[0] === "tab") {
                    indentSize = 1;
                    indentType = "tab";
                }
                else /* c8 ignore start */ if (typeof context.options[0] === "number") {
                    indentSize = context.options[0];
                    indentType = "space";
                } /* c8 ignore stop */
                if (context.options[1]) {
                    const opts = context.options[1];
                    options.SwitchCase = opts.SwitchCase || 0;
                    const variableDeclaratorRules = opts.VariableDeclarator;
                    if (typeof variableDeclaratorRules === "number") {
                        options.VariableDeclarator = {
                            var: variableDeclaratorRules,
                            let: variableDeclaratorRules,
                            const: variableDeclaratorRules
                        };
                    }
                    else if (typeof variableDeclaratorRules === "object") {
                        Object.assign(options.VariableDeclarator, variableDeclaratorRules);
                    }
                    if (typeof opts.outerIIFEBody === "number") {
                        options.outerIIFEBody = opts.outerIIFEBody;
                    }
                    if (typeof opts.MemberExpression === "number") {
                        options.MemberExpression = opts.MemberExpression;
                    }
                    if (typeof opts.FunctionDeclaration === "object") {
                        Object.assign(options.FunctionDeclaration, opts.FunctionDeclaration);
                    }
                    if (typeof opts.FunctionExpression === "object") {
                        Object.assign(options.FunctionExpression, opts.FunctionExpression);
                    }
                    if (typeof opts.CallExpression === "object") {
                        Object.assign(options.CallExpression, opts.CallExpression);
                    }
                    if (typeof opts.ArrayExpression === "number" || typeof opts.ArrayExpression === "string") {
                        options.ArrayExpression = opts.ArrayExpression;
                    }
                    if (typeof opts.ObjectExpression === "number" || typeof opts.ObjectExpression === "string") {
                        options.ObjectExpression = opts.ObjectExpression;
                    }
                }
            }
            const caseIndentStore = {};
            /**
             * Creates an error message for a line, given the expected/actual indentation.
             * @param {int} expectedAmount The expected amount of indentation characters for this line
             * @param {int} actualSpaces The actual number of indentation spaces that were found on this line
             * @param {int} actualTabs The actual number of indentation tabs that were found on this line
             * @returns {string} An error message for this line
             */
            function createErrorMessageData(expectedAmount, actualSpaces, actualTabs) {
                const expectedStatement = `${expectedAmount} ${indentType}${expectedAmount === 1 ? "" : "s"}`; // e.g. "2 tabs"
                const foundSpacesWord = `space${actualSpaces === 1 ? "" : "s"}`; // e.g. "space"
                const foundTabsWord = `tab${actualTabs === 1 ? "" : "s"}`; // e.g. "tabs"
                let foundStatement;
                if (actualSpaces > 0 && actualTabs > 0) {
                    foundStatement = `${actualSpaces} ${foundSpacesWord} and ${actualTabs} ${foundTabsWord}`; // e.g. "1 space and 2 tabs"
                }
                else if (actualSpaces > 0) {
                    /*
                     * Abbreviate the message if the expected indentation is also spaces.
                     * e.g. 'Expected 4 spaces but found 2' rather than 'Expected 4 spaces but found 2 spaces'
                     */
                    foundStatement = indentType === "space" ? actualSpaces : `${actualSpaces} ${foundSpacesWord}`;
                }
                else if (actualTabs > 0) {
                    foundStatement = indentType === "tab" ? actualTabs : `${actualTabs} ${foundTabsWord}`;
                }
                else {
                    foundStatement = "0";
                }
                return {
                    expected: expectedStatement,
                    actual: foundStatement
                };
            }
            /**
             * Reports a given indent violation
             * @param {ASTNode} node Node violating the indent rule
             * @param {int} needed Expected indentation character count
             * @param {int} gottenSpaces Indentation space count in the actual node/code
             * @param {int} gottenTabs Indentation tab count in the actual node/code
             * @param {Object} [loc] Error line and column location
             * @param {boolean} isLastNodeCheck Is the error for last node check
             * @returns {void}
             */
            function report(node, needed, gottenSpaces, gottenTabs, loc, isLastNodeCheck) {
                if (gottenSpaces && gottenTabs) {
                    // To avoid conflicts with `no-mixed-spaces-and-tabs`, don't report lines that have both spaces and tabs.
                    return;
                }
                const desiredIndent = (indentType === "space" ? " " : "\t").repeat(needed);
                const textRange = isLastNodeCheck
                    ? [node.range[1] - node.loc.end.column, node.range[1] - node.loc.end.column + gottenSpaces + gottenTabs]
                    : [node.range[0] - node.loc.start.column, node.range[0] - node.loc.start.column + gottenSpaces + gottenTabs];
                context.report({
                    node,
                    loc,
                    messageId: "expected",
                    data: createErrorMessageData(needed, gottenSpaces, gottenTabs),
                    fix: fixer => fixer.replaceTextRange(textRange, desiredIndent)
                });
            }
            /**
             * Get the actual indent of node
             * @param {ASTNode|Token} node Node to examine
             * @param {boolean} [byLastLine=false] get indent of node's last line
             * @returns {Object} The node's indent. Contains keys `space` and `tab`, representing the indent of each character. Also
             * contains keys `goodChar` and `badChar`, where `goodChar` is the amount of the user's desired indentation character, and
             * `badChar` is the amount of the other indentation character.
             */
            function getNodeIndent(node, byLastLine) {
                const token = byLastLine ? sourceCode.getLastToken(node) : sourceCode.getFirstToken(node);
                const srcCharsBeforeNode = sourceCode.getText(token, token.loc.start.column).split("");
                const indentChars = srcCharsBeforeNode.slice(0, srcCharsBeforeNode.findIndex(char => char !== " " && char !== "\t"));
                const spaces = indentChars.filter(char => char === " ").length;
                const tabs = indentChars.filter(char => char === "\t").length;
                return {
                    space: spaces,
                    tab: tabs,
                    goodChar: indentType === "space" ? spaces : tabs,
                    badChar: indentType === "space" ? tabs : spaces
                };
            }
            /**
             * Checks node is the first in its own start line. By default it looks by start line.
             * @param {ASTNode} node The node to check
             * @param {boolean} [byEndLocation=false] Lookup based on start position or end
             * @returns {boolean} true if its the first in the its start line
             */
            function isNodeFirstInLine(node, byEndLocation) {
                const firstToken = byEndLocation === true ? sourceCode.getLastToken(node, 1) : sourceCode.getTokenBefore(node), startLine = byEndLocation === true ? node.loc.end.line : node.loc.start.line, endLine = firstToken ? firstToken.loc.end.line : -1;
                return startLine !== endLine;
            }
            /**
             * Check indent for node
             * @param {ASTNode} node Node to check
             * @param {int} neededIndent needed indent
             * @returns {void}
             */
            function checkNodeIndent(node, neededIndent) {
                const actualIndent = getNodeIndent(node, false);
                if (node.type !== "ArrayExpression" &&
                    node.type !== "ObjectExpression" &&
                    (actualIndent.goodChar !== neededIndent || actualIndent.badChar !== 0) &&
                    isNodeFirstInLine(node)) {
                    report(node, neededIndent, actualIndent.space, actualIndent.tab);
                }
                if (node.type === "IfStatement" && node.alternate) {
                    const elseToken = sourceCode.getTokenBefore(node.alternate);
                    checkNodeIndent(elseToken, neededIndent);
                    if (!isNodeFirstInLine(node.alternate)) {
                        checkNodeIndent(node.alternate, neededIndent);
                    }
                }
                if (node.type === "TryStatement" && node.handler) {
                    const catchToken = sourceCode.getFirstToken(node.handler);
                    checkNodeIndent(catchToken, neededIndent);
                }
                if (node.type === "TryStatement" && node.finalizer) {
                    const finallyToken = sourceCode.getTokenBefore(node.finalizer);
                    checkNodeIndent(finallyToken, neededIndent);
                }
                if (node.type === "DoWhileStatement") {
                    const whileToken = sourceCode.getTokenAfter(node.body);
                    checkNodeIndent(whileToken, neededIndent);
                }
            }
            /**
             * Check indent for nodes list
             * @param {ASTNode[]} nodes list of node objects
             * @param {int} indent needed indent
             * @returns {void}
             */
            function checkNodesIndent(nodes, indent) {
                nodes.forEach(node => checkNodeIndent(node, indent));
            }
            /**
             * Check last node line indent this detects, that block closed correctly
             * @param {ASTNode} node Node to examine
             * @param {int} lastLineIndent needed indent
             * @returns {void}
             */
            function checkLastNodeLineIndent(node, lastLineIndent) {
                const lastToken = sourceCode.getLastToken(node);
                const endIndent = getNodeIndent(lastToken, true);
                if ((endIndent.goodChar !== lastLineIndent || endIndent.badChar !== 0) && isNodeFirstInLine(node, true)) {
                    report(node, lastLineIndent, endIndent.space, endIndent.tab, { line: lastToken.loc.start.line, column: lastToken.loc.start.column }, true);
                }
            }
            /**
             * Check last node line indent this detects, that block closed correctly
             * This function for more complicated return statement case, where closing parenthesis may be followed by ';'
             * @param {ASTNode} node Node to examine
             * @param {int} firstLineIndent first line needed indent
             * @returns {void}
             */
            function checkLastReturnStatementLineIndent(node, firstLineIndent) {
                /*
                 * in case if return statement ends with ');' we have traverse back to ')'
                 * otherwise we'll measure indent for ';' and replace ')'
                 */
                const lastToken = sourceCode.getLastToken(node, astUtils.isClosingParenToken);
                const textBeforeClosingParenthesis = sourceCode.getText(lastToken, lastToken.loc.start.column).slice(0, -1);
                if (textBeforeClosingParenthesis.trim()) {
                    // There are tokens before the closing paren, don't report this case
                    return;
                }
                const endIndent = getNodeIndent(lastToken, true);
                if (endIndent.goodChar !== firstLineIndent) {
                    report(node, firstLineIndent, endIndent.space, endIndent.tab, { line: lastToken.loc.start.line, column: lastToken.loc.start.column }, true);
                }
            }
            /**
             * Check first node line indent is correct
             * @param {ASTNode} node Node to examine
             * @param {int} firstLineIndent needed indent
             * @returns {void}
             */
            function checkFirstNodeLineIndent(node, firstLineIndent) {
                const startIndent = getNodeIndent(node, false);
                if ((startIndent.goodChar !== firstLineIndent || startIndent.badChar !== 0) && isNodeFirstInLine(node)) {
                    report(node, firstLineIndent, startIndent.space, startIndent.tab, { line: node.loc.start.line, column: node.loc.start.column });
                }
            }
            /**
             * Returns a parent node of given node based on a specified type
             * if not present then return null
             * @param {ASTNode} node node to examine
             * @param {string} type type that is being looked for
             * @param {string} stopAtList end points for the evaluating code
             * @returns {ASTNode|void} if found then node otherwise null
             */
            function getParentNodeByType(node, type, stopAtList) {
                let parent = node.parent;
                const stopAtSet = new Set(stopAtList || ["Program"]);
                while (parent.type !== type && !stopAtSet.has(parent.type) && parent.type !== "Program") {
                    parent = parent.parent;
                }
                return parent.type === type ? parent : null;
            }
            /**
             * Returns the VariableDeclarator based on the current node
             * if not present then return null
             * @param {ASTNode} node node to examine
             * @returns {ASTNode|void} if found then node otherwise null
             */
            function getVariableDeclaratorNode(node) {
                return getParentNodeByType(node, "VariableDeclarator");
            }
            /**
             * Check to see if the node is part of the multi-line variable declaration.
             * Also if its on the same line as the varNode
             * @param {ASTNode} node node to check
             * @param {ASTNode} varNode variable declaration node to check against
             * @returns {boolean} True if all the above condition satisfy
             */
            function isNodeInVarOnTop(node, varNode) {
                return varNode &&
                    varNode.parent.loc.start.line === node.loc.start.line &&
                    varNode.parent.declarations.length > 1;
            }
            /**
             * Check to see if the argument before the callee node is multi-line and
             * there should only be 1 argument before the callee node
             * @param {ASTNode} node node to check
             * @returns {boolean} True if arguments are multi-line
             */
            function isArgBeforeCalleeNodeMultiline(node) {
                const parent = node.parent;
                if (parent.arguments.length >= 2 && parent.arguments[1] === node) {
                    return parent.arguments[0].loc.end.line > parent.arguments[0].loc.start.line;
                }
                return false;
            }
            /**
             * Check to see if the node is a file level IIFE
             * @param {ASTNode} node The function node to check.
             * @returns {boolean} True if the node is the outer IIFE
             */
            function isOuterIIFE(node) {
                const parent = node.parent;
                let stmt = parent.parent;
                /*
                 * Verify that the node is an IIEF
                 */
                if (parent.type !== "CallExpression" ||
                    parent.callee !== node) {
                    return false;
                }
                /*
                 * Navigate legal ancestors to determine whether this IIEF is outer
                 */
                while (stmt.type === "UnaryExpression" && (stmt.operator === "!" ||
                    stmt.operator === "~" ||
                    stmt.operator === "+" ||
                    stmt.operator === "-") ||
                    stmt.type === "AssignmentExpression" ||
                    stmt.type === "LogicalExpression" ||
                    stmt.type === "SequenceExpression" ||
                    stmt.type === "VariableDeclarator") {
                    stmt = stmt.parent;
                }
                return ((stmt.type === "ExpressionStatement" ||
                    stmt.type === "VariableDeclaration") &&
                    stmt.parent && stmt.parent.type === "Program");
            }
            /**
             * Check indent for function block content
             * @param {ASTNode} node A BlockStatement node that is inside of a function.
             * @returns {void}
             */
            function checkIndentInFunctionBlock(node) {
                /*
                 * Search first caller in chain.
                 * Ex.:
                 *
                 * Models <- Identifier
                 *   .User
                 *   .find()
                 *   .exec(function() {
                 *   // function body
                 * });
                 *
                 * Looks for 'Models'
                 */
                const calleeNode = node.parent; // FunctionExpression
                let indent;
                if (calleeNode.parent &&
                    (calleeNode.parent.type === "Property" ||
                        calleeNode.parent.type === "ArrayExpression")) {
                    // If function is part of array or object, comma can be put at left
                    indent = getNodeIndent(calleeNode, false).goodChar;
                }
                else {
                    // If function is standalone, simple calculate indent
                    indent = getNodeIndent(calleeNode).goodChar;
                }
                if (calleeNode.parent.type === "CallExpression") {
                    const calleeParent = calleeNode.parent;
                    if (calleeNode.type !== "FunctionExpression" && calleeNode.type !== "ArrowFunctionExpression") {
                        if (calleeParent && calleeParent.loc.start.line < node.loc.start.line) {
                            indent = getNodeIndent(calleeParent).goodChar;
                        }
                    }
                    else {
                        if (isArgBeforeCalleeNodeMultiline(calleeNode) &&
                            calleeParent.callee.loc.start.line === calleeParent.callee.loc.end.line &&
                            !isNodeFirstInLine(calleeNode)) {
                            indent = getNodeIndent(calleeParent).goodChar;
                        }
                    }
                }
                /*
                 * function body indent should be indent + indent size, unless this
                 * is a FunctionDeclaration, FunctionExpression, or outer IIFE and the corresponding options are enabled.
                 */
                let functionOffset = indentSize;
                if (options.outerIIFEBody !== null && isOuterIIFE(calleeNode)) {
                    functionOffset = options.outerIIFEBody * indentSize;
                }
                else if (calleeNode.type === "FunctionExpression") {
                    functionOffset = options.FunctionExpression.body * indentSize;
                }
                else if (calleeNode.type === "FunctionDeclaration") {
                    functionOffset = options.FunctionDeclaration.body * indentSize;
                }
                indent += functionOffset;
                // check if the node is inside a variable
                const parentVarNode = getVariableDeclaratorNode(node);
                if (parentVarNode && isNodeInVarOnTop(node, parentVarNode)) {
                    indent += indentSize * options.VariableDeclarator[parentVarNode.parent.kind];
                }
                if (node.body.length > 0) {
                    checkNodesIndent(node.body, indent);
                }
                checkLastNodeLineIndent(node, indent - functionOffset);
            }
            /**
             * Checks if the given node starts and ends on the same line
             * @param {ASTNode} node The node to check
             * @returns {boolean} Whether or not the block starts and ends on the same line.
             */
            function isSingleLineNode(node) {
                const lastToken = sourceCode.getLastToken(node), startLine = node.loc.start.line, endLine = lastToken.loc.end.line;
                return startLine === endLine;
            }
            /**
             * Check indent for array block content or object block content
             * @param {ASTNode} node node to examine
             * @returns {void}
             */
            function checkIndentInArrayOrObjectBlock(node) {
                // Skip inline
                if (isSingleLineNode(node)) {
                    return;
                }
                let elements = (node.type === "ArrayExpression") ? node.elements : node.properties;
                // filter out empty elements example would be [ , 2] so remove first element as espree considers it as null
                elements = elements.filter(elem => elem !== null);
                let nodeIndent;
                let elementsIndent;
                const parentVarNode = getVariableDeclaratorNode(node);
                // TODO - come up with a better strategy in future
                if (isNodeFirstInLine(node)) {
                    const parent = node.parent;
                    nodeIndent = getNodeIndent(parent).goodChar;
                    if (!parentVarNode || parentVarNode.loc.start.line !== node.loc.start.line) {
                        if (parent.type !== "VariableDeclarator" || parentVarNode === parentVarNode.parent.declarations[0]) {
                            if (parent.type === "VariableDeclarator" && parentVarNode.loc.start.line === parent.loc.start.line) {
                                nodeIndent += (indentSize * options.VariableDeclarator[parentVarNode.parent.kind]);
                            }
                            else if (parent.type === "ObjectExpression" || parent.type === "ArrayExpression") {
                                const parentElements = node.parent.type === "ObjectExpression" ? node.parent.properties : node.parent.elements;
                                if (parentElements[0] &&
                                    parentElements[0].loc.start.line === parent.loc.start.line &&
                                    parentElements[0].loc.end.line !== parent.loc.start.line) {
                                    /*
                                     * If the first element of the array spans multiple lines, don't increase the expected indentation of the rest.
                                     * e.g. [{
                                     *        foo: 1
                                     *      },
                                     *      {
                                     *        bar: 1
                                     *      }]
                                     * the second object is not indented.
                                     */
                                }
                                else if (typeof options[parent.type] === "number") {
                                    nodeIndent += options[parent.type] * indentSize;
                                }
                                else {
                                    nodeIndent = parentElements[0].loc.start.column;
                                }
                            }
                            else if (parent.type === "CallExpression" || parent.type === "NewExpression") {
                                if (typeof options.CallExpression.arguments === "number") {
                                    nodeIndent += options.CallExpression.arguments * indentSize;
                                }
                                else if (options.CallExpression.arguments === "first") {
                                    if (parent.arguments.includes(node)) {
                                        nodeIndent = parent.arguments[0].loc.start.column;
                                    }
                                }
                                else {
                                    nodeIndent += indentSize;
                                }
                            }
                            else if (parent.type === "LogicalExpression" || parent.type === "ArrowFunctionExpression") {
                                nodeIndent += indentSize;
                            }
                        }
                    }
                    checkFirstNodeLineIndent(node, nodeIndent);
                }
                else {
                    nodeIndent = getNodeIndent(node).goodChar;
                }
                if (options[node.type] === "first") {
                    elementsIndent = elements.length ? elements[0].loc.start.column : 0; // If there are no elements, elementsIndent doesn't matter.
                }
                else {
                    elementsIndent = nodeIndent + indentSize * options[node.type];
                }
                /*
                 * Check if the node is a multiple variable declaration; if so, then
                 * make sure indentation takes that into account.
                 */
                if (isNodeInVarOnTop(node, parentVarNode)) {
                    elementsIndent += indentSize * options.VariableDeclarator[parentVarNode.parent.kind];
                }
                checkNodesIndent(elements, elementsIndent);
                if (elements.length > 0) {
                    // Skip last block line check if last item in same line
                    if (elements[elements.length - 1].loc.end.line === node.loc.end.line) {
                        return;
                    }
                }
                checkLastNodeLineIndent(node, nodeIndent +
                    (isNodeInVarOnTop(node, parentVarNode) ? options.VariableDeclarator[parentVarNode.parent.kind] * indentSize : 0));
            }
            /**
             * Check if the node or node body is a BlockStatement or not
             * @param {ASTNode} node node to test
             * @returns {boolean} True if it or its body is a block statement
             */
            function isNodeBodyBlock(node) {
                return node.type === "BlockStatement" || node.type === "ClassBody" || (node.body && node.body.type === "BlockStatement") ||
                    (node.consequent && node.consequent.type === "BlockStatement");
            }
            /**
             * Check indentation for blocks
             * @param {ASTNode} node node to check
             * @returns {void}
             */
            function blockIndentationCheck(node) {
                // Skip inline blocks
                if (isSingleLineNode(node)) {
                    return;
                }
                if (node.parent && (node.parent.type === "FunctionExpression" ||
                    node.parent.type === "FunctionDeclaration" ||
                    node.parent.type === "ArrowFunctionExpression")) {
                    checkIndentInFunctionBlock(node);
                    return;
                }
                let indent;
                let nodesToCheck = [];
                /*
                 * For this statements we should check indent from statement beginning,
                 * not from the beginning of the block.
                 */
                const statementsWithProperties = [
                    "IfStatement", "WhileStatement", "ForStatement", "ForInStatement", "ForOfStatement", "DoWhileStatement", "ClassDeclaration", "TryStatement"
                ];
                if (node.parent && statementsWithProperties.includes(node.parent.type) && isNodeBodyBlock(node)) {
                    indent = getNodeIndent(node.parent).goodChar;
                }
                else if (node.parent && node.parent.type === "CatchClause") {
                    indent = getNodeIndent(node.parent.parent).goodChar;
                }
                else {
                    indent = getNodeIndent(node).goodChar;
                }
                if (node.type === "IfStatement" && node.consequent.type !== "BlockStatement") {
                    nodesToCheck = [node.consequent];
                }
                else if (Array.isArray(node.body)) {
                    nodesToCheck = node.body;
                }
                else {
                    nodesToCheck = [node.body];
                }
                if (nodesToCheck.length > 0) {
                    checkNodesIndent(nodesToCheck, indent + indentSize);
                }
                if (node.type === "BlockStatement") {
                    checkLastNodeLineIndent(node, indent);
                }
            }
            /**
             * Filter out the elements which are on the same line of each other or the node.
             * basically have only 1 elements from each line except the variable declaration line.
             * @param {ASTNode} node Variable declaration node
             * @returns {ASTNode[]} Filtered elements
             */
            function filterOutSameLineVars(node) {
                return node.declarations.reduce((finalCollection, elem) => {
                    const lastElem = finalCollection[finalCollection.length - 1];
                    if ((elem.loc.start.line !== node.loc.start.line && !lastElem) ||
                        (lastElem && lastElem.loc.start.line !== elem.loc.start.line)) {
                        finalCollection.push(elem);
                    }
                    return finalCollection;
                }, []);
            }
            /**
             * Check indentation for variable declarations
             * @param {ASTNode} node node to examine
             * @returns {void}
             */
            function checkIndentInVariableDeclarations(node) {
                const elements = filterOutSameLineVars(node);
                const nodeIndent = getNodeIndent(node).goodChar;
                const lastElement = elements[elements.length - 1];
                const elementsIndent = nodeIndent + indentSize * options.VariableDeclarator[node.kind];
                checkNodesIndent(elements, elementsIndent);
                // Only check the last line if there is any token after the last item
                if (sourceCode.getLastToken(node).loc.end.line <= lastElement.loc.end.line) {
                    return;
                }
                const tokenBeforeLastElement = sourceCode.getTokenBefore(lastElement);
                if (tokenBeforeLastElement.value === ",") {
                    // Special case for comma-first syntax where the semicolon is indented
                    checkLastNodeLineIndent(node, getNodeIndent(tokenBeforeLastElement).goodChar);
                }
                else {
                    checkLastNodeLineIndent(node, elementsIndent - indentSize);
                }
            }
            /**
             * Check and decide whether to check for indentation for blockless nodes
             * Scenarios are for or while statements without braces around them
             * @param {ASTNode} node node to examine
             * @returns {void}
             */
            function blockLessNodes(node) {
                if (node.body.type !== "BlockStatement") {
                    blockIndentationCheck(node);
                }
            }
            /**
             * Returns the expected indentation for the case statement
             * @param {ASTNode} node node to examine
             * @param {int} [providedSwitchIndent] indent for switch statement
             * @returns {int} indent size
             */
            function expectedCaseIndent(node, providedSwitchIndent) {
                const switchNode = (node.type === "SwitchStatement") ? node : node.parent;
                const switchIndent = typeof providedSwitchIndent === "undefined"
                    ? getNodeIndent(switchNode).goodChar
                    : providedSwitchIndent;
                let caseIndent;
                if (caseIndentStore[switchNode.loc.start.line]) {
                    return caseIndentStore[switchNode.loc.start.line];
                }
                if (switchNode.cases.length > 0 && options.SwitchCase === 0) {
                    caseIndent = switchIndent;
                }
                else {
                    caseIndent = switchIndent + (indentSize * options.SwitchCase);
                }
                caseIndentStore[switchNode.loc.start.line] = caseIndent;
                return caseIndent;
            }
            /**
             * Checks whether a return statement is wrapped in ()
             * @param {ASTNode} node node to examine
             * @returns {boolean} the result
             */
            function isWrappedInParenthesis(node) {
                const regex = /^return\s*?\(\s*?\);*?/u;
                const statementWithoutArgument = sourceCode.getText(node).replace(sourceCode.getText(node.argument), "");
                return regex.test(statementWithoutArgument);
            }
            return {
                Program(node) {
                    if (node.body.length > 0) {
                        // Root nodes should have no indent
                        checkNodesIndent(node.body, getNodeIndent(node).goodChar);
                    }
                },
                ClassBody: blockIndentationCheck,
                BlockStatement: blockIndentationCheck,
                WhileStatement: blockLessNodes,
                ForStatement: blockLessNodes,
                ForInStatement: blockLessNodes,
                ForOfStatement: blockLessNodes,
                DoWhileStatement: blockLessNodes,
                IfStatement(node) {
                    if (node.consequent.type !== "BlockStatement" && node.consequent.loc.start.line > node.loc.start.line) {
                        blockIndentationCheck(node);
                    }
                },
                VariableDeclaration(node) {
                    if (node.declarations[node.declarations.length - 1].loc.start.line > node.declarations[0].loc.start.line) {
                        checkIndentInVariableDeclarations(node);
                    }
                },
                ObjectExpression(node) {
                    checkIndentInArrayOrObjectBlock(node);
                },
                ArrayExpression(node) {
                    checkIndentInArrayOrObjectBlock(node);
                },
                MemberExpression(node) {
                    if (typeof options.MemberExpression === "undefined") {
                        return;
                    }
                    if (isSingleLineNode(node)) {
                        return;
                    }
                    /*
                     * The typical layout of variable declarations and assignments
                     * alter the expectation of correct indentation. Skip them.
                     * TODO: Add appropriate configuration options for variable
                     * declarations and assignments.
                     */
                    if (getParentNodeByType(node, "VariableDeclarator", ["FunctionExpression", "ArrowFunctionExpression"])) {
                        return;
                    }
                    if (getParentNodeByType(node, "AssignmentExpression", ["FunctionExpression"])) {
                        return;
                    }
                    const propertyIndent = getNodeIndent(node).goodChar + indentSize * options.MemberExpression;
                    const checkNodes = [node.property];
                    const dot = sourceCode.getTokenBefore(node.property);
                    if (dot.type === "Punctuator" && dot.value === ".") {
                        checkNodes.push(dot);
                    }
                    checkNodesIndent(checkNodes, propertyIndent);
                },
                SwitchStatement(node) {
                    // Switch is not a 'BlockStatement'
                    const switchIndent = getNodeIndent(node).goodChar;
                    const caseIndent = expectedCaseIndent(node, switchIndent);
                    checkNodesIndent(node.cases, caseIndent);
                    checkLastNodeLineIndent(node, switchIndent);
                },
                SwitchCase(node) {
                    // Skip inline cases
                    if (isSingleLineNode(node)) {
                        return;
                    }
                    const caseIndent = expectedCaseIndent(node);
                    checkNodesIndent(node.consequent, caseIndent + indentSize);
                },
                FunctionDeclaration(node) {
                    if (isSingleLineNode(node)) {
                        return;
                    }
                    if (options.FunctionDeclaration.parameters === "first" && node.params.length) {
                        checkNodesIndent(node.params.slice(1), node.params[0].loc.start.column);
                    }
                    else if (options.FunctionDeclaration.parameters !== null) {
                        checkNodesIndent(node.params, getNodeIndent(node).goodChar + indentSize * options.FunctionDeclaration.parameters);
                    }
                },
                FunctionExpression(node) {
                    if (isSingleLineNode(node)) {
                        return;
                    }
                    if (options.FunctionExpression.parameters === "first" && node.params.length) {
                        checkNodesIndent(node.params.slice(1), node.params[0].loc.start.column);
                    }
                    else if (options.FunctionExpression.parameters !== null) {
                        checkNodesIndent(node.params, getNodeIndent(node).goodChar + indentSize * options.FunctionExpression.parameters);
                    }
                },
                ReturnStatement(node) {
                    if (isSingleLineNode(node)) {
                        return;
                    }
                    const firstLineIndent = getNodeIndent(node).goodChar;
                    // in case if return statement is wrapped in parenthesis
                    if (isWrappedInParenthesis(node)) {
                        checkLastReturnStatementLineIndent(node, firstLineIndent);
                    }
                    else {
                        checkNodeIndent(node, firstLineIndent);
                    }
                },
                CallExpression(node) {
                    if (isSingleLineNode(node)) {
                        return;
                    }
                    if (options.CallExpression.arguments === "first" && node.arguments.length) {
                        checkNodesIndent(node.arguments.slice(1), node.arguments[0].loc.start.column);
                    }
                    else if (options.CallExpression.arguments !== null) {
                        checkNodesIndent(node.arguments, getNodeIndent(node).goodChar + indentSize * options.CallExpression.arguments);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/init-declarations.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to control the style of variable initializations.
     * @author Colin Ihrig
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a given node is a for loop.
     * @param {ASTNode} block A node to check.
     * @returns {boolean} `true` when the node is a for loop.
     */
    function isForLoop(block) {
        return block.type === "ForInStatement" ||
            block.type === "ForOfStatement" ||
            block.type === "ForStatement";
    }
    /**
     * Checks whether or not a given declarator node has its initializer.
     * @param {ASTNode} node A declarator node to check.
     * @returns {boolean} `true` when the node has its initializer.
     */
    function isInitialized(node) {
        const declaration = node.parent;
        const block = declaration.parent;
        if (isForLoop(block)) {
            if (block.type === "ForStatement") {
                return block.init === declaration;
            }
            return block.left === declaration;
        }
        return Boolean(node.init);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require or disallow initialization in variable declarations",
                recommended: false,
                url: "https://eslint.org/docs/rules/init-declarations"
            },
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always"]
                            }
                        ],
                        minItems: 0,
                        maxItems: 1
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["never"]
                            },
                            {
                                type: "object",
                                properties: {
                                    ignoreForLoopInit: {
                                        type: "boolean"
                                    }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    }
                ]
            },
            messages: {
                initialized: "Variable '{{idName}}' should be initialized on declaration.",
                notInitialized: "Variable '{{idName}}' should not be initialized on declaration."
            }
        },
        create(context) {
            const MODE_ALWAYS = "always", MODE_NEVER = "never";
            const mode = context.options[0] || MODE_ALWAYS;
            const params = context.options[1] || {};
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                "VariableDeclaration:exit"(node) {
                    const kind = node.kind, declarations = node.declarations;
                    for (let i = 0; i < declarations.length; ++i) {
                        const declaration = declarations[i], id = declaration.id, initialized = isInitialized(declaration), isIgnoredForLoop = params.ignoreForLoopInit && isForLoop(node.parent);
                        let messageId = "";
                        if (mode === MODE_ALWAYS && !initialized) {
                            messageId = "initialized";
                        }
                        else if (mode === MODE_NEVER && kind !== "const" && initialized && !isIgnoredForLoop) {
                            messageId = "notInitialized";
                        }
                        if (id.type === "Identifier" && messageId) {
                            context.report({
                                node: declaration,
                                messageId,
                                data: {
                                    idName: id.name
                                }
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/jsx-quotes.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to ensure consistent quotes used in jsx syntax.
     * @author Mathias Schreck <https://github.com/lo1tuma>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Constants
    //------------------------------------------------------------------------------
    const QUOTE_SETTINGS = {
        "prefer-double": {
            quote: "\"",
            description: "singlequote",
            convert(str) {
                return str.replace(/'/gu, "\"");
            }
        },
        "prefer-single": {
            quote: "'",
            description: "doublequote",
            convert(str) {
                return str.replace(/"/gu, "'");
            }
        }
    };
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce the consistent use of either double or single quotes in JSX attributes",
                recommended: false,
                url: "https://eslint.org/docs/rules/jsx-quotes"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["prefer-single", "prefer-double"]
                }
            ],
            messages: {
                unexpected: "Unexpected usage of {{description}}."
            }
        },
        create(context) {
            const quoteOption = context.options[0] || "prefer-double", setting = QUOTE_SETTINGS[quoteOption];
            /**
             * Checks if the given string literal node uses the expected quotes
             * @param {ASTNode} node A string literal node.
             * @returns {boolean} Whether or not the string literal used the expected quotes.
             * @public
             */
            function usesExpectedQuotes(node) {
                return node.value.includes(setting.quote) || astUtils.isSurroundedBy(node.raw, setting.quote);
            }
            return {
                JSXAttribute(node) {
                    const attributeValue = node.value;
                    if (attributeValue && astUtils.isStringLiteral(attributeValue) && !usesExpectedQuotes(attributeValue)) {
                        context.report({
                            node: attributeValue,
                            messageId: "unexpected",
                            data: {
                                description: setting.description
                            },
                            fix(fixer) {
                                return fixer.replaceText(attributeValue, setting.convert(attributeValue.raw));
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/key-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to specify spacing of object literal keys and values
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const GraphemeSplitter = require(414) /* grapheme-splitter */;
    const splitter = new GraphemeSplitter();
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether a string contains a line terminator as defined in
     * http://www.ecma-international.org/ecma-262/5.1/#sec-7.3
     * @param {string} str String to test.
     * @returns {boolean} True if str contains a line terminator.
     */
    function containsLineTerminator(str) {
        return astUtils.LINEBREAK_MATCHER.test(str);
    }
    /**
     * Gets the last element of an array.
     * @param {Array} arr An array.
     * @returns {any} Last element of arr.
     */
    function last(arr) {
        return arr[arr.length - 1];
    }
    /**
     * Checks whether a node is contained on a single line.
     * @param {ASTNode} node AST Node being evaluated.
     * @returns {boolean} True if the node is a single line.
     */
    function isSingleLine(node) {
        return (node.loc.end.line === node.loc.start.line);
    }
    /**
     * Checks whether the properties on a single line.
     * @param {ASTNode[]} properties List of Property AST nodes.
     * @returns {boolean} True if all properties is on a single line.
     */
    function isSingleLineProperties(properties) {
        const [firstProp] = properties, lastProp = last(properties);
        return firstProp.loc.start.line === lastProp.loc.end.line;
    }
    /**
     * Initializes a single option property from the configuration with defaults for undefined values
     * @param {Object} toOptions Object to be initialized
     * @param {Object} fromOptions Object to be initialized from
     * @returns {Object} The object with correctly initialized options and values
     */
    function initOptionProperty(toOptions, fromOptions) {
        toOptions.mode = fromOptions.mode || "strict";
        // Set value of beforeColon
        if (typeof fromOptions.beforeColon !== "undefined") {
            toOptions.beforeColon = +fromOptions.beforeColon;
        }
        else {
            toOptions.beforeColon = 0;
        }
        // Set value of afterColon
        if (typeof fromOptions.afterColon !== "undefined") {
            toOptions.afterColon = +fromOptions.afterColon;
        }
        else {
            toOptions.afterColon = 1;
        }
        // Set align if exists
        if (typeof fromOptions.align !== "undefined") {
            if (typeof fromOptions.align === "object") {
                toOptions.align = fromOptions.align;
            }
            else { // "string"
                toOptions.align = {
                    on: fromOptions.align,
                    mode: toOptions.mode,
                    beforeColon: toOptions.beforeColon,
                    afterColon: toOptions.afterColon
                };
            }
        }
        return toOptions;
    }
    /**
     * Initializes all the option values (singleLine, multiLine and align) from the configuration with defaults for undefined values
     * @param {Object} toOptions Object to be initialized
     * @param {Object} fromOptions Object to be initialized from
     * @returns {Object} The object with correctly initialized options and values
     */
    function initOptions(toOptions, fromOptions) {
        if (typeof fromOptions.align === "object") {
            // Initialize the alignment configuration
            toOptions.align = initOptionProperty({}, fromOptions.align);
            toOptions.align.on = fromOptions.align.on || "colon";
            toOptions.align.mode = fromOptions.align.mode || "strict";
            toOptions.multiLine = initOptionProperty({}, (fromOptions.multiLine || fromOptions));
            toOptions.singleLine = initOptionProperty({}, (fromOptions.singleLine || fromOptions));
        }
        else { // string or undefined
            toOptions.multiLine = initOptionProperty({}, (fromOptions.multiLine || fromOptions));
            toOptions.singleLine = initOptionProperty({}, (fromOptions.singleLine || fromOptions));
            // If alignment options are defined in multiLine, pull them out into the general align configuration
            if (toOptions.multiLine.align) {
                toOptions.align = {
                    on: toOptions.multiLine.align.on,
                    mode: toOptions.multiLine.align.mode || toOptions.multiLine.mode,
                    beforeColon: toOptions.multiLine.align.beforeColon,
                    afterColon: toOptions.multiLine.align.afterColon
                };
            }
        }
        return toOptions;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing between keys and values in object literal properties",
                recommended: false,
                url: "https://eslint.org/docs/rules/key-spacing"
            },
            fixable: "whitespace",
            schema: [{
                    anyOf: [
                        {
                            type: "object",
                            properties: {
                                align: {
                                    anyOf: [
                                        {
                                            enum: ["colon", "value"]
                                        },
                                        {
                                            type: "object",
                                            properties: {
                                                mode: {
                                                    enum: ["strict", "minimum"]
                                                },
                                                on: {
                                                    enum: ["colon", "value"]
                                                },
                                                beforeColon: {
                                                    type: "boolean"
                                                },
                                                afterColon: {
                                                    type: "boolean"
                                                }
                                            },
                                            additionalProperties: false
                                        }
                                    ]
                                },
                                mode: {
                                    enum: ["strict", "minimum"]
                                },
                                beforeColon: {
                                    type: "boolean"
                                },
                                afterColon: {
                                    type: "boolean"
                                }
                            },
                            additionalProperties: false
                        },
                        {
                            type: "object",
                            properties: {
                                singleLine: {
                                    type: "object",
                                    properties: {
                                        mode: {
                                            enum: ["strict", "minimum"]
                                        },
                                        beforeColon: {
                                            type: "boolean"
                                        },
                                        afterColon: {
                                            type: "boolean"
                                        }
                                    },
                                    additionalProperties: false
                                },
                                multiLine: {
                                    type: "object",
                                    properties: {
                                        align: {
                                            anyOf: [
                                                {
                                                    enum: ["colon", "value"]
                                                },
                                                {
                                                    type: "object",
                                                    properties: {
                                                        mode: {
                                                            enum: ["strict", "minimum"]
                                                        },
                                                        on: {
                                                            enum: ["colon", "value"]
                                                        },
                                                        beforeColon: {
                                                            type: "boolean"
                                                        },
                                                        afterColon: {
                                                            type: "boolean"
                                                        }
                                                    },
                                                    additionalProperties: false
                                                }
                                            ]
                                        },
                                        mode: {
                                            enum: ["strict", "minimum"]
                                        },
                                        beforeColon: {
                                            type: "boolean"
                                        },
                                        afterColon: {
                                            type: "boolean"
                                        }
                                    },
                                    additionalProperties: false
                                }
                            },
                            additionalProperties: false
                        },
                        {
                            type: "object",
                            properties: {
                                singleLine: {
                                    type: "object",
                                    properties: {
                                        mode: {
                                            enum: ["strict", "minimum"]
                                        },
                                        beforeColon: {
                                            type: "boolean"
                                        },
                                        afterColon: {
                                            type: "boolean"
                                        }
                                    },
                                    additionalProperties: false
                                },
                                multiLine: {
                                    type: "object",
                                    properties: {
                                        mode: {
                                            enum: ["strict", "minimum"]
                                        },
                                        beforeColon: {
                                            type: "boolean"
                                        },
                                        afterColon: {
                                            type: "boolean"
                                        }
                                    },
                                    additionalProperties: false
                                },
                                align: {
                                    type: "object",
                                    properties: {
                                        mode: {
                                            enum: ["strict", "minimum"]
                                        },
                                        on: {
                                            enum: ["colon", "value"]
                                        },
                                        beforeColon: {
                                            type: "boolean"
                                        },
                                        afterColon: {
                                            type: "boolean"
                                        }
                                    },
                                    additionalProperties: false
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }],
            messages: {
                extraKey: "Extra space after {{computed}}key '{{key}}'.",
                extraValue: "Extra space before value for {{computed}}key '{{key}}'.",
                missingKey: "Missing space after {{computed}}key '{{key}}'.",
                missingValue: "Missing space before value for {{computed}}key '{{key}}'."
            }
        },
        create(context) {
            /**
             * OPTIONS
             * "key-spacing": [2, {
             *     beforeColon: false,
             *     afterColon: true,
             *     align: "colon" // Optional, or "value"
             * }
             */
            const options = context.options[0] || {}, ruleOptions = initOptions({}, options), multiLineOptions = ruleOptions.multiLine, singleLineOptions = ruleOptions.singleLine, alignmentOptions = ruleOptions.align || null;
            const sourceCode = context.getSourceCode();
            /**
             * Determines if the given property is key-value property.
             * @param {ASTNode} property Property node to check.
             * @returns {boolean} Whether the property is a key-value property.
             */
            function isKeyValueProperty(property) {
                return !((property.method ||
                    property.shorthand ||
                    property.kind !== "init" || property.type !== "Property") // Could be "ExperimentalSpreadProperty" or "SpreadElement"
                );
            }
            /**
             * Starting from the given node (a property.key node here) looks forward
             * until it finds the colon punctuator and returns it.
             * @param {ASTNode} node The node to start looking from.
             * @returns {ASTNode} The colon punctuator.
             */
            function getNextColon(node) {
                return sourceCode.getTokenAfter(node, astUtils.isColonToken);
            }
            /**
             * Starting from the given node (a property.key node here) looks forward
             * until it finds the last token before a colon punctuator and returns it.
             * @param {ASTNode} node The node to start looking from.
             * @returns {ASTNode} The last token before a colon punctuator.
             */
            function getLastTokenBeforeColon(node) {
                const colonToken = getNextColon(node);
                return sourceCode.getTokenBefore(colonToken);
            }
            /**
             * Starting from the given node (a property.key node here) looks forward
             * until it finds the first token after a colon punctuator and returns it.
             * @param {ASTNode} node The node to start looking from.
             * @returns {ASTNode} The first token after a colon punctuator.
             */
            function getFirstTokenAfterColon(node) {
                const colonToken = getNextColon(node);
                return sourceCode.getTokenAfter(colonToken);
            }
            /**
             * Checks whether a property is a member of the property group it follows.
             * @param {ASTNode} lastMember The last Property known to be in the group.
             * @param {ASTNode} candidate The next Property that might be in the group.
             * @returns {boolean} True if the candidate property is part of the group.
             */
            function continuesPropertyGroup(lastMember, candidate) {
                const groupEndLine = lastMember.loc.start.line, candidateValueStartLine = (isKeyValueProperty(candidate) ? getFirstTokenAfterColon(candidate.key) : candidate).loc.start.line;
                if (candidateValueStartLine - groupEndLine <= 1) {
                    return true;
                }
                /*
                 * Check that the first comment is adjacent to the end of the group, the
                 * last comment is adjacent to the candidate property, and that successive
                 * comments are adjacent to each other.
                 */
                const leadingComments = sourceCode.getCommentsBefore(candidate);
                if (leadingComments.length &&
                    leadingComments[0].loc.start.line - groupEndLine <= 1 &&
                    candidateValueStartLine - last(leadingComments).loc.end.line <= 1) {
                    for (let i = 1; i < leadingComments.length; i++) {
                        if (leadingComments[i].loc.start.line - leadingComments[i - 1].loc.end.line > 1) {
                            return false;
                        }
                    }
                    return true;
                }
                return false;
            }
            /**
             * Gets an object literal property's key as the identifier name or string value.
             * @param {ASTNode} property Property node whose key to retrieve.
             * @returns {string} The property's key.
             */
            function getKey(property) {
                const key = property.key;
                if (property.computed) {
                    return sourceCode.getText().slice(key.range[0], key.range[1]);
                }
                return astUtils.getStaticPropertyName(property);
            }
            /**
             * Reports an appropriately-formatted error if spacing is incorrect on one
             * side of the colon.
             * @param {ASTNode} property Key-value pair in an object literal.
             * @param {string} side Side being verified - either "key" or "value".
             * @param {string} whitespace Actual whitespace string.
             * @param {int} expected Expected whitespace length.
             * @param {string} mode Value of the mode as "strict" or "minimum"
             * @returns {void}
             */
            function report(property, side, whitespace, expected, mode) {
                const diff = whitespace.length - expected;
                if ((diff && mode === "strict" ||
                    diff < 0 && mode === "minimum" ||
                    diff > 0 && !expected && mode === "minimum") &&
                    !(expected && containsLineTerminator(whitespace))) {
                    const nextColon = getNextColon(property.key), tokenBeforeColon = sourceCode.getTokenBefore(nextColon, { includeComments: true }), tokenAfterColon = sourceCode.getTokenAfter(nextColon, { includeComments: true }), isKeySide = side === "key", isExtra = diff > 0, diffAbs = Math.abs(diff), spaces = Array(diffAbs + 1).join(" ");
                    const locStart = isKeySide ? tokenBeforeColon.loc.end : nextColon.loc.start;
                    const locEnd = isKeySide ? nextColon.loc.start : tokenAfterColon.loc.start;
                    const missingLoc = isKeySide ? tokenBeforeColon.loc : tokenAfterColon.loc;
                    const loc = isExtra ? { start: locStart, end: locEnd } : missingLoc;
                    let fix;
                    if (isExtra) {
                        let range;
                        // Remove whitespace
                        if (isKeySide) {
                            range = [tokenBeforeColon.range[1], tokenBeforeColon.range[1] + diffAbs];
                        }
                        else {
                            range = [tokenAfterColon.range[0] - diffAbs, tokenAfterColon.range[0]];
                        }
                        fix = function (fixer) {
                            return fixer.removeRange(range);
                        };
                    }
                    else {
                        // Add whitespace
                        if (isKeySide) {
                            fix = function (fixer) {
                                return fixer.insertTextAfter(tokenBeforeColon, spaces);
                            };
                        }
                        else {
                            fix = function (fixer) {
                                return fixer.insertTextBefore(tokenAfterColon, spaces);
                            };
                        }
                    }
                    let messageId = "";
                    if (isExtra) {
                        messageId = side === "key" ? "extraKey" : "extraValue";
                    }
                    else {
                        messageId = side === "key" ? "missingKey" : "missingValue";
                    }
                    context.report({
                        node: property[side],
                        loc,
                        messageId,
                        data: {
                            computed: property.computed ? "computed " : "",
                            key: getKey(property)
                        },
                        fix
                    });
                }
            }
            /**
             * Gets the number of characters in a key, including quotes around string
             * keys and braces around computed property keys.
             * @param {ASTNode} property Property of on object literal.
             * @returns {int} Width of the key.
             */
            function getKeyWidth(property) {
                const startToken = sourceCode.getFirstToken(property);
                const endToken = getLastTokenBeforeColon(property.key);
                return splitter.countGraphemes(sourceCode.getText().slice(startToken.range[0], endToken.range[1]));
            }
            /**
             * Gets the whitespace around the colon in an object literal property.
             * @param {ASTNode} property Property node from an object literal.
             * @returns {Object} Whitespace before and after the property's colon.
             */
            function getPropertyWhitespace(property) {
                const whitespace = /(\s*):(\s*)/u.exec(sourceCode.getText().slice(property.key.range[1], property.value.range[0]));
                if (whitespace) {
                    return {
                        beforeColon: whitespace[1],
                        afterColon: whitespace[2]
                    };
                }
                return null;
            }
            /**
             * Creates groups of properties.
             * @param {ASTNode} node ObjectExpression node being evaluated.
             * @returns {Array<ASTNode[]>} Groups of property AST node lists.
             */
            function createGroups(node) {
                if (node.properties.length === 1) {
                    return [node.properties];
                }
                return node.properties.reduce((groups, property) => {
                    const currentGroup = last(groups), prev = last(currentGroup);
                    if (!prev || continuesPropertyGroup(prev, property)) {
                        currentGroup.push(property);
                    }
                    else {
                        groups.push([property]);
                    }
                    return groups;
                }, [
                    []
                ]);
            }
            /**
             * Verifies correct vertical alignment of a group of properties.
             * @param {ASTNode[]} properties List of Property AST nodes.
             * @returns {void}
             */
            function verifyGroupAlignment(properties) {
                const length = properties.length, widths = properties.map(getKeyWidth), // Width of keys, including quotes
                align = alignmentOptions.on; // "value" or "colon"
                let targetWidth = Math.max(...widths), beforeColon, afterColon, mode;
                if (alignmentOptions && length > 1) { // When aligning values within a group, use the alignment configuration.
                    beforeColon = alignmentOptions.beforeColon;
                    afterColon = alignmentOptions.afterColon;
                    mode = alignmentOptions.mode;
                }
                else {
                    beforeColon = multiLineOptions.beforeColon;
                    afterColon = multiLineOptions.afterColon;
                    mode = alignmentOptions.mode;
                }
                // Conditionally include one space before or after colon
                targetWidth += (align === "colon" ? beforeColon : afterColon);
                for (let i = 0; i < length; i++) {
                    const property = properties[i];
                    const whitespace = getPropertyWhitespace(property);
                    if (whitespace) { // Object literal getters/setters lack a colon
                        const width = widths[i];
                        if (align === "value") {
                            report(property, "key", whitespace.beforeColon, beforeColon, mode);
                            report(property, "value", whitespace.afterColon, targetWidth - width, mode);
                        }
                        else { // align = "colon"
                            report(property, "key", whitespace.beforeColon, targetWidth - width, mode);
                            report(property, "value", whitespace.afterColon, afterColon, mode);
                        }
                    }
                }
            }
            /**
             * Verifies spacing of property conforms to specified options.
             * @param {ASTNode} node Property node being evaluated.
             * @param {Object} lineOptions Configured singleLine or multiLine options
             * @returns {void}
             */
            function verifySpacing(node, lineOptions) {
                const actual = getPropertyWhitespace(node);
                if (actual) { // Object literal getters/setters lack colons
                    report(node, "key", actual.beforeColon, lineOptions.beforeColon, lineOptions.mode);
                    report(node, "value", actual.afterColon, lineOptions.afterColon, lineOptions.mode);
                }
            }
            /**
             * Verifies spacing of each property in a list.
             * @param {ASTNode[]} properties List of Property AST nodes.
             * @param {Object} lineOptions Configured singleLine or multiLine options
             * @returns {void}
             */
            function verifyListSpacing(properties, lineOptions) {
                const length = properties.length;
                for (let i = 0; i < length; i++) {
                    verifySpacing(properties[i], lineOptions);
                }
            }
            /**
             * Verifies vertical alignment, taking into account groups of properties.
             * @param {ASTNode} node ObjectExpression node being evaluated.
             * @returns {void}
             */
            function verifyAlignment(node) {
                createGroups(node).forEach(group => {
                    const properties = group.filter(isKeyValueProperty);
                    if (properties.length > 0 && isSingleLineProperties(properties)) {
                        verifyListSpacing(properties, multiLineOptions);
                    }
                    else {
                        verifyGroupAlignment(properties);
                    }
                });
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            if (alignmentOptions) { // Verify vertical alignment
                return {
                    ObjectExpression(node) {
                        if (isSingleLine(node)) {
                            verifyListSpacing(node.properties.filter(isKeyValueProperty), singleLineOptions);
                        }
                        else {
                            verifyAlignment(node);
                        }
                    }
                };
            }
            // Obey beforeColon and afterColon in each property as configured
            return {
                Property(node) {
                    verifySpacing(node, isSingleLine(node.parent) ? singleLineOptions : multiLineOptions);
                }
            };
        }
    };
},
/* eslint/lib/rules/keyword-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce spacing before and after keywords.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */, keywords = require(395) /* ./utils/keywords */;
    //------------------------------------------------------------------------------
    // Constants
    //------------------------------------------------------------------------------
    const PREV_TOKEN = /^[)\]}>]$/u;
    const NEXT_TOKEN = /^(?:[([{<~!]|\+\+?|--?)$/u;
    const PREV_TOKEN_M = /^[)\]}>*]$/u;
    const NEXT_TOKEN_M = /^[{*]$/u;
    const TEMPLATE_OPEN_PAREN = /\$\{$/u;
    const TEMPLATE_CLOSE_PAREN = /^\}/u;
    const CHECK_TYPE = /^(?:JSXElement|RegularExpression|String|Template|PrivateIdentifier)$/u;
    const KEYS = keywords.concat(["as", "async", "await", "from", "get", "let", "of", "set", "yield"]);
    // check duplications.
    (function () {
        KEYS.sort();
        for (let i = 1; i < KEYS.length; ++i) {
            if (KEYS[i] === KEYS[i - 1]) {
                throw new Error(`Duplication was found in the keyword list: ${KEYS[i]}`);
            }
        }
    }());
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a given token is a "Template" token ends with "${".
     * @param {Token} token A token to check.
     * @returns {boolean} `true` if the token is a "Template" token ends with "${".
     */
    function isOpenParenOfTemplate(token) {
        return token.type === "Template" && TEMPLATE_OPEN_PAREN.test(token.value);
    }
    /**
     * Checks whether or not a given token is a "Template" token starts with "}".
     * @param {Token} token A token to check.
     * @returns {boolean} `true` if the token is a "Template" token starts with "}".
     */
    function isCloseParenOfTemplate(token) {
        return token.type === "Template" && TEMPLATE_CLOSE_PAREN.test(token.value);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing before and after keywords",
                recommended: false,
                url: "https://eslint.org/docs/rules/keyword-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        before: { type: "boolean", default: true },
                        after: { type: "boolean", default: true },
                        overrides: {
                            type: "object",
                            properties: KEYS.reduce((retv, key) => {
                                retv[key] = {
                                    type: "object",
                                    properties: {
                                        before: { type: "boolean" },
                                        after: { type: "boolean" }
                                    },
                                    additionalProperties: false
                                };
                                return retv;
                            }, {}),
                            additionalProperties: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                expectedBefore: "Expected space(s) before \"{{value}}\".",
                expectedAfter: "Expected space(s) after \"{{value}}\".",
                unexpectedBefore: "Unexpected space(s) before \"{{value}}\".",
                unexpectedAfter: "Unexpected space(s) after \"{{value}}\"."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const tokensToIgnore = new WeakSet();
            /**
             * Reports a given token if there are not space(s) before the token.
             * @param {Token} token A token to report.
             * @param {RegExp} pattern A pattern of the previous token to check.
             * @returns {void}
             */
            function expectSpaceBefore(token, pattern) {
                const prevToken = sourceCode.getTokenBefore(token);
                if (prevToken &&
                    (CHECK_TYPE.test(prevToken.type) || pattern.test(prevToken.value)) &&
                    !isOpenParenOfTemplate(prevToken) &&
                    !tokensToIgnore.has(prevToken) &&
                    astUtils.isTokenOnSameLine(prevToken, token) &&
                    !sourceCode.isSpaceBetweenTokens(prevToken, token)) {
                    context.report({
                        loc: token.loc,
                        messageId: "expectedBefore",
                        data: token,
                        fix(fixer) {
                            return fixer.insertTextBefore(token, " ");
                        }
                    });
                }
            }
            /**
             * Reports a given token if there are space(s) before the token.
             * @param {Token} token A token to report.
             * @param {RegExp} pattern A pattern of the previous token to check.
             * @returns {void}
             */
            function unexpectSpaceBefore(token, pattern) {
                const prevToken = sourceCode.getTokenBefore(token);
                if (prevToken &&
                    (CHECK_TYPE.test(prevToken.type) || pattern.test(prevToken.value)) &&
                    !isOpenParenOfTemplate(prevToken) &&
                    !tokensToIgnore.has(prevToken) &&
                    astUtils.isTokenOnSameLine(prevToken, token) &&
                    sourceCode.isSpaceBetweenTokens(prevToken, token)) {
                    context.report({
                        loc: { start: prevToken.loc.end, end: token.loc.start },
                        messageId: "unexpectedBefore",
                        data: token,
                        fix(fixer) {
                            return fixer.removeRange([prevToken.range[1], token.range[0]]);
                        }
                    });
                }
            }
            /**
             * Reports a given token if there are not space(s) after the token.
             * @param {Token} token A token to report.
             * @param {RegExp} pattern A pattern of the next token to check.
             * @returns {void}
             */
            function expectSpaceAfter(token, pattern) {
                const nextToken = sourceCode.getTokenAfter(token);
                if (nextToken &&
                    (CHECK_TYPE.test(nextToken.type) || pattern.test(nextToken.value)) &&
                    !isCloseParenOfTemplate(nextToken) &&
                    !tokensToIgnore.has(nextToken) &&
                    astUtils.isTokenOnSameLine(token, nextToken) &&
                    !sourceCode.isSpaceBetweenTokens(token, nextToken)) {
                    context.report({
                        loc: token.loc,
                        messageId: "expectedAfter",
                        data: token,
                        fix(fixer) {
                            return fixer.insertTextAfter(token, " ");
                        }
                    });
                }
            }
            /**
             * Reports a given token if there are space(s) after the token.
             * @param {Token} token A token to report.
             * @param {RegExp} pattern A pattern of the next token to check.
             * @returns {void}
             */
            function unexpectSpaceAfter(token, pattern) {
                const nextToken = sourceCode.getTokenAfter(token);
                if (nextToken &&
                    (CHECK_TYPE.test(nextToken.type) || pattern.test(nextToken.value)) &&
                    !isCloseParenOfTemplate(nextToken) &&
                    !tokensToIgnore.has(nextToken) &&
                    astUtils.isTokenOnSameLine(token, nextToken) &&
                    sourceCode.isSpaceBetweenTokens(token, nextToken)) {
                    context.report({
                        loc: { start: token.loc.end, end: nextToken.loc.start },
                        messageId: "unexpectedAfter",
                        data: token,
                        fix(fixer) {
                            return fixer.removeRange([token.range[1], nextToken.range[0]]);
                        }
                    });
                }
            }
            /**
             * Parses the option object and determines check methods for each keyword.
             * @param {Object|undefined} options The option object to parse.
             * @returns {Object} - Normalized option object.
             *      Keys are keywords (there are for every keyword).
             *      Values are instances of `{"before": function, "after": function}`.
             */
            function parseOptions(options = {}) {
                const before = options.before !== false;
                const after = options.after !== false;
                const defaultValue = {
                    before: before ? expectSpaceBefore : unexpectSpaceBefore,
                    after: after ? expectSpaceAfter : unexpectSpaceAfter
                };
                const overrides = (options && options.overrides) || {};
                const retv = Object.create(null);
                for (let i = 0; i < KEYS.length; ++i) {
                    const key = KEYS[i];
                    const override = overrides[key];
                    if (override) {
                        const thisBefore = ("before" in override) ? override.before : before;
                        const thisAfter = ("after" in override) ? override.after : after;
                        retv[key] = {
                            before: thisBefore ? expectSpaceBefore : unexpectSpaceBefore,
                            after: thisAfter ? expectSpaceAfter : unexpectSpaceAfter
                        };
                    }
                    else {
                        retv[key] = defaultValue;
                    }
                }
                return retv;
            }
            const checkMethodMap = parseOptions(context.options[0]);
            /**
             * Reports a given token if usage of spacing followed by the token is
             * invalid.
             * @param {Token} token A token to report.
             * @param {RegExp} [pattern] Optional. A pattern of the previous
             *      token to check.
             * @returns {void}
             */
            function checkSpacingBefore(token, pattern) {
                checkMethodMap[token.value].before(token, pattern || PREV_TOKEN);
            }
            /**
             * Reports a given token if usage of spacing preceded by the token is
             * invalid.
             * @param {Token} token A token to report.
             * @param {RegExp} [pattern] Optional. A pattern of the next
             *      token to check.
             * @returns {void}
             */
            function checkSpacingAfter(token, pattern) {
                checkMethodMap[token.value].after(token, pattern || NEXT_TOKEN);
            }
            /**
             * Reports a given token if usage of spacing around the token is invalid.
             * @param {Token} token A token to report.
             * @returns {void}
             */
            function checkSpacingAround(token) {
                checkSpacingBefore(token);
                checkSpacingAfter(token);
            }
            /**
             * Reports the first token of a given node if the first token is a keyword
             * and usage of spacing around the token is invalid.
             * @param {ASTNode|null} node A node to report.
             * @returns {void}
             */
            function checkSpacingAroundFirstToken(node) {
                const firstToken = node && sourceCode.getFirstToken(node);
                if (firstToken && firstToken.type === "Keyword") {
                    checkSpacingAround(firstToken);
                }
            }
            /**
             * Reports the first token of a given node if the first token is a keyword
             * and usage of spacing followed by the token is invalid.
             *
             * This is used for unary operators (e.g. `typeof`), `function`, and `super`.
             * Other rules are handling usage of spacing preceded by those keywords.
             * @param {ASTNode|null} node A node to report.
             * @returns {void}
             */
            function checkSpacingBeforeFirstToken(node) {
                const firstToken = node && sourceCode.getFirstToken(node);
                if (firstToken && firstToken.type === "Keyword") {
                    checkSpacingBefore(firstToken);
                }
            }
            /**
             * Reports the previous token of a given node if the token is a keyword and
             * usage of spacing around the token is invalid.
             * @param {ASTNode|null} node A node to report.
             * @returns {void}
             */
            function checkSpacingAroundTokenBefore(node) {
                if (node) {
                    const token = sourceCode.getTokenBefore(node, astUtils.isKeywordToken);
                    checkSpacingAround(token);
                }
            }
            /**
             * Reports `async` or `function` keywords of a given node if usage of
             * spacing around those keywords is invalid.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForFunction(node) {
                const firstToken = node && sourceCode.getFirstToken(node);
                if (firstToken &&
                    ((firstToken.type === "Keyword" && firstToken.value === "function") ||
                        firstToken.value === "async")) {
                    checkSpacingBefore(firstToken);
                }
            }
            /**
             * Reports `class` and `extends` keywords of a given node if usage of
             * spacing around those keywords is invalid.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForClass(node) {
                checkSpacingAroundFirstToken(node);
                checkSpacingAroundTokenBefore(node.superClass);
            }
            /**
             * Reports `if` and `else` keywords of a given node if usage of spacing
             * around those keywords is invalid.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForIfStatement(node) {
                checkSpacingAroundFirstToken(node);
                checkSpacingAroundTokenBefore(node.alternate);
            }
            /**
             * Reports `try`, `catch`, and `finally` keywords of a given node if usage
             * of spacing around those keywords is invalid.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForTryStatement(node) {
                checkSpacingAroundFirstToken(node);
                checkSpacingAroundFirstToken(node.handler);
                checkSpacingAroundTokenBefore(node.finalizer);
            }
            /**
             * Reports `do` and `while` keywords of a given node if usage of spacing
             * around those keywords is invalid.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForDoWhileStatement(node) {
                checkSpacingAroundFirstToken(node);
                checkSpacingAroundTokenBefore(node.test);
            }
            /**
             * Reports `for` and `in` keywords of a given node if usage of spacing
             * around those keywords is invalid.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForForInStatement(node) {
                checkSpacingAroundFirstToken(node);
                const inToken = sourceCode.getTokenBefore(node.right, astUtils.isNotOpeningParenToken);
                const previousToken = sourceCode.getTokenBefore(inToken);
                if (previousToken.type !== "PrivateIdentifier") {
                    checkSpacingBefore(inToken);
                }
                checkSpacingAfter(inToken);
            }
            /**
             * Reports `for` and `of` keywords of a given node if usage of spacing
             * around those keywords is invalid.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForForOfStatement(node) {
                if (node.await) {
                    checkSpacingBefore(sourceCode.getFirstToken(node, 0));
                    checkSpacingAfter(sourceCode.getFirstToken(node, 1));
                }
                else {
                    checkSpacingAroundFirstToken(node);
                }
                const ofToken = sourceCode.getTokenBefore(node.right, astUtils.isNotOpeningParenToken);
                const previousToken = sourceCode.getTokenBefore(ofToken);
                if (previousToken.type !== "PrivateIdentifier") {
                    checkSpacingBefore(ofToken);
                }
                checkSpacingAfter(ofToken);
            }
            /**
             * Reports `import`, `export`, `as`, and `from` keywords of a given node if
             * usage of spacing around those keywords is invalid.
             *
             * This rule handles the `*` token in module declarations.
             *
             *     import*as A from "./a"; /*error Expected space(s) after "import".
             *                               error Expected space(s) before "as".
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForModuleDeclaration(node) {
                const firstToken = sourceCode.getFirstToken(node);
                checkSpacingBefore(firstToken, PREV_TOKEN_M);
                checkSpacingAfter(firstToken, NEXT_TOKEN_M);
                if (node.type === "ExportDefaultDeclaration") {
                    checkSpacingAround(sourceCode.getTokenAfter(firstToken));
                }
                if (node.type === "ExportAllDeclaration" && node.exported) {
                    const asToken = sourceCode.getTokenBefore(node.exported);
                    checkSpacingBefore(asToken, PREV_TOKEN_M);
                    checkSpacingAfter(asToken, NEXT_TOKEN_M);
                }
                if (node.source) {
                    const fromToken = sourceCode.getTokenBefore(node.source);
                    checkSpacingBefore(fromToken, PREV_TOKEN_M);
                    checkSpacingAfter(fromToken, NEXT_TOKEN_M);
                }
            }
            /**
             * Reports `as` keyword of a given node if usage of spacing around this
             * keyword is invalid.
             * @param {ASTNode} node An `ImportSpecifier` node to check.
             * @returns {void}
             */
            function checkSpacingForImportSpecifier(node) {
                if (node.imported.range[0] !== node.local.range[0]) {
                    const asToken = sourceCode.getTokenBefore(node.local);
                    checkSpacingBefore(asToken, PREV_TOKEN_M);
                }
            }
            /**
             * Reports `as` keyword of a given node if usage of spacing around this
             * keyword is invalid.
             * @param {ASTNode} node An `ExportSpecifier` node to check.
             * @returns {void}
             */
            function checkSpacingForExportSpecifier(node) {
                if (node.local.range[0] !== node.exported.range[0]) {
                    const asToken = sourceCode.getTokenBefore(node.exported);
                    checkSpacingBefore(asToken, PREV_TOKEN_M);
                    checkSpacingAfter(asToken, NEXT_TOKEN_M);
                }
            }
            /**
             * Reports `as` keyword of a given node if usage of spacing around this
             * keyword is invalid.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForImportNamespaceSpecifier(node) {
                const asToken = sourceCode.getFirstToken(node, 1);
                checkSpacingBefore(asToken, PREV_TOKEN_M);
            }
            /**
             * Reports `static`, `get`, and `set` keywords of a given node if usage of
             * spacing around those keywords is invalid.
             * @param {ASTNode} node A node to report.
             * @throws {Error} If unable to find token get, set, or async beside method name.
             * @returns {void}
             */
            function checkSpacingForProperty(node) {
                if (node.static) {
                    checkSpacingAroundFirstToken(node);
                }
                if (node.kind === "get" ||
                    node.kind === "set" ||
                    ((node.method || node.type === "MethodDefinition") &&
                        node.value.async)) {
                    const token = sourceCode.getTokenBefore(node.key, tok => {
                        switch (tok.value) {
                            case "get":
                            case "set":
                            case "async":
                                return true;
                            default:
                                return false;
                        }
                    });
                    if (!token) {
                        throw new Error("Failed to find token get, set, or async beside method name");
                    }
                    checkSpacingAround(token);
                }
            }
            /**
             * Reports `await` keyword of a given node if usage of spacing before
             * this keyword is invalid.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function checkSpacingForAwaitExpression(node) {
                checkSpacingBefore(sourceCode.getFirstToken(node));
            }
            return {
                // Statements
                DebuggerStatement: checkSpacingAroundFirstToken,
                WithStatement: checkSpacingAroundFirstToken,
                // Statements - Control flow
                BreakStatement: checkSpacingAroundFirstToken,
                ContinueStatement: checkSpacingAroundFirstToken,
                ReturnStatement: checkSpacingAroundFirstToken,
                ThrowStatement: checkSpacingAroundFirstToken,
                TryStatement: checkSpacingForTryStatement,
                // Statements - Choice
                IfStatement: checkSpacingForIfStatement,
                SwitchStatement: checkSpacingAroundFirstToken,
                SwitchCase: checkSpacingAroundFirstToken,
                // Statements - Loops
                DoWhileStatement: checkSpacingForDoWhileStatement,
                ForInStatement: checkSpacingForForInStatement,
                ForOfStatement: checkSpacingForForOfStatement,
                ForStatement: checkSpacingAroundFirstToken,
                WhileStatement: checkSpacingAroundFirstToken,
                // Statements - Declarations
                ClassDeclaration: checkSpacingForClass,
                ExportNamedDeclaration: checkSpacingForModuleDeclaration,
                ExportDefaultDeclaration: checkSpacingForModuleDeclaration,
                ExportAllDeclaration: checkSpacingForModuleDeclaration,
                FunctionDeclaration: checkSpacingForFunction,
                ImportDeclaration: checkSpacingForModuleDeclaration,
                VariableDeclaration: checkSpacingAroundFirstToken,
                // Expressions
                ArrowFunctionExpression: checkSpacingForFunction,
                AwaitExpression: checkSpacingForAwaitExpression,
                ClassExpression: checkSpacingForClass,
                FunctionExpression: checkSpacingForFunction,
                NewExpression: checkSpacingBeforeFirstToken,
                Super: checkSpacingBeforeFirstToken,
                ThisExpression: checkSpacingBeforeFirstToken,
                UnaryExpression: checkSpacingBeforeFirstToken,
                YieldExpression: checkSpacingBeforeFirstToken,
                // Others
                ImportSpecifier: checkSpacingForImportSpecifier,
                ExportSpecifier: checkSpacingForExportSpecifier,
                ImportNamespaceSpecifier: checkSpacingForImportNamespaceSpecifier,
                MethodDefinition: checkSpacingForProperty,
                PropertyDefinition: checkSpacingForProperty,
                StaticBlock: checkSpacingAroundFirstToken,
                Property: checkSpacingForProperty,
                // To avoid conflicts with `space-infix-ops`, e.g. `a > this.b`
                "BinaryExpression[operator='>']"(node) {
                    const operatorToken = sourceCode.getTokenBefore(node.right, astUtils.isNotOpeningParenToken);
                    tokensToIgnore.add(operatorToken);
                }
            };
        }
    };
},
/* eslint/lib/rules/line-comment-position.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to enforce the position of line comments
     * @author Alberto Rodríguez
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce position of line comments",
                recommended: false,
                url: "https://eslint.org/docs/rules/line-comment-position"
            },
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["above", "beside"]
                        },
                        {
                            type: "object",
                            properties: {
                                position: {
                                    enum: ["above", "beside"]
                                },
                                ignorePattern: {
                                    type: "string"
                                },
                                applyDefaultPatterns: {
                                    type: "boolean"
                                },
                                applyDefaultIgnorePatterns: {
                                    type: "boolean"
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                above: "Expected comment to be above code.",
                beside: "Expected comment to be beside code."
            }
        },
        create(context) {
            const options = context.options[0];
            let above, ignorePattern, applyDefaultIgnorePatterns = true;
            if (!options || typeof options === "string") {
                above = !options || options === "above";
            }
            else {
                above = !options.position || options.position === "above";
                ignorePattern = options.ignorePattern;
                if (Object.prototype.hasOwnProperty.call(options, "applyDefaultIgnorePatterns")) {
                    applyDefaultIgnorePatterns = options.applyDefaultIgnorePatterns;
                }
                else {
                    applyDefaultIgnorePatterns = options.applyDefaultPatterns !== false;
                }
            }
            const defaultIgnoreRegExp = astUtils.COMMENTS_IGNORE_PATTERN;
            const fallThroughRegExp = /^\s*falls?\s?through/u;
            const customIgnoreRegExp = new RegExp(ignorePattern, "u");
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program() {
                    const comments = sourceCode.getAllComments();
                    comments.filter(token => token.type === "Line").forEach(node => {
                        if (applyDefaultIgnorePatterns && (defaultIgnoreRegExp.test(node.value) || fallThroughRegExp.test(node.value))) {
                            return;
                        }
                        if (ignorePattern && customIgnoreRegExp.test(node.value)) {
                            return;
                        }
                        const previous = sourceCode.getTokenBefore(node, { includeComments: true });
                        const isOnSameLine = previous && previous.loc.end.line === node.loc.start.line;
                        if (above) {
                            if (isOnSameLine) {
                                context.report({
                                    node,
                                    messageId: "above"
                                });
                            }
                        }
                        else {
                            if (!isOnSameLine) {
                                context.report({
                                    node,
                                    messageId: "beside"
                                });
                            }
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/linebreak-style.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce a single linebreak style.
     * @author Erik Mueller
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent linebreak style",
                recommended: false,
                url: "https://eslint.org/docs/rules/linebreak-style"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["unix", "windows"]
                }
            ],
            messages: {
                expectedLF: "Expected linebreaks to be 'LF' but found 'CRLF'.",
                expectedCRLF: "Expected linebreaks to be 'CRLF' but found 'LF'."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Builds a fix function that replaces text at the specified range in the source text.
             * @param {int[]} range The range to replace
             * @param {string} text The text to insert.
             * @returns {Function} Fixer function
             * @private
             */
            function createFix(range, text) {
                return function (fixer) {
                    return fixer.replaceTextRange(range, text);
                };
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program: function checkForLinebreakStyle(node) {
                    const linebreakStyle = context.options[0] || "unix", expectedLF = linebreakStyle === "unix", expectedLFChars = expectedLF ? "\n" : "\r\n", source = sourceCode.getText(), pattern = astUtils.createGlobalLinebreakMatcher();
                    let match;
                    let i = 0;
                    while ((match = pattern.exec(source)) !== null) {
                        i++;
                        if (match[0] === expectedLFChars) {
                            continue;
                        }
                        const index = match.index;
                        const range = [index, index + match[0].length];
                        context.report({
                            node,
                            loc: {
                                start: {
                                    line: i,
                                    column: sourceCode.lines[i - 1].length
                                },
                                end: {
                                    line: i + 1,
                                    column: 0
                                }
                            },
                            messageId: expectedLF ? "expectedLF" : "expectedCRLF",
                            fix: createFix(range, expectedLFChars)
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/lines-around-comment.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Enforces empty lines around comments.
     * @author Jamund Ferguson
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Return an array with any line numbers that are empty.
     * @param {Array} lines An array of each line of the file.
     * @returns {Array} An array of line numbers.
     */
    function getEmptyLineNums(lines) {
        const emptyLines = lines.map((line, i) => ({
            code: line.trim(),
            num: i + 1
        })).filter(line => !line.code).map(line => line.num);
        return emptyLines;
    }
    /**
     * Return an array with any line numbers that contain comments.
     * @param {Array} comments An array of comment tokens.
     * @returns {Array} An array of line numbers.
     */
    function getCommentLineNums(comments) {
        const lines = [];
        comments.forEach(token => {
            const start = token.loc.start.line;
            const end = token.loc.end.line;
            lines.push(start, end);
        });
        return lines;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require empty lines around comments",
                recommended: false,
                url: "https://eslint.org/docs/rules/lines-around-comment"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        beforeBlockComment: {
                            type: "boolean",
                            default: true
                        },
                        afterBlockComment: {
                            type: "boolean",
                            default: false
                        },
                        beforeLineComment: {
                            type: "boolean",
                            default: false
                        },
                        afterLineComment: {
                            type: "boolean",
                            default: false
                        },
                        allowBlockStart: {
                            type: "boolean",
                            default: false
                        },
                        allowBlockEnd: {
                            type: "boolean",
                            default: false
                        },
                        allowClassStart: {
                            type: "boolean"
                        },
                        allowClassEnd: {
                            type: "boolean"
                        },
                        allowObjectStart: {
                            type: "boolean"
                        },
                        allowObjectEnd: {
                            type: "boolean"
                        },
                        allowArrayStart: {
                            type: "boolean"
                        },
                        allowArrayEnd: {
                            type: "boolean"
                        },
                        ignorePattern: {
                            type: "string"
                        },
                        applyDefaultIgnorePatterns: {
                            type: "boolean"
                        },
                        afterHashbangComment: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                after: "Expected line after comment.",
                before: "Expected line before comment."
            }
        },
        create(context) {
            const options = Object.assign({}, context.options[0]);
            const ignorePattern = options.ignorePattern;
            const defaultIgnoreRegExp = astUtils.COMMENTS_IGNORE_PATTERN;
            const customIgnoreRegExp = new RegExp(ignorePattern, "u");
            const applyDefaultIgnorePatterns = options.applyDefaultIgnorePatterns !== false;
            options.beforeBlockComment = typeof options.beforeBlockComment !== "undefined" ? options.beforeBlockComment : true;
            const sourceCode = context.getSourceCode();
            const lines = sourceCode.lines, numLines = lines.length + 1, comments = sourceCode.getAllComments(), commentLines = getCommentLineNums(comments), emptyLines = getEmptyLineNums(lines), commentAndEmptyLines = new Set(commentLines.concat(emptyLines));
            /**
             * Returns whether or not comments are on lines starting with or ending with code
             * @param {token} token The comment token to check.
             * @returns {boolean} True if the comment is not alone.
             */
            function codeAroundComment(token) {
                let currentToken = token;
                do {
                    currentToken = sourceCode.getTokenBefore(currentToken, { includeComments: true });
                } while (currentToken && astUtils.isCommentToken(currentToken));
                if (currentToken && astUtils.isTokenOnSameLine(currentToken, token)) {
                    return true;
                }
                currentToken = token;
                do {
                    currentToken = sourceCode.getTokenAfter(currentToken, { includeComments: true });
                } while (currentToken && astUtils.isCommentToken(currentToken));
                if (currentToken && astUtils.isTokenOnSameLine(token, currentToken)) {
                    return true;
                }
                return false;
            }
            /**
             * Returns whether or not comments are inside a node type or not.
             * @param {ASTNode} parent The Comment parent node.
             * @param {string} nodeType The parent type to check against.
             * @returns {boolean} True if the comment is inside nodeType.
             */
            function isParentNodeType(parent, nodeType) {
                return parent.type === nodeType ||
                    (parent.body && parent.body.type === nodeType) ||
                    (parent.consequent && parent.consequent.type === nodeType);
            }
            /**
             * Returns the parent node that contains the given token.
             * @param {token} token The token to check.
             * @returns {ASTNode|null} The parent node that contains the given token.
             */
            function getParentNodeOfToken(token) {
                const node = sourceCode.getNodeByRangeIndex(token.range[0]);
                /*
                 * For the purpose of this rule, the comment token is in a `StaticBlock` node only
                 * if it's inside the braces of that `StaticBlock` node.
                 *
                 * Example where this function returns `null`:
                 *
                 *   static
                 *   // comment
                 *   {
                 *   }
                 *
                 * Example where this function returns `StaticBlock` node:
                 *
                 *   static
                 *   {
                 *   // comment
                 *   }
                 *
                 */
                if (node && node.type === "StaticBlock") {
                    const openingBrace = sourceCode.getFirstToken(node, { skip: 1 }); // skip the `static` token
                    return token.range[0] >= openingBrace.range[0]
                        ? node
                        : null;
                }
                return node;
            }
            /**
             * Returns whether or not comments are at the parent start or not.
             * @param {token} token The Comment token.
             * @param {string} nodeType The parent type to check against.
             * @returns {boolean} True if the comment is at parent start.
             */
            function isCommentAtParentStart(token, nodeType) {
                const parent = getParentNodeOfToken(token);
                if (parent && isParentNodeType(parent, nodeType)) {
                    let parentStartNodeOrToken = parent;
                    if (parent.type === "StaticBlock") {
                        parentStartNodeOrToken = sourceCode.getFirstToken(parent, { skip: 1 }); // opening brace of the static block
                    }
                    else if (parent.type === "SwitchStatement") {
                        parentStartNodeOrToken = sourceCode.getTokenAfter(parent.discriminant, {
                            filter: astUtils.isOpeningBraceToken
                        }); // opening brace of the switch statement
                    }
                    return token.loc.start.line - parentStartNodeOrToken.loc.start.line === 1;
                }
                return false;
            }
            /**
             * Returns whether or not comments are at the parent end or not.
             * @param {token} token The Comment token.
             * @param {string} nodeType The parent type to check against.
             * @returns {boolean} True if the comment is at parent end.
             */
            function isCommentAtParentEnd(token, nodeType) {
                const parent = getParentNodeOfToken(token);
                return !!parent && isParentNodeType(parent, nodeType) &&
                    parent.loc.end.line - token.loc.end.line === 1;
            }
            /**
             * Returns whether or not comments are at the block start or not.
             * @param {token} token The Comment token.
             * @returns {boolean} True if the comment is at block start.
             */
            function isCommentAtBlockStart(token) {
                return (isCommentAtParentStart(token, "ClassBody") ||
                    isCommentAtParentStart(token, "BlockStatement") ||
                    isCommentAtParentStart(token, "StaticBlock") ||
                    isCommentAtParentStart(token, "SwitchCase") ||
                    isCommentAtParentStart(token, "SwitchStatement"));
            }
            /**
             * Returns whether or not comments are at the block end or not.
             * @param {token} token The Comment token.
             * @returns {boolean} True if the comment is at block end.
             */
            function isCommentAtBlockEnd(token) {
                return (isCommentAtParentEnd(token, "ClassBody") ||
                    isCommentAtParentEnd(token, "BlockStatement") ||
                    isCommentAtParentEnd(token, "StaticBlock") ||
                    isCommentAtParentEnd(token, "SwitchCase") ||
                    isCommentAtParentEnd(token, "SwitchStatement"));
            }
            /**
             * Returns whether or not comments are at the class start or not.
             * @param {token} token The Comment token.
             * @returns {boolean} True if the comment is at class start.
             */
            function isCommentAtClassStart(token) {
                return isCommentAtParentStart(token, "ClassBody");
            }
            /**
             * Returns whether or not comments are at the class end or not.
             * @param {token} token The Comment token.
             * @returns {boolean} True if the comment is at class end.
             */
            function isCommentAtClassEnd(token) {
                return isCommentAtParentEnd(token, "ClassBody");
            }
            /**
             * Returns whether or not comments are at the object start or not.
             * @param {token} token The Comment token.
             * @returns {boolean} True if the comment is at object start.
             */
            function isCommentAtObjectStart(token) {
                return isCommentAtParentStart(token, "ObjectExpression") || isCommentAtParentStart(token, "ObjectPattern");
            }
            /**
             * Returns whether or not comments are at the object end or not.
             * @param {token} token The Comment token.
             * @returns {boolean} True if the comment is at object end.
             */
            function isCommentAtObjectEnd(token) {
                return isCommentAtParentEnd(token, "ObjectExpression") || isCommentAtParentEnd(token, "ObjectPattern");
            }
            /**
             * Returns whether or not comments are at the array start or not.
             * @param {token} token The Comment token.
             * @returns {boolean} True if the comment is at array start.
             */
            function isCommentAtArrayStart(token) {
                return isCommentAtParentStart(token, "ArrayExpression") || isCommentAtParentStart(token, "ArrayPattern");
            }
            /**
             * Returns whether or not comments are at the array end or not.
             * @param {token} token The Comment token.
             * @returns {boolean} True if the comment is at array end.
             */
            function isCommentAtArrayEnd(token) {
                return isCommentAtParentEnd(token, "ArrayExpression") || isCommentAtParentEnd(token, "ArrayPattern");
            }
            /**
             * Checks if a comment token has lines around it (ignores inline comments)
             * @param {token} token The Comment token.
             * @param {Object} opts Options to determine the newline.
             * @param {boolean} opts.after Should have a newline after this line.
             * @param {boolean} opts.before Should have a newline before this line.
             * @returns {void}
             */
            function checkForEmptyLine(token, opts) {
                if (applyDefaultIgnorePatterns && defaultIgnoreRegExp.test(token.value)) {
                    return;
                }
                if (ignorePattern && customIgnoreRegExp.test(token.value)) {
                    return;
                }
                let after = opts.after, before = opts.before;
                const prevLineNum = token.loc.start.line - 1, nextLineNum = token.loc.end.line + 1, commentIsNotAlone = codeAroundComment(token);
                const blockStartAllowed = options.allowBlockStart &&
                    isCommentAtBlockStart(token) &&
                    !(options.allowClassStart === false &&
                        isCommentAtClassStart(token)), blockEndAllowed = options.allowBlockEnd && isCommentAtBlockEnd(token) && !(options.allowClassEnd === false && isCommentAtClassEnd(token)), classStartAllowed = options.allowClassStart && isCommentAtClassStart(token), classEndAllowed = options.allowClassEnd && isCommentAtClassEnd(token), objectStartAllowed = options.allowObjectStart && isCommentAtObjectStart(token), objectEndAllowed = options.allowObjectEnd && isCommentAtObjectEnd(token), arrayStartAllowed = options.allowArrayStart && isCommentAtArrayStart(token), arrayEndAllowed = options.allowArrayEnd && isCommentAtArrayEnd(token);
                const exceptionStartAllowed = blockStartAllowed || classStartAllowed || objectStartAllowed || arrayStartAllowed;
                const exceptionEndAllowed = blockEndAllowed || classEndAllowed || objectEndAllowed || arrayEndAllowed;
                // ignore top of the file and bottom of the file
                if (prevLineNum < 1) {
                    before = false;
                }
                if (nextLineNum >= numLines) {
                    after = false;
                }
                // we ignore all inline comments
                if (commentIsNotAlone) {
                    return;
                }
                const previousTokenOrComment = sourceCode.getTokenBefore(token, { includeComments: true });
                const nextTokenOrComment = sourceCode.getTokenAfter(token, { includeComments: true });
                // check for newline before
                if (!exceptionStartAllowed && before && !commentAndEmptyLines.has(prevLineNum) &&
                    !(astUtils.isCommentToken(previousTokenOrComment) && astUtils.isTokenOnSameLine(previousTokenOrComment, token))) {
                    const lineStart = token.range[0] - token.loc.start.column;
                    const range = [lineStart, lineStart];
                    context.report({
                        node: token,
                        messageId: "before",
                        fix(fixer) {
                            return fixer.insertTextBeforeRange(range, "\n");
                        }
                    });
                }
                // check for newline after
                if (!exceptionEndAllowed && after && !commentAndEmptyLines.has(nextLineNum) &&
                    !(astUtils.isCommentToken(nextTokenOrComment) && astUtils.isTokenOnSameLine(token, nextTokenOrComment))) {
                    context.report({
                        node: token,
                        messageId: "after",
                        fix(fixer) {
                            return fixer.insertTextAfter(token, "\n");
                        }
                    });
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program() {
                    comments.forEach(token => {
                        if (token.type === "Line") {
                            if (options.beforeLineComment || options.afterLineComment) {
                                checkForEmptyLine(token, {
                                    after: options.afterLineComment,
                                    before: options.beforeLineComment
                                });
                            }
                        }
                        else if (token.type === "Block") {
                            if (options.beforeBlockComment || options.afterBlockComment) {
                                checkForEmptyLine(token, {
                                    after: options.afterBlockComment,
                                    before: options.beforeBlockComment
                                });
                            }
                        }
                        else if (token.type === "Shebang") {
                            if (options.afterHashbangComment) {
                                checkForEmptyLine(token, {
                                    after: options.afterHashbangComment,
                                    before: false
                                });
                            }
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/lines-around-directive.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Require or disallow newlines around directives.
     * @author Kai Cataldo
     * @deprecated in ESLint v4.0.0
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow newlines around directives",
                recommended: false,
                url: "https://eslint.org/docs/rules/lines-around-directive"
            },
            schema: [{
                    oneOf: [
                        {
                            enum: ["always", "never"]
                        },
                        {
                            type: "object",
                            properties: {
                                before: {
                                    enum: ["always", "never"]
                                },
                                after: {
                                    enum: ["always", "never"]
                                }
                            },
                            additionalProperties: false,
                            minProperties: 2
                        }
                    ]
                }],
            fixable: "whitespace",
            messages: {
                expected: "Expected newline {{location}} \"{{value}}\" directive.",
                unexpected: "Unexpected newline {{location}} \"{{value}}\" directive."
            },
            deprecated: true,
            replacedBy: ["padding-line-between-statements"]
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const config = context.options[0] || "always";
            const expectLineBefore = typeof config === "string" ? config : config.before;
            const expectLineAfter = typeof config === "string" ? config : config.after;
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Check if node is preceded by a blank newline.
             * @param {ASTNode} node Node to check.
             * @returns {boolean} Whether or not the passed in node is preceded by a blank newline.
             */
            function hasNewlineBefore(node) {
                const tokenBefore = sourceCode.getTokenBefore(node, { includeComments: true });
                const tokenLineBefore = tokenBefore ? tokenBefore.loc.end.line : 0;
                return node.loc.start.line - tokenLineBefore >= 2;
            }
            /**
             * Gets the last token of a node that is on the same line as the rest of the node.
             * This will usually be the last token of the node, but it will be the second-to-last token if the node has a trailing
             * semicolon on a different line.
             * @param {ASTNode} node A directive node
             * @returns {Token} The last token of the node on the line
             */
            function getLastTokenOnLine(node) {
                const lastToken = sourceCode.getLastToken(node);
                const secondToLastToken = sourceCode.getTokenBefore(lastToken);
                return astUtils.isSemicolonToken(lastToken) && lastToken.loc.start.line > secondToLastToken.loc.end.line
                    ? secondToLastToken
                    : lastToken;
            }
            /**
             * Check if node is followed by a blank newline.
             * @param {ASTNode} node Node to check.
             * @returns {boolean} Whether or not the passed in node is followed by a blank newline.
             */
            function hasNewlineAfter(node) {
                const lastToken = getLastTokenOnLine(node);
                const tokenAfter = sourceCode.getTokenAfter(lastToken, { includeComments: true });
                return tokenAfter.loc.start.line - lastToken.loc.end.line >= 2;
            }
            /**
             * Report errors for newlines around directives.
             * @param {ASTNode} node Node to check.
             * @param {string} location Whether the error was found before or after the directive.
             * @param {boolean} expected Whether or not a newline was expected or unexpected.
             * @returns {void}
             */
            function reportError(node, location, expected) {
                context.report({
                    node,
                    messageId: expected ? "expected" : "unexpected",
                    data: {
                        value: node.expression.value,
                        location
                    },
                    fix(fixer) {
                        const lastToken = getLastTokenOnLine(node);
                        if (expected) {
                            return location === "before" ? fixer.insertTextBefore(node, "\n") : fixer.insertTextAfter(lastToken, "\n");
                        }
                        return fixer.removeRange(location === "before" ? [node.range[0] - 1, node.range[0]] : [lastToken.range[1], lastToken.range[1] + 1]);
                    }
                });
            }
            /**
             * Check lines around directives in node
             * @param {ASTNode} node node to check
             * @returns {void}
             */
            function checkDirectives(node) {
                const directives = astUtils.getDirectivePrologue(node);
                if (!directives.length) {
                    return;
                }
                const firstDirective = directives[0];
                const leadingComments = sourceCode.getCommentsBefore(firstDirective);
                /*
                 * Only check before the first directive if it is preceded by a comment or if it is at the top of
                 * the file and expectLineBefore is set to "never". This is to not force a newline at the top of
                 * the file if there are no comments as well as for compatibility with padded-blocks.
                 */
                if (leadingComments.length) {
                    if (expectLineBefore === "always" && !hasNewlineBefore(firstDirective)) {
                        reportError(firstDirective, "before", true);
                    }
                    if (expectLineBefore === "never" && hasNewlineBefore(firstDirective)) {
                        reportError(firstDirective, "before", false);
                    }
                }
                else if (node.type === "Program" &&
                    expectLineBefore === "never" &&
                    !leadingComments.length &&
                    hasNewlineBefore(firstDirective)) {
                    reportError(firstDirective, "before", false);
                }
                const lastDirective = directives[directives.length - 1];
                const statements = node.type === "Program" ? node.body : node.body.body;
                /*
                 * Do not check after the last directive if the body only
                 * contains a directive prologue and isn't followed by a comment to ensure
                 * this rule behaves well with padded-blocks.
                 */
                if (lastDirective === statements[statements.length - 1] && !lastDirective.trailingComments) {
                    return;
                }
                if (expectLineAfter === "always" && !hasNewlineAfter(lastDirective)) {
                    reportError(lastDirective, "after", true);
                }
                if (expectLineAfter === "never" && hasNewlineAfter(lastDirective)) {
                    reportError(lastDirective, "after", false);
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program: checkDirectives,
                FunctionDeclaration: checkDirectives,
                FunctionExpression: checkDirectives,
                ArrowFunctionExpression: checkDirectives
            };
        }
    };
},
/* eslint/lib/rules/lines-between-class-members.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to check empty newline between class members
     * @author 薛定谔的猫<hh_2013@foxmail.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow an empty line between class members",
                recommended: false,
                url: "https://eslint.org/docs/rules/lines-between-class-members"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never"]
                },
                {
                    type: "object",
                    properties: {
                        exceptAfterSingleLine: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                never: "Unexpected blank line between class members.",
                always: "Expected blank line between class members."
            }
        },
        create(context) {
            const options = [];
            options[0] = context.options[0] || "always";
            options[1] = context.options[1] || { exceptAfterSingleLine: false };
            const sourceCode = context.getSourceCode();
            /**
             * Gets a pair of tokens that should be used to check lines between two class member nodes.
             *
             * In most cases, this returns the very last token of the current node and
             * the very first token of the next node.
             * For example:
             *
             *     class C {
             *         x = 1;   // curLast: `;` nextFirst: `in`
             *         in = 2
             *     }
             *
             * There is only one exception. If the given node ends with a semicolon, and it looks like
             * a semicolon-less style's semicolon - one that is not on the same line as the preceding
             * token, but is on the line where the next class member starts - this returns the preceding
             * token and the semicolon as boundary tokens.
             * For example:
             *
             *     class C {
             *         x = 1    // curLast: `1` nextFirst: `;`
             *         ;in = 2
             *     }
             * When determining the desired layout of the code, we should treat this semicolon as
             * a part of the next class member node instead of the one it technically belongs to.
             * @param {ASTNode} curNode Current class member node.
             * @param {ASTNode} nextNode Next class member node.
             * @returns {Token} The actual last token of `node`.
             * @private
             */
            function getBoundaryTokens(curNode, nextNode) {
                const lastToken = sourceCode.getLastToken(curNode);
                const prevToken = sourceCode.getTokenBefore(lastToken);
                const nextToken = sourceCode.getFirstToken(nextNode); // skip possible lone `;` between nodes
                const isSemicolonLessStyle = (astUtils.isSemicolonToken(lastToken) &&
                    !astUtils.isTokenOnSameLine(prevToken, lastToken) &&
                    astUtils.isTokenOnSameLine(lastToken, nextToken));
                return isSemicolonLessStyle
                    ? { curLast: prevToken, nextFirst: lastToken }
                    : { curLast: lastToken, nextFirst: nextToken };
            }
            /**
             * Return the last token among the consecutive tokens that have no exceed max line difference in between, before the first token in the next member.
             * @param {Token} prevLastToken The last token in the previous member node.
             * @param {Token} nextFirstToken The first token in the next member node.
             * @param {number} maxLine The maximum number of allowed line difference between consecutive tokens.
             * @returns {Token} The last token among the consecutive tokens.
             */
            function findLastConsecutiveTokenAfter(prevLastToken, nextFirstToken, maxLine) {
                const after = sourceCode.getTokenAfter(prevLastToken, { includeComments: true });
                if (after !== nextFirstToken && after.loc.start.line - prevLastToken.loc.end.line <= maxLine) {
                    return findLastConsecutiveTokenAfter(after, nextFirstToken, maxLine);
                }
                return prevLastToken;
            }
            /**
             * Return the first token among the consecutive tokens that have no exceed max line difference in between, after the last token in the previous member.
             * @param {Token} nextFirstToken The first token in the next member node.
             * @param {Token} prevLastToken The last token in the previous member node.
             * @param {number} maxLine The maximum number of allowed line difference between consecutive tokens.
             * @returns {Token} The first token among the consecutive tokens.
             */
            function findFirstConsecutiveTokenBefore(nextFirstToken, prevLastToken, maxLine) {
                const before = sourceCode.getTokenBefore(nextFirstToken, { includeComments: true });
                if (before !== prevLastToken && nextFirstToken.loc.start.line - before.loc.end.line <= maxLine) {
                    return findFirstConsecutiveTokenBefore(before, prevLastToken, maxLine);
                }
                return nextFirstToken;
            }
            /**
             * Checks if there is a token or comment between two tokens.
             * @param {Token} before The token before.
             * @param {Token} after The token after.
             * @returns {boolean} True if there is a token or comment between two tokens.
             */
            function hasTokenOrCommentBetween(before, after) {
                return sourceCode.getTokensBetween(before, after, { includeComments: true }).length !== 0;
            }
            return {
                ClassBody(node) {
                    const body = node.body;
                    for (let i = 0; i < body.length - 1; i++) {
                        const curFirst = sourceCode.getFirstToken(body[i]);
                        const { curLast, nextFirst } = getBoundaryTokens(body[i], body[i + 1]);
                        const isMulti = !astUtils.isTokenOnSameLine(curFirst, curLast);
                        const skip = !isMulti && options[1].exceptAfterSingleLine;
                        const beforePadding = findLastConsecutiveTokenAfter(curLast, nextFirst, 1);
                        const afterPadding = findFirstConsecutiveTokenBefore(nextFirst, curLast, 1);
                        const isPadded = afterPadding.loc.start.line - beforePadding.loc.end.line > 1;
                        const hasTokenInPadding = hasTokenOrCommentBetween(beforePadding, afterPadding);
                        const curLineLastToken = findLastConsecutiveTokenAfter(curLast, nextFirst, 0);
                        if ((options[0] === "always" && !skip && !isPadded) ||
                            (options[0] === "never" && isPadded)) {
                            context.report({
                                node: body[i + 1],
                                messageId: isPadded ? "never" : "always",
                                fix(fixer) {
                                    if (hasTokenInPadding) {
                                        return null;
                                    }
                                    return isPadded
                                        ? fixer.replaceTextRange([beforePadding.range[1], afterPadding.range[0]], "\n")
                                        : fixer.insertTextAfter(curLineLastToken, "\n");
                                }
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/logical-assignment-operators.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to replace assignment expressions with logical operator assignment
     * @author Daniel Martens
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils.js */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const baseTypes = new Set(["Identifier", "Super", "ThisExpression"]);
    /**
     * Returns true iff either "undefined" or a void expression (eg. "void 0")
     * @param {ASTNode} expression Expression to check
     * @param {import('eslint-scope').Scope} scope Scope of the expression
     * @returns {boolean} True iff "undefined" or "void ..."
     */
    function isUndefined(expression, scope) {
        if (expression.type === "Identifier" && expression.name === "undefined") {
            return astUtils.isReferenceToGlobalVariable(scope, expression);
        }
        return expression.type === "UnaryExpression" &&
            expression.operator === "void" &&
            expression.argument.type === "Literal" &&
            expression.argument.value === 0;
    }
    /**
     * Returns true iff the reference is either an identifier or member expression
     * @param {ASTNode} expression Expression to check
     * @returns {boolean} True for identifiers and member expressions
     */
    function isReference(expression) {
        return (expression.type === "Identifier" && expression.name !== "undefined") ||
            expression.type === "MemberExpression";
    }
    /**
     * Returns true iff the expression checks for nullish with loose equals.
     * Examples: value == null, value == void 0
     * @param {ASTNode} expression Test condition
     * @param {import('eslint-scope').Scope} scope Scope of the expression
     * @returns {boolean} True iff implicit nullish comparison
     */
    function isImplicitNullishComparison(expression, scope) {
        if (expression.type !== "BinaryExpression" || expression.operator !== "==") {
            return false;
        }
        const reference = isReference(expression.left) ? "left" : "right";
        const nullish = reference === "left" ? "right" : "left";
        return isReference(expression[reference]) &&
            (astUtils.isNullLiteral(expression[nullish]) || isUndefined(expression[nullish], scope));
    }
    /**
     * Condition with two equal comparisons.
     * @param {ASTNode} expression Condition
     * @returns {boolean} True iff matches ? === ? || ? === ?
     */
    function isDoubleComparison(expression) {
        return expression.type === "LogicalExpression" &&
            expression.operator === "||" &&
            expression.left.type === "BinaryExpression" &&
            expression.left.operator === "===" &&
            expression.right.type === "BinaryExpression" &&
            expression.right.operator === "===";
    }
    /**
     * Returns true iff the expression checks for undefined and null.
     * Example: value === null || value === undefined
     * @param {ASTNode} expression Test condition
     * @param {import('eslint-scope').Scope} scope Scope of the expression
     * @returns {boolean} True iff explicit nullish comparison
     */
    function isExplicitNullishComparison(expression, scope) {
        if (!isDoubleComparison(expression)) {
            return false;
        }
        const leftReference = isReference(expression.left.left) ? "left" : "right";
        const leftNullish = leftReference === "left" ? "right" : "left";
        const rightReference = isReference(expression.right.left) ? "left" : "right";
        const rightNullish = rightReference === "left" ? "right" : "left";
        return astUtils.isSameReference(expression.left[leftReference], expression.right[rightReference]) &&
            ((astUtils.isNullLiteral(expression.left[leftNullish]) && isUndefined(expression.right[rightNullish], scope)) ||
                (isUndefined(expression.left[leftNullish], scope) && astUtils.isNullLiteral(expression.right[rightNullish])));
    }
    /**
     * Returns true for Boolean(arg) calls
     * @param {ASTNode} expression Test condition
     * @param {import('eslint-scope').Scope} scope Scope of the expression
     * @returns {boolean} Whether the expression is a boolean cast
     */
    function isBooleanCast(expression, scope) {
        return expression.type === "CallExpression" &&
            expression.callee.name === "Boolean" &&
            expression.arguments.length === 1 &&
            astUtils.isReferenceToGlobalVariable(scope, expression.callee);
    }
    /**
     * Returns true for:
     * truthiness checks:  value, Boolean(value), !!value
     * falsiness checks:   !value, !Boolean(value)
     * nullish checks:     value == null, value === undefined || value === null
     * @param {ASTNode} expression Test condition
     * @param {import('eslint-scope').Scope} scope Scope of the expression
     * @returns {?{ reference: ASTNode, operator: '??'|'||'|'&&'}} Null if not a known existence
     */
    function getExistence(expression, scope) {
        const isNegated = expression.type === "UnaryExpression" && expression.operator === "!";
        const base = isNegated ? expression.argument : expression;
        switch (true) {
            case isReference(base):
                return { reference: base, operator: isNegated ? "||" : "&&" };
            case base.type === "UnaryExpression" && base.operator === "!" && isReference(base.argument):
                return { reference: base.argument, operator: "&&" };
            case isBooleanCast(base, scope) && isReference(base.arguments[0]):
                return { reference: base.arguments[0], operator: isNegated ? "||" : "&&" };
            case isImplicitNullishComparison(expression, scope):
                return { reference: isReference(expression.left) ? expression.left : expression.right, operator: "??" };
            case isExplicitNullishComparison(expression, scope):
                return { reference: isReference(expression.left.left) ? expression.left.left : expression.left.right, operator: "??" };
            default: return null;
        }
    }
    /**
     * Returns true iff the node is inside a with block
     * @param {ASTNode} node Node to check
     * @returns {boolean} True iff passed node is inside a with block
     */
    function isInsideWithBlock(node) {
        if (node.type === "Program") {
            return false;
        }
        return node.parent.type === "WithStatement" && node.parent.body === node ? true : isInsideWithBlock(node.parent);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require or disallow logical assignment logical operator shorthand",
                recommended: false,
                url: "https://eslint.org/docs/rules/logical-assignment-operators"
            },
            schema: {
                type: "array",
                oneOf: [{
                        items: [
                            { const: "always" },
                            {
                                type: "object",
                                properties: {
                                    enforceForIfStatements: {
                                        type: "boolean"
                                    }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    }, {
                        items: [{ const: "never" }],
                        minItems: 1,
                        maxItems: 1
                    }]
            },
            fixable: "code",
            // eslint-disable-next-line eslint-plugin/require-meta-has-suggestions -- Does not detect conditional suggestions
            hasSuggestions: true,
            messages: {
                assignment: "Assignment (=) can be replaced with operator assignment ({{operator}}).",
                useLogicalOperator: "Convert this assignment to use the operator {{ operator }}.",
                logical: "Logical expression can be replaced with an assignment ({{ operator }}).",
                convertLogical: "Replace this logical expression with an assignment with the operator {{ operator }}.",
                if: "'if' statement can be replaced with a logical operator assignment with operator {{ operator }}.",
                convertIf: "Replace this 'if' statement with a logical assignment with operator {{ operator }}.",
                unexpected: "Unexpected logical operator assignment ({{operator}}) shorthand.",
                separate: "Separate the logical assignment into an assignment with a logical operator."
            }
        },
        create(context) {
            const mode = context.options[0] === "never" ? "never" : "always";
            const checkIf = mode === "always" && context.options.length > 1 && context.options[1].enforceForIfStatements;
            const sourceCode = context.getSourceCode();
            const isStrict = context.getScope().isStrict;
            /**
             * Returns false if the access could be a getter
             * @param {ASTNode} node Assignment expression
             * @returns {boolean} True iff the fix is safe
             */
            function cannotBeGetter(node) {
                return node.type === "Identifier" &&
                    (isStrict || !isInsideWithBlock(node));
            }
            /**
             * Check whether only a single property is accessed
             * @param {ASTNode} node reference
             * @returns {boolean} True iff a single property is accessed
             */
            function accessesSingleProperty(node) {
                if (!isStrict && isInsideWithBlock(node)) {
                    return node.type === "Identifier";
                }
                return node.type === "MemberExpression" &&
                    baseTypes.has(node.object.type) &&
                    (!node.computed || (node.property.type !== "MemberExpression" && node.property.type !== "ChainExpression"));
            }
            /**
             * Adds a fixer or suggestion whether on the fix is safe.
             * @param {{ messageId: string, node: ASTNode }} descriptor Report descriptor without fix or suggest
             * @param {{ messageId: string, fix: Function }} suggestion Adds the fix or the whole suggestion as only element in "suggest" to suggestion
             * @param {boolean} shouldBeFixed Fix iff the condition is true
             * @returns {Object} Descriptor with either an added fix or suggestion
             */
            function createConditionalFixer(descriptor, suggestion, shouldBeFixed) {
                if (shouldBeFixed) {
                    return {
                        ...descriptor,
                        fix: suggestion.fix
                    };
                }
                return {
                    ...descriptor,
                    suggest: [suggestion]
                };
            }
            /**
             * Returns the operator token for assignments and binary expressions
             * @param {ASTNode} node AssignmentExpression or BinaryExpression
             * @returns {import('eslint').AST.Token} Operator token between the left and right expression
             */
            function getOperatorToken(node) {
                return sourceCode.getFirstTokenBetween(node.left, node.right, token => token.value === node.operator);
            }
            if (mode === "never") {
                return {
                    // foo ||= bar
                    "AssignmentExpression"(assignment) {
                        if (!astUtils.isLogicalAssignmentOperator(assignment.operator)) {
                            return;
                        }
                        const descriptor = {
                            messageId: "unexpected",
                            node: assignment,
                            data: { operator: assignment.operator }
                        };
                        const suggestion = {
                            messageId: "separate",
                            *fix(ruleFixer) {
                                if (sourceCode.getCommentsInside(assignment).length > 0) {
                                    return;
                                }
                                const operatorToken = getOperatorToken(assignment);
                                // -> foo = bar
                                yield ruleFixer.replaceText(operatorToken, "=");
                                const assignmentText = sourceCode.getText(assignment.left);
                                const operator = assignment.operator.slice(0, -1);
                                // -> foo = foo || bar
                                yield ruleFixer.insertTextAfter(operatorToken, ` ${assignmentText} ${operator}`);
                                const precedence = astUtils.getPrecedence(assignment.right) <= astUtils.getPrecedence({ type: "LogicalExpression", operator });
                                // ?? and || / && cannot be mixed but have same precedence
                                const mixed = assignment.operator === "??=" && astUtils.isLogicalExpression(assignment.right);
                                if (!astUtils.isParenthesised(sourceCode, assignment.right) && (precedence || mixed)) {
                                    // -> foo = foo || (bar)
                                    yield ruleFixer.insertTextBefore(assignment.right, "(");
                                    yield ruleFixer.insertTextAfter(assignment.right, ")");
                                }
                            }
                        };
                        context.report(createConditionalFixer(descriptor, suggestion, cannotBeGetter(assignment.left)));
                    }
                };
            }
            return {
                // foo = foo || bar
                "AssignmentExpression[operator='='][right.type='LogicalExpression']"(assignment) {
                    if (!astUtils.isSameReference(assignment.left, assignment.right.left)) {
                        return;
                    }
                    const descriptor = {
                        messageId: "assignment",
                        node: assignment,
                        data: { operator: `${assignment.right.operator}=` }
                    };
                    const suggestion = {
                        messageId: "useLogicalOperator",
                        data: { operator: `${assignment.right.operator}=` },
                        *fix(ruleFixer) {
                            if (sourceCode.getCommentsInside(assignment).length > 0) {
                                return;
                            }
                            // No need for parenthesis around the assignment based on precedence as the precedence stays the same even with changed operator
                            const assignmentOperatorToken = getOperatorToken(assignment);
                            // -> foo ||= foo || bar
                            yield ruleFixer.insertTextBefore(assignmentOperatorToken, assignment.right.operator);
                            // -> foo ||= bar
                            const logicalOperatorToken = getOperatorToken(assignment.right);
                            const firstRightOperandToken = sourceCode.getTokenAfter(logicalOperatorToken);
                            yield ruleFixer.removeRange([assignment.right.range[0], firstRightOperandToken.range[0]]);
                        }
                    };
                    context.report(createConditionalFixer(descriptor, suggestion, cannotBeGetter(assignment.left)));
                },
                // foo || (foo = bar)
                'LogicalExpression[right.type="AssignmentExpression"][right.operator="="]'(logical) {
                    // Right side has to be parenthesized, otherwise would be parsed as (foo || foo) = bar which is illegal
                    if (isReference(logical.left) && astUtils.isSameReference(logical.left, logical.right.left)) {
                        const descriptor = {
                            messageId: "logical",
                            node: logical,
                            data: { operator: `${logical.operator}=` }
                        };
                        const suggestion = {
                            messageId: "convertLogical",
                            data: { operator: `${logical.operator}=` },
                            *fix(ruleFixer) {
                                if (sourceCode.getCommentsInside(logical).length > 0) {
                                    return;
                                }
                                const requiresOuterParenthesis = logical.parent.type !== "ExpressionStatement" &&
                                    (astUtils.getPrecedence({ type: "AssignmentExpression" }) < astUtils.getPrecedence(logical.parent));
                                if (!astUtils.isParenthesised(sourceCode, logical) && requiresOuterParenthesis) {
                                    yield ruleFixer.insertTextBefore(logical, "(");
                                    yield ruleFixer.insertTextAfter(logical, ")");
                                }
                                // Also removes all opening parenthesis
                                yield ruleFixer.removeRange([logical.range[0], logical.right.range[0]]); // -> foo = bar)
                                // Also removes all ending parenthesis
                                yield ruleFixer.removeRange([logical.right.range[1], logical.range[1]]); // -> foo = bar
                                const operatorToken = getOperatorToken(logical.right);
                                yield ruleFixer.insertTextBefore(operatorToken, logical.operator); // -> foo ||= bar
                            }
                        };
                        const fix = cannotBeGetter(logical.left) || accessesSingleProperty(logical.left);
                        context.report(createConditionalFixer(descriptor, suggestion, fix));
                    }
                },
                // if (foo) foo = bar
                "IfStatement[alternate=null]"(ifNode) {
                    if (!checkIf) {
                        return;
                    }
                    const hasBody = ifNode.consequent.type === "BlockStatement";
                    if (hasBody && ifNode.consequent.body.length !== 1) {
                        return;
                    }
                    const body = hasBody ? ifNode.consequent.body[0] : ifNode.consequent;
                    const scope = context.getScope();
                    const existence = getExistence(ifNode.test, scope);
                    if (body.type === "ExpressionStatement" &&
                        body.expression.type === "AssignmentExpression" &&
                        body.expression.operator === "=" &&
                        existence !== null &&
                        astUtils.isSameReference(existence.reference, body.expression.left)) {
                        const descriptor = {
                            messageId: "if",
                            node: ifNode,
                            data: { operator: `${existence.operator}=` }
                        };
                        const suggestion = {
                            messageId: "convertIf",
                            data: { operator: `${existence.operator}=` },
                            *fix(ruleFixer) {
                                if (sourceCode.getCommentsInside(ifNode).length > 0) {
                                    return;
                                }
                                const firstBodyToken = sourceCode.getFirstToken(body);
                                const prevToken = sourceCode.getTokenBefore(ifNode);
                                if (prevToken !== null &&
                                    prevToken.value !== ";" &&
                                    prevToken.value !== "{" &&
                                    firstBodyToken.type !== "Identifier" &&
                                    firstBodyToken.type !== "Keyword") {
                                    // Do not fix if the fixed statement could be part of the previous statement (eg. fn() if (a == null) (a) = b --> fn()(a) ??= b)
                                    return;
                                }
                                const operatorToken = getOperatorToken(body.expression);
                                yield ruleFixer.insertTextBefore(operatorToken, existence.operator); // -> if (foo) foo ||= bar
                                yield ruleFixer.removeRange([ifNode.range[0], body.range[0]]); // -> foo ||= bar
                                yield ruleFixer.removeRange([body.range[1], ifNode.range[1]]); // -> foo ||= bar, only present if "if" had a body
                                const nextToken = sourceCode.getTokenAfter(body.expression);
                                if (hasBody && (nextToken !== null && nextToken.value !== ";")) {
                                    yield ruleFixer.insertTextAfter(ifNode, ";");
                                }
                            }
                        };
                        const shouldBeFixed = cannotBeGetter(existence.reference) ||
                            (ifNode.test.type !== "LogicalExpression" && accessesSingleProperty(existence.reference));
                        context.report(createConditionalFixer(descriptor, suggestion, shouldBeFixed));
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/max-classes-per-file.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Enforce a maximum number of classes per file
     * @author James Garbutt <https://github.com/43081j>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce a maximum number of classes per file",
                recommended: false,
                url: "https://eslint.org/docs/rules/max-classes-per-file"
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: "integer",
                            minimum: 1
                        },
                        {
                            type: "object",
                            properties: {
                                ignoreExpressions: {
                                    type: "boolean"
                                },
                                max: {
                                    type: "integer",
                                    minimum: 1
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                maximumExceeded: "File has too many classes ({{ classCount }}). Maximum allowed is {{ max }}."
            }
        },
        create(context) {
            const [option = {}] = context.options;
            const [ignoreExpressions, max] = typeof option === "number"
                ? [false, option || 1]
                : [option.ignoreExpressions, option.max || 1];
            let classCount = 0;
            return {
                Program() {
                    classCount = 0;
                },
                "Program:exit"(node) {
                    if (classCount > max) {
                        context.report({
                            node,
                            messageId: "maximumExceeded",
                            data: {
                                classCount,
                                max
                            }
                        });
                    }
                },
                "ClassDeclaration"() {
                    classCount++;
                },
                "ClassExpression"() {
                    if (!ignoreExpressions) {
                        classCount++;
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/max-depth.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to set the maximum depth block can be nested in a function.
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce a maximum depth that blocks can be nested",
                recommended: false,
                url: "https://eslint.org/docs/rules/max-depth"
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: "integer",
                            minimum: 0
                        },
                        {
                            type: "object",
                            properties: {
                                maximum: {
                                    type: "integer",
                                    minimum: 0
                                },
                                max: {
                                    type: "integer",
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                tooDeeply: "Blocks are nested too deeply ({{depth}}). Maximum allowed is {{maxDepth}}."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            const functionStack = [], option = context.options[0];
            let maxDepth = 4;
            if (typeof option === "object" &&
                (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
                maxDepth = option.maximum || option.max;
            }
            if (typeof option === "number") {
                maxDepth = option;
            }
            /**
             * When parsing a new function, store it in our function stack
             * @returns {void}
             * @private
             */
            function startFunction() {
                functionStack.push(0);
            }
            /**
             * When parsing is done then pop out the reference
             * @returns {void}
             * @private
             */
            function endFunction() {
                functionStack.pop();
            }
            /**
             * Save the block and Evaluate the node
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function pushBlock(node) {
                const len = ++functionStack[functionStack.length - 1];
                if (len > maxDepth) {
                    context.report({ node, messageId: "tooDeeply", data: { depth: len, maxDepth } });
                }
            }
            /**
             * Pop the saved block
             * @returns {void}
             * @private
             */
            function popBlock() {
                functionStack[functionStack.length - 1]--;
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                Program: startFunction,
                FunctionDeclaration: startFunction,
                FunctionExpression: startFunction,
                ArrowFunctionExpression: startFunction,
                StaticBlock: startFunction,
                IfStatement(node) {
                    if (node.parent.type !== "IfStatement") {
                        pushBlock(node);
                    }
                },
                SwitchStatement: pushBlock,
                TryStatement: pushBlock,
                DoWhileStatement: pushBlock,
                WhileStatement: pushBlock,
                WithStatement: pushBlock,
                ForStatement: pushBlock,
                ForInStatement: pushBlock,
                ForOfStatement: pushBlock,
                "IfStatement:exit": popBlock,
                "SwitchStatement:exit": popBlock,
                "TryStatement:exit": popBlock,
                "DoWhileStatement:exit": popBlock,
                "WhileStatement:exit": popBlock,
                "WithStatement:exit": popBlock,
                "ForStatement:exit": popBlock,
                "ForInStatement:exit": popBlock,
                "ForOfStatement:exit": popBlock,
                "FunctionDeclaration:exit": endFunction,
                "FunctionExpression:exit": endFunction,
                "ArrowFunctionExpression:exit": endFunction,
                "StaticBlock:exit": endFunction,
                "Program:exit": endFunction
            };
        }
    };
},
/* eslint/lib/rules/max-len.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check for max length on a line.
     * @author Matt DuVall <http://www.mattduvall.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Constants
    //------------------------------------------------------------------------------
    const OPTIONS_SCHEMA = {
        type: "object",
        properties: {
            code: {
                type: "integer",
                minimum: 0
            },
            comments: {
                type: "integer",
                minimum: 0
            },
            tabWidth: {
                type: "integer",
                minimum: 0
            },
            ignorePattern: {
                type: "string"
            },
            ignoreComments: {
                type: "boolean"
            },
            ignoreStrings: {
                type: "boolean"
            },
            ignoreUrls: {
                type: "boolean"
            },
            ignoreTemplateLiterals: {
                type: "boolean"
            },
            ignoreRegExpLiterals: {
                type: "boolean"
            },
            ignoreTrailingComments: {
                type: "boolean"
            }
        },
        additionalProperties: false
    };
    const OPTIONS_OR_INTEGER_SCHEMA = {
        anyOf: [
            OPTIONS_SCHEMA,
            {
                type: "integer",
                minimum: 0
            }
        ]
    };
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce a maximum line length",
                recommended: false,
                url: "https://eslint.org/docs/rules/max-len"
            },
            schema: [
                OPTIONS_OR_INTEGER_SCHEMA,
                OPTIONS_OR_INTEGER_SCHEMA,
                OPTIONS_SCHEMA
            ],
            messages: {
                max: "This line has a length of {{lineLength}}. Maximum allowed is {{maxLength}}.",
                maxComment: "This line has a comment length of {{lineLength}}. Maximum allowed is {{maxCommentLength}}."
            }
        },
        create(context) {
            /*
             * Inspired by http://tools.ietf.org/html/rfc3986#appendix-B, however:
             * - They're matching an entire string that we know is a URI
             * - We're matching part of a string where we think there *might* be a URL
             * - We're only concerned about URLs, as picking out any URI would cause
             *   too many false positives
             * - We don't care about matching the entire URL, any small segment is fine
             */
            const URL_REGEXP = /[^:/?#]:\/\/[^?#]/u;
            const sourceCode = context.getSourceCode();
            /**
             * Computes the length of a line that may contain tabs. The width of each
             * tab will be the number of spaces to the next tab stop.
             * @param {string} line The line.
             * @param {int} tabWidth The width of each tab stop in spaces.
             * @returns {int} The computed line length.
             * @private
             */
            function computeLineLength(line, tabWidth) {
                let extraCharacterCount = 0;
                line.replace(/\t/gu, (match, offset) => {
                    const totalOffset = offset + extraCharacterCount, previousTabStopOffset = tabWidth ? totalOffset % tabWidth : 0, spaceCount = tabWidth - previousTabStopOffset;
                    extraCharacterCount += spaceCount - 1; // -1 for the replaced tab
                });
                return Array.from(line).length + extraCharacterCount;
            }
            // The options object must be the last option specified…
            const options = Object.assign({}, context.options[context.options.length - 1]);
            // …but max code length…
            if (typeof context.options[0] === "number") {
                options.code = context.options[0];
            }
            // …and tabWidth can be optionally specified directly as integers.
            if (typeof context.options[1] === "number") {
                options.tabWidth = context.options[1];
            }
            const maxLength = typeof options.code === "number" ? options.code : 80, tabWidth = typeof options.tabWidth === "number" ? options.tabWidth : 4, ignoreComments = !!options.ignoreComments, ignoreStrings = !!options.ignoreStrings, ignoreTemplateLiterals = !!options.ignoreTemplateLiterals, ignoreRegExpLiterals = !!options.ignoreRegExpLiterals, ignoreTrailingComments = !!options.ignoreTrailingComments || !!options.ignoreComments, ignoreUrls = !!options.ignoreUrls, maxCommentLength = options.comments;
            let ignorePattern = options.ignorePattern || null;
            if (ignorePattern) {
                ignorePattern = new RegExp(ignorePattern, "u");
            }
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Tells if a given comment is trailing: it starts on the current line and
             * extends to or past the end of the current line.
             * @param {string} line The source line we want to check for a trailing comment on
             * @param {number} lineNumber The one-indexed line number for line
             * @param {ASTNode} comment The comment to inspect
             * @returns {boolean} If the comment is trailing on the given line
             */
            function isTrailingComment(line, lineNumber, comment) {
                return comment &&
                    (comment.loc.start.line === lineNumber && lineNumber <= comment.loc.end.line) &&
                    (comment.loc.end.line > lineNumber || comment.loc.end.column === line.length);
            }
            /**
             * Tells if a comment encompasses the entire line.
             * @param {string} line The source line with a trailing comment
             * @param {number} lineNumber The one-indexed line number this is on
             * @param {ASTNode} comment The comment to remove
             * @returns {boolean} If the comment covers the entire line
             */
            function isFullLineComment(line, lineNumber, comment) {
                const start = comment.loc.start, end = comment.loc.end, isFirstTokenOnLine = !line.slice(0, comment.loc.start.column).trim();
                return comment &&
                    (start.line < lineNumber || (start.line === lineNumber && isFirstTokenOnLine)) &&
                    (end.line > lineNumber || (end.line === lineNumber && end.column === line.length));
            }
            /**
             * Check if a node is a JSXEmptyExpression contained in a single line JSXExpressionContainer.
             * @param {ASTNode} node A node to check.
             * @returns {boolean} True if the node is a JSXEmptyExpression contained in a single line JSXExpressionContainer.
             */
            function isJSXEmptyExpressionInSingleLineContainer(node) {
                if (!node || !node.parent || node.type !== "JSXEmptyExpression" || node.parent.type !== "JSXExpressionContainer") {
                    return false;
                }
                const parent = node.parent;
                return parent.loc.start.line === parent.loc.end.line;
            }
            /**
             * Gets the line after the comment and any remaining trailing whitespace is
             * stripped.
             * @param {string} line The source line with a trailing comment
             * @param {ASTNode} comment The comment to remove
             * @returns {string} Line without comment and trailing whitespace
             */
            function stripTrailingComment(line, comment) {
                // loc.column is zero-indexed
                return line.slice(0, comment.loc.start.column).replace(/\s+$/u, "");
            }
            /**
             * Ensure that an array exists at [key] on `object`, and add `value` to it.
             * @param {Object} object the object to mutate
             * @param {string} key the object's key
             * @param {any} value the value to add
             * @returns {void}
             * @private
             */
            function ensureArrayAndPush(object, key, value) {
                if (!Array.isArray(object[key])) {
                    object[key] = [];
                }
                object[key].push(value);
            }
            /**
             * Retrieves an array containing all strings (" or ') in the source code.
             * @returns {ASTNode[]} An array of string nodes.
             */
            function getAllStrings() {
                return sourceCode.ast.tokens.filter(token => (token.type === "String" ||
                    (token.type === "JSXText" && sourceCode.getNodeByRangeIndex(token.range[0] - 1).type === "JSXAttribute")));
            }
            /**
             * Retrieves an array containing all template literals in the source code.
             * @returns {ASTNode[]} An array of template literal nodes.
             */
            function getAllTemplateLiterals() {
                return sourceCode.ast.tokens.filter(token => token.type === "Template");
            }
            /**
             * Retrieves an array containing all RegExp literals in the source code.
             * @returns {ASTNode[]} An array of RegExp literal nodes.
             */
            function getAllRegExpLiterals() {
                return sourceCode.ast.tokens.filter(token => token.type === "RegularExpression");
            }
            /**
             * A reducer to group an AST node by line number, both start and end.
             * @param {Object} acc the accumulator
             * @param {ASTNode} node the AST node in question
             * @returns {Object} the modified accumulator
             * @private
             */
            function groupByLineNumber(acc, node) {
                for (let i = node.loc.start.line; i <= node.loc.end.line; ++i) {
                    ensureArrayAndPush(acc, i, node);
                }
                return acc;
            }
            /**
             * Returns an array of all comments in the source code.
             * If the element in the array is a JSXEmptyExpression contained with a single line JSXExpressionContainer,
             * the element is changed with JSXExpressionContainer node.
             * @returns {ASTNode[]} An array of comment nodes
             */
            function getAllComments() {
                const comments = [];
                sourceCode.getAllComments()
                    .forEach(commentNode => {
                    const containingNode = sourceCode.getNodeByRangeIndex(commentNode.range[0]);
                    if (isJSXEmptyExpressionInSingleLineContainer(containingNode)) {
                        // push a unique node only
                        if (comments[comments.length - 1] !== containingNode.parent) {
                            comments.push(containingNode.parent);
                        }
                    }
                    else {
                        comments.push(commentNode);
                    }
                });
                return comments;
            }
            /**
             * Check the program for max length
             * @param {ASTNode} node Node to examine
             * @returns {void}
             * @private
             */
            function checkProgramForMaxLength(node) {
                // split (honors line-ending)
                const lines = sourceCode.lines, 
                // list of comments to ignore
                comments = ignoreComments || maxCommentLength || ignoreTrailingComments ? getAllComments() : [];
                // we iterate over comments in parallel with the lines
                let commentsIndex = 0;
                const strings = getAllStrings();
                const stringsByLine = strings.reduce(groupByLineNumber, {});
                const templateLiterals = getAllTemplateLiterals();
                const templateLiteralsByLine = templateLiterals.reduce(groupByLineNumber, {});
                const regExpLiterals = getAllRegExpLiterals();
                const regExpLiteralsByLine = regExpLiterals.reduce(groupByLineNumber, {});
                lines.forEach((line, i) => {
                    // i is zero-indexed, line numbers are one-indexed
                    const lineNumber = i + 1;
                    /*
                     * if we're checking comment length; we need to know whether this
                     * line is a comment
                     */
                    let lineIsComment = false;
                    let textToMeasure;
                    /*
                     * We can short-circuit the comment checks if we're already out of
                     * comments to check.
                     */
                    if (commentsIndex < comments.length) {
                        let comment = null;
                        // iterate over comments until we find one past the current line
                        do {
                            comment = comments[++commentsIndex];
                        } while (comment && comment.loc.start.line <= lineNumber);
                        // and step back by one
                        comment = comments[--commentsIndex];
                        if (isFullLineComment(line, lineNumber, comment)) {
                            lineIsComment = true;
                            textToMeasure = line;
                        }
                        else if (ignoreTrailingComments && isTrailingComment(line, lineNumber, comment)) {
                            textToMeasure = stripTrailingComment(line, comment);
                            // ignore multiple trailing comments in the same line
                            let lastIndex = commentsIndex;
                            while (isTrailingComment(textToMeasure, lineNumber, comments[--lastIndex])) {
                                textToMeasure = stripTrailingComment(textToMeasure, comments[lastIndex]);
                            }
                        }
                        else {
                            textToMeasure = line;
                        }
                    }
                    else {
                        textToMeasure = line;
                    }
                    if (ignorePattern && ignorePattern.test(textToMeasure) ||
                        ignoreUrls && URL_REGEXP.test(textToMeasure) ||
                        ignoreStrings && stringsByLine[lineNumber] ||
                        ignoreTemplateLiterals && templateLiteralsByLine[lineNumber] ||
                        ignoreRegExpLiterals && regExpLiteralsByLine[lineNumber]) {
                        // ignore this line
                        return;
                    }
                    const lineLength = computeLineLength(textToMeasure, tabWidth);
                    const commentLengthApplies = lineIsComment && maxCommentLength;
                    if (lineIsComment && ignoreComments) {
                        return;
                    }
                    const loc = {
                        start: {
                            line: lineNumber,
                            column: 0
                        },
                        end: {
                            line: lineNumber,
                            column: textToMeasure.length
                        }
                    };
                    if (commentLengthApplies) {
                        if (lineLength > maxCommentLength) {
                            context.report({
                                node,
                                loc,
                                messageId: "maxComment",
                                data: {
                                    lineLength,
                                    maxCommentLength
                                }
                            });
                        }
                    }
                    else if (lineLength > maxLength) {
                        context.report({
                            node,
                            loc,
                            messageId: "max",
                            data: {
                                lineLength,
                                maxLength
                            }
                        });
                    }
                });
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                Program: checkProgramForMaxLength
            };
        }
    };
},
/* eslint/lib/rules/max-lines.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview enforce a maximum file length
     * @author Alberto Rodríguez
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Creates an array of numbers from `start` up to, but not including, `end`
     * @param {number} start The start of the range
     * @param {number} end The end of the range
     * @returns {number[]} The range of numbers
     */
    function range(start, end) {
        return [...Array(end - start).keys()].map(x => x + start);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce a maximum number of lines per file",
                recommended: false,
                url: "https://eslint.org/docs/rules/max-lines"
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: "integer",
                            minimum: 0
                        },
                        {
                            type: "object",
                            properties: {
                                max: {
                                    type: "integer",
                                    minimum: 0
                                },
                                skipComments: {
                                    type: "boolean"
                                },
                                skipBlankLines: {
                                    type: "boolean"
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                exceed: "File has too many lines ({{actual}}). Maximum allowed is {{max}}."
            }
        },
        create(context) {
            const option = context.options[0];
            let max = 300;
            if (typeof option === "object" &&
                Object.prototype.hasOwnProperty.call(option, "max")) {
                max = option.max;
            }
            else if (typeof option === "number") {
                max = option;
            }
            const skipComments = option && option.skipComments;
            const skipBlankLines = option && option.skipBlankLines;
            const sourceCode = context.getSourceCode();
            /**
             * Returns whether or not a token is a comment node type
             * @param {Token} token The token to check
             * @returns {boolean} True if the token is a comment node
             */
            function isCommentNodeType(token) {
                return token && (token.type === "Block" || token.type === "Line");
            }
            /**
             * Returns the line numbers of a comment that don't have any code on the same line
             * @param {Node} comment The comment node to check
             * @returns {number[]} The line numbers
             */
            function getLinesWithoutCode(comment) {
                let start = comment.loc.start.line;
                let end = comment.loc.end.line;
                let token;
                token = comment;
                do {
                    token = sourceCode.getTokenBefore(token, {
                        includeComments: true
                    });
                } while (isCommentNodeType(token));
                if (token && astUtils.isTokenOnSameLine(token, comment)) {
                    start += 1;
                }
                token = comment;
                do {
                    token = sourceCode.getTokenAfter(token, {
                        includeComments: true
                    });
                } while (isCommentNodeType(token));
                if (token && astUtils.isTokenOnSameLine(comment, token)) {
                    end -= 1;
                }
                if (start <= end) {
                    return range(start, end + 1);
                }
                return [];
            }
            return {
                "Program:exit"() {
                    let lines = sourceCode.lines.map((text, i) => ({
                        lineNumber: i + 1,
                        text
                    }));
                    /*
                     * If file ends with a linebreak, `sourceCode.lines` will have one extra empty line at the end.
                     * That isn't a real line, so we shouldn't count it.
                     */
                    if (lines.length > 1 && lines[lines.length - 1].text === "") {
                        lines.pop();
                    }
                    if (skipBlankLines) {
                        lines = lines.filter(l => l.text.trim() !== "");
                    }
                    if (skipComments) {
                        const comments = sourceCode.getAllComments();
                        const commentLines = new Set(comments.flatMap(getLinesWithoutCode));
                        lines = lines.filter(l => !commentLines.has(l.lineNumber));
                    }
                    if (lines.length > max) {
                        const loc = {
                            start: {
                                line: lines[max].lineNumber,
                                column: 0
                            },
                            end: {
                                line: sourceCode.lines.length,
                                column: sourceCode.lines[sourceCode.lines.length - 1].length
                            }
                        };
                        context.report({
                            loc,
                            messageId: "exceed",
                            data: {
                                max,
                                actual: lines.length
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/max-lines-per-function.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview A rule to set the maximum number of line of code in a function.
     * @author Pete Ward <peteward44@gmail.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const { upperCaseFirst } = require(384) /* ../shared/string-utils */;
    //------------------------------------------------------------------------------
    // Constants
    //------------------------------------------------------------------------------
    const OPTIONS_SCHEMA = {
        type: "object",
        properties: {
            max: {
                type: "integer",
                minimum: 0
            },
            skipComments: {
                type: "boolean"
            },
            skipBlankLines: {
                type: "boolean"
            },
            IIFEs: {
                type: "boolean"
            }
        },
        additionalProperties: false
    };
    const OPTIONS_OR_INTEGER_SCHEMA = {
        oneOf: [
            OPTIONS_SCHEMA,
            {
                type: "integer",
                minimum: 1
            }
        ]
    };
    /**
     * Given a list of comment nodes, return a map with numeric keys (source code line numbers) and comment token values.
     * @param {Array} comments An array of comment nodes.
     * @returns {Map<string, Node>} A map with numeric keys (source code line numbers) and comment token values.
     */
    function getCommentLineNumbers(comments) {
        const map = new Map();
        comments.forEach(comment => {
            for (let i = comment.loc.start.line; i <= comment.loc.end.line; i++) {
                map.set(i, comment);
            }
        });
        return map;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce a maximum number of lines of code in a function",
                recommended: false,
                url: "https://eslint.org/docs/rules/max-lines-per-function"
            },
            schema: [
                OPTIONS_OR_INTEGER_SCHEMA
            ],
            messages: {
                exceed: "{{name}} has too many lines ({{lineCount}}). Maximum allowed is {{maxLines}}."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const lines = sourceCode.lines;
            const option = context.options[0];
            let maxLines = 50;
            let skipComments = false;
            let skipBlankLines = false;
            let IIFEs = false;
            if (typeof option === "object") {
                maxLines = typeof option.max === "number" ? option.max : 50;
                skipComments = !!option.skipComments;
                skipBlankLines = !!option.skipBlankLines;
                IIFEs = !!option.IIFEs;
            }
            else if (typeof option === "number") {
                maxLines = option;
            }
            const commentLineNumbers = getCommentLineNumbers(sourceCode.getAllComments());
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Tells if a comment encompasses the entire line.
             * @param {string} line The source line with a trailing comment
             * @param {number} lineNumber The one-indexed line number this is on
             * @param {ASTNode} comment The comment to remove
             * @returns {boolean} If the comment covers the entire line
             */
            function isFullLineComment(line, lineNumber, comment) {
                const start = comment.loc.start, end = comment.loc.end, isFirstTokenOnLine = start.line === lineNumber && !line.slice(0, start.column).trim(), isLastTokenOnLine = end.line === lineNumber && !line.slice(end.column).trim();
                return comment &&
                    (start.line < lineNumber || isFirstTokenOnLine) &&
                    (end.line > lineNumber || isLastTokenOnLine);
            }
            /**
             * Identifies is a node is a FunctionExpression which is part of an IIFE
             * @param {ASTNode} node Node to test
             * @returns {boolean} True if it's an IIFE
             */
            function isIIFE(node) {
                return (node.type === "FunctionExpression" || node.type === "ArrowFunctionExpression") && node.parent && node.parent.type === "CallExpression" && node.parent.callee === node;
            }
            /**
             * Identifies is a node is a FunctionExpression which is embedded within a MethodDefinition or Property
             * @param {ASTNode} node Node to test
             * @returns {boolean} True if it's a FunctionExpression embedded within a MethodDefinition or Property
             */
            function isEmbedded(node) {
                if (!node.parent) {
                    return false;
                }
                if (node !== node.parent.value) {
                    return false;
                }
                if (node.parent.type === "MethodDefinition") {
                    return true;
                }
                if (node.parent.type === "Property") {
                    return node.parent.method === true || node.parent.kind === "get" || node.parent.kind === "set";
                }
                return false;
            }
            /**
             * Count the lines in the function
             * @param {ASTNode} funcNode Function AST node
             * @returns {void}
             * @private
             */
            function processFunction(funcNode) {
                const node = isEmbedded(funcNode) ? funcNode.parent : funcNode;
                if (!IIFEs && isIIFE(node)) {
                    return;
                }
                let lineCount = 0;
                for (let i = node.loc.start.line - 1; i < node.loc.end.line; ++i) {
                    const line = lines[i];
                    if (skipComments) {
                        if (commentLineNumbers.has(i + 1) && isFullLineComment(line, i + 1, commentLineNumbers.get(i + 1))) {
                            continue;
                        }
                    }
                    if (skipBlankLines) {
                        if (line.match(/^\s*$/u)) {
                            continue;
                        }
                    }
                    lineCount++;
                }
                if (lineCount > maxLines) {
                    const name = upperCaseFirst(astUtils.getFunctionNameWithKind(funcNode));
                    context.report({
                        node,
                        messageId: "exceed",
                        data: { name, lineCount, maxLines }
                    });
                }
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                FunctionDeclaration: processFunction,
                FunctionExpression: processFunction,
                ArrowFunctionExpression: processFunction
            };
        }
    };
},
/* eslint/lib/rules/max-nested-callbacks.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce a maximum number of nested callbacks.
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce a maximum depth that callbacks can be nested",
                recommended: false,
                url: "https://eslint.org/docs/rules/max-nested-callbacks"
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: "integer",
                            minimum: 0
                        },
                        {
                            type: "object",
                            properties: {
                                maximum: {
                                    type: "integer",
                                    minimum: 0
                                },
                                max: {
                                    type: "integer",
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                exceed: "Too many nested callbacks ({{num}}). Maximum allowed is {{max}}."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Constants
            //--------------------------------------------------------------------------
            const option = context.options[0];
            let THRESHOLD = 10;
            if (typeof option === "object" &&
                (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
                THRESHOLD = option.maximum || option.max;
            }
            else if (typeof option === "number") {
                THRESHOLD = option;
            }
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            const callbackStack = [];
            /**
             * Checks a given function node for too many callbacks.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             * @private
             */
            function checkFunction(node) {
                const parent = node.parent;
                if (parent.type === "CallExpression") {
                    callbackStack.push(node);
                }
                if (callbackStack.length > THRESHOLD) {
                    const opts = { num: callbackStack.length, max: THRESHOLD };
                    context.report({ node, messageId: "exceed", data: opts });
                }
            }
            /**
             * Pops the call stack.
             * @returns {void}
             * @private
             */
            function popStack() {
                callbackStack.pop();
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                ArrowFunctionExpression: checkFunction,
                "ArrowFunctionExpression:exit": popStack,
                FunctionExpression: checkFunction,
                "FunctionExpression:exit": popStack
            };
        }
    };
},
/* eslint/lib/rules/max-params.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when a function has too many parameters
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const { upperCaseFirst } = require(384) /* ../shared/string-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce a maximum number of parameters in function definitions",
                recommended: false,
                url: "https://eslint.org/docs/rules/max-params"
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: "integer",
                            minimum: 0
                        },
                        {
                            type: "object",
                            properties: {
                                maximum: {
                                    type: "integer",
                                    minimum: 0
                                },
                                max: {
                                    type: "integer",
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                exceed: "{{name}} has too many parameters ({{count}}). Maximum allowed is {{max}}."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const option = context.options[0];
            let numParams = 3;
            if (typeof option === "object" &&
                (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
                numParams = option.maximum || option.max;
            }
            if (typeof option === "number") {
                numParams = option;
            }
            /**
             * Checks a function to see if it has too many parameters.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             * @private
             */
            function checkFunction(node) {
                if (node.params.length > numParams) {
                    context.report({
                        loc: astUtils.getFunctionHeadLoc(node, sourceCode),
                        node,
                        messageId: "exceed",
                        data: {
                            name: upperCaseFirst(astUtils.getFunctionNameWithKind(node)),
                            count: node.params.length,
                            max: numParams
                        }
                    });
                }
            }
            return {
                FunctionDeclaration: checkFunction,
                ArrowFunctionExpression: checkFunction,
                FunctionExpression: checkFunction
            };
        }
    };
},
/* eslint/lib/rules/max-statements.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to set the maximum number of statements in a function.
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const { upperCaseFirst } = require(384) /* ../shared/string-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce a maximum number of statements allowed in function blocks",
                recommended: false,
                url: "https://eslint.org/docs/rules/max-statements"
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: "integer",
                            minimum: 0
                        },
                        {
                            type: "object",
                            properties: {
                                maximum: {
                                    type: "integer",
                                    minimum: 0
                                },
                                max: {
                                    type: "integer",
                                    minimum: 0
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                },
                {
                    type: "object",
                    properties: {
                        ignoreTopLevelFunctions: {
                            type: "boolean"
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                exceed: "{{name}} has too many statements ({{count}}). Maximum allowed is {{max}}."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            const functionStack = [], option = context.options[0], ignoreTopLevelFunctions = context.options[1] && context.options[1].ignoreTopLevelFunctions || false, topLevelFunctions = [];
            let maxStatements = 10;
            if (typeof option === "object" &&
                (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
                maxStatements = option.maximum || option.max;
            }
            else if (typeof option === "number") {
                maxStatements = option;
            }
            /**
             * Reports a node if it has too many statements
             * @param {ASTNode} node node to evaluate
             * @param {int} count Number of statements in node
             * @param {int} max Maximum number of statements allowed
             * @returns {void}
             * @private
             */
            function reportIfTooManyStatements(node, count, max) {
                if (count > max) {
                    const name = upperCaseFirst(astUtils.getFunctionNameWithKind(node));
                    context.report({
                        node,
                        messageId: "exceed",
                        data: { name, count, max }
                    });
                }
            }
            /**
             * When parsing a new function, store it in our function stack
             * @returns {void}
             * @private
             */
            function startFunction() {
                functionStack.push(0);
            }
            /**
             * Evaluate the node at the end of function
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function endFunction(node) {
                const count = functionStack.pop();
                /*
                 * This rule does not apply to class static blocks, but we have to track them so
                 * that statements in them do not count as statements in the enclosing function.
                 */
                if (node.type === "StaticBlock") {
                    return;
                }
                if (ignoreTopLevelFunctions && functionStack.length === 0) {
                    topLevelFunctions.push({ node, count });
                }
                else {
                    reportIfTooManyStatements(node, count, maxStatements);
                }
            }
            /**
             * Increment the count of the functions
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function countStatements(node) {
                functionStack[functionStack.length - 1] += node.body.length;
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                FunctionDeclaration: startFunction,
                FunctionExpression: startFunction,
                ArrowFunctionExpression: startFunction,
                StaticBlock: startFunction,
                BlockStatement: countStatements,
                "FunctionDeclaration:exit": endFunction,
                "FunctionExpression:exit": endFunction,
                "ArrowFunctionExpression:exit": endFunction,
                "StaticBlock:exit": endFunction,
                "Program:exit"() {
                    if (topLevelFunctions.length === 1) {
                        return;
                    }
                    topLevelFunctions.forEach(element => {
                        const count = element.count;
                        const node = element.node;
                        reportIfTooManyStatements(node, count, maxStatements);
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/max-statements-per-line.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Specify the maximum number of statements allowed per line.
     * @author Kenneth Williams
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce a maximum number of statements allowed per line",
                recommended: false,
                url: "https://eslint.org/docs/rules/max-statements-per-line"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        max: {
                            type: "integer",
                            minimum: 1,
                            default: 1
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                exceed: "This line has {{numberOfStatementsOnThisLine}} {{statements}}. Maximum allowed is {{maxStatementsPerLine}}."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode(), options = context.options[0] || {}, maxStatementsPerLine = typeof options.max !== "undefined" ? options.max : 1;
            let lastStatementLine = 0, numberOfStatementsOnThisLine = 0, firstExtraStatement;
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            const SINGLE_CHILD_ALLOWED = /^(?:(?:DoWhile|For|ForIn|ForOf|If|Labeled|While)Statement|Export(?:Default|Named)Declaration)$/u;
            /**
             * Reports with the first extra statement, and clears it.
             * @returns {void}
             */
            function reportFirstExtraStatementAndClear() {
                if (firstExtraStatement) {
                    context.report({
                        node: firstExtraStatement,
                        messageId: "exceed",
                        data: {
                            numberOfStatementsOnThisLine,
                            maxStatementsPerLine,
                            statements: numberOfStatementsOnThisLine === 1 ? "statement" : "statements"
                        }
                    });
                }
                firstExtraStatement = null;
            }
            /**
             * Gets the actual last token of a given node.
             * @param {ASTNode} node A node to get. This is a node except EmptyStatement.
             * @returns {Token} The actual last token.
             */
            function getActualLastToken(node) {
                return sourceCode.getLastToken(node, astUtils.isNotSemicolonToken);
            }
            /**
             * Addresses a given node.
             * It updates the state of this rule, then reports the node if the node violated this rule.
             * @param {ASTNode} node A node to check.
             * @returns {void}
             */
            function enterStatement(node) {
                const line = node.loc.start.line;
                /*
                 * Skip to allow non-block statements if this is direct child of control statements.
                 * `if (a) foo();` is counted as 1.
                 * But `if (a) foo(); else foo();` should be counted as 2.
                 */
                if (SINGLE_CHILD_ALLOWED.test(node.parent.type) &&
                    node.parent.alternate !== node) {
                    return;
                }
                // Update state.
                if (line === lastStatementLine) {
                    numberOfStatementsOnThisLine += 1;
                }
                else {
                    reportFirstExtraStatementAndClear();
                    numberOfStatementsOnThisLine = 1;
                    lastStatementLine = line;
                }
                // Reports if the node violated this rule.
                if (numberOfStatementsOnThisLine === maxStatementsPerLine + 1) {
                    firstExtraStatement = firstExtraStatement || node;
                }
            }
            /**
             * Updates the state of this rule with the end line of leaving node to check with the next statement.
             * @param {ASTNode} node A node to check.
             * @returns {void}
             */
            function leaveStatement(node) {
                const line = getActualLastToken(node).loc.end.line;
                // Update state.
                if (line !== lastStatementLine) {
                    reportFirstExtraStatementAndClear();
                    numberOfStatementsOnThisLine = 1;
                    lastStatementLine = line;
                }
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                BreakStatement: enterStatement,
                ClassDeclaration: enterStatement,
                ContinueStatement: enterStatement,
                DebuggerStatement: enterStatement,
                DoWhileStatement: enterStatement,
                ExpressionStatement: enterStatement,
                ForInStatement: enterStatement,
                ForOfStatement: enterStatement,
                ForStatement: enterStatement,
                FunctionDeclaration: enterStatement,
                IfStatement: enterStatement,
                ImportDeclaration: enterStatement,
                LabeledStatement: enterStatement,
                ReturnStatement: enterStatement,
                SwitchStatement: enterStatement,
                ThrowStatement: enterStatement,
                TryStatement: enterStatement,
                VariableDeclaration: enterStatement,
                WhileStatement: enterStatement,
                WithStatement: enterStatement,
                ExportNamedDeclaration: enterStatement,
                ExportDefaultDeclaration: enterStatement,
                ExportAllDeclaration: enterStatement,
                "BreakStatement:exit": leaveStatement,
                "ClassDeclaration:exit": leaveStatement,
                "ContinueStatement:exit": leaveStatement,
                "DebuggerStatement:exit": leaveStatement,
                "DoWhileStatement:exit": leaveStatement,
                "ExpressionStatement:exit": leaveStatement,
                "ForInStatement:exit": leaveStatement,
                "ForOfStatement:exit": leaveStatement,
                "ForStatement:exit": leaveStatement,
                "FunctionDeclaration:exit": leaveStatement,
                "IfStatement:exit": leaveStatement,
                "ImportDeclaration:exit": leaveStatement,
                "LabeledStatement:exit": leaveStatement,
                "ReturnStatement:exit": leaveStatement,
                "SwitchStatement:exit": leaveStatement,
                "ThrowStatement:exit": leaveStatement,
                "TryStatement:exit": leaveStatement,
                "VariableDeclaration:exit": leaveStatement,
                "WhileStatement:exit": leaveStatement,
                "WithStatement:exit": leaveStatement,
                "ExportNamedDeclaration:exit": leaveStatement,
                "ExportDefaultDeclaration:exit": leaveStatement,
                "ExportAllDeclaration:exit": leaveStatement,
                "Program:exit": reportFirstExtraStatementAndClear
            };
        }
    };
},
/* eslint/lib/rules/multiline-comment-style.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview enforce a particular style for multiline comments
     * @author Teddy Katz
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce a particular style for multiline comments",
                recommended: false,
                url: "https://eslint.org/docs/rules/multiline-comment-style"
            },
            fixable: "whitespace",
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["starred-block", "bare-block"]
                            }
                        ],
                        additionalItems: false
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["separate-lines"]
                            },
                            {
                                type: "object",
                                properties: {
                                    checkJSDoc: {
                                        type: "boolean"
                                    }
                                },
                                additionalProperties: false
                            }
                        ],
                        additionalItems: false
                    }
                ]
            },
            messages: {
                expectedBlock: "Expected a block comment instead of consecutive line comments.",
                expectedBareBlock: "Expected a block comment without padding stars.",
                startNewline: "Expected a linebreak after '/*'.",
                endNewline: "Expected a linebreak before '*/'.",
                missingStar: "Expected a '*' at the start of this line.",
                alignment: "Expected this line to be aligned with the start of the comment.",
                expectedLines: "Expected multiple line comments instead of a block comment."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const option = context.options[0] || "starred-block";
            const params = context.options[1] || {};
            const checkJSDoc = !!params.checkJSDoc;
            //----------------------------------------------------------------------
            // Helpers
            //----------------------------------------------------------------------
            /**
             * Checks if a comment line is starred.
             * @param {string} line A string representing a comment line.
             * @returns {boolean} Whether or not the comment line is starred.
             */
            function isStarredCommentLine(line) {
                return /^\s*\*/u.test(line);
            }
            /**
             * Checks if a comment group is in starred-block form.
             * @param {Token[]} commentGroup A group of comments, containing either multiple line comments or a single block comment.
             * @returns {boolean} Whether or not the comment group is in starred block form.
             */
            function isStarredBlockComment([firstComment]) {
                if (firstComment.type !== "Block") {
                    return false;
                }
                const lines = firstComment.value.split(astUtils.LINEBREAK_MATCHER);
                // The first and last lines can only contain whitespace.
                return lines.length > 0 && lines.every((line, i) => (i === 0 || i === lines.length - 1 ? /^\s*$/u : /^\s*\*/u).test(line));
            }
            /**
             * Checks if a comment group is in JSDoc form.
             * @param {Token[]} commentGroup A group of comments, containing either multiple line comments or a single block comment.
             * @returns {boolean} Whether or not the comment group is in JSDoc form.
             */
            function isJSDocComment([firstComment]) {
                if (firstComment.type !== "Block") {
                    return false;
                }
                const lines = firstComment.value.split(astUtils.LINEBREAK_MATCHER);
                return /^\*\s*$/u.test(lines[0]) &&
                    lines.slice(1, -1).every(line => /^\s* /u.test(line)) &&
                    /^\s*$/u.test(lines[lines.length - 1]);
            }
            /**
             * Processes a comment group that is currently in separate-line form, calculating the offset for each line.
             * @param {Token[]} commentGroup A group of comments containing multiple line comments.
             * @returns {string[]} An array of the processed lines.
             */
            function processSeparateLineComments(commentGroup) {
                const allLinesHaveLeadingSpace = commentGroup
                    .map(({ value }) => value)
                    .filter(line => line.trim().length)
                    .every(line => line.startsWith(" "));
                return commentGroup.map(({ value }) => (allLinesHaveLeadingSpace ? value.replace(/^ /u, "") : value));
            }
            /**
             * Processes a comment group that is currently in starred-block form, calculating the offset for each line.
             * @param {Token} comment A single block comment token in starred-block form.
             * @returns {string[]} An array of the processed lines.
             */
            function processStarredBlockComment(comment) {
                const lines = comment.value.split(astUtils.LINEBREAK_MATCHER)
                    .filter((line, i, linesArr) => !(i === 0 || i === linesArr.length - 1))
                    .map(line => line.replace(/^\s*$/u, ""));
                const allLinesHaveLeadingSpace = lines
                    .map(line => line.replace(/\s*\*/u, ""))
                    .filter(line => line.trim().length)
                    .every(line => line.startsWith(" "));
                return lines.map(line => line.replace(allLinesHaveLeadingSpace ? /\s*\* ?/u : /\s*\*/u, ""));
            }
            /**
             * Processes a comment group that is currently in bare-block form, calculating the offset for each line.
             * @param {Token} comment A single block comment token in bare-block form.
             * @returns {string[]} An array of the processed lines.
             */
            function processBareBlockComment(comment) {
                const lines = comment.value.split(astUtils.LINEBREAK_MATCHER).map(line => line.replace(/^\s*$/u, ""));
                const leadingWhitespace = `${sourceCode.text.slice(comment.range[0] - comment.loc.start.column, comment.range[0])}   `;
                let offset = "";
                /*
                 * Calculate the offset of the least indented line and use that as the basis for offsetting all the lines.
                 * The first line should not be checked because it is inline with the opening block comment delimiter.
                 */
                for (const [i, line] of lines.entries()) {
                    if (!line.trim().length || i === 0) {
                        continue;
                    }
                    const [, lineOffset] = line.match(/^(\s*\*?\s*)/u);
                    if (lineOffset.length < leadingWhitespace.length) {
                        const newOffset = leadingWhitespace.slice(lineOffset.length - leadingWhitespace.length);
                        if (newOffset.length > offset.length) {
                            offset = newOffset;
                        }
                    }
                }
                return lines.map(line => {
                    const match = line.match(/^(\s*\*?\s*)(.*)/u);
                    const [, lineOffset, lineContents] = match;
                    if (lineOffset.length > leadingWhitespace.length) {
                        return `${lineOffset.slice(leadingWhitespace.length - (offset.length + lineOffset.length))}${lineContents}`;
                    }
                    if (lineOffset.length < leadingWhitespace.length) {
                        return `${lineOffset.slice(leadingWhitespace.length)}${lineContents}`;
                    }
                    return lineContents;
                });
            }
            /**
             * Gets a list of comment lines in a group, formatting leading whitespace as necessary.
             * @param {Token[]} commentGroup A group of comments containing either multiple line comments or a single block comment.
             * @returns {string[]} A list of comment lines.
             */
            function getCommentLines(commentGroup) {
                const [firstComment] = commentGroup;
                if (firstComment.type === "Line") {
                    return processSeparateLineComments(commentGroup);
                }
                if (isStarredBlockComment(commentGroup)) {
                    return processStarredBlockComment(firstComment);
                }
                return processBareBlockComment(firstComment);
            }
            /**
             * Gets the initial offset (whitespace) from the beginning of a line to a given comment token.
             * @param {Token} comment The token to check.
             * @returns {string} The offset from the beginning of a line to the token.
             */
            function getInitialOffset(comment) {
                return sourceCode.text.slice(comment.range[0] - comment.loc.start.column, comment.range[0]);
            }
            /**
             * Converts a comment into starred-block form
             * @param {Token} firstComment The first comment of the group being converted
             * @param {string[]} commentLinesList A list of lines to appear in the new starred-block comment
             * @returns {string} A representation of the comment value in starred-block form, excluding start and end markers
             */
            function convertToStarredBlock(firstComment, commentLinesList) {
                const initialOffset = getInitialOffset(firstComment);
                return `/*\n${commentLinesList.map(line => `${initialOffset} * ${line}`).join("\n")}\n${initialOffset} */`;
            }
            /**
             * Converts a comment into separate-line form
             * @param {Token} firstComment The first comment of the group being converted
             * @param {string[]} commentLinesList A list of lines to appear in the new starred-block comment
             * @returns {string} A representation of the comment value in separate-line form
             */
            function convertToSeparateLines(firstComment, commentLinesList) {
                return commentLinesList.map(line => `// ${line}`).join(`\n${getInitialOffset(firstComment)}`);
            }
            /**
             * Converts a comment into bare-block form
             * @param {Token} firstComment The first comment of the group being converted
             * @param {string[]} commentLinesList A list of lines to appear in the new starred-block comment
             * @returns {string} A representation of the comment value in bare-block form
             */
            function convertToBlock(firstComment, commentLinesList) {
                return `/* ${commentLinesList.join(`\n${getInitialOffset(firstComment)}   `)} */`;
            }
            /**
             * Each method checks a group of comments to see if it's valid according to the given option.
             * @param {Token[]} commentGroup A list of comments that appear together. This will either contain a single
             * block comment or multiple line comments.
             * @returns {void}
             */
            const commentGroupCheckers = {
                "starred-block"(commentGroup) {
                    const [firstComment] = commentGroup;
                    const commentLines = getCommentLines(commentGroup);
                    if (commentLines.some(value => value.includes("*/"))) {
                        return;
                    }
                    if (commentGroup.length > 1) {
                        context.report({
                            loc: {
                                start: firstComment.loc.start,
                                end: commentGroup[commentGroup.length - 1].loc.end
                            },
                            messageId: "expectedBlock",
                            fix(fixer) {
                                const range = [firstComment.range[0], commentGroup[commentGroup.length - 1].range[1]];
                                return commentLines.some(value => value.startsWith("/"))
                                    ? null
                                    : fixer.replaceTextRange(range, convertToStarredBlock(firstComment, commentLines));
                            }
                        });
                    }
                    else {
                        const lines = firstComment.value.split(astUtils.LINEBREAK_MATCHER);
                        const expectedLeadingWhitespace = getInitialOffset(firstComment);
                        const expectedLinePrefix = `${expectedLeadingWhitespace} *`;
                        if (!/^\*?\s*$/u.test(lines[0])) {
                            const start = firstComment.value.startsWith("*") ? firstComment.range[0] + 1 : firstComment.range[0];
                            context.report({
                                loc: {
                                    start: firstComment.loc.start,
                                    end: { line: firstComment.loc.start.line, column: firstComment.loc.start.column + 2 }
                                },
                                messageId: "startNewline",
                                fix: fixer => fixer.insertTextAfterRange([start, start + 2], `\n${expectedLinePrefix}`)
                            });
                        }
                        if (!/^\s*$/u.test(lines[lines.length - 1])) {
                            context.report({
                                loc: {
                                    start: { line: firstComment.loc.end.line, column: firstComment.loc.end.column - 2 },
                                    end: firstComment.loc.end
                                },
                                messageId: "endNewline",
                                fix: fixer => fixer.replaceTextRange([firstComment.range[1] - 2, firstComment.range[1]], `\n${expectedLinePrefix}/`)
                            });
                        }
                        for (let lineNumber = firstComment.loc.start.line + 1; lineNumber <= firstComment.loc.end.line; lineNumber++) {
                            const lineText = sourceCode.lines[lineNumber - 1];
                            const errorType = isStarredCommentLine(lineText)
                                ? "alignment"
                                : "missingStar";
                            if (!lineText.startsWith(expectedLinePrefix)) {
                                context.report({
                                    loc: {
                                        start: { line: lineNumber, column: 0 },
                                        end: { line: lineNumber, column: lineText.length }
                                    },
                                    messageId: errorType,
                                    fix(fixer) {
                                        const lineStartIndex = sourceCode.getIndexFromLoc({ line: lineNumber, column: 0 });
                                        if (errorType === "alignment") {
                                            const [, commentTextPrefix = ""] = lineText.match(/^(\s*\*)/u) || [];
                                            const commentTextStartIndex = lineStartIndex + commentTextPrefix.length;
                                            return fixer.replaceTextRange([lineStartIndex, commentTextStartIndex], expectedLinePrefix);
                                        }
                                        const [, commentTextPrefix = ""] = lineText.match(/^(\s*)/u) || [];
                                        const commentTextStartIndex = lineStartIndex + commentTextPrefix.length;
                                        let offset;
                                        for (const [idx, line] of lines.entries()) {
                                            if (!/\S+/u.test(line)) {
                                                continue;
                                            }
                                            const lineTextToAlignWith = sourceCode.lines[firstComment.loc.start.line - 1 + idx];
                                            const [, prefix = "", initialOffset = ""] = lineTextToAlignWith.match(/^(\s*(?:\/?\*)?(\s*))/u) || [];
                                            offset = `${commentTextPrefix.slice(prefix.length)}${initialOffset}`;
                                            if (/^\s*\//u.test(lineText) && offset.length === 0) {
                                                offset += " ";
                                            }
                                            break;
                                        }
                                        return fixer.replaceTextRange([lineStartIndex, commentTextStartIndex], `${expectedLinePrefix}${offset}`);
                                    }
                                });
                            }
                        }
                    }
                },
                "separate-lines"(commentGroup) {
                    const [firstComment] = commentGroup;
                    const isJSDoc = isJSDocComment(commentGroup);
                    if (firstComment.type !== "Block" || (!checkJSDoc && isJSDoc)) {
                        return;
                    }
                    let commentLines = getCommentLines(commentGroup);
                    if (isJSDoc) {
                        commentLines = commentLines.slice(1, commentLines.length - 1);
                    }
                    const tokenAfter = sourceCode.getTokenAfter(firstComment, { includeComments: true });
                    if (tokenAfter && firstComment.loc.end.line === tokenAfter.loc.start.line) {
                        return;
                    }
                    context.report({
                        loc: {
                            start: firstComment.loc.start,
                            end: { line: firstComment.loc.start.line, column: firstComment.loc.start.column + 2 }
                        },
                        messageId: "expectedLines",
                        fix(fixer) {
                            return fixer.replaceText(firstComment, convertToSeparateLines(firstComment, commentLines));
                        }
                    });
                },
                "bare-block"(commentGroup) {
                    if (isJSDocComment(commentGroup)) {
                        return;
                    }
                    const [firstComment] = commentGroup;
                    const commentLines = getCommentLines(commentGroup);
                    // Disallows consecutive line comments in favor of using a block comment.
                    if (firstComment.type === "Line" && commentLines.length > 1 &&
                        !commentLines.some(value => value.includes("*/"))) {
                        context.report({
                            loc: {
                                start: firstComment.loc.start,
                                end: commentGroup[commentGroup.length - 1].loc.end
                            },
                            messageId: "expectedBlock",
                            fix(fixer) {
                                return fixer.replaceTextRange([firstComment.range[0], commentGroup[commentGroup.length - 1].range[1]], convertToBlock(firstComment, commentLines));
                            }
                        });
                    }
                    // Prohibits block comments from having a * at the beginning of each line.
                    if (isStarredBlockComment(commentGroup)) {
                        context.report({
                            loc: {
                                start: firstComment.loc.start,
                                end: { line: firstComment.loc.start.line, column: firstComment.loc.start.column + 2 }
                            },
                            messageId: "expectedBareBlock",
                            fix(fixer) {
                                return fixer.replaceText(firstComment, convertToBlock(firstComment, commentLines));
                            }
                        });
                    }
                }
            };
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                Program() {
                    return sourceCode.getAllComments()
                        .filter(comment => comment.type !== "Shebang")
                        .filter(comment => !astUtils.COMMENTS_IGNORE_PATTERN.test(comment.value))
                        .filter(comment => {
                        const tokenBefore = sourceCode.getTokenBefore(comment, { includeComments: true });
                        return !tokenBefore || tokenBefore.loc.end.line < comment.loc.start.line;
                    })
                        .reduce((commentGroups, comment, index, commentList) => {
                        const tokenBefore = sourceCode.getTokenBefore(comment, { includeComments: true });
                        if (comment.type === "Line" &&
                            index && commentList[index - 1].type === "Line" &&
                            tokenBefore && tokenBefore.loc.end.line === comment.loc.start.line - 1 &&
                            tokenBefore === commentList[index - 1]) {
                            commentGroups[commentGroups.length - 1].push(comment);
                        }
                        else {
                            commentGroups.push([comment]);
                        }
                        return commentGroups;
                    }, [])
                        .filter(commentGroup => !(commentGroup.length === 1 && commentGroup[0].loc.start.line === commentGroup[0].loc.end.line))
                        .forEach(commentGroupCheckers[option]);
                }
            };
        }
    };
},
/* eslint/lib/rules/multiline-ternary.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Enforce newlines between operands of ternary expressions
     * @author Kai Cataldo
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce newlines between operands of ternary expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/multiline-ternary"
            },
            schema: [
                {
                    enum: ["always", "always-multiline", "never"]
                }
            ],
            messages: {
                expectedTestCons: "Expected newline between test and consequent of ternary expression.",
                expectedConsAlt: "Expected newline between consequent and alternate of ternary expression.",
                unexpectedTestCons: "Unexpected newline between test and consequent of ternary expression.",
                unexpectedConsAlt: "Unexpected newline between consequent and alternate of ternary expression."
            },
            fixable: "whitespace"
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const option = context.options[0];
            const multiline = option !== "never";
            const allowSingleLine = option === "always-multiline";
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                ConditionalExpression(node) {
                    const questionToken = sourceCode.getTokenAfter(node.test, astUtils.isNotClosingParenToken);
                    const colonToken = sourceCode.getTokenAfter(node.consequent, astUtils.isNotClosingParenToken);
                    const firstTokenOfTest = sourceCode.getFirstToken(node);
                    const lastTokenOfTest = sourceCode.getTokenBefore(questionToken);
                    const firstTokenOfConsequent = sourceCode.getTokenAfter(questionToken);
                    const lastTokenOfConsequent = sourceCode.getTokenBefore(colonToken);
                    const firstTokenOfAlternate = sourceCode.getTokenAfter(colonToken);
                    const areTestAndConsequentOnSameLine = astUtils.isTokenOnSameLine(lastTokenOfTest, firstTokenOfConsequent);
                    const areConsequentAndAlternateOnSameLine = astUtils.isTokenOnSameLine(lastTokenOfConsequent, firstTokenOfAlternate);
                    const hasComments = !!sourceCode.getCommentsInside(node).length;
                    if (!multiline) {
                        if (!areTestAndConsequentOnSameLine) {
                            context.report({
                                node: node.test,
                                loc: {
                                    start: firstTokenOfTest.loc.start,
                                    end: lastTokenOfTest.loc.end
                                },
                                messageId: "unexpectedTestCons",
                                fix(fixer) {
                                    if (hasComments) {
                                        return null;
                                    }
                                    const fixers = [];
                                    const areTestAndQuestionOnSameLine = astUtils.isTokenOnSameLine(lastTokenOfTest, questionToken);
                                    const areQuestionAndConsOnSameLine = astUtils.isTokenOnSameLine(questionToken, firstTokenOfConsequent);
                                    if (!areTestAndQuestionOnSameLine) {
                                        fixers.push(fixer.removeRange([lastTokenOfTest.range[1], questionToken.range[0]]));
                                    }
                                    if (!areQuestionAndConsOnSameLine) {
                                        fixers.push(fixer.removeRange([questionToken.range[1], firstTokenOfConsequent.range[0]]));
                                    }
                                    return fixers;
                                }
                            });
                        }
                        if (!areConsequentAndAlternateOnSameLine) {
                            context.report({
                                node: node.consequent,
                                loc: {
                                    start: firstTokenOfConsequent.loc.start,
                                    end: lastTokenOfConsequent.loc.end
                                },
                                messageId: "unexpectedConsAlt",
                                fix(fixer) {
                                    if (hasComments) {
                                        return null;
                                    }
                                    const fixers = [];
                                    const areConsAndColonOnSameLine = astUtils.isTokenOnSameLine(lastTokenOfConsequent, colonToken);
                                    const areColonAndAltOnSameLine = astUtils.isTokenOnSameLine(colonToken, firstTokenOfAlternate);
                                    if (!areConsAndColonOnSameLine) {
                                        fixers.push(fixer.removeRange([lastTokenOfConsequent.range[1], colonToken.range[0]]));
                                    }
                                    if (!areColonAndAltOnSameLine) {
                                        fixers.push(fixer.removeRange([colonToken.range[1], firstTokenOfAlternate.range[0]]));
                                    }
                                    return fixers;
                                }
                            });
                        }
                    }
                    else {
                        if (allowSingleLine && node.loc.start.line === node.loc.end.line) {
                            return;
                        }
                        if (areTestAndConsequentOnSameLine) {
                            context.report({
                                node: node.test,
                                loc: {
                                    start: firstTokenOfTest.loc.start,
                                    end: lastTokenOfTest.loc.end
                                },
                                messageId: "expectedTestCons",
                                fix: fixer => (hasComments ? null : (fixer.replaceTextRange([
                                    lastTokenOfTest.range[1],
                                    questionToken.range[0]
                                ], "\n")))
                            });
                        }
                        if (areConsequentAndAlternateOnSameLine) {
                            context.report({
                                node: node.consequent,
                                loc: {
                                    start: firstTokenOfConsequent.loc.start,
                                    end: lastTokenOfConsequent.loc.end
                                },
                                messageId: "expectedConsAlt",
                                fix: (fixer => (hasComments ? null : (fixer.replaceTextRange([
                                    lastTokenOfConsequent.range[1],
                                    colonToken.range[0]
                                ], "\n"))))
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/new-cap.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of constructors without capital letters
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const CAPS_ALLOWED = [
        "Array",
        "Boolean",
        "Date",
        "Error",
        "Function",
        "Number",
        "Object",
        "RegExp",
        "String",
        "Symbol",
        "BigInt"
    ];
    /**
     * Ensure that if the key is provided, it must be an array.
     * @param {Object} obj Object to check with `key`.
     * @param {string} key Object key to check on `obj`.
     * @param {any} fallback If obj[key] is not present, this will be returned.
     * @throws {TypeError} If key is not an own array type property of `obj`.
     * @returns {string[]} Returns obj[key] if it's an Array, otherwise `fallback`
     */
    function checkArray(obj, key, fallback) {
        /* c8 ignore start */
        if (Object.prototype.hasOwnProperty.call(obj, key) && !Array.isArray(obj[key])) {
            throw new TypeError(`${key}, if provided, must be an Array`);
        } /* c8 ignore stop */
        return obj[key] || fallback;
    }
    /**
     * A reducer function to invert an array to an Object mapping the string form of the key, to `true`.
     * @param {Object} map Accumulator object for the reduce.
     * @param {string} key Object key to set to `true`.
     * @returns {Object} Returns the updated Object for further reduction.
     */
    function invert(map, key) {
        map[key] = true;
        return map;
    }
    /**
     * Creates an object with the cap is new exceptions as its keys and true as their values.
     * @param {Object} config Rule configuration
     * @returns {Object} Object with cap is new exceptions.
     */
    function calculateCapIsNewExceptions(config) {
        let capIsNewExceptions = checkArray(config, "capIsNewExceptions", CAPS_ALLOWED);
        if (capIsNewExceptions !== CAPS_ALLOWED) {
            capIsNewExceptions = capIsNewExceptions.concat(CAPS_ALLOWED);
        }
        return capIsNewExceptions.reduce(invert, {});
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require constructor names to begin with a capital letter",
                recommended: false,
                url: "https://eslint.org/docs/rules/new-cap"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        newIsCap: {
                            type: "boolean",
                            default: true
                        },
                        capIsNew: {
                            type: "boolean",
                            default: true
                        },
                        newIsCapExceptions: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        },
                        newIsCapExceptionPattern: {
                            type: "string"
                        },
                        capIsNewExceptions: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        },
                        capIsNewExceptionPattern: {
                            type: "string"
                        },
                        properties: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                upper: "A function with a name starting with an uppercase letter should only be used as a constructor.",
                lower: "A constructor name should not start with a lowercase letter."
            }
        },
        create(context) {
            const config = Object.assign({}, context.options[0]);
            config.newIsCap = config.newIsCap !== false;
            config.capIsNew = config.capIsNew !== false;
            const skipProperties = config.properties === false;
            const newIsCapExceptions = checkArray(config, "newIsCapExceptions", []).reduce(invert, {});
            const newIsCapExceptionPattern = config.newIsCapExceptionPattern ? new RegExp(config.newIsCapExceptionPattern, "u") : null;
            const capIsNewExceptions = calculateCapIsNewExceptions(config);
            const capIsNewExceptionPattern = config.capIsNewExceptionPattern ? new RegExp(config.capIsNewExceptionPattern, "u") : null;
            const listeners = {};
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Get exact callee name from expression
             * @param {ASTNode} node CallExpression or NewExpression node
             * @returns {string} name
             */
            function extractNameFromExpression(node) {
                return node.callee.type === "Identifier"
                    ? node.callee.name
                    : astUtils.getStaticPropertyName(node.callee) || "";
            }
            /**
             * Returns the capitalization state of the string -
             * Whether the first character is uppercase, lowercase, or non-alphabetic
             * @param {string} str String
             * @returns {string} capitalization state: "non-alpha", "lower", or "upper"
             */
            function getCap(str) {
                const firstChar = str.charAt(0);
                const firstCharLower = firstChar.toLowerCase();
                const firstCharUpper = firstChar.toUpperCase();
                if (firstCharLower === firstCharUpper) {
                    // char has no uppercase variant, so it's non-alphabetic
                    return "non-alpha";
                }
                if (firstChar === firstCharLower) {
                    return "lower";
                }
                return "upper";
            }
            /**
             * Check if capitalization is allowed for a CallExpression
             * @param {Object} allowedMap Object mapping calleeName to a Boolean
             * @param {ASTNode} node CallExpression node
             * @param {string} calleeName Capitalized callee name from a CallExpression
             * @param {Object} pattern RegExp object from options pattern
             * @returns {boolean} Returns true if the callee may be capitalized
             */
            function isCapAllowed(allowedMap, node, calleeName, pattern) {
                const sourceText = sourceCode.getText(node.callee);
                if (allowedMap[calleeName] || allowedMap[sourceText]) {
                    return true;
                }
                if (pattern && pattern.test(sourceText)) {
                    return true;
                }
                const callee = astUtils.skipChainExpression(node.callee);
                if (calleeName === "UTC" && callee.type === "MemberExpression") {
                    // allow if callee is Date.UTC
                    return callee.object.type === "Identifier" &&
                        callee.object.name === "Date";
                }
                return skipProperties && callee.type === "MemberExpression";
            }
            /**
             * Reports the given messageId for the given node. The location will be the start of the property or the callee.
             * @param {ASTNode} node CallExpression or NewExpression node.
             * @param {string} messageId The messageId to report.
             * @returns {void}
             */
            function report(node, messageId) {
                let callee = astUtils.skipChainExpression(node.callee);
                if (callee.type === "MemberExpression") {
                    callee = callee.property;
                }
                context.report({ node, loc: callee.loc, messageId });
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            if (config.newIsCap) {
                listeners.NewExpression = function (node) {
                    const constructorName = extractNameFromExpression(node);
                    if (constructorName) {
                        const capitalization = getCap(constructorName);
                        const isAllowed = capitalization !== "lower" || isCapAllowed(newIsCapExceptions, node, constructorName, newIsCapExceptionPattern);
                        if (!isAllowed) {
                            report(node, "lower");
                        }
                    }
                };
            }
            if (config.capIsNew) {
                listeners.CallExpression = function (node) {
                    const calleeName = extractNameFromExpression(node);
                    if (calleeName) {
                        const capitalization = getCap(calleeName);
                        const isAllowed = capitalization !== "upper" || isCapAllowed(capIsNewExceptions, node, calleeName, capIsNewExceptionPattern);
                        if (!isAllowed) {
                            report(node, "upper");
                        }
                    }
                };
            }
            return listeners;
        }
    };
},
/* eslint/lib/rules/new-parens.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when using constructor without parentheses
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce or disallow parentheses when invoking a constructor with no arguments",
                recommended: false,
                url: "https://eslint.org/docs/rules/new-parens"
            },
            fixable: "code",
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always", "never"]
                            }
                        ],
                        minItems: 0,
                        maxItems: 1
                    }
                ]
            },
            messages: {
                missing: "Missing '()' invoking a constructor.",
                unnecessary: "Unnecessary '()' invoking a constructor with no arguments."
            }
        },
        create(context) {
            const options = context.options;
            const always = options[0] !== "never"; // Default is always
            const sourceCode = context.getSourceCode();
            return {
                NewExpression(node) {
                    if (node.arguments.length !== 0) {
                        return; // if there are arguments, there have to be parens
                    }
                    const lastToken = sourceCode.getLastToken(node);
                    const hasLastParen = lastToken && astUtils.isClosingParenToken(lastToken);
                    // `hasParens` is true only if the new expression ends with its own parens, e.g., new new foo() does not end with its own parens
                    const hasParens = hasLastParen &&
                        astUtils.isOpeningParenToken(sourceCode.getTokenBefore(lastToken)) &&
                        node.callee.range[1] < node.range[1];
                    if (always) {
                        if (!hasParens) {
                            context.report({
                                node,
                                messageId: "missing",
                                fix: fixer => fixer.insertTextAfter(node, "()")
                            });
                        }
                    }
                    else {
                        if (hasParens) {
                            context.report({
                                node,
                                messageId: "unnecessary",
                                fix: fixer => [
                                    fixer.remove(sourceCode.getTokenBefore(lastToken)),
                                    fixer.remove(lastToken),
                                    fixer.insertTextBefore(node, "("),
                                    fixer.insertTextAfter(node, ")")
                                ]
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/newline-after-var.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check empty newline after "var" statement
     * @author Gopal Venkatesan
     * @deprecated in ESLint v4.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow an empty line after variable declarations",
                recommended: false,
                url: "https://eslint.org/docs/rules/newline-after-var"
            },
            schema: [
                {
                    enum: ["never", "always"]
                }
            ],
            fixable: "whitespace",
            messages: {
                expected: "Expected blank line after variable declarations.",
                unexpected: "Unexpected blank line after variable declarations."
            },
            deprecated: true,
            replacedBy: ["padding-line-between-statements"]
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            // Default `mode` to "always".
            const mode = context.options[0] === "never" ? "never" : "always";
            // Cache starting and ending line numbers of comments for faster lookup
            const commentEndLine = sourceCode.getAllComments().reduce((result, token) => {
                result[token.loc.start.line] = token.loc.end.line;
                return result;
            }, {});
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Gets a token from the given node to compare line to the next statement.
             *
             * In general, the token is the last token of the node. However, the token is the second last token if the following conditions satisfy.
             *
             * - The last token is semicolon.
             * - The semicolon is on a different line from the previous token of the semicolon.
             *
             * This behavior would address semicolon-less style code. e.g.:
             *
             *     var foo = 1
             *
             *     ;(a || b).doSomething()
             * @param {ASTNode} node The node to get.
             * @returns {Token} The token to compare line to the next statement.
             */
            function getLastToken(node) {
                const lastToken = sourceCode.getLastToken(node);
                if (lastToken.type === "Punctuator" && lastToken.value === ";") {
                    const prevToken = sourceCode.getTokenBefore(lastToken);
                    if (prevToken.loc.end.line !== lastToken.loc.start.line) {
                        return prevToken;
                    }
                }
                return lastToken;
            }
            /**
             * Determine if provided keyword is a variable declaration
             * @private
             * @param {string} keyword keyword to test
             * @returns {boolean} True if `keyword` is a type of var
             */
            function isVar(keyword) {
                return keyword === "var" || keyword === "let" || keyword === "const";
            }
            /**
             * Determine if provided keyword is a variant of for specifiers
             * @private
             * @param {string} keyword keyword to test
             * @returns {boolean} True if `keyword` is a variant of for specifier
             */
            function isForTypeSpecifier(keyword) {
                return keyword === "ForStatement" || keyword === "ForInStatement" || keyword === "ForOfStatement";
            }
            /**
             * Determine if provided keyword is an export specifiers
             * @private
             * @param {string} nodeType nodeType to test
             * @returns {boolean} True if `nodeType` is an export specifier
             */
            function isExportSpecifier(nodeType) {
                return nodeType === "ExportNamedDeclaration" || nodeType === "ExportSpecifier" ||
                    nodeType === "ExportDefaultDeclaration" || nodeType === "ExportAllDeclaration";
            }
            /**
             * Determine if provided node is the last of their parent block.
             * @private
             * @param {ASTNode} node node to test
             * @returns {boolean} True if `node` is last of their parent block.
             */
            function isLastNode(node) {
                const token = sourceCode.getTokenAfter(node);
                return !token || (token.type === "Punctuator" && token.value === "}");
            }
            /**
             * Gets the last line of a group of consecutive comments
             * @param {number} commentStartLine The starting line of the group
             * @returns {number} The number of the last comment line of the group
             */
            function getLastCommentLineOfBlock(commentStartLine) {
                const currentCommentEnd = commentEndLine[commentStartLine];
                return commentEndLine[currentCommentEnd + 1] ? getLastCommentLineOfBlock(currentCommentEnd + 1) : currentCommentEnd;
            }
            /**
             * Determine if a token starts more than one line after a comment ends
             * @param {token} token The token being checked
             * @param {integer} commentStartLine The line number on which the comment starts
             * @returns {boolean} True if `token` does not start immediately after a comment
             */
            function hasBlankLineAfterComment(token, commentStartLine) {
                return token.loc.start.line > getLastCommentLineOfBlock(commentStartLine) + 1;
            }
            /**
             * Checks that a blank line exists after a variable declaration when mode is
             * set to "always", or checks that there is no blank line when mode is set
             * to "never"
             * @private
             * @param {ASTNode} node `VariableDeclaration` node to test
             * @returns {void}
             */
            function checkForBlankLine(node) {
                /*
                 * lastToken is the last token on the node's line. It will usually also be the last token of the node, but it will
                 * sometimes be second-last if there is a semicolon on a different line.
                 */
                const lastToken = getLastToken(node), 
                /*
                 * If lastToken is the last token of the node, nextToken should be the token after the node. Otherwise, nextToken
                 * is the last token of the node.
                 */
                nextToken = lastToken === sourceCode.getLastToken(node) ? sourceCode.getTokenAfter(node) : sourceCode.getLastToken(node), nextLineNum = lastToken.loc.end.line + 1;
                // Ignore if there is no following statement
                if (!nextToken) {
                    return;
                }
                // Ignore if parent of node is a for variant
                if (isForTypeSpecifier(node.parent.type)) {
                    return;
                }
                // Ignore if parent of node is an export specifier
                if (isExportSpecifier(node.parent.type)) {
                    return;
                }
                /*
                 * Some coding styles use multiple `var` statements, so do nothing if
                 * the next token is a `var` statement.
                 */
                if (nextToken.type === "Keyword" && isVar(nextToken.value)) {
                    return;
                }
                // Ignore if it is last statement in a block
                if (isLastNode(node)) {
                    return;
                }
                // Next statement is not a `var`...
                const noNextLineToken = nextToken.loc.start.line > nextLineNum;
                const hasNextLineComment = (typeof commentEndLine[nextLineNum] !== "undefined");
                if (mode === "never" && noNextLineToken && !hasNextLineComment) {
                    context.report({
                        node,
                        messageId: "unexpected",
                        data: { identifier: node.name },
                        fix(fixer) {
                            const linesBetween = sourceCode.getText().slice(lastToken.range[1], nextToken.range[0]).split(astUtils.LINEBREAK_MATCHER);
                            return fixer.replaceTextRange([lastToken.range[1], nextToken.range[0]], `${linesBetween.slice(0, -1).join("")}\n${linesBetween[linesBetween.length - 1]}`);
                        }
                    });
                }
                // Token on the next line, or comment without blank line
                if (mode === "always" && (!noNextLineToken ||
                    hasNextLineComment && !hasBlankLineAfterComment(nextToken, nextLineNum))) {
                    context.report({
                        node,
                        messageId: "expected",
                        data: { identifier: node.name },
                        fix(fixer) {
                            if ((noNextLineToken ? getLastCommentLineOfBlock(nextLineNum) : lastToken.loc.end.line) === nextToken.loc.start.line) {
                                return fixer.insertTextBefore(nextToken, "\n\n");
                            }
                            return fixer.insertTextBeforeRange([nextToken.range[0] - nextToken.loc.start.column, nextToken.range[1]], "\n");
                        }
                    });
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                VariableDeclaration: checkForBlankLine
            };
        }
    };
},
/* eslint/lib/rules/newline-before-return.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to require newlines before `return` statement
     * @author Kai Cataldo
     * @deprecated in ESLint v4.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require an empty line before `return` statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/newline-before-return"
            },
            fixable: "whitespace",
            schema: [],
            messages: {
                expected: "Expected newline before return statement."
            },
            deprecated: true,
            replacedBy: ["padding-line-between-statements"]
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Tests whether node is preceded by supplied tokens
             * @param {ASTNode} node node to check
             * @param {Array} testTokens array of tokens to test against
             * @returns {boolean} Whether or not the node is preceded by one of the supplied tokens
             * @private
             */
            function isPrecededByTokens(node, testTokens) {
                const tokenBefore = sourceCode.getTokenBefore(node);
                return testTokens.includes(tokenBefore.value);
            }
            /**
             * Checks whether node is the first node after statement or in block
             * @param {ASTNode} node node to check
             * @returns {boolean} Whether or not the node is the first node after statement or in block
             * @private
             */
            function isFirstNode(node) {
                const parentType = node.parent.type;
                if (node.parent.body) {
                    return Array.isArray(node.parent.body)
                        ? node.parent.body[0] === node
                        : node.parent.body === node;
                }
                if (parentType === "IfStatement") {
                    return isPrecededByTokens(node, ["else", ")"]);
                }
                if (parentType === "DoWhileStatement") {
                    return isPrecededByTokens(node, ["do"]);
                }
                if (parentType === "SwitchCase") {
                    return isPrecededByTokens(node, [":"]);
                }
                return isPrecededByTokens(node, [")"]);
            }
            /**
             * Returns the number of lines of comments that precede the node
             * @param {ASTNode} node node to check for overlapping comments
             * @param {number} lineNumTokenBefore line number of previous token, to check for overlapping comments
             * @returns {number} Number of lines of comments that precede the node
             * @private
             */
            function calcCommentLines(node, lineNumTokenBefore) {
                const comments = sourceCode.getCommentsBefore(node);
                let numLinesComments = 0;
                if (!comments.length) {
                    return numLinesComments;
                }
                comments.forEach(comment => {
                    numLinesComments++;
                    if (comment.type === "Block") {
                        numLinesComments += comment.loc.end.line - comment.loc.start.line;
                    }
                    // avoid counting lines with inline comments twice
                    if (comment.loc.start.line === lineNumTokenBefore) {
                        numLinesComments--;
                    }
                    if (comment.loc.end.line === node.loc.start.line) {
                        numLinesComments--;
                    }
                });
                return numLinesComments;
            }
            /**
             * Returns the line number of the token before the node that is passed in as an argument
             * @param {ASTNode} node The node to use as the start of the calculation
             * @returns {number} Line number of the token before `node`
             * @private
             */
            function getLineNumberOfTokenBefore(node) {
                const tokenBefore = sourceCode.getTokenBefore(node);
                let lineNumTokenBefore;
                /**
                 * Global return (at the beginning of a script) is a special case.
                 * If there is no token before `return`, then we expect no line
                 * break before the return. Comments are allowed to occupy lines
                 * before the global return, just no blank lines.
                 * Setting lineNumTokenBefore to zero in that case results in the
                 * desired behavior.
                 */
                if (tokenBefore) {
                    lineNumTokenBefore = tokenBefore.loc.end.line;
                }
                else {
                    lineNumTokenBefore = 0; // global return at beginning of script
                }
                return lineNumTokenBefore;
            }
            /**
             * Checks whether node is preceded by a newline
             * @param {ASTNode} node node to check
             * @returns {boolean} Whether or not the node is preceded by a newline
             * @private
             */
            function hasNewlineBefore(node) {
                const lineNumNode = node.loc.start.line;
                const lineNumTokenBefore = getLineNumberOfTokenBefore(node);
                const commentLines = calcCommentLines(node, lineNumTokenBefore);
                return (lineNumNode - lineNumTokenBefore - commentLines) > 1;
            }
            /**
             * Checks whether it is safe to apply a fix to a given return statement.
             *
             * The fix is not considered safe if the given return statement has leading comments,
             * as we cannot safely determine if the newline should be added before or after the comments.
             * For more information, see: https://github.com/eslint/eslint/issues/5958#issuecomment-222767211
             * @param {ASTNode} node The return statement node to check.
             * @returns {boolean} `true` if it can fix the node.
             * @private
             */
            function canFix(node) {
                const leadingComments = sourceCode.getCommentsBefore(node);
                const lastLeadingComment = leadingComments[leadingComments.length - 1];
                const tokenBefore = sourceCode.getTokenBefore(node);
                if (leadingComments.length === 0) {
                    return true;
                }
                /*
                 * if the last leading comment ends in the same line as the previous token and
                 * does not share a line with the `return` node, we can consider it safe to fix.
                 * Example:
                 * function a() {
                 *     var b; //comment
                 *     return;
                 * }
                 */
                if (lastLeadingComment.loc.end.line === tokenBefore.loc.end.line &&
                    lastLeadingComment.loc.end.line !== node.loc.start.line) {
                    return true;
                }
                return false;
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                ReturnStatement(node) {
                    if (!isFirstNode(node) && !hasNewlineBefore(node)) {
                        context.report({
                            node,
                            messageId: "expected",
                            fix(fixer) {
                                if (canFix(node)) {
                                    const tokenBefore = sourceCode.getTokenBefore(node);
                                    const newlines = node.loc.start.line === tokenBefore.loc.end.line ? "\n\n" : "\n";
                                    return fixer.insertTextBefore(node, newlines);
                                }
                                return null;
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/newline-per-chained-call.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to ensure newline per method call when chaining calls
     * @author Rajendra Patil
     * @author Burak Yigit Kaya
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require a newline after each call in a method chain",
                recommended: false,
                url: "https://eslint.org/docs/rules/newline-per-chained-call"
            },
            fixable: "whitespace",
            schema: [{
                    type: "object",
                    properties: {
                        ignoreChainWithDepth: {
                            type: "integer",
                            minimum: 1,
                            maximum: 10,
                            default: 2
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                expected: "Expected line break before `{{callee}}`."
            }
        },
        create(context) {
            const options = context.options[0] || {}, ignoreChainWithDepth = options.ignoreChainWithDepth || 2;
            const sourceCode = context.getSourceCode();
            /**
             * Get the prefix of a given MemberExpression node.
             * If the MemberExpression node is a computed value it returns a
             * left bracket. If not it returns a period.
             * @param {ASTNode} node A MemberExpression node to get
             * @returns {string} The prefix of the node.
             */
            function getPrefix(node) {
                if (node.computed) {
                    if (node.optional) {
                        return "?.[";
                    }
                    return "[";
                }
                if (node.optional) {
                    return "?.";
                }
                return ".";
            }
            /**
             * Gets the property text of a given MemberExpression node.
             * If the text is multiline, this returns only the first line.
             * @param {ASTNode} node A MemberExpression node to get.
             * @returns {string} The property text of the node.
             */
            function getPropertyText(node) {
                const prefix = getPrefix(node);
                const lines = sourceCode.getText(node.property).split(astUtils.LINEBREAK_MATCHER);
                const suffix = node.computed && lines.length === 1 ? "]" : "";
                return prefix + lines[0] + suffix;
            }
            return {
                "CallExpression:exit"(node) {
                    const callee = astUtils.skipChainExpression(node.callee);
                    if (callee.type !== "MemberExpression") {
                        return;
                    }
                    let parent = astUtils.skipChainExpression(callee.object);
                    let depth = 1;
                    while (parent && parent.callee) {
                        depth += 1;
                        parent = astUtils.skipChainExpression(astUtils.skipChainExpression(parent.callee).object);
                    }
                    if (depth > ignoreChainWithDepth && astUtils.isTokenOnSameLine(callee.object, callee.property)) {
                        const firstTokenAfterObject = sourceCode.getTokenAfter(callee.object, astUtils.isNotClosingParenToken);
                        context.report({
                            node: callee.property,
                            loc: {
                                start: firstTokenAfterObject.loc.start,
                                end: callee.loc.end
                            },
                            messageId: "expected",
                            data: {
                                callee: getPropertyText(callee)
                            },
                            fix(fixer) {
                                return fixer.insertTextBefore(firstTokenAfterObject, "\n");
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-alert.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag use of alert, confirm, prompt
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { getStaticPropertyName: getPropertyName, getVariableByName, skipChainExpression } = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks if the given name is a prohibited identifier.
     * @param {string} name The name to check
     * @returns {boolean} Whether or not the name is prohibited.
     */
    function isProhibitedIdentifier(name) {
        return /^(alert|confirm|prompt)$/u.test(name);
    }
    /**
     * Finds the eslint-scope reference in the given scope.
     * @param {Object} scope The scope to search.
     * @param {ASTNode} node The identifier node.
     * @returns {Reference|null} Returns the found reference or null if none were found.
     */
    function findReference(scope, node) {
        const references = scope.references.filter(reference => reference.identifier.range[0] === node.range[0] &&
            reference.identifier.range[1] === node.range[1]);
        if (references.length === 1) {
            return references[0];
        }
        return null;
    }
    /**
     * Checks if the given identifier node is shadowed in the given scope.
     * @param {Object} scope The current scope.
     * @param {string} node The identifier node to check
     * @returns {boolean} Whether or not the name is shadowed.
     */
    function isShadowed(scope, node) {
        const reference = findReference(scope, node);
        return reference && reference.resolved && reference.resolved.defs.length > 0;
    }
    /**
     * Checks if the given identifier node is a ThisExpression in the global scope or the global window property.
     * @param {Object} scope The current scope.
     * @param {string} node The identifier node to check
     * @returns {boolean} Whether or not the node is a reference to the global object.
     */
    function isGlobalThisReferenceOrGlobalWindow(scope, node) {
        if (scope.type === "global" && node.type === "ThisExpression") {
            return true;
        }
        if (node.type === "Identifier" &&
            (node.name === "window" ||
                (node.name === "globalThis" && getVariableByName(scope, "globalThis")))) {
            return !isShadowed(scope, node);
        }
        return false;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the use of `alert`, `confirm`, and `prompt`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-alert"
            },
            schema: [],
            messages: {
                unexpected: "Unexpected {{name}}."
            }
        },
        create(context) {
            return {
                CallExpression(node) {
                    const callee = skipChainExpression(node.callee), currentScope = context.getScope();
                    // without window.
                    if (callee.type === "Identifier") {
                        const name = callee.name;
                        if (!isShadowed(currentScope, callee) && isProhibitedIdentifier(callee.name)) {
                            context.report({
                                node,
                                messageId: "unexpected",
                                data: { name }
                            });
                        }
                    }
                    else if (callee.type === "MemberExpression" && isGlobalThisReferenceOrGlobalWindow(currentScope, callee.object)) {
                        const name = getPropertyName(callee);
                        if (isProhibitedIdentifier(name)) {
                            context.report({
                                node,
                                messageId: "unexpected",
                                data: { name }
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-array-constructor.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Disallow construction of dense arrays using the Array constructor
     * @author Matt DuVall <http://www.mattduvall.com/>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `Array` constructors",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-array-constructor"
            },
            schema: [],
            messages: {
                preferLiteral: "The array literal notation [] is preferable."
            }
        },
        create(context) {
            /**
             * Disallow construction of dense arrays using the Array constructor
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function check(node) {
                if (node.arguments.length !== 1 &&
                    node.callee.type === "Identifier" &&
                    node.callee.name === "Array") {
                    context.report({ node, messageId: "preferLiteral" });
                }
            }
            return {
                CallExpression: check,
                NewExpression: check
            };
        }
    };
},
/* eslint/lib/rules/no-async-promise-executor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview disallow using an async function as a Promise executor
     * @author Teddy Katz
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow using an async function as a Promise executor",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-async-promise-executor"
            },
            fixable: null,
            schema: [],
            messages: {
                async: "Promise executor functions should not be async."
            }
        },
        create(context) {
            return {
                "NewExpression[callee.name='Promise'][arguments.0.async=true]"(node) {
                    context.report({
                        node: context.getSourceCode().getFirstToken(node.arguments[0], token => token.value === "async"),
                        messageId: "async"
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-await-in-loop.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to disallow uses of await inside of loops.
     * @author Nat Mote (nmote)
     */
    "use strict";
    /**
     * Check whether it should stop traversing ancestors at the given node.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if it should stop traversing.
     */
    function isBoundary(node) {
        const t = node.type;
        return (t === "FunctionDeclaration" ||
            t === "FunctionExpression" ||
            t === "ArrowFunctionExpression" ||
            /*
             * Don't report the await expressions on for-await-of loop since it's
             * asynchronous iteration intentionally.
             */
            (t === "ForOfStatement" && node.await === true));
    }
    /**
     * Check whether the given node is in loop.
     * @param {ASTNode} node A node to check.
     * @param {ASTNode} parent A parent node to check.
     * @returns {boolean} `true` if the node is in loop.
     */
    function isLooped(node, parent) {
        switch (parent.type) {
            case "ForStatement":
                return (node === parent.test ||
                    node === parent.update ||
                    node === parent.body);
            case "ForOfStatement":
            case "ForInStatement":
                return node === parent.body;
            case "WhileStatement":
            case "DoWhileStatement":
                return node === parent.test || node === parent.body;
            default:
                return false;
        }
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow `await` inside of loops",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-await-in-loop"
            },
            schema: [],
            messages: {
                unexpectedAwait: "Unexpected `await` inside a loop."
            }
        },
        create(context) {
            /**
             * Validate an await expression.
             * @param {ASTNode} awaitNode An AwaitExpression or ForOfStatement node to validate.
             * @returns {void}
             */
            function validate(awaitNode) {
                if (awaitNode.type === "ForOfStatement" && !awaitNode.await) {
                    return;
                }
                let node = awaitNode;
                let parent = node.parent;
                while (parent && !isBoundary(parent)) {
                    if (isLooped(node, parent)) {
                        context.report({
                            node: awaitNode,
                            messageId: "unexpectedAwait"
                        });
                        return;
                    }
                    node = parent;
                    parent = parent.parent;
                }
            }
            return {
                AwaitExpression: validate,
                ForOfStatement: validate
            };
        }
    };
},
/* eslint/lib/rules/no-bitwise.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag bitwise identifiers
     * @author Nicholas C. Zakas
     */
    "use strict";
    /*
     *
     * Set of bitwise operators.
     *
     */
    const BITWISE_OPERATORS = [
        "^", "|", "&", "<<", ">>", ">>>",
        "^=", "|=", "&=", "<<=", ">>=", ">>>=",
        "~"
    ];
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow bitwise operators",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-bitwise"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allow: {
                            type: "array",
                            items: {
                                enum: BITWISE_OPERATORS
                            },
                            uniqueItems: true
                        },
                        int32Hint: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpected: "Unexpected use of '{{operator}}'."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const allowed = options.allow || [];
            const int32Hint = options.int32Hint === true;
            /**
             * Reports an unexpected use of a bitwise operator.
             * @param {ASTNode} node Node which contains the bitwise operator.
             * @returns {void}
             */
            function report(node) {
                context.report({ node, messageId: "unexpected", data: { operator: node.operator } });
            }
            /**
             * Checks if the given node has a bitwise operator.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} Whether or not the node has a bitwise operator.
             */
            function hasBitwiseOperator(node) {
                return BITWISE_OPERATORS.includes(node.operator);
            }
            /**
             * Checks if exceptions were provided, e.g. `{ allow: ['~', '|'] }`.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} Whether or not the node has a bitwise operator.
             */
            function allowedOperator(node) {
                return allowed.includes(node.operator);
            }
            /**
             * Checks if the given bitwise operator is used for integer typecasting, i.e. "|0"
             * @param {ASTNode} node The node to check.
             * @returns {boolean} whether the node is used in integer typecasting.
             */
            function isInt32Hint(node) {
                return int32Hint && node.operator === "|" && node.right &&
                    node.right.type === "Literal" && node.right.value === 0;
            }
            /**
             * Report if the given node contains a bitwise operator.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             */
            function checkNodeForBitwiseOperator(node) {
                if (hasBitwiseOperator(node) && !allowedOperator(node) && !isInt32Hint(node)) {
                    report(node);
                }
            }
            return {
                AssignmentExpression: checkNodeForBitwiseOperator,
                BinaryExpression: checkNodeForBitwiseOperator,
                UnaryExpression: checkNodeForBitwiseOperator
            };
        }
    };
},
/* eslint/lib/rules/no-buffer-constructor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview disallow use of the Buffer() constructor
     * @author Teddy Katz
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "problem",
            docs: {
                description: "Disallow use of the `Buffer()` constructor",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-buffer-constructor"
            },
            schema: [],
            messages: {
                deprecated: "{{expr}} is deprecated. Use Buffer.from(), Buffer.alloc(), or Buffer.allocUnsafe() instead."
            }
        },
        create(context) {
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                "CallExpression[callee.name='Buffer'], NewExpression[callee.name='Buffer']"(node) {
                    context.report({
                        node,
                        messageId: "deprecated",
                        data: { expr: node.type === "CallExpression" ? "Buffer()" : "new Buffer()" }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-caller.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of arguments.callee and arguments.caller.
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the use of `arguments.caller` or `arguments.callee`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-caller"
            },
            schema: [],
            messages: {
                unexpected: "Avoid arguments.{{prop}}."
            }
        },
        create(context) {
            return {
                MemberExpression(node) {
                    const objectName = node.object.name, propertyName = node.property.name;
                    if (objectName === "arguments" && !node.computed && propertyName && propertyName.match(/^calle[er]$/u)) {
                        context.report({ node, messageId: "unexpected", data: { prop: propertyName } });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-case-declarations.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag use of an lexical declarations inside a case clause
     * @author Erik Arvidsson
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow lexical declarations in case clauses",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-case-declarations"
            },
            schema: [],
            messages: {
                unexpected: "Unexpected lexical declaration in case block."
            }
        },
        create(context) {
            /**
             * Checks whether or not a node is a lexical declaration.
             * @param {ASTNode} node A direct child statement of a switch case.
             * @returns {boolean} Whether or not the node is a lexical declaration.
             */
            function isLexicalDeclaration(node) {
                switch (node.type) {
                    case "FunctionDeclaration":
                    case "ClassDeclaration":
                        return true;
                    case "VariableDeclaration":
                        return node.kind !== "var";
                    default:
                        return false;
                }
            }
            return {
                SwitchCase(node) {
                    for (let i = 0; i < node.consequent.length; i++) {
                        const statement = node.consequent[i];
                        if (isLexicalDeclaration(statement)) {
                            context.report({
                                node: statement,
                                messageId: "unexpected"
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-catch-shadow.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag variable leak in CatchClauses in IE 8 and earlier
     * @author Ian Christian Myers
     * @deprecated in ESLint v5.1.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `catch` clause parameters from shadowing variables in the outer scope",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-catch-shadow"
            },
            replacedBy: ["no-shadow"],
            deprecated: true,
            schema: [],
            messages: {
                mutable: "Value of '{{name}}' may be overwritten in IE 8 and earlier."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Check if the parameters are been shadowed
             * @param {Object} scope current scope
             * @param {string} name parameter name
             * @returns {boolean} True is its been shadowed
             */
            function paramIsShadowing(scope, name) {
                return astUtils.getVariableByName(scope, name) !== null;
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                "CatchClause[param!=null]"(node) {
                    let scope = context.getScope();
                    /*
                     * When ecmaVersion >= 6, CatchClause creates its own scope
                     * so start from one upper scope to exclude the current node
                     */
                    if (scope.block === node) {
                        scope = scope.upper;
                    }
                    if (paramIsShadowing(scope, node.param.name)) {
                        context.report({ node, messageId: "mutable", data: { name: node.param.name } });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-class-assign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow modifying variables of class declarations
     * @author Toru Nagashima
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow reassigning class members",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-class-assign"
            },
            schema: [],
            messages: {
                class: "'{{name}}' is a class."
            }
        },
        create(context) {
            /**
             * Finds and reports references that are non initializer and writable.
             * @param {Variable} variable A variable to check.
             * @returns {void}
             */
            function checkVariable(variable) {
                astUtils.getModifyingReferences(variable.references).forEach(reference => {
                    context.report({ node: reference.identifier, messageId: "class", data: { name: reference.identifier.name } });
                });
            }
            /**
             * Finds and reports references that are non initializer and writable.
             * @param {ASTNode} node A ClassDeclaration/ClassExpression node to check.
             * @returns {void}
             */
            function checkForClass(node) {
                context.getDeclaredVariables(node).forEach(checkVariable);
            }
            return {
                ClassDeclaration: checkForClass,
                ClassExpression: checkForClass
            };
        }
    };
},
/* eslint/lib/rules/no-compare-neg-zero.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview The rule should warn against code that tries to compare against -0.
     * @author Aladdin-ADD <hh_2013@foxmail.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow comparing against -0",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-compare-neg-zero"
            },
            fixable: null,
            schema: [],
            messages: {
                unexpected: "Do not use the '{{operator}}' operator to compare against -0."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Checks a given node is -0
             * @param {ASTNode} node A node to check.
             * @returns {boolean} `true` if the node is -0.
             */
            function isNegZero(node) {
                return node.type === "UnaryExpression" && node.operator === "-" && node.argument.type === "Literal" && node.argument.value === 0;
            }
            const OPERATORS_TO_CHECK = new Set([">", ">=", "<", "<=", "==", "===", "!=", "!=="]);
            return {
                BinaryExpression(node) {
                    if (OPERATORS_TO_CHECK.has(node.operator)) {
                        if (isNegZero(node.left) || isNegZero(node.right)) {
                            context.report({
                                node,
                                messageId: "unexpected",
                                data: { operator: node.operator }
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-cond-assign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag assignment in a conditional statement's test expression
     * @author Stephen Murray <spmurrayzzz>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const TEST_CONDITION_PARENT_TYPES = new Set(["IfStatement", "WhileStatement", "DoWhileStatement", "ForStatement", "ConditionalExpression"]);
    const NODE_DESCRIPTIONS = {
        DoWhileStatement: "a 'do...while' statement",
        ForStatement: "a 'for' statement",
        IfStatement: "an 'if' statement",
        WhileStatement: "a 'while' statement"
    };
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow assignment operators in conditional expressions",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-cond-assign"
            },
            schema: [
                {
                    enum: ["except-parens", "always"]
                }
            ],
            messages: {
                unexpected: "Unexpected assignment within {{type}}.",
                // must match JSHint's error message
                missing: "Expected a conditional expression and instead saw an assignment."
            }
        },
        create(context) {
            const prohibitAssign = (context.options[0] || "except-parens");
            const sourceCode = context.getSourceCode();
            /**
             * Check whether an AST node is the test expression for a conditional statement.
             * @param {!Object} node The node to test.
             * @returns {boolean} `true` if the node is the text expression for a conditional statement; otherwise, `false`.
             */
            function isConditionalTestExpression(node) {
                return node.parent &&
                    TEST_CONDITION_PARENT_TYPES.has(node.parent.type) &&
                    node === node.parent.test;
            }
            /**
             * Given an AST node, perform a bottom-up search for the first ancestor that represents a conditional statement.
             * @param {!Object} node The node to use at the start of the search.
             * @returns {?Object} The closest ancestor node that represents a conditional statement.
             */
            function findConditionalAncestor(node) {
                let currentAncestor = node;
                do {
                    if (isConditionalTestExpression(currentAncestor)) {
                        return currentAncestor.parent;
                    }
                } while ((currentAncestor = currentAncestor.parent) && !astUtils.isFunction(currentAncestor));
                return null;
            }
            /**
             * Check whether the code represented by an AST node is enclosed in two sets of parentheses.
             * @param {!Object} node The node to test.
             * @returns {boolean} `true` if the code is enclosed in two sets of parentheses; otherwise, `false`.
             */
            function isParenthesisedTwice(node) {
                const previousToken = sourceCode.getTokenBefore(node, 1), nextToken = sourceCode.getTokenAfter(node, 1);
                return astUtils.isParenthesised(sourceCode, node) &&
                    previousToken && astUtils.isOpeningParenToken(previousToken) && previousToken.range[1] <= node.range[0] &&
                    astUtils.isClosingParenToken(nextToken) && nextToken.range[0] >= node.range[1];
            }
            /**
             * Check a conditional statement's test expression for top-level assignments that are not enclosed in parentheses.
             * @param {!Object} node The node for the conditional statement.
             * @returns {void}
             */
            function testForAssign(node) {
                if (node.test &&
                    (node.test.type === "AssignmentExpression") &&
                    (node.type === "ForStatement"
                        ? !astUtils.isParenthesised(sourceCode, node.test)
                        : !isParenthesisedTwice(node.test))) {
                    context.report({
                        node: node.test,
                        messageId: "missing"
                    });
                }
            }
            /**
             * Check whether an assignment expression is descended from a conditional statement's test expression.
             * @param {!Object} node The node for the assignment expression.
             * @returns {void}
             */
            function testForConditionalAncestor(node) {
                const ancestor = findConditionalAncestor(node);
                if (ancestor) {
                    context.report({
                        node,
                        messageId: "unexpected",
                        data: {
                            type: NODE_DESCRIPTIONS[ancestor.type] || ancestor.type
                        }
                    });
                }
            }
            if (prohibitAssign === "always") {
                return {
                    AssignmentExpression: testForConditionalAncestor
                };
            }
            return {
                DoWhileStatement: testForAssign,
                ForStatement: testForAssign,
                IfStatement: testForAssign,
                WhileStatement: testForAssign,
                ConditionalExpression: testForAssign
            };
        }
    };
},
/* eslint/lib/rules/no-confusing-arrow.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to warn against using arrow functions when they could be
     * confused with comparisons
     * @author Jxck <https://github.com/Jxck>
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils.js */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a node is a conditional expression.
     * @param {ASTNode} node node to test
     * @returns {boolean} `true` if the node is a conditional expression.
     */
    function isConditional(node) {
        return node && node.type === "ConditionalExpression";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow arrow functions where they could be confused with comparisons",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-confusing-arrow"
            },
            fixable: "code",
            schema: [{
                    type: "object",
                    properties: {
                        allowParens: { type: "boolean", default: true },
                        onlyOneSimpleParam: { type: "boolean", default: false }
                    },
                    additionalProperties: false
                }],
            messages: {
                confusing: "Arrow function used ambiguously with a conditional expression."
            }
        },
        create(context) {
            const config = context.options[0] || {};
            const allowParens = config.allowParens || (config.allowParens === void 0);
            const onlyOneSimpleParam = config.onlyOneSimpleParam;
            const sourceCode = context.getSourceCode();
            /**
             * Reports if an arrow function contains an ambiguous conditional.
             * @param {ASTNode} node A node to check and report.
             * @returns {void}
             */
            function checkArrowFunc(node) {
                const body = node.body;
                if (isConditional(body) &&
                    !(allowParens && astUtils.isParenthesised(sourceCode, body)) &&
                    !(onlyOneSimpleParam && !(node.params.length === 1 && node.params[0].type === "Identifier"))) {
                    context.report({
                        node,
                        messageId: "confusing",
                        fix(fixer) {
                            // if `allowParens` is not set to true don't bother wrapping in parens
                            return allowParens && fixer.replaceText(node.body, `(${sourceCode.getText(node.body)})`);
                        }
                    });
                }
            }
            return {
                ArrowFunctionExpression: checkArrowFunc
            };
        }
    };
},
/* eslint/lib/rules/no-console.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of console object
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the use of `console`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-console"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allow: {
                            type: "array",
                            items: {
                                type: "string"
                            },
                            minItems: 1,
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpected: "Unexpected console statement."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const allowed = options.allow || [];
            /**
             * Checks whether the given reference is 'console' or not.
             * @param {eslint-scope.Reference} reference The reference to check.
             * @returns {boolean} `true` if the reference is 'console'.
             */
            function isConsole(reference) {
                const id = reference.identifier;
                return id && id.name === "console";
            }
            /**
             * Checks whether the property name of the given MemberExpression node
             * is allowed by options or not.
             * @param {ASTNode} node The MemberExpression node to check.
             * @returns {boolean} `true` if the property name of the node is allowed.
             */
            function isAllowed(node) {
                const propertyName = astUtils.getStaticPropertyName(node);
                return propertyName && allowed.includes(propertyName);
            }
            /**
             * Checks whether the given reference is a member access which is not
             * allowed by options or not.
             * @param {eslint-scope.Reference} reference The reference to check.
             * @returns {boolean} `true` if the reference is a member access which
             *      is not allowed by options.
             */
            function isMemberAccessExceptAllowed(reference) {
                const node = reference.identifier;
                const parent = node.parent;
                return (parent.type === "MemberExpression" &&
                    parent.object === node &&
                    !isAllowed(parent));
            }
            /**
             * Reports the given reference as a violation.
             * @param {eslint-scope.Reference} reference The reference to report.
             * @returns {void}
             */
            function report(reference) {
                const node = reference.identifier.parent;
                context.report({
                    node,
                    loc: node.loc,
                    messageId: "unexpected"
                });
            }
            return {
                "Program:exit"() {
                    const scope = context.getScope();
                    const consoleVar = astUtils.getVariableByName(scope, "console");
                    const shadowed = consoleVar && consoleVar.defs.length > 0;
                    /*
                     * 'scope.through' includes all references to undefined
                     * variables. If the variable 'console' is not defined, it uses
                     * 'scope.through'.
                     */
                    const references = consoleVar
                        ? consoleVar.references
                        : scope.through.filter(isConsole);
                    if (!shadowed) {
                        references
                            .filter(isMemberAccessExceptAllowed)
                            .forEach(report);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-const-assign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow modifying variables that are declared using `const`
     * @author Toru Nagashima
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow reassigning `const` variables",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-const-assign"
            },
            schema: [],
            messages: {
                const: "'{{name}}' is constant."
            }
        },
        create(context) {
            /**
             * Finds and reports references that are non initializer and writable.
             * @param {Variable} variable A variable to check.
             * @returns {void}
             */
            function checkVariable(variable) {
                astUtils.getModifyingReferences(variable.references).forEach(reference => {
                    context.report({ node: reference.identifier, messageId: "const", data: { name: reference.identifier.name } });
                });
            }
            return {
                VariableDeclaration(node) {
                    if (node.kind === "const") {
                        context.getDeclaredVariables(node).forEach(checkVariable);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-constant-binary-expression.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag constant comparisons and logical expressions that always/never short circuit
     * @author Jordan Eldredge <https://jordaneldredge.com>
     */
    "use strict";
    const globals = require(279) /* globals */;
    const { isNullLiteral, isConstant, isReferenceToGlobalVariable, isLogicalAssignmentOperator } = require(360) /* ./utils/ast-utils */;
    const NUMERIC_OR_STRING_BINARY_OPERATORS = new Set(["+", "-", "*", "/", "%", "|", "^", "&", "**", "<<", ">>", ">>>"]);
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a node is `null` or `undefined`. Similar to the one
     * found in ast-utils.js, but this one correctly handles the edge case that
     * `undefined` has been redefined.
     * @param {Scope} scope Scope in which the expression was found.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} Whether or not the node is a `null` or `undefined`.
     * @public
     */
    function isNullOrUndefined(scope, node) {
        return (isNullLiteral(node) ||
            (node.type === "Identifier" && node.name === "undefined" && isReferenceToGlobalVariable(scope, node)) ||
            (node.type === "UnaryExpression" && node.operator === "void"));
    }
    /**
     * Test if an AST node has a statically knowable constant nullishness. Meaning,
     * it will always resolve to a constant value of either: `null`, `undefined`
     * or not `null` _or_ `undefined`. An expression that can vary between those
     * three states at runtime would return `false`.
     * @param {Scope} scope The scope in which the node was found.
     * @param {ASTNode} node The AST node being tested.
     * @param {boolean} nonNullish if `true` then nullish values are not considered constant.
     * @returns {boolean} Does `node` have constant nullishness?
     */
    function hasConstantNullishness(scope, node, nonNullish) {
        if (nonNullish && isNullOrUndefined(scope, node)) {
            return false;
        }
        switch (node.type) {
            case "ObjectExpression": // Objects are never nullish
            case "ArrayExpression": // Arrays are never nullish
            case "ArrowFunctionExpression": // Functions never nullish
            case "FunctionExpression": // Functions are never nullish
            case "ClassExpression": // Classes are never nullish
            case "NewExpression": // Objects are never nullish
            case "Literal": // Nullish, or non-nullish, literals never change
            case "TemplateLiteral": // A string is never nullish
            case "UpdateExpression": // Numbers are never nullish
            case "BinaryExpression": // Numbers, strings, or booleans are never nullish
                return true;
            case "CallExpression": {
                if (node.callee.type !== "Identifier") {
                    return false;
                }
                const functionName = node.callee.name;
                return (functionName === "Boolean" || functionName === "String" || functionName === "Number") &&
                    isReferenceToGlobalVariable(scope, node.callee);
            }
            case "LogicalExpression": {
                return node.operator === "??" && hasConstantNullishness(scope, node.right, true);
            }
            case "AssignmentExpression":
                if (node.operator === "=") {
                    return hasConstantNullishness(scope, node.right, nonNullish);
                }
                /*
                 * Handling short-circuiting assignment operators would require
                 * walking the scope. We won't attempt that (for now...) /
                 */
                if (isLogicalAssignmentOperator(node.operator)) {
                    return false;
                }
                /*
                 * The remaining assignment expressions all result in a numeric or
                 * string (non-nullish) value:
                 *   "+=", "-=", "*=", "/=", "%=", "<<=", ">>=", ">>>=", "|=", "^=", "&="
                 */
                return true;
            case "UnaryExpression":
                /*
                 * "void" Always returns `undefined`
                 * "typeof" All types are strings, and thus non-nullish
                 * "!" Boolean is never nullish
                 * "delete" Returns a boolean, which is never nullish
                 * Math operators always return numbers or strings, neither of which
                 * are non-nullish "+", "-", "~"
                 */
                return true;
            case "SequenceExpression": {
                const last = node.expressions[node.expressions.length - 1];
                return hasConstantNullishness(scope, last, nonNullish);
            }
            case "Identifier":
                return node.name === "undefined" && isReferenceToGlobalVariable(scope, node);
            case "JSXElement": // ESLint has a policy of not assuming any specific JSX behavior.
            case "JSXFragment":
                return false;
            default:
                return false;
        }
    }
    /**
     * Test if an AST node is a boolean value that never changes. Specifically we
     * test for:
     * 1. Literal booleans (`true` or `false`)
     * 2. Unary `!` expressions with a constant value
     * 3. Constant booleans created via the `Boolean` global function
     * @param {Scope} scope The scope in which the node was found.
     * @param {ASTNode} node The node to test
     * @returns {boolean} Is `node` guaranteed to be a boolean?
     */
    function isStaticBoolean(scope, node) {
        switch (node.type) {
            case "Literal":
                return typeof node.value === "boolean";
            case "CallExpression":
                return node.callee.type === "Identifier" && node.callee.name === "Boolean" &&
                    isReferenceToGlobalVariable(scope, node.callee) &&
                    (node.arguments.length === 0 || isConstant(scope, node.arguments[0], true));
            case "UnaryExpression":
                return node.operator === "!" && isConstant(scope, node.argument, true);
            default:
                return false;
        }
    }
    /**
     * Test if an AST node will always give the same result when compared to a
     * boolean value. Note that comparison to boolean values is different than
     * truthiness.
     * https://262.ecma-international.org/5.1/#sec-11.9.3
     *
     * Javascript `==` operator works by converting the boolean to `1` (true) or
     * `+0` (false) and then checks the values `==` equality to that number.
     * @param {Scope} scope The scope in which node was found.
     * @param {ASTNode} node The node to test.
     * @returns {boolean} Will `node` always coerce to the same boolean value?
     */
    function hasConstantLooseBooleanComparison(scope, node) {
        switch (node.type) {
            case "ObjectExpression":
            case "ClassExpression":
                /**
                 * In theory objects like:
                 *
                 * `{toString: () => a}`
                 * `{valueOf: () => a}`
                 *
                 * Or a classes like:
                 *
                 * `class { static toString() { return a } }`
                 * `class { static valueOf() { return a } }`
                 *
                 * Are not constant verifiably when `inBooleanPosition` is
                 * false, but it's an edge case we've opted not to handle.
                 */
                return true;
            case "ArrayExpression": {
                const nonSpreadElements = node.elements.filter(e => 
                // Elements can be `null` in sparse arrays: `[,,]`;
                e !== null && e.type !== "SpreadElement");
                /*
                 * Possible future direction if needed: We could check if the
                 * single value would result in variable boolean comparison.
                 * For now we will err on the side of caution since `[x]` could
                 * evaluate to `[0]` or `[1]`.
                 */
                return node.elements.length === 0 || nonSpreadElements.length > 1;
            }
            case "ArrowFunctionExpression":
            case "FunctionExpression":
                return true;
            case "UnaryExpression":
                if (node.operator === "void" || // Always returns `undefined`
                    node.operator === "typeof" // All `typeof` strings, when coerced to number, are not 0 or 1.
                ) {
                    return true;
                }
                if (node.operator === "!") {
                    return isConstant(scope, node.argument, true);
                }
                /*
                 * We won't try to reason about +, -, ~, or delete
                 * In theory, for the mathematical operators, we could look at the
                 * argument and try to determine if it coerces to a constant numeric
                 * value.
                 */
                return false;
            case "NewExpression": // Objects might have custom `.valueOf` or `.toString`.
                return false;
            case "CallExpression": {
                if (node.callee.type === "Identifier" &&
                    node.callee.name === "Boolean" &&
                    isReferenceToGlobalVariable(scope, node.callee)) {
                    return node.arguments.length === 0 || isConstant(scope, node.arguments[0], true);
                }
                return false;
            }
            case "Literal": // True or false, literals never change
                return true;
            case "Identifier":
                return node.name === "undefined" && isReferenceToGlobalVariable(scope, node);
            case "TemplateLiteral":
                /*
                 * In theory we could try to check if the quasi are sufficient to
                 * prove that the expression will always be true, but it would be
                 * tricky to get right. For example: `000.${foo}000`
                 */
                return node.expressions.length === 0;
            case "AssignmentExpression":
                if (node.operator === "=") {
                    return hasConstantLooseBooleanComparison(scope, node.right);
                }
                /*
                 * Handling short-circuiting assignment operators would require
                 * walking the scope. We won't attempt that (for now...)
                 *
                 * The remaining assignment expressions all result in a numeric or
                 * string (non-nullish) values which could be truthy or falsy:
                 *   "+=", "-=", "*=", "/=", "%=", "<<=", ">>=", ">>>=", "|=", "^=", "&="
                 */
                return false;
            case "SequenceExpression": {
                const last = node.expressions[node.expressions.length - 1];
                return hasConstantLooseBooleanComparison(scope, last);
            }
            case "JSXElement": // ESLint has a policy of not assuming any specific JSX behavior.
            case "JSXFragment":
                return false;
            default:
                return false;
        }
    }
    /**
     * Test if an AST node will always give the same result when _strictly_ compared
     * to a boolean value. This can happen if the expression can never be boolean, or
     * if it is always the same boolean value.
     * @param {Scope} scope The scope in which the node was found.
     * @param {ASTNode} node The node to test
     * @returns {boolean} Will `node` always give the same result when compared to a
     * static boolean value?
     */
    function hasConstantStrictBooleanComparison(scope, node) {
        switch (node.type) {
            case "ObjectExpression": // Objects are not booleans
            case "ArrayExpression": // Arrays are not booleans
            case "ArrowFunctionExpression": // Functions are not booleans
            case "FunctionExpression":
            case "ClassExpression": // Classes are not booleans
            case "NewExpression": // Objects are not booleans
            case "TemplateLiteral": // Strings are not booleans
            case "Literal": // True, false, or not boolean, literals never change.
            case "UpdateExpression": // Numbers are not booleans
                return true;
            case "BinaryExpression":
                return NUMERIC_OR_STRING_BINARY_OPERATORS.has(node.operator);
            case "UnaryExpression": {
                if (node.operator === "delete") {
                    return false;
                }
                if (node.operator === "!") {
                    return isConstant(scope, node.argument, true);
                }
                /*
                 * The remaining operators return either strings or numbers, neither
                 * of which are boolean.
                 */
                return true;
            }
            case "SequenceExpression": {
                const last = node.expressions[node.expressions.length - 1];
                return hasConstantStrictBooleanComparison(scope, last);
            }
            case "Identifier":
                return node.name === "undefined" && isReferenceToGlobalVariable(scope, node);
            case "AssignmentExpression":
                if (node.operator === "=") {
                    return hasConstantStrictBooleanComparison(scope, node.right);
                }
                /*
                 * Handling short-circuiting assignment operators would require
                 * walking the scope. We won't attempt that (for now...)
                 */
                if (isLogicalAssignmentOperator(node.operator)) {
                    return false;
                }
                /*
                 * The remaining assignment expressions all result in either a number
                 * or a string, neither of which can ever be boolean.
                 */
                return true;
            case "CallExpression": {
                if (node.callee.type !== "Identifier") {
                    return false;
                }
                const functionName = node.callee.name;
                if ((functionName === "String" || functionName === "Number") &&
                    isReferenceToGlobalVariable(scope, node.callee)) {
                    return true;
                }
                if (functionName === "Boolean" && isReferenceToGlobalVariable(scope, node.callee)) {
                    return (node.arguments.length === 0 || isConstant(scope, node.arguments[0], true));
                }
                return false;
            }
            case "JSXElement": // ESLint has a policy of not assuming any specific JSX behavior.
            case "JSXFragment":
                return false;
            default:
                return false;
        }
    }
    /**
     * Test if an AST node will always result in a newly constructed object
     * @param {Scope} scope The scope in which the node was found.
     * @param {ASTNode} node The node to test
     * @returns {boolean} Will `node` always be new?
     */
    function isAlwaysNew(scope, node) {
        switch (node.type) {
            case "ObjectExpression":
            case "ArrayExpression":
            case "ArrowFunctionExpression":
            case "FunctionExpression":
            case "ClassExpression":
                return true;
            case "NewExpression": {
                if (node.callee.type !== "Identifier") {
                    return false;
                }
                /*
                 * All the built-in constructors are always new, but
                 * user-defined constructors could return a sentinel
                 * object.
                 *
                 * Catching these is especially useful for primitive constructors
                 * which return boxed values, a surprising gotcha' in JavaScript.
                 */
                return Object.hasOwnProperty.call(globals.builtin, node.callee.name) &&
                    isReferenceToGlobalVariable(scope, node.callee);
            }
            case "Literal":
                // Regular expressions are objects, and thus always new
                return typeof node.regex === "object";
            case "SequenceExpression": {
                const last = node.expressions[node.expressions.length - 1];
                return isAlwaysNew(scope, last);
            }
            case "AssignmentExpression":
                if (node.operator === "=") {
                    return isAlwaysNew(scope, node.right);
                }
                return false;
            case "ConditionalExpression":
                return isAlwaysNew(scope, node.consequent) && isAlwaysNew(scope, node.alternate);
            case "JSXElement": // ESLint has a policy of not assuming any specific JSX behavior.
            case "JSXFragment":
                return false;
            default:
                return false;
        }
    }
    /**
     * Checks if one operand will cause the result to be constant.
     * @param {Scope} scope Scope in which the expression was found.
     * @param {ASTNode} a One side of the expression
     * @param {ASTNode} b The other side of the expression
     * @param {string} operator The binary expression operator
     * @returns {ASTNode | null} The node which will cause the expression to have a constant result.
     */
    function findBinaryExpressionConstantOperand(scope, a, b, operator) {
        if (operator === "==" || operator === "!=") {
            if ((isNullOrUndefined(scope, a) && hasConstantNullishness(scope, b, false)) ||
                (isStaticBoolean(scope, a) && hasConstantLooseBooleanComparison(scope, b))) {
                return b;
            }
        }
        else if (operator === "===" || operator === "!==") {
            if ((isNullOrUndefined(scope, a) && hasConstantNullishness(scope, b, false)) ||
                (isStaticBoolean(scope, a) && hasConstantStrictBooleanComparison(scope, b))) {
                return b;
            }
        }
        return null;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow expressions where the operation doesn't affect the value",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-constant-binary-expression"
            },
            schema: [],
            messages: {
                constantBinaryOperand: "Unexpected constant binary expression. Compares constantly with the {{otherSide}}-hand side of the `{{operator}}`.",
                constantShortCircuit: "Unexpected constant {{property}} on the left-hand side of a `{{operator}}` expression.",
                alwaysNew: "Unexpected comparison to newly constructed object. These two values can never be equal.",
                bothAlwaysNew: "Unexpected comparison of two newly constructed objects. These two values can never be equal."
            }
        },
        create(context) {
            return {
                LogicalExpression(node) {
                    const { operator, left } = node;
                    const scope = context.getScope();
                    if ((operator === "&&" || operator === "||") && isConstant(scope, left, true)) {
                        context.report({ node: left, messageId: "constantShortCircuit", data: { property: "truthiness", operator } });
                    }
                    else if (operator === "??" && hasConstantNullishness(scope, left, false)) {
                        context.report({ node: left, messageId: "constantShortCircuit", data: { property: "nullishness", operator } });
                    }
                },
                BinaryExpression(node) {
                    const scope = context.getScope();
                    const { right, left, operator } = node;
                    const rightConstantOperand = findBinaryExpressionConstantOperand(scope, left, right, operator);
                    const leftConstantOperand = findBinaryExpressionConstantOperand(scope, right, left, operator);
                    if (rightConstantOperand) {
                        context.report({ node: rightConstantOperand, messageId: "constantBinaryOperand", data: { operator, otherSide: "left" } });
                    }
                    else if (leftConstantOperand) {
                        context.report({ node: leftConstantOperand, messageId: "constantBinaryOperand", data: { operator, otherSide: "right" } });
                    }
                    else if (operator === "===" || operator === "!==") {
                        if (isAlwaysNew(scope, left)) {
                            context.report({ node: left, messageId: "alwaysNew" });
                        }
                        else if (isAlwaysNew(scope, right)) {
                            context.report({ node: right, messageId: "alwaysNew" });
                        }
                    }
                    else if (operator === "==" || operator === "!=") {
                        /*
                         * If both sides are "new", then both sides are objects and
                         * therefore they will be compared by reference even with `==`
                         * equality.
                         */
                        if (isAlwaysNew(scope, left) && isAlwaysNew(scope, right)) {
                            context.report({ node: left, messageId: "bothAlwaysNew" });
                        }
                    }
                }
                /*
                 * In theory we could handle short-circuiting assignment operators,
                 * for some constant values, but that would require walking the
                 * scope to find the value of the variable being assigned. This is
                 * dependant on https://github.com/eslint/eslint/issues/13776
                 *
                 * AssignmentExpression() {},
                 */
            };
        }
    };
},
/* eslint/lib/rules/no-constant-condition.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use constant conditions
     * @author Christian Schulz <http://rndm.de>
     */
    "use strict";
    const { isConstant } = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow constant expressions in conditions",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-constant-condition"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        checkLoops: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpected: "Unexpected constant condition."
            }
        },
        create(context) {
            const options = context.options[0] || {}, checkLoops = options.checkLoops !== false, loopSetStack = [];
            let loopsInCurrentScope = new Set();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Tracks when the given node contains a constant condition.
             * @param {ASTNode} node The AST node to check.
             * @returns {void}
             * @private
             */
            function trackConstantConditionLoop(node) {
                if (node.test && isConstant(context.getScope(), node.test, true)) {
                    loopsInCurrentScope.add(node);
                }
            }
            /**
             * Reports when the set contains the given constant condition node
             * @param {ASTNode} node The AST node to check.
             * @returns {void}
             * @private
             */
            function checkConstantConditionLoopInSet(node) {
                if (loopsInCurrentScope.has(node)) {
                    loopsInCurrentScope.delete(node);
                    context.report({ node: node.test, messageId: "unexpected" });
                }
            }
            /**
             * Reports when the given node contains a constant condition.
             * @param {ASTNode} node The AST node to check.
             * @returns {void}
             * @private
             */
            function reportIfConstant(node) {
                if (node.test && isConstant(context.getScope(), node.test, true)) {
                    context.report({ node: node.test, messageId: "unexpected" });
                }
            }
            /**
             * Stores current set of constant loops in loopSetStack temporarily
             * and uses a new set to track constant loops
             * @returns {void}
             * @private
             */
            function enterFunction() {
                loopSetStack.push(loopsInCurrentScope);
                loopsInCurrentScope = new Set();
            }
            /**
             * Reports when the set still contains stored constant conditions
             * @returns {void}
             * @private
             */
            function exitFunction() {
                loopsInCurrentScope = loopSetStack.pop();
            }
            /**
             * Checks node when checkLoops option is enabled
             * @param {ASTNode} node The AST node to check.
             * @returns {void}
             * @private
             */
            function checkLoop(node) {
                if (checkLoops) {
                    trackConstantConditionLoop(node);
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                ConditionalExpression: reportIfConstant,
                IfStatement: reportIfConstant,
                WhileStatement: checkLoop,
                "WhileStatement:exit": checkConstantConditionLoopInSet,
                DoWhileStatement: checkLoop,
                "DoWhileStatement:exit": checkConstantConditionLoopInSet,
                ForStatement: checkLoop,
                "ForStatement > .test": node => checkLoop(node.parent),
                "ForStatement:exit": checkConstantConditionLoopInSet,
                FunctionDeclaration: enterFunction,
                "FunctionDeclaration:exit": exitFunction,
                FunctionExpression: enterFunction,
                "FunctionExpression:exit": exitFunction,
                YieldExpression: () => loopsInCurrentScope.clear()
            };
        }
    };
},
/* eslint/lib/rules/no-constructor-return.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow returning value from constructor.
     * @author Pig Fang <https://github.com/g-plane>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow returning value from constructor",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-constructor-return"
            },
            schema: {},
            fixable: null,
            messages: {
                unexpected: "Unexpected return statement in constructor."
            }
        },
        create(context) {
            const stack = [];
            return {
                onCodePathStart(_, node) {
                    stack.push(node);
                },
                onCodePathEnd() {
                    stack.pop();
                },
                ReturnStatement(node) {
                    const last = stack[stack.length - 1];
                    if (!last.parent) {
                        return;
                    }
                    if (last.parent.type === "MethodDefinition" &&
                        last.parent.kind === "constructor" &&
                        (node.parent.parent === last || node.argument)) {
                        context.report({
                            node,
                            messageId: "unexpected"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-continue.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of continue statement
     * @author Borislav Zhivkov
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `continue` statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-continue"
            },
            schema: [],
            messages: {
                unexpected: "Unexpected use of continue statement."
            }
        },
        create(context) {
            return {
                ContinueStatement(node) {
                    context.report({ node, messageId: "unexpected" });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-control-regex.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to forbid control characters from regular expressions.
     * @author Nicholas C. Zakas
     */
    "use strict";
    const RegExpValidator = require(485) /* @eslint-community/regexpp */.RegExpValidator;
    const collector = new (class {
        constructor() {
            this._source = "";
            this._controlChars = [];
            this._validator = new RegExpValidator(this);
        }
        onPatternEnter() {
            this._controlChars = [];
        }
        onCharacter(start, end, cp) {
            if (cp >= 0x00 &&
                cp <= 0x1F &&
                (this._source.codePointAt(start) === cp ||
                    this._source.slice(start, end).startsWith("\\x") ||
                    this._source.slice(start, end).startsWith("\\u"))) {
                this._controlChars.push(`\\x${`0${cp.toString(16)}`.slice(-2)}`);
            }
        }
        collectControlChars(regexpStr, flags) {
            const uFlag = typeof flags === "string" && flags.includes("u");
            try {
                this._source = regexpStr;
                this._validator.validatePattern(regexpStr, void 0, void 0, uFlag); // Call onCharacter hook
            }
            catch {
                // Ignore syntax errors in RegExp.
            }
            return this._controlChars;
        }
    })();
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow control characters in regular expressions",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-control-regex"
            },
            schema: [],
            messages: {
                unexpected: "Unexpected control character(s) in regular expression: {{controlChars}}."
            }
        },
        create(context) {
            /**
             * Get the regex expression
             * @param {ASTNode} node `Literal` node to evaluate
             * @returns {{ pattern: string, flags: string | null } | null} Regex if found (the given node is either a regex literal
             * or a string literal that is the pattern argument of a RegExp constructor call). Otherwise `null`. If flags cannot be determined,
             * the `flags` property will be `null`.
             * @private
             */
            function getRegExp(node) {
                if (node.regex) {
                    return node.regex;
                }
                if (typeof node.value === "string" &&
                    (node.parent.type === "NewExpression" || node.parent.type === "CallExpression") &&
                    node.parent.callee.type === "Identifier" &&
                    node.parent.callee.name === "RegExp" &&
                    node.parent.arguments[0] === node) {
                    const pattern = node.value;
                    const flags = node.parent.arguments.length > 1 &&
                        node.parent.arguments[1].type === "Literal" &&
                        typeof node.parent.arguments[1].value === "string"
                        ? node.parent.arguments[1].value
                        : null;
                    return { pattern, flags };
                }
                return null;
            }
            return {
                Literal(node) {
                    const regExp = getRegExp(node);
                    if (regExp) {
                        const { pattern, flags } = regExp;
                        const controlCharacters = collector.collectControlChars(pattern, flags);
                        if (controlCharacters.length > 0) {
                            context.report({
                                node,
                                messageId: "unexpected",
                                data: {
                                    controlChars: controlCharacters.join(", ")
                                }
                            });
                        }
                    }
                }
            };
        }
    };
},
/* @eslint-community/regexpp/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    var ast = /*#__PURE__*/ Object.freeze({
        __proto__: null
    });
    let largeIdStartRanges = undefined;
    let largeIdContinueRanges = undefined;
    function isIdStart(cp) {
        if (cp < 0x41)
            return false;
        if (cp < 0x5b)
            return true;
        if (cp < 0x61)
            return false;
        if (cp < 0x7b)
            return true;
        return isLargeIdStart(cp);
    }
    function isIdContinue(cp) {
        if (cp < 0x30)
            return false;
        if (cp < 0x3a)
            return true;
        if (cp < 0x41)
            return false;
        if (cp < 0x5b)
            return true;
        if (cp === 0x5f)
            return true;
        if (cp < 0x61)
            return false;
        if (cp < 0x7b)
            return true;
        return isLargeIdStart(cp) || isLargeIdContinue(cp);
    }
    function isLargeIdStart(cp) {
        return isInRange(cp, largeIdStartRanges !== null && largeIdStartRanges !== void 0 ? largeIdStartRanges : (largeIdStartRanges = initLargeIdStartRanges()));
    }
    function isLargeIdContinue(cp) {
        return isInRange(cp, largeIdContinueRanges !== null && largeIdContinueRanges !== void 0 ? largeIdContinueRanges : (largeIdContinueRanges = initLargeIdContinueRanges()));
    }
    function initLargeIdStartRanges() {
        return restoreRanges("4q 0 b 0 5 0 6 m 2 u 2 cp 5 b f 4 8 0 2 0 3m 4 2 1 3 3 2 0 7 0 2 2 2 0 2 j 2 2a 2 3u 9 4l 2 11 3 0 7 14 20 q 5 3 1a 16 10 1 2 2q 2 0 g 1 8 1 b 2 3 0 h 0 2 t u 2g c 0 p w a 1 5 0 6 l 5 0 a 0 4 0 o o 8 a 6 n 2 5 i 15 1n 1h 4 0 j 0 8 9 g f 5 7 3 1 3 l 2 6 2 0 4 3 4 0 h 0 e 1 2 2 f 1 b 0 9 5 5 1 3 l 2 6 2 1 2 1 2 1 w 3 2 0 k 2 h 8 2 2 2 l 2 6 2 1 2 4 4 0 j 0 g 1 o 0 c 7 3 1 3 l 2 6 2 1 2 4 4 0 v 1 2 2 g 0 i 0 2 5 4 2 2 3 4 1 2 0 2 1 4 1 4 2 4 b n 0 1h 7 2 2 2 m 2 f 4 0 r 2 3 0 3 1 v 0 5 7 2 2 2 m 2 9 2 4 4 0 w 1 2 1 g 1 i 8 2 2 2 14 3 0 h 0 6 2 9 2 p 5 6 h 4 n 2 8 2 0 3 6 1n 1b 2 1 d 6 1n 1 2 0 2 4 2 n 2 0 2 9 2 1 a 0 3 4 2 0 m 3 x 0 1s 7 2 z s 4 38 16 l 0 h 5 5 3 4 0 4 1 8 2 5 c d 0 i 11 2 0 6 0 3 16 2 98 2 3 3 6 2 0 2 3 3 14 2 3 3 w 2 3 3 6 2 0 2 3 3 e 2 1k 2 3 3 1u 12 f h 2d 3 5 4 h7 3 g 2 p 6 22 4 a 8 h e i f h f c 2 2 g 1f 10 0 5 0 1w 2g 8 14 2 0 6 1x b u 1e t 3 4 c 17 5 p 1j m a 1g 2b 0 2m 1a i 7 1j t e 1 b 17 r z 16 2 b z 3 8 8 16 3 2 16 3 2 5 2 1 4 0 6 5b 1t 7p 3 5 3 11 3 5 3 7 2 0 2 0 2 0 2 u 3 1g 2 6 2 0 4 2 2 6 4 3 3 5 5 c 6 2 2 6 39 0 e 0 h c 2u 0 5 0 3 9 2 0 3 5 7 0 2 0 2 0 2 f 3 3 6 4 5 0 i 14 22g 6c 7 3 4 1 d 11 2 0 6 0 3 1j 8 0 h m a 6 2 6 2 6 2 6 2 6 2 6 2 6 2 6 fb 2 q 8 8 4 3 4 5 2d 5 4 2 2h 2 3 6 16 2 2l i v 1d f e9 533 1t h3g 1w 19 3 7g 4 f b 1 l 1a h u 3 27 14 8 3 2u 3 1r 6 1 2 0 2 4 p f 2 2 2 3 2 m u 1f f 1d 1r 5 4 0 2 1 c r b m q s 8 1a t 0 h 4 2 9 b 4 2 14 o 2 2 7 l m 4 0 4 1d 2 0 4 1 3 4 3 0 2 0 p 2 3 a 8 2 d 5 3 5 3 5 a 6 2 6 2 16 2 d 7 36 u 8mb d m 5 1c 6it a5 3 2x 13 6 d 4 6 0 2 9 2 c 2 4 2 0 2 1 2 1 2 2z y a2 j 1r 3 1h 15 b 39 4 2 3q 11 p 7 p c 2g 4 5 3 5 3 5 3 2 10 b 2 p 2 i 2 1 2 e 3 d z 3e 1y 1g 7g s 4 1c 1c v e t 6 11 b t 3 z 5 7 2 4 17 4d j z 5 z 5 13 9 1f d a 2 e 2 6 2 1 2 a 2 e 2 6 2 1 1w 8m a l b 7 p 5 2 15 2 8 1y 5 3 0 2 17 2 1 4 0 3 m b m a u 1u i 2 1 b l b p 1z 1j 7 1 1t 0 g 3 2 2 2 s 17 s 4 s 10 7 2 r s 1h b l b i e h 33 20 1k 1e e 1e e z 9p 15 7 1 27 s b 0 9 l 17 h 1b k s m d 1g 1m 1 3 0 e 18 x o r z u 0 3 0 9 y 4 0 d 1b f 3 m 0 2 0 10 h 2 o k 1 1s 6 2 0 2 3 2 e 2 9 8 1a 13 7 3 1 3 l 2 6 2 1 2 4 4 0 j 0 d 4 4f 1g j 3 l 2 v 1b l 1 2 0 55 1a 16 3 11 1b l 0 1o 16 e 0 20 q 12 6 56 17 39 1r w 7 3 0 3 7 2 1 2 n g 0 2 0 2n 7 3 12 h 0 2 0 t 0 b 13 8 0 m 0 c 19 k 0 j 20 7c 8 2 10 i 0 1e t 35 6 2 1 2 11 m 0 q 5 2 1 2 v f 0 94 i g 0 2 c 2 x 3h 0 28 pl 2v 32 i 5f 219 2o g tr i 5 33u g6 6nu fs 8 u i 26 i t j 1b h 3 w k 6 i j5 1r 3l 22 6 0 1v c 1t 1 2 0 t 4qf 9 yd 17 8 6w8 3 2 6 2 1 2 82 g 0 u 2 3 0 f 3 9 az 1s5 2y 6 c 4 8 8 9 4mf 2c 2 1y 2 1 3 0 3 1 3 3 2 b 2 0 2 6 2 1s 2 3 3 7 2 6 2 r 2 3 2 4 2 0 4 6 2 9f 3 o 2 o 2 u 2 o 2 u 2 o 2 u 2 o 2 u 2 o 2 7 1f9 u 7 5 7a 1p 43 18 b 6 h 0 8y t j 17 dh r l1 6 2 3 2 1 2 e 2 5g 1o 1v 8 0 xh 3 2 q 2 1 2 0 3 0 2 9 2 3 2 0 2 0 7 0 5 0 2 0 2 0 2 2 2 1 2 0 3 0 2 0 2 0 2 0 2 0 2 1 2 0 3 3 2 6 2 3 2 3 2 0 2 9 2 g 6 2 2 4 2 g 3et wyn x 37d 7 65 3 4g1 f 5rk 2e8 f1 15v 3t6 6 38f");
    }
    function initLargeIdContinueRanges() {
        return restoreRanges("53 0 g9 33 o 0 70 4 7e 18 2 0 2 1 2 1 2 0 21 a 1d u 7 0 2u 6 3 5 3 1 2 3 3 9 o 0 v q 2k a g 9 y 8 a 0 p 3 2 8 2 2 2 4 18 2 1p 7 17 n 2 w 1j 2 2 h 2 6 b 1 3 9 i 2 1l 0 2 6 3 1 3 2 a 0 b 1 3 9 f 0 3 2 1l 0 2 4 5 1 3 2 4 0 l b 4 0 c 2 1l 0 2 7 2 2 2 2 l 1 3 9 b 5 2 2 1l 0 2 6 3 1 3 2 8 2 b 1 3 9 j 0 1o 4 4 2 2 3 a 0 f 9 h 4 1k 0 2 6 2 2 2 3 8 1 c 1 3 9 i 2 1l 0 2 6 2 2 2 3 8 1 c 1 3 9 4 0 d 3 1k 1 2 6 2 2 2 3 a 0 b 1 3 9 i 2 1z 0 5 5 2 0 2 7 7 9 3 1 1q 0 3 6 d 7 2 9 2g 0 3 8 c 6 2 9 1r 1 7 9 c 0 2 0 2 0 5 1 1e j 2 1 6 a 2 z a 0 2t j 2 9 d 3 5 2 2 2 3 6 4 3 e b 2 e jk 2 a 8 pt 3 t 2 u 1 v 1 1t v a 0 3 9 y 2 2 a 40 0 3b b 5 b b 9 3l a 1p 4 1m 9 2 s 3 a 7 9 n d 2 f 1e 4 1c g c 9 i 8 d 2 v c 3 9 19 d 1d j 9 9 7 9 3b 2 2 k 5 0 7 0 3 2 5j 1r g0 1 k 0 3g c 5 0 4 b 2db 2 3y 0 2p v ff 5 2y 1 n7q 9 1y 0 5 9 x 1 29 1 7l 0 4 0 5 0 o 4 5 0 2c 1 1f h b 9 7 h e a t 7 q c 19 3 1c d g 9 c 0 b 9 1c d d 0 9 1 3 9 y 2 1f 0 2 2 3 1 6 1 2 0 16 4 6 1 6l 7 2 1 3 9 fmt 0 ki f h f 4 1 p 2 5d 9 12 0 ji 0 6b 0 46 4 86 9 120 2 2 1 6 3 15 2 5 0 4m 1 fy 3 9 9 aa 1 29 2 1z a 1e 3 3f 2 1i e w a 3 1 b 3 1a a 8 0 1a 9 7 2 11 d 2 9 6 1 19 0 d 2 1d d 9 3 2 b 2b b 7 0 3 0 4e b 6 9 7 3 1k 1 2 6 3 1 3 2 a 0 b 1 3 6 4 4 5d h a 9 5 0 2a j d 9 5y 6 3 8 s 1 2b g g 9 2a c 9 9 2c e 5 9 6r e 4m 9 1z 5 2 1 3 3 2 0 2 1 d 9 3c 6 3 6 4 0 t 9 15 6 2 3 9 0 a a 1b f ba 7 2 7 h 9 1l l 2 d 3f 5 4 0 2 1 2 6 2 0 9 9 1d 4 2 1 2 4 9 9 96 3 a 1 2 0 1d 6 4 4 e 9 44n 0 7 e aob 9 2f 9 13 4 1o 6 q 9 s6 0 2 1i 8 3 2a 0 c 1 f58 1 3mq 19 3 m f3 4 4 5 9 7 3 6 v 3 45 2 13e 1d e9 1i 5 1d 9 0 f 0 n 4 2 e 11t 6 2 g 3 6 2 1 2 4 2t 0 4h 6 a 9 9x 0 1q d dv d rb 6 32 6 6 9 3o7 9 gvt3 6n");
    }
    function isInRange(cp, ranges) {
        let l = 0, r = (ranges.length / 2) | 0, i = 0, min = 0, max = 0;
        while (l < r) {
            i = ((l + r) / 2) | 0;
            min = ranges[2 * i];
            max = ranges[2 * i + 1];
            if (cp < min) {
                r = i;
            }
            else if (cp > max) {
                l = i + 1;
            }
            else {
                return true;
            }
        }
        return false;
    }
    function restoreRanges(data) {
        let last = 0;
        return data.split(" ").map((s) => (last += parseInt(s, 36) | 0));
    }
    class DataSet {
        constructor(raw2018, raw2019, raw2020, raw2021, raw2022, raw2023) {
            this._raw2018 = raw2018;
            this._raw2019 = raw2019;
            this._raw2020 = raw2020;
            this._raw2021 = raw2021;
            this._raw2022 = raw2022;
            this._raw2023 = raw2023;
        }
        get es2018() {
            var _a;
            return ((_a = this._set2018) !== null && _a !== void 0 ? _a : (this._set2018 = new Set(this._raw2018.split(" "))));
        }
        get es2019() {
            var _a;
            return ((_a = this._set2019) !== null && _a !== void 0 ? _a : (this._set2019 = new Set(this._raw2019.split(" "))));
        }
        get es2020() {
            var _a;
            return ((_a = this._set2020) !== null && _a !== void 0 ? _a : (this._set2020 = new Set(this._raw2020.split(" "))));
        }
        get es2021() {
            var _a;
            return ((_a = this._set2021) !== null && _a !== void 0 ? _a : (this._set2021 = new Set(this._raw2021.split(" "))));
        }
        get es2022() {
            var _a;
            return ((_a = this._set2022) !== null && _a !== void 0 ? _a : (this._set2022 = new Set(this._raw2022.split(" "))));
        }
        get es2023() {
            var _a;
            return ((_a = this._set2023) !== null && _a !== void 0 ? _a : (this._set2023 = new Set(this._raw2023.split(" "))));
        }
    }
    const gcNameSet = new Set(["General_Category", "gc"]);
    const scNameSet = new Set(["Script", "Script_Extensions", "sc", "scx"]);
    const gcValueSets = new DataSet("C Cased_Letter Cc Cf Close_Punctuation Cn Co Combining_Mark Connector_Punctuation Control Cs Currency_Symbol Dash_Punctuation Decimal_Number Enclosing_Mark Final_Punctuation Format Initial_Punctuation L LC Letter Letter_Number Line_Separator Ll Lm Lo Lowercase_Letter Lt Lu M Mark Math_Symbol Mc Me Mn Modifier_Letter Modifier_Symbol N Nd Nl No Nonspacing_Mark Number Open_Punctuation Other Other_Letter Other_Number Other_Punctuation Other_Symbol P Paragraph_Separator Pc Pd Pe Pf Pi Po Private_Use Ps Punctuation S Sc Separator Sk Sm So Space_Separator Spacing_Mark Surrogate Symbol Titlecase_Letter Unassigned Uppercase_Letter Z Zl Zp Zs cntrl digit punct", "", "", "", "", "");
    const scValueSets = new DataSet("Adlam Adlm Aghb Ahom Anatolian_Hieroglyphs Arab Arabic Armenian Armi Armn Avestan Avst Bali Balinese Bamu Bamum Bass Bassa_Vah Batak Batk Beng Bengali Bhaiksuki Bhks Bopo Bopomofo Brah Brahmi Brai Braille Bugi Buginese Buhd Buhid Cakm Canadian_Aboriginal Cans Cari Carian Caucasian_Albanian Chakma Cham Cher Cherokee Common Copt Coptic Cprt Cuneiform Cypriot Cyrillic Cyrl Deseret Deva Devanagari Dsrt Dupl Duployan Egyp Egyptian_Hieroglyphs Elba Elbasan Ethi Ethiopic Geor Georgian Glag Glagolitic Gonm Goth Gothic Gran Grantha Greek Grek Gujarati Gujr Gurmukhi Guru Han Hang Hangul Hani Hano Hanunoo Hatr Hatran Hebr Hebrew Hira Hiragana Hluw Hmng Hung Imperial_Aramaic Inherited Inscriptional_Pahlavi Inscriptional_Parthian Ital Java Javanese Kaithi Kali Kana Kannada Katakana Kayah_Li Khar Kharoshthi Khmer Khmr Khoj Khojki Khudawadi Knda Kthi Lana Lao Laoo Latin Latn Lepc Lepcha Limb Limbu Lina Linb Linear_A Linear_B Lisu Lyci Lycian Lydi Lydian Mahajani Mahj Malayalam Mand Mandaic Mani Manichaean Marc Marchen Masaram_Gondi Meetei_Mayek Mend Mende_Kikakui Merc Mero Meroitic_Cursive Meroitic_Hieroglyphs Miao Mlym Modi Mong Mongolian Mro Mroo Mtei Mult Multani Myanmar Mymr Nabataean Narb Nbat New_Tai_Lue Newa Nko Nkoo Nshu Nushu Ogam Ogham Ol_Chiki Olck Old_Hungarian Old_Italic Old_North_Arabian Old_Permic Old_Persian Old_South_Arabian Old_Turkic Oriya Orkh Orya Osage Osge Osma Osmanya Pahawh_Hmong Palm Palmyrene Pau_Cin_Hau Pauc Perm Phag Phags_Pa Phli Phlp Phnx Phoenician Plrd Prti Psalter_Pahlavi Qaac Qaai Rejang Rjng Runic Runr Samaritan Samr Sarb Saur Saurashtra Sgnw Sharada Shavian Shaw Shrd Sidd Siddham SignWriting Sind Sinh Sinhala Sora Sora_Sompeng Soyo Soyombo Sund Sundanese Sylo Syloti_Nagri Syrc Syriac Tagalog Tagb Tagbanwa Tai_Le Tai_Tham Tai_Viet Takr Takri Tale Talu Tamil Taml Tang Tangut Tavt Telu Telugu Tfng Tglg Thaa Thaana Thai Tibetan Tibt Tifinagh Tirh Tirhuta Ugar Ugaritic Vai Vaii Wara Warang_Citi Xpeo Xsux Yi Yiii Zanabazar_Square Zanb Zinh Zyyy", "Dogr Dogra Gong Gunjala_Gondi Hanifi_Rohingya Maka Makasar Medefaidrin Medf Old_Sogdian Rohg Sogd Sogdian Sogo", "Elym Elymaic Hmnp Nand Nandinagari Nyiakeng_Puachue_Hmong Wancho Wcho", "Chorasmian Chrs Diak Dives_Akuru Khitan_Small_Script Kits Yezi Yezidi", "Cpmn Cypro_Minoan Old_Uyghur Ougr Tangsa Tnsa Toto Vith Vithkuqi", "");
    const binPropertySets = new DataSet("AHex ASCII ASCII_Hex_Digit Alpha Alphabetic Any Assigned Bidi_C Bidi_Control Bidi_M Bidi_Mirrored CI CWCF CWCM CWKCF CWL CWT CWU Case_Ignorable Cased Changes_When_Casefolded Changes_When_Casemapped Changes_When_Lowercased Changes_When_NFKC_Casefolded Changes_When_Titlecased Changes_When_Uppercased DI Dash Default_Ignorable_Code_Point Dep Deprecated Dia Diacritic Emoji Emoji_Component Emoji_Modifier Emoji_Modifier_Base Emoji_Presentation Ext Extender Gr_Base Gr_Ext Grapheme_Base Grapheme_Extend Hex Hex_Digit IDC IDS IDSB IDST IDS_Binary_Operator IDS_Trinary_Operator ID_Continue ID_Start Ideo Ideographic Join_C Join_Control LOE Logical_Order_Exception Lower Lowercase Math NChar Noncharacter_Code_Point Pat_Syn Pat_WS Pattern_Syntax Pattern_White_Space QMark Quotation_Mark RI Radical Regional_Indicator SD STerm Sentence_Terminal Soft_Dotted Term Terminal_Punctuation UIdeo Unified_Ideograph Upper Uppercase VS Variation_Selector White_Space XIDC XIDS XID_Continue XID_Start space", "Extended_Pictographic", "", "EBase EComp EMod EPres ExtPict", "", "");
    function isValidUnicodeProperty(version, name, value) {
        if (gcNameSet.has(name)) {
            return version >= 2018 && gcValueSets.es2018.has(value);
        }
        if (scNameSet.has(name)) {
            return ((version >= 2018 && scValueSets.es2018.has(value)) ||
                (version >= 2019 && scValueSets.es2019.has(value)) ||
                (version >= 2020 && scValueSets.es2020.has(value)) ||
                (version >= 2021 && scValueSets.es2021.has(value)) ||
                (version >= 2022 && scValueSets.es2022.has(value)));
        }
        return false;
    }
    function isValidLoneUnicodeProperty(version, value) {
        return ((version >= 2018 && binPropertySets.es2018.has(value)) ||
            (version >= 2019 && binPropertySets.es2019.has(value)) ||
            (version >= 2021 && binPropertySets.es2021.has(value)));
    }
    const BACKSPACE = 0x08;
    const CHARACTER_TABULATION = 0x09;
    const LINE_FEED = 0x0a;
    const LINE_TABULATION = 0x0b;
    const FORM_FEED = 0x0c;
    const CARRIAGE_RETURN = 0x0d;
    const EXCLAMATION_MARK = 0x21;
    const DOLLAR_SIGN = 0x24;
    const LEFT_PARENTHESIS = 0x28;
    const RIGHT_PARENTHESIS = 0x29;
    const ASTERISK = 0x2a;
    const PLUS_SIGN = 0x2b;
    const COMMA = 0x2c;
    const HYPHEN_MINUS = 0x2d;
    const FULL_STOP = 0x2e;
    const SOLIDUS = 0x2f;
    const DIGIT_ZERO = 0x30;
    const DIGIT_ONE = 0x31;
    const DIGIT_SEVEN = 0x37;
    const DIGIT_NINE = 0x39;
    const COLON = 0x3a;
    const LESS_THAN_SIGN = 0x3c;
    const EQUALS_SIGN = 0x3d;
    const GREATER_THAN_SIGN = 0x3e;
    const QUESTION_MARK = 0x3f;
    const LATIN_CAPITAL_LETTER_A = 0x41;
    const LATIN_CAPITAL_LETTER_B = 0x42;
    const LATIN_CAPITAL_LETTER_D = 0x44;
    const LATIN_CAPITAL_LETTER_F = 0x46;
    const LATIN_CAPITAL_LETTER_P = 0x50;
    const LATIN_CAPITAL_LETTER_S = 0x53;
    const LATIN_CAPITAL_LETTER_W = 0x57;
    const LATIN_CAPITAL_LETTER_Z = 0x5a;
    const LOW_LINE = 0x5f;
    const LATIN_SMALL_LETTER_A = 0x61;
    const LATIN_SMALL_LETTER_B = 0x62;
    const LATIN_SMALL_LETTER_C = 0x63;
    const LATIN_SMALL_LETTER_D = 0x64;
    const LATIN_SMALL_LETTER_F = 0x66;
    const LATIN_SMALL_LETTER_G = 0x67;
    const LATIN_SMALL_LETTER_I = 0x69;
    const LATIN_SMALL_LETTER_K = 0x6b;
    const LATIN_SMALL_LETTER_M = 0x6d;
    const LATIN_SMALL_LETTER_N = 0x6e;
    const LATIN_SMALL_LETTER_P = 0x70;
    const LATIN_SMALL_LETTER_R = 0x72;
    const LATIN_SMALL_LETTER_S = 0x73;
    const LATIN_SMALL_LETTER_T = 0x74;
    const LATIN_SMALL_LETTER_U = 0x75;
    const LATIN_SMALL_LETTER_V = 0x76;
    const LATIN_SMALL_LETTER_W = 0x77;
    const LATIN_SMALL_LETTER_X = 0x78;
    const LATIN_SMALL_LETTER_Y = 0x79;
    const LATIN_SMALL_LETTER_Z = 0x7a;
    const LEFT_SQUARE_BRACKET = 0x5b;
    const REVERSE_SOLIDUS = 0x5c;
    const RIGHT_SQUARE_BRACKET = 0x5d;
    const CIRCUMFLEX_ACCENT = 0x5e;
    const LEFT_CURLY_BRACKET = 0x7b;
    const VERTICAL_LINE = 0x7c;
    const RIGHT_CURLY_BRACKET = 0x7d;
    const ZERO_WIDTH_NON_JOINER = 0x200c;
    const ZERO_WIDTH_JOINER = 0x200d;
    const LINE_SEPARATOR = 0x2028;
    const PARAGRAPH_SEPARATOR = 0x2029;
    const MIN_CODE_POINT = 0x00;
    const MAX_CODE_POINT = 0x10ffff;
    function isLatinLetter(code) {
        return ((code >= LATIN_CAPITAL_LETTER_A && code <= LATIN_CAPITAL_LETTER_Z) ||
            (code >= LATIN_SMALL_LETTER_A && code <= LATIN_SMALL_LETTER_Z));
    }
    function isDecimalDigit(code) {
        return code >= DIGIT_ZERO && code <= DIGIT_NINE;
    }
    function isOctalDigit(code) {
        return code >= DIGIT_ZERO && code <= DIGIT_SEVEN;
    }
    function isHexDigit(code) {
        return ((code >= DIGIT_ZERO && code <= DIGIT_NINE) ||
            (code >= LATIN_CAPITAL_LETTER_A && code <= LATIN_CAPITAL_LETTER_F) ||
            (code >= LATIN_SMALL_LETTER_A && code <= LATIN_SMALL_LETTER_F));
    }
    function isLineTerminator(code) {
        return (code === LINE_FEED ||
            code === CARRIAGE_RETURN ||
            code === LINE_SEPARATOR ||
            code === PARAGRAPH_SEPARATOR);
    }
    function isValidUnicode(code) {
        return code >= MIN_CODE_POINT && code <= MAX_CODE_POINT;
    }
    function digitToInt(code) {
        if (code >= LATIN_SMALL_LETTER_A && code <= LATIN_SMALL_LETTER_F) {
            return code - LATIN_SMALL_LETTER_A + 10;
        }
        if (code >= LATIN_CAPITAL_LETTER_A && code <= LATIN_CAPITAL_LETTER_F) {
            return code - LATIN_CAPITAL_LETTER_A + 10;
        }
        return code - DIGIT_ZERO;
    }
    function isLeadSurrogate(code) {
        return code >= 0xd800 && code <= 0xdbff;
    }
    function isTrailSurrogate(code) {
        return code >= 0xdc00 && code <= 0xdfff;
    }
    function combineSurrogatePair(lead, trail) {
        return (lead - 0xd800) * 0x400 + (trail - 0xdc00) + 0x10000;
    }
    const legacyImpl = {
        at(s, end, i) {
            return i < end ? s.charCodeAt(i) : -1;
        },
        width(c) {
            return 1;
        },
    };
    const unicodeImpl = {
        at(s, end, i) {
            return i < end ? s.codePointAt(i) : -1;
        },
        width(c) {
            return c > 0xffff ? 2 : 1;
        },
    };
    class Reader {
        constructor() {
            this._impl = legacyImpl;
            this._s = "";
            this._i = 0;
            this._end = 0;
            this._cp1 = -1;
            this._w1 = 1;
            this._cp2 = -1;
            this._w2 = 1;
            this._cp3 = -1;
            this._w3 = 1;
            this._cp4 = -1;
        }
        get source() {
            return this._s;
        }
        get index() {
            return this._i;
        }
        get currentCodePoint() {
            return this._cp1;
        }
        get nextCodePoint() {
            return this._cp2;
        }
        get nextCodePoint2() {
            return this._cp3;
        }
        get nextCodePoint3() {
            return this._cp4;
        }
        reset(source, start, end, uFlag) {
            this._impl = uFlag ? unicodeImpl : legacyImpl;
            this._s = source;
            this._end = end;
            this.rewind(start);
        }
        rewind(index) {
            const impl = this._impl;
            this._i = index;
            this._cp1 = impl.at(this._s, this._end, index);
            this._w1 = impl.width(this._cp1);
            this._cp2 = impl.at(this._s, this._end, index + this._w1);
            this._w2 = impl.width(this._cp2);
            this._cp3 = impl.at(this._s, this._end, index + this._w1 + this._w2);
            this._w3 = impl.width(this._cp3);
            this._cp4 = impl.at(this._s, this._end, index + this._w1 + this._w2 + this._w3);
        }
        advance() {
            if (this._cp1 !== -1) {
                const impl = this._impl;
                this._i += this._w1;
                this._cp1 = this._cp2;
                this._w1 = this._w2;
                this._cp2 = this._cp3;
                this._w2 = impl.width(this._cp2);
                this._cp3 = this._cp4;
                this._w3 = impl.width(this._cp3);
                this._cp4 = impl.at(this._s, this._end, this._i + this._w1 + this._w2 + this._w3);
            }
        }
        eat(cp) {
            if (this._cp1 === cp) {
                this.advance();
                return true;
            }
            return false;
        }
        eat2(cp1, cp2) {
            if (this._cp1 === cp1 && this._cp2 === cp2) {
                this.advance();
                this.advance();
                return true;
            }
            return false;
        }
        eat3(cp1, cp2, cp3) {
            if (this._cp1 === cp1 && this._cp2 === cp2 && this._cp3 === cp3) {
                this.advance();
                this.advance();
                this.advance();
                return true;
            }
            return false;
        }
    }
    class RegExpSyntaxError extends SyntaxError {
        constructor(source, uFlag, index, message) {
            if (source) {
                if (!source.startsWith("/")) {
                    source = `/${source}/${uFlag ? "u" : ""}`;
                }
                source = `: ${source}`;
            }
            super(`Invalid regular expression${source}: ${message}`);
            this.index = index;
        }
    }
    function isSyntaxCharacter(cp) {
        return (cp === CIRCUMFLEX_ACCENT ||
            cp === DOLLAR_SIGN ||
            cp === REVERSE_SOLIDUS ||
            cp === FULL_STOP ||
            cp === ASTERISK ||
            cp === PLUS_SIGN ||
            cp === QUESTION_MARK ||
            cp === LEFT_PARENTHESIS ||
            cp === RIGHT_PARENTHESIS ||
            cp === LEFT_SQUARE_BRACKET ||
            cp === RIGHT_SQUARE_BRACKET ||
            cp === LEFT_CURLY_BRACKET ||
            cp === RIGHT_CURLY_BRACKET ||
            cp === VERTICAL_LINE);
    }
    function isRegExpIdentifierStart(cp) {
        return isIdStart(cp) || cp === DOLLAR_SIGN || cp === LOW_LINE;
    }
    function isRegExpIdentifierPart(cp) {
        return (isIdContinue(cp) ||
            cp === DOLLAR_SIGN ||
            cp === LOW_LINE ||
            cp === ZERO_WIDTH_NON_JOINER ||
            cp === ZERO_WIDTH_JOINER);
    }
    function isUnicodePropertyNameCharacter(cp) {
        return isLatinLetter(cp) || cp === LOW_LINE;
    }
    function isUnicodePropertyValueCharacter(cp) {
        return isUnicodePropertyNameCharacter(cp) || isDecimalDigit(cp);
    }
    class RegExpValidator {
        constructor(options) {
            this._reader = new Reader();
            this._uFlag = false;
            this._nFlag = false;
            this._lastIntValue = 0;
            this._lastMinValue = 0;
            this._lastMaxValue = 0;
            this._lastStrValue = "";
            this._lastKeyValue = "";
            this._lastValValue = "";
            this._lastAssertionIsQuantifiable = false;
            this._numCapturingParens = 0;
            this._groupNames = new Set();
            this._backreferenceNames = new Set();
            this._options = options !== null && options !== void 0 ? options : {};
        }
        validateLiteral(source, start = 0, end = source.length) {
            this._uFlag = this._nFlag = false;
            this.reset(source, start, end);
            this.onLiteralEnter(start);
            if (this.eat(SOLIDUS) && this.eatRegExpBody() && this.eat(SOLIDUS)) {
                const flagStart = this.index;
                const uFlag = source.includes("u", flagStart);
                this.validateFlags(source, flagStart, end);
                this.validatePattern(source, start + 1, flagStart - 1, uFlag);
            }
            else if (start >= end) {
                this.raise("Empty");
            }
            else {
                const c = String.fromCodePoint(this.currentCodePoint);
                this.raise(`Unexpected character '${c}'`);
            }
            this.onLiteralLeave(start, end);
        }
        validateFlags(source, start = 0, end = source.length) {
            const existingFlags = new Set();
            let global = false;
            let ignoreCase = false;
            let multiline = false;
            let sticky = false;
            let unicode = false;
            let dotAll = false;
            let hasIndices = false;
            for (let i = start; i < end; ++i) {
                const flag = source.charCodeAt(i);
                if (existingFlags.has(flag)) {
                    this.raise(`Duplicated flag '${source[i]}'`);
                }
                existingFlags.add(flag);
                if (flag === LATIN_SMALL_LETTER_G) {
                    global = true;
                }
                else if (flag === LATIN_SMALL_LETTER_I) {
                    ignoreCase = true;
                }
                else if (flag === LATIN_SMALL_LETTER_M) {
                    multiline = true;
                }
                else if (flag === LATIN_SMALL_LETTER_U &&
                    this.ecmaVersion >= 2015) {
                    unicode = true;
                }
                else if (flag === LATIN_SMALL_LETTER_Y &&
                    this.ecmaVersion >= 2015) {
                    sticky = true;
                }
                else if (flag === LATIN_SMALL_LETTER_S &&
                    this.ecmaVersion >= 2018) {
                    dotAll = true;
                }
                else if (flag === LATIN_SMALL_LETTER_D &&
                    this.ecmaVersion >= 2022) {
                    hasIndices = true;
                }
                else {
                    this.raise(`Invalid flag '${source[i]}'`);
                }
            }
            this.onRegExpFlags(start, end, {
                global,
                ignoreCase,
                multiline,
                unicode,
                sticky,
                dotAll,
                hasIndices,
            });
        }
        validatePattern(source, start = 0, end = source.length, uFlag = false) {
            this._uFlag = uFlag && this.ecmaVersion >= 2015;
            this._nFlag = uFlag && this.ecmaVersion >= 2018;
            this.reset(source, start, end);
            this.consumePattern();
            if (!this._nFlag &&
                this.ecmaVersion >= 2018 &&
                this._groupNames.size > 0) {
                this._nFlag = true;
                this.rewind(start);
                this.consumePattern();
            }
        }
        get strict() {
            return Boolean(this._options.strict) || this._uFlag;
        }
        get ecmaVersion() {
            var _a;
            return (_a = this._options.ecmaVersion) !== null && _a !== void 0 ? _a : 2022;
        }
        onLiteralEnter(start) {
            if (this._options.onLiteralEnter) {
                this._options.onLiteralEnter(start);
            }
        }
        onLiteralLeave(start, end) {
            if (this._options.onLiteralLeave) {
                this._options.onLiteralLeave(start, end);
            }
        }
        onRegExpFlags(start, end, flags) {
            if (this._options.onRegExpFlags) {
                this._options.onRegExpFlags(start, end, flags);
            }
            if (this._options.onFlags) {
                this._options.onFlags(start, end, flags.global, flags.ignoreCase, flags.multiline, flags.unicode, flags.sticky, flags.dotAll, flags.hasIndices);
            }
        }
        onPatternEnter(start) {
            if (this._options.onPatternEnter) {
                this._options.onPatternEnter(start);
            }
        }
        onPatternLeave(start, end) {
            if (this._options.onPatternLeave) {
                this._options.onPatternLeave(start, end);
            }
        }
        onDisjunctionEnter(start) {
            if (this._options.onDisjunctionEnter) {
                this._options.onDisjunctionEnter(start);
            }
        }
        onDisjunctionLeave(start, end) {
            if (this._options.onDisjunctionLeave) {
                this._options.onDisjunctionLeave(start, end);
            }
        }
        onAlternativeEnter(start, index) {
            if (this._options.onAlternativeEnter) {
                this._options.onAlternativeEnter(start, index);
            }
        }
        onAlternativeLeave(start, end, index) {
            if (this._options.onAlternativeLeave) {
                this._options.onAlternativeLeave(start, end, index);
            }
        }
        onGroupEnter(start) {
            if (this._options.onGroupEnter) {
                this._options.onGroupEnter(start);
            }
        }
        onGroupLeave(start, end) {
            if (this._options.onGroupLeave) {
                this._options.onGroupLeave(start, end);
            }
        }
        onCapturingGroupEnter(start, name) {
            if (this._options.onCapturingGroupEnter) {
                this._options.onCapturingGroupEnter(start, name);
            }
        }
        onCapturingGroupLeave(start, end, name) {
            if (this._options.onCapturingGroupLeave) {
                this._options.onCapturingGroupLeave(start, end, name);
            }
        }
        onQuantifier(start, end, min, max, greedy) {
            if (this._options.onQuantifier) {
                this._options.onQuantifier(start, end, min, max, greedy);
            }
        }
        onLookaroundAssertionEnter(start, kind, negate) {
            if (this._options.onLookaroundAssertionEnter) {
                this._options.onLookaroundAssertionEnter(start, kind, negate);
            }
        }
        onLookaroundAssertionLeave(start, end, kind, negate) {
            if (this._options.onLookaroundAssertionLeave) {
                this._options.onLookaroundAssertionLeave(start, end, kind, negate);
            }
        }
        onEdgeAssertion(start, end, kind) {
            if (this._options.onEdgeAssertion) {
                this._options.onEdgeAssertion(start, end, kind);
            }
        }
        onWordBoundaryAssertion(start, end, kind, negate) {
            if (this._options.onWordBoundaryAssertion) {
                this._options.onWordBoundaryAssertion(start, end, kind, negate);
            }
        }
        onAnyCharacterSet(start, end, kind) {
            if (this._options.onAnyCharacterSet) {
                this._options.onAnyCharacterSet(start, end, kind);
            }
        }
        onEscapeCharacterSet(start, end, kind, negate) {
            if (this._options.onEscapeCharacterSet) {
                this._options.onEscapeCharacterSet(start, end, kind, negate);
            }
        }
        onUnicodePropertyCharacterSet(start, end, kind, key, value, negate) {
            if (this._options.onUnicodePropertyCharacterSet) {
                this._options.onUnicodePropertyCharacterSet(start, end, kind, key, value, negate);
            }
        }
        onCharacter(start, end, value) {
            if (this._options.onCharacter) {
                this._options.onCharacter(start, end, value);
            }
        }
        onBackreference(start, end, ref) {
            if (this._options.onBackreference) {
                this._options.onBackreference(start, end, ref);
            }
        }
        onCharacterClassEnter(start, negate) {
            if (this._options.onCharacterClassEnter) {
                this._options.onCharacterClassEnter(start, negate);
            }
        }
        onCharacterClassLeave(start, end, negate) {
            if (this._options.onCharacterClassLeave) {
                this._options.onCharacterClassLeave(start, end, negate);
            }
        }
        onCharacterClassRange(start, end, min, max) {
            if (this._options.onCharacterClassRange) {
                this._options.onCharacterClassRange(start, end, min, max);
            }
        }
        get source() {
            return this._reader.source;
        }
        get index() {
            return this._reader.index;
        }
        get currentCodePoint() {
            return this._reader.currentCodePoint;
        }
        get nextCodePoint() {
            return this._reader.nextCodePoint;
        }
        get nextCodePoint2() {
            return this._reader.nextCodePoint2;
        }
        get nextCodePoint3() {
            return this._reader.nextCodePoint3;
        }
        reset(source, start, end) {
            this._reader.reset(source, start, end, this._uFlag);
        }
        rewind(index) {
            this._reader.rewind(index);
        }
        advance() {
            this._reader.advance();
        }
        eat(cp) {
            return this._reader.eat(cp);
        }
        eat2(cp1, cp2) {
            return this._reader.eat2(cp1, cp2);
        }
        eat3(cp1, cp2, cp3) {
            return this._reader.eat3(cp1, cp2, cp3);
        }
        raise(message) {
            throw new RegExpSyntaxError(this.source, this._uFlag, this.index, message);
        }
        eatRegExpBody() {
            const start = this.index;
            let inClass = false;
            let escaped = false;
            for (;;) {
                const cp = this.currentCodePoint;
                if (cp === -1 || isLineTerminator(cp)) {
                    const kind = inClass ? "character class" : "regular expression";
                    this.raise(`Unterminated ${kind}`);
                }
                if (escaped) {
                    escaped = false;
                }
                else if (cp === REVERSE_SOLIDUS) {
                    escaped = true;
                }
                else if (cp === LEFT_SQUARE_BRACKET) {
                    inClass = true;
                }
                else if (cp === RIGHT_SQUARE_BRACKET) {
                    inClass = false;
                }
                else if ((cp === SOLIDUS && !inClass) ||
                    (cp === ASTERISK && this.index === start)) {
                    break;
                }
                this.advance();
            }
            return this.index !== start;
        }
        consumePattern() {
            const start = this.index;
            this._numCapturingParens = this.countCapturingParens();
            this._groupNames.clear();
            this._backreferenceNames.clear();
            this.onPatternEnter(start);
            this.consumeDisjunction();
            const cp = this.currentCodePoint;
            if (this.currentCodePoint !== -1) {
                if (cp === RIGHT_PARENTHESIS) {
                    this.raise("Unmatched ')'");
                }
                if (cp === REVERSE_SOLIDUS) {
                    this.raise("\\ at end of pattern");
                }
                if (cp === RIGHT_SQUARE_BRACKET || cp === RIGHT_CURLY_BRACKET) {
                    this.raise("Lone quantifier brackets");
                }
                const c = String.fromCodePoint(cp);
                this.raise(`Unexpected character '${c}'`);
            }
            for (const name of this._backreferenceNames) {
                if (!this._groupNames.has(name)) {
                    this.raise("Invalid named capture referenced");
                }
            }
            this.onPatternLeave(start, this.index);
        }
        countCapturingParens() {
            const start = this.index;
            let inClass = false;
            let escaped = false;
            let count = 0;
            let cp = 0;
            while ((cp = this.currentCodePoint) !== -1) {
                if (escaped) {
                    escaped = false;
                }
                else if (cp === REVERSE_SOLIDUS) {
                    escaped = true;
                }
                else if (cp === LEFT_SQUARE_BRACKET) {
                    inClass = true;
                }
                else if (cp === RIGHT_SQUARE_BRACKET) {
                    inClass = false;
                }
                else if (cp === LEFT_PARENTHESIS &&
                    !inClass &&
                    (this.nextCodePoint !== QUESTION_MARK ||
                        (this.nextCodePoint2 === LESS_THAN_SIGN &&
                            this.nextCodePoint3 !== EQUALS_SIGN &&
                            this.nextCodePoint3 !== EXCLAMATION_MARK))) {
                    count += 1;
                }
                this.advance();
            }
            this.rewind(start);
            return count;
        }
        consumeDisjunction() {
            const start = this.index;
            let i = 0;
            this.onDisjunctionEnter(start);
            do {
                this.consumeAlternative(i++);
            } while (this.eat(VERTICAL_LINE));
            if (this.consumeQuantifier(true)) {
                this.raise("Nothing to repeat");
            }
            if (this.eat(LEFT_CURLY_BRACKET)) {
                this.raise("Lone quantifier brackets");
            }
            this.onDisjunctionLeave(start, this.index);
        }
        consumeAlternative(i) {
            const start = this.index;
            this.onAlternativeEnter(start, i);
            while (this.currentCodePoint !== -1 && this.consumeTerm()) {
            }
            this.onAlternativeLeave(start, this.index, i);
        }
        consumeTerm() {
            if (this._uFlag || this.strict) {
                return (this.consumeAssertion() ||
                    (this.consumeAtom() && this.consumeOptionalQuantifier()));
            }
            return ((this.consumeAssertion() &&
                (!this._lastAssertionIsQuantifiable ||
                    this.consumeOptionalQuantifier())) ||
                (this.consumeExtendedAtom() && this.consumeOptionalQuantifier()));
        }
        consumeOptionalQuantifier() {
            this.consumeQuantifier();
            return true;
        }
        consumeAssertion() {
            const start = this.index;
            this._lastAssertionIsQuantifiable = false;
            if (this.eat(CIRCUMFLEX_ACCENT)) {
                this.onEdgeAssertion(start, this.index, "start");
                return true;
            }
            if (this.eat(DOLLAR_SIGN)) {
                this.onEdgeAssertion(start, this.index, "end");
                return true;
            }
            if (this.eat2(REVERSE_SOLIDUS, LATIN_CAPITAL_LETTER_B)) {
                this.onWordBoundaryAssertion(start, this.index, "word", true);
                return true;
            }
            if (this.eat2(REVERSE_SOLIDUS, LATIN_SMALL_LETTER_B)) {
                this.onWordBoundaryAssertion(start, this.index, "word", false);
                return true;
            }
            if (this.eat2(LEFT_PARENTHESIS, QUESTION_MARK)) {
                const lookbehind = this.ecmaVersion >= 2018 && this.eat(LESS_THAN_SIGN);
                let negate = false;
                if (this.eat(EQUALS_SIGN) ||
                    (negate = this.eat(EXCLAMATION_MARK))) {
                    const kind = lookbehind ? "lookbehind" : "lookahead";
                    this.onLookaroundAssertionEnter(start, kind, negate);
                    this.consumeDisjunction();
                    if (!this.eat(RIGHT_PARENTHESIS)) {
                        this.raise("Unterminated group");
                    }
                    this._lastAssertionIsQuantifiable = !lookbehind && !this.strict;
                    this.onLookaroundAssertionLeave(start, this.index, kind, negate);
                    return true;
                }
                this.rewind(start);
            }
            return false;
        }
        consumeQuantifier(noConsume = false) {
            const start = this.index;
            let min = 0;
            let max = 0;
            let greedy = false;
            if (this.eat(ASTERISK)) {
                min = 0;
                max = Number.POSITIVE_INFINITY;
            }
            else if (this.eat(PLUS_SIGN)) {
                min = 1;
                max = Number.POSITIVE_INFINITY;
            }
            else if (this.eat(QUESTION_MARK)) {
                min = 0;
                max = 1;
            }
            else if (this.eatBracedQuantifier(noConsume)) {
                min = this._lastMinValue;
                max = this._lastMaxValue;
            }
            else {
                return false;
            }
            greedy = !this.eat(QUESTION_MARK);
            if (!noConsume) {
                this.onQuantifier(start, this.index, min, max, greedy);
            }
            return true;
        }
        eatBracedQuantifier(noError) {
            const start = this.index;
            if (this.eat(LEFT_CURLY_BRACKET)) {
                this._lastMinValue = 0;
                this._lastMaxValue = Number.POSITIVE_INFINITY;
                if (this.eatDecimalDigits()) {
                    this._lastMinValue = this._lastMaxValue = this._lastIntValue;
                    if (this.eat(COMMA)) {
                        this._lastMaxValue = this.eatDecimalDigits()
                            ? this._lastIntValue
                            : Number.POSITIVE_INFINITY;
                    }
                    if (this.eat(RIGHT_CURLY_BRACKET)) {
                        if (!noError && this._lastMaxValue < this._lastMinValue) {
                            this.raise("numbers out of order in {} quantifier");
                        }
                        return true;
                    }
                }
                if (!noError && (this._uFlag || this.strict)) {
                    this.raise("Incomplete quantifier");
                }
                this.rewind(start);
            }
            return false;
        }
        consumeAtom() {
            return (this.consumePatternCharacter() ||
                this.consumeDot() ||
                this.consumeReverseSolidusAtomEscape() ||
                this.consumeCharacterClass() ||
                this.consumeUncapturingGroup() ||
                this.consumeCapturingGroup());
        }
        consumeDot() {
            if (this.eat(FULL_STOP)) {
                this.onAnyCharacterSet(this.index - 1, this.index, "any");
                return true;
            }
            return false;
        }
        consumeReverseSolidusAtomEscape() {
            const start = this.index;
            if (this.eat(REVERSE_SOLIDUS)) {
                if (this.consumeAtomEscape()) {
                    return true;
                }
                this.rewind(start);
            }
            return false;
        }
        consumeUncapturingGroup() {
            const start = this.index;
            if (this.eat3(LEFT_PARENTHESIS, QUESTION_MARK, COLON)) {
                this.onGroupEnter(start);
                this.consumeDisjunction();
                if (!this.eat(RIGHT_PARENTHESIS)) {
                    this.raise("Unterminated group");
                }
                this.onGroupLeave(start, this.index);
                return true;
            }
            return false;
        }
        consumeCapturingGroup() {
            const start = this.index;
            if (this.eat(LEFT_PARENTHESIS)) {
                let name = null;
                if (this.ecmaVersion >= 2018) {
                    if (this.consumeGroupSpecifier()) {
                        name = this._lastStrValue;
                    }
                }
                else if (this.currentCodePoint === QUESTION_MARK) {
                    this.raise("Invalid group");
                }
                this.onCapturingGroupEnter(start, name);
                this.consumeDisjunction();
                if (!this.eat(RIGHT_PARENTHESIS)) {
                    this.raise("Unterminated group");
                }
                this.onCapturingGroupLeave(start, this.index, name);
                return true;
            }
            return false;
        }
        consumeExtendedAtom() {
            return (this.consumeDot() ||
                this.consumeReverseSolidusAtomEscape() ||
                this.consumeReverseSolidusFollowedByC() ||
                this.consumeCharacterClass() ||
                this.consumeUncapturingGroup() ||
                this.consumeCapturingGroup() ||
                this.consumeInvalidBracedQuantifier() ||
                this.consumeExtendedPatternCharacter());
        }
        consumeReverseSolidusFollowedByC() {
            const start = this.index;
            if (this.currentCodePoint === REVERSE_SOLIDUS &&
                this.nextCodePoint === LATIN_SMALL_LETTER_C) {
                this._lastIntValue = this.currentCodePoint;
                this.advance();
                this.onCharacter(start, this.index, REVERSE_SOLIDUS);
                return true;
            }
            return false;
        }
        consumeInvalidBracedQuantifier() {
            if (this.eatBracedQuantifier(true)) {
                this.raise("Nothing to repeat");
            }
            return false;
        }
        consumePatternCharacter() {
            const start = this.index;
            const cp = this.currentCodePoint;
            if (cp !== -1 && !isSyntaxCharacter(cp)) {
                this.advance();
                this.onCharacter(start, this.index, cp);
                return true;
            }
            return false;
        }
        consumeExtendedPatternCharacter() {
            const start = this.index;
            const cp = this.currentCodePoint;
            if (cp !== -1 &&
                cp !== CIRCUMFLEX_ACCENT &&
                cp !== DOLLAR_SIGN &&
                cp !== REVERSE_SOLIDUS &&
                cp !== FULL_STOP &&
                cp !== ASTERISK &&
                cp !== PLUS_SIGN &&
                cp !== QUESTION_MARK &&
                cp !== LEFT_PARENTHESIS &&
                cp !== RIGHT_PARENTHESIS &&
                cp !== LEFT_SQUARE_BRACKET &&
                cp !== VERTICAL_LINE) {
                this.advance();
                this.onCharacter(start, this.index, cp);
                return true;
            }
            return false;
        }
        consumeGroupSpecifier() {
            if (this.eat(QUESTION_MARK)) {
                if (this.eatGroupName()) {
                    if (!this._groupNames.has(this._lastStrValue)) {
                        this._groupNames.add(this._lastStrValue);
                        return true;
                    }
                    this.raise("Duplicate capture group name");
                }
                this.raise("Invalid group");
            }
            return false;
        }
        consumeAtomEscape() {
            if (this.consumeBackreference() ||
                this.consumeCharacterClassEscape() ||
                this.consumeCharacterEscape() ||
                (this._nFlag && this.consumeKGroupName())) {
                return true;
            }
            if (this.strict || this._uFlag) {
                this.raise("Invalid escape");
            }
            return false;
        }
        consumeBackreference() {
            const start = this.index;
            if (this.eatDecimalEscape()) {
                const n = this._lastIntValue;
                if (n <= this._numCapturingParens) {
                    this.onBackreference(start - 1, this.index, n);
                    return true;
                }
                if (this.strict || this._uFlag) {
                    this.raise("Invalid escape");
                }
                this.rewind(start);
            }
            return false;
        }
        consumeCharacterClassEscape() {
            const start = this.index;
            if (this.eat(LATIN_SMALL_LETTER_D)) {
                this._lastIntValue = -1;
                this.onEscapeCharacterSet(start - 1, this.index, "digit", false);
                return true;
            }
            if (this.eat(LATIN_CAPITAL_LETTER_D)) {
                this._lastIntValue = -1;
                this.onEscapeCharacterSet(start - 1, this.index, "digit", true);
                return true;
            }
            if (this.eat(LATIN_SMALL_LETTER_S)) {
                this._lastIntValue = -1;
                this.onEscapeCharacterSet(start - 1, this.index, "space", false);
                return true;
            }
            if (this.eat(LATIN_CAPITAL_LETTER_S)) {
                this._lastIntValue = -1;
                this.onEscapeCharacterSet(start - 1, this.index, "space", true);
                return true;
            }
            if (this.eat(LATIN_SMALL_LETTER_W)) {
                this._lastIntValue = -1;
                this.onEscapeCharacterSet(start - 1, this.index, "word", false);
                return true;
            }
            if (this.eat(LATIN_CAPITAL_LETTER_W)) {
                this._lastIntValue = -1;
                this.onEscapeCharacterSet(start - 1, this.index, "word", true);
                return true;
            }
            let negate = false;
            if (this._uFlag &&
                this.ecmaVersion >= 2018 &&
                (this.eat(LATIN_SMALL_LETTER_P) ||
                    (negate = this.eat(LATIN_CAPITAL_LETTER_P)))) {
                this._lastIntValue = -1;
                if (this.eat(LEFT_CURLY_BRACKET) &&
                    this.eatUnicodePropertyValueExpression() &&
                    this.eat(RIGHT_CURLY_BRACKET)) {
                    this.onUnicodePropertyCharacterSet(start - 1, this.index, "property", this._lastKeyValue, this._lastValValue || null, negate);
                    return true;
                }
                this.raise("Invalid property name");
            }
            return false;
        }
        consumeCharacterEscape() {
            const start = this.index;
            if (this.eatControlEscape() ||
                this.eatCControlLetter() ||
                this.eatZero() ||
                this.eatHexEscapeSequence() ||
                this.eatRegExpUnicodeEscapeSequence() ||
                (!this.strict &&
                    !this._uFlag &&
                    this.eatLegacyOctalEscapeSequence()) ||
                this.eatIdentityEscape()) {
                this.onCharacter(start - 1, this.index, this._lastIntValue);
                return true;
            }
            return false;
        }
        consumeKGroupName() {
            const start = this.index;
            if (this.eat(LATIN_SMALL_LETTER_K)) {
                if (this.eatGroupName()) {
                    const groupName = this._lastStrValue;
                    this._backreferenceNames.add(groupName);
                    this.onBackreference(start - 1, this.index, groupName);
                    return true;
                }
                this.raise("Invalid named reference");
            }
            return false;
        }
        consumeCharacterClass() {
            const start = this.index;
            if (this.eat(LEFT_SQUARE_BRACKET)) {
                const negate = this.eat(CIRCUMFLEX_ACCENT);
                this.onCharacterClassEnter(start, negate);
                this.consumeClassRanges();
                if (!this.eat(RIGHT_SQUARE_BRACKET)) {
                    this.raise("Unterminated character class");
                }
                this.onCharacterClassLeave(start, this.index, negate);
                return true;
            }
            return false;
        }
        consumeClassRanges() {
            const strict = this.strict || this._uFlag;
            for (;;) {
                const rangeStart = this.index;
                if (!this.consumeClassAtom()) {
                    break;
                }
                const min = this._lastIntValue;
                if (!this.eat(HYPHEN_MINUS)) {
                    continue;
                }
                this.onCharacter(this.index - 1, this.index, HYPHEN_MINUS);
                if (!this.consumeClassAtom()) {
                    break;
                }
                const max = this._lastIntValue;
                if (min === -1 || max === -1) {
                    if (strict) {
                        this.raise("Invalid character class");
                    }
                    continue;
                }
                if (min > max) {
                    this.raise("Range out of order in character class");
                }
                this.onCharacterClassRange(rangeStart, this.index, min, max);
            }
        }
        consumeClassAtom() {
            const start = this.index;
            const cp = this.currentCodePoint;
            if (cp !== -1 &&
                cp !== REVERSE_SOLIDUS &&
                cp !== RIGHT_SQUARE_BRACKET) {
                this.advance();
                this._lastIntValue = cp;
                this.onCharacter(start, this.index, this._lastIntValue);
                return true;
            }
            if (this.eat(REVERSE_SOLIDUS)) {
                if (this.consumeClassEscape()) {
                    return true;
                }
                if (!this.strict &&
                    this.currentCodePoint === LATIN_SMALL_LETTER_C) {
                    this._lastIntValue = REVERSE_SOLIDUS;
                    this.onCharacter(start, this.index, this._lastIntValue);
                    return true;
                }
                if (this.strict || this._uFlag) {
                    this.raise("Invalid escape");
                }
                this.rewind(start);
            }
            return false;
        }
        consumeClassEscape() {
            const start = this.index;
            if (this.eat(LATIN_SMALL_LETTER_B)) {
                this._lastIntValue = BACKSPACE;
                this.onCharacter(start - 1, this.index, this._lastIntValue);
                return true;
            }
            if (this._uFlag && this.eat(HYPHEN_MINUS)) {
                this._lastIntValue = HYPHEN_MINUS;
                this.onCharacter(start - 1, this.index, this._lastIntValue);
                return true;
            }
            let cp = 0;
            if (!this.strict &&
                !this._uFlag &&
                this.currentCodePoint === LATIN_SMALL_LETTER_C &&
                (isDecimalDigit((cp = this.nextCodePoint)) || cp === LOW_LINE)) {
                this.advance();
                this.advance();
                this._lastIntValue = cp % 0x20;
                this.onCharacter(start - 1, this.index, this._lastIntValue);
                return true;
            }
            return (this.consumeCharacterClassEscape() || this.consumeCharacterEscape());
        }
        eatGroupName() {
            if (this.eat(LESS_THAN_SIGN)) {
                if (this.eatRegExpIdentifierName() && this.eat(GREATER_THAN_SIGN)) {
                    return true;
                }
                this.raise("Invalid capture group name");
            }
            return false;
        }
        eatRegExpIdentifierName() {
            if (this.eatRegExpIdentifierStart()) {
                this._lastStrValue = String.fromCodePoint(this._lastIntValue);
                while (this.eatRegExpIdentifierPart()) {
                    this._lastStrValue += String.fromCodePoint(this._lastIntValue);
                }
                return true;
            }
            return false;
        }
        eatRegExpIdentifierStart() {
            const start = this.index;
            const forceUFlag = !this._uFlag && this.ecmaVersion >= 2020;
            let cp = this.currentCodePoint;
            this.advance();
            if (cp === REVERSE_SOLIDUS &&
                this.eatRegExpUnicodeEscapeSequence(forceUFlag)) {
                cp = this._lastIntValue;
            }
            else if (forceUFlag &&
                isLeadSurrogate(cp) &&
                isTrailSurrogate(this.currentCodePoint)) {
                cp = combineSurrogatePair(cp, this.currentCodePoint);
                this.advance();
            }
            if (isRegExpIdentifierStart(cp)) {
                this._lastIntValue = cp;
                return true;
            }
            if (this.index !== start) {
                this.rewind(start);
            }
            return false;
        }
        eatRegExpIdentifierPart() {
            const start = this.index;
            const forceUFlag = !this._uFlag && this.ecmaVersion >= 2020;
            let cp = this.currentCodePoint;
            this.advance();
            if (cp === REVERSE_SOLIDUS &&
                this.eatRegExpUnicodeEscapeSequence(forceUFlag)) {
                cp = this._lastIntValue;
            }
            else if (forceUFlag &&
                isLeadSurrogate(cp) &&
                isTrailSurrogate(this.currentCodePoint)) {
                cp = combineSurrogatePair(cp, this.currentCodePoint);
                this.advance();
            }
            if (isRegExpIdentifierPart(cp)) {
                this._lastIntValue = cp;
                return true;
            }
            if (this.index !== start) {
                this.rewind(start);
            }
            return false;
        }
        eatCControlLetter() {
            const start = this.index;
            if (this.eat(LATIN_SMALL_LETTER_C)) {
                if (this.eatControlLetter()) {
                    return true;
                }
                this.rewind(start);
            }
            return false;
        }
        eatZero() {
            if (this.currentCodePoint === DIGIT_ZERO &&
                !isDecimalDigit(this.nextCodePoint)) {
                this._lastIntValue = 0;
                this.advance();
                return true;
            }
            return false;
        }
        eatControlEscape() {
            if (this.eat(LATIN_SMALL_LETTER_F)) {
                this._lastIntValue = FORM_FEED;
                return true;
            }
            if (this.eat(LATIN_SMALL_LETTER_N)) {
                this._lastIntValue = LINE_FEED;
                return true;
            }
            if (this.eat(LATIN_SMALL_LETTER_R)) {
                this._lastIntValue = CARRIAGE_RETURN;
                return true;
            }
            if (this.eat(LATIN_SMALL_LETTER_T)) {
                this._lastIntValue = CHARACTER_TABULATION;
                return true;
            }
            if (this.eat(LATIN_SMALL_LETTER_V)) {
                this._lastIntValue = LINE_TABULATION;
                return true;
            }
            return false;
        }
        eatControlLetter() {
            const cp = this.currentCodePoint;
            if (isLatinLetter(cp)) {
                this.advance();
                this._lastIntValue = cp % 0x20;
                return true;
            }
            return false;
        }
        eatRegExpUnicodeEscapeSequence(forceUFlag = false) {
            const start = this.index;
            const uFlag = forceUFlag || this._uFlag;
            if (this.eat(LATIN_SMALL_LETTER_U)) {
                if ((uFlag && this.eatRegExpUnicodeSurrogatePairEscape()) ||
                    this.eatFixedHexDigits(4) ||
                    (uFlag && this.eatRegExpUnicodeCodePointEscape())) {
                    return true;
                }
                if (this.strict || uFlag) {
                    this.raise("Invalid unicode escape");
                }
                this.rewind(start);
            }
            return false;
        }
        eatRegExpUnicodeSurrogatePairEscape() {
            const start = this.index;
            if (this.eatFixedHexDigits(4)) {
                const lead = this._lastIntValue;
                if (isLeadSurrogate(lead) &&
                    this.eat(REVERSE_SOLIDUS) &&
                    this.eat(LATIN_SMALL_LETTER_U) &&
                    this.eatFixedHexDigits(4)) {
                    const trail = this._lastIntValue;
                    if (isTrailSurrogate(trail)) {
                        this._lastIntValue = combineSurrogatePair(lead, trail);
                        return true;
                    }
                }
                this.rewind(start);
            }
            return false;
        }
        eatRegExpUnicodeCodePointEscape() {
            const start = this.index;
            if (this.eat(LEFT_CURLY_BRACKET) &&
                this.eatHexDigits() &&
                this.eat(RIGHT_CURLY_BRACKET) &&
                isValidUnicode(this._lastIntValue)) {
                return true;
            }
            this.rewind(start);
            return false;
        }
        eatIdentityEscape() {
            const cp = this.currentCodePoint;
            if (this.isValidIdentityEscape(cp)) {
                this._lastIntValue = cp;
                this.advance();
                return true;
            }
            return false;
        }
        isValidIdentityEscape(cp) {
            if (cp === -1) {
                return false;
            }
            if (this._uFlag) {
                return isSyntaxCharacter(cp) || cp === SOLIDUS;
            }
            if (this.strict) {
                return !isIdContinue(cp);
            }
            if (this._nFlag) {
                return !(cp === LATIN_SMALL_LETTER_C || cp === LATIN_SMALL_LETTER_K);
            }
            return cp !== LATIN_SMALL_LETTER_C;
        }
        eatDecimalEscape() {
            this._lastIntValue = 0;
            let cp = this.currentCodePoint;
            if (cp >= DIGIT_ONE && cp <= DIGIT_NINE) {
                do {
                    this._lastIntValue = 10 * this._lastIntValue + (cp - DIGIT_ZERO);
                    this.advance();
                } while ((cp = this.currentCodePoint) >= DIGIT_ZERO &&
                    cp <= DIGIT_NINE);
                return true;
            }
            return false;
        }
        eatUnicodePropertyValueExpression() {
            const start = this.index;
            if (this.eatUnicodePropertyName() && this.eat(EQUALS_SIGN)) {
                this._lastKeyValue = this._lastStrValue;
                if (this.eatUnicodePropertyValue()) {
                    this._lastValValue = this._lastStrValue;
                    if (isValidUnicodeProperty(this.ecmaVersion, this._lastKeyValue, this._lastValValue)) {
                        return true;
                    }
                    this.raise("Invalid property name");
                }
            }
            this.rewind(start);
            if (this.eatLoneUnicodePropertyNameOrValue()) {
                const nameOrValue = this._lastStrValue;
                if (isValidUnicodeProperty(this.ecmaVersion, "General_Category", nameOrValue)) {
                    this._lastKeyValue = "General_Category";
                    this._lastValValue = nameOrValue;
                    return true;
                }
                if (isValidLoneUnicodeProperty(this.ecmaVersion, nameOrValue)) {
                    this._lastKeyValue = nameOrValue;
                    this._lastValValue = "";
                    return true;
                }
                this.raise("Invalid property name");
            }
            return false;
        }
        eatUnicodePropertyName() {
            this._lastStrValue = "";
            while (isUnicodePropertyNameCharacter(this.currentCodePoint)) {
                this._lastStrValue += String.fromCodePoint(this.currentCodePoint);
                this.advance();
            }
            return this._lastStrValue !== "";
        }
        eatUnicodePropertyValue() {
            this._lastStrValue = "";
            while (isUnicodePropertyValueCharacter(this.currentCodePoint)) {
                this._lastStrValue += String.fromCodePoint(this.currentCodePoint);
                this.advance();
            }
            return this._lastStrValue !== "";
        }
        eatLoneUnicodePropertyNameOrValue() {
            return this.eatUnicodePropertyValue();
        }
        eatHexEscapeSequence() {
            const start = this.index;
            if (this.eat(LATIN_SMALL_LETTER_X)) {
                if (this.eatFixedHexDigits(2)) {
                    return true;
                }
                if (this._uFlag || this.strict) {
                    this.raise("Invalid escape");
                }
                this.rewind(start);
            }
            return false;
        }
        eatDecimalDigits() {
            const start = this.index;
            this._lastIntValue = 0;
            while (isDecimalDigit(this.currentCodePoint)) {
                this._lastIntValue =
                    10 * this._lastIntValue + digitToInt(this.currentCodePoint);
                this.advance();
            }
            return this.index !== start;
        }
        eatHexDigits() {
            const start = this.index;
            this._lastIntValue = 0;
            while (isHexDigit(this.currentCodePoint)) {
                this._lastIntValue =
                    16 * this._lastIntValue + digitToInt(this.currentCodePoint);
                this.advance();
            }
            return this.index !== start;
        }
        eatLegacyOctalEscapeSequence() {
            if (this.eatOctalDigit()) {
                const n1 = this._lastIntValue;
                if (this.eatOctalDigit()) {
                    const n2 = this._lastIntValue;
                    if (n1 <= 3 && this.eatOctalDigit()) {
                        this._lastIntValue = n1 * 64 + n2 * 8 + this._lastIntValue;
                    }
                    else {
                        this._lastIntValue = n1 * 8 + n2;
                    }
                }
                else {
                    this._lastIntValue = n1;
                }
                return true;
            }
            return false;
        }
        eatOctalDigit() {
            const cp = this.currentCodePoint;
            if (isOctalDigit(cp)) {
                this.advance();
                this._lastIntValue = cp - DIGIT_ZERO;
                return true;
            }
            this._lastIntValue = 0;
            return false;
        }
        eatFixedHexDigits(length) {
            const start = this.index;
            this._lastIntValue = 0;
            for (let i = 0; i < length; ++i) {
                const cp = this.currentCodePoint;
                if (!isHexDigit(cp)) {
                    this.rewind(start);
                    return false;
                }
                this._lastIntValue = 16 * this._lastIntValue + digitToInt(cp);
                this.advance();
            }
            return true;
        }
    }
    const DUMMY_PATTERN = {};
    const DUMMY_FLAGS = {};
    const DUMMY_CAPTURING_GROUP = {};
    class RegExpParserState {
        constructor(options) {
            var _a;
            this._node = DUMMY_PATTERN;
            this._flags = DUMMY_FLAGS;
            this._backreferences = [];
            this._capturingGroups = [];
            this.source = "";
            this.strict = Boolean(options === null || options === void 0 ? void 0 : options.strict);
            this.ecmaVersion = (_a = options === null || options === void 0 ? void 0 : options.ecmaVersion) !== null && _a !== void 0 ? _a : 2022;
        }
        get pattern() {
            if (this._node.type !== "Pattern") {
                throw new Error("UnknownError");
            }
            return this._node;
        }
        get flags() {
            if (this._flags.type !== "Flags") {
                throw new Error("UnknownError");
            }
            return this._flags;
        }
        onRegExpFlags(start, end, { global, ignoreCase, multiline, unicode, sticky, dotAll, hasIndices, }) {
            this._flags = {
                type: "Flags",
                parent: null,
                start,
                end,
                raw: this.source.slice(start, end),
                global,
                ignoreCase,
                multiline,
                unicode,
                sticky,
                dotAll,
                hasIndices,
            };
        }
        onPatternEnter(start) {
            this._node = {
                type: "Pattern",
                parent: null,
                start,
                end: start,
                raw: "",
                alternatives: [],
            };
            this._backreferences.length = 0;
            this._capturingGroups.length = 0;
        }
        onPatternLeave(start, end) {
            this._node.end = end;
            this._node.raw = this.source.slice(start, end);
            for (const reference of this._backreferences) {
                const ref = reference.ref;
                const group = typeof ref === "number"
                    ? this._capturingGroups[ref - 1]
                    : this._capturingGroups.find((g) => g.name === ref);
                reference.resolved = group;
                group.references.push(reference);
            }
        }
        onAlternativeEnter(start) {
            const parent = this._node;
            if (parent.type !== "Assertion" &&
                parent.type !== "CapturingGroup" &&
                parent.type !== "Group" &&
                parent.type !== "Pattern") {
                throw new Error("UnknownError");
            }
            this._node = {
                type: "Alternative",
                parent,
                start,
                end: start,
                raw: "",
                elements: [],
            };
            parent.alternatives.push(this._node);
        }
        onAlternativeLeave(start, end) {
            const node = this._node;
            if (node.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            node.end = end;
            node.raw = this.source.slice(start, end);
            this._node = node.parent;
        }
        onGroupEnter(start) {
            const parent = this._node;
            if (parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            this._node = {
                type: "Group",
                parent,
                start,
                end: start,
                raw: "",
                alternatives: [],
            };
            parent.elements.push(this._node);
        }
        onGroupLeave(start, end) {
            const node = this._node;
            if (node.type !== "Group" || node.parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            node.end = end;
            node.raw = this.source.slice(start, end);
            this._node = node.parent;
        }
        onCapturingGroupEnter(start, name) {
            const parent = this._node;
            if (parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            this._node = {
                type: "CapturingGroup",
                parent,
                start,
                end: start,
                raw: "",
                name,
                alternatives: [],
                references: [],
            };
            parent.elements.push(this._node);
            this._capturingGroups.push(this._node);
        }
        onCapturingGroupLeave(start, end) {
            const node = this._node;
            if (node.type !== "CapturingGroup" ||
                node.parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            node.end = end;
            node.raw = this.source.slice(start, end);
            this._node = node.parent;
        }
        onQuantifier(start, end, min, max, greedy) {
            const parent = this._node;
            if (parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            const element = parent.elements.pop();
            if (element == null ||
                element.type === "Quantifier" ||
                (element.type === "Assertion" && element.kind !== "lookahead")) {
                throw new Error("UnknownError");
            }
            const node = {
                type: "Quantifier",
                parent,
                start: element.start,
                end,
                raw: this.source.slice(element.start, end),
                min,
                max,
                greedy,
                element,
            };
            parent.elements.push(node);
            element.parent = node;
        }
        onLookaroundAssertionEnter(start, kind, negate) {
            const parent = this._node;
            if (parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            const node = (this._node = {
                type: "Assertion",
                parent,
                start,
                end: start,
                raw: "",
                kind,
                negate,
                alternatives: [],
            });
            parent.elements.push(node);
        }
        onLookaroundAssertionLeave(start, end) {
            const node = this._node;
            if (node.type !== "Assertion" || node.parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            node.end = end;
            node.raw = this.source.slice(start, end);
            this._node = node.parent;
        }
        onEdgeAssertion(start, end, kind) {
            const parent = this._node;
            if (parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            parent.elements.push({
                type: "Assertion",
                parent,
                start,
                end,
                raw: this.source.slice(start, end),
                kind,
            });
        }
        onWordBoundaryAssertion(start, end, kind, negate) {
            const parent = this._node;
            if (parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            parent.elements.push({
                type: "Assertion",
                parent,
                start,
                end,
                raw: this.source.slice(start, end),
                kind,
                negate,
            });
        }
        onAnyCharacterSet(start, end, kind) {
            const parent = this._node;
            if (parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            parent.elements.push({
                type: "CharacterSet",
                parent,
                start,
                end,
                raw: this.source.slice(start, end),
                kind,
            });
        }
        onEscapeCharacterSet(start, end, kind, negate) {
            const parent = this._node;
            if (parent.type !== "Alternative" && parent.type !== "CharacterClass") {
                throw new Error("UnknownError");
            }
            parent.elements.push({
                type: "CharacterSet",
                parent,
                start,
                end,
                raw: this.source.slice(start, end),
                kind,
                negate,
            });
        }
        onUnicodePropertyCharacterSet(start, end, kind, key, value, negate) {
            const parent = this._node;
            if (parent.type !== "Alternative" && parent.type !== "CharacterClass") {
                throw new Error("UnknownError");
            }
            parent.elements.push({
                type: "CharacterSet",
                parent,
                start,
                end,
                raw: this.source.slice(start, end),
                kind,
                key,
                value,
                negate,
            });
        }
        onCharacter(start, end, value) {
            const parent = this._node;
            if (parent.type !== "Alternative" && parent.type !== "CharacterClass") {
                throw new Error("UnknownError");
            }
            parent.elements.push({
                type: "Character",
                parent,
                start,
                end,
                raw: this.source.slice(start, end),
                value,
            });
        }
        onBackreference(start, end, ref) {
            const parent = this._node;
            if (parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            const node = {
                type: "Backreference",
                parent,
                start,
                end,
                raw: this.source.slice(start, end),
                ref,
                resolved: DUMMY_CAPTURING_GROUP,
            };
            parent.elements.push(node);
            this._backreferences.push(node);
        }
        onCharacterClassEnter(start, negate) {
            const parent = this._node;
            if (parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            this._node = {
                type: "CharacterClass",
                parent,
                start,
                end: start,
                raw: "",
                negate,
                elements: [],
            };
            parent.elements.push(this._node);
        }
        onCharacterClassLeave(start, end) {
            const node = this._node;
            if (node.type !== "CharacterClass" ||
                node.parent.type !== "Alternative") {
                throw new Error("UnknownError");
            }
            node.end = end;
            node.raw = this.source.slice(start, end);
            this._node = node.parent;
        }
        onCharacterClassRange(start, end) {
            const parent = this._node;
            if (parent.type !== "CharacterClass") {
                throw new Error("UnknownError");
            }
            const elements = parent.elements;
            const max = elements.pop();
            const hyphen = elements.pop();
            const min = elements.pop();
            if (!min ||
                !max ||
                !hyphen ||
                min.type !== "Character" ||
                max.type !== "Character" ||
                hyphen.type !== "Character" ||
                hyphen.value !== HYPHEN_MINUS) {
                throw new Error("UnknownError");
            }
            const node = {
                type: "CharacterClassRange",
                parent,
                start,
                end,
                raw: this.source.slice(start, end),
                min,
                max,
            };
            min.parent = node;
            max.parent = node;
            elements.push(node);
        }
    }
    class RegExpParser {
        constructor(options) {
            this._state = new RegExpParserState(options);
            this._validator = new RegExpValidator(this._state);
        }
        parseLiteral(source, start = 0, end = source.length) {
            this._state.source = source;
            this._validator.validateLiteral(source, start, end);
            const pattern = this._state.pattern;
            const flags = this._state.flags;
            const literal = {
                type: "RegExpLiteral",
                parent: null,
                start,
                end,
                raw: source,
                pattern,
                flags,
            };
            pattern.parent = literal;
            flags.parent = literal;
            return literal;
        }
        parseFlags(source, start = 0, end = source.length) {
            this._state.source = source;
            this._validator.validateFlags(source, start, end);
            return this._state.flags;
        }
        parsePattern(source, start = 0, end = source.length, uFlag = false) {
            this._state.source = source;
            this._validator.validatePattern(source, start, end, uFlag);
            return this._state.pattern;
        }
    }
    class RegExpVisitor {
        constructor(handlers) {
            this._handlers = handlers;
        }
        visit(node) {
            switch (node.type) {
                case "Alternative":
                    this.visitAlternative(node);
                    break;
                case "Assertion":
                    this.visitAssertion(node);
                    break;
                case "Backreference":
                    this.visitBackreference(node);
                    break;
                case "CapturingGroup":
                    this.visitCapturingGroup(node);
                    break;
                case "Character":
                    this.visitCharacter(node);
                    break;
                case "CharacterClass":
                    this.visitCharacterClass(node);
                    break;
                case "CharacterClassRange":
                    this.visitCharacterClassRange(node);
                    break;
                case "CharacterSet":
                    this.visitCharacterSet(node);
                    break;
                case "Flags":
                    this.visitFlags(node);
                    break;
                case "Group":
                    this.visitGroup(node);
                    break;
                case "Pattern":
                    this.visitPattern(node);
                    break;
                case "Quantifier":
                    this.visitQuantifier(node);
                    break;
                case "RegExpLiteral":
                    this.visitRegExpLiteral(node);
                    break;
                default:
                    throw new Error(`Unknown type: ${node.type}`);
            }
        }
        visitAlternative(node) {
            if (this._handlers.onAlternativeEnter) {
                this._handlers.onAlternativeEnter(node);
            }
            node.elements.forEach(this.visit, this);
            if (this._handlers.onAlternativeLeave) {
                this._handlers.onAlternativeLeave(node);
            }
        }
        visitAssertion(node) {
            if (this._handlers.onAssertionEnter) {
                this._handlers.onAssertionEnter(node);
            }
            if (node.kind === "lookahead" || node.kind === "lookbehind") {
                node.alternatives.forEach(this.visit, this);
            }
            if (this._handlers.onAssertionLeave) {
                this._handlers.onAssertionLeave(node);
            }
        }
        visitBackreference(node) {
            if (this._handlers.onBackreferenceEnter) {
                this._handlers.onBackreferenceEnter(node);
            }
            if (this._handlers.onBackreferenceLeave) {
                this._handlers.onBackreferenceLeave(node);
            }
        }
        visitCapturingGroup(node) {
            if (this._handlers.onCapturingGroupEnter) {
                this._handlers.onCapturingGroupEnter(node);
            }
            node.alternatives.forEach(this.visit, this);
            if (this._handlers.onCapturingGroupLeave) {
                this._handlers.onCapturingGroupLeave(node);
            }
        }
        visitCharacter(node) {
            if (this._handlers.onCharacterEnter) {
                this._handlers.onCharacterEnter(node);
            }
            if (this._handlers.onCharacterLeave) {
                this._handlers.onCharacterLeave(node);
            }
        }
        visitCharacterClass(node) {
            if (this._handlers.onCharacterClassEnter) {
                this._handlers.onCharacterClassEnter(node);
            }
            node.elements.forEach(this.visit, this);
            if (this._handlers.onCharacterClassLeave) {
                this._handlers.onCharacterClassLeave(node);
            }
        }
        visitCharacterClassRange(node) {
            if (this._handlers.onCharacterClassRangeEnter) {
                this._handlers.onCharacterClassRangeEnter(node);
            }
            this.visitCharacter(node.min);
            this.visitCharacter(node.max);
            if (this._handlers.onCharacterClassRangeLeave) {
                this._handlers.onCharacterClassRangeLeave(node);
            }
        }
        visitCharacterSet(node) {
            if (this._handlers.onCharacterSetEnter) {
                this._handlers.onCharacterSetEnter(node);
            }
            if (this._handlers.onCharacterSetLeave) {
                this._handlers.onCharacterSetLeave(node);
            }
        }
        visitFlags(node) {
            if (this._handlers.onFlagsEnter) {
                this._handlers.onFlagsEnter(node);
            }
            if (this._handlers.onFlagsLeave) {
                this._handlers.onFlagsLeave(node);
            }
        }
        visitGroup(node) {
            if (this._handlers.onGroupEnter) {
                this._handlers.onGroupEnter(node);
            }
            node.alternatives.forEach(this.visit, this);
            if (this._handlers.onGroupLeave) {
                this._handlers.onGroupLeave(node);
            }
        }
        visitPattern(node) {
            if (this._handlers.onPatternEnter) {
                this._handlers.onPatternEnter(node);
            }
            node.alternatives.forEach(this.visit, this);
            if (this._handlers.onPatternLeave) {
                this._handlers.onPatternLeave(node);
            }
        }
        visitQuantifier(node) {
            if (this._handlers.onQuantifierEnter) {
                this._handlers.onQuantifierEnter(node);
            }
            this.visit(node.element);
            if (this._handlers.onQuantifierLeave) {
                this._handlers.onQuantifierLeave(node);
            }
        }
        visitRegExpLiteral(node) {
            if (this._handlers.onRegExpLiteralEnter) {
                this._handlers.onRegExpLiteralEnter(node);
            }
            this.visitPattern(node.pattern);
            this.visitFlags(node.flags);
            if (this._handlers.onRegExpLiteralLeave) {
                this._handlers.onRegExpLiteralLeave(node);
            }
        }
    }
    function parseRegExpLiteral(source, options) {
        return new RegExpParser(options).parseLiteral(String(source));
    }
    function validateRegExpLiteral(source, options) {
        new RegExpValidator(options).validateLiteral(source);
    }
    function visitRegExpAST(node, handlers) {
        new RegExpVisitor(handlers).visit(node);
    }
    exports.AST = ast;
    exports.RegExpParser = RegExpParser;
    exports.RegExpValidator = RegExpValidator;
    exports.parseRegExpLiteral = parseRegExpLiteral;
    exports.validateRegExpLiteral = validateRegExpLiteral;
    exports.visitRegExpAST = visitRegExpAST;
    
},
/* eslint/lib/rules/no-debugger.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of a debugger statement
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow the use of `debugger`",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-debugger"
            },
            fixable: null,
            schema: [],
            messages: {
                unexpected: "Unexpected 'debugger' statement."
            }
        },
        create(context) {
            return {
                DebuggerStatement(node) {
                    context.report({
                        node,
                        messageId: "unexpected"
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-delete-var.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when deleting variables
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow deleting variables",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-delete-var"
            },
            schema: [],
            messages: {
                unexpected: "Variables should not be deleted."
            }
        },
        create(context) {
            return {
                UnaryExpression(node) {
                    if (node.operator === "delete" && node.argument.type === "Identifier") {
                        context.report({ node, messageId: "unexpected" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-div-regex.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check for ambiguous div operator in regexes
     * @author Matt DuVall <http://www.mattduvall.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow division operators explicitly at the beginning of regular expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-div-regex"
            },
            fixable: "code",
            schema: [],
            messages: {
                unexpected: "A regular expression literal can be confused with '/='."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                Literal(node) {
                    const token = sourceCode.getFirstToken(node);
                    if (token.type === "RegularExpression" && token.value[1] === "=") {
                        context.report({
                            node,
                            messageId: "unexpected",
                            fix(fixer) {
                                return fixer.replaceTextRange([token.range[0] + 1, token.range[0] + 2], "[=]");
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-dupe-args.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag duplicate arguments
     * @author Jamund Ferguson
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow duplicate arguments in `function` definitions",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-dupe-args"
            },
            schema: [],
            messages: {
                unexpected: "Duplicate param '{{name}}'."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Checks whether or not a given definition is a parameter's.
             * @param {eslint-scope.DefEntry} def A definition to check.
             * @returns {boolean} `true` if the definition is a parameter's.
             */
            function isParameter(def) {
                return def.type === "Parameter";
            }
            /**
             * Determines if a given node has duplicate parameters.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             * @private
             */
            function checkParams(node) {
                const variables = context.getDeclaredVariables(node);
                for (let i = 0; i < variables.length; ++i) {
                    const variable = variables[i];
                    // Checks and reports duplications.
                    const defs = variable.defs.filter(isParameter);
                    if (defs.length >= 2) {
                        context.report({
                            node,
                            messageId: "unexpected",
                            data: { name: variable.name }
                        });
                    }
                }
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                FunctionDeclaration: checkParams,
                FunctionExpression: checkParams
            };
        }
    };
},
/* eslint/lib/rules/no-dupe-class-members.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow duplicate name in class members.
     * @author Toru Nagashima
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow duplicate class members",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-dupe-class-members"
            },
            schema: [],
            messages: {
                unexpected: "Duplicate name '{{name}}'."
            }
        },
        create(context) {
            let stack = [];
            /**
             * Gets state of a given member name.
             * @param {string} name A name of a member.
             * @param {boolean} isStatic A flag which specifies that is a static member.
             * @returns {Object} A state of a given member name.
             *   - retv.init {boolean} A flag which shows the name is declared as normal member.
             *   - retv.get {boolean} A flag which shows the name is declared as getter.
             *   - retv.set {boolean} A flag which shows the name is declared as setter.
             */
            function getState(name, isStatic) {
                const stateMap = stack[stack.length - 1];
                const key = `$${name}`; // to avoid "__proto__".
                if (!stateMap[key]) {
                    stateMap[key] = {
                        nonStatic: { init: false, get: false, set: false },
                        static: { init: false, get: false, set: false }
                    };
                }
                return stateMap[key][isStatic ? "static" : "nonStatic"];
            }
            return {
                // Initializes the stack of state of member declarations.
                Program() {
                    stack = [];
                },
                // Initializes state of member declarations for the class.
                ClassBody() {
                    stack.push(Object.create(null));
                },
                // Disposes the state for the class.
                "ClassBody:exit"() {
                    stack.pop();
                },
                // Reports the node if its name has been declared already.
                "MethodDefinition, PropertyDefinition"(node) {
                    const name = astUtils.getStaticPropertyName(node);
                    const kind = node.type === "MethodDefinition" ? node.kind : "field";
                    if (name === null || kind === "constructor") {
                        return;
                    }
                    const state = getState(name, node.static);
                    let isDuplicate = false;
                    if (kind === "get") {
                        isDuplicate = (state.init || state.get);
                        state.get = true;
                    }
                    else if (kind === "set") {
                        isDuplicate = (state.init || state.set);
                        state.set = true;
                    }
                    else {
                        isDuplicate = (state.init || state.get || state.set);
                        state.init = true;
                    }
                    if (isDuplicate) {
                        context.report({ node, messageId: "unexpected", data: { name } });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-dupe-else-if.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow duplicate conditions in if-else-if chains
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Determines whether the first given array is a subset of the second given array.
     * @param {Function} comparator A function to compare two elements, should return `true` if they are equal.
     * @param {Array} arrA The array to compare from.
     * @param {Array} arrB The array to compare against.
     * @returns {boolean} `true` if the array `arrA` is a subset of the array `arrB`.
     */
    function isSubsetByComparator(comparator, arrA, arrB) {
        return arrA.every(a => arrB.some(b => comparator(a, b)));
    }
    /**
     * Splits the given node by the given logical operator.
     * @param {string} operator Logical operator `||` or `&&`.
     * @param {ASTNode} node The node to split.
     * @returns {ASTNode[]} Array of conditions that makes the node when joined by the operator.
     */
    function splitByLogicalOperator(operator, node) {
        if (node.type === "LogicalExpression" && node.operator === operator) {
            return [...splitByLogicalOperator(operator, node.left), ...splitByLogicalOperator(operator, node.right)];
        }
        return [node];
    }
    const splitByOr = splitByLogicalOperator.bind(null, "||");
    const splitByAnd = splitByLogicalOperator.bind(null, "&&");
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow duplicate conditions in if-else-if chains",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-dupe-else-if"
            },
            schema: [],
            messages: {
                unexpected: "This branch can never execute. Its condition is a duplicate or covered by previous conditions in the if-else-if chain."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Determines whether the two given nodes are considered to be equal. In particular, given that the nodes
             * represent expressions in a boolean context, `||` and `&&` can be considered as commutative operators.
             * @param {ASTNode} a First node.
             * @param {ASTNode} b Second node.
             * @returns {boolean} `true` if the nodes are considered to be equal.
             */
            function equal(a, b) {
                if (a.type !== b.type) {
                    return false;
                }
                if (a.type === "LogicalExpression" &&
                    (a.operator === "||" || a.operator === "&&") &&
                    a.operator === b.operator) {
                    return equal(a.left, b.left) && equal(a.right, b.right) ||
                        equal(a.left, b.right) && equal(a.right, b.left);
                }
                return astUtils.equalTokens(a, b, sourceCode);
            }
            const isSubset = isSubsetByComparator.bind(null, equal);
            return {
                IfStatement(node) {
                    const test = node.test, conditionsToCheck = test.type === "LogicalExpression" && test.operator === "&&"
                        ? [test, ...splitByAnd(test)]
                        : [test];
                    let current = node, listToCheck = conditionsToCheck.map(c => splitByOr(c).map(splitByAnd));
                    while (current.parent && current.parent.type === "IfStatement" && current.parent.alternate === current) {
                        current = current.parent;
                        const currentOrOperands = splitByOr(current.test).map(splitByAnd);
                        listToCheck = listToCheck.map(orOperands => orOperands.filter(orOperand => !currentOrOperands.some(currentOrOperand => isSubset(currentOrOperand, orOperand))));
                        if (listToCheck.some(orOperands => orOperands.length === 0)) {
                            context.report({ node: test, messageId: "unexpected" });
                            break;
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-dupe-keys.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of duplicate keys in an object.
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const GET_KIND = /^(?:init|get)$/u;
    const SET_KIND = /^(?:init|set)$/u;
    /**
     * The class which stores properties' information of an object.
     */
    class ObjectInfo {
        /**
         * @param {ObjectInfo|null} upper The information of the outer object.
         * @param {ASTNode} node The ObjectExpression node of this information.
         */
        constructor(upper, node) {
            this.upper = upper;
            this.node = node;
            this.properties = new Map();
        }
        /**
         * Gets the information of the given Property node.
         * @param {ASTNode} node The Property node to get.
         * @returns {{get: boolean, set: boolean}} The information of the property.
         */
        getPropertyInfo(node) {
            const name = astUtils.getStaticPropertyName(node);
            if (!this.properties.has(name)) {
                this.properties.set(name, { get: false, set: false });
            }
            return this.properties.get(name);
        }
        /**
         * Checks whether the given property has been defined already or not.
         * @param {ASTNode} node The Property node to check.
         * @returns {boolean} `true` if the property has been defined.
         */
        isPropertyDefined(node) {
            const entry = this.getPropertyInfo(node);
            return ((GET_KIND.test(node.kind) && entry.get) ||
                (SET_KIND.test(node.kind) && entry.set));
        }
        /**
         * Defines the given property.
         * @param {ASTNode} node The Property node to define.
         * @returns {void}
         */
        defineProperty(node) {
            const entry = this.getPropertyInfo(node);
            if (GET_KIND.test(node.kind)) {
                entry.get = true;
            }
            if (SET_KIND.test(node.kind)) {
                entry.set = true;
            }
        }
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow duplicate keys in object literals",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-dupe-keys"
            },
            schema: [],
            messages: {
                unexpected: "Duplicate key '{{name}}'."
            }
        },
        create(context) {
            let info = null;
            return {
                ObjectExpression(node) {
                    info = new ObjectInfo(info, node);
                },
                "ObjectExpression:exit"() {
                    info = info.upper;
                },
                Property(node) {
                    const name = astUtils.getStaticPropertyName(node);
                    // Skip destructuring.
                    if (node.parent.type !== "ObjectExpression") {
                        return;
                    }
                    // Skip if the name is not static.
                    if (name === null) {
                        return;
                    }
                    // Reports if the name is defined already.
                    if (info.isPropertyDefined(node)) {
                        context.report({
                            node: info.node,
                            loc: node.key.loc,
                            messageId: "unexpected",
                            data: { name }
                        });
                    }
                    // Update info.
                    info.defineProperty(node);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-duplicate-case.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow a duplicate case label.
     * @author Dieter Oberkofler
     * @author Burak Yigit Kaya
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow duplicate case labels",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-duplicate-case"
            },
            schema: [],
            messages: {
                unexpected: "Duplicate case label."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Determines whether the two given nodes are considered to be equal.
             * @param {ASTNode} a First node.
             * @param {ASTNode} b Second node.
             * @returns {boolean} `true` if the nodes are considered to be equal.
             */
            function equal(a, b) {
                if (a.type !== b.type) {
                    return false;
                }
                return astUtils.equalTokens(a, b, sourceCode);
            }
            return {
                SwitchStatement(node) {
                    const previousTests = [];
                    for (const switchCase of node.cases) {
                        if (switchCase.test) {
                            const test = switchCase.test;
                            if (previousTests.some(previousTest => equal(previousTest, test))) {
                                context.report({ node: switchCase, messageId: "unexpected" });
                            }
                            else {
                                previousTests.push(test);
                            }
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-duplicate-imports.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Restrict usage of duplicate imports.
     * @author Simen Bekkhus
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const NAMED_TYPES = ["ImportSpecifier", "ExportSpecifier"];
    const NAMESPACE_TYPES = [
        "ImportNamespaceSpecifier",
        "ExportNamespaceSpecifier"
    ];
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /**
     * Check if an import/export type belongs to (ImportSpecifier|ExportSpecifier) or (ImportNamespaceSpecifier|ExportNamespaceSpecifier).
     * @param {string} importExportType An import/export type to check.
     * @param {string} type Can be "named" or "namespace"
     * @returns {boolean} True if import/export type belongs to (ImportSpecifier|ExportSpecifier) or (ImportNamespaceSpecifier|ExportNamespaceSpecifier) and false if it doesn't.
     */
    function isImportExportSpecifier(importExportType, type) {
        const arrayToCheck = type === "named" ? NAMED_TYPES : NAMESPACE_TYPES;
        return arrayToCheck.includes(importExportType);
    }
    /**
     * Return the type of (import|export).
     * @param {ASTNode} node A node to get.
     * @returns {string} The type of the (import|export).
     */
    function getImportExportType(node) {
        if (node.specifiers && node.specifiers.length > 0) {
            const nodeSpecifiers = node.specifiers;
            const index = nodeSpecifiers.findIndex(({ type }) => isImportExportSpecifier(type, "named") ||
                isImportExportSpecifier(type, "namespace"));
            const i = index > -1 ? index : 0;
            return nodeSpecifiers[i].type;
        }
        if (node.type === "ExportAllDeclaration") {
            if (node.exported) {
                return "ExportNamespaceSpecifier";
            }
            return "ExportAll";
        }
        return "SideEffectImport";
    }
    /**
     * Returns a boolean indicates if two (import|export) can be merged
     * @param {ASTNode} node1 A node to check.
     * @param {ASTNode} node2 A node to check.
     * @returns {boolean} True if two (import|export) can be merged, false if they can't.
     */
    function isImportExportCanBeMerged(node1, node2) {
        const importExportType1 = getImportExportType(node1);
        const importExportType2 = getImportExportType(node2);
        if ((importExportType1 === "ExportAll" &&
            importExportType2 !== "ExportAll" &&
            importExportType2 !== "SideEffectImport") ||
            (importExportType1 !== "ExportAll" &&
                importExportType1 !== "SideEffectImport" &&
                importExportType2 === "ExportAll")) {
            return false;
        }
        if ((isImportExportSpecifier(importExportType1, "namespace") &&
            isImportExportSpecifier(importExportType2, "named")) ||
            (isImportExportSpecifier(importExportType2, "namespace") &&
                isImportExportSpecifier(importExportType1, "named"))) {
            return false;
        }
        return true;
    }
    /**
     * Returns a boolean if we should report (import|export).
     * @param {ASTNode} node A node to be reported or not.
     * @param {[ASTNode]} previousNodes An array contains previous nodes of the module imported or exported.
     * @returns {boolean} True if the (import|export) should be reported.
     */
    function shouldReportImportExport(node, previousNodes) {
        let i = 0;
        while (i < previousNodes.length) {
            if (isImportExportCanBeMerged(node, previousNodes[i])) {
                return true;
            }
            i++;
        }
        return false;
    }
    /**
     * Returns array contains only nodes with declarations types equal to type.
     * @param {[{node: ASTNode, declarationType: string}]} nodes An array contains objects, each object contains a node and a declaration type.
     * @param {string} type Declaration type.
     * @returns {[ASTNode]} An array contains only nodes with declarations types equal to type.
     */
    function getNodesByDeclarationType(nodes, type) {
        return nodes
            .filter(({ declarationType }) => declarationType === type)
            .map(({ node }) => node);
    }
    /**
     * Returns the name of the module imported or re-exported.
     * @param {ASTNode} node A node to get.
     * @returns {string} The name of the module, or empty string if no name.
     */
    function getModule(node) {
        if (node && node.source && node.source.value) {
            return node.source.value.trim();
        }
        return "";
    }
    /**
     * Checks if the (import|export) can be merged with at least one import or one export, and reports if so.
     * @param {RuleContext} context The ESLint rule context object.
     * @param {ASTNode} node A node to get.
     * @param {Map} modules A Map object contains as a key a module name and as value an array contains objects, each object contains a node and a declaration type.
     * @param {string} declarationType A declaration type can be an import or export.
     * @param {boolean} includeExports Whether or not to check for exports in addition to imports.
     * @returns {void} No return value.
     */
    function checkAndReport(context, node, modules, declarationType, includeExports) {
        const module = getModule(node);
        if (modules.has(module)) {
            const previousNodes = modules.get(module);
            const messagesIds = [];
            const importNodes = getNodesByDeclarationType(previousNodes, "import");
            let exportNodes;
            if (includeExports) {
                exportNodes = getNodesByDeclarationType(previousNodes, "export");
            }
            if (declarationType === "import") {
                if (shouldReportImportExport(node, importNodes)) {
                    messagesIds.push("import");
                }
                if (includeExports) {
                    if (shouldReportImportExport(node, exportNodes)) {
                        messagesIds.push("importAs");
                    }
                }
            }
            else if (declarationType === "export") {
                if (shouldReportImportExport(node, exportNodes)) {
                    messagesIds.push("export");
                }
                if (shouldReportImportExport(node, importNodes)) {
                    messagesIds.push("exportAs");
                }
            }
            messagesIds.forEach(messageId => context.report({
                node,
                messageId,
                data: {
                    module
                }
            }));
        }
    }
    /**
     * @callback nodeCallback
     * @param {ASTNode} node A node to handle.
     */
    /**
     * Returns a function handling the (imports|exports) of a given file
     * @param {RuleContext} context The ESLint rule context object.
     * @param {Map} modules A Map object contains as a key a module name and as value an array contains objects, each object contains a node and a declaration type.
     * @param {string} declarationType A declaration type can be an import or export.
     * @param {boolean} includeExports Whether or not to check for exports in addition to imports.
     * @returns {nodeCallback} A function passed to ESLint to handle the statement.
     */
    function handleImportsExports(context, modules, declarationType, includeExports) {
        return function (node) {
            const module = getModule(node);
            if (module) {
                checkAndReport(context, node, modules, declarationType, includeExports);
                const currentNode = { node, declarationType };
                let nodes = [currentNode];
                if (modules.has(module)) {
                    const previousNodes = modules.get(module);
                    nodes = [...previousNodes, currentNode];
                }
                modules.set(module, nodes);
            }
        };
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow duplicate module imports",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-duplicate-imports"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        includeExports: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                import: "'{{module}}' import is duplicated.",
                importAs: "'{{module}}' import is duplicated as export.",
                export: "'{{module}}' export is duplicated.",
                exportAs: "'{{module}}' export is duplicated as import."
            }
        },
        create(context) {
            const includeExports = (context.options[0] || {}).includeExports, modules = new Map();
            const handlers = {
                ImportDeclaration: handleImportsExports(context, modules, "import", includeExports)
            };
            if (includeExports) {
                handlers.ExportNamedDeclaration = handleImportsExports(context, modules, "export", includeExports);
                handlers.ExportAllDeclaration = handleImportsExports(context, modules, "export", includeExports);
            }
            return handlers;
        }
    };
},
/* eslint/lib/rules/no-else-return.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag `else` after a `return` in `if`
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const FixTracker = require(496) /* ./utils/fix-tracker */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `else` blocks after `return` statements in `if` statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-else-return"
            },
            schema: [{
                    type: "object",
                    properties: {
                        allowElseIf: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }],
            fixable: "code",
            messages: {
                unexpected: "Unnecessary 'else' after 'return'."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Checks whether the given names can be safely used to declare block-scoped variables
             * in the given scope. Name collisions can produce redeclaration syntax errors,
             * or silently change references and modify behavior of the original code.
             *
             * This is not a generic function. In particular, it is assumed that the scope is a function scope or
             * a function's inner scope, and that the names can be valid identifiers in the given scope.
             * @param {string[]} names Array of variable names.
             * @param {eslint-scope.Scope} scope Function scope or a function's inner scope.
             * @returns {boolean} True if all names can be safely declared, false otherwise.
             */
            function isSafeToDeclare(names, scope) {
                if (names.length === 0) {
                    return true;
                }
                const functionScope = scope.variableScope;
                /*
                 * If this is a function scope, scope.variables will contain parameters, implicit variables such as "arguments",
                 * all function-scoped variables ('var'), and block-scoped variables defined in the scope.
                 * If this is an inner scope, scope.variables will contain block-scoped variables defined in the scope.
                 *
                 * Redeclaring any of these would cause a syntax error, except for the implicit variables.
                 */
                const declaredVariables = scope.variables.filter(({ defs }) => defs.length > 0);
                if (declaredVariables.some(({ name }) => names.includes(name))) {
                    return false;
                }
                // Redeclaring a catch variable would also cause a syntax error.
                if (scope !== functionScope && scope.upper.type === "catch") {
                    if (scope.upper.variables.some(({ name }) => names.includes(name))) {
                        return false;
                    }
                }
                /*
                 * Redeclaring an implicit variable, such as "arguments", would not cause a syntax error.
                 * However, if the variable was used, declaring a new one with the same name would change references
                 * and modify behavior.
                 */
                const usedImplicitVariables = scope.variables.filter(({ defs, references }) => defs.length === 0 && references.length > 0);
                if (usedImplicitVariables.some(({ name }) => names.includes(name))) {
                    return false;
                }
                /*
                 * Declaring a variable with a name that was already used to reference a variable from an upper scope
                 * would change references and modify behavior.
                 */
                if (scope.through.some(t => names.includes(t.identifier.name))) {
                    return false;
                }
                /*
                 * If the scope is an inner scope (not the function scope), an uninitialized `var` variable declared inside
                 * the scope node (directly or in one of its descendants) is neither declared nor 'through' in the scope.
                 *
                 * For example, this would be a syntax error "Identifier 'a' has already been declared":
                 * function foo() { if (bar) { let a; if (baz) { var a; } } }
                 */
                if (scope !== functionScope) {
                    const scopeNodeRange = scope.block.range;
                    const variablesToCheck = functionScope.variables.filter(({ name }) => names.includes(name));
                    if (variablesToCheck.some(v => v.defs.some(({ node: { range } }) => scopeNodeRange[0] <= range[0] && range[1] <= scopeNodeRange[1]))) {
                        return false;
                    }
                }
                return true;
            }
            /**
             * Checks whether the removal of `else` and its braces is safe from variable name collisions.
             * @param {Node} node The 'else' node.
             * @param {eslint-scope.Scope} scope The scope in which the node and the whole 'if' statement is.
             * @returns {boolean} True if it is safe, false otherwise.
             */
            function isSafeFromNameCollisions(node, scope) {
                if (node.type === "FunctionDeclaration") {
                    // Conditional function declaration. Scope and hoisting are unpredictable, different engines work differently.
                    return false;
                }
                if (node.type !== "BlockStatement") {
                    return true;
                }
                const elseBlockScope = scope.childScopes.find(({ block }) => block === node);
                if (!elseBlockScope) {
                    // ecmaVersion < 6, `else` block statement cannot have its own scope, no possible collisions.
                    return true;
                }
                /*
                 * elseBlockScope is supposed to merge into its upper scope. elseBlockScope.variables array contains
                 * only block-scoped variables (such as let and const variables or class and function declarations)
                 * defined directly in the elseBlockScope. These are exactly the only names that could cause collisions.
                 */
                const namesToCheck = elseBlockScope.variables.map(({ name }) => name);
                return isSafeToDeclare(namesToCheck, scope);
            }
            /**
             * Display the context report if rule is violated
             * @param {Node} node The 'else' node
             * @returns {void}
             */
            function displayReport(node) {
                const currentScope = context.getScope();
                context.report({
                    node,
                    messageId: "unexpected",
                    fix(fixer) {
                        if (!isSafeFromNameCollisions(node, currentScope)) {
                            return null;
                        }
                        const sourceCode = context.getSourceCode();
                        const startToken = sourceCode.getFirstToken(node);
                        const elseToken = sourceCode.getTokenBefore(startToken);
                        const source = sourceCode.getText(node);
                        const lastIfToken = sourceCode.getTokenBefore(elseToken);
                        let fixedSource, firstTokenOfElseBlock;
                        if (startToken.type === "Punctuator" && startToken.value === "{") {
                            firstTokenOfElseBlock = sourceCode.getTokenAfter(startToken);
                        }
                        else {
                            firstTokenOfElseBlock = startToken;
                        }
                        /*
                         * If the if block does not have curly braces and does not end in a semicolon
                         * and the else block starts with (, [, /, +, ` or -, then it is not
                         * safe to remove the else keyword, because ASI will not add a semicolon
                         * after the if block
                         */
                        const ifBlockMaybeUnsafe = node.parent.consequent.type !== "BlockStatement" && lastIfToken.value !== ";";
                        const elseBlockUnsafe = /^[([/+`-]/u.test(firstTokenOfElseBlock.value);
                        if (ifBlockMaybeUnsafe && elseBlockUnsafe) {
                            return null;
                        }
                        const endToken = sourceCode.getLastToken(node);
                        const lastTokenOfElseBlock = sourceCode.getTokenBefore(endToken);
                        if (lastTokenOfElseBlock.value !== ";") {
                            const nextToken = sourceCode.getTokenAfter(endToken);
                            const nextTokenUnsafe = nextToken && /^[([/+`-]/u.test(nextToken.value);
                            const nextTokenOnSameLine = nextToken && nextToken.loc.start.line === lastTokenOfElseBlock.loc.start.line;
                            /*
                             * If the else block contents does not end in a semicolon,
                             * and the else block starts with (, [, /, +, ` or -, then it is not
                             * safe to remove the else block, because ASI will not add a semicolon
                             * after the remaining else block contents
                             */
                            if (nextTokenUnsafe || (nextTokenOnSameLine && nextToken.value !== "}")) {
                                return null;
                            }
                        }
                        if (startToken.type === "Punctuator" && startToken.value === "{") {
                            fixedSource = source.slice(1, -1);
                        }
                        else {
                            fixedSource = source;
                        }
                        /*
                         * Extend the replacement range to include the entire
                         * function to avoid conflicting with no-useless-return.
                         * https://github.com/eslint/eslint/issues/8026
                         *
                         * Also, to avoid name collisions between two else blocks.
                         */
                        return new FixTracker(fixer, sourceCode)
                            .retainEnclosingFunction(node)
                            .replaceTextRange([elseToken.range[0], node.range[1]], fixedSource);
                    }
                });
            }
            /**
             * Check to see if the node is a ReturnStatement
             * @param {Node} node The node being evaluated
             * @returns {boolean} True if node is a return
             */
            function checkForReturn(node) {
                return node.type === "ReturnStatement";
            }
            /**
             * Naive return checking, does not iterate through the whole
             * BlockStatement because we make the assumption that the ReturnStatement
             * will be the last node in the body of the BlockStatement.
             * @param {Node} node The consequent/alternate node
             * @returns {boolean} True if it has a return
             */
            function naiveHasReturn(node) {
                if (node.type === "BlockStatement") {
                    const body = node.body, lastChildNode = body[body.length - 1];
                    return lastChildNode && checkForReturn(lastChildNode);
                }
                return checkForReturn(node);
            }
            /**
             * Check to see if the node is valid for evaluation,
             * meaning it has an else.
             * @param {Node} node The node being evaluated
             * @returns {boolean} True if the node is valid
             */
            function hasElse(node) {
                return node.alternate && node.consequent;
            }
            /**
             * If the consequent is an IfStatement, check to see if it has an else
             * and both its consequent and alternate path return, meaning this is
             * a nested case of rule violation.  If-Else not considered currently.
             * @param {Node} node The consequent node
             * @returns {boolean} True if this is a nested rule violation
             */
            function checkForIf(node) {
                return node.type === "IfStatement" && hasElse(node) &&
                    naiveHasReturn(node.alternate) && naiveHasReturn(node.consequent);
            }
            /**
             * Check the consequent/body node to make sure it is not
             * a ReturnStatement or an IfStatement that returns on both
             * code paths.
             * @param {Node} node The consequent or body node
             * @returns {boolean} `true` if it is a Return/If node that always returns.
             */
            function checkForReturnOrIf(node) {
                return checkForReturn(node) || checkForIf(node);
            }
            /**
             * Check whether a node returns in every codepath.
             * @param {Node} node The node to be checked
             * @returns {boolean} `true` if it returns on every codepath.
             */
            function alwaysReturns(node) {
                if (node.type === "BlockStatement") {
                    // If we have a BlockStatement, check each consequent body node.
                    return node.body.some(checkForReturnOrIf);
                }
                /*
                 * If not a block statement, make sure the consequent isn't a
                 * ReturnStatement or an IfStatement with returns on both paths.
                 */
                return checkForReturnOrIf(node);
            }
            /**
             * Check the if statement, but don't catch else-if blocks.
             * @returns {void}
             * @param {Node} node The node for the if statement to check
             * @private
             */
            function checkIfWithoutElse(node) {
                const parent = node.parent;
                /*
                 * Fixing this would require splitting one statement into two, so no error should
                 * be reported if this node is in a position where only one statement is allowed.
                 */
                if (!astUtils.STATEMENT_LIST_PARENTS.has(parent.type)) {
                    return;
                }
                const consequents = [];
                let alternate;
                for (let currentNode = node; currentNode.type === "IfStatement"; currentNode = currentNode.alternate) {
                    if (!currentNode.alternate) {
                        return;
                    }
                    consequents.push(currentNode.consequent);
                    alternate = currentNode.alternate;
                }
                if (consequents.every(alwaysReturns)) {
                    displayReport(alternate);
                }
            }
            /**
             * Check the if statement
             * @returns {void}
             * @param {Node} node The node for the if statement to check
             * @private
             */
            function checkIfWithElse(node) {
                const parent = node.parent;
                /*
                 * Fixing this would require splitting one statement into two, so no error should
                 * be reported if this node is in a position where only one statement is allowed.
                 */
                if (!astUtils.STATEMENT_LIST_PARENTS.has(parent.type)) {
                    return;
                }
                const alternate = node.alternate;
                if (alternate && alwaysReturns(node.consequent)) {
                    displayReport(alternate);
                }
            }
            const allowElseIf = !(context.options[0] && context.options[0].allowElseIf === false);
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                "IfStatement:exit": allowElseIf ? checkIfWithoutElse : checkIfWithElse
            };
        }
    };
},
/* eslint/lib/rules/utils/fix-tracker.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Helper class to aid in constructing fix commands.
     * @author Alan Pierce
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./ast-utils */;
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * A helper class to combine fix options into a fix command. Currently, it
     * exposes some "retain" methods that extend the range of the text being
     * replaced so that other fixes won't touch that region in the same pass.
     */
    class FixTracker {
        /**
         * Create a new FixTracker.
         * @param {ruleFixer} fixer A ruleFixer instance.
         * @param {SourceCode} sourceCode A SourceCode object for the current code.
         */
        constructor(fixer, sourceCode) {
            this.fixer = fixer;
            this.sourceCode = sourceCode;
            this.retainedRange = null;
        }
        /**
         * Mark the given range as "retained", meaning that other fixes may not
         * may not modify this region in the same pass.
         * @param {int[]} range The range to retain.
         * @returns {FixTracker} The same RuleFixer, for chained calls.
         */
        retainRange(range) {
            this.retainedRange = range;
            return this;
        }
        /**
         * Given a node, find the function containing it (or the entire program) and
         * mark it as retained, meaning that other fixes may not modify it in this
         * pass. This is useful for avoiding conflicts in fixes that modify control
         * flow.
         * @param {ASTNode} node The node to use as a starting point.
         * @returns {FixTracker} The same RuleFixer, for chained calls.
         */
        retainEnclosingFunction(node) {
            const functionNode = astUtils.getUpperFunction(node);
            return this.retainRange(functionNode ? functionNode.range : this.sourceCode.ast.range);
        }
        /**
         * Given a node or token, find the token before and afterward, and mark that
         * range as retained, meaning that other fixes may not modify it in this
         * pass. This is useful for avoiding conflicts in fixes that make a small
         * change to the code where the AST should not be changed.
         * @param {ASTNode|Token} nodeOrToken The node or token to use as a starting
         *      point. The token to the left and right are use in the range.
         * @returns {FixTracker} The same RuleFixer, for chained calls.
         */
        retainSurroundingTokens(nodeOrToken) {
            const tokenBefore = this.sourceCode.getTokenBefore(nodeOrToken) || nodeOrToken;
            const tokenAfter = this.sourceCode.getTokenAfter(nodeOrToken) || nodeOrToken;
            return this.retainRange([tokenBefore.range[0], tokenAfter.range[1]]);
        }
        /**
         * Create a fix command that replaces the given range with the given text,
         * accounting for any retained ranges.
         * @param {int[]} range The range to remove in the fix.
         * @param {string} text The text to insert in place of the range.
         * @returns {Object} The fix command.
         */
        replaceTextRange(range, text) {
            let actualRange;
            if (this.retainedRange) {
                actualRange = [
                    Math.min(this.retainedRange[0], range[0]),
                    Math.max(this.retainedRange[1], range[1])
                ];
            }
            else {
                actualRange = range;
            }
            return this.fixer.replaceTextRange(actualRange, this.sourceCode.text.slice(actualRange[0], range[0]) +
                text +
                this.sourceCode.text.slice(range[1], actualRange[1]));
        }
        /**
         * Create a fix command that removes the given node or token, accounting for
         * any retained ranges.
         * @param {ASTNode|Token} nodeOrToken The node or token to remove.
         * @returns {Object} The fix command.
         */
        remove(nodeOrToken) {
            return this.replaceTextRange(nodeOrToken.range, "");
        }
    }
    module.exports = FixTracker;
},
/* eslint/lib/rules/no-empty.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag use of an empty block statement
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            hasSuggestions: true,
            type: "suggestion",
            docs: {
                description: "Disallow empty block statements",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-empty"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowEmptyCatch: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpected: "Empty {{type}} statement.",
                suggestComment: "Add comment inside empty {{type}} statement."
            }
        },
        create(context) {
            const options = context.options[0] || {}, allowEmptyCatch = options.allowEmptyCatch || false;
            const sourceCode = context.getSourceCode();
            return {
                BlockStatement(node) {
                    // if the body is not empty, we can just return immediately
                    if (node.body.length !== 0) {
                        return;
                    }
                    // a function is generally allowed to be empty
                    if (astUtils.isFunction(node.parent)) {
                        return;
                    }
                    if (allowEmptyCatch && node.parent.type === "CatchClause") {
                        return;
                    }
                    // any other block is only allowed to be empty, if it contains a comment
                    if (sourceCode.getCommentsInside(node).length > 0) {
                        return;
                    }
                    context.report({
                        node,
                        messageId: "unexpected",
                        data: { type: "block" },
                        suggest: [
                            {
                                messageId: "suggestComment",
                                data: { type: "block" },
                                fix(fixer) {
                                    const range = [node.range[0] + 1, node.range[1] - 1];
                                    return fixer.replaceTextRange(range, " /* empty */ ");
                                }
                            }
                        ]
                    });
                },
                SwitchStatement(node) {
                    if (typeof node.cases === "undefined" || node.cases.length === 0) {
                        context.report({ node, messageId: "unexpected", data: { type: "switch" } });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-empty-character-class.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag the use of empty character classes in regular expressions
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /*
     * plain-English description of the following regexp:
     * 0. `^` fix the match at the beginning of the string
     * 1. `([^\\[]|\\.|\[([^\\\]]|\\.)+\])*`: regexp contents; 0 or more of the following
     * 1.0. `[^\\[]`: any character that's not a `\` or a `[` (anything but escape sequences and character classes)
     * 1.1. `\\.`: an escape sequence
     * 1.2. `\[([^\\\]]|\\.)+\]`: a character class that isn't empty
     * 2. `$`: fix the match at the end of the string
     */
    const regex = /^([^\\[]|\\.|\[([^\\\]]|\\.)+\])*$/u;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow empty character classes in regular expressions",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-empty-character-class"
            },
            schema: [],
            messages: {
                unexpected: "Empty class."
            }
        },
        create(context) {
            return {
                "Literal[regex]"(node) {
                    if (!regex.test(node.regex.pattern)) {
                        context.report({ node, messageId: "unexpected" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-empty-function.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow empty functions.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const ALLOW_OPTIONS = Object.freeze([
        "functions",
        "arrowFunctions",
        "generatorFunctions",
        "methods",
        "generatorMethods",
        "getters",
        "setters",
        "constructors",
        "asyncFunctions",
        "asyncMethods"
    ]);
    /**
     * Gets the kind of a given function node.
     * @param {ASTNode} node A function node to get. This is one of
     *      an ArrowFunctionExpression, a FunctionDeclaration, or a
     *      FunctionExpression.
     * @returns {string} The kind of the function. This is one of "functions",
     *      "arrowFunctions", "generatorFunctions", "asyncFunctions", "methods",
     *      "generatorMethods", "asyncMethods", "getters", "setters", and
     *      "constructors".
     */
    function getKind(node) {
        const parent = node.parent;
        let kind = "";
        if (node.type === "ArrowFunctionExpression") {
            return "arrowFunctions";
        }
        // Detects main kind.
        if (parent.type === "Property") {
            if (parent.kind === "get") {
                return "getters";
            }
            if (parent.kind === "set") {
                return "setters";
            }
            kind = parent.method ? "methods" : "functions";
        }
        else if (parent.type === "MethodDefinition") {
            if (parent.kind === "get") {
                return "getters";
            }
            if (parent.kind === "set") {
                return "setters";
            }
            if (parent.kind === "constructor") {
                return "constructors";
            }
            kind = "methods";
        }
        else {
            kind = "functions";
        }
        // Detects prefix.
        let prefix = "";
        if (node.generator) {
            prefix = "generator";
        }
        else if (node.async) {
            prefix = "async";
        }
        else {
            return kind;
        }
        return prefix + kind[0].toUpperCase() + kind.slice(1);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow empty functions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-empty-function"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allow: {
                            type: "array",
                            items: { enum: ALLOW_OPTIONS },
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpected: "Unexpected empty {{name}}."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const allowed = options.allow || [];
            const sourceCode = context.getSourceCode();
            /**
             * Reports a given function node if the node matches the following patterns.
             *
             * - Not allowed by options.
             * - The body is empty.
             * - The body doesn't have any comments.
             * @param {ASTNode} node A function node to report. This is one of
             *      an ArrowFunctionExpression, a FunctionDeclaration, or a
             *      FunctionExpression.
             * @returns {void}
             */
            function reportIfEmpty(node) {
                const kind = getKind(node);
                const name = astUtils.getFunctionNameWithKind(node);
                const innerComments = sourceCode.getTokens(node.body, {
                    includeComments: true,
                    filter: astUtils.isCommentToken
                });
                if (!allowed.includes(kind) &&
                    node.body.type === "BlockStatement" &&
                    node.body.body.length === 0 &&
                    innerComments.length === 0) {
                    context.report({
                        node,
                        loc: node.body.loc,
                        messageId: "unexpected",
                        data: { name }
                    });
                }
            }
            return {
                ArrowFunctionExpression: reportIfEmpty,
                FunctionDeclaration: reportIfEmpty,
                FunctionExpression: reportIfEmpty
            };
        }
    };
},
/* eslint/lib/rules/no-empty-pattern.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to disallow an empty pattern
     * @author Alberto Rodríguez
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow empty destructuring patterns",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-empty-pattern"
            },
            schema: [],
            messages: {
                unexpected: "Unexpected empty {{type}} pattern."
            }
        },
        create(context) {
            return {
                ObjectPattern(node) {
                    if (node.properties.length === 0) {
                        context.report({ node, messageId: "unexpected", data: { type: "object" } });
                    }
                },
                ArrayPattern(node) {
                    if (node.elements.length === 0) {
                        context.report({ node, messageId: "unexpected", data: { type: "array" } });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-empty-static-block.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to disallow empty static blocks.
     * @author Sosuke Suzuki
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow empty static blocks",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-empty-static-block"
            },
            schema: [],
            messages: {
                unexpected: "Unexpected empty static block."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                StaticBlock(node) {
                    if (node.body.length === 0) {
                        const closingBrace = sourceCode.getLastToken(node);
                        if (sourceCode.getCommentsBefore(closingBrace).length === 0) {
                            context.report({
                                node,
                                messageId: "unexpected"
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-eq-null.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag comparisons to null without a type-checking
     * operator.
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `null` comparisons without type-checking operators",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-eq-null"
            },
            schema: [],
            messages: {
                unexpected: "Use '===' to compare with null."
            }
        },
        create(context) {
            return {
                BinaryExpression(node) {
                    const badOperator = node.operator === "==" || node.operator === "!=";
                    if (node.right.type === "Literal" && node.right.raw === "null" && badOperator ||
                        node.left.type === "Literal" && node.left.raw === "null" && badOperator) {
                        context.report({ node, messageId: "unexpected" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-eval.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of eval() statement
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const candidatesOfGlobalObject = Object.freeze([
        "global",
        "window",
        "globalThis"
    ]);
    /**
     * Checks a given node is a MemberExpression node which has the specified name's
     * property.
     * @param {ASTNode} node A node to check.
     * @param {string} name A name to check.
     * @returns {boolean} `true` if the node is a MemberExpression node which has
     *      the specified name's property
     */
    function isMember(node, name) {
        return astUtils.isSpecificMemberAccess(node, null, name);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the use of `eval()`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-eval"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowIndirect: { type: "boolean", default: false }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpected: "eval can be harmful."
            }
        },
        create(context) {
            const allowIndirect = Boolean(context.options[0] &&
                context.options[0].allowIndirect);
            const sourceCode = context.getSourceCode();
            let funcInfo = null;
            /**
             * Pushes a `this` scope (non-arrow function, class static block, or class field initializer) information to the stack.
             * Top-level scopes are handled separately.
             *
             * This is used in order to check whether or not `this` binding is a
             * reference to the global object.
             * @param {ASTNode} node A node of the scope.
             *      For functions, this is one of FunctionDeclaration, FunctionExpression.
             *      For class static blocks, this is StaticBlock.
             *      For class field initializers, this can be any node that is PropertyDefinition#value.
             * @returns {void}
             */
            function enterThisScope(node) {
                const strict = context.getScope().isStrict;
                funcInfo = {
                    upper: funcInfo,
                    node,
                    strict,
                    isTopLevelOfScript: false,
                    defaultThis: false,
                    initialized: strict
                };
            }
            /**
             * Pops a variable scope from the stack.
             * @returns {void}
             */
            function exitThisScope() {
                funcInfo = funcInfo.upper;
            }
            /**
             * Reports a given node.
             *
             * `node` is `Identifier` or `MemberExpression`.
             * The parent of `node` might be `CallExpression`.
             *
             * The location of the report is always `eval` `Identifier` (or possibly
             * `Literal`). The type of the report is `CallExpression` if the parent is
             * `CallExpression`. Otherwise, it's the given node type.
             * @param {ASTNode} node A node to report.
             * @returns {void}
             */
            function report(node) {
                const parent = node.parent;
                const locationNode = node.type === "MemberExpression"
                    ? node.property
                    : node;
                const reportNode = parent.type === "CallExpression" && parent.callee === node
                    ? parent
                    : node;
                context.report({
                    node: reportNode,
                    loc: locationNode.loc,
                    messageId: "unexpected"
                });
            }
            /**
             * Reports accesses of `eval` via the global object.
             * @param {eslint-scope.Scope} globalScope The global scope.
             * @returns {void}
             */
            function reportAccessingEvalViaGlobalObject(globalScope) {
                for (let i = 0; i < candidatesOfGlobalObject.length; ++i) {
                    const name = candidatesOfGlobalObject[i];
                    const variable = astUtils.getVariableByName(globalScope, name);
                    if (!variable) {
                        continue;
                    }
                    const references = variable.references;
                    for (let j = 0; j < references.length; ++j) {
                        const identifier = references[j].identifier;
                        let node = identifier.parent;
                        // To detect code like `window.window.eval`.
                        while (isMember(node, name)) {
                            node = node.parent;
                        }
                        // Reports.
                        if (isMember(node, "eval")) {
                            report(node);
                        }
                    }
                }
            }
            /**
             * Reports all accesses of `eval` (excludes direct calls to eval).
             * @param {eslint-scope.Scope} globalScope The global scope.
             * @returns {void}
             */
            function reportAccessingEval(globalScope) {
                const variable = astUtils.getVariableByName(globalScope, "eval");
                if (!variable) {
                    return;
                }
                const references = variable.references;
                for (let i = 0; i < references.length; ++i) {
                    const reference = references[i];
                    const id = reference.identifier;
                    if (id.name === "eval" && !astUtils.isCallee(id)) {
                        // Is accessing to eval (excludes direct calls to eval)
                        report(id);
                    }
                }
            }
            if (allowIndirect) {
                // Checks only direct calls to eval. It's simple!
                return {
                    "CallExpression:exit"(node) {
                        const callee = node.callee;
                        /*
                         * Optional call (`eval?.("code")`) is not direct eval.
                         * The direct eval is only step 6.a.vi of https://tc39.es/ecma262/#sec-function-calls-runtime-semantics-evaluation
                         * But the optional call is https://tc39.es/ecma262/#sec-optional-chaining-chain-evaluation
                         */
                        if (!node.optional && astUtils.isSpecificId(callee, "eval")) {
                            report(callee);
                        }
                    }
                };
            }
            return {
                "CallExpression:exit"(node) {
                    const callee = node.callee;
                    if (astUtils.isSpecificId(callee, "eval")) {
                        report(callee);
                    }
                },
                Program(node) {
                    const scope = context.getScope(), features = context.parserOptions.ecmaFeatures || {}, strict = scope.isStrict ||
                        node.sourceType === "module" ||
                        (features.globalReturn && scope.childScopes[0].isStrict), isTopLevelOfScript = node.sourceType !== "module" && !features.globalReturn;
                    funcInfo = {
                        upper: null,
                        node,
                        strict,
                        isTopLevelOfScript,
                        defaultThis: true,
                        initialized: true
                    };
                },
                "Program:exit"() {
                    const globalScope = context.getScope();
                    exitThisScope();
                    reportAccessingEval(globalScope);
                    reportAccessingEvalViaGlobalObject(globalScope);
                },
                FunctionDeclaration: enterThisScope,
                "FunctionDeclaration:exit": exitThisScope,
                FunctionExpression: enterThisScope,
                "FunctionExpression:exit": exitThisScope,
                "PropertyDefinition > *.value": enterThisScope,
                "PropertyDefinition > *.value:exit": exitThisScope,
                StaticBlock: enterThisScope,
                "StaticBlock:exit": exitThisScope,
                ThisExpression(node) {
                    if (!isMember(node.parent, "eval")) {
                        return;
                    }
                    /*
                     * `this.eval` is found.
                     * Checks whether or not the value of `this` is the global object.
                     */
                    if (!funcInfo.initialized) {
                        funcInfo.initialized = true;
                        funcInfo.defaultThis = astUtils.isDefaultThisBinding(funcInfo.node, sourceCode);
                    }
                    // `this` at the top level of scripts always refers to the global object
                    if (funcInfo.isTopLevelOfScript || (!funcInfo.strict && funcInfo.defaultThis)) {
                        // `this.eval` is possible built-in `eval`.
                        report(node.parent);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-ex-assign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag assignment of the exception parameter
     * @author Stephen Murray <spmurrayzzz>
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow reassigning exceptions in `catch` clauses",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-ex-assign"
            },
            schema: [],
            messages: {
                unexpected: "Do not assign to the exception parameter."
            }
        },
        create(context) {
            /**
             * Finds and reports references that are non initializer and writable.
             * @param {Variable} variable A variable to check.
             * @returns {void}
             */
            function checkVariable(variable) {
                astUtils.getModifyingReferences(variable.references).forEach(reference => {
                    context.report({ node: reference.identifier, messageId: "unexpected" });
                });
            }
            return {
                CatchClause(node) {
                    context.getDeclaredVariables(node).forEach(checkVariable);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-extend-native.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag adding properties to native object's prototypes.
     * @author David Nelson
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const globals = require(279) /* globals */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow extending native types",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-extend-native"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        exceptions: {
                            type: "array",
                            items: {
                                type: "string"
                            },
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpected: "{{builtin}} prototype is read only, properties should not be added."
            }
        },
        create(context) {
            const config = context.options[0] || {};
            const exceptions = new Set(config.exceptions || []);
            const modifiedBuiltins = new Set(Object.keys(globals.builtin)
                .filter(builtin => builtin[0].toUpperCase() === builtin[0])
                .filter(builtin => !exceptions.has(builtin)));
            /**
             * Reports a lint error for the given node.
             * @param {ASTNode} node The node to report.
             * @param {string} builtin The name of the native builtin being extended.
             * @returns {void}
             */
            function reportNode(node, builtin) {
                context.report({
                    node,
                    messageId: "unexpected",
                    data: {
                        builtin
                    }
                });
            }
            /**
             * Check to see if the `prototype` property of the given object
             * identifier node is being accessed.
             * @param {ASTNode} identifierNode The Identifier representing the object
             * to check.
             * @returns {boolean} True if the identifier is the object of a
             * MemberExpression and its `prototype` property is being accessed,
             * false otherwise.
             */
            function isPrototypePropertyAccessed(identifierNode) {
                return Boolean(identifierNode &&
                    identifierNode.parent &&
                    identifierNode.parent.type === "MemberExpression" &&
                    identifierNode.parent.object === identifierNode &&
                    astUtils.getStaticPropertyName(identifierNode.parent) === "prototype");
            }
            /**
             * Check if it's an assignment to the property of the given node.
             * Example: `*.prop = 0` // the `*` is the given node.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} True if an assignment to the property of the node.
             */
            function isAssigningToPropertyOf(node) {
                return (node.parent.type === "MemberExpression" &&
                    node.parent.object === node &&
                    node.parent.parent.type === "AssignmentExpression" &&
                    node.parent.parent.left === node.parent);
            }
            /**
             * Checks if the given node is at the first argument of the method call of `Object.defineProperty()` or `Object.defineProperties()`.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} True if the node is at the first argument of the method call of `Object.defineProperty()` or `Object.defineProperties()`.
             */
            function isInDefinePropertyCall(node) {
                return (node.parent.type === "CallExpression" &&
                    node.parent.arguments[0] === node &&
                    astUtils.isSpecificMemberAccess(node.parent.callee, "Object", /^definePropert(?:y|ies)$/u));
            }
            /**
             * Check to see if object prototype access is part of a prototype
             * extension. There are three ways a prototype can be extended:
             * 1. Assignment to prototype property (Object.prototype.foo = 1)
             * 2. Object.defineProperty()/Object.defineProperties() on a prototype
             * If prototype extension is detected, report the AssignmentExpression
             * or CallExpression node.
             * @param {ASTNode} identifierNode The Identifier representing the object
             * which prototype is being accessed and possibly extended.
             * @returns {void}
             */
            function checkAndReportPrototypeExtension(identifierNode) {
                if (!isPrototypePropertyAccessed(identifierNode)) {
                    return; // This is not `*.prototype` access.
                }
                /*
                 * `identifierNode.parent` is a MemberExpression `*.prototype`.
                 * If it's an optional member access, it may be wrapped by a `ChainExpression` node.
                 */
                const prototypeNode = identifierNode.parent.parent.type === "ChainExpression"
                    ? identifierNode.parent.parent
                    : identifierNode.parent;
                if (isAssigningToPropertyOf(prototypeNode)) {
                    // `*.prototype` -> MemberExpression -> AssignmentExpression
                    reportNode(prototypeNode.parent.parent, identifierNode.name);
                }
                else if (isInDefinePropertyCall(prototypeNode)) {
                    // `*.prototype` -> CallExpression
                    reportNode(prototypeNode.parent, identifierNode.name);
                }
            }
            return {
                "Program:exit"() {
                    const globalScope = context.getScope();
                    modifiedBuiltins.forEach(builtin => {
                        const builtinVar = globalScope.set.get(builtin);
                        if (builtinVar && builtinVar.references) {
                            builtinVar.references
                                .map(ref => ref.identifier)
                                .forEach(checkAndReportPrototypeExtension);
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-extra-bind.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag unnecessary bind calls
     * @author Bence Dányi <bence@danyi.me>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const SIDE_EFFECT_FREE_NODE_TYPES = new Set(["Literal", "Identifier", "ThisExpression", "FunctionExpression"]);
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary calls to `.bind()`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-extra-bind"
            },
            schema: [],
            fixable: "code",
            messages: {
                unexpected: "The function binding is unnecessary."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            let scopeInfo = null;
            /**
             * Checks if a node is free of side effects.
             *
             * This check is stricter than it needs to be, in order to keep the implementation simple.
             * @param {ASTNode} node A node to check.
             * @returns {boolean} True if the node is known to be side-effect free, false otherwise.
             */
            function isSideEffectFree(node) {
                return SIDE_EFFECT_FREE_NODE_TYPES.has(node.type);
            }
            /**
             * Reports a given function node.
             * @param {ASTNode} node A node to report. This is a FunctionExpression or
             *      an ArrowFunctionExpression.
             * @returns {void}
             */
            function report(node) {
                const memberNode = node.parent;
                const callNode = memberNode.parent.type === "ChainExpression"
                    ? memberNode.parent.parent
                    : memberNode.parent;
                context.report({
                    node: callNode,
                    messageId: "unexpected",
                    loc: memberNode.property.loc,
                    fix(fixer) {
                        if (!isSideEffectFree(callNode.arguments[0])) {
                            return null;
                        }
                        /*
                         * The list of the first/last token pair of a removal range.
                         * This is two parts because closing parentheses may exist between the method name and arguments.
                         * E.g. `(function(){}.bind ) (obj)`
                         *                    ^^^^^   ^^^^^ < removal ranges
                         * E.g. `(function(){}?.['bind'] ) ?.(obj)`
                         *                    ^^^^^^^^^^   ^^^^^^^ < removal ranges
                         */
                        const tokenPairs = [
                            [
                                // `.`, `?.`, or `[` token.
                                sourceCode.getTokenAfter(memberNode.object, astUtils.isNotClosingParenToken),
                                // property name or `]` token.
                                sourceCode.getLastToken(memberNode)
                            ],
                            [
                                // `?.` or `(` token of arguments.
                                sourceCode.getTokenAfter(memberNode, astUtils.isNotClosingParenToken),
                                // `)` token of arguments.
                                sourceCode.getLastToken(callNode)
                            ]
                        ];
                        const firstTokenToRemove = tokenPairs[0][0];
                        const lastTokenToRemove = tokenPairs[1][1];
                        if (sourceCode.commentsExistBetween(firstTokenToRemove, lastTokenToRemove)) {
                            return null;
                        }
                        return tokenPairs.map(([start, end]) => fixer.removeRange([start.range[0], end.range[1]]));
                    }
                });
            }
            /**
             * Checks whether or not a given function node is the callee of `.bind()`
             * method.
             *
             * e.g. `(function() {}.bind(foo))`
             * @param {ASTNode} node A node to report. This is a FunctionExpression or
             *      an ArrowFunctionExpression.
             * @returns {boolean} `true` if the node is the callee of `.bind()` method.
             */
            function isCalleeOfBindMethod(node) {
                if (!astUtils.isSpecificMemberAccess(node.parent, null, "bind")) {
                    return false;
                }
                // The node of `*.bind` member access.
                const bindNode = node.parent.parent.type === "ChainExpression"
                    ? node.parent.parent
                    : node.parent;
                return (bindNode.parent.type === "CallExpression" &&
                    bindNode.parent.callee === bindNode &&
                    bindNode.parent.arguments.length === 1 &&
                    bindNode.parent.arguments[0].type !== "SpreadElement");
            }
            /**
             * Adds a scope information object to the stack.
             * @param {ASTNode} node A node to add. This node is a FunctionExpression
             *      or a FunctionDeclaration node.
             * @returns {void}
             */
            function enterFunction(node) {
                scopeInfo = {
                    isBound: isCalleeOfBindMethod(node),
                    thisFound: false,
                    upper: scopeInfo
                };
            }
            /**
             * Removes the scope information object from the top of the stack.
             * At the same time, this reports the function node if the function has
             * `.bind()` and the `this` keywords found.
             * @param {ASTNode} node A node to remove. This node is a
             *      FunctionExpression or a FunctionDeclaration node.
             * @returns {void}
             */
            function exitFunction(node) {
                if (scopeInfo.isBound && !scopeInfo.thisFound) {
                    report(node);
                }
                scopeInfo = scopeInfo.upper;
            }
            /**
             * Reports a given arrow function if the function is callee of `.bind()`
             * method.
             * @param {ASTNode} node A node to report. This node is an
             *      ArrowFunctionExpression.
             * @returns {void}
             */
            function exitArrowFunction(node) {
                if (isCalleeOfBindMethod(node)) {
                    report(node);
                }
            }
            /**
             * Set the mark as the `this` keyword was found in this scope.
             * @returns {void}
             */
            function markAsThisFound() {
                if (scopeInfo) {
                    scopeInfo.thisFound = true;
                }
            }
            return {
                "ArrowFunctionExpression:exit": exitArrowFunction,
                FunctionDeclaration: enterFunction,
                "FunctionDeclaration:exit": exitFunction,
                FunctionExpression: enterFunction,
                "FunctionExpression:exit": exitFunction,
                ThisExpression: markAsThisFound
            };
        }
    };
},
/* eslint/lib/rules/no-extra-boolean-cast.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag unnecessary double negation in Boolean contexts
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const eslintUtils = require(316) /* @eslint-community/eslint-utils */;
    const precedence = astUtils.getPrecedence;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary boolean casts",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-extra-boolean-cast"
            },
            schema: [{
                    type: "object",
                    properties: {
                        enforceForLogicalOperands: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }],
            fixable: "code",
            messages: {
                unexpectedCall: "Redundant Boolean call.",
                unexpectedNegation: "Redundant double negation."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            // Node types which have a test which will coerce values to booleans.
            const BOOLEAN_NODE_TYPES = new Set([
                "IfStatement",
                "DoWhileStatement",
                "WhileStatement",
                "ConditionalExpression",
                "ForStatement"
            ]);
            /**
             * Check if a node is a Boolean function or constructor.
             * @param {ASTNode} node the node
             * @returns {boolean} If the node is Boolean function or constructor
             */
            function isBooleanFunctionOrConstructorCall(node) {
                // Boolean(<bool>) and new Boolean(<bool>)
                return (node.type === "CallExpression" || node.type === "NewExpression") &&
                    node.callee.type === "Identifier" &&
                    node.callee.name === "Boolean";
            }
            /**
             * Checks whether the node is a logical expression and that the option is enabled
             * @param {ASTNode} node the node
             * @returns {boolean} if the node is a logical expression and option is enabled
             */
            function isLogicalContext(node) {
                return node.type === "LogicalExpression" &&
                    (node.operator === "||" || node.operator === "&&") &&
                    (context.options.length && context.options[0].enforceForLogicalOperands === true);
            }
            /**
             * Check if a node is in a context where its value would be coerced to a boolean at runtime.
             * @param {ASTNode} node The node
             * @returns {boolean} If it is in a boolean context
             */
            function isInBooleanContext(node) {
                return ((isBooleanFunctionOrConstructorCall(node.parent) &&
                    node === node.parent.arguments[0]) ||
                    (BOOLEAN_NODE_TYPES.has(node.parent.type) &&
                        node === node.parent.test) ||
                    // !<bool>
                    (node.parent.type === "UnaryExpression" &&
                        node.parent.operator === "!"));
            }
            /**
             * Checks whether the node is a context that should report an error
             * Acts recursively if it is in a logical context
             * @param {ASTNode} node the node
             * @returns {boolean} If the node is in one of the flagged contexts
             */
            function isInFlaggedContext(node) {
                if (node.parent.type === "ChainExpression") {
                    return isInFlaggedContext(node.parent);
                }
                return isInBooleanContext(node) ||
                    (isLogicalContext(node.parent) &&
                        // For nested logical statements
                        isInFlaggedContext(node.parent));
            }
            /**
             * Check if a node has comments inside.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} `true` if it has comments inside.
             */
            function hasCommentsInside(node) {
                return Boolean(sourceCode.getCommentsInside(node).length);
            }
            /**
             * Checks if the given node is wrapped in grouping parentheses. Parentheses for constructs such as if() don't count.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} `true` if the node is parenthesized.
             * @private
             */
            function isParenthesized(node) {
                return eslintUtils.isParenthesized(1, node, sourceCode);
            }
            /**
             * Determines whether the given node needs to be parenthesized when replacing the previous node.
             * It assumes that `previousNode` is the node to be reported by this rule, so it has a limited list
             * of possible parent node types. By the same assumption, the node's role in a particular parent is already known.
             * For example, if the parent is `ConditionalExpression`, `previousNode` must be its `test` child.
             * @param {ASTNode} previousNode Previous node.
             * @param {ASTNode} node The node to check.
             * @throws {Error} (Unreachable.)
             * @returns {boolean} `true` if the node needs to be parenthesized.
             */
            function needsParens(previousNode, node) {
                if (previousNode.parent.type === "ChainExpression") {
                    return needsParens(previousNode.parent, node);
                }
                if (isParenthesized(previousNode)) {
                    // parentheses around the previous node will stay, so there is no need for an additional pair
                    return false;
                }
                // parent of the previous node will become parent of the replacement node
                const parent = previousNode.parent;
                switch (parent.type) {
                    case "CallExpression":
                    case "NewExpression":
                        return node.type === "SequenceExpression";
                    case "IfStatement":
                    case "DoWhileStatement":
                    case "WhileStatement":
                    case "ForStatement":
                        return false;
                    case "ConditionalExpression":
                        return precedence(node) <= precedence(parent);
                    case "UnaryExpression":
                        return precedence(node) < precedence(parent);
                    case "LogicalExpression":
                        if (astUtils.isMixedLogicalAndCoalesceExpressions(node, parent)) {
                            return true;
                        }
                        if (previousNode === parent.left) {
                            return precedence(node) < precedence(parent);
                        }
                        return precedence(node) <= precedence(parent);
                    /* c8 ignore next */
                    default:
                        throw new Error(`Unexpected parent type: ${parent.type}`);
                }
            }
            return {
                UnaryExpression(node) {
                    const parent = node.parent;
                    // Exit early if it's guaranteed not to match
                    if (node.operator !== "!" ||
                        parent.type !== "UnaryExpression" ||
                        parent.operator !== "!") {
                        return;
                    }
                    if (isInFlaggedContext(parent)) {
                        context.report({
                            node: parent,
                            messageId: "unexpectedNegation",
                            fix(fixer) {
                                if (hasCommentsInside(parent)) {
                                    return null;
                                }
                                if (needsParens(parent, node.argument)) {
                                    return fixer.replaceText(parent, `(${sourceCode.getText(node.argument)})`);
                                }
                                let prefix = "";
                                const tokenBefore = sourceCode.getTokenBefore(parent);
                                const firstReplacementToken = sourceCode.getFirstToken(node.argument);
                                if (tokenBefore &&
                                    tokenBefore.range[1] === parent.range[0] &&
                                    !astUtils.canTokensBeAdjacent(tokenBefore, firstReplacementToken)) {
                                    prefix = " ";
                                }
                                return fixer.replaceText(parent, prefix + sourceCode.getText(node.argument));
                            }
                        });
                    }
                },
                CallExpression(node) {
                    if (node.callee.type !== "Identifier" || node.callee.name !== "Boolean") {
                        return;
                    }
                    if (isInFlaggedContext(node)) {
                        context.report({
                            node,
                            messageId: "unexpectedCall",
                            fix(fixer) {
                                const parent = node.parent;
                                if (node.arguments.length === 0) {
                                    if (parent.type === "UnaryExpression" && parent.operator === "!") {
                                        /*
                                         * !Boolean() -> true
                                         */
                                        if (hasCommentsInside(parent)) {
                                            return null;
                                        }
                                        const replacement = "true";
                                        let prefix = "";
                                        const tokenBefore = sourceCode.getTokenBefore(parent);
                                        if (tokenBefore &&
                                            tokenBefore.range[1] === parent.range[0] &&
                                            !astUtils.canTokensBeAdjacent(tokenBefore, replacement)) {
                                            prefix = " ";
                                        }
                                        return fixer.replaceText(parent, prefix + replacement);
                                    }
                                    /*
                                     * Boolean() -> false
                                     */
                                    if (hasCommentsInside(node)) {
                                        return null;
                                    }
                                    return fixer.replaceText(node, "false");
                                }
                                if (node.arguments.length === 1) {
                                    const argument = node.arguments[0];
                                    if (argument.type === "SpreadElement" || hasCommentsInside(node)) {
                                        return null;
                                    }
                                    /*
                                     * Boolean(expression) -> expression
                                     */
                                    if (needsParens(node, argument)) {
                                        return fixer.replaceText(node, `(${sourceCode.getText(argument)})`);
                                    }
                                    return fixer.replaceText(node, sourceCode.getText(argument));
                                }
                                // two or more arguments
                                return null;
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-extra-label.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow unnecessary labels
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary labels",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-extra-label"
            },
            schema: [],
            fixable: "code",
            messages: {
                unexpected: "This label '{{name}}' is unnecessary."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            let scopeInfo = null;
            /**
             * Creates a new scope with a breakable statement.
             * @param {ASTNode} node A node to create. This is a BreakableStatement.
             * @returns {void}
             */
            function enterBreakableStatement(node) {
                scopeInfo = {
                    label: node.parent.type === "LabeledStatement" ? node.parent.label : null,
                    breakable: true,
                    upper: scopeInfo
                };
            }
            /**
             * Removes the top scope of the stack.
             * @returns {void}
             */
            function exitBreakableStatement() {
                scopeInfo = scopeInfo.upper;
            }
            /**
             * Creates a new scope with a labeled statement.
             *
             * This ignores it if the body is a breakable statement.
             * In this case it's handled in the `enterBreakableStatement` function.
             * @param {ASTNode} node A node to create. This is a LabeledStatement.
             * @returns {void}
             */
            function enterLabeledStatement(node) {
                if (!astUtils.isBreakableStatement(node.body)) {
                    scopeInfo = {
                        label: node.label,
                        breakable: false,
                        upper: scopeInfo
                    };
                }
            }
            /**
             * Removes the top scope of the stack.
             *
             * This ignores it if the body is a breakable statement.
             * In this case it's handled in the `exitBreakableStatement` function.
             * @param {ASTNode} node A node. This is a LabeledStatement.
             * @returns {void}
             */
            function exitLabeledStatement(node) {
                if (!astUtils.isBreakableStatement(node.body)) {
                    scopeInfo = scopeInfo.upper;
                }
            }
            /**
             * Reports a given control node if it's unnecessary.
             * @param {ASTNode} node A node. This is a BreakStatement or a
             *      ContinueStatement.
             * @returns {void}
             */
            function reportIfUnnecessary(node) {
                if (!node.label) {
                    return;
                }
                const labelNode = node.label;
                for (let info = scopeInfo; info !== null; info = info.upper) {
                    if (info.breakable || info.label && info.label.name === labelNode.name) {
                        if (info.breakable && info.label && info.label.name === labelNode.name) {
                            context.report({
                                node: labelNode,
                                messageId: "unexpected",
                                data: labelNode,
                                fix(fixer) {
                                    const breakOrContinueToken = sourceCode.getFirstToken(node);
                                    if (sourceCode.commentsExistBetween(breakOrContinueToken, labelNode)) {
                                        return null;
                                    }
                                    return fixer.removeRange([breakOrContinueToken.range[1], labelNode.range[1]]);
                                }
                            });
                        }
                        return;
                    }
                }
            }
            return {
                WhileStatement: enterBreakableStatement,
                "WhileStatement:exit": exitBreakableStatement,
                DoWhileStatement: enterBreakableStatement,
                "DoWhileStatement:exit": exitBreakableStatement,
                ForStatement: enterBreakableStatement,
                "ForStatement:exit": exitBreakableStatement,
                ForInStatement: enterBreakableStatement,
                "ForInStatement:exit": exitBreakableStatement,
                ForOfStatement: enterBreakableStatement,
                "ForOfStatement:exit": exitBreakableStatement,
                SwitchStatement: enterBreakableStatement,
                "SwitchStatement:exit": exitBreakableStatement,
                LabeledStatement: enterLabeledStatement,
                "LabeledStatement:exit": exitLabeledStatement,
                BreakStatement: reportIfUnnecessary,
                ContinueStatement: reportIfUnnecessary
            };
        }
    };
},
/* eslint/lib/rules/no-extra-parens.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow parenthesising higher precedence subexpressions.
     * @author Michael Ficarra
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const { isParenthesized: isParenthesizedRaw } = require(316) /* @eslint-community/eslint-utils */;
    const astUtils = require(360) /* ./utils/ast-utils.js */;
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Disallow unnecessary parentheses",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-extra-parens"
            },
            fixable: "code",
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["functions"]
                            }
                        ],
                        minItems: 0,
                        maxItems: 1
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["all"]
                            },
                            {
                                type: "object",
                                properties: {
                                    conditionalAssign: { type: "boolean" },
                                    nestedBinaryExpressions: { type: "boolean" },
                                    returnAssign: { type: "boolean" },
                                    ignoreJSX: { enum: ["none", "all", "single-line", "multi-line"] },
                                    enforceForArrowConditionals: { type: "boolean" },
                                    enforceForSequenceExpressions: { type: "boolean" },
                                    enforceForNewInMemberExpressions: { type: "boolean" },
                                    enforceForFunctionPrototypeMethods: { type: "boolean" },
                                    allowParensAfterCommentPattern: { type: "string" }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    }
                ]
            },
            messages: {
                unexpected: "Unnecessary parentheses around expression."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const tokensToIgnore = new WeakSet();
            const precedence = astUtils.getPrecedence;
            const ALL_NODES = context.options[0] !== "functions";
            const EXCEPT_COND_ASSIGN = ALL_NODES && context.options[1] && context.options[1].conditionalAssign === false;
            const NESTED_BINARY = ALL_NODES && context.options[1] && context.options[1].nestedBinaryExpressions === false;
            const EXCEPT_RETURN_ASSIGN = ALL_NODES && context.options[1] && context.options[1].returnAssign === false;
            const IGNORE_JSX = ALL_NODES && context.options[1] && context.options[1].ignoreJSX;
            const IGNORE_ARROW_CONDITIONALS = ALL_NODES && context.options[1] &&
                context.options[1].enforceForArrowConditionals === false;
            const IGNORE_SEQUENCE_EXPRESSIONS = ALL_NODES && context.options[1] &&
                context.options[1].enforceForSequenceExpressions === false;
            const IGNORE_NEW_IN_MEMBER_EXPR = ALL_NODES && context.options[1] &&
                context.options[1].enforceForNewInMemberExpressions === false;
            const IGNORE_FUNCTION_PROTOTYPE_METHODS = ALL_NODES && context.options[1] &&
                context.options[1].enforceForFunctionPrototypeMethods === false;
            const ALLOW_PARENS_AFTER_COMMENT_PATTERN = ALL_NODES && context.options[1] && context.options[1].allowParensAfterCommentPattern;
            const PRECEDENCE_OF_ASSIGNMENT_EXPR = precedence({ type: "AssignmentExpression" });
            const PRECEDENCE_OF_UPDATE_EXPR = precedence({ type: "UpdateExpression" });
            let reportsBuffer;
            /**
             * Determines whether the given node is a `call` or `apply` method call, invoked directly on a `FunctionExpression` node.
             * Example: function(){}.call()
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the node is an immediate `call` or `apply` method call.
             * @private
             */
            function isImmediateFunctionPrototypeMethodCall(node) {
                const callNode = astUtils.skipChainExpression(node);
                if (callNode.type !== "CallExpression") {
                    return false;
                }
                const callee = astUtils.skipChainExpression(callNode.callee);
                return (callee.type === "MemberExpression" &&
                    callee.object.type === "FunctionExpression" &&
                    ["call", "apply"].includes(astUtils.getStaticPropertyName(callee)));
            }
            /**
             * Determines if this rule should be enforced for a node given the current configuration.
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the rule should be enforced for this node.
             * @private
             */
            function ruleApplies(node) {
                if (node.type === "JSXElement" || node.type === "JSXFragment") {
                    const isSingleLine = node.loc.start.line === node.loc.end.line;
                    switch (IGNORE_JSX) {
                        // Exclude this JSX element from linting
                        case "all":
                            return false;
                        // Exclude this JSX element if it is multi-line element
                        case "multi-line":
                            return isSingleLine;
                        // Exclude this JSX element if it is single-line element
                        case "single-line":
                            return !isSingleLine;
                        // Nothing special to be done for JSX elements
                        case "none":
                            break;
                        // no default
                    }
                }
                if (node.type === "SequenceExpression" && IGNORE_SEQUENCE_EXPRESSIONS) {
                    return false;
                }
                if (isImmediateFunctionPrototypeMethodCall(node) && IGNORE_FUNCTION_PROTOTYPE_METHODS) {
                    return false;
                }
                return ALL_NODES || node.type === "FunctionExpression" || node.type === "ArrowFunctionExpression";
            }
            /**
             * Determines if a node is surrounded by parentheses.
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the node is parenthesised.
             * @private
             */
            function isParenthesised(node) {
                return isParenthesizedRaw(1, node, sourceCode);
            }
            /**
             * Determines if a node is surrounded by parentheses twice.
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the node is doubly parenthesised.
             * @private
             */
            function isParenthesisedTwice(node) {
                return isParenthesizedRaw(2, node, sourceCode);
            }
            /**
             * Determines if a node is surrounded by (potentially) invalid parentheses.
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the node is incorrectly parenthesised.
             * @private
             */
            function hasExcessParens(node) {
                return ruleApplies(node) && isParenthesised(node);
            }
            /**
             * Determines if a node that is expected to be parenthesised is surrounded by
             * (potentially) invalid extra parentheses.
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the node is has an unexpected extra pair of parentheses.
             * @private
             */
            function hasDoubleExcessParens(node) {
                return ruleApplies(node) && isParenthesisedTwice(node);
            }
            /**
             * Determines if a node that is expected to be parenthesised is surrounded by
             * (potentially) invalid extra parentheses with considering precedence level of the node.
             * If the preference level of the node is not higher or equal to precedence lower limit, it also checks
             * whether the node is surrounded by parentheses twice or not.
             * @param {ASTNode} node The node to be checked.
             * @param {number} precedenceLowerLimit The lower limit of precedence.
             * @returns {boolean} True if the node is has an unexpected extra pair of parentheses.
             * @private
             */
            function hasExcessParensWithPrecedence(node, precedenceLowerLimit) {
                if (ruleApplies(node) && isParenthesised(node)) {
                    if (precedence(node) >= precedenceLowerLimit ||
                        isParenthesisedTwice(node)) {
                        return true;
                    }
                }
                return false;
            }
            /**
             * Determines if a node test expression is allowed to have a parenthesised assignment
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the assignment can be parenthesised.
             * @private
             */
            function isCondAssignException(node) {
                return EXCEPT_COND_ASSIGN && node.test.type === "AssignmentExpression";
            }
            /**
             * Determines if a node is in a return statement
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the node is in a return statement.
             * @private
             */
            function isInReturnStatement(node) {
                for (let currentNode = node; currentNode; currentNode = currentNode.parent) {
                    if (currentNode.type === "ReturnStatement" ||
                        (currentNode.type === "ArrowFunctionExpression" && currentNode.body.type !== "BlockStatement")) {
                        return true;
                    }
                }
                return false;
            }
            /**
             * Determines if a constructor function is newed-up with parens
             * @param {ASTNode} newExpression The NewExpression node to be checked.
             * @returns {boolean} True if the constructor is called with parens.
             * @private
             */
            function isNewExpressionWithParens(newExpression) {
                const lastToken = sourceCode.getLastToken(newExpression);
                const penultimateToken = sourceCode.getTokenBefore(lastToken);
                return newExpression.arguments.length > 0 ||
                    (
                    // The expression should end with its own parens, e.g., new new foo() is not a new expression with parens
                    astUtils.isOpeningParenToken(penultimateToken) &&
                        astUtils.isClosingParenToken(lastToken) &&
                        newExpression.callee.range[1] < newExpression.range[1]);
            }
            /**
             * Determines if a node is or contains an assignment expression
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the node is or contains an assignment expression.
             * @private
             */
            function containsAssignment(node) {
                if (node.type === "AssignmentExpression") {
                    return true;
                }
                if (node.type === "ConditionalExpression" &&
                    (node.consequent.type === "AssignmentExpression" || node.alternate.type === "AssignmentExpression")) {
                    return true;
                }
                if ((node.left && node.left.type === "AssignmentExpression") ||
                    (node.right && node.right.type === "AssignmentExpression")) {
                    return true;
                }
                return false;
            }
            /**
             * Determines if a node is contained by or is itself a return statement and is allowed to have a parenthesised assignment
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the assignment can be parenthesised.
             * @private
             */
            function isReturnAssignException(node) {
                if (!EXCEPT_RETURN_ASSIGN || !isInReturnStatement(node)) {
                    return false;
                }
                if (node.type === "ReturnStatement") {
                    return node.argument && containsAssignment(node.argument);
                }
                if (node.type === "ArrowFunctionExpression" && node.body.type !== "BlockStatement") {
                    return containsAssignment(node.body);
                }
                return containsAssignment(node);
            }
            /**
             * Determines if a node following a [no LineTerminator here] restriction is
             * surrounded by (potentially) invalid extra parentheses.
             * @param {Token} token The token preceding the [no LineTerminator here] restriction.
             * @param {ASTNode} node The node to be checked.
             * @returns {boolean} True if the node is incorrectly parenthesised.
             * @private
             */
            function hasExcessParensNoLineTerminator(token, node) {
                if (token.loc.end.line === node.loc.start.line) {
                    return hasExcessParens(node);
                }
                return hasDoubleExcessParens(node);
            }
            /**
             * Determines whether a node should be preceded by an additional space when removing parens
             * @param {ASTNode} node node to evaluate; must be surrounded by parentheses
             * @returns {boolean} `true` if a space should be inserted before the node
             * @private
             */
            function requiresLeadingSpace(node) {
                const leftParenToken = sourceCode.getTokenBefore(node);
                const tokenBeforeLeftParen = sourceCode.getTokenBefore(leftParenToken, { includeComments: true });
                const tokenAfterLeftParen = sourceCode.getTokenAfter(leftParenToken, { includeComments: true });
                return tokenBeforeLeftParen &&
                    tokenBeforeLeftParen.range[1] === leftParenToken.range[0] &&
                    leftParenToken.range[1] === tokenAfterLeftParen.range[0] &&
                    !astUtils.canTokensBeAdjacent(tokenBeforeLeftParen, tokenAfterLeftParen);
            }
            /**
             * Determines whether a node should be followed by an additional space when removing parens
             * @param {ASTNode} node node to evaluate; must be surrounded by parentheses
             * @returns {boolean} `true` if a space should be inserted after the node
             * @private
             */
            function requiresTrailingSpace(node) {
                const nextTwoTokens = sourceCode.getTokensAfter(node, { count: 2 });
                const rightParenToken = nextTwoTokens[0];
                const tokenAfterRightParen = nextTwoTokens[1];
                const tokenBeforeRightParen = sourceCode.getLastToken(node);
                return rightParenToken && tokenAfterRightParen &&
                    !sourceCode.isSpaceBetweenTokens(rightParenToken, tokenAfterRightParen) &&
                    !astUtils.canTokensBeAdjacent(tokenBeforeRightParen, tokenAfterRightParen);
            }
            /**
             * Determines if a given expression node is an IIFE
             * @param {ASTNode} node The node to check
             * @returns {boolean} `true` if the given node is an IIFE
             */
            function isIIFE(node) {
                const maybeCallNode = astUtils.skipChainExpression(node);
                return maybeCallNode.type === "CallExpression" && maybeCallNode.callee.type === "FunctionExpression";
            }
            /**
             * Determines if the given node can be the assignment target in destructuring or the LHS of an assignment.
             * This is to avoid an autofix that could change behavior because parsers mistakenly allow invalid syntax,
             * such as `(a = b) = c` and `[(a = b) = c] = []`. Ideally, this function shouldn't be necessary.
             * @param {ASTNode} [node] The node to check
             * @returns {boolean} `true` if the given node can be a valid assignment target
             */
            function canBeAssignmentTarget(node) {
                return node && (node.type === "Identifier" || node.type === "MemberExpression");
            }
            /**
             * Report the node
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function report(node) {
                const leftParenToken = sourceCode.getTokenBefore(node);
                const rightParenToken = sourceCode.getTokenAfter(node);
                if (!isParenthesisedTwice(node)) {
                    if (tokensToIgnore.has(sourceCode.getFirstToken(node))) {
                        return;
                    }
                    if (isIIFE(node) && !isParenthesised(node.callee)) {
                        return;
                    }
                    if (ALLOW_PARENS_AFTER_COMMENT_PATTERN) {
                        const commentsBeforeLeftParenToken = sourceCode.getCommentsBefore(leftParenToken);
                        const totalCommentsBeforeLeftParenTokenCount = commentsBeforeLeftParenToken.length;
                        const ignorePattern = new RegExp(ALLOW_PARENS_AFTER_COMMENT_PATTERN, "u");
                        if (totalCommentsBeforeLeftParenTokenCount > 0 &&
                            ignorePattern.test(commentsBeforeLeftParenToken[totalCommentsBeforeLeftParenTokenCount - 1].value)) {
                            return;
                        }
                    }
                }
                /**
                 * Finishes reporting
                 * @returns {void}
                 * @private
                 */
                function finishReport() {
                    context.report({
                        node,
                        loc: leftParenToken.loc,
                        messageId: "unexpected",
                        fix(fixer) {
                            const parenthesizedSource = sourceCode.text.slice(leftParenToken.range[1], rightParenToken.range[0]);
                            return fixer.replaceTextRange([
                                leftParenToken.range[0],
                                rightParenToken.range[1]
                            ], (requiresLeadingSpace(node) ? " " : "") + parenthesizedSource + (requiresTrailingSpace(node) ? " " : ""));
                        }
                    });
                }
                if (reportsBuffer) {
                    reportsBuffer.reports.push({ node, finishReport });
                    return;
                }
                finishReport();
            }
            /**
             * Evaluate a argument of the node.
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkArgumentWithPrecedence(node) {
                if (hasExcessParensWithPrecedence(node.argument, precedence(node))) {
                    report(node.argument);
                }
            }
            /**
             * Check if a member expression contains a call expression
             * @param {ASTNode} node MemberExpression node to evaluate
             * @returns {boolean} true if found, false if not
             */
            function doesMemberExpressionContainCallExpression(node) {
                let currentNode = node.object;
                let currentNodeType = node.object.type;
                while (currentNodeType === "MemberExpression") {
                    currentNode = currentNode.object;
                    currentNodeType = currentNode.type;
                }
                return currentNodeType === "CallExpression";
            }
            /**
             * Evaluate a new call
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkCallNew(node) {
                const callee = node.callee;
                if (hasExcessParensWithPrecedence(callee, precedence(node))) {
                    if (hasDoubleExcessParens(callee) ||
                        !(isIIFE(node) ||
                            // (new A)(); new (new A)();
                            (callee.type === "NewExpression" &&
                                !isNewExpressionWithParens(callee) &&
                                !(node.type === "NewExpression" &&
                                    !isNewExpressionWithParens(node))) ||
                            // new (a().b)(); new (a.b().c);
                            (node.type === "NewExpression" &&
                                callee.type === "MemberExpression" &&
                                doesMemberExpressionContainCallExpression(callee)) ||
                            // (a?.b)(); (a?.())();
                            (!node.optional &&
                                callee.type === "ChainExpression"))) {
                        report(node.callee);
                    }
                }
                node.arguments
                    .filter(arg => hasExcessParensWithPrecedence(arg, PRECEDENCE_OF_ASSIGNMENT_EXPR))
                    .forEach(report);
            }
            /**
             * Evaluate binary logicals
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkBinaryLogical(node) {
                const prec = precedence(node);
                const leftPrecedence = precedence(node.left);
                const rightPrecedence = precedence(node.right);
                const isExponentiation = node.operator === "**";
                const shouldSkipLeft = NESTED_BINARY && (node.left.type === "BinaryExpression" || node.left.type === "LogicalExpression");
                const shouldSkipRight = NESTED_BINARY && (node.right.type === "BinaryExpression" || node.right.type === "LogicalExpression");
                if (!shouldSkipLeft && hasExcessParens(node.left)) {
                    if (!(["AwaitExpression", "UnaryExpression"].includes(node.left.type) && isExponentiation) &&
                        !astUtils.isMixedLogicalAndCoalesceExpressions(node.left, node) &&
                        (leftPrecedence > prec || (leftPrecedence === prec && !isExponentiation)) ||
                        isParenthesisedTwice(node.left)) {
                        report(node.left);
                    }
                }
                if (!shouldSkipRight && hasExcessParens(node.right)) {
                    if (!astUtils.isMixedLogicalAndCoalesceExpressions(node.right, node) &&
                        (rightPrecedence > prec || (rightPrecedence === prec && isExponentiation)) ||
                        isParenthesisedTwice(node.right)) {
                        report(node.right);
                    }
                }
            }
            /**
             * Check the parentheses around the super class of the given class definition.
             * @param {ASTNode} node The node of class declarations to check.
             * @returns {void}
             */
            function checkClass(node) {
                if (!node.superClass) {
                    return;
                }
                /*
                 * If `node.superClass` is a LeftHandSideExpression, parentheses are extra.
                 * Otherwise, parentheses are needed.
                 */
                const hasExtraParens = precedence(node.superClass) > PRECEDENCE_OF_UPDATE_EXPR
                    ? hasExcessParens(node.superClass)
                    : hasDoubleExcessParens(node.superClass);
                if (hasExtraParens) {
                    report(node.superClass);
                }
            }
            /**
             * Check the parentheses around the argument of the given spread operator.
             * @param {ASTNode} node The node of spread elements/properties to check.
             * @returns {void}
             */
            function checkSpreadOperator(node) {
                if (hasExcessParensWithPrecedence(node.argument, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                    report(node.argument);
                }
            }
            /**
             * Checks the parentheses for an ExpressionStatement or ExportDefaultDeclaration
             * @param {ASTNode} node The ExpressionStatement.expression or ExportDefaultDeclaration.declaration node
             * @returns {void}
             */
            function checkExpressionOrExportStatement(node) {
                const firstToken = isParenthesised(node) ? sourceCode.getTokenBefore(node) : sourceCode.getFirstToken(node);
                const secondToken = sourceCode.getTokenAfter(firstToken, astUtils.isNotOpeningParenToken);
                const thirdToken = secondToken ? sourceCode.getTokenAfter(secondToken) : null;
                const tokenAfterClosingParens = secondToken ? sourceCode.getTokenAfter(secondToken, astUtils.isNotClosingParenToken) : null;
                if (astUtils.isOpeningParenToken(firstToken) &&
                    (astUtils.isOpeningBraceToken(secondToken) ||
                        secondToken.type === "Keyword" && (secondToken.value === "function" ||
                            secondToken.value === "class" ||
                            secondToken.value === "let" &&
                                tokenAfterClosingParens &&
                                (astUtils.isOpeningBracketToken(tokenAfterClosingParens) ||
                                    tokenAfterClosingParens.type === "Identifier")) ||
                        secondToken && secondToken.type === "Identifier" && secondToken.value === "async" && thirdToken && thirdToken.type === "Keyword" && thirdToken.value === "function")) {
                    tokensToIgnore.add(secondToken);
                }
                const hasExtraParens = node.parent.type === "ExportDefaultDeclaration"
                    ? hasExcessParensWithPrecedence(node, PRECEDENCE_OF_ASSIGNMENT_EXPR)
                    : hasExcessParens(node);
                if (hasExtraParens) {
                    report(node);
                }
            }
            /**
             * Finds the path from the given node to the specified ancestor.
             * @param {ASTNode} node First node in the path.
             * @param {ASTNode} ancestor Last node in the path.
             * @returns {ASTNode[]} Path, including both nodes.
             * @throws {Error} If the given node does not have the specified ancestor.
             */
            function pathToAncestor(node, ancestor) {
                const path = [node];
                let currentNode = node;
                while (currentNode !== ancestor) {
                    currentNode = currentNode.parent;
                    /* c8 ignore start */
                    if (currentNode === null) {
                        throw new Error("Nodes are not in the ancestor-descendant relationship.");
                    } /* c8 ignore stop */
                    path.push(currentNode);
                }
                return path;
            }
            /**
             * Finds the path from the given node to the specified descendant.
             * @param {ASTNode} node First node in the path.
             * @param {ASTNode} descendant Last node in the path.
             * @returns {ASTNode[]} Path, including both nodes.
             * @throws {Error} If the given node does not have the specified descendant.
             */
            function pathToDescendant(node, descendant) {
                return pathToAncestor(descendant, node).reverse();
            }
            /**
             * Checks whether the syntax of the given ancestor of an 'in' expression inside a for-loop initializer
             * is preventing the 'in' keyword from being interpreted as a part of an ill-formed for-in loop.
             * @param {ASTNode} node Ancestor of an 'in' expression.
             * @param {ASTNode} child Child of the node, ancestor of the same 'in' expression or the 'in' expression itself.
             * @returns {boolean} True if the keyword 'in' would be interpreted as the 'in' operator, without any parenthesis.
             */
            function isSafelyEnclosingInExpression(node, child) {
                switch (node.type) {
                    case "ArrayExpression":
                    case "ArrayPattern":
                    case "BlockStatement":
                    case "ObjectExpression":
                    case "ObjectPattern":
                    case "TemplateLiteral":
                        return true;
                    case "ArrowFunctionExpression":
                    case "FunctionExpression":
                        return node.params.includes(child);
                    case "CallExpression":
                    case "NewExpression":
                        return node.arguments.includes(child);
                    case "MemberExpression":
                        return node.computed && node.property === child;
                    case "ConditionalExpression":
                        return node.consequent === child;
                    default:
                        return false;
                }
            }
            /**
             * Starts a new reports buffering. Warnings will be stored in a buffer instead of being reported immediately.
             * An additional logic that requires multiple nodes (e.g. a whole subtree) may dismiss some of the stored warnings.
             * @returns {void}
             */
            function startNewReportsBuffering() {
                reportsBuffer = {
                    upper: reportsBuffer,
                    inExpressionNodes: [],
                    reports: []
                };
            }
            /**
             * Ends the current reports buffering.
             * @returns {void}
             */
            function endCurrentReportsBuffering() {
                const { upper, inExpressionNodes, reports } = reportsBuffer;
                if (upper) {
                    upper.inExpressionNodes.push(...inExpressionNodes);
                    upper.reports.push(...reports);
                }
                else {
                    // flush remaining reports
                    reports.forEach(({ finishReport }) => finishReport());
                }
                reportsBuffer = upper;
            }
            /**
             * Checks whether the given node is in the current reports buffer.
             * @param {ASTNode} node Node to check.
             * @returns {boolean} True if the node is in the current buffer, false otherwise.
             */
            function isInCurrentReportsBuffer(node) {
                return reportsBuffer.reports.some(r => r.node === node);
            }
            /**
             * Removes the given node from the current reports buffer.
             * @param {ASTNode} node Node to remove.
             * @returns {void}
             */
            function removeFromCurrentReportsBuffer(node) {
                reportsBuffer.reports = reportsBuffer.reports.filter(r => r.node !== node);
            }
            /**
             * Checks whether a node is a MemberExpression at NewExpression's callee.
             * @param {ASTNode} node node to check.
             * @returns {boolean} True if the node is a MemberExpression at NewExpression's callee. false otherwise.
             */
            function isMemberExpInNewCallee(node) {
                if (node.type === "MemberExpression") {
                    return node.parent.type === "NewExpression" && node.parent.callee === node
                        ? true
                        : node.parent.object === node && isMemberExpInNewCallee(node.parent);
                }
                return false;
            }
            /**
             * Checks if the left-hand side of an assignment is an identifier, the operator is one of
             * `=`, `&&=`, `||=` or `??=` and the right-hand side is an anonymous class or function.
             *
             * As per https://tc39.es/ecma262/#sec-assignment-operators-runtime-semantics-evaluation, an
             * assignment involving one of the operators `=`, `&&=`, `||=` or `??=` where the right-hand
             * side is an anonymous class or function and the left-hand side is an *unparenthesized*
             * identifier has different semantics than other assignments.
             * Specifically, when an expression like `foo = function () {}` is evaluated, `foo.name`
             * will be set to the string "foo", i.e. the identifier name. The same thing does not happen
             * when evaluating `(foo) = function () {}`.
             * Since the parenthesizing of the identifier in the left-hand side is significant in this
             * special case, the parentheses, if present, should not be flagged as unnecessary.
             * @param {ASTNode} node an AssignmentExpression node.
             * @returns {boolean} `true` if the left-hand side of the assignment is an identifier, the
             * operator is one of `=`, `&&=`, `||=` or `??=` and the right-hand side is an anonymous
             * class or function; otherwise, `false`.
             */
            function isAnonymousFunctionAssignmentException({ left, operator, right }) {
                if (left.type === "Identifier" && ["=", "&&=", "||=", "??="].includes(operator)) {
                    const rhsType = right.type;
                    if (rhsType === "ArrowFunctionExpression") {
                        return true;
                    }
                    if ((rhsType === "FunctionExpression" || rhsType === "ClassExpression") && !right.id) {
                        return true;
                    }
                }
                return false;
            }
            return {
                ArrayExpression(node) {
                    node.elements
                        .filter(e => e && hasExcessParensWithPrecedence(e, PRECEDENCE_OF_ASSIGNMENT_EXPR))
                        .forEach(report);
                },
                ArrayPattern(node) {
                    node.elements
                        .filter(e => canBeAssignmentTarget(e) && hasExcessParens(e))
                        .forEach(report);
                },
                ArrowFunctionExpression(node) {
                    if (isReturnAssignException(node)) {
                        return;
                    }
                    if (node.body.type === "ConditionalExpression" &&
                        IGNORE_ARROW_CONDITIONALS) {
                        return;
                    }
                    if (node.body.type !== "BlockStatement") {
                        const firstBodyToken = sourceCode.getFirstToken(node.body, astUtils.isNotOpeningParenToken);
                        const tokenBeforeFirst = sourceCode.getTokenBefore(firstBodyToken);
                        if (astUtils.isOpeningParenToken(tokenBeforeFirst) && astUtils.isOpeningBraceToken(firstBodyToken)) {
                            tokensToIgnore.add(firstBodyToken);
                        }
                        if (hasExcessParensWithPrecedence(node.body, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                            report(node.body);
                        }
                    }
                },
                AssignmentExpression(node) {
                    if (canBeAssignmentTarget(node.left) && hasExcessParens(node.left) &&
                        (!isAnonymousFunctionAssignmentException(node) || isParenthesisedTwice(node.left))) {
                        report(node.left);
                    }
                    if (!isReturnAssignException(node) && hasExcessParensWithPrecedence(node.right, precedence(node))) {
                        report(node.right);
                    }
                },
                BinaryExpression(node) {
                    if (reportsBuffer && node.operator === "in") {
                        reportsBuffer.inExpressionNodes.push(node);
                    }
                    checkBinaryLogical(node);
                },
                CallExpression: checkCallNew,
                ConditionalExpression(node) {
                    if (isReturnAssignException(node)) {
                        return;
                    }
                    if (!isCondAssignException(node) &&
                        hasExcessParensWithPrecedence(node.test, precedence({ type: "LogicalExpression", operator: "||" }))) {
                        report(node.test);
                    }
                    if (hasExcessParensWithPrecedence(node.consequent, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                        report(node.consequent);
                    }
                    if (hasExcessParensWithPrecedence(node.alternate, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                        report(node.alternate);
                    }
                },
                DoWhileStatement(node) {
                    if (hasExcessParens(node.test) && !isCondAssignException(node)) {
                        report(node.test);
                    }
                },
                ExportDefaultDeclaration: node => checkExpressionOrExportStatement(node.declaration),
                ExpressionStatement: node => checkExpressionOrExportStatement(node.expression),
                ForInStatement(node) {
                    if (node.left.type !== "VariableDeclaration") {
                        const firstLeftToken = sourceCode.getFirstToken(node.left, astUtils.isNotOpeningParenToken);
                        if (firstLeftToken.value === "let" &&
                            astUtils.isOpeningBracketToken(sourceCode.getTokenAfter(firstLeftToken, astUtils.isNotClosingParenToken))) {
                            // ForInStatement#left expression cannot start with `let[`.
                            tokensToIgnore.add(firstLeftToken);
                        }
                    }
                    if (hasExcessParens(node.left)) {
                        report(node.left);
                    }
                    if (hasExcessParens(node.right)) {
                        report(node.right);
                    }
                },
                ForOfStatement(node) {
                    if (node.left.type !== "VariableDeclaration") {
                        const firstLeftToken = sourceCode.getFirstToken(node.left, astUtils.isNotOpeningParenToken);
                        if (firstLeftToken.value === "let") {
                            // ForOfStatement#left expression cannot start with `let`.
                            tokensToIgnore.add(firstLeftToken);
                        }
                    }
                    if (hasExcessParens(node.left)) {
                        report(node.left);
                    }
                    if (hasExcessParensWithPrecedence(node.right, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                        report(node.right);
                    }
                },
                ForStatement(node) {
                    if (node.test && hasExcessParens(node.test) && !isCondAssignException(node)) {
                        report(node.test);
                    }
                    if (node.update && hasExcessParens(node.update)) {
                        report(node.update);
                    }
                    if (node.init) {
                        if (node.init.type !== "VariableDeclaration") {
                            const firstToken = sourceCode.getFirstToken(node.init, astUtils.isNotOpeningParenToken);
                            if (firstToken.value === "let" &&
                                astUtils.isOpeningBracketToken(sourceCode.getTokenAfter(firstToken, astUtils.isNotClosingParenToken))) {
                                // ForStatement#init expression cannot start with `let[`.
                                tokensToIgnore.add(firstToken);
                            }
                        }
                        startNewReportsBuffering();
                        if (hasExcessParens(node.init)) {
                            report(node.init);
                        }
                    }
                },
                "ForStatement > *.init:exit"(node) {
                    /*
                     * Removing parentheses around `in` expressions might change semantics and cause errors.
                     *
                     * For example, this valid for loop:
                     *      for (let a = (b in c); ;);
                     * after removing parentheses would be treated as an invalid for-in loop:
                     *      for (let a = b in c; ;);
                     */
                    if (reportsBuffer.reports.length) {
                        reportsBuffer.inExpressionNodes.forEach(inExpressionNode => {
                            const path = pathToDescendant(node, inExpressionNode);
                            let nodeToExclude;
                            for (let i = 0; i < path.length; i++) {
                                const pathNode = path[i];
                                if (i < path.length - 1) {
                                    const nextPathNode = path[i + 1];
                                    if (isSafelyEnclosingInExpression(pathNode, nextPathNode)) {
                                        // The 'in' expression in safely enclosed by the syntax of its ancestor nodes (e.g. by '{}' or '[]').
                                        return;
                                    }
                                }
                                if (isParenthesised(pathNode)) {
                                    if (isInCurrentReportsBuffer(pathNode)) {
                                        // This node was supposed to be reported, but parentheses might be necessary.
                                        if (isParenthesisedTwice(pathNode)) {
                                            /*
                                             * This node is parenthesised twice, it certainly has at least one pair of `extra` parentheses.
                                             * If the --fix option is on, the current fixing iteration will remove only one pair of parentheses.
                                             * The remaining pair is safely enclosing the 'in' expression.
                                             */
                                            return;
                                        }
                                        // Exclude the outermost node only.
                                        if (!nodeToExclude) {
                                            nodeToExclude = pathNode;
                                        }
                                        // Don't break the loop here, there might be some safe nodes or parentheses that will stay inside.
                                    }
                                    else {
                                        // This node will stay parenthesised, the 'in' expression in safely enclosed by '()'.
                                        return;
                                    }
                                }
                            }
                            // Exclude the node from the list (i.e. treat parentheses as necessary)
                            removeFromCurrentReportsBuffer(nodeToExclude);
                        });
                    }
                    endCurrentReportsBuffering();
                },
                IfStatement(node) {
                    if (hasExcessParens(node.test) && !isCondAssignException(node)) {
                        report(node.test);
                    }
                },
                ImportExpression(node) {
                    const { source } = node;
                    if (source.type === "SequenceExpression") {
                        if (hasDoubleExcessParens(source)) {
                            report(source);
                        }
                    }
                    else if (hasExcessParens(source)) {
                        report(source);
                    }
                },
                LogicalExpression: checkBinaryLogical,
                MemberExpression(node) {
                    const shouldAllowWrapOnce = isMemberExpInNewCallee(node) &&
                        doesMemberExpressionContainCallExpression(node);
                    const nodeObjHasExcessParens = shouldAllowWrapOnce
                        ? hasDoubleExcessParens(node.object)
                        : hasExcessParens(node.object) &&
                            !(isImmediateFunctionPrototypeMethodCall(node.parent) &&
                                node.parent.callee === node &&
                                IGNORE_FUNCTION_PROTOTYPE_METHODS);
                    if (nodeObjHasExcessParens &&
                        precedence(node.object) >= precedence(node) &&
                        (node.computed ||
                            !(astUtils.isDecimalInteger(node.object) ||
                                // RegExp literal is allowed to have parens (#1589)
                                (node.object.type === "Literal" && node.object.regex)))) {
                        report(node.object);
                    }
                    if (nodeObjHasExcessParens &&
                        node.object.type === "CallExpression") {
                        report(node.object);
                    }
                    if (nodeObjHasExcessParens &&
                        !IGNORE_NEW_IN_MEMBER_EXPR &&
                        node.object.type === "NewExpression" &&
                        isNewExpressionWithParens(node.object)) {
                        report(node.object);
                    }
                    if (nodeObjHasExcessParens &&
                        node.optional &&
                        node.object.type === "ChainExpression") {
                        report(node.object);
                    }
                    if (node.computed && hasExcessParens(node.property)) {
                        report(node.property);
                    }
                },
                "MethodDefinition[computed=true]"(node) {
                    if (hasExcessParensWithPrecedence(node.key, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                        report(node.key);
                    }
                },
                NewExpression: checkCallNew,
                ObjectExpression(node) {
                    node.properties
                        .filter(property => property.value && hasExcessParensWithPrecedence(property.value, PRECEDENCE_OF_ASSIGNMENT_EXPR))
                        .forEach(property => report(property.value));
                },
                ObjectPattern(node) {
                    node.properties
                        .filter(property => {
                        const value = property.value;
                        return canBeAssignmentTarget(value) && hasExcessParens(value);
                    }).forEach(property => report(property.value));
                },
                Property(node) {
                    if (node.computed) {
                        const { key } = node;
                        if (key && hasExcessParensWithPrecedence(key, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                            report(key);
                        }
                    }
                },
                PropertyDefinition(node) {
                    if (node.computed && hasExcessParensWithPrecedence(node.key, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                        report(node.key);
                    }
                    if (node.value && hasExcessParensWithPrecedence(node.value, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                        report(node.value);
                    }
                },
                RestElement(node) {
                    const argument = node.argument;
                    if (canBeAssignmentTarget(argument) && hasExcessParens(argument)) {
                        report(argument);
                    }
                },
                ReturnStatement(node) {
                    const returnToken = sourceCode.getFirstToken(node);
                    if (isReturnAssignException(node)) {
                        return;
                    }
                    if (node.argument &&
                        hasExcessParensNoLineTerminator(returnToken, node.argument) &&
                        // RegExp literal is allowed to have parens (#1589)
                        !(node.argument.type === "Literal" && node.argument.regex)) {
                        report(node.argument);
                    }
                },
                SequenceExpression(node) {
                    const precedenceOfNode = precedence(node);
                    node.expressions
                        .filter(e => hasExcessParensWithPrecedence(e, precedenceOfNode))
                        .forEach(report);
                },
                SwitchCase(node) {
                    if (node.test && hasExcessParens(node.test)) {
                        report(node.test);
                    }
                },
                SwitchStatement(node) {
                    if (hasExcessParens(node.discriminant)) {
                        report(node.discriminant);
                    }
                },
                ThrowStatement(node) {
                    const throwToken = sourceCode.getFirstToken(node);
                    if (hasExcessParensNoLineTerminator(throwToken, node.argument)) {
                        report(node.argument);
                    }
                },
                UnaryExpression: checkArgumentWithPrecedence,
                UpdateExpression(node) {
                    if (node.prefix) {
                        checkArgumentWithPrecedence(node);
                    }
                    else {
                        const { argument } = node;
                        const operatorToken = sourceCode.getLastToken(node);
                        if (argument.loc.end.line === operatorToken.loc.start.line) {
                            checkArgumentWithPrecedence(node);
                        }
                        else {
                            if (hasDoubleExcessParens(argument)) {
                                report(argument);
                            }
                        }
                    }
                },
                AwaitExpression: checkArgumentWithPrecedence,
                VariableDeclarator(node) {
                    if (node.init && hasExcessParensWithPrecedence(node.init, PRECEDENCE_OF_ASSIGNMENT_EXPR) &&
                        // RegExp literal is allowed to have parens (#1589)
                        !(node.init.type === "Literal" && node.init.regex)) {
                        report(node.init);
                    }
                },
                WhileStatement(node) {
                    if (hasExcessParens(node.test) && !isCondAssignException(node)) {
                        report(node.test);
                    }
                },
                WithStatement(node) {
                    if (hasExcessParens(node.object)) {
                        report(node.object);
                    }
                },
                YieldExpression(node) {
                    if (node.argument) {
                        const yieldToken = sourceCode.getFirstToken(node);
                        if ((precedence(node.argument) >= precedence(node) &&
                            hasExcessParensNoLineTerminator(yieldToken, node.argument)) ||
                            hasDoubleExcessParens(node.argument)) {
                            report(node.argument);
                        }
                    }
                },
                ClassDeclaration: checkClass,
                ClassExpression: checkClass,
                SpreadElement: checkSpreadOperator,
                SpreadProperty: checkSpreadOperator,
                ExperimentalSpreadProperty: checkSpreadOperator,
                TemplateLiteral(node) {
                    node.expressions
                        .filter(e => e && hasExcessParens(e))
                        .forEach(report);
                },
                AssignmentPattern(node) {
                    const { left, right } = node;
                    if (canBeAssignmentTarget(left) && hasExcessParens(left)) {
                        report(left);
                    }
                    if (right && hasExcessParensWithPrecedence(right, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                        report(right);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-extra-semi.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of unnecessary semicolons
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const FixTracker = require(496) /* ./utils/fix-tracker */;
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary semicolons",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-extra-semi"
            },
            fixable: "code",
            schema: [],
            messages: {
                unexpected: "Unnecessary semicolon."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Reports an unnecessary semicolon error.
             * @param {Node|Token} nodeOrToken A node or a token to be reported.
             * @returns {void}
             */
            function report(nodeOrToken) {
                context.report({
                    node: nodeOrToken,
                    messageId: "unexpected",
                    fix(fixer) {
                        /*
                         * Expand the replacement range to include the surrounding
                         * tokens to avoid conflicting with semi.
                         * https://github.com/eslint/eslint/issues/7928
                         */
                        return new FixTracker(fixer, context.getSourceCode())
                            .retainSurroundingTokens(nodeOrToken)
                            .remove(nodeOrToken);
                    }
                });
            }
            /**
             * Checks for a part of a class body.
             * This checks tokens from a specified token to a next MethodDefinition or the end of class body.
             * @param {Token} firstToken The first token to check.
             * @returns {void}
             */
            function checkForPartOfClassBody(firstToken) {
                for (let token = firstToken; token.type === "Punctuator" && !astUtils.isClosingBraceToken(token); token = sourceCode.getTokenAfter(token)) {
                    if (astUtils.isSemicolonToken(token)) {
                        report(token);
                    }
                }
            }
            return {
                /**
                 * Reports this empty statement, except if the parent node is a loop.
                 * @param {Node} node A EmptyStatement node to be reported.
                 * @returns {void}
                 */
                EmptyStatement(node) {
                    const parent = node.parent, allowedParentTypes = [
                        "ForStatement",
                        "ForInStatement",
                        "ForOfStatement",
                        "WhileStatement",
                        "DoWhileStatement",
                        "IfStatement",
                        "LabeledStatement",
                        "WithStatement"
                    ];
                    if (!allowedParentTypes.includes(parent.type)) {
                        report(node);
                    }
                },
                /**
                 * Checks tokens from the head of this class body to the first MethodDefinition or the end of this class body.
                 * @param {Node} node A ClassBody node to check.
                 * @returns {void}
                 */
                ClassBody(node) {
                    checkForPartOfClassBody(sourceCode.getFirstToken(node, 1)); // 0 is `{`.
                },
                /**
                 * Checks tokens from this MethodDefinition to the next MethodDefinition or the end of this class body.
                 * @param {Node} node A MethodDefinition node of the start point.
                 * @returns {void}
                 */
                "MethodDefinition, PropertyDefinition, StaticBlock"(node) {
                    checkForPartOfClassBody(sourceCode.getTokenAfter(node));
                }
            };
        }
    };
},
/* eslint/lib/rules/no-fallthrough.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag fall-through cases in switch statements.
     * @author Matt DuVall <http://mattduvall.com/>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { directivesPattern } = require(310) /* ../shared/directives */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const DEFAULT_FALLTHROUGH_COMMENT = /falls?\s?through/iu;
    /**
     * Checks whether or not a given comment string is really a fallthrough comment and not an ESLint directive.
     * @param {string} comment The comment string to check.
     * @param {RegExp} fallthroughCommentPattern The regular expression used for checking for fallthrough comments.
     * @returns {boolean} `true` if the comment string is truly a fallthrough comment.
     */
    function isFallThroughComment(comment, fallthroughCommentPattern) {
        return fallthroughCommentPattern.test(comment) && !directivesPattern.test(comment.trim());
    }
    /**
     * Checks whether or not a given case has a fallthrough comment.
     * @param {ASTNode} caseWhichFallsThrough SwitchCase node which falls through.
     * @param {ASTNode} subsequentCase The case after caseWhichFallsThrough.
     * @param {RuleContext} context A rule context which stores comments.
     * @param {RegExp} fallthroughCommentPattern A pattern to match comment to.
     * @returns {boolean} `true` if the case has a valid fallthrough comment.
     */
    function hasFallthroughComment(caseWhichFallsThrough, subsequentCase, context, fallthroughCommentPattern) {
        const sourceCode = context.getSourceCode();
        if (caseWhichFallsThrough.consequent.length === 1 && caseWhichFallsThrough.consequent[0].type === "BlockStatement") {
            const trailingCloseBrace = sourceCode.getLastToken(caseWhichFallsThrough.consequent[0]);
            const commentInBlock = sourceCode.getCommentsBefore(trailingCloseBrace).pop();
            if (commentInBlock && isFallThroughComment(commentInBlock.value, fallthroughCommentPattern)) {
                return true;
            }
        }
        const comment = sourceCode.getCommentsBefore(subsequentCase).pop();
        return Boolean(comment && isFallThroughComment(comment.value, fallthroughCommentPattern));
    }
    /**
     * Checks whether or not a given code path segment is reachable.
     * @param {CodePathSegment} segment A CodePathSegment to check.
     * @returns {boolean} `true` if the segment is reachable.
     */
    function isReachable(segment) {
        return segment.reachable;
    }
    /**
     * Checks whether a node and a token are separated by blank lines
     * @param {ASTNode} node The node to check
     * @param {Token} token The token to compare against
     * @returns {boolean} `true` if there are blank lines between node and token
     */
    function hasBlankLinesBetween(node, token) {
        return token.loc.start.line > node.loc.end.line + 1;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow fallthrough of `case` statements",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-fallthrough"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        commentPattern: {
                            type: "string",
                            default: ""
                        },
                        allowEmptyCase: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                case: "Expected a 'break' statement before 'case'.",
                default: "Expected a 'break' statement before 'default'."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            let currentCodePath = null;
            const sourceCode = context.getSourceCode();
            const allowEmptyCase = options.allowEmptyCase || false;
            /*
             * We need to use leading comments of the next SwitchCase node because
             * trailing comments is wrong if semicolons are omitted.
             */
            let fallthroughCase = null;
            let fallthroughCommentPattern = null;
            if (options.commentPattern) {
                fallthroughCommentPattern = new RegExp(options.commentPattern, "u");
            }
            else {
                fallthroughCommentPattern = DEFAULT_FALLTHROUGH_COMMENT;
            }
            return {
                onCodePathStart(codePath) {
                    currentCodePath = codePath;
                },
                onCodePathEnd() {
                    currentCodePath = currentCodePath.upper;
                },
                SwitchCase(node) {
                    /*
                     * Checks whether or not there is a fallthrough comment.
                     * And reports the previous fallthrough node if that does not exist.
                     */
                    if (fallthroughCase && (!hasFallthroughComment(fallthroughCase, node, context, fallthroughCommentPattern))) {
                        context.report({
                            messageId: node.test ? "case" : "default",
                            node
                        });
                    }
                    fallthroughCase = null;
                },
                "SwitchCase:exit"(node) {
                    const nextToken = sourceCode.getTokenAfter(node);
                    /*
                     * `reachable` meant fall through because statements preceded by
                     * `break`, `return`, or `throw` are unreachable.
                     * And allows empty cases and the last case.
                     */
                    if (currentCodePath.currentSegments.some(isReachable) &&
                        (node.consequent.length > 0 || (!allowEmptyCase && hasBlankLinesBetween(node, nextToken))) &&
                        node.parent.cases[node.parent.cases.length - 1] !== node) {
                        fallthroughCase = node;
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-floating-decimal.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of a leading/trailing decimal point in a numeric literal
     * @author James Allardice
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow leading or trailing decimal points in numeric literals",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-floating-decimal"
            },
            schema: [],
            fixable: "code",
            messages: {
                leading: "A leading decimal point can be confused with a dot.",
                trailing: "A trailing decimal point can be confused with a dot."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                Literal(node) {
                    if (typeof node.value === "number") {
                        if (node.raw.startsWith(".")) {
                            context.report({
                                node,
                                messageId: "leading",
                                fix(fixer) {
                                    const tokenBefore = sourceCode.getTokenBefore(node);
                                    const needsSpaceBefore = tokenBefore &&
                                        tokenBefore.range[1] === node.range[0] &&
                                        !astUtils.canTokensBeAdjacent(tokenBefore, `0${node.raw}`);
                                    return fixer.insertTextBefore(node, needsSpaceBefore ? " 0" : "0");
                                }
                            });
                        }
                        if (node.raw.indexOf(".") === node.raw.length - 1) {
                            context.report({
                                node,
                                messageId: "trailing",
                                fix: fixer => fixer.insertTextAfter(node, "0")
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-func-assign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of function declaration identifiers as variables.
     * @author Ian Christian Myers
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow reassigning `function` declarations",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-func-assign"
            },
            schema: [],
            messages: {
                isAFunction: "'{{name}}' is a function."
            }
        },
        create(context) {
            /**
             * Reports a reference if is non initializer and writable.
             * @param {References} references Collection of reference to check.
             * @returns {void}
             */
            function checkReference(references) {
                astUtils.getModifyingReferences(references).forEach(reference => {
                    context.report({
                        node: reference.identifier,
                        messageId: "isAFunction",
                        data: {
                            name: reference.identifier.name
                        }
                    });
                });
            }
            /**
             * Finds and reports references that are non initializer and writable.
             * @param {Variable} variable A variable to check.
             * @returns {void}
             */
            function checkVariable(variable) {
                if (variable.defs[0].type === "FunctionName") {
                    checkReference(variable.references);
                }
            }
            /**
             * Checks parameters of a given function node.
             * @param {ASTNode} node A function node to check.
             * @returns {void}
             */
            function checkForFunction(node) {
                context.getDeclaredVariables(node).forEach(checkVariable);
            }
            return {
                FunctionDeclaration: checkForFunction,
                FunctionExpression: checkForFunction
            };
        }
    };
},
/* eslint/lib/rules/no-global-assign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow assignments to native objects or read-only global variables
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow assignments to native objects or read-only global variables",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-global-assign"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        exceptions: {
                            type: "array",
                            items: { type: "string" },
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                globalShouldNotBeModified: "Read-only global '{{name}}' should not be modified."
            }
        },
        create(context) {
            const config = context.options[0];
            const exceptions = (config && config.exceptions) || [];
            /**
             * Reports write references.
             * @param {Reference} reference A reference to check.
             * @param {int} index The index of the reference in the references.
             * @param {Reference[]} references The array that the reference belongs to.
             * @returns {void}
             */
            function checkReference(reference, index, references) {
                const identifier = reference.identifier;
                if (reference.init === false &&
                    reference.isWrite() &&
                    /*
                     * Destructuring assignments can have multiple default value,
                     * so possibly there are multiple writeable references for the same identifier.
                     */
                    (index === 0 || references[index - 1].identifier !== identifier)) {
                    context.report({
                        node: identifier,
                        messageId: "globalShouldNotBeModified",
                        data: {
                            name: identifier.name
                        }
                    });
                }
            }
            /**
             * Reports write references if a given variable is read-only builtin.
             * @param {Variable} variable A variable to check.
             * @returns {void}
             */
            function checkVariable(variable) {
                if (variable.writeable === false && !exceptions.includes(variable.name)) {
                    variable.references.forEach(checkReference);
                }
            }
            return {
                Program() {
                    const globalScope = context.getScope();
                    globalScope.variables.forEach(checkVariable);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-implicit-coercion.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow the type conversions with shorter notations.
     * @author Toru Nagashima
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const INDEX_OF_PATTERN = /^(?:i|lastI)ndexOf$/u;
    const ALLOWABLE_OPERATORS = ["~", "!!", "+", "*"];
    /**
     * Parses and normalizes an option object.
     * @param {Object} options An option object to parse.
     * @returns {Object} The parsed and normalized option object.
     */
    function parseOptions(options) {
        return {
            boolean: "boolean" in options ? options.boolean : true,
            number: "number" in options ? options.number : true,
            string: "string" in options ? options.string : true,
            disallowTemplateShorthand: "disallowTemplateShorthand" in options ? options.disallowTemplateShorthand : false,
            allow: options.allow || []
        };
    }
    /**
     * Checks whether or not a node is a double logical negating.
     * @param {ASTNode} node An UnaryExpression node to check.
     * @returns {boolean} Whether or not the node is a double logical negating.
     */
    function isDoubleLogicalNegating(node) {
        return (node.operator === "!" &&
            node.argument.type === "UnaryExpression" &&
            node.argument.operator === "!");
    }
    /**
     * Checks whether or not a node is a binary negating of `.indexOf()` method calling.
     * @param {ASTNode} node An UnaryExpression node to check.
     * @returns {boolean} Whether or not the node is a binary negating of `.indexOf()` method calling.
     */
    function isBinaryNegatingOfIndexOf(node) {
        if (node.operator !== "~") {
            return false;
        }
        const callNode = astUtils.skipChainExpression(node.argument);
        return (callNode.type === "CallExpression" &&
            astUtils.isSpecificMemberAccess(callNode.callee, null, INDEX_OF_PATTERN));
    }
    /**
     * Checks whether or not a node is a multiplying by one.
     * @param {BinaryExpression} node A BinaryExpression node to check.
     * @returns {boolean} Whether or not the node is a multiplying by one.
     */
    function isMultiplyByOne(node) {
        return node.operator === "*" && (node.left.type === "Literal" && node.left.value === 1 ||
            node.right.type === "Literal" && node.right.value === 1);
    }
    /**
     * Checks whether the given node logically represents multiplication by a fraction of `1`.
     * For example, `a * 1` in `a * 1 / b` is technically multiplication by `1`, but the
     * whole expression can be logically interpreted as `a * (1 / b)` rather than `(a * 1) / b`.
     * @param {BinaryExpression} node A BinaryExpression node to check.
     * @param {SourceCode} sourceCode The source code object.
     * @returns {boolean} Whether or not the node is a multiplying by a fraction of `1`.
     */
    function isMultiplyByFractionOfOne(node, sourceCode) {
        return node.type === "BinaryExpression" &&
            node.operator === "*" &&
            (node.right.type === "Literal" && node.right.value === 1) &&
            node.parent.type === "BinaryExpression" &&
            node.parent.operator === "/" &&
            node.parent.left === node &&
            !astUtils.isParenthesised(sourceCode, node);
    }
    /**
     * Checks whether the result of a node is numeric or not
     * @param {ASTNode} node The node to test
     * @returns {boolean} true if the node is a number literal or a `Number()`, `parseInt` or `parseFloat` call
     */
    function isNumeric(node) {
        return (node.type === "Literal" && typeof node.value === "number" ||
            node.type === "CallExpression" && (node.callee.name === "Number" ||
                node.callee.name === "parseInt" ||
                node.callee.name === "parseFloat"));
    }
    /**
     * Returns the first non-numeric operand in a BinaryExpression. Designed to be
     * used from bottom to up since it walks up the BinaryExpression trees using
     * node.parent to find the result.
     * @param {BinaryExpression} node The BinaryExpression node to be walked up on
     * @returns {ASTNode|null} The first non-numeric item in the BinaryExpression tree or null
     */
    function getNonNumericOperand(node) {
        const left = node.left, right = node.right;
        if (right.type !== "BinaryExpression" && !isNumeric(right)) {
            return right;
        }
        if (left.type !== "BinaryExpression" && !isNumeric(left)) {
            return left;
        }
        return null;
    }
    /**
     * Checks whether an expression evaluates to a string.
     * @param {ASTNode} node node that represents the expression to check.
     * @returns {boolean} Whether or not the expression evaluates to a string.
     */
    function isStringType(node) {
        return astUtils.isStringLiteral(node) ||
            (node.type === "CallExpression" &&
                node.callee.type === "Identifier" &&
                node.callee.name === "String");
    }
    /**
     * Checks whether a node is an empty string literal or not.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} Whether or not the passed in node is an
     * empty string literal or not.
     */
    function isEmptyString(node) {
        return astUtils.isStringLiteral(node) && (node.value === "" || (node.type === "TemplateLiteral" && node.quasis.length === 1 && node.quasis[0].value.cooked === ""));
    }
    /**
     * Checks whether or not a node is a concatenating with an empty string.
     * @param {ASTNode} node A BinaryExpression node to check.
     * @returns {boolean} Whether or not the node is a concatenating with an empty string.
     */
    function isConcatWithEmptyString(node) {
        return node.operator === "+" && ((isEmptyString(node.left) && !isStringType(node.right)) ||
            (isEmptyString(node.right) && !isStringType(node.left)));
    }
    /**
     * Checks whether or not a node is appended with an empty string.
     * @param {ASTNode} node An AssignmentExpression node to check.
     * @returns {boolean} Whether or not the node is appended with an empty string.
     */
    function isAppendEmptyString(node) {
        return node.operator === "+=" && isEmptyString(node.right);
    }
    /**
     * Returns the operand that is not an empty string from a flagged BinaryExpression.
     * @param {ASTNode} node The flagged BinaryExpression node to check.
     * @returns {ASTNode} The operand that is not an empty string from a flagged BinaryExpression.
     */
    function getNonEmptyOperand(node) {
        return isEmptyString(node.left) ? node.right : node.left;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow shorthand type conversions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-implicit-coercion"
            },
            fixable: "code",
            schema: [{
                    type: "object",
                    properties: {
                        boolean: {
                            type: "boolean",
                            default: true
                        },
                        number: {
                            type: "boolean",
                            default: true
                        },
                        string: {
                            type: "boolean",
                            default: true
                        },
                        disallowTemplateShorthand: {
                            type: "boolean",
                            default: false
                        },
                        allow: {
                            type: "array",
                            items: {
                                enum: ALLOWABLE_OPERATORS
                            },
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                useRecommendation: "use `{{recommendation}}` instead."
            }
        },
        create(context) {
            const options = parseOptions(context.options[0] || {});
            const sourceCode = context.getSourceCode();
            /**
             * Reports an error and autofixes the node
             * @param {ASTNode} node An ast node to report the error on.
             * @param {string} recommendation The recommended code for the issue
             * @param {bool} shouldFix Whether this report should fix the node
             * @returns {void}
             */
            function report(node, recommendation, shouldFix) {
                context.report({
                    node,
                    messageId: "useRecommendation",
                    data: {
                        recommendation
                    },
                    fix(fixer) {
                        if (!shouldFix) {
                            return null;
                        }
                        const tokenBefore = sourceCode.getTokenBefore(node);
                        if (tokenBefore &&
                            tokenBefore.range[1] === node.range[0] &&
                            !astUtils.canTokensBeAdjacent(tokenBefore, recommendation)) {
                            return fixer.replaceText(node, ` ${recommendation}`);
                        }
                        return fixer.replaceText(node, recommendation);
                    }
                });
            }
            return {
                UnaryExpression(node) {
                    let operatorAllowed;
                    // !!foo
                    operatorAllowed = options.allow.includes("!!");
                    if (!operatorAllowed && options.boolean && isDoubleLogicalNegating(node)) {
                        const recommendation = `Boolean(${sourceCode.getText(node.argument.argument)})`;
                        report(node, recommendation, true);
                    }
                    // ~foo.indexOf(bar)
                    operatorAllowed = options.allow.includes("~");
                    if (!operatorAllowed && options.boolean && isBinaryNegatingOfIndexOf(node)) {
                        // `foo?.indexOf(bar) !== -1` will be true (== found) if the `foo` is nullish. So use `>= 0` in that case.
                        const comparison = node.argument.type === "ChainExpression" ? ">= 0" : "!== -1";
                        const recommendation = `${sourceCode.getText(node.argument)} ${comparison}`;
                        report(node, recommendation, false);
                    }
                    // +foo
                    operatorAllowed = options.allow.includes("+");
                    if (!operatorAllowed && options.number && node.operator === "+" && !isNumeric(node.argument)) {
                        const recommendation = `Number(${sourceCode.getText(node.argument)})`;
                        report(node, recommendation, true);
                    }
                },
                // Use `:exit` to prevent double reporting
                "BinaryExpression:exit"(node) {
                    let operatorAllowed;
                    // 1 * foo
                    operatorAllowed = options.allow.includes("*");
                    const nonNumericOperand = !operatorAllowed && options.number && isMultiplyByOne(node) && !isMultiplyByFractionOfOne(node, sourceCode) &&
                        getNonNumericOperand(node);
                    if (nonNumericOperand) {
                        const recommendation = `Number(${sourceCode.getText(nonNumericOperand)})`;
                        report(node, recommendation, true);
                    }
                    // "" + foo
                    operatorAllowed = options.allow.includes("+");
                    if (!operatorAllowed && options.string && isConcatWithEmptyString(node)) {
                        const recommendation = `String(${sourceCode.getText(getNonEmptyOperand(node))})`;
                        report(node, recommendation, true);
                    }
                },
                AssignmentExpression(node) {
                    // foo += ""
                    const operatorAllowed = options.allow.includes("+");
                    if (!operatorAllowed && options.string && isAppendEmptyString(node)) {
                        const code = sourceCode.getText(getNonEmptyOperand(node));
                        const recommendation = `${code} = String(${code})`;
                        report(node, recommendation, true);
                    }
                },
                TemplateLiteral(node) {
                    if (!options.disallowTemplateShorthand) {
                        return;
                    }
                    // tag`${foo}`
                    if (node.parent.type === "TaggedTemplateExpression") {
                        return;
                    }
                    // `` or `${foo}${bar}`
                    if (node.expressions.length !== 1) {
                        return;
                    }
                    //  `prefix${foo}`
                    if (node.quasis[0].value.cooked !== "") {
                        return;
                    }
                    //  `${foo}postfix`
                    if (node.quasis[1].value.cooked !== "") {
                        return;
                    }
                    // if the expression is already a string, then this isn't a coercion
                    if (isStringType(node.expressions[0])) {
                        return;
                    }
                    const code = sourceCode.getText(node.expressions[0]);
                    const recommendation = `String(${code})`;
                    report(node, recommendation, true);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-implicit-globals.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check for implicit global variables, functions and classes.
     * @author Joshua Peek
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow declarations in the global scope",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-implicit-globals"
            },
            schema: [{
                    type: "object",
                    properties: {
                        lexicalBindings: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                globalNonLexicalBinding: "Unexpected {{kind}} declaration in the global scope, wrap in an IIFE for a local variable, assign as global property for a global variable.",
                globalLexicalBinding: "Unexpected {{kind}} declaration in the global scope, wrap in a block or in an IIFE.",
                globalVariableLeak: "Global variable leak, declare the variable if it is intended to be local.",
                assignmentToReadonlyGlobal: "Unexpected assignment to read-only global variable.",
                redeclarationOfReadonlyGlobal: "Unexpected redeclaration of read-only global variable."
            }
        },
        create(context) {
            const checkLexicalBindings = context.options[0] && context.options[0].lexicalBindings === true;
            /**
             * Reports the node.
             * @param {ASTNode} node Node to report.
             * @param {string} messageId Id of the message to report.
             * @param {string|undefined} kind Declaration kind, can be 'var', 'const', 'let', function or class.
             * @returns {void}
             */
            function report(node, messageId, kind) {
                context.report({
                    node,
                    messageId,
                    data: {
                        kind
                    }
                });
            }
            return {
                Program() {
                    const scope = context.getScope();
                    scope.variables.forEach(variable => {
                        // Only ESLint global variables have the `writable` key.
                        const isReadonlyEslintGlobalVariable = variable.writeable === false;
                        const isWritableEslintGlobalVariable = variable.writeable === true;
                        if (isWritableEslintGlobalVariable) {
                            // Everything is allowed with writable ESLint global variables.
                            return;
                        }
                        // Variables exported by "exported" block comments
                        if (variable.eslintExported) {
                            return;
                        }
                        variable.defs.forEach(def => {
                            const defNode = def.node;
                            if (def.type === "FunctionName" || (def.type === "Variable" && def.parent.kind === "var")) {
                                if (isReadonlyEslintGlobalVariable) {
                                    report(defNode, "redeclarationOfReadonlyGlobal");
                                }
                                else {
                                    report(defNode, "globalNonLexicalBinding", def.type === "FunctionName" ? "function" : `'${def.parent.kind}'`);
                                }
                            }
                            if (checkLexicalBindings) {
                                if (def.type === "ClassName" ||
                                    (def.type === "Variable" && (def.parent.kind === "let" || def.parent.kind === "const"))) {
                                    if (isReadonlyEslintGlobalVariable) {
                                        report(defNode, "redeclarationOfReadonlyGlobal");
                                    }
                                    else {
                                        report(defNode, "globalLexicalBinding", def.type === "ClassName" ? "class" : `'${def.parent.kind}'`);
                                    }
                                }
                            }
                        });
                    });
                    // Undeclared assigned variables.
                    scope.implicit.variables.forEach(variable => {
                        const scopeVariable = scope.set.get(variable.name);
                        let messageId;
                        if (scopeVariable) {
                            // ESLint global variable
                            if (scopeVariable.writeable) {
                                return;
                            }
                            messageId = "assignmentToReadonlyGlobal";
                        }
                        else {
                            // Reference to an unknown variable, possible global leak.
                            messageId = "globalVariableLeak";
                        }
                        // def.node is an AssignmentExpression, ForInStatement or ForOfStatement.
                        variable.defs.forEach(def => {
                            report(def.node, messageId);
                        });
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-implied-eval.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of implied eval via setTimeout and setInterval
     * @author James Allardice
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const { getStaticValue } = require(316) /* @eslint-community/eslint-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the use of `eval()`-like methods",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-implied-eval"
            },
            schema: [],
            messages: {
                impliedEval: "Implied eval. Consider passing a function instead of a string."
            }
        },
        create(context) {
            const GLOBAL_CANDIDATES = Object.freeze(["global", "window", "globalThis"]);
            const EVAL_LIKE_FUNC_PATTERN = /^(?:set(?:Interval|Timeout)|execScript)$/u;
            /**
             * Checks whether a node is evaluated as a string or not.
             * @param {ASTNode} node A node to check.
             * @returns {boolean} True if the node is evaluated as a string.
             */
            function isEvaluatedString(node) {
                if ((node.type === "Literal" && typeof node.value === "string") ||
                    node.type === "TemplateLiteral") {
                    return true;
                }
                if (node.type === "BinaryExpression" && node.operator === "+") {
                    return isEvaluatedString(node.left) || isEvaluatedString(node.right);
                }
                return false;
            }
            /**
             * Reports if the `CallExpression` node has evaluated argument.
             * @param {ASTNode} node A CallExpression to check.
             * @returns {void}
             */
            function reportImpliedEvalCallExpression(node) {
                const [firstArgument] = node.arguments;
                if (firstArgument) {
                    const staticValue = getStaticValue(firstArgument, context.getScope());
                    const isStaticString = staticValue && typeof staticValue.value === "string";
                    const isString = isStaticString || isEvaluatedString(firstArgument);
                    if (isString) {
                        context.report({
                            node,
                            messageId: "impliedEval"
                        });
                    }
                }
            }
            /**
             * Reports calls of `implied eval` via the global references.
             * @param {Variable} globalVar A global variable to check.
             * @returns {void}
             */
            function reportImpliedEvalViaGlobal(globalVar) {
                const { references, name } = globalVar;
                references.forEach(ref => {
                    const identifier = ref.identifier;
                    let node = identifier.parent;
                    while (astUtils.isSpecificMemberAccess(node, null, name)) {
                        node = node.parent;
                    }
                    if (astUtils.isSpecificMemberAccess(node, null, EVAL_LIKE_FUNC_PATTERN)) {
                        const calleeNode = node.parent.type === "ChainExpression" ? node.parent : node;
                        const parent = calleeNode.parent;
                        if (parent.type === "CallExpression" && parent.callee === calleeNode) {
                            reportImpliedEvalCallExpression(parent);
                        }
                    }
                });
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                CallExpression(node) {
                    if (astUtils.isSpecificId(node.callee, EVAL_LIKE_FUNC_PATTERN)) {
                        reportImpliedEvalCallExpression(node);
                    }
                },
                "Program:exit"() {
                    const globalScope = context.getScope();
                    GLOBAL_CANDIDATES
                        .map(candidate => astUtils.getVariableByName(globalScope, candidate))
                        .filter(globalVar => !!globalVar && globalVar.defs.length === 0)
                        .forEach(reportImpliedEvalViaGlobal);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-import-assign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag updates of imported bindings.
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const { findVariable } = require(316) /* @eslint-community/eslint-utils */;
    const astUtils = require(360) /* ./utils/ast-utils */;
    const WellKnownMutationFunctions = {
        Object: /^(?:assign|definePropert(?:y|ies)|freeze|setPrototypeOf)$/u,
        Reflect: /^(?:(?:define|delete)Property|set(?:PrototypeOf)?)$/u
    };
    /**
     * Check if a given node is LHS of an assignment node.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is LHS.
     */
    function isAssignmentLeft(node) {
        const { parent } = node;
        return ((parent.type === "AssignmentExpression" &&
            parent.left === node) ||
            // Destructuring assignments
            parent.type === "ArrayPattern" ||
            (parent.type === "Property" &&
                parent.value === node &&
                parent.parent.type === "ObjectPattern") ||
            parent.type === "RestElement" ||
            (parent.type === "AssignmentPattern" &&
                parent.left === node));
    }
    /**
     * Check if a given node is the operand of mutation unary operator.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is the operand of mutation unary operator.
     */
    function isOperandOfMutationUnaryOperator(node) {
        const argumentNode = node.parent.type === "ChainExpression"
            ? node.parent
            : node;
        const { parent } = argumentNode;
        return ((parent.type === "UpdateExpression" &&
            parent.argument === argumentNode) ||
            (parent.type === "UnaryExpression" &&
                parent.operator === "delete" &&
                parent.argument === argumentNode));
    }
    /**
     * Check if a given node is the iteration variable of `for-in`/`for-of` syntax.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is the iteration variable.
     */
    function isIterationVariable(node) {
        const { parent } = node;
        return ((parent.type === "ForInStatement" &&
            parent.left === node) ||
            (parent.type === "ForOfStatement" &&
                parent.left === node));
    }
    /**
     * Check if a given node is at the first argument of a well-known mutation function.
     * - `Object.assign`
     * - `Object.defineProperty`
     * - `Object.defineProperties`
     * - `Object.freeze`
     * - `Object.setPrototypeOf`
     * - `Reflect.defineProperty`
     * - `Reflect.deleteProperty`
     * - `Reflect.set`
     * - `Reflect.setPrototypeOf`
     * @param {ASTNode} node The node to check.
     * @param {Scope} scope A `escope.Scope` object to find variable (whichever).
     * @returns {boolean} `true` if the node is at the first argument of a well-known mutation function.
     */
    function isArgumentOfWellKnownMutationFunction(node, scope) {
        const { parent } = node;
        if (parent.type !== "CallExpression" || parent.arguments[0] !== node) {
            return false;
        }
        const callee = astUtils.skipChainExpression(parent.callee);
        if (!astUtils.isSpecificMemberAccess(callee, "Object", WellKnownMutationFunctions.Object) &&
            !astUtils.isSpecificMemberAccess(callee, "Reflect", WellKnownMutationFunctions.Reflect)) {
            return false;
        }
        const variable = findVariable(scope, callee.object);
        return variable !== null && variable.scope.type === "global";
    }
    /**
     * Check if the identifier node is placed at to update members.
     * @param {ASTNode} id The Identifier node to check.
     * @param {Scope} scope A `escope.Scope` object to find variable (whichever).
     * @returns {boolean} `true` if the member of `id` was updated.
     */
    function isMemberWrite(id, scope) {
        const { parent } = id;
        return ((parent.type === "MemberExpression" &&
            parent.object === id &&
            (isAssignmentLeft(parent) ||
                isOperandOfMutationUnaryOperator(parent) ||
                isIterationVariable(parent))) ||
            isArgumentOfWellKnownMutationFunction(id, scope));
    }
    /**
     * Get the mutation node.
     * @param {ASTNode} id The Identifier node to get.
     * @returns {ASTNode} The mutation node.
     */
    function getWriteNode(id) {
        let node = id.parent;
        while (node &&
            node.type !== "AssignmentExpression" &&
            node.type !== "UpdateExpression" &&
            node.type !== "UnaryExpression" &&
            node.type !== "CallExpression" &&
            node.type !== "ForInStatement" &&
            node.type !== "ForOfStatement") {
            node = node.parent;
        }
        return node || id;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow assigning to imported bindings",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-import-assign"
            },
            schema: [],
            messages: {
                readonly: "'{{name}}' is read-only.",
                readonlyMember: "The members of '{{name}}' are read-only."
            }
        },
        create(context) {
            return {
                ImportDeclaration(node) {
                    const scope = context.getScope();
                    for (const variable of context.getDeclaredVariables(node)) {
                        const shouldCheckMembers = variable.defs.some(d => d.node.type === "ImportNamespaceSpecifier");
                        let prevIdNode = null;
                        for (const reference of variable.references) {
                            const idNode = reference.identifier;
                            /*
                             * AssignmentPattern (e.g. `[a = 0] = b`) makes two write
                             * references for the same identifier. This should skip
                             * the one of the two in order to prevent redundant reports.
                             */
                            if (idNode === prevIdNode) {
                                continue;
                            }
                            prevIdNode = idNode;
                            if (reference.isWrite()) {
                                context.report({
                                    node: getWriteNode(idNode),
                                    messageId: "readonly",
                                    data: { name: idNode.name }
                                });
                            }
                            else if (shouldCheckMembers && isMemberWrite(idNode, scope)) {
                                context.report({
                                    node: getWriteNode(idNode),
                                    messageId: "readonlyMember",
                                    data: { name: idNode.name }
                                });
                            }
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-inline-comments.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Enforces or disallows inline comments.
     * @author Greg Cochard
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow inline comments after code",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-inline-comments"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        ignorePattern: {
                            type: "string"
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedInlineComment: "Unexpected comment inline with code."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const options = context.options[0];
            let customIgnoreRegExp;
            if (options && options.ignorePattern) {
                customIgnoreRegExp = new RegExp(options.ignorePattern, "u");
            }
            /**
             * Will check that comments are not on lines starting with or ending with code
             * @param {ASTNode} node The comment node to check
             * @private
             * @returns {void}
             */
            function testCodeAroundComment(node) {
                const startLine = String(sourceCode.lines[node.loc.start.line - 1]), endLine = String(sourceCode.lines[node.loc.end.line - 1]), preamble = startLine.slice(0, node.loc.start.column).trim(), postamble = endLine.slice(node.loc.end.column).trim(), isPreambleEmpty = !preamble, isPostambleEmpty = !postamble;
                // Nothing on both sides
                if (isPreambleEmpty && isPostambleEmpty) {
                    return;
                }
                // Matches the ignore pattern
                if (customIgnoreRegExp && customIgnoreRegExp.test(node.value)) {
                    return;
                }
                // JSX Exception
                if ((isPreambleEmpty || preamble === "{") &&
                    (isPostambleEmpty || postamble === "}")) {
                    const enclosingNode = sourceCode.getNodeByRangeIndex(node.range[0]);
                    if (enclosingNode && enclosingNode.type === "JSXEmptyExpression") {
                        return;
                    }
                }
                // Don't report ESLint directive comments
                if (astUtils.isDirectiveComment(node)) {
                    return;
                }
                context.report({
                    node,
                    messageId: "unexpectedInlineComment"
                });
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program() {
                    sourceCode.getAllComments()
                        .filter(token => token.type !== "Shebang")
                        .forEach(testCodeAroundComment);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-inner-declarations.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce declarations in program or function body root.
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const validParent = new Set(["Program", "StaticBlock", "ExportNamedDeclaration", "ExportDefaultDeclaration"]);
    const validBlockStatementParent = new Set(["FunctionDeclaration", "FunctionExpression", "ArrowFunctionExpression"]);
    /**
     * Finds the nearest enclosing context where this rule allows declarations and returns its description.
     * @param {ASTNode} node Node to search from.
     * @returns {string} Description. One of "program", "function body", "class static block body".
     */
    function getAllowedBodyDescription(node) {
        let { parent } = node;
        while (parent) {
            if (parent.type === "StaticBlock") {
                return "class static block body";
            }
            if (astUtils.isFunction(parent)) {
                return "function body";
            }
            ({ parent } = parent);
        }
        return "program";
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow variable or `function` declarations in nested blocks",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-inner-declarations"
            },
            schema: [
                {
                    enum: ["functions", "both"]
                }
            ],
            messages: {
                moveDeclToRoot: "Move {{type}} declaration to {{body}} root."
            }
        },
        create(context) {
            /**
             * Ensure that a given node is at a program or function body's root.
             * @param {ASTNode} node Declaration node to check.
             * @returns {void}
             */
            function check(node) {
                const parent = node.parent;
                if (parent.type === "BlockStatement" && validBlockStatementParent.has(parent.parent.type)) {
                    return;
                }
                if (validParent.has(parent.type)) {
                    return;
                }
                context.report({
                    node,
                    messageId: "moveDeclToRoot",
                    data: {
                        type: (node.type === "FunctionDeclaration" ? "function" : "variable"),
                        body: getAllowedBodyDescription(node)
                    }
                });
            }
            return {
                FunctionDeclaration: check,
                VariableDeclaration(node) {
                    if (context.options[0] === "both" && node.kind === "var") {
                        check(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-invalid-regexp.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Validate strings passed to the RegExp constructor
     * @author Michael Ficarra
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const RegExpValidator = require(485) /* @eslint-community/regexpp */.RegExpValidator;
    const validator = new RegExpValidator();
    const validFlags = /[dgimsuy]/gu;
    const undefined1 = void 0;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow invalid regular expression strings in `RegExp` constructors",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-invalid-regexp"
            },
            schema: [{
                    type: "object",
                    properties: {
                        allowConstructorFlags: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                regexMessage: "{{message}}."
            }
        },
        create(context) {
            const options = context.options[0];
            let allowedFlags = null;
            if (options && options.allowConstructorFlags) {
                const temp = options.allowConstructorFlags.join("").replace(validFlags, "");
                if (temp) {
                    allowedFlags = new RegExp(`[${temp}]`, "giu");
                }
            }
            /**
             * Reports error with the provided message.
             * @param {ASTNode} node The node holding the invalid RegExp
             * @param {string} message The message to report.
             * @returns {void}
             */
            function report(node, message) {
                context.report({
                    node,
                    messageId: "regexMessage",
                    data: { message }
                });
            }
            /**
             * Check if node is a string
             * @param {ASTNode} node node to evaluate
             * @returns {boolean} True if its a string
             * @private
             */
            function isString(node) {
                return node && node.type === "Literal" && typeof node.value === "string";
            }
            /**
             * Gets flags of a regular expression created by the given `RegExp()` or `new RegExp()` call
             * Examples:
             *     new RegExp(".")         // => ""
             *     new RegExp(".", "gu")   // => "gu"
             *     new RegExp(".", flags)  // => null
             * @param {ASTNode} node `CallExpression` or `NewExpression` node
             * @returns {string|null} flags if they can be determined, `null` otherwise
             * @private
             */
            function getFlags(node) {
                if (node.arguments.length < 2) {
                    return "";
                }
                if (isString(node.arguments[1])) {
                    return node.arguments[1].value;
                }
                return null;
            }
            /**
             * Check syntax error in a given pattern.
             * @param {string} pattern The RegExp pattern to validate.
             * @param {boolean} uFlag The Unicode flag.
             * @returns {string|null} The syntax error.
             */
            function validateRegExpPattern(pattern, uFlag) {
                try {
                    validator.validatePattern(pattern, undefined1, undefined1, uFlag);
                    return null;
                }
                catch (err) {
                    return err.message;
                }
            }
            /**
             * Check syntax error in a given flags.
             * @param {string|null} flags The RegExp flags to validate.
             * @returns {string|null} The syntax error.
             */
            function validateRegExpFlags(flags) {
                if (!flags) {
                    return null;
                }
                try {
                    validator.validateFlags(flags);
                    return null;
                }
                catch {
                    return `Invalid flags supplied to RegExp constructor '${flags}'`;
                }
            }
            return {
                "CallExpression, NewExpression"(node) {
                    if (node.callee.type !== "Identifier" || node.callee.name !== "RegExp") {
                        return;
                    }
                    let flags = getFlags(node);
                    if (flags && allowedFlags) {
                        flags = flags.replace(allowedFlags, "");
                    }
                    let message = validateRegExpFlags(flags);
                    if (message) {
                        report(node, message);
                        return;
                    }
                    if (!isString(node.arguments[0])) {
                        return;
                    }
                    const pattern = node.arguments[0].value;
                    message = (
                    // If flags are unknown, report the regex only if its pattern is invalid both with and without the "u" flag
                    flags === null
                        ? validateRegExpPattern(pattern, true) && validateRegExpPattern(pattern, false)
                        : validateRegExpPattern(pattern, flags.includes("u")));
                    if (message) {
                        report(node, message);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-invalid-this.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow `this` keywords in contexts where the value of `this` is `undefined`.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Determines if the given code path is a code path with lexical `this` binding.
     * That is, if `this` within the code path refers to `this` of surrounding code path.
     * @param {CodePath} codePath Code path.
     * @param {ASTNode} node Node that started the code path.
     * @returns {boolean} `true` if it is a code path with lexical `this` binding.
     */
    function isCodePathWithLexicalThis(codePath, node) {
        return codePath.origin === "function" && node.type === "ArrowFunctionExpression";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow use of `this` in contexts where the value of `this` is `undefined`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-invalid-this"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        capIsConstructor: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedThis: "Unexpected 'this'."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const capIsConstructor = options.capIsConstructor !== false;
            const stack = [], sourceCode = context.getSourceCode();
            /**
             * Gets the current checking context.
             *
             * The return value has a flag that whether or not `this` keyword is valid.
             * The flag is initialized when got at the first time.
             * @returns {{valid: boolean}}
             *   an object which has a flag that whether or not `this` keyword is valid.
             */
            stack.getCurrent = function () {
                const current = this[this.length - 1];
                if (!current.init) {
                    current.init = true;
                    current.valid = !astUtils.isDefaultThisBinding(current.node, sourceCode, { capIsConstructor });
                }
                return current;
            };
            return {
                onCodePathStart(codePath, node) {
                    if (isCodePathWithLexicalThis(codePath, node)) {
                        return;
                    }
                    if (codePath.origin === "program") {
                        const scope = context.getScope();
                        const features = context.parserOptions.ecmaFeatures || {};
                        // `this` at the top level of scripts always refers to the global object
                        stack.push({
                            init: true,
                            node,
                            valid: !(node.sourceType === "module" ||
                                (features.globalReturn && scope.childScopes[0].isStrict))
                        });
                        return;
                    }
                    /*
                     * `init: false` means that `valid` isn't determined yet.
                     * Most functions don't use `this`, and the calculation for `valid`
                     * is relatively costly, so we'll calculate it lazily when the first
                     * `this` within the function is traversed. A special case are non-strict
                     * functions, because `this` refers to the global object and therefore is
                     * always valid, so we can set `init: true` right away.
                     */
                    stack.push({
                        init: !context.getScope().isStrict,
                        node,
                        valid: true
                    });
                },
                onCodePathEnd(codePath, node) {
                    if (isCodePathWithLexicalThis(codePath, node)) {
                        return;
                    }
                    stack.pop();
                },
                // Reports if `this` of the current context is invalid.
                ThisExpression(node) {
                    const current = stack.getCurrent();
                    if (current && !current.valid) {
                        context.report({
                            node,
                            messageId: "unexpectedThis"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-irregular-whitespace.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow whitespace that is not a tab or space, whitespace inside strings and comments are allowed
     * @author Jonathan Kingston
     * @author Christophe Porteneuve
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Constants
    //------------------------------------------------------------------------------
    const ALL_IRREGULARS = /[\f\v\u0085\ufeff\u00a0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u200b\u202f\u205f\u3000\u2028\u2029]/u;
    const IRREGULAR_WHITESPACE = /[\f\v\u0085\ufeff\u00a0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u200b\u202f\u205f\u3000]+/mgu;
    const IRREGULAR_LINE_TERMINATORS = /[\u2028\u2029]/mgu;
    const LINE_BREAK = astUtils.createGlobalLinebreakMatcher();
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow irregular whitespace",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-irregular-whitespace"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        skipComments: {
                            type: "boolean",
                            default: false
                        },
                        skipStrings: {
                            type: "boolean",
                            default: true
                        },
                        skipTemplates: {
                            type: "boolean",
                            default: false
                        },
                        skipRegExps: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                noIrregularWhitespace: "Irregular whitespace not allowed."
            }
        },
        create(context) {
            // Module store of errors that we have found
            let errors = [];
            // Lookup the `skipComments` option, which defaults to `false`.
            const options = context.options[0] || {};
            const skipComments = !!options.skipComments;
            const skipStrings = options.skipStrings !== false;
            const skipRegExps = !!options.skipRegExps;
            const skipTemplates = !!options.skipTemplates;
            const sourceCode = context.getSourceCode();
            const commentNodes = sourceCode.getAllComments();
            /**
             * Removes errors that occur inside the given node
             * @param {ASTNode} node to check for matching errors.
             * @returns {void}
             * @private
             */
            function removeWhitespaceError(node) {
                const locStart = node.loc.start;
                const locEnd = node.loc.end;
                errors = errors.filter(({ loc: { start: errorLocStart } }) => (errorLocStart.line < locStart.line ||
                    errorLocStart.line === locStart.line && errorLocStart.column < locStart.column ||
                    errorLocStart.line === locEnd.line && errorLocStart.column >= locEnd.column ||
                    errorLocStart.line > locEnd.line));
            }
            /**
             * Checks identifier or literal nodes for errors that we are choosing to ignore and calls the relevant methods to remove the errors
             * @param {ASTNode} node to check for matching errors.
             * @returns {void}
             * @private
             */
            function removeInvalidNodeErrorsInIdentifierOrLiteral(node) {
                const shouldCheckStrings = skipStrings && (typeof node.value === "string");
                const shouldCheckRegExps = skipRegExps && Boolean(node.regex);
                if (shouldCheckStrings || shouldCheckRegExps) {
                    // If we have irregular characters remove them from the errors list
                    if (ALL_IRREGULARS.test(node.raw)) {
                        removeWhitespaceError(node);
                    }
                }
            }
            /**
             * Checks template string literal nodes for errors that we are choosing to ignore and calls the relevant methods to remove the errors
             * @param {ASTNode} node to check for matching errors.
             * @returns {void}
             * @private
             */
            function removeInvalidNodeErrorsInTemplateLiteral(node) {
                if (typeof node.value.raw === "string") {
                    if (ALL_IRREGULARS.test(node.value.raw)) {
                        removeWhitespaceError(node);
                    }
                }
            }
            /**
             * Checks comment nodes for errors that we are choosing to ignore and calls the relevant methods to remove the errors
             * @param {ASTNode} node to check for matching errors.
             * @returns {void}
             * @private
             */
            function removeInvalidNodeErrorsInComment(node) {
                if (ALL_IRREGULARS.test(node.value)) {
                    removeWhitespaceError(node);
                }
            }
            /**
             * Checks the program source for irregular whitespace
             * @param {ASTNode} node The program node
             * @returns {void}
             * @private
             */
            function checkForIrregularWhitespace(node) {
                const sourceLines = sourceCode.lines;
                sourceLines.forEach((sourceLine, lineIndex) => {
                    const lineNumber = lineIndex + 1;
                    let match;
                    while ((match = IRREGULAR_WHITESPACE.exec(sourceLine)) !== null) {
                        errors.push({
                            node,
                            messageId: "noIrregularWhitespace",
                            loc: {
                                start: {
                                    line: lineNumber,
                                    column: match.index
                                },
                                end: {
                                    line: lineNumber,
                                    column: match.index + match[0].length
                                }
                            }
                        });
                    }
                });
            }
            /**
             * Checks the program source for irregular line terminators
             * @param {ASTNode} node The program node
             * @returns {void}
             * @private
             */
            function checkForIrregularLineTerminators(node) {
                const source = sourceCode.getText(), sourceLines = sourceCode.lines, linebreaks = source.match(LINE_BREAK);
                let lastLineIndex = -1, match;
                while ((match = IRREGULAR_LINE_TERMINATORS.exec(source)) !== null) {
                    const lineIndex = linebreaks.indexOf(match[0], lastLineIndex + 1) || 0;
                    errors.push({
                        node,
                        messageId: "noIrregularWhitespace",
                        loc: {
                            start: {
                                line: lineIndex + 1,
                                column: sourceLines[lineIndex].length
                            },
                            end: {
                                line: lineIndex + 2,
                                column: 0
                            }
                        }
                    });
                    lastLineIndex = lineIndex;
                }
            }
            /**
             * A no-op function to act as placeholder for comment accumulation when the `skipComments` option is `false`.
             * @returns {void}
             * @private
             */
            function noop() { }
            const nodes = {};
            if (ALL_IRREGULARS.test(sourceCode.getText())) {
                nodes.Program = function (node) {
                    /*
                     * As we can easily fire warnings for all white space issues with
                     * all the source its simpler to fire them here.
                     * This means we can check all the application code without having
                     * to worry about issues caused in the parser tokens.
                     * When writing this code also evaluating per node was missing out
                     * connecting tokens in some cases.
                     * We can later filter the errors when they are found to be not an
                     * issue in nodes we don't care about.
                     */
                    checkForIrregularWhitespace(node);
                    checkForIrregularLineTerminators(node);
                };
                nodes.Identifier = removeInvalidNodeErrorsInIdentifierOrLiteral;
                nodes.Literal = removeInvalidNodeErrorsInIdentifierOrLiteral;
                nodes.TemplateElement = skipTemplates ? removeInvalidNodeErrorsInTemplateLiteral : noop;
                nodes["Program:exit"] = function () {
                    if (skipComments) {
                        // First strip errors occurring in comment nodes.
                        commentNodes.forEach(removeInvalidNodeErrorsInComment);
                    }
                    // If we have any errors remaining report on them
                    errors.forEach(error => context.report(error));
                };
            }
            else {
                nodes.Program = noop;
            }
            return nodes;
        }
    };
},
/* eslint/lib/rules/no-iterator.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag usage of __iterator__ property
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { getStaticPropertyName } = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the use of the `__iterator__` property",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-iterator"
            },
            schema: [],
            messages: {
                noIterator: "Reserved name '__iterator__'."
            }
        },
        create(context) {
            return {
                MemberExpression(node) {
                    if (getStaticPropertyName(node) === "__iterator__") {
                        context.report({
                            node,
                            messageId: "noIterator"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-label-var.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag labels that are the same as an identifier
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow labels that share a name with a variable",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-label-var"
            },
            schema: [],
            messages: {
                identifierClashWithLabel: "Found identifier with same name as label."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Check if the identifier is present inside current scope
             * @param {Object} scope current scope
             * @param {string} name To evaluate
             * @returns {boolean} True if its present
             * @private
             */
            function findIdentifier(scope, name) {
                return astUtils.getVariableByName(scope, name) !== null;
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                LabeledStatement(node) {
                    // Fetch the innermost scope.
                    const scope = context.getScope();
                    /*
                     * Recursively find the identifier walking up the scope, starting
                     * with the innermost scope.
                     */
                    if (findIdentifier(scope, node.label.name)) {
                        context.report({
                            node,
                            messageId: "identifierClashWithLabel"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-labels.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow Labeled Statements
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow labeled statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-labels"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowLoop: {
                            type: "boolean",
                            default: false
                        },
                        allowSwitch: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedLabel: "Unexpected labeled statement.",
                unexpectedLabelInBreak: "Unexpected label in break statement.",
                unexpectedLabelInContinue: "Unexpected label in continue statement."
            }
        },
        create(context) {
            const options = context.options[0];
            const allowLoop = options && options.allowLoop;
            const allowSwitch = options && options.allowSwitch;
            let scopeInfo = null;
            /**
             * Gets the kind of a given node.
             * @param {ASTNode} node A node to get.
             * @returns {string} The kind of the node.
             */
            function getBodyKind(node) {
                if (astUtils.isLoop(node)) {
                    return "loop";
                }
                if (node.type === "SwitchStatement") {
                    return "switch";
                }
                return "other";
            }
            /**
             * Checks whether the label of a given kind is allowed or not.
             * @param {string} kind A kind to check.
             * @returns {boolean} `true` if the kind is allowed.
             */
            function isAllowed(kind) {
                switch (kind) {
                    case "loop": return allowLoop;
                    case "switch": return allowSwitch;
                    default: return false;
                }
            }
            /**
             * Checks whether a given name is a label of a loop or not.
             * @param {string} label A name of a label to check.
             * @returns {boolean} `true` if the name is a label of a loop.
             */
            function getKind(label) {
                let info = scopeInfo;
                while (info) {
                    if (info.label === label) {
                        return info.kind;
                    }
                    info = info.upper;
                }
                /* c8 ignore next */
                return "other";
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                LabeledStatement(node) {
                    scopeInfo = {
                        label: node.label.name,
                        kind: getBodyKind(node.body),
                        upper: scopeInfo
                    };
                },
                "LabeledStatement:exit"(node) {
                    if (!isAllowed(scopeInfo.kind)) {
                        context.report({
                            node,
                            messageId: "unexpectedLabel"
                        });
                    }
                    scopeInfo = scopeInfo.upper;
                },
                BreakStatement(node) {
                    if (node.label && !isAllowed(getKind(node.label.name))) {
                        context.report({
                            node,
                            messageId: "unexpectedLabelInBreak"
                        });
                    }
                },
                ContinueStatement(node) {
                    if (node.label && !isAllowed(getKind(node.label.name))) {
                        context.report({
                            node,
                            messageId: "unexpectedLabelInContinue"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-lone-blocks.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag blocks with no reason to exist
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary nested blocks",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-lone-blocks"
            },
            schema: [],
            messages: {
                redundantBlock: "Block is redundant.",
                redundantNestedBlock: "Nested block is redundant."
            }
        },
        create(context) {
            // A stack of lone blocks to be checked for block-level bindings
            const loneBlocks = [];
            let ruleDef;
            /**
             * Reports a node as invalid.
             * @param {ASTNode} node The node to be reported.
             * @returns {void}
             */
            function report(node) {
                const messageId = node.parent.type === "BlockStatement" || node.parent.type === "StaticBlock"
                    ? "redundantNestedBlock"
                    : "redundantBlock";
                context.report({
                    node,
                    messageId
                });
            }
            /**
             * Checks for any occurrence of a BlockStatement in a place where lists of statements can appear
             * @param {ASTNode} node The node to check
             * @returns {boolean} True if the node is a lone block.
             */
            function isLoneBlock(node) {
                return node.parent.type === "BlockStatement" ||
                    node.parent.type === "StaticBlock" ||
                    node.parent.type === "Program" ||
                    // Don't report blocks in switch cases if the block is the only statement of the case.
                    node.parent.type === "SwitchCase" && !(node.parent.consequent[0] === node && node.parent.consequent.length === 1);
            }
            /**
             * Checks the enclosing block of the current node for block-level bindings,
             * and "marks it" as valid if any.
             * @returns {void}
             */
            function markLoneBlock() {
                if (loneBlocks.length === 0) {
                    return;
                }
                const block = context.getAncestors().pop();
                if (loneBlocks[loneBlocks.length - 1] === block) {
                    loneBlocks.pop();
                }
            }
            // Default rule definition: report all lone blocks
            ruleDef = {
                BlockStatement(node) {
                    if (isLoneBlock(node)) {
                        report(node);
                    }
                }
            };
            // ES6: report blocks without block-level bindings, or that's only child of another block
            if (context.languageOptions.ecmaVersion >= 2015) {
                ruleDef = {
                    BlockStatement(node) {
                        if (isLoneBlock(node)) {
                            loneBlocks.push(node);
                        }
                    },
                    "BlockStatement:exit"(node) {
                        if (loneBlocks.length > 0 && loneBlocks[loneBlocks.length - 1] === node) {
                            loneBlocks.pop();
                            report(node);
                        }
                        else if ((node.parent.type === "BlockStatement" ||
                            node.parent.type === "StaticBlock") &&
                            node.parent.body.length === 1) {
                            report(node);
                        }
                    }
                };
                ruleDef.VariableDeclaration = function (node) {
                    if (node.kind === "let" || node.kind === "const") {
                        markLoneBlock();
                    }
                };
                ruleDef.FunctionDeclaration = function () {
                    if (context.getScope().isStrict) {
                        markLoneBlock();
                    }
                };
                ruleDef.ClassDeclaration = markLoneBlock;
            }
            return ruleDef;
        }
    };
},
/* eslint/lib/rules/no-lonely-if.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to disallow if as the only statement in an else block
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `if` statements as the only statement in `else` blocks",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-lonely-if"
            },
            schema: [],
            fixable: "code",
            messages: {
                unexpectedLonelyIf: "Unexpected if as the only statement in an else block."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                IfStatement(node) {
                    const ancestors = context.getAncestors(), parent = ancestors.pop(), grandparent = ancestors.pop();
                    if (parent && parent.type === "BlockStatement" &&
                        parent.body.length === 1 && grandparent &&
                        grandparent.type === "IfStatement" &&
                        parent === grandparent.alternate) {
                        context.report({
                            node,
                            messageId: "unexpectedLonelyIf",
                            fix(fixer) {
                                const openingElseCurly = sourceCode.getFirstToken(parent);
                                const closingElseCurly = sourceCode.getLastToken(parent);
                                const elseKeyword = sourceCode.getTokenBefore(openingElseCurly);
                                const tokenAfterElseBlock = sourceCode.getTokenAfter(closingElseCurly);
                                const lastIfToken = sourceCode.getLastToken(node.consequent);
                                const sourceText = sourceCode.getText();
                                if (sourceText.slice(openingElseCurly.range[1], node.range[0]).trim() || sourceText.slice(node.range[1], closingElseCurly.range[0]).trim()) {
                                    // Don't fix if there are any non-whitespace characters interfering (e.g. comments)
                                    return null;
                                }
                                if (node.consequent.type !== "BlockStatement" && lastIfToken.value !== ";" && tokenAfterElseBlock &&
                                    (node.consequent.loc.end.line === tokenAfterElseBlock.loc.start.line ||
                                        /^[([/+`-]/u.test(tokenAfterElseBlock.value) ||
                                        lastIfToken.value === "++" ||
                                        lastIfToken.value === "--")) {
                                    /*
                                     * If the `if` statement has no block, and is not followed by a semicolon, make sure that fixing
                                     * the issue would not change semantics due to ASI. If this would happen, don't do a fix.
                                     */
                                    return null;
                                }
                                return fixer.replaceTextRange([openingElseCurly.range[0], closingElseCurly.range[1]], (elseKeyword.range[1] === openingElseCurly.range[0] ? " " : "") + sourceCode.getText(node));
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-loop-func.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag creation of function inside a loop
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Gets the containing loop node of a specified node.
     *
     * We don't need to check nested functions, so this ignores those.
     * `Scope.through` contains references of nested functions.
     * @param {ASTNode} node An AST node to get.
     * @returns {ASTNode|null} The containing loop node of the specified node, or
     *      `null`.
     */
    function getContainingLoopNode(node) {
        for (let currentNode = node; currentNode.parent; currentNode = currentNode.parent) {
            const parent = currentNode.parent;
            switch (parent.type) {
                case "WhileStatement":
                case "DoWhileStatement":
                    return parent;
                case "ForStatement":
                    // `init` is outside of the loop.
                    if (parent.init !== currentNode) {
                        return parent;
                    }
                    break;
                case "ForInStatement":
                case "ForOfStatement":
                    // `right` is outside of the loop.
                    if (parent.right !== currentNode) {
                        return parent;
                    }
                    break;
                case "ArrowFunctionExpression":
                case "FunctionExpression":
                case "FunctionDeclaration":
                    // We don't need to check nested functions.
                    return null;
                default:
                    break;
            }
        }
        return null;
    }
    /**
     * Gets the containing loop node of a given node.
     * If the loop was nested, this returns the most outer loop.
     * @param {ASTNode} node A node to get. This is a loop node.
     * @param {ASTNode|null} excludedNode A node that the result node should not
     *      include.
     * @returns {ASTNode} The most outer loop node.
     */
    function getTopLoopNode(node, excludedNode) {
        const border = excludedNode ? excludedNode.range[1] : 0;
        let retv = node;
        let containingLoopNode = node;
        while (containingLoopNode && containingLoopNode.range[0] >= border) {
            retv = containingLoopNode;
            containingLoopNode = getContainingLoopNode(containingLoopNode);
        }
        return retv;
    }
    /**
     * Checks whether a given reference which refers to an upper scope's variable is
     * safe or not.
     * @param {ASTNode} loopNode A containing loop node.
     * @param {eslint-scope.Reference} reference A reference to check.
     * @returns {boolean} `true` if the reference is safe or not.
     */
    function isSafe(loopNode, reference) {
        const variable = reference.resolved;
        const definition = variable && variable.defs[0];
        const declaration = definition && definition.parent;
        const kind = (declaration && declaration.type === "VariableDeclaration")
            ? declaration.kind
            : "";
        // Variables which are declared by `const` is safe.
        if (kind === "const") {
            return true;
        }
        /*
         * Variables which are declared by `let` in the loop is safe.
         * It's a different instance from the next loop step's.
         */
        if (kind === "let" &&
            declaration.range[0] > loopNode.range[0] &&
            declaration.range[1] < loopNode.range[1]) {
            return true;
        }
        /*
         * WriteReferences which exist after this border are unsafe because those
         * can modify the variable.
         */
        const border = getTopLoopNode(loopNode, (kind === "let") ? declaration : null).range[0];
        /**
         * Checks whether a given reference is safe or not.
         * The reference is every reference of the upper scope's variable we are
         * looking now.
         *
         * It's safe if the reference matches one of the following condition.
         * - is readonly.
         * - doesn't exist inside a local function and after the border.
         * @param {eslint-scope.Reference} upperRef A reference to check.
         * @returns {boolean} `true` if the reference is safe.
         */
        function isSafeReference(upperRef) {
            const id = upperRef.identifier;
            return (!upperRef.isWrite() ||
                variable.scope.variableScope === upperRef.from.variableScope &&
                    id.range[0] < border);
        }
        return Boolean(variable) && variable.references.every(isSafeReference);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow function declarations that contain unsafe references inside loop statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-loop-func"
            },
            schema: [],
            messages: {
                unsafeRefs: "Function declared in a loop contains unsafe references to variable(s) {{ varNames }}."
            }
        },
        create(context) {
            /**
             * Reports functions which match the following condition:
             *
             * - has a loop node in ancestors.
             * - has any references which refers to an unsafe variable.
             * @param {ASTNode} node The AST node to check.
             * @returns {void}
             */
            function checkForLoops(node) {
                const loopNode = getContainingLoopNode(node);
                if (!loopNode) {
                    return;
                }
                const references = context.getScope().through;
                const unsafeRefs = references.filter(r => !isSafe(loopNode, r)).map(r => r.identifier.name);
                if (unsafeRefs.length > 0) {
                    context.report({
                        node,
                        messageId: "unsafeRefs",
                        data: { varNames: `'${unsafeRefs.join("', '")}'` }
                    });
                }
            }
            return {
                ArrowFunctionExpression: checkForLoops,
                FunctionExpression: checkForLoops,
                FunctionDeclaration: checkForLoops
            };
        }
    };
},
/* eslint/lib/rules/no-loss-of-precision.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag numbers that will lose significant figure precision at runtime
     * @author Jacob Moore
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow literal numbers that lose precision",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-loss-of-precision"
            },
            schema: [],
            messages: {
                noLossOfPrecision: "This number literal will lose precision at runtime."
            }
        },
        create(context) {
            /**
             * Returns whether the node is number literal
             * @param {Node} node the node literal being evaluated
             * @returns {boolean} true if the node is a number literal
             */
            function isNumber(node) {
                return typeof node.value === "number";
            }
            /**
             * Gets the source code of the given number literal. Removes `_` numeric separators from the result.
             * @param {Node} node the number `Literal` node
             * @returns {string} raw source code of the literal, without numeric separators
             */
            function getRaw(node) {
                return node.raw.replace(/_/gu, "");
            }
            /**
             * Checks whether the number is  base ten
             * @param {ASTNode} node the node being evaluated
             * @returns {boolean} true if the node is in base ten
             */
            function isBaseTen(node) {
                const prefixes = ["0x", "0X", "0b", "0B", "0o", "0O"];
                return prefixes.every(prefix => !node.raw.startsWith(prefix)) &&
                    !/^0[0-7]+$/u.test(node.raw);
            }
            /**
             * Checks that the user-intended non-base ten number equals the actual number after is has been converted to the Number type
             * @param {Node} node the node being evaluated
             * @returns {boolean} true if they do not match
             */
            function notBaseTenLosesPrecision(node) {
                const rawString = getRaw(node).toUpperCase();
                let base = 0;
                if (rawString.startsWith("0B")) {
                    base = 2;
                }
                else if (rawString.startsWith("0X")) {
                    base = 16;
                }
                else {
                    base = 8;
                }
                return !rawString.endsWith(node.value.toString(base).toUpperCase());
            }
            /**
             * Adds a decimal point to the numeric string at index 1
             * @param {string} stringNumber the numeric string without any decimal point
             * @returns {string} the numeric string with a decimal point in the proper place
             */
            function addDecimalPointToNumber(stringNumber) {
                return `${stringNumber.slice(0, 1)}.${stringNumber.slice(1)}`;
            }
            /**
             * Returns the number stripped of leading zeros
             * @param {string} numberAsString the string representation of the number
             * @returns {string} the stripped string
             */
            function removeLeadingZeros(numberAsString) {
                return numberAsString.replace(/^0*/u, "");
            }
            /**
             * Returns the number stripped of trailing zeros
             * @param {string} numberAsString the string representation of the number
             * @returns {string} the stripped string
             */
            function removeTrailingZeros(numberAsString) {
                return numberAsString.replace(/0*$/u, "");
            }
            /**
             * Converts an integer to an object containing the integer's coefficient and order of magnitude
             * @param {string} stringInteger the string representation of the integer being converted
             * @returns {Object} the object containing the integer's coefficient and order of magnitude
             */
            function normalizeInteger(stringInteger) {
                const significantDigits = removeTrailingZeros(removeLeadingZeros(stringInteger));
                return {
                    magnitude: stringInteger.startsWith("0") ? stringInteger.length - 2 : stringInteger.length - 1,
                    coefficient: addDecimalPointToNumber(significantDigits)
                };
            }
            /**
             *
             * Converts a float to an object containing the floats's coefficient and order of magnitude
             * @param {string} stringFloat the string representation of the float being converted
             * @returns {Object} the object containing the integer's coefficient and order of magnitude
             */
            function normalizeFloat(stringFloat) {
                const trimmedFloat = removeLeadingZeros(stringFloat);
                if (trimmedFloat.startsWith(".")) {
                    const decimalDigits = trimmedFloat.split(".").pop();
                    const significantDigits = removeLeadingZeros(decimalDigits);
                    return {
                        magnitude: significantDigits.length - decimalDigits.length - 1,
                        coefficient: addDecimalPointToNumber(significantDigits)
                    };
                }
                return {
                    magnitude: trimmedFloat.indexOf(".") - 1,
                    coefficient: addDecimalPointToNumber(trimmedFloat.replace(".", ""))
                };
            }
            /**
             * Converts a base ten number to proper scientific notation
             * @param {string} stringNumber the string representation of the base ten number to be converted
             * @returns {string} the number converted to scientific notation
             */
            function convertNumberToScientificNotation(stringNumber) {
                const splitNumber = stringNumber.replace("E", "e").split("e");
                const originalCoefficient = splitNumber[0];
                const normalizedNumber = stringNumber.includes(".") ? normalizeFloat(originalCoefficient)
                    : normalizeInteger(originalCoefficient);
                const normalizedCoefficient = normalizedNumber.coefficient;
                const magnitude = splitNumber.length > 1 ? (parseInt(splitNumber[1], 10) + normalizedNumber.magnitude)
                    : normalizedNumber.magnitude;
                return `${normalizedCoefficient}e${magnitude}`;
            }
            /**
             * Checks that the user-intended base ten number equals the actual number after is has been converted to the Number type
             * @param {Node} node the node being evaluated
             * @returns {boolean} true if they do not match
             */
            function baseTenLosesPrecision(node) {
                const normalizedRawNumber = convertNumberToScientificNotation(getRaw(node));
                const requestedPrecision = normalizedRawNumber.split("e")[0].replace(".", "").length;
                if (requestedPrecision > 100) {
                    return true;
                }
                const storedNumber = node.value.toPrecision(requestedPrecision);
                const normalizedStoredNumber = convertNumberToScientificNotation(storedNumber);
                return normalizedRawNumber !== normalizedStoredNumber;
            }
            /**
             * Checks that the user-intended number equals the actual number after is has been converted to the Number type
             * @param {Node} node the node being evaluated
             * @returns {boolean} true if they do not match
             */
            function losesPrecision(node) {
                return isBaseTen(node) ? baseTenLosesPrecision(node) : notBaseTenLosesPrecision(node);
            }
            return {
                Literal(node) {
                    if (node.value && isNumber(node) && losesPrecision(node)) {
                        context.report({
                            messageId: "noLossOfPrecision",
                            node
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-magic-numbers.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag statements that use magic numbers (adapted from https://github.com/danielstjules/buddy.js)
     * @author Vincent Lemeunier
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    // Maximum array length by the ECMAScript Specification.
    const MAX_ARRAY_LENGTH = 2 ** 32 - 1;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /**
     * Convert the value to bigint if it's a string. Otherwise return the value as-is.
     * @param {bigint|number|string} x The value to normalize.
     * @returns {bigint|number} The normalized value.
     */
    function normalizeIgnoreValue(x) {
        if (typeof x === "string") {
            return BigInt(x.slice(0, -1));
        }
        return x;
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow magic numbers",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-magic-numbers"
            },
            schema: [{
                    type: "object",
                    properties: {
                        detectObjects: {
                            type: "boolean",
                            default: false
                        },
                        enforceConst: {
                            type: "boolean",
                            default: false
                        },
                        ignore: {
                            type: "array",
                            items: {
                                anyOf: [
                                    { type: "number" },
                                    { type: "string", pattern: "^[+-]?(?:0|[1-9][0-9]*)n$" }
                                ]
                            },
                            uniqueItems: true
                        },
                        ignoreArrayIndexes: {
                            type: "boolean",
                            default: false
                        },
                        ignoreDefaultValues: {
                            type: "boolean",
                            default: false
                        },
                        ignoreClassFieldInitialValues: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                useConst: "Number constants declarations must use 'const'.",
                noMagic: "No magic number: {{raw}}."
            }
        },
        create(context) {
            const config = context.options[0] || {}, detectObjects = !!config.detectObjects, enforceConst = !!config.enforceConst, ignore = new Set((config.ignore || []).map(normalizeIgnoreValue)), ignoreArrayIndexes = !!config.ignoreArrayIndexes, ignoreDefaultValues = !!config.ignoreDefaultValues, ignoreClassFieldInitialValues = !!config.ignoreClassFieldInitialValues;
            const okTypes = detectObjects ? [] : ["ObjectExpression", "Property", "AssignmentExpression"];
            /**
             * Returns whether the rule is configured to ignore the given value
             * @param {bigint|number} value The value to check
             * @returns {boolean} true if the value is ignored
             */
            function isIgnoredValue(value) {
                return ignore.has(value);
            }
            /**
             * Returns whether the number is a default value assignment.
             * @param {ASTNode} fullNumberNode `Literal` or `UnaryExpression` full number node
             * @returns {boolean} true if the number is a default value
             */
            function isDefaultValue(fullNumberNode) {
                const parent = fullNumberNode.parent;
                return parent.type === "AssignmentPattern" && parent.right === fullNumberNode;
            }
            /**
             * Returns whether the number is the initial value of a class field.
             * @param {ASTNode} fullNumberNode `Literal` or `UnaryExpression` full number node
             * @returns {boolean} true if the number is the initial value of a class field.
             */
            function isClassFieldInitialValue(fullNumberNode) {
                const parent = fullNumberNode.parent;
                return parent.type === "PropertyDefinition" && parent.value === fullNumberNode;
            }
            /**
             * Returns whether the given node is used as a radix within parseInt() or Number.parseInt()
             * @param {ASTNode} fullNumberNode `Literal` or `UnaryExpression` full number node
             * @returns {boolean} true if the node is radix
             */
            function isParseIntRadix(fullNumberNode) {
                const parent = fullNumberNode.parent;
                return parent.type === "CallExpression" && fullNumberNode === parent.arguments[1] &&
                    (astUtils.isSpecificId(parent.callee, "parseInt") ||
                        astUtils.isSpecificMemberAccess(parent.callee, "Number", "parseInt"));
            }
            /**
             * Returns whether the given node is a direct child of a JSX node.
             * In particular, it aims to detect numbers used as prop values in JSX tags.
             * Example: <input maxLength={10} />
             * @param {ASTNode} fullNumberNode `Literal` or `UnaryExpression` full number node
             * @returns {boolean} true if the node is a JSX number
             */
            function isJSXNumber(fullNumberNode) {
                return fullNumberNode.parent.type.indexOf("JSX") === 0;
            }
            /**
             * Returns whether the given node is used as an array index.
             * Value must coerce to a valid array index name: "0", "1", "2" ... "4294967294".
             *
             * All other values, like "-1", "2.5", or "4294967295", are just "normal" object properties,
             * which can be created and accessed on an array in addition to the array index properties,
             * but they don't affect array's length and are not considered by methods such as .map(), .forEach() etc.
             *
             * The maximum array length by the specification is 2 ** 32 - 1 = 4294967295,
             * thus the maximum valid index is 2 ** 32 - 2 = 4294967294.
             *
             * All notations are allowed, as long as the value coerces to one of "0", "1", "2" ... "4294967294".
             *
             * Valid examples:
             * a[0], a[1], a[1.2e1], a[0xAB], a[0n], a[1n]
             * a[-0] (same as a[0] because -0 coerces to "0")
             * a[-0n] (-0n evaluates to 0n)
             *
             * Invalid examples:
             * a[-1], a[-0xAB], a[-1n], a[2.5], a[1.23e1], a[12e-1]
             * a[4294967295] (above the max index, it's an access to a regular property a["4294967295"])
             * a[999999999999999999999] (even if it wasn't above the max index, it would be a["1e+21"])
             * a[1e310] (same as a["Infinity"])
             * @param {ASTNode} fullNumberNode `Literal` or `UnaryExpression` full number node
             * @param {bigint|number} value Value expressed by the fullNumberNode
             * @returns {boolean} true if the node is a valid array index
             */
            function isArrayIndex(fullNumberNode, value) {
                const parent = fullNumberNode.parent;
                return parent.type === "MemberExpression" && parent.property === fullNumberNode &&
                    (Number.isInteger(value) || typeof value === "bigint") &&
                    value >= 0 && value < MAX_ARRAY_LENGTH;
            }
            return {
                Literal(node) {
                    if (!astUtils.isNumericLiteral(node)) {
                        return;
                    }
                    let fullNumberNode;
                    let value;
                    let raw;
                    // Treat unary minus as a part of the number
                    if (node.parent.type === "UnaryExpression" && node.parent.operator === "-") {
                        fullNumberNode = node.parent;
                        value = -node.value;
                        raw = `-${node.raw}`;
                    }
                    else {
                        fullNumberNode = node;
                        value = node.value;
                        raw = node.raw;
                    }
                    const parent = fullNumberNode.parent;
                    // Always allow radix arguments and JSX props
                    if (isIgnoredValue(value) ||
                        (ignoreDefaultValues && isDefaultValue(fullNumberNode)) ||
                        (ignoreClassFieldInitialValues && isClassFieldInitialValue(fullNumberNode)) ||
                        isParseIntRadix(fullNumberNode) ||
                        isJSXNumber(fullNumberNode) ||
                        (ignoreArrayIndexes && isArrayIndex(fullNumberNode, value))) {
                        return;
                    }
                    if (parent.type === "VariableDeclarator") {
                        if (enforceConst && parent.parent.kind !== "const") {
                            context.report({
                                node: fullNumberNode,
                                messageId: "useConst"
                            });
                        }
                    }
                    else if (!okTypes.includes(parent.type) ||
                        (parent.type === "AssignmentExpression" && parent.left.type === "Identifier")) {
                        context.report({
                            node: fullNumberNode,
                            messageId: "noMagic",
                            data: {
                                raw
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-misleading-character-class.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    const { CALL, CONSTRUCT, ReferenceTracker, getStringIfConstant } = require(316) /* @eslint-community/eslint-utils */;
    const { RegExpValidator, RegExpParser, visitRegExpAST } = require(485) /* @eslint-community/regexpp */;
    const { isCombiningCharacter, isEmojiModifier, isRegionalIndicatorSymbol, isSurrogatePair } = require(533) /* ./utils/unicode */;
    const astUtils = require(360) /* ./utils/ast-utils.js */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const REGEXPP_LATEST_ECMA_VERSION = 2022;
    /**
     * Iterate character sequences of a given nodes.
     *
     * CharacterClassRange syntax can steal a part of character sequence,
     * so this function reverts CharacterClassRange syntax and restore the sequence.
     * @param {regexpp.AST.CharacterClassElement[]} nodes The node list to iterate character sequences.
     * @returns {IterableIterator<number[]>} The list of character sequences.
     */
    function* iterateCharacterSequence(nodes) {
        let seq = [];
        for (const node of nodes) {
            switch (node.type) {
                case "Character":
                    seq.push(node.value);
                    break;
                case "CharacterClassRange":
                    seq.push(node.min.value);
                    yield seq;
                    seq = [node.max.value];
                    break;
                case "CharacterSet":
                    if (seq.length > 0) {
                        yield seq;
                        seq = [];
                    }
                    break;
                // no default
            }
        }
        if (seq.length > 0) {
            yield seq;
        }
    }
    const hasCharacterSequence = {
        surrogatePairWithoutUFlag(chars) {
            return chars.some((c, i) => i !== 0 && isSurrogatePair(chars[i - 1], c));
        },
        combiningClass(chars) {
            return chars.some((c, i) => (i !== 0 &&
                isCombiningCharacter(c) &&
                !isCombiningCharacter(chars[i - 1])));
        },
        emojiModifier(chars) {
            return chars.some((c, i) => (i !== 0 &&
                isEmojiModifier(c) &&
                !isEmojiModifier(chars[i - 1])));
        },
        regionalIndicatorSymbol(chars) {
            return chars.some((c, i) => (i !== 0 &&
                isRegionalIndicatorSymbol(c) &&
                isRegionalIndicatorSymbol(chars[i - 1])));
        },
        zwj(chars) {
            const lastIndex = chars.length - 1;
            return chars.some((c, i) => (i !== 0 &&
                i !== lastIndex &&
                c === 0x200d &&
                chars[i - 1] !== 0x200d &&
                chars[i + 1] !== 0x200d));
        }
    };
    const kinds = Object.keys(hasCharacterSequence);
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow characters which are made with multiple code points in character class syntax",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-misleading-character-class"
            },
            hasSuggestions: true,
            schema: [],
            messages: {
                surrogatePairWithoutUFlag: "Unexpected surrogate pair in character class. Use 'u' flag.",
                combiningClass: "Unexpected combined character in character class.",
                emojiModifier: "Unexpected modified Emoji in character class.",
                regionalIndicatorSymbol: "Unexpected national flag in character class.",
                zwj: "Unexpected joined character sequence in character class.",
                suggestUnicodeFlag: "Add unicode 'u' flag to regex."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const parser = new RegExpParser();
            /**
             * Verify a given regular expression.
             * @param {Node} node The node to report.
             * @param {string} pattern The regular expression pattern to verify.
             * @param {string} flags The flags of the regular expression.
             * @param {Function} unicodeFixer Fixer for missing "u" flag.
             * @returns {void}
             */
            function verify(node, pattern, flags, unicodeFixer) {
                let patternNode;
                try {
                    patternNode = parser.parsePattern(pattern, 0, pattern.length, flags.includes("u"));
                }
                catch {
                    // Ignore regular expressions with syntax errors
                    return;
                }
                const foundKinds = new Set();
                visitRegExpAST(patternNode, {
                    onCharacterClassEnter(ccNode) {
                        for (const chars of iterateCharacterSequence(ccNode.elements)) {
                            for (const kind of kinds) {
                                if (hasCharacterSequence[kind](chars)) {
                                    foundKinds.add(kind);
                                }
                            }
                        }
                    }
                });
                for (const kind of foundKinds) {
                    let suggest;
                    if (kind === "surrogatePairWithoutUFlag") {
                        suggest = [{
                                messageId: "suggestUnicodeFlag",
                                fix: unicodeFixer
                            }];
                    }
                    context.report({
                        node,
                        messageId: kind,
                        suggest
                    });
                }
            }
            /**
             * Checks if the given regular expression pattern would be valid with the `u` flag.
             * @param {string} pattern The regular expression pattern to verify.
             * @returns {boolean} `true` if the pattern would be valid with the `u` flag.
             * `false` if the pattern would be invalid with the `u` flag or the configured
             * ecmaVersion doesn't support the `u` flag.
             */
            function isValidWithUnicodeFlag(pattern) {
                const { ecmaVersion } = context.languageOptions;
                // ecmaVersion <= 5 doesn't support the 'u' flag
                if (ecmaVersion <= 5) {
                    return false;
                }
                const validator = new RegExpValidator({
                    ecmaVersion: Math.min(ecmaVersion, REGEXPP_LATEST_ECMA_VERSION)
                });
                try {
                    validator.validatePattern(pattern, void 0, void 0, /* uFlag = */ true);
                }
                catch {
                    return false;
                }
                return true;
            }
            return {
                "Literal[regex]"(node) {
                    verify(node, node.regex.pattern, node.regex.flags, fixer => {
                        if (!isValidWithUnicodeFlag(node.regex.pattern)) {
                            return null;
                        }
                        return fixer.insertTextAfter(node, "u");
                    });
                },
                "Program"() {
                    const scope = context.getScope();
                    const tracker = new ReferenceTracker(scope);
                    /*
                     * Iterate calls of RegExp.
                     * E.g., `new RegExp()`, `RegExp()`, `new window.RegExp()`,
                     *       `const {RegExp: a} = window; new a()`, etc...
                     */
                    for (const { node } of tracker.iterateGlobalReferences({
                        RegExp: { [CALL]: true, [CONSTRUCT]: true }
                    })) {
                        const [patternNode, flagsNode] = node.arguments;
                        const pattern = getStringIfConstant(patternNode, scope);
                        const flags = getStringIfConstant(flagsNode, scope);
                        if (typeof pattern === "string") {
                            verify(node, pattern, flags || "", fixer => {
                                if (!isValidWithUnicodeFlag(pattern)) {
                                    return null;
                                }
                                if (node.arguments.length === 1) {
                                    const penultimateToken = sourceCode.getLastToken(node, { skip: 1 }); // skip closing parenthesis
                                    return fixer.insertTextAfter(penultimateToken, astUtils.isCommaToken(penultimateToken)
                                        ? ' "u",'
                                        : ', "u"');
                                }
                                if ((flagsNode.type === "Literal" && typeof flagsNode.value === "string") || flagsNode.type === "TemplateLiteral") {
                                    const range = [flagsNode.range[0], flagsNode.range[1] - 1];
                                    return fixer.insertTextAfterRange(range, "u");
                                }
                                return null;
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/utils/unicode/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    module.exports = {
        isCombiningCharacter: require(534) /* ./is-combining-character */,
        isEmojiModifier: require(535) /* ./is-emoji-modifier */,
        isRegionalIndicatorSymbol: require(536) /* ./is-regional-indicator-symbol */,
        isSurrogatePair: require(537) /* ./is-surrogate-pair */
    };
},
/* eslint/lib/rules/utils/unicode/is-combining-character.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    /**
     * Check whether a given character is a combining mark or not.
     * @param {number} codePoint The character code to check.
     * @returns {boolean} `true` if the character belongs to the category, any of `Mc`, `Me`, and `Mn`.
     */
    module.exports = function isCombiningCharacter(codePoint) {
        return /^[\p{Mc}\p{Me}\p{Mn}]$/u.test(String.fromCodePoint(codePoint));
    };
},
/* eslint/lib/rules/utils/unicode/is-emoji-modifier.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    /**
     * Check whether a given character is an emoji modifier.
     * @param {number} code The character code to check.
     * @returns {boolean} `true` if the character is an emoji modifier.
     */
    module.exports = function isEmojiModifier(code) {
        return code >= 0x1F3FB && code <= 0x1F3FF;
    };
},
/* eslint/lib/rules/utils/unicode/is-regional-indicator-symbol.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    /**
     * Check whether a given character is a regional indicator symbol.
     * @param {number} code The character code to check.
     * @returns {boolean} `true` if the character is a regional indicator symbol.
     */
    module.exports = function isRegionalIndicatorSymbol(code) {
        return code >= 0x1F1E6 && code <= 0x1F1FF;
    };
},
/* eslint/lib/rules/utils/unicode/is-surrogate-pair.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @author Toru Nagashima <https://github.com/mysticatea>
     */
    "use strict";
    /**
     * Check whether given two characters are a surrogate pair.
     * @param {number} lead The code of the lead character.
     * @param {number} tail The code of the tail character.
     * @returns {boolean} `true` if the character pair is a surrogate pair.
     */
    module.exports = function isSurrogatePair(lead, tail) {
        return lead >= 0xD800 && lead < 0xDC00 && tail >= 0xDC00 && tail < 0xE000;
    };
},
/* eslint/lib/rules/no-mixed-operators.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow mixed binary operators.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils.js */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const ARITHMETIC_OPERATORS = ["+", "-", "*", "/", "%", "**"];
    const BITWISE_OPERATORS = ["&", "|", "^", "~", "<<", ">>", ">>>"];
    const COMPARISON_OPERATORS = ["==", "!=", "===", "!==", ">", ">=", "<", "<="];
    const LOGICAL_OPERATORS = ["&&", "||"];
    const RELATIONAL_OPERATORS = ["in", "instanceof"];
    const TERNARY_OPERATOR = ["?:"];
    const COALESCE_OPERATOR = ["??"];
    const ALL_OPERATORS = [].concat(ARITHMETIC_OPERATORS, BITWISE_OPERATORS, COMPARISON_OPERATORS, LOGICAL_OPERATORS, RELATIONAL_OPERATORS, TERNARY_OPERATOR, COALESCE_OPERATOR);
    const DEFAULT_GROUPS = [
        ARITHMETIC_OPERATORS,
        BITWISE_OPERATORS,
        COMPARISON_OPERATORS,
        LOGICAL_OPERATORS,
        RELATIONAL_OPERATORS
    ];
    const TARGET_NODE_TYPE = /^(?:Binary|Logical|Conditional)Expression$/u;
    /**
     * Normalizes options.
     * @param {Object|undefined} options A options object to normalize.
     * @returns {Object} Normalized option object.
     */
    function normalizeOptions(options = {}) {
        const hasGroups = options.groups && options.groups.length > 0;
        const groups = hasGroups ? options.groups : DEFAULT_GROUPS;
        const allowSamePrecedence = options.allowSamePrecedence !== false;
        return {
            groups,
            allowSamePrecedence
        };
    }
    /**
     * Checks whether any group which includes both given operator exists or not.
     * @param {Array<string[]>} groups A list of groups to check.
     * @param {string} left An operator.
     * @param {string} right Another operator.
     * @returns {boolean} `true` if such group existed.
     */
    function includesBothInAGroup(groups, left, right) {
        return groups.some(group => group.includes(left) && group.includes(right));
    }
    /**
     * Checks whether the given node is a conditional expression and returns the test node else the left node.
     * @param {ASTNode} node A node which can be a BinaryExpression or a LogicalExpression node.
     * This parent node can be BinaryExpression, LogicalExpression
     *      , or a ConditionalExpression node
     * @returns {ASTNode} node the appropriate node(left or test).
     */
    function getChildNode(node) {
        return node.type === "ConditionalExpression" ? node.test : node.left;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow mixed binary operators",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-mixed-operators"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        groups: {
                            type: "array",
                            items: {
                                type: "array",
                                items: { enum: ALL_OPERATORS },
                                minItems: 2,
                                uniqueItems: true
                            },
                            uniqueItems: true
                        },
                        allowSamePrecedence: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedMixedOperator: "Unexpected mix of '{{leftOperator}}' and '{{rightOperator}}'. Use parentheses to clarify the intended order of operations."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const options = normalizeOptions(context.options[0]);
            /**
             * Checks whether a given node should be ignored by options or not.
             * @param {ASTNode} node A node to check. This is a BinaryExpression
             *      node or a LogicalExpression node. This parent node is one of
             *      them, too.
             * @returns {boolean} `true` if the node should be ignored.
             */
            function shouldIgnore(node) {
                const a = node;
                const b = node.parent;
                return (!includesBothInAGroup(options.groups, a.operator, b.type === "ConditionalExpression" ? "?:" : b.operator) ||
                    (options.allowSamePrecedence &&
                        astUtils.getPrecedence(a) === astUtils.getPrecedence(b)));
            }
            /**
             * Checks whether the operator of a given node is mixed with parent
             * node's operator or not.
             * @param {ASTNode} node A node to check. This is a BinaryExpression
             *      node or a LogicalExpression node. This parent node is one of
             *      them, too.
             * @returns {boolean} `true` if the node was mixed.
             */
            function isMixedWithParent(node) {
                return (node.operator !== node.parent.operator &&
                    !astUtils.isParenthesised(sourceCode, node));
            }
            /**
             * Gets the operator token of a given node.
             * @param {ASTNode} node A node to check. This is a BinaryExpression
             *      node or a LogicalExpression node.
             * @returns {Token} The operator token of the node.
             */
            function getOperatorToken(node) {
                return sourceCode.getTokenAfter(getChildNode(node), astUtils.isNotClosingParenToken);
            }
            /**
             * Reports both the operator of a given node and the operator of the
             * parent node.
             * @param {ASTNode} node A node to check. This is a BinaryExpression
             *      node or a LogicalExpression node. This parent node is one of
             *      them, too.
             * @returns {void}
             */
            function reportBothOperators(node) {
                const parent = node.parent;
                const left = (getChildNode(parent) === node) ? node : parent;
                const right = (getChildNode(parent) !== node) ? node : parent;
                const data = {
                    leftOperator: left.operator || "?:",
                    rightOperator: right.operator || "?:"
                };
                context.report({
                    node: left,
                    loc: getOperatorToken(left).loc,
                    messageId: "unexpectedMixedOperator",
                    data
                });
                context.report({
                    node: right,
                    loc: getOperatorToken(right).loc,
                    messageId: "unexpectedMixedOperator",
                    data
                });
            }
            /**
             * Checks between the operator of this node and the operator of the
             * parent node.
             * @param {ASTNode} node A node to check.
             * @returns {void}
             */
            function check(node) {
                if (TARGET_NODE_TYPE.test(node.parent.type) &&
                    isMixedWithParent(node) &&
                    !shouldIgnore(node)) {
                    reportBothOperators(node);
                }
            }
            return {
                BinaryExpression: check,
                LogicalExpression: check
            };
        }
    };
},
/* eslint/lib/rules/no-mixed-requires.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce grouped require statements for Node.JS
     * @author Raphael Pigulla
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Disallow `require` calls to be mixed with regular variable declarations",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-mixed-requires"
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: "boolean"
                        },
                        {
                            type: "object",
                            properties: {
                                grouping: {
                                    type: "boolean"
                                },
                                allowCall: {
                                    type: "boolean"
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                noMixRequire: "Do not mix 'require' and other declarations.",
                noMixCoreModuleFileComputed: "Do not mix core, module, file and computed requires."
            }
        },
        create(context) {
            const options = context.options[0];
            let grouping = false, allowCall = false;
            if (typeof options === "object") {
                grouping = options.grouping;
                allowCall = options.allowCall;
            }
            else {
                grouping = !!options;
            }
            /**
             * Returns the list of built-in modules.
             * @returns {string[]} An array of built-in Node.js modules.
             */
            function getBuiltinModules() {
                /*
                 * This list is generated using:
                 * `require("repl")._builtinLibs.concat('repl').sort()`
                 * This particular list is as per nodejs v0.12.2 and iojs v0.7.1
                 */
                return [
                    "assert", "buffer", "child_process", "cluster", "crypto",
                    "dgram", "dns", "domain", "events", "fs", "http", "https",
                    "net", "os", "path", "punycode", "querystring", "readline",
                    "repl", "smalloc", "stream", "string_decoder", "tls", "tty",
                    "url", "util", "v8", "vm", "zlib"
                ];
            }
            const BUILTIN_MODULES = getBuiltinModules();
            const DECL_REQUIRE = "require", DECL_UNINITIALIZED = "uninitialized", DECL_OTHER = "other";
            const REQ_CORE = "core", REQ_FILE = "file", REQ_MODULE = "module", REQ_COMPUTED = "computed";
            /**
             * Determines the type of a declaration statement.
             * @param {ASTNode} initExpression The init node of the VariableDeclarator.
             * @returns {string} The type of declaration represented by the expression.
             */
            function getDeclarationType(initExpression) {
                if (!initExpression) {
                    // "var x;"
                    return DECL_UNINITIALIZED;
                }
                if (initExpression.type === "CallExpression" &&
                    initExpression.callee.type === "Identifier" &&
                    initExpression.callee.name === "require") {
                    // "var x = require('util');"
                    return DECL_REQUIRE;
                }
                if (allowCall &&
                    initExpression.type === "CallExpression" &&
                    initExpression.callee.type === "CallExpression") {
                    // "var x = require('diagnose')('sub-module');"
                    return getDeclarationType(initExpression.callee);
                }
                if (initExpression.type === "MemberExpression") {
                    // "var x = require('glob').Glob;"
                    return getDeclarationType(initExpression.object);
                }
                // "var x = 42;"
                return DECL_OTHER;
            }
            /**
             * Determines the type of module that is loaded via require.
             * @param {ASTNode} initExpression The init node of the VariableDeclarator.
             * @returns {string} The module type.
             */
            function inferModuleType(initExpression) {
                if (initExpression.type === "MemberExpression") {
                    // "var x = require('glob').Glob;"
                    return inferModuleType(initExpression.object);
                }
                if (initExpression.arguments.length === 0) {
                    // "var x = require();"
                    return REQ_COMPUTED;
                }
                const arg = initExpression.arguments[0];
                if (arg.type !== "Literal" || typeof arg.value !== "string") {
                    // "var x = require(42);"
                    return REQ_COMPUTED;
                }
                if (BUILTIN_MODULES.includes(arg.value)) {
                    // "var fs = require('fs');"
                    return REQ_CORE;
                }
                if (/^\.{0,2}\//u.test(arg.value)) {
                    // "var utils = require('./utils');"
                    return REQ_FILE;
                }
                // "var async = require('async');"
                return REQ_MODULE;
            }
            /**
             * Check if the list of variable declarations is mixed, i.e. whether it
             * contains both require and other declarations.
             * @param {ASTNode} declarations The list of VariableDeclarators.
             * @returns {boolean} True if the declarations are mixed, false if not.
             */
            function isMixed(declarations) {
                const contains = {};
                declarations.forEach(declaration => {
                    const type = getDeclarationType(declaration.init);
                    contains[type] = true;
                });
                return !!(contains[DECL_REQUIRE] &&
                    (contains[DECL_UNINITIALIZED] || contains[DECL_OTHER]));
            }
            /**
             * Check if all require declarations in the given list are of the same
             * type.
             * @param {ASTNode} declarations The list of VariableDeclarators.
             * @returns {boolean} True if the declarations are grouped, false if not.
             */
            function isGrouped(declarations) {
                const found = {};
                declarations.forEach(declaration => {
                    if (getDeclarationType(declaration.init) === DECL_REQUIRE) {
                        found[inferModuleType(declaration.init)] = true;
                    }
                });
                return Object.keys(found).length <= 1;
            }
            return {
                VariableDeclaration(node) {
                    if (isMixed(node.declarations)) {
                        context.report({
                            node,
                            messageId: "noMixRequire"
                        });
                    }
                    else if (grouping && !isGrouped(node.declarations)) {
                        context.report({
                            node,
                            messageId: "noMixCoreModuleFileComputed"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-mixed-spaces-and-tabs.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow mixed spaces and tabs for indentation
     * @author Jary Niebur
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Disallow mixed spaces and tabs for indentation",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-mixed-spaces-and-tabs"
            },
            schema: [
                {
                    enum: ["smart-tabs", true, false]
                }
            ],
            messages: {
                mixedSpacesAndTabs: "Mixed spaces and tabs."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            let smartTabs;
            switch (context.options[0]) {
                case true: // Support old syntax, maybe add deprecation warning here
                case "smart-tabs":
                    smartTabs = true;
                    break;
                default:
                    smartTabs = false;
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                "Program:exit"(node) {
                    const lines = sourceCode.lines, comments = sourceCode.getAllComments(), ignoredCommentLines = new Set();
                    // Add all lines except the first ones.
                    comments.forEach(comment => {
                        for (let i = comment.loc.start.line + 1; i <= comment.loc.end.line; i++) {
                            ignoredCommentLines.add(i);
                        }
                    });
                    /*
                     * At least one space followed by a tab
                     * or the reverse before non-tab/-space
                     * characters begin.
                     */
                    let regex = /^(?=( +|\t+))\1(?:\t| )/u;
                    if (smartTabs) {
                        /*
                         * At least one space followed by a tab
                         * before non-tab/-space characters begin.
                         */
                        regex = /^(?=(\t*))\1(?=( +))\2\t/u;
                    }
                    lines.forEach((line, i) => {
                        const match = regex.exec(line);
                        if (match) {
                            const lineNumber = i + 1;
                            const loc = {
                                start: {
                                    line: lineNumber,
                                    column: match[0].length - 2
                                },
                                end: {
                                    line: lineNumber,
                                    column: match[0].length
                                }
                            };
                            if (!ignoredCommentLines.has(lineNumber)) {
                                const containingNode = sourceCode.getNodeByRangeIndex(sourceCode.getIndexFromLoc(loc.start));
                                if (!(containingNode && ["Literal", "TemplateElement"].includes(containingNode.type))) {
                                    context.report({
                                        node,
                                        loc,
                                        messageId: "mixedSpacesAndTabs"
                                    });
                                }
                            }
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-multi-assign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check use of chained assignment expressions
     * @author Stewart Rand
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow use of chained assignment expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-multi-assign"
            },
            schema: [{
                    type: "object",
                    properties: {
                        ignoreNonDeclaration: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                unexpectedChain: "Unexpected chained assignment."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            const options = context.options[0] || {
                ignoreNonDeclaration: false
            };
            const selectors = [
                "VariableDeclarator > AssignmentExpression.init",
                "PropertyDefinition > AssignmentExpression.value"
            ];
            if (!options.ignoreNonDeclaration) {
                selectors.push("AssignmentExpression > AssignmentExpression.right");
            }
            return {
                [selectors](node) {
                    context.report({
                        node,
                        messageId: "unexpectedChain"
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-multi-spaces.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Disallow use of multiple spaces.
     * @author Nicholas C. Zakas
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Disallow multiple spaces",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-multi-spaces"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        exceptions: {
                            type: "object",
                            patternProperties: {
                                "^([A-Z][a-z]*)+$": {
                                    type: "boolean"
                                }
                            },
                            additionalProperties: false
                        },
                        ignoreEOLComments: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                multipleSpaces: "Multiple spaces found before '{{displayValue}}'."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const options = context.options[0] || {};
            const ignoreEOLComments = options.ignoreEOLComments;
            const exceptions = Object.assign({ Property: true }, options.exceptions);
            const hasExceptions = Object.keys(exceptions).some(key => exceptions[key]);
            /**
             * Formats value of given comment token for error message by truncating its length.
             * @param {Token} token comment token
             * @returns {string} formatted value
             * @private
             */
            function formatReportedCommentValue(token) {
                const valueLines = token.value.split("\n");
                const value = valueLines[0];
                const formattedValue = `${value.slice(0, 12)}...`;
                return valueLines.length === 1 && value.length <= 12 ? value : formattedValue;
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program() {
                    sourceCode.tokensAndComments.forEach((leftToken, leftIndex, tokensAndComments) => {
                        if (leftIndex === tokensAndComments.length - 1) {
                            return;
                        }
                        const rightToken = tokensAndComments[leftIndex + 1];
                        // Ignore tokens that don't have 2 spaces between them or are on different lines
                        if (!sourceCode.text.slice(leftToken.range[1], rightToken.range[0]).includes("  ") ||
                            leftToken.loc.end.line < rightToken.loc.start.line) {
                            return;
                        }
                        // Ignore comments that are the last token on their line if `ignoreEOLComments` is active.
                        if (ignoreEOLComments &&
                            astUtils.isCommentToken(rightToken) &&
                            (leftIndex === tokensAndComments.length - 2 ||
                                rightToken.loc.end.line < tokensAndComments[leftIndex + 2].loc.start.line)) {
                            return;
                        }
                        // Ignore tokens that are in a node in the "exceptions" object
                        if (hasExceptions) {
                            const parentNode = sourceCode.getNodeByRangeIndex(rightToken.range[0] - 1);
                            if (parentNode && exceptions[parentNode.type]) {
                                return;
                            }
                        }
                        let displayValue;
                        if (rightToken.type === "Block") {
                            displayValue = `/*${formatReportedCommentValue(rightToken)}*/`;
                        }
                        else if (rightToken.type === "Line") {
                            displayValue = `//${formatReportedCommentValue(rightToken)}`;
                        }
                        else {
                            displayValue = rightToken.value;
                        }
                        context.report({
                            node: rightToken,
                            loc: { start: leftToken.loc.end, end: rightToken.loc.start },
                            messageId: "multipleSpaces",
                            data: { displayValue },
                            fix: fixer => fixer.replaceTextRange([leftToken.range[1], rightToken.range[0]], " ")
                        });
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-multi-str.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when using multiline strings
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow multiline strings",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-multi-str"
            },
            schema: [],
            messages: {
                multilineString: "Multiline support is limited to browsers supporting ES5 only."
            }
        },
        create(context) {
            /**
             * Determines if a given node is part of JSX syntax.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} True if the node is a JSX node, false if not.
             * @private
             */
            function isJSXElement(node) {
                return node.type.indexOf("JSX") === 0;
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                Literal(node) {
                    if (astUtils.LINEBREAK_MATCHER.test(node.raw) && !isJSXElement(node.parent)) {
                        context.report({
                            node,
                            messageId: "multilineString"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-multiple-empty-lines.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallows multiple blank lines.
     * implementation adapted from the no-trailing-spaces rule.
     * @author Greg Cochard
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Disallow multiple empty lines",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-multiple-empty-lines"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        max: {
                            type: "integer",
                            minimum: 0
                        },
                        maxEOF: {
                            type: "integer",
                            minimum: 0
                        },
                        maxBOF: {
                            type: "integer",
                            minimum: 0
                        }
                    },
                    required: ["max"],
                    additionalProperties: false
                }
            ],
            messages: {
                blankBeginningOfFile: "Too many blank lines at the beginning of file. Max of {{max}} allowed.",
                blankEndOfFile: "Too many blank lines at the end of file. Max of {{max}} allowed.",
                consecutiveBlank: "More than {{max}} blank {{pluralizedLines}} not allowed."
            }
        },
        create(context) {
            // Use options.max or 2 as default
            let max = 2, maxEOF = max, maxBOF = max;
            if (context.options.length) {
                max = context.options[0].max;
                maxEOF = typeof context.options[0].maxEOF !== "undefined" ? context.options[0].maxEOF : max;
                maxBOF = typeof context.options[0].maxBOF !== "undefined" ? context.options[0].maxBOF : max;
            }
            const sourceCode = context.getSourceCode();
            // Swallow the final newline, as some editors add it automatically and we don't want it to cause an issue
            const allLines = sourceCode.lines[sourceCode.lines.length - 1] === "" ? sourceCode.lines.slice(0, -1) : sourceCode.lines;
            const templateLiteralLines = new Set();
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                TemplateLiteral(node) {
                    node.quasis.forEach(literalPart => {
                        // Empty lines have a semantic meaning if they're inside template literals. Don't count these as empty lines.
                        for (let ignoredLine = literalPart.loc.start.line; ignoredLine < literalPart.loc.end.line; ignoredLine++) {
                            templateLiteralLines.add(ignoredLine);
                        }
                    });
                },
                "Program:exit"(node) {
                    return allLines
                        // Given a list of lines, first get a list of line numbers that are non-empty.
                        .reduce((nonEmptyLineNumbers, line, index) => {
                        if (line.trim() || templateLiteralLines.has(index + 1)) {
                            nonEmptyLineNumbers.push(index + 1);
                        }
                        return nonEmptyLineNumbers;
                    }, [])
                        // Add a value at the end to allow trailing empty lines to be checked.
                        .concat(allLines.length + 1)
                        // Given two line numbers of non-empty lines, report the lines between if the difference is too large.
                        .reduce((lastLineNumber, lineNumber) => {
                        let messageId, maxAllowed;
                        if (lastLineNumber === 0) {
                            messageId = "blankBeginningOfFile";
                            maxAllowed = maxBOF;
                        }
                        else if (lineNumber === allLines.length + 1) {
                            messageId = "blankEndOfFile";
                            maxAllowed = maxEOF;
                        }
                        else {
                            messageId = "consecutiveBlank";
                            maxAllowed = max;
                        }
                        if (lineNumber - lastLineNumber - 1 > maxAllowed) {
                            context.report({
                                node,
                                loc: {
                                    start: { line: lastLineNumber + maxAllowed + 1, column: 0 },
                                    end: { line: lineNumber, column: 0 }
                                },
                                messageId,
                                data: {
                                    max: maxAllowed,
                                    pluralizedLines: maxAllowed === 1 ? "line" : "lines"
                                },
                                fix(fixer) {
                                    const rangeStart = sourceCode.getIndexFromLoc({ line: lastLineNumber + 1, column: 0 });
                                    /*
                                     * The end of the removal range is usually the start index of the next line.
                                     * However, at the end of the file there is no next line, so the end of the
                                     * range is just the length of the text.
                                     */
                                    const lineNumberAfterRemovedLines = lineNumber - maxAllowed;
                                    const rangeEnd = lineNumberAfterRemovedLines <= allLines.length
                                        ? sourceCode.getIndexFromLoc({ line: lineNumberAfterRemovedLines, column: 0 })
                                        : sourceCode.text.length;
                                    return fixer.removeRange([rangeStart, rangeEnd]);
                                }
                            });
                        }
                        return lineNumber;
                    }, 0);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-native-reassign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow assignments to native objects or read-only global variables
     * @author Ilya Volodin
     * @deprecated in ESLint v3.3.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow assignments to native objects or read-only global variables",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-native-reassign"
            },
            deprecated: true,
            replacedBy: ["no-global-assign"],
            schema: [
                {
                    type: "object",
                    properties: {
                        exceptions: {
                            type: "array",
                            items: { type: "string" },
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                nativeReassign: "Read-only global '{{name}}' should not be modified."
            }
        },
        create(context) {
            const config = context.options[0];
            const exceptions = (config && config.exceptions) || [];
            /**
             * Reports write references.
             * @param {Reference} reference A reference to check.
             * @param {int} index The index of the reference in the references.
             * @param {Reference[]} references The array that the reference belongs to.
             * @returns {void}
             */
            function checkReference(reference, index, references) {
                const identifier = reference.identifier;
                if (reference.init === false &&
                    reference.isWrite() &&
                    /*
                     * Destructuring assignments can have multiple default value,
                     * so possibly there are multiple writeable references for the same identifier.
                     */
                    (index === 0 || references[index - 1].identifier !== identifier)) {
                    context.report({
                        node: identifier,
                        messageId: "nativeReassign",
                        data: identifier
                    });
                }
            }
            /**
             * Reports write references if a given variable is read-only builtin.
             * @param {Variable} variable A variable to check.
             * @returns {void}
             */
            function checkVariable(variable) {
                if (variable.writeable === false && !exceptions.includes(variable.name)) {
                    variable.references.forEach(checkReference);
                }
            }
            return {
                Program() {
                    const globalScope = context.getScope();
                    globalScope.variables.forEach(checkVariable);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-negated-condition.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to disallow a negated condition
     * @author Alberto Rodríguez
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow negated conditions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-negated-condition"
            },
            schema: [],
            messages: {
                unexpectedNegated: "Unexpected negated condition."
            }
        },
        create(context) {
            /**
             * Determines if a given node is an if-else without a condition on the else
             * @param {ASTNode} node The node to check.
             * @returns {boolean} True if the node has an else without an if.
             * @private
             */
            function hasElseWithoutCondition(node) {
                return node.alternate && node.alternate.type !== "IfStatement";
            }
            /**
             * Determines if a given node is a negated unary expression
             * @param {Object} test The test object to check.
             * @returns {boolean} True if the node is a negated unary expression.
             * @private
             */
            function isNegatedUnaryExpression(test) {
                return test.type === "UnaryExpression" && test.operator === "!";
            }
            /**
             * Determines if a given node is a negated binary expression
             * @param {Test} test The test to check.
             * @returns {boolean} True if the node is a negated binary expression.
             * @private
             */
            function isNegatedBinaryExpression(test) {
                return test.type === "BinaryExpression" &&
                    (test.operator === "!=" || test.operator === "!==");
            }
            /**
             * Determines if a given node has a negated if expression
             * @param {ASTNode} node The node to check.
             * @returns {boolean} True if the node has a negated if expression.
             * @private
             */
            function isNegatedIf(node) {
                return isNegatedUnaryExpression(node.test) || isNegatedBinaryExpression(node.test);
            }
            return {
                IfStatement(node) {
                    if (!hasElseWithoutCondition(node)) {
                        return;
                    }
                    if (isNegatedIf(node)) {
                        context.report({
                            node,
                            messageId: "unexpectedNegated"
                        });
                    }
                },
                ConditionalExpression(node) {
                    if (isNegatedIf(node)) {
                        context.report({
                            node,
                            messageId: "unexpectedNegated"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-negated-in-lhs.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow negated left operands of the `in` operator
     * @author Michael Ficarra
     * @deprecated in ESLint v3.3.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow negating the left operand in `in` expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-negated-in-lhs"
            },
            replacedBy: ["no-unsafe-negation"],
            deprecated: true,
            schema: [],
            messages: {
                negatedLHS: "The 'in' expression's left operand is negated."
            }
        },
        create(context) {
            return {
                BinaryExpression(node) {
                    if (node.operator === "in" && node.left.type === "UnaryExpression" && node.left.operator === "!") {
                        context.report({ node, messageId: "negatedLHS" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-nested-ternary.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag nested ternary expressions
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow nested ternary expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-nested-ternary"
            },
            schema: [],
            messages: {
                noNestedTernary: "Do not nest ternary expressions."
            }
        },
        create(context) {
            return {
                ConditionalExpression(node) {
                    if (node.alternate.type === "ConditionalExpression" ||
                        node.consequent.type === "ConditionalExpression") {
                        context.report({
                            node,
                            messageId: "noNestedTernary"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-new.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag statements with function invocation preceded by
     * "new" and not part of assignment
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `new` operators outside of assignments or comparisons",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-new"
            },
            schema: [],
            messages: {
                noNewStatement: "Do not use 'new' for side effects."
            }
        },
        create(context) {
            return {
                "ExpressionStatement > NewExpression"(node) {
                    context.report({
                        node: node.parent,
                        messageId: "noNewStatement"
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-new-func.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when using new Function
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const callMethods = new Set(["apply", "bind", "call"]);
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `new` operators with the `Function` object",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-new-func"
            },
            schema: [],
            messages: {
                noFunctionConstructor: "The Function constructor is eval."
            }
        },
        create(context) {
            return {
                "Program:exit"() {
                    const globalScope = context.getScope();
                    const variable = globalScope.set.get("Function");
                    if (variable && variable.defs.length === 0) {
                        variable.references.forEach(ref => {
                            const node = ref.identifier;
                            const { parent } = node;
                            let evalNode;
                            if (parent) {
                                if (node === parent.callee && (parent.type === "NewExpression" ||
                                    parent.type === "CallExpression")) {
                                    evalNode = parent;
                                }
                                else if (parent.type === "MemberExpression" &&
                                    node === parent.object &&
                                    callMethods.has(astUtils.getStaticPropertyName(parent))) {
                                    const maybeCallee = parent.parent.type === "ChainExpression" ? parent.parent : parent;
                                    if (maybeCallee.parent.type === "CallExpression" && maybeCallee.parent.callee === maybeCallee) {
                                        evalNode = maybeCallee.parent;
                                    }
                                }
                            }
                            if (evalNode) {
                                context.report({
                                    node: evalNode,
                                    messageId: "noFunctionConstructor"
                                });
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-new-native-nonconstructor.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow use of the new operator with global non-constructor functions
     * @author Sosuke Suzuki
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const nonConstructorGlobalFunctionNames = ["Symbol", "BigInt"];
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow `new` operators with global non-constructor functions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-new-native-nonconstructor"
            },
            schema: [],
            messages: {
                noNewNonconstructor: "`{{name}}` cannot be called as a constructor."
            }
        },
        create(context) {
            return {
                "Program:exit"() {
                    const globalScope = context.getScope();
                    for (const nonConstructorName of nonConstructorGlobalFunctionNames) {
                        const variable = globalScope.set.get(nonConstructorName);
                        if (variable && variable.defs.length === 0) {
                            variable.references.forEach(ref => {
                                const node = ref.identifier;
                                const parent = node.parent;
                                if (parent && parent.type === "NewExpression" && parent.callee === node) {
                                    context.report({
                                        node,
                                        messageId: "noNewNonconstructor",
                                        data: { name: nonConstructorName }
                                    });
                                }
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-new-object.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow calls to the Object constructor
     * @author Matt DuVall <http://www.mattduvall.com/>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `Object` constructors",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-new-object"
            },
            schema: [],
            messages: {
                preferLiteral: "The object literal notation {} is preferable."
            }
        },
        create(context) {
            return {
                NewExpression(node) {
                    const variable = astUtils.getVariableByName(context.getScope(), node.callee.name);
                    if (variable && variable.identifiers.length > 0) {
                        return;
                    }
                    if (node.callee.name === "Object") {
                        context.report({
                            node,
                            messageId: "preferLiteral"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-new-require.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow use of new operator with the `require` function
     * @author Wil Moore III
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Disallow `new` operators with calls to `require`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-new-require"
            },
            schema: [],
            messages: {
                noNewRequire: "Unexpected use of new with require."
            }
        },
        create(context) {
            return {
                NewExpression(node) {
                    if (node.callee.type === "Identifier" && node.callee.name === "require") {
                        context.report({
                            node,
                            messageId: "noNewRequire"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-new-symbol.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow use of the new operator with the `Symbol` object
     * @author Alberto Rodríguez
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow `new` operators with the `Symbol` object",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-new-symbol"
            },
            schema: [],
            messages: {
                noNewSymbol: "`Symbol` cannot be called as a constructor."
            }
        },
        create(context) {
            return {
                "Program:exit"() {
                    const globalScope = context.getScope();
                    const variable = globalScope.set.get("Symbol");
                    if (variable && variable.defs.length === 0) {
                        variable.references.forEach(ref => {
                            const node = ref.identifier;
                            const parent = node.parent;
                            if (parent && parent.type === "NewExpression" && parent.callee === node) {
                                context.report({
                                    node,
                                    messageId: "noNewSymbol"
                                });
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-new-wrappers.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when using constructor for wrapper objects
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `new` operators with the `String`, `Number`, and `Boolean` objects",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-new-wrappers"
            },
            schema: [],
            messages: {
                noConstructor: "Do not use {{fn}} as a constructor."
            }
        },
        create(context) {
            return {
                NewExpression(node) {
                    const wrapperObjects = ["String", "Number", "Boolean"];
                    if (wrapperObjects.includes(node.callee.name)) {
                        context.report({
                            node,
                            messageId: "noConstructor",
                            data: { fn: node.callee.name }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-nonoctal-decimal-escape.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow `\8` and `\9` escape sequences in string literals.
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const QUICK_TEST_REGEX = /\\[89]/u;
    /**
     * Returns unicode escape sequence that represents the given character.
     * @param {string} character A single code unit.
     * @returns {string} "\uXXXX" sequence.
     */
    function getUnicodeEscape(character) {
        return `\\u${character.charCodeAt(0).toString(16).padStart(4, "0")}`;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `\\8` and `\\9` escape sequences in string literals",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-nonoctal-decimal-escape"
            },
            hasSuggestions: true,
            schema: [],
            messages: {
                decimalEscape: "Don't use '{{decimalEscape}}' escape sequence.",
                // suggestions
                refactor: "Replace '{{original}}' with '{{replacement}}'. This maintains the current functionality.",
                escapeBackslash: "Replace '{{original}}' with '{{replacement}}' to include the actual backslash character."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Creates a new Suggestion object.
             * @param {string} messageId "refactor" or "escapeBackslash".
             * @param {int[]} range The range to replace.
             * @param {string} replacement New text for the range.
             * @returns {Object} Suggestion
             */
            function createSuggestion(messageId, range, replacement) {
                return {
                    messageId,
                    data: {
                        original: sourceCode.getText().slice(...range),
                        replacement
                    },
                    fix(fixer) {
                        return fixer.replaceTextRange(range, replacement);
                    }
                };
            }
            return {
                Literal(node) {
                    if (typeof node.value !== "string") {
                        return;
                    }
                    if (!QUICK_TEST_REGEX.test(node.raw)) {
                        return;
                    }
                    const regex = /(?:[^\\]|(?<previousEscape>\\.))*?(?<decimalEscape>\\[89])/suy;
                    let match;
                    while ((match = regex.exec(node.raw))) {
                        const { previousEscape, decimalEscape } = match.groups;
                        const decimalEscapeRangeEnd = node.range[0] + match.index + match[0].length;
                        const decimalEscapeRangeStart = decimalEscapeRangeEnd - decimalEscape.length;
                        const decimalEscapeRange = [decimalEscapeRangeStart, decimalEscapeRangeEnd];
                        const suggest = [];
                        // When `regex` is matched, `previousEscape` can only capture characters adjacent to `decimalEscape`
                        if (previousEscape === "\\0") {
                            /*
                             * Now we have a NULL escape "\0" immediately followed by a decimal escape, e.g.: "\0\8".
                             * Fixing this to "\08" would turn "\0" into a legacy octal escape. To avoid producing
                             * an octal escape while fixing a decimal escape, we provide different suggestions.
                             */
                            suggest.push(createSuggestion(// "\0\8" -> "\u00008"
                            "refactor", [decimalEscapeRangeStart - previousEscape.length, decimalEscapeRangeEnd], `${getUnicodeEscape("\0")}${decimalEscape[1]}`), createSuggestion(// "\8" -> "\u0038"
                            "refactor", decimalEscapeRange, getUnicodeEscape(decimalEscape[1])));
                        }
                        else {
                            suggest.push(createSuggestion(// "\8" -> "8"
                            "refactor", decimalEscapeRange, decimalEscape[1]));
                        }
                        suggest.push(createSuggestion(// "\8" -> "\\8"
                        "escapeBackslash", decimalEscapeRange, `\\${decimalEscape}`));
                        context.report({
                            node,
                            loc: {
                                start: sourceCode.getLocFromIndex(decimalEscapeRangeStart),
                                end: sourceCode.getLocFromIndex(decimalEscapeRangeEnd)
                            },
                            messageId: "decimalEscape",
                            data: {
                                decimalEscape
                            },
                            suggest
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-obj-calls.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of an object property of the global object (Math and JSON) as a function
     * @author James Allardice
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { CALL, CONSTRUCT, ReferenceTracker } = require(316) /* @eslint-community/eslint-utils */;
    const getPropertyName = require(360) /* ./utils/ast-utils */.getStaticPropertyName;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const nonCallableGlobals = ["Atomics", "JSON", "Math", "Reflect", "Intl"];
    /**
     * Returns the name of the node to report
     * @param {ASTNode} node A node to report
     * @returns {string} name to report
     */
    function getReportNodeName(node) {
        if (node.type === "ChainExpression") {
            return getReportNodeName(node.expression);
        }
        if (node.type === "MemberExpression") {
            return getPropertyName(node);
        }
        return node.name;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow calling global object properties as functions",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-obj-calls"
            },
            schema: [],
            messages: {
                unexpectedCall: "'{{name}}' is not a function.",
                unexpectedRefCall: "'{{name}}' is reference to '{{ref}}', which is not a function."
            }
        },
        create(context) {
            return {
                Program() {
                    const scope = context.getScope();
                    const tracker = new ReferenceTracker(scope);
                    const traceMap = {};
                    for (const g of nonCallableGlobals) {
                        traceMap[g] = {
                            [CALL]: true,
                            [CONSTRUCT]: true
                        };
                    }
                    for (const { node, path } of tracker.iterateGlobalReferences(traceMap)) {
                        const name = getReportNodeName(node.callee);
                        const ref = path[0];
                        const messageId = name === ref ? "unexpectedCall" : "unexpectedRefCall";
                        context.report({ node, messageId, data: { name, ref } });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-octal.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when initializing octal literal
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow octal literals",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-octal"
            },
            schema: [],
            messages: {
                noOctal: "Octal literals should not be used."
            }
        },
        create(context) {
            return {
                Literal(node) {
                    if (typeof node.value === "number" && /^0[0-9]/u.test(node.raw)) {
                        context.report({
                            node,
                            messageId: "noOctal"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-octal-escape.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag octal escape sequences in string literals.
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow octal escape sequences in string literals",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-octal-escape"
            },
            schema: [],
            messages: {
                octalEscapeSequence: "Don't use octal: '\\{{sequence}}'. Use '\\u....' instead."
            }
        },
        create(context) {
            return {
                Literal(node) {
                    if (typeof node.value !== "string") {
                        return;
                    }
                    // \0 represents a valid NULL character if it isn't followed by a digit.
                    const match = node.raw.match(/^(?:[^\\]|\\.)*?\\([0-3][0-7]{1,2}|[4-7][0-7]|0(?=[89])|[1-7])/su);
                    if (match) {
                        context.report({
                            node,
                            messageId: "octalEscapeSequence",
                            data: { sequence: match[1] }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-param-reassign.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow reassignment of function parameters.
     * @author Nat Burns
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const stopNodePattern = /(?:Statement|Declaration|Function(?:Expression)?|Program)$/u;
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow reassigning `function` parameters",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-param-reassign"
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: "object",
                            properties: {
                                props: {
                                    enum: [false]
                                }
                            },
                            additionalProperties: false
                        },
                        {
                            type: "object",
                            properties: {
                                props: {
                                    enum: [true]
                                },
                                ignorePropertyModificationsFor: {
                                    type: "array",
                                    items: {
                                        type: "string"
                                    },
                                    uniqueItems: true
                                },
                                ignorePropertyModificationsForRegex: {
                                    type: "array",
                                    items: {
                                        type: "string"
                                    },
                                    uniqueItems: true
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                assignmentToFunctionParam: "Assignment to function parameter '{{name}}'.",
                assignmentToFunctionParamProp: "Assignment to property of function parameter '{{name}}'."
            }
        },
        create(context) {
            const props = context.options[0] && context.options[0].props;
            const ignoredPropertyAssignmentsFor = context.options[0] && context.options[0].ignorePropertyModificationsFor || [];
            const ignoredPropertyAssignmentsForRegex = context.options[0] && context.options[0].ignorePropertyModificationsForRegex || [];
            /**
             * Checks whether or not the reference modifies properties of its variable.
             * @param {Reference} reference A reference to check.
             * @returns {boolean} Whether or not the reference modifies properties of its variable.
             */
            function isModifyingProp(reference) {
                let node = reference.identifier;
                let parent = node.parent;
                while (parent && (!stopNodePattern.test(parent.type) ||
                    parent.type === "ForInStatement" || parent.type === "ForOfStatement")) {
                    switch (parent.type) {
                        // e.g. foo.a = 0;
                        case "AssignmentExpression":
                            return parent.left === node;
                        // e.g. ++foo.a;
                        case "UpdateExpression":
                            return true;
                        // e.g. delete foo.a;
                        case "UnaryExpression":
                            if (parent.operator === "delete") {
                                return true;
                            }
                            break;
                        // e.g. for (foo.a in b) {}
                        case "ForInStatement":
                        case "ForOfStatement":
                            if (parent.left === node) {
                                return true;
                            }
                            // this is a stop node for parent.right and parent.body
                            return false;
                        // EXCLUDES: e.g. cache.get(foo.a).b = 0;
                        case "CallExpression":
                            if (parent.callee !== node) {
                                return false;
                            }
                            break;
                        // EXCLUDES: e.g. cache[foo.a] = 0;
                        case "MemberExpression":
                            if (parent.property === node) {
                                return false;
                            }
                            break;
                        // EXCLUDES: e.g. ({ [foo]: a }) = bar;
                        case "Property":
                            if (parent.key === node) {
                                return false;
                            }
                            break;
                        // EXCLUDES: e.g. (foo ? a : b).c = bar;
                        case "ConditionalExpression":
                            if (parent.test === node) {
                                return false;
                            }
                            break;
                        // no default
                    }
                    node = parent;
                    parent = node.parent;
                }
                return false;
            }
            /**
             * Tests that an identifier name matches any of the ignored property assignments.
             * First we test strings in ignoredPropertyAssignmentsFor.
             * Then we instantiate and test RegExp objects from ignoredPropertyAssignmentsForRegex strings.
             * @param {string} identifierName A string that describes the name of an identifier to
             * ignore property assignments for.
             * @returns {boolean} Whether the string matches an ignored property assignment regular expression or not.
             */
            function isIgnoredPropertyAssignment(identifierName) {
                return ignoredPropertyAssignmentsFor.includes(identifierName) ||
                    ignoredPropertyAssignmentsForRegex.some(ignored => new RegExp(ignored, "u").test(identifierName));
            }
            /**
             * Reports a reference if is non initializer and writable.
             * @param {Reference} reference A reference to check.
             * @param {int} index The index of the reference in the references.
             * @param {Reference[]} references The array that the reference belongs to.
             * @returns {void}
             */
            function checkReference(reference, index, references) {
                const identifier = reference.identifier;
                if (identifier &&
                    !reference.init &&
                    /*
                     * Destructuring assignments can have multiple default value,
                     * so possibly there are multiple writeable references for the same identifier.
                     */
                    (index === 0 || references[index - 1].identifier !== identifier)) {
                    if (reference.isWrite()) {
                        context.report({
                            node: identifier,
                            messageId: "assignmentToFunctionParam",
                            data: { name: identifier.name }
                        });
                    }
                    else if (props && isModifyingProp(reference) && !isIgnoredPropertyAssignment(identifier.name)) {
                        context.report({
                            node: identifier,
                            messageId: "assignmentToFunctionParamProp",
                            data: { name: identifier.name }
                        });
                    }
                }
            }
            /**
             * Finds and reports references that are non initializer and writable.
             * @param {Variable} variable A variable to check.
             * @returns {void}
             */
            function checkVariable(variable) {
                if (variable.defs[0].type === "Parameter") {
                    variable.references.forEach(checkReference);
                }
            }
            /**
             * Checks parameters of a given function node.
             * @param {ASTNode} node A function node to check.
             * @returns {void}
             */
            function checkForFunction(node) {
                context.getDeclaredVariables(node).forEach(checkVariable);
            }
            return {
                // `:exit` is needed for the `node.parent` property of identifier nodes.
                "FunctionDeclaration:exit": checkForFunction,
                "FunctionExpression:exit": checkForFunction,
                "ArrowFunctionExpression:exit": checkForFunction
            };
        }
    };
},
/* eslint/lib/rules/no-path-concat.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow string concatenation when using __dirname and __filename
     * @author Nicholas C. Zakas
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Disallow string concatenation with `__dirname` and `__filename`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-path-concat"
            },
            schema: [],
            messages: {
                usePathFunctions: "Use path.join() or path.resolve() instead of + to create paths."
            }
        },
        create(context) {
            const MATCHER = /^__(?:dir|file)name$/u;
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                BinaryExpression(node) {
                    const left = node.left, right = node.right;
                    if (node.operator === "+" &&
                        ((left.type === "Identifier" && MATCHER.test(left.name)) ||
                            (right.type === "Identifier" && MATCHER.test(right.name)))) {
                        context.report({
                            node,
                            messageId: "usePathFunctions"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-plusplus.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of unary increment and decrement operators.
     * @author Ian Christian Myers
     * @author Brody McKee (github.com/mrmckeb)
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Determines whether the given node is the update node of a `ForStatement`.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is `ForStatement` update.
     */
    function isForStatementUpdate(node) {
        const parent = node.parent;
        return parent.type === "ForStatement" && parent.update === node;
    }
    /**
     * Determines whether the given node is considered to be a for loop "afterthought" by the logic of this rule.
     * In particular, it returns `true` if the given node is either:
     *   - The update node of a `ForStatement`: for (;; i++) {}
     *   - An operand of a sequence expression that is the update node: for (;; foo(), i++) {}
     *   - An operand of a sequence expression that is child of another sequence expression, etc.,
     *     up to the sequence expression that is the update node: for (;; foo(), (bar(), (baz(), i++))) {}
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is a for loop afterthought.
     */
    function isForLoopAfterthought(node) {
        const parent = node.parent;
        if (parent.type === "SequenceExpression") {
            return isForLoopAfterthought(parent);
        }
        return isForStatementUpdate(node);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the unary operators `++` and `--`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-plusplus"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowForLoopAfterthoughts: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedUnaryOp: "Unary operator '{{operator}}' used."
            }
        },
        create(context) {
            const config = context.options[0];
            let allowForLoopAfterthoughts = false;
            if (typeof config === "object") {
                allowForLoopAfterthoughts = config.allowForLoopAfterthoughts === true;
            }
            return {
                UpdateExpression(node) {
                    if (allowForLoopAfterthoughts && isForLoopAfterthought(node)) {
                        return;
                    }
                    context.report({
                        node,
                        messageId: "unexpectedUnaryOp",
                        data: {
                            operator: node.operator
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-process-env.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow the use of process.env()
     * @author Vignesh Anand
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Disallow the use of `process.env`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-process-env"
            },
            schema: [],
            messages: {
                unexpectedProcessEnv: "Unexpected use of process.env."
            }
        },
        create(context) {
            return {
                MemberExpression(node) {
                    const objectName = node.object.name, propertyName = node.property.name;
                    if (objectName === "process" && !node.computed && propertyName && propertyName === "env") {
                        context.report({ node, messageId: "unexpectedProcessEnv" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-process-exit.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow the use of process.exit()
     * @author Nicholas C. Zakas
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Disallow the use of `process.exit()`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-process-exit"
            },
            schema: [],
            messages: {
                noProcessExit: "Don't use process.exit(); throw an error instead."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                "CallExpression > MemberExpression.callee[object.name = 'process'][property.name = 'exit']"(node) {
                    context.report({ node: node.parent, messageId: "noProcessExit" });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-promise-executor-return.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow returning values from Promise executor functions
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { findVariable } = require(316) /* @eslint-community/eslint-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const functionTypesToCheck = new Set(["ArrowFunctionExpression", "FunctionExpression"]);
    /**
     * Determines whether the given identifier node is a reference to a global variable.
     * @param {ASTNode} node `Identifier` node to check.
     * @param {Scope} scope Scope to which the node belongs.
     * @returns {boolean} True if the identifier is a reference to a global variable.
     */
    function isGlobalReference(node, scope) {
        const variable = findVariable(scope, node);
        return variable !== null && variable.scope.type === "global" && variable.defs.length === 0;
    }
    /**
     * Finds function's outer scope.
     * @param {Scope} scope Function's own scope.
     * @returns {Scope} Function's outer scope.
     */
    function getOuterScope(scope) {
        const upper = scope.upper;
        if (upper.type === "function-expression-name") {
            return upper.upper;
        }
        return upper;
    }
    /**
     * Determines whether the given function node is used as a Promise executor.
     * @param {ASTNode} node The node to check.
     * @param {Scope} scope Function's own scope.
     * @returns {boolean} `true` if the node is a Promise executor.
     */
    function isPromiseExecutor(node, scope) {
        const parent = node.parent;
        return parent.type === "NewExpression" &&
            parent.arguments[0] === node &&
            parent.callee.type === "Identifier" &&
            parent.callee.name === "Promise" &&
            isGlobalReference(parent.callee, getOuterScope(scope));
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow returning values from Promise executor functions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-promise-executor-return"
            },
            schema: [],
            messages: {
                returnsValue: "Return values from promise executor functions cannot be read."
            }
        },
        create(context) {
            let funcInfo = null;
            /**
             * Reports the given node.
             * @param {ASTNode} node Node to report.
             * @returns {void}
             */
            function report(node) {
                context.report({ node, messageId: "returnsValue" });
            }
            return {
                onCodePathStart(_, node) {
                    funcInfo = {
                        upper: funcInfo,
                        shouldCheck: functionTypesToCheck.has(node.type) && isPromiseExecutor(node, context.getScope())
                    };
                    if (funcInfo.shouldCheck && node.type === "ArrowFunctionExpression" && node.expression) {
                        report(node.body);
                    }
                },
                onCodePathEnd() {
                    funcInfo = funcInfo.upper;
                },
                ReturnStatement(node) {
                    if (funcInfo.shouldCheck && node.argument) {
                        report(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-proto.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag usage of __proto__ property
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { getStaticPropertyName } = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the use of the `__proto__` property",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-proto"
            },
            schema: [],
            messages: {
                unexpectedProto: "The '__proto__' property is deprecated."
            }
        },
        create(context) {
            return {
                MemberExpression(node) {
                    if (getStaticPropertyName(node) === "__proto__") {
                        context.report({ node, messageId: "unexpectedProto" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-prototype-builtins.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to disallow use of Object.prototype builtins on objects
     * @author Andrew Levine
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow calling some `Object.prototype` methods directly on objects",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-prototype-builtins"
            },
            schema: [],
            messages: {
                prototypeBuildIn: "Do not access Object.prototype method '{{prop}}' from target object."
            }
        },
        create(context) {
            const DISALLOWED_PROPS = new Set([
                "hasOwnProperty",
                "isPrototypeOf",
                "propertyIsEnumerable"
            ]);
            /**
             * Reports if a disallowed property is used in a CallExpression
             * @param {ASTNode} node The CallExpression node.
             * @returns {void}
             */
            function disallowBuiltIns(node) {
                const callee = astUtils.skipChainExpression(node.callee);
                if (callee.type !== "MemberExpression") {
                    return;
                }
                const propName = astUtils.getStaticPropertyName(callee);
                if (propName !== null && DISALLOWED_PROPS.has(propName)) {
                    context.report({
                        messageId: "prototypeBuildIn",
                        loc: callee.property.loc,
                        data: { prop: propName },
                        node
                    });
                }
            }
            return {
                CallExpression: disallowBuiltIns
            };
        }
    };
},
/* eslint/lib/rules/no-redeclare.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when the same variable is declared more then once.
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow variable redeclaration",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-redeclare"
            },
            messages: {
                redeclared: "'{{id}}' is already defined.",
                redeclaredAsBuiltin: "'{{id}}' is already defined as a built-in global variable.",
                redeclaredBySyntax: "'{{id}}' is already defined by a variable declaration."
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        builtinGlobals: { type: "boolean", default: true }
                    },
                    additionalProperties: false
                }
            ]
        },
        create(context) {
            const options = {
                builtinGlobals: Boolean(context.options.length === 0 ||
                    context.options[0].builtinGlobals)
            };
            const sourceCode = context.getSourceCode();
            /**
             * Iterate declarations of a given variable.
             * @param {escope.variable} variable The variable object to iterate declarations.
             * @returns {IterableIterator<{type:string,node:ASTNode,loc:SourceLocation}>} The declarations.
             */
            function* iterateDeclarations(variable) {
                if (options.builtinGlobals && (variable.eslintImplicitGlobalSetting === "readonly" ||
                    variable.eslintImplicitGlobalSetting === "writable")) {
                    yield { type: "builtin" };
                }
                for (const id of variable.identifiers) {
                    yield { type: "syntax", node: id, loc: id.loc };
                }
                if (variable.eslintExplicitGlobalComments) {
                    for (const comment of variable.eslintExplicitGlobalComments) {
                        yield {
                            type: "comment",
                            node: comment,
                            loc: astUtils.getNameLocationInGlobalDirectiveComment(sourceCode, comment, variable.name)
                        };
                    }
                }
            }
            /**
             * Find variables in a given scope and flag redeclared ones.
             * @param {Scope} scope An eslint-scope scope object.
             * @returns {void}
             * @private
             */
            function findVariablesInScope(scope) {
                for (const variable of scope.variables) {
                    const [declaration, ...extraDeclarations] = iterateDeclarations(variable);
                    if (extraDeclarations.length === 0) {
                        continue;
                    }
                    /*
                     * If the type of a declaration is different from the type of
                     * the first declaration, it shows the location of the first
                     * declaration.
                     */
                    const detailMessageId = declaration.type === "builtin"
                        ? "redeclaredAsBuiltin"
                        : "redeclaredBySyntax";
                    const data = { id: variable.name };
                    // Report extra declarations.
                    for (const { type, node, loc } of extraDeclarations) {
                        const messageId = type === declaration.type
                            ? "redeclared"
                            : detailMessageId;
                        context.report({ node, loc, messageId, data });
                    }
                }
            }
            /**
             * Find variables in the current scope.
             * @param {ASTNode} node The node of the current scope.
             * @returns {void}
             * @private
             */
            function checkForBlock(node) {
                const scope = context.getScope();
                /*
                 * In ES5, some node type such as `BlockStatement` doesn't have that scope.
                 * `scope.block` is a different node in such a case.
                 */
                if (scope.block === node) {
                    findVariablesInScope(scope);
                }
            }
            return {
                Program() {
                    const scope = context.getScope();
                    findVariablesInScope(scope);
                    // Node.js or ES modules has a special scope.
                    if (scope.type === "global" &&
                        scope.childScopes[0] &&
                        // The special scope's block is the Program node.
                        scope.block === scope.childScopes[0].block) {
                        findVariablesInScope(scope.childScopes[0]);
                    }
                },
                FunctionDeclaration: checkForBlock,
                FunctionExpression: checkForBlock,
                ArrowFunctionExpression: checkForBlock,
                StaticBlock: checkForBlock,
                BlockStatement: checkForBlock,
                ForStatement: checkForBlock,
                ForInStatement: checkForBlock,
                ForOfStatement: checkForBlock,
                SwitchStatement: checkForBlock
            };
        }
    };
},
/* eslint/lib/rules/no-regex-spaces.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to count multiple spaces in regular expressions
     * @author Matt DuVall <http://www.mattduvall.com/>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const regexpp = require(485) /* @eslint-community/regexpp */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const regExpParser = new regexpp.RegExpParser();
    const DOUBLE_SPACE = / {2}/u;
    /**
     * Check if node is a string
     * @param {ASTNode} node node to evaluate
     * @returns {boolean} True if its a string
     * @private
     */
    function isString(node) {
        return node && node.type === "Literal" && typeof node.value === "string";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow multiple spaces in regular expressions",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-regex-spaces"
            },
            schema: [],
            fixable: "code",
            messages: {
                multipleSpaces: "Spaces are hard to count. Use {{{length}}}."
            }
        },
        create(context) {
            /**
             * Validate regular expression
             * @param {ASTNode} nodeToReport Node to report.
             * @param {string} pattern Regular expression pattern to validate.
             * @param {string} rawPattern Raw representation of the pattern in the source code.
             * @param {number} rawPatternStartRange Start range of the pattern in the source code.
             * @param {string} flags Regular expression flags.
             * @returns {void}
             * @private
             */
            function checkRegex(nodeToReport, pattern, rawPattern, rawPatternStartRange, flags) {
                // Skip if there are no consecutive spaces in the source code, to avoid reporting e.g., RegExp(' \ ').
                if (!DOUBLE_SPACE.test(rawPattern)) {
                    return;
                }
                const characterClassNodes = [];
                let regExpAST;
                try {
                    regExpAST = regExpParser.parsePattern(pattern, 0, pattern.length, flags.includes("u"));
                }
                catch {
                    // Ignore regular expressions with syntax errors
                    return;
                }
                regexpp.visitRegExpAST(regExpAST, {
                    onCharacterClassEnter(ccNode) {
                        characterClassNodes.push(ccNode);
                    }
                });
                const spacesPattern = /( {2,})(?: [+*{?]|[^+*{?]|$)/gu;
                let match;
                while ((match = spacesPattern.exec(pattern))) {
                    const { 1: { length }, index } = match;
                    // Report only consecutive spaces that are not in character classes.
                    if (characterClassNodes.every(({ start, end }) => index < start || end <= index)) {
                        context.report({
                            node: nodeToReport,
                            messageId: "multipleSpaces",
                            data: { length },
                            fix(fixer) {
                                if (pattern !== rawPattern) {
                                    return null;
                                }
                                return fixer.replaceTextRange([rawPatternStartRange + index, rawPatternStartRange + index + length], ` {${length}}`);
                            }
                        });
                        // Report only the first occurrence of consecutive spaces
                        return;
                    }
                }
            }
            /**
             * Validate regular expression literals
             * @param {ASTNode} node node to validate
             * @returns {void}
             * @private
             */
            function checkLiteral(node) {
                if (node.regex) {
                    const pattern = node.regex.pattern;
                    const rawPattern = node.raw.slice(1, node.raw.lastIndexOf("/"));
                    const rawPatternStartRange = node.range[0] + 1;
                    const flags = node.regex.flags;
                    checkRegex(node, pattern, rawPattern, rawPatternStartRange, flags);
                }
            }
            /**
             * Validate strings passed to the RegExp constructor
             * @param {ASTNode} node node to validate
             * @returns {void}
             * @private
             */
            function checkFunction(node) {
                const scope = context.getScope();
                const regExpVar = astUtils.getVariableByName(scope, "RegExp");
                const shadowed = regExpVar && regExpVar.defs.length > 0;
                const patternNode = node.arguments[0];
                const flagsNode = node.arguments[1];
                if (node.callee.type === "Identifier" && node.callee.name === "RegExp" && isString(patternNode) && !shadowed) {
                    const pattern = patternNode.value;
                    const rawPattern = patternNode.raw.slice(1, -1);
                    const rawPatternStartRange = patternNode.range[0] + 1;
                    const flags = isString(flagsNode) ? flagsNode.value : "";
                    checkRegex(node, pattern, rawPattern, rawPatternStartRange, flags);
                }
            }
            return {
                Literal: checkLiteral,
                CallExpression: checkFunction,
                NewExpression: checkFunction
            };
        }
    };
},
/* eslint/lib/rules/no-restricted-exports.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow specified names in exports
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow specified names in exports",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-restricted-exports"
            },
            schema: [{
                    anyOf: [
                        {
                            type: "object",
                            properties: {
                                restrictedNamedExports: {
                                    type: "array",
                                    items: {
                                        type: "string"
                                    },
                                    uniqueItems: true
                                }
                            },
                            additionalProperties: false
                        },
                        {
                            type: "object",
                            properties: {
                                restrictedNamedExports: {
                                    type: "array",
                                    items: {
                                        type: "string",
                                        pattern: "^(?!default$)"
                                    },
                                    uniqueItems: true
                                },
                                restrictDefaultExports: {
                                    type: "object",
                                    properties: {
                                        // Allow/Disallow `export default foo; export default 42; export default function foo() {}` format
                                        direct: {
                                            type: "boolean"
                                        },
                                        // Allow/Disallow `export { foo as default };` declarations
                                        named: {
                                            type: "boolean"
                                        },
                                        //  Allow/Disallow `export { default } from "mod"; export { default as default } from "mod";` declarations
                                        defaultFrom: {
                                            type: "boolean"
                                        },
                                        //  Allow/Disallow `export { foo as default } from "mod";` declarations
                                        namedFrom: {
                                            type: "boolean"
                                        },
                                        //  Allow/Disallow `export * as default from "mod"`; declarations
                                        namespaceFrom: {
                                            type: "boolean"
                                        }
                                    },
                                    additionalProperties: false
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }],
            messages: {
                restrictedNamed: "'{{name}}' is restricted from being used as an exported name.",
                restrictedDefault: "Exporting 'default' is restricted."
            }
        },
        create(context) {
            const restrictedNames = new Set(context.options[0] && context.options[0].restrictedNamedExports);
            const restrictDefaultExports = context.options[0] && context.options[0].restrictDefaultExports;
            /**
             * Checks and reports given exported name.
             * @param {ASTNode} node exported `Identifier` or string `Literal` node to check.
             * @returns {void}
             */
            function checkExportedName(node) {
                const name = astUtils.getModuleExportName(node);
                if (restrictedNames.has(name)) {
                    context.report({
                        node,
                        messageId: "restrictedNamed",
                        data: { name }
                    });
                    return;
                }
                if (name === "default") {
                    if (node.parent.type === "ExportAllDeclaration") {
                        if (restrictDefaultExports && restrictDefaultExports.namespaceFrom) {
                            context.report({
                                node,
                                messageId: "restrictedDefault"
                            });
                        }
                    }
                    else { // ExportSpecifier
                        const isSourceSpecified = !!node.parent.parent.source;
                        const specifierLocalName = astUtils.getModuleExportName(node.parent.local);
                        if (!isSourceSpecified && restrictDefaultExports && restrictDefaultExports.named) {
                            context.report({
                                node,
                                messageId: "restrictedDefault"
                            });
                            return;
                        }
                        if (isSourceSpecified && restrictDefaultExports) {
                            if ((specifierLocalName === "default" && restrictDefaultExports.defaultFrom) ||
                                (specifierLocalName !== "default" && restrictDefaultExports.namedFrom)) {
                                context.report({
                                    node,
                                    messageId: "restrictedDefault"
                                });
                            }
                        }
                    }
                }
            }
            return {
                ExportAllDeclaration(node) {
                    if (node.exported) {
                        checkExportedName(node.exported);
                    }
                },
                ExportDefaultDeclaration(node) {
                    if (restrictDefaultExports && restrictDefaultExports.direct) {
                        context.report({
                            node,
                            messageId: "restrictedDefault"
                        });
                    }
                },
                ExportNamedDeclaration(node) {
                    const declaration = node.declaration;
                    if (declaration) {
                        if (declaration.type === "FunctionDeclaration" || declaration.type === "ClassDeclaration") {
                            checkExportedName(declaration.id);
                        }
                        else if (declaration.type === "VariableDeclaration") {
                            context.getDeclaredVariables(declaration)
                                .map(v => v.defs.find(d => d.parent === declaration))
                                .map(d => d.name) // Identifier nodes
                                .forEach(checkExportedName);
                        }
                    }
                    else {
                        node.specifiers
                            .map(s => s.exported)
                            .forEach(checkExportedName);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-restricted-globals.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Restrict usage of specified globals.
     * @author Benoît Zugmeyer
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow specified global variables",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-restricted-globals"
            },
            schema: {
                type: "array",
                items: {
                    oneOf: [
                        {
                            type: "string"
                        },
                        {
                            type: "object",
                            properties: {
                                name: { type: "string" },
                                message: { type: "string" }
                            },
                            required: ["name"],
                            additionalProperties: false
                        }
                    ]
                },
                uniqueItems: true,
                minItems: 0
            },
            messages: {
                defaultMessage: "Unexpected use of '{{name}}'.",
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                customMessage: "Unexpected use of '{{name}}'. {{customMessage}}"
            }
        },
        create(context) {
            // If no globals are restricted, we don't need to do anything
            if (context.options.length === 0) {
                return {};
            }
            const restrictedGlobalMessages = context.options.reduce((memo, option) => {
                if (typeof option === "string") {
                    memo[option] = null;
                }
                else {
                    memo[option.name] = option.message;
                }
                return memo;
            }, {});
            /**
             * Report a variable to be used as a restricted global.
             * @param {Reference} reference the variable reference
             * @returns {void}
             * @private
             */
            function reportReference(reference) {
                const name = reference.identifier.name, customMessage = restrictedGlobalMessages[name], messageId = customMessage
                    ? "customMessage"
                    : "defaultMessage";
                context.report({
                    node: reference.identifier,
                    messageId,
                    data: {
                        name,
                        customMessage
                    }
                });
            }
            /**
             * Check if the given name is a restricted global name.
             * @param {string} name name of a variable
             * @returns {boolean} whether the variable is a restricted global or not
             * @private
             */
            function isRestricted(name) {
                return Object.prototype.hasOwnProperty.call(restrictedGlobalMessages, name);
            }
            return {
                Program() {
                    const scope = context.getScope();
                    // Report variables declared elsewhere (ex: variables defined as "global" by eslint)
                    scope.variables.forEach(variable => {
                        if (!variable.defs.length && isRestricted(variable.name)) {
                            variable.references.forEach(reportReference);
                        }
                    });
                    // Report variables not declared at all
                    scope.through.forEach(reference => {
                        if (isRestricted(reference.identifier.name)) {
                            reportReference(reference);
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-restricted-imports.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Restrict usage of specified node imports.
     * @author Guy Ellis
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const ignore = require(228) /* ignore */;
    const arrayOfStringsOrObjects = {
        type: "array",
        items: {
            anyOf: [
                { type: "string" },
                {
                    type: "object",
                    properties: {
                        name: { type: "string" },
                        message: {
                            type: "string",
                            minLength: 1
                        },
                        importNames: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        }
                    },
                    additionalProperties: false,
                    required: ["name"]
                }
            ]
        },
        uniqueItems: true
    };
    const arrayOfStringsOrObjectPatterns = {
        anyOf: [
            {
                type: "array",
                items: {
                    type: "string"
                },
                uniqueItems: true
            },
            {
                type: "array",
                items: {
                    type: "object",
                    properties: {
                        importNames: {
                            type: "array",
                            items: {
                                type: "string"
                            },
                            minItems: 1,
                            uniqueItems: true
                        },
                        group: {
                            type: "array",
                            items: {
                                type: "string"
                            },
                            minItems: 1,
                            uniqueItems: true
                        },
                        message: {
                            type: "string",
                            minLength: 1
                        },
                        caseSensitive: {
                            type: "boolean"
                        }
                    },
                    additionalProperties: false,
                    required: ["group"]
                },
                uniqueItems: true
            }
        ]
    };
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow specified modules when loaded by `import`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-restricted-imports"
            },
            messages: {
                path: "'{{importSource}}' import is restricted from being used.",
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                pathWithCustomMessage: "'{{importSource}}' import is restricted from being used. {{customMessage}}",
                patterns: "'{{importSource}}' import is restricted from being used by a pattern.",
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                patternWithCustomMessage: "'{{importSource}}' import is restricted from being used by a pattern. {{customMessage}}",
                patternAndImportName: "'{{importName}}' import from '{{importSource}}' is restricted from being used by a pattern.",
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                patternAndImportNameWithCustomMessage: "'{{importName}}' import from '{{importSource}}' is restricted from being used by a pattern. {{customMessage}}",
                patternAndEverything: "* import is invalid because '{{importNames}}' from '{{importSource}}' is restricted from being used by a pattern.",
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                patternAndEverythingWithCustomMessage: "* import is invalid because '{{importNames}}' from '{{importSource}}' is restricted from being used by a pattern. {{customMessage}}",
                everything: "* import is invalid because '{{importNames}}' from '{{importSource}}' is restricted.",
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                everythingWithCustomMessage: "* import is invalid because '{{importNames}}' from '{{importSource}}' is restricted. {{customMessage}}",
                importName: "'{{importName}}' import from '{{importSource}}' is restricted.",
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                importNameWithCustomMessage: "'{{importName}}' import from '{{importSource}}' is restricted. {{customMessage}}"
            },
            schema: {
                anyOf: [
                    arrayOfStringsOrObjects,
                    {
                        type: "array",
                        items: [{
                                type: "object",
                                properties: {
                                    paths: arrayOfStringsOrObjects,
                                    patterns: arrayOfStringsOrObjectPatterns
                                },
                                additionalProperties: false
                            }],
                        additionalItems: false
                    }
                ]
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const options = Array.isArray(context.options) ? context.options : [];
            const isPathAndPatternsObject = typeof options[0] === "object" &&
                (Object.prototype.hasOwnProperty.call(options[0], "paths") || Object.prototype.hasOwnProperty.call(options[0], "patterns"));
            const restrictedPaths = (isPathAndPatternsObject ? options[0].paths : context.options) || [];
            const restrictedPathMessages = restrictedPaths.reduce((memo, importSource) => {
                if (typeof importSource === "string") {
                    memo[importSource] = { message: null };
                }
                else {
                    memo[importSource.name] = {
                        message: importSource.message,
                        importNames: importSource.importNames
                    };
                }
                return memo;
            }, {});
            // Handle patterns too, either as strings or groups
            let restrictedPatterns = (isPathAndPatternsObject ? options[0].patterns : []) || [];
            // standardize to array of objects if we have an array of strings
            if (restrictedPatterns.length > 0 && typeof restrictedPatterns[0] === "string") {
                restrictedPatterns = [{ group: restrictedPatterns }];
            }
            // relative paths are supported for this rule
            const restrictedPatternGroups = restrictedPatterns.map(({ group, message, caseSensitive, importNames }) => ({
                matcher: ignore({ allowRelativePaths: true, ignorecase: !caseSensitive }).add(group),
                customMessage: message,
                importNames
            }));
            // if no imports are restricted we don't need to check
            if (Object.keys(restrictedPaths).length === 0 && restrictedPatternGroups.length === 0) {
                return {};
            }
            /**
             * Report a restricted path.
             * @param {string} importSource path of the import
             * @param {Map<string,Object[]>} importNames Map of import names that are being imported
             * @param {node} node representing the restricted path reference
             * @returns {void}
             * @private
             */
            function checkRestrictedPathAndReport(importSource, importNames, node) {
                if (!Object.prototype.hasOwnProperty.call(restrictedPathMessages, importSource)) {
                    return;
                }
                const customMessage = restrictedPathMessages[importSource].message;
                const restrictedImportNames = restrictedPathMessages[importSource].importNames;
                if (restrictedImportNames) {
                    if (importNames.has("*")) {
                        const specifierData = importNames.get("*")[0];
                        context.report({
                            node,
                            messageId: customMessage ? "everythingWithCustomMessage" : "everything",
                            loc: specifierData.loc,
                            data: {
                                importSource,
                                importNames: restrictedImportNames,
                                customMessage
                            }
                        });
                    }
                    restrictedImportNames.forEach(importName => {
                        if (importNames.has(importName)) {
                            const specifiers = importNames.get(importName);
                            specifiers.forEach(specifier => {
                                context.report({
                                    node,
                                    messageId: customMessage ? "importNameWithCustomMessage" : "importName",
                                    loc: specifier.loc,
                                    data: {
                                        importSource,
                                        customMessage,
                                        importName
                                    }
                                });
                            });
                        }
                    });
                }
                else {
                    context.report({
                        node,
                        messageId: customMessage ? "pathWithCustomMessage" : "path",
                        data: {
                            importSource,
                            customMessage
                        }
                    });
                }
            }
            /**
             * Report a restricted path specifically for patterns.
             * @param {node} node representing the restricted path reference
             * @param {Object} group contains an Ignore instance for paths, the customMessage to show on failure,
             * and any restricted import names that have been specified in the config
             * @param {Map<string,Object[]>} importNames Map of import names that are being imported
             * @returns {void}
             * @private
             */
            function reportPathForPatterns(node, group, importNames) {
                const importSource = node.source.value.trim();
                const customMessage = group.customMessage;
                const restrictedImportNames = group.importNames;
                /*
                 * If we are not restricting to any specific import names and just the pattern itself,
                 * report the error and move on
                 */
                if (!restrictedImportNames) {
                    context.report({
                        node,
                        messageId: customMessage ? "patternWithCustomMessage" : "patterns",
                        data: {
                            importSource,
                            customMessage
                        }
                    });
                    return;
                }
                if (importNames.has("*")) {
                    const specifierData = importNames.get("*")[0];
                    context.report({
                        node,
                        messageId: customMessage ? "patternAndEverythingWithCustomMessage" : "patternAndEverything",
                        loc: specifierData.loc,
                        data: {
                            importSource,
                            importNames: restrictedImportNames,
                            customMessage
                        }
                    });
                }
                restrictedImportNames.forEach(importName => {
                    if (!importNames.has(importName)) {
                        return;
                    }
                    const specifiers = importNames.get(importName);
                    specifiers.forEach(specifier => {
                        context.report({
                            node,
                            messageId: customMessage ? "patternAndImportNameWithCustomMessage" : "patternAndImportName",
                            loc: specifier.loc,
                            data: {
                                importSource,
                                customMessage,
                                importName
                            }
                        });
                    });
                });
            }
            /**
             * Check if the given importSource is restricted by a pattern.
             * @param {string} importSource path of the import
             * @param {Object} group contains a Ignore instance for paths, and the customMessage to show if it fails
             * @returns {boolean} whether the variable is a restricted pattern or not
             * @private
             */
            function isRestrictedPattern(importSource, group) {
                return group.matcher.ignores(importSource);
            }
            /**
             * Checks a node to see if any problems should be reported.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             * @private
             */
            function checkNode(node) {
                const importSource = node.source.value.trim();
                const importNames = new Map();
                if (node.type === "ExportAllDeclaration") {
                    const starToken = sourceCode.getFirstToken(node, 1);
                    importNames.set("*", [{ loc: starToken.loc }]);
                }
                else if (node.specifiers) {
                    for (const specifier of node.specifiers) {
                        let name;
                        const specifierData = { loc: specifier.loc };
                        if (specifier.type === "ImportDefaultSpecifier") {
                            name = "default";
                        }
                        else if (specifier.type === "ImportNamespaceSpecifier") {
                            name = "*";
                        }
                        else if (specifier.imported) {
                            name = astUtils.getModuleExportName(specifier.imported);
                        }
                        else if (specifier.local) {
                            name = astUtils.getModuleExportName(specifier.local);
                        }
                        if (typeof name === "string") {
                            if (importNames.has(name)) {
                                importNames.get(name).push(specifierData);
                            }
                            else {
                                importNames.set(name, [specifierData]);
                            }
                        }
                    }
                }
                checkRestrictedPathAndReport(importSource, importNames, node);
                restrictedPatternGroups.forEach(group => {
                    if (isRestrictedPattern(importSource, group)) {
                        reportPathForPatterns(node, group, importNames);
                    }
                });
            }
            return {
                ImportDeclaration: checkNode,
                ExportNamedDeclaration(node) {
                    if (node.source) {
                        checkNode(node);
                    }
                },
                ExportAllDeclaration: checkNode
            };
        }
    };
},
/* eslint/lib/rules/no-restricted-modules.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Restrict usage of specified node modules.
     * @author Christian Schulz
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const ignore = require(228) /* ignore */;
    const arrayOfStrings = {
        type: "array",
        items: { type: "string" },
        uniqueItems: true
    };
    const arrayOfStringsOrObjects = {
        type: "array",
        items: {
            anyOf: [
                { type: "string" },
                {
                    type: "object",
                    properties: {
                        name: { type: "string" },
                        message: {
                            type: "string",
                            minLength: 1
                        }
                    },
                    additionalProperties: false,
                    required: ["name"]
                }
            ]
        },
        uniqueItems: true
    };
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Disallow specified modules when loaded by `require`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-restricted-modules"
            },
            schema: {
                anyOf: [
                    arrayOfStringsOrObjects,
                    {
                        type: "array",
                        items: {
                            type: "object",
                            properties: {
                                paths: arrayOfStringsOrObjects,
                                patterns: arrayOfStrings
                            },
                            additionalProperties: false
                        },
                        additionalItems: false
                    }
                ]
            },
            messages: {
                defaultMessage: "'{{name}}' module is restricted from being used.",
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                customMessage: "'{{name}}' module is restricted from being used. {{customMessage}}",
                patternMessage: "'{{name}}' module is restricted from being used by a pattern."
            }
        },
        create(context) {
            const options = Array.isArray(context.options) ? context.options : [];
            const isPathAndPatternsObject = typeof options[0] === "object" &&
                (Object.prototype.hasOwnProperty.call(options[0], "paths") || Object.prototype.hasOwnProperty.call(options[0], "patterns"));
            const restrictedPaths = (isPathAndPatternsObject ? options[0].paths : context.options) || [];
            const restrictedPatterns = (isPathAndPatternsObject ? options[0].patterns : []) || [];
            const restrictedPathMessages = restrictedPaths.reduce((memo, importName) => {
                if (typeof importName === "string") {
                    memo[importName] = null;
                }
                else {
                    memo[importName.name] = importName.message;
                }
                return memo;
            }, {});
            // if no imports are restricted we don't need to check
            if (Object.keys(restrictedPaths).length === 0 && restrictedPatterns.length === 0) {
                return {};
            }
            // relative paths are supported for this rule
            const ig = ignore({ allowRelativePaths: true }).add(restrictedPatterns);
            /**
             * Function to check if a node is a string literal.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} If the node is a string literal.
             */
            function isStringLiteral(node) {
                return node && node.type === "Literal" && typeof node.value === "string";
            }
            /**
             * Function to check if a node is a static string template literal.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} If the node is a string template literal.
             */
            function isStaticTemplateLiteral(node) {
                return node && node.type === "TemplateLiteral" && node.expressions.length === 0;
            }
            /**
             * Function to check if a node is a require call.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} If the node is a require call.
             */
            function isRequireCall(node) {
                return node.callee.type === "Identifier" && node.callee.name === "require";
            }
            /**
             * Extract string from Literal or TemplateLiteral node
             * @param {ASTNode} node The node to extract from
             * @returns {string|null} Extracted string or null if node doesn't represent a string
             */
            function getFirstArgumentString(node) {
                if (isStringLiteral(node)) {
                    return node.value.trim();
                }
                if (isStaticTemplateLiteral(node)) {
                    return node.quasis[0].value.cooked.trim();
                }
                return null;
            }
            /**
             * Report a restricted path.
             * @param {node} node representing the restricted path reference
             * @param {string} name restricted path
             * @returns {void}
             * @private
             */
            function reportPath(node, name) {
                const customMessage = restrictedPathMessages[name];
                const messageId = customMessage
                    ? "customMessage"
                    : "defaultMessage";
                context.report({
                    node,
                    messageId,
                    data: {
                        name,
                        customMessage
                    }
                });
            }
            /**
             * Check if the given name is a restricted path name
             * @param {string} name name of a variable
             * @returns {boolean} whether the variable is a restricted path or not
             * @private
             */
            function isRestrictedPath(name) {
                return Object.prototype.hasOwnProperty.call(restrictedPathMessages, name);
            }
            return {
                CallExpression(node) {
                    if (isRequireCall(node)) {
                        // node has arguments
                        if (node.arguments.length) {
                            const name = getFirstArgumentString(node.arguments[0]);
                            // if first argument is a string literal or a static string template literal
                            if (name) {
                                // check if argument value is in restricted modules array
                                if (isRestrictedPath(name)) {
                                    reportPath(node, name);
                                }
                                if (restrictedPatterns.length > 0 && ig.ignores(name)) {
                                    context.report({
                                        node,
                                        messageId: "patternMessage",
                                        data: { name }
                                    });
                                }
                            }
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-restricted-properties.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow certain object properties
     * @author Will Klein & Eli White
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow certain properties on certain objects",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-restricted-properties"
            },
            schema: {
                type: "array",
                items: {
                    anyOf: [
                        {
                            type: "object",
                            properties: {
                                object: {
                                    type: "string"
                                },
                                property: {
                                    type: "string"
                                },
                                message: {
                                    type: "string"
                                }
                            },
                            additionalProperties: false,
                            required: ["object"]
                        },
                        {
                            type: "object",
                            properties: {
                                object: {
                                    type: "string"
                                },
                                property: {
                                    type: "string"
                                },
                                message: {
                                    type: "string"
                                }
                            },
                            additionalProperties: false,
                            required: ["property"]
                        }
                    ]
                },
                uniqueItems: true
            },
            messages: {
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                restrictedObjectProperty: "'{{objectName}}.{{propertyName}}' is restricted from being used.{{message}}",
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                restrictedProperty: "'{{propertyName}}' is restricted from being used.{{message}}"
            }
        },
        create(context) {
            const restrictedCalls = context.options;
            if (restrictedCalls.length === 0) {
                return {};
            }
            const restrictedProperties = new Map();
            const globallyRestrictedObjects = new Map();
            const globallyRestrictedProperties = new Map();
            restrictedCalls.forEach(option => {
                const objectName = option.object;
                const propertyName = option.property;
                if (typeof objectName === "undefined") {
                    globallyRestrictedProperties.set(propertyName, { message: option.message });
                }
                else if (typeof propertyName === "undefined") {
                    globallyRestrictedObjects.set(objectName, { message: option.message });
                }
                else {
                    if (!restrictedProperties.has(objectName)) {
                        restrictedProperties.set(objectName, new Map());
                    }
                    restrictedProperties.get(objectName).set(propertyName, {
                        message: option.message
                    });
                }
            });
            /**
             * Checks to see whether a property access is restricted, and reports it if so.
             * @param {ASTNode} node The node to report
             * @param {string} objectName The name of the object
             * @param {string} propertyName The name of the property
             * @returns {undefined}
             */
            function checkPropertyAccess(node, objectName, propertyName) {
                if (propertyName === null) {
                    return;
                }
                const matchedObject = restrictedProperties.get(objectName);
                const matchedObjectProperty = matchedObject ? matchedObject.get(propertyName) : globallyRestrictedObjects.get(objectName);
                const globalMatchedProperty = globallyRestrictedProperties.get(propertyName);
                if (matchedObjectProperty) {
                    const message = matchedObjectProperty.message ? ` ${matchedObjectProperty.message}` : "";
                    context.report({
                        node,
                        messageId: "restrictedObjectProperty",
                        data: {
                            objectName,
                            propertyName,
                            message
                        }
                    });
                }
                else if (globalMatchedProperty) {
                    const message = globalMatchedProperty.message ? ` ${globalMatchedProperty.message}` : "";
                    context.report({
                        node,
                        messageId: "restrictedProperty",
                        data: {
                            propertyName,
                            message
                        }
                    });
                }
            }
            /**
             * Checks property accesses in a destructuring assignment expression, e.g. `var foo; ({foo} = bar);`
             * @param {ASTNode} node An AssignmentExpression or AssignmentPattern node
             * @returns {undefined}
             */
            function checkDestructuringAssignment(node) {
                if (node.right.type === "Identifier") {
                    const objectName = node.right.name;
                    if (node.left.type === "ObjectPattern") {
                        node.left.properties.forEach(property => {
                            checkPropertyAccess(node.left, objectName, astUtils.getStaticPropertyName(property));
                        });
                    }
                }
            }
            return {
                MemberExpression(node) {
                    checkPropertyAccess(node, node.object && node.object.name, astUtils.getStaticPropertyName(node));
                },
                VariableDeclarator(node) {
                    if (node.init && node.init.type === "Identifier") {
                        const objectName = node.init.name;
                        if (node.id.type === "ObjectPattern") {
                            node.id.properties.forEach(property => {
                                checkPropertyAccess(node.id, objectName, astUtils.getStaticPropertyName(property));
                            });
                        }
                    }
                },
                AssignmentExpression: checkDestructuringAssignment,
                AssignmentPattern: checkDestructuringAssignment
            };
        }
    };
},
/* eslint/lib/rules/no-restricted-syntax.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag use of certain node types
     * @author Burak Yigit Kaya
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow specified syntax",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-restricted-syntax"
            },
            schema: {
                type: "array",
                items: {
                    oneOf: [
                        {
                            type: "string"
                        },
                        {
                            type: "object",
                            properties: {
                                selector: { type: "string" },
                                message: { type: "string" }
                            },
                            required: ["selector"],
                            additionalProperties: false
                        }
                    ]
                },
                uniqueItems: true,
                minItems: 0
            },
            messages: {
                // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
                restrictedSyntax: "{{message}}"
            }
        },
        create(context) {
            return context.options.reduce((result, selectorOrObject) => {
                const isStringFormat = (typeof selectorOrObject === "string");
                const hasCustomMessage = !isStringFormat && Boolean(selectorOrObject.message);
                const selector = isStringFormat ? selectorOrObject : selectorOrObject.selector;
                const message = hasCustomMessage ? selectorOrObject.message : `Using '${selector}' is not allowed.`;
                return Object.assign(result, {
                    [selector](node) {
                        context.report({
                            node,
                            messageId: "restrictedSyntax",
                            data: { message }
                        });
                    }
                });
            }, {});
        }
    };
},
/* eslint/lib/rules/no-return-assign.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag when return statement contains assignment
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const SENTINEL_TYPE = /^(?:[a-zA-Z]+?Statement|ArrowFunctionExpression|FunctionExpression|ClassExpression)$/u;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow assignment operators in `return` statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-return-assign"
            },
            schema: [
                {
                    enum: ["except-parens", "always"]
                }
            ],
            messages: {
                returnAssignment: "Return statement should not contain assignment.",
                arrowAssignment: "Arrow function should not return assignment."
            }
        },
        create(context) {
            const always = (context.options[0] || "except-parens") !== "except-parens";
            const sourceCode = context.getSourceCode();
            return {
                AssignmentExpression(node) {
                    if (!always && astUtils.isParenthesised(sourceCode, node)) {
                        return;
                    }
                    let currentChild = node;
                    let parent = currentChild.parent;
                    // Find ReturnStatement or ArrowFunctionExpression in ancestors.
                    while (parent && !SENTINEL_TYPE.test(parent.type)) {
                        currentChild = parent;
                        parent = parent.parent;
                    }
                    // Reports.
                    if (parent && parent.type === "ReturnStatement") {
                        context.report({
                            node: parent,
                            messageId: "returnAssignment"
                        });
                    }
                    else if (parent && parent.type === "ArrowFunctionExpression" && parent.body === currentChild) {
                        context.report({
                            node: parent,
                            messageId: "arrowAssignment"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-return-await.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallows unnecessary `return await`
     * @author Jordan Harband
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            hasSuggestions: true,
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary `return await`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-return-await"
            },
            fixable: null,
            schema: [],
            messages: {
                removeAwait: "Remove redundant `await`.",
                redundantUseOfAwait: "Redundant use of `await` on a return value."
            }
        },
        create(context) {
            /**
             * Reports a found unnecessary `await` expression.
             * @param {ASTNode} node The node representing the `await` expression to report
             * @returns {void}
             */
            function reportUnnecessaryAwait(node) {
                context.report({
                    node: context.getSourceCode().getFirstToken(node),
                    loc: node.loc,
                    messageId: "redundantUseOfAwait",
                    suggest: [
                        {
                            messageId: "removeAwait",
                            fix(fixer) {
                                const sourceCode = context.getSourceCode();
                                const [awaitToken, tokenAfterAwait] = sourceCode.getFirstTokens(node, 2);
                                const areAwaitAndAwaitedExpressionOnTheSameLine = awaitToken.loc.start.line === tokenAfterAwait.loc.start.line;
                                if (!areAwaitAndAwaitedExpressionOnTheSameLine) {
                                    return null;
                                }
                                const [startOfAwait, endOfAwait] = awaitToken.range;
                                const characterAfterAwait = sourceCode.text[endOfAwait];
                                const trimLength = characterAfterAwait === " " ? 1 : 0;
                                const range = [startOfAwait, endOfAwait + trimLength];
                                return fixer.removeRange(range);
                            }
                        }
                    ]
                });
            }
            /**
             * Determines whether a thrown error from this node will be caught/handled within this function rather than immediately halting
             * this function. For example, a statement in a `try` block will always have an error handler. A statement in
             * a `catch` block will only have an error handler if there is also a `finally` block.
             * @param {ASTNode} node A node representing a location where an could be thrown
             * @returns {boolean} `true` if a thrown error will be caught/handled in this function
             */
            function hasErrorHandler(node) {
                let ancestor = node;
                while (!astUtils.isFunction(ancestor) && ancestor.type !== "Program") {
                    if (ancestor.parent.type === "TryStatement" && (ancestor === ancestor.parent.block || ancestor === ancestor.parent.handler && ancestor.parent.finalizer)) {
                        return true;
                    }
                    ancestor = ancestor.parent;
                }
                return false;
            }
            /**
             * Checks if a node is placed in tail call position. Once `return` arguments (or arrow function expressions) can be a complex expression,
             * an `await` expression could or could not be unnecessary by the definition of this rule. So we're looking for `await` expressions that are in tail position.
             * @param {ASTNode} node A node representing the `await` expression to check
             * @returns {boolean} The checking result
             */
            function isInTailCallPosition(node) {
                if (node.parent.type === "ArrowFunctionExpression") {
                    return true;
                }
                if (node.parent.type === "ReturnStatement") {
                    return !hasErrorHandler(node.parent);
                }
                if (node.parent.type === "ConditionalExpression" && (node === node.parent.consequent || node === node.parent.alternate)) {
                    return isInTailCallPosition(node.parent);
                }
                if (node.parent.type === "LogicalExpression" && node === node.parent.right) {
                    return isInTailCallPosition(node.parent);
                }
                if (node.parent.type === "SequenceExpression" && node === node.parent.expressions[node.parent.expressions.length - 1]) {
                    return isInTailCallPosition(node.parent);
                }
                return false;
            }
            return {
                AwaitExpression(node) {
                    if (isInTailCallPosition(node) && !hasErrorHandler(node)) {
                        reportUnnecessaryAwait(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-script-url.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when using javascript: urls
     * @author Ilya Volodin
     */
    /* eslint no-script-url: 0 -- Code is checking to report such URLs */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `javascript:` urls",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-script-url"
            },
            schema: [],
            messages: {
                unexpectedScriptURL: "Script URL is a form of eval."
            }
        },
        create(context) {
            /**
             * Check whether a node's static value starts with "javascript:" or not.
             * And report an error for unexpected script URL.
             * @param {ASTNode} node node to check
             * @returns {void}
             */
            function check(node) {
                const value = astUtils.getStaticStringValue(node);
                if (typeof value === "string" && value.toLowerCase().indexOf("javascript:") === 0) {
                    context.report({ node, messageId: "unexpectedScriptURL" });
                }
            }
            return {
                Literal(node) {
                    if (node.value && typeof node.value === "string") {
                        check(node);
                    }
                },
                TemplateLiteral(node) {
                    if (!(node.parent && node.parent.type === "TaggedTemplateExpression")) {
                        check(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-self-assign.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow assignments where both sides are exactly the same
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const SPACES = /\s+/gu;
    /**
     * Traverses 2 Pattern nodes in parallel, then reports self-assignments.
     * @param {ASTNode|null} left A left node to traverse. This is a Pattern or
     *      a Property.
     * @param {ASTNode|null} right A right node to traverse. This is a Pattern or
     *      a Property.
     * @param {boolean} props The flag to check member expressions as well.
     * @param {Function} report A callback function to report.
     * @returns {void}
     */
    function eachSelfAssignment(left, right, props, report) {
        if (!left || !right) {
            // do nothing
        }
        else if (left.type === "Identifier" &&
            right.type === "Identifier" &&
            left.name === right.name) {
            report(right);
        }
        else if (left.type === "ArrayPattern" &&
            right.type === "ArrayExpression") {
            const end = Math.min(left.elements.length, right.elements.length);
            for (let i = 0; i < end; ++i) {
                const leftElement = left.elements[i];
                const rightElement = right.elements[i];
                // Avoid cases such as [...a] = [...a, 1]
                if (leftElement &&
                    leftElement.type === "RestElement" &&
                    i < right.elements.length - 1) {
                    break;
                }
                eachSelfAssignment(leftElement, rightElement, props, report);
                // After a spread element, those indices are unknown.
                if (rightElement && rightElement.type === "SpreadElement") {
                    break;
                }
            }
        }
        else if (left.type === "RestElement" &&
            right.type === "SpreadElement") {
            eachSelfAssignment(left.argument, right.argument, props, report);
        }
        else if (left.type === "ObjectPattern" &&
            right.type === "ObjectExpression" &&
            right.properties.length >= 1) {
            /*
             * Gets the index of the last spread property.
             * It's possible to overwrite properties followed by it.
             */
            let startJ = 0;
            for (let i = right.properties.length - 1; i >= 0; --i) {
                const propType = right.properties[i].type;
                if (propType === "SpreadElement" || propType === "ExperimentalSpreadProperty") {
                    startJ = i + 1;
                    break;
                }
            }
            for (let i = 0; i < left.properties.length; ++i) {
                for (let j = startJ; j < right.properties.length; ++j) {
                    eachSelfAssignment(left.properties[i], right.properties[j], props, report);
                }
            }
        }
        else if (left.type === "Property" &&
            right.type === "Property" &&
            right.kind === "init" &&
            !right.method) {
            const leftName = astUtils.getStaticPropertyName(left);
            if (leftName !== null && leftName === astUtils.getStaticPropertyName(right)) {
                eachSelfAssignment(left.value, right.value, props, report);
            }
        }
        else if (props &&
            astUtils.skipChainExpression(left).type === "MemberExpression" &&
            astUtils.skipChainExpression(right).type === "MemberExpression" &&
            astUtils.isSameReference(left, right)) {
            report(right);
        }
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow assignments where both sides are exactly the same",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-self-assign"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        props: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                selfAssignment: "'{{name}}' is assigned to itself."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const [{ props = true } = {}] = context.options;
            /**
             * Reports a given node as self assignments.
             * @param {ASTNode} node A node to report. This is an Identifier node.
             * @returns {void}
             */
            function report(node) {
                context.report({
                    node,
                    messageId: "selfAssignment",
                    data: {
                        name: sourceCode.getText(node).replace(SPACES, "")
                    }
                });
            }
            return {
                AssignmentExpression(node) {
                    if (["=", "&&=", "||=", "??="].includes(node.operator)) {
                        eachSelfAssignment(node.left, node.right, props, report);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-self-compare.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag comparison where left part is the same as the right
     * part.
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow comparisons where both sides are exactly the same",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-self-compare"
            },
            schema: [],
            messages: {
                comparingToSelf: "Comparing to itself is potentially pointless."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Determines whether two nodes are composed of the same tokens.
             * @param {ASTNode} nodeA The first node
             * @param {ASTNode} nodeB The second node
             * @returns {boolean} true if the nodes have identical token representations
             */
            function hasSameTokens(nodeA, nodeB) {
                const tokensA = sourceCode.getTokens(nodeA);
                const tokensB = sourceCode.getTokens(nodeB);
                return tokensA.length === tokensB.length &&
                    tokensA.every((token, index) => token.type === tokensB[index].type && token.value === tokensB[index].value);
            }
            return {
                BinaryExpression(node) {
                    const operators = new Set(["===", "==", "!==", "!=", ">", "<", ">=", "<="]);
                    if (operators.has(node.operator) && hasSameTokens(node.left, node.right)) {
                        context.report({ node, messageId: "comparingToSelf" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-sequences.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of comma operator
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const DEFAULT_OPTIONS = {
        allowInParentheses: true
    };
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow comma operators",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-sequences"
            },
            schema: [{
                    properties: {
                        allowInParentheses: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                unexpectedCommaExpression: "Unexpected use of comma operator."
            }
        },
        create(context) {
            const options = Object.assign({}, DEFAULT_OPTIONS, context.options[0]);
            const sourceCode = context.getSourceCode();
            /**
             * Parts of the grammar that are required to have parens.
             */
            const parenthesized = {
                DoWhileStatement: "test",
                IfStatement: "test",
                SwitchStatement: "discriminant",
                WhileStatement: "test",
                WithStatement: "object",
                ArrowFunctionExpression: "body"
                /*
                 * Omitting CallExpression - commas are parsed as argument separators
                 * Omitting NewExpression - commas are parsed as argument separators
                 * Omitting ForInStatement - parts aren't individually parenthesised
                 * Omitting ForStatement - parts aren't individually parenthesised
                 */
            };
            /**
             * Determines whether a node is required by the grammar to be wrapped in
             * parens, e.g. the test of an if statement.
             * @param {ASTNode} node The AST node
             * @returns {boolean} True if parens around node belong to parent node.
             */
            function requiresExtraParens(node) {
                return node.parent && parenthesized[node.parent.type] &&
                    node === node.parent[parenthesized[node.parent.type]];
            }
            /**
             * Check if a node is wrapped in parens.
             * @param {ASTNode} node The AST node
             * @returns {boolean} True if the node has a paren on each side.
             */
            function isParenthesised(node) {
                return astUtils.isParenthesised(sourceCode, node);
            }
            /**
             * Check if a node is wrapped in two levels of parens.
             * @param {ASTNode} node The AST node
             * @returns {boolean} True if two parens surround the node on each side.
             */
            function isParenthesisedTwice(node) {
                const previousToken = sourceCode.getTokenBefore(node, 1), nextToken = sourceCode.getTokenAfter(node, 1);
                return isParenthesised(node) && previousToken && nextToken &&
                    astUtils.isOpeningParenToken(previousToken) && previousToken.range[1] <= node.range[0] &&
                    astUtils.isClosingParenToken(nextToken) && nextToken.range[0] >= node.range[1];
            }
            return {
                SequenceExpression(node) {
                    // Always allow sequences in for statement update
                    if (node.parent.type === "ForStatement" &&
                        (node === node.parent.init || node === node.parent.update)) {
                        return;
                    }
                    // Wrapping a sequence in extra parens indicates intent
                    if (options.allowInParentheses) {
                        if (requiresExtraParens(node)) {
                            if (isParenthesisedTwice(node)) {
                                return;
                            }
                        }
                        else {
                            if (isParenthesised(node)) {
                                return;
                            }
                        }
                    }
                    const firstCommaToken = sourceCode.getTokenAfter(node.expressions[0], astUtils.isCommaToken);
                    context.report({ node, loc: firstCommaToken.loc, messageId: "unexpectedCommaExpression" });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-setter-return.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow returning values from setters
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const { findVariable } = require(316) /* @eslint-community/eslint-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Determines whether the given identifier node is a reference to a global variable.
     * @param {ASTNode} node `Identifier` node to check.
     * @param {Scope} scope Scope to which the node belongs.
     * @returns {boolean} True if the identifier is a reference to a global variable.
     */
    function isGlobalReference(node, scope) {
        const variable = findVariable(scope, node);
        return variable !== null && variable.scope.type === "global" && variable.defs.length === 0;
    }
    /**
     * Determines whether the given node is an argument of the specified global method call, at the given `index` position.
     * E.g., for given `index === 1`, this function checks for `objectName.methodName(foo, node)`, where objectName is a global variable.
     * @param {ASTNode} node The node to check.
     * @param {Scope} scope Scope to which the node belongs.
     * @param {string} objectName Name of the global object.
     * @param {string} methodName Name of the method.
     * @param {number} index The given position.
     * @returns {boolean} `true` if the node is argument at the given position.
     */
    function isArgumentOfGlobalMethodCall(node, scope, objectName, methodName, index) {
        const callNode = node.parent;
        return callNode.type === "CallExpression" &&
            callNode.arguments[index] === node &&
            astUtils.isSpecificMemberAccess(callNode.callee, objectName, methodName) &&
            isGlobalReference(astUtils.skipChainExpression(callNode.callee).object, scope);
    }
    /**
     * Determines whether the given node is used as a property descriptor.
     * @param {ASTNode} node The node to check.
     * @param {Scope} scope Scope to which the node belongs.
     * @returns {boolean} `true` if the node is a property descriptor.
     */
    function isPropertyDescriptor(node, scope) {
        if (isArgumentOfGlobalMethodCall(node, scope, "Object", "defineProperty", 2) ||
            isArgumentOfGlobalMethodCall(node, scope, "Reflect", "defineProperty", 2)) {
            return true;
        }
        const parent = node.parent;
        if (parent.type === "Property" &&
            parent.value === node) {
            const grandparent = parent.parent;
            if (grandparent.type === "ObjectExpression" &&
                (isArgumentOfGlobalMethodCall(grandparent, scope, "Object", "create", 1) ||
                    isArgumentOfGlobalMethodCall(grandparent, scope, "Object", "defineProperties", 1))) {
                return true;
            }
        }
        return false;
    }
    /**
     * Determines whether the given function node is used as a setter function.
     * @param {ASTNode} node The node to check.
     * @param {Scope} scope Scope to which the node belongs.
     * @returns {boolean} `true` if the node is a setter.
     */
    function isSetter(node, scope) {
        const parent = node.parent;
        if ((parent.type === "Property" || parent.type === "MethodDefinition") &&
            parent.kind === "set" &&
            parent.value === node) {
            // Setter in an object literal or in a class
            return true;
        }
        if (parent.type === "Property" &&
            parent.value === node &&
            astUtils.getStaticPropertyName(parent) === "set" &&
            parent.parent.type === "ObjectExpression" &&
            isPropertyDescriptor(parent.parent, scope)) {
            // Setter in a property descriptor
            return true;
        }
        return false;
    }
    /**
     * Finds function's outer scope.
     * @param {Scope} scope Function's own scope.
     * @returns {Scope} Function's outer scope.
     */
    function getOuterScope(scope) {
        const upper = scope.upper;
        if (upper.type === "function-expression-name") {
            return upper.upper;
        }
        return upper;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow returning values from setters",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-setter-return"
            },
            schema: [],
            messages: {
                returnsValue: "Setter cannot return a value."
            }
        },
        create(context) {
            let funcInfo = null;
            /**
             * Creates and pushes to the stack a function info object for the given function node.
             * @param {ASTNode} node The function node.
             * @returns {void}
             */
            function enterFunction(node) {
                const outerScope = getOuterScope(context.getScope());
                funcInfo = {
                    upper: funcInfo,
                    isSetter: isSetter(node, outerScope)
                };
            }
            /**
             * Pops the current function info object from the stack.
             * @returns {void}
             */
            function exitFunction() {
                funcInfo = funcInfo.upper;
            }
            /**
             * Reports the given node.
             * @param {ASTNode} node Node to report.
             * @returns {void}
             */
            function report(node) {
                context.report({ node, messageId: "returnsValue" });
            }
            return {
                /*
                 * Function declarations cannot be setters, but we still have to track them in the `funcInfo` stack to avoid
                 * false positives, because a ReturnStatement node can belong to a function declaration inside a setter.
                 *
                 * Note: A previously declared function can be referenced and actually used as a setter in a property descriptor,
                 * but that's out of scope for this rule.
                 */
                FunctionDeclaration: enterFunction,
                FunctionExpression: enterFunction,
                ArrowFunctionExpression(node) {
                    enterFunction(node);
                    if (funcInfo.isSetter && node.expression) {
                        // { set: foo => bar } property descriptor. Report implicit return 'bar' as the equivalent for a return statement.
                        report(node.body);
                    }
                },
                "FunctionDeclaration:exit": exitFunction,
                "FunctionExpression:exit": exitFunction,
                "ArrowFunctionExpression:exit": exitFunction,
                ReturnStatement(node) {
                    // Global returns (e.g., at the top level of a Node module) don't have `funcInfo`.
                    if (funcInfo && funcInfo.isSetter && node.argument) {
                        report(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-shadow.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag on declaring variables already declared in the outer scope
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const FUNC_EXPR_NODE_TYPES = new Set(["ArrowFunctionExpression", "FunctionExpression"]);
    const CALL_EXPR_NODE_TYPE = new Set(["CallExpression"]);
    const FOR_IN_OF_TYPE = /^For(?:In|Of)Statement$/u;
    const SENTINEL_TYPE = /^(?:(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression|CatchClause|ImportDeclaration|ExportNamedDeclaration)$/u;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow variable declarations from shadowing variables declared in the outer scope",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-shadow"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        builtinGlobals: { type: "boolean", default: false },
                        hoist: { enum: ["all", "functions", "never"], default: "functions" },
                        allow: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        },
                        ignoreOnInitialization: { type: "boolean", default: false }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                noShadow: "'{{name}}' is already declared in the upper scope on line {{shadowedLine}} column {{shadowedColumn}}.",
                noShadowGlobal: "'{{name}}' is already a global variable."
            }
        },
        create(context) {
            const options = {
                builtinGlobals: context.options[0] && context.options[0].builtinGlobals,
                hoist: (context.options[0] && context.options[0].hoist) || "functions",
                allow: (context.options[0] && context.options[0].allow) || [],
                ignoreOnInitialization: context.options[0] && context.options[0].ignoreOnInitialization
            };
            /**
             * Checks whether or not a given location is inside of the range of a given node.
             * @param {ASTNode} node An node to check.
             * @param {number} location A location to check.
             * @returns {boolean} `true` if the location is inside of the range of the node.
             */
            function isInRange(node, location) {
                return node && node.range[0] <= location && location <= node.range[1];
            }
            /**
             * Searches from the current node through its ancestry to find a matching node.
             * @param {ASTNode} node a node to get.
             * @param {(node: ASTNode) => boolean} match a callback that checks whether or not the node verifies its condition or not.
             * @returns {ASTNode|null} the matching node.
             */
            function findSelfOrAncestor(node, match) {
                let currentNode = node;
                while (currentNode && !match(currentNode)) {
                    currentNode = currentNode.parent;
                }
                return currentNode;
            }
            /**
             * Finds function's outer scope.
             * @param {Scope} scope Function's own scope.
             * @returns {Scope} Function's outer scope.
             */
            function getOuterScope(scope) {
                const upper = scope.upper;
                if (upper.type === "function-expression-name") {
                    return upper.upper;
                }
                return upper;
            }
            /**
             * Checks if a variable and a shadowedVariable have the same init pattern ancestor.
             * @param {Object} variable a variable to check.
             * @param {Object} shadowedVariable a shadowedVariable to check.
             * @returns {boolean} Whether or not the variable and the shadowedVariable have the same init pattern ancestor.
             */
            function isInitPatternNode(variable, shadowedVariable) {
                const outerDef = shadowedVariable.defs[0];
                if (!outerDef) {
                    return false;
                }
                const { variableScope } = variable.scope;
                if (!(FUNC_EXPR_NODE_TYPES.has(variableScope.block.type) && getOuterScope(variableScope) === shadowedVariable.scope)) {
                    return false;
                }
                const fun = variableScope.block;
                const { parent } = fun;
                const callExpression = findSelfOrAncestor(parent, node => CALL_EXPR_NODE_TYPE.has(node.type));
                if (!callExpression) {
                    return false;
                }
                let node = outerDef.name;
                const location = callExpression.range[1];
                while (node) {
                    if (node.type === "VariableDeclarator") {
                        if (isInRange(node.init, location)) {
                            return true;
                        }
                        if (FOR_IN_OF_TYPE.test(node.parent.parent.type) &&
                            isInRange(node.parent.parent.right, location)) {
                            return true;
                        }
                        break;
                    }
                    else if (node.type === "AssignmentPattern") {
                        if (isInRange(node.right, location)) {
                            return true;
                        }
                    }
                    else if (SENTINEL_TYPE.test(node.type)) {
                        break;
                    }
                    node = node.parent;
                }
                return false;
            }
            /**
             * Check if variable name is allowed.
             * @param {ASTNode} variable The variable to check.
             * @returns {boolean} Whether or not the variable name is allowed.
             */
            function isAllowed(variable) {
                return options.allow.includes(variable.name);
            }
            /**
             * Checks if a variable of the class name in the class scope of ClassDeclaration.
             *
             * ClassDeclaration creates two variables of its name into its outer scope and its class scope.
             * So we should ignore the variable in the class scope.
             * @param {Object} variable The variable to check.
             * @returns {boolean} Whether or not the variable of the class name in the class scope of ClassDeclaration.
             */
            function isDuplicatedClassNameVariable(variable) {
                const block = variable.scope.block;
                return block.type === "ClassDeclaration" && block.id === variable.identifiers[0];
            }
            /**
             * Checks if a variable is inside the initializer of scopeVar.
             *
             * To avoid reporting at declarations such as `var a = function a() {};`.
             * But it should report `var a = function(a) {};` or `var a = function() { function a() {} };`.
             * @param {Object} variable The variable to check.
             * @param {Object} scopeVar The scope variable to look for.
             * @returns {boolean} Whether or not the variable is inside initializer of scopeVar.
             */
            function isOnInitializer(variable, scopeVar) {
                const outerScope = scopeVar.scope;
                const outerDef = scopeVar.defs[0];
                const outer = outerDef && outerDef.parent && outerDef.parent.range;
                const innerScope = variable.scope;
                const innerDef = variable.defs[0];
                const inner = innerDef && innerDef.name.range;
                return (outer &&
                    inner &&
                    outer[0] < inner[0] &&
                    inner[1] < outer[1] &&
                    ((innerDef.type === "FunctionName" && innerDef.node.type === "FunctionExpression") || innerDef.node.type === "ClassExpression") &&
                    outerScope === innerScope.upper);
            }
            /**
             * Get a range of a variable's identifier node.
             * @param {Object} variable The variable to get.
             * @returns {Array|undefined} The range of the variable's identifier node.
             */
            function getNameRange(variable) {
                const def = variable.defs[0];
                return def && def.name.range;
            }
            /**
             * Get declared line and column of a variable.
             * @param {eslint-scope.Variable} variable The variable to get.
             * @returns {Object} The declared line and column of the variable.
             */
            function getDeclaredLocation(variable) {
                const identifier = variable.identifiers[0];
                let obj;
                if (identifier) {
                    obj = {
                        global: false,
                        line: identifier.loc.start.line,
                        column: identifier.loc.start.column + 1
                    };
                }
                else {
                    obj = {
                        global: true
                    };
                }
                return obj;
            }
            /**
             * Checks if a variable is in TDZ of scopeVar.
             * @param {Object} variable The variable to check.
             * @param {Object} scopeVar The variable of TDZ.
             * @returns {boolean} Whether or not the variable is in TDZ of scopeVar.
             */
            function isInTdz(variable, scopeVar) {
                const outerDef = scopeVar.defs[0];
                const inner = getNameRange(variable);
                const outer = getNameRange(scopeVar);
                return (inner &&
                    outer &&
                    inner[1] < outer[0] &&
                    // Excepts FunctionDeclaration if is {"hoist":"function"}.
                    (options.hoist !== "functions" || !outerDef || outerDef.node.type !== "FunctionDeclaration"));
            }
            /**
             * Checks the current context for shadowed variables.
             * @param {Scope} scope Fixme
             * @returns {void}
             */
            function checkForShadows(scope) {
                const variables = scope.variables;
                for (let i = 0; i < variables.length; ++i) {
                    const variable = variables[i];
                    // Skips "arguments" or variables of a class name in the class scope of ClassDeclaration.
                    if (variable.identifiers.length === 0 ||
                        isDuplicatedClassNameVariable(variable) ||
                        isAllowed(variable)) {
                        continue;
                    }
                    // Gets shadowed variable.
                    const shadowed = astUtils.getVariableByName(scope.upper, variable.name);
                    if (shadowed &&
                        (shadowed.identifiers.length > 0 || (options.builtinGlobals && "writeable" in shadowed)) &&
                        !isOnInitializer(variable, shadowed) &&
                        !(options.ignoreOnInitialization && isInitPatternNode(variable, shadowed)) &&
                        !(options.hoist !== "all" && isInTdz(variable, shadowed))) {
                        const location = getDeclaredLocation(shadowed);
                        const messageId = location.global ? "noShadowGlobal" : "noShadow";
                        const data = { name: variable.name };
                        if (!location.global) {
                            data.shadowedLine = location.line;
                            data.shadowedColumn = location.column;
                        }
                        context.report({
                            node: variable.identifiers[0],
                            messageId,
                            data
                        });
                    }
                }
            }
            return {
                "Program:exit"() {
                    const globalScope = context.getScope();
                    const stack = globalScope.childScopes.slice();
                    while (stack.length) {
                        const scope = stack.pop();
                        stack.push(...scope.childScopes);
                        checkForShadows(scope);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-shadow-restricted-names.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow shadowing of NaN, undefined, and Infinity (ES5 section 15.1.1)
     * @author Michael Ficarra
     */
    "use strict";
    /**
     * Determines if a variable safely shadows undefined.
     * This is the case when a variable named `undefined` is never assigned to a value (i.e. it always shares the same value
     * as the global).
     * @param {eslintScope.Variable} variable The variable to check
     * @returns {boolean} true if this variable safely shadows `undefined`
     */
    function safelyShadowsUndefined(variable) {
        return variable.name === "undefined" &&
            variable.references.every(ref => !ref.isWrite()) &&
            variable.defs.every(def => def.node.type === "VariableDeclarator" && def.node.init === null);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow identifiers from shadowing restricted names",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-shadow-restricted-names"
            },
            schema: [],
            messages: {
                shadowingRestrictedName: "Shadowing of global property '{{name}}'."
            }
        },
        create(context) {
            const RESTRICTED = new Set(["undefined", "NaN", "Infinity", "arguments", "eval"]);
            return {
                "VariableDeclaration, :function, CatchClause"(node) {
                    for (const variable of context.getDeclaredVariables(node)) {
                        if (variable.defs.length > 0 && RESTRICTED.has(variable.name) && !safelyShadowsUndefined(variable)) {
                            context.report({
                                node: variable.defs[0].name,
                                messageId: "shadowingRestrictedName",
                                data: {
                                    name: variable.name
                                }
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-spaced-func.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check that spaced function application
     * @author Matt DuVall <http://www.mattduvall.com>
     * @deprecated in ESLint v3.3.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Disallow spacing between function identifiers and their applications (deprecated)",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-spaced-func"
            },
            deprecated: true,
            replacedBy: ["func-call-spacing"],
            fixable: "whitespace",
            schema: [],
            messages: {
                noSpacedFunction: "Unexpected space between function name and paren."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Check if open space is present in a function name
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function detectOpenSpaces(node) {
                const lastCalleeToken = sourceCode.getLastToken(node.callee);
                let prevToken = lastCalleeToken, parenToken = sourceCode.getTokenAfter(lastCalleeToken);
                // advances to an open parenthesis.
                while (parenToken &&
                    parenToken.range[1] < node.range[1] &&
                    parenToken.value !== "(") {
                    prevToken = parenToken;
                    parenToken = sourceCode.getTokenAfter(parenToken);
                }
                // look for a space between the callee and the open paren
                if (parenToken &&
                    parenToken.range[1] < node.range[1] &&
                    sourceCode.isSpaceBetweenTokens(prevToken, parenToken)) {
                    context.report({
                        node,
                        loc: lastCalleeToken.loc.start,
                        messageId: "noSpacedFunction",
                        fix(fixer) {
                            return fixer.removeRange([prevToken.range[1], parenToken.range[0]]);
                        }
                    });
                }
            }
            return {
                CallExpression: detectOpenSpaces,
                NewExpression: detectOpenSpaces
            };
        }
    };
},
/* eslint/lib/rules/no-sparse-arrays.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow sparse arrays
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow sparse arrays",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-sparse-arrays"
            },
            schema: [],
            messages: {
                unexpectedSparseArray: "Unexpected comma in middle of array."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                ArrayExpression(node) {
                    const emptySpot = node.elements.includes(null);
                    if (emptySpot) {
                        context.report({ node, messageId: "unexpectedSparseArray" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-sync.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check for properties whose identifier ends with the string Sync
     * @author Matt DuVall<http://mattduvall.com/>
     * @deprecated in ESLint v7.0.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            deprecated: true,
            replacedBy: [],
            type: "suggestion",
            docs: {
                description: "Disallow synchronous methods",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-sync"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowAtRootLevel: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                noSync: "Unexpected sync method: '{{propertyName}}'."
            }
        },
        create(context) {
            const selector = context.options[0] && context.options[0].allowAtRootLevel
                ? ":function MemberExpression[property.name=/.*Sync$/]"
                : "MemberExpression[property.name=/.*Sync$/]";
            return {
                [selector](node) {
                    context.report({
                        node,
                        messageId: "noSync",
                        data: {
                            propertyName: node.property.name
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-tabs.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check for tabs inside a file
     * @author Gyandeep Singh
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const tabRegex = /\t+/gu;
    const anyNonWhitespaceRegex = /\S/u;
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Disallow all tabs",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-tabs"
            },
            schema: [{
                    type: "object",
                    properties: {
                        allowIndentationTabs: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                unexpectedTab: "Unexpected tab character."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const allowIndentationTabs = context.options && context.options[0] && context.options[0].allowIndentationTabs;
            return {
                Program(node) {
                    sourceCode.getLines().forEach((line, index) => {
                        let match;
                        while ((match = tabRegex.exec(line)) !== null) {
                            if (allowIndentationTabs && !anyNonWhitespaceRegex.test(line.slice(0, match.index))) {
                                continue;
                            }
                            context.report({
                                node,
                                loc: {
                                    start: {
                                        line: index + 1,
                                        column: match.index
                                    },
                                    end: {
                                        line: index + 1,
                                        column: match.index + match[0].length
                                    }
                                },
                                messageId: "unexpectedTab"
                            });
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-template-curly-in-string.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Warn when using template string syntax in regular strings
     * @author Jeroen Engels
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow template literal placeholder syntax in regular strings",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-template-curly-in-string"
            },
            schema: [],
            messages: {
                unexpectedTemplateExpression: "Unexpected template string expression."
            }
        },
        create(context) {
            const regex = /\$\{[^}]+\}/u;
            return {
                Literal(node) {
                    if (typeof node.value === "string" && regex.test(node.value)) {
                        context.report({
                            node,
                            messageId: "unexpectedTemplateExpression"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-ternary.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of ternary operators.
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow ternary operators",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-ternary"
            },
            schema: [],
            messages: {
                noTernaryOperator: "Ternary operator used."
            }
        },
        create(context) {
            return {
                ConditionalExpression(node) {
                    context.report({ node, messageId: "noTernaryOperator" });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-this-before-super.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow using `this`/`super` before `super()`.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a given node is a constructor.
     * @param {ASTNode} node A node to check. This node type is one of
     *   `Program`, `FunctionDeclaration`, `FunctionExpression`, and
     *   `ArrowFunctionExpression`.
     * @returns {boolean} `true` if the node is a constructor.
     */
    function isConstructorFunction(node) {
        return (node.type === "FunctionExpression" &&
            node.parent.type === "MethodDefinition" &&
            node.parent.kind === "constructor");
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow `this`/`super` before calling `super()` in constructors",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-this-before-super"
            },
            schema: [],
            messages: {
                noBeforeSuper: "'{{kind}}' is not allowed before 'super()'."
            }
        },
        create(context) {
            /*
             * Information for each constructor.
             * - upper:      Information of the upper constructor.
             * - hasExtends: A flag which shows whether the owner class has a valid
             *   `extends` part.
             * - scope:      The scope of the owner class.
             * - codePath:   The code path of this constructor.
             */
            let funcInfo = null;
            /*
             * Information for each code path segment.
             * Each key is the id of a code path segment.
             * Each value is an object:
             * - superCalled:  The flag which shows `super()` called in all code paths.
             * - invalidNodes: The array of invalid ThisExpression and Super nodes.
             */
            let segInfoMap = Object.create(null);
            /**
             * Gets whether or not `super()` is called in a given code path segment.
             * @param {CodePathSegment} segment A code path segment to get.
             * @returns {boolean} `true` if `super()` is called.
             */
            function isCalled(segment) {
                return !segment.reachable || segInfoMap[segment.id].superCalled;
            }
            /**
             * Checks whether or not this is in a constructor.
             * @returns {boolean} `true` if this is in a constructor.
             */
            function isInConstructorOfDerivedClass() {
                return Boolean(funcInfo && funcInfo.isConstructor && funcInfo.hasExtends);
            }
            /**
             * Checks whether or not this is before `super()` is called.
             * @returns {boolean} `true` if this is before `super()` is called.
             */
            function isBeforeCallOfSuper() {
                return (isInConstructorOfDerivedClass() &&
                    !funcInfo.codePath.currentSegments.every(isCalled));
            }
            /**
             * Sets a given node as invalid.
             * @param {ASTNode} node A node to set as invalid. This is one of
             *      a ThisExpression and a Super.
             * @returns {void}
             */
            function setInvalid(node) {
                const segments = funcInfo.codePath.currentSegments;
                for (let i = 0; i < segments.length; ++i) {
                    const segment = segments[i];
                    if (segment.reachable) {
                        segInfoMap[segment.id].invalidNodes.push(node);
                    }
                }
            }
            /**
             * Sets the current segment as `super` was called.
             * @returns {void}
             */
            function setSuperCalled() {
                const segments = funcInfo.codePath.currentSegments;
                for (let i = 0; i < segments.length; ++i) {
                    const segment = segments[i];
                    if (segment.reachable) {
                        segInfoMap[segment.id].superCalled = true;
                    }
                }
            }
            return {
                /**
                 * Adds information of a constructor into the stack.
                 * @param {CodePath} codePath A code path which was started.
                 * @param {ASTNode} node The current node.
                 * @returns {void}
                 */
                onCodePathStart(codePath, node) {
                    if (isConstructorFunction(node)) {
                        // Class > ClassBody > MethodDefinition > FunctionExpression
                        const classNode = node.parent.parent.parent;
                        funcInfo = {
                            upper: funcInfo,
                            isConstructor: true,
                            hasExtends: Boolean(classNode.superClass &&
                                !astUtils.isNullOrUndefined(classNode.superClass)),
                            codePath
                        };
                    }
                    else {
                        funcInfo = {
                            upper: funcInfo,
                            isConstructor: false,
                            hasExtends: false,
                            codePath
                        };
                    }
                },
                /**
                 * Removes the top of stack item.
                 *
                 * And this traverses all segments of this code path then reports every
                 * invalid node.
                 * @param {CodePath} codePath A code path which was ended.
                 * @returns {void}
                 */
                onCodePathEnd(codePath) {
                    const isDerivedClass = funcInfo.hasExtends;
                    funcInfo = funcInfo.upper;
                    if (!isDerivedClass) {
                        return;
                    }
                    codePath.traverseSegments((segment, controller) => {
                        const info = segInfoMap[segment.id];
                        for (let i = 0; i < info.invalidNodes.length; ++i) {
                            const invalidNode = info.invalidNodes[i];
                            context.report({
                                messageId: "noBeforeSuper",
                                node: invalidNode,
                                data: {
                                    kind: invalidNode.type === "Super" ? "super" : "this"
                                }
                            });
                        }
                        if (info.superCalled) {
                            controller.skip();
                        }
                    });
                },
                /**
                 * Initialize information of a given code path segment.
                 * @param {CodePathSegment} segment A code path segment to initialize.
                 * @returns {void}
                 */
                onCodePathSegmentStart(segment) {
                    if (!isInConstructorOfDerivedClass()) {
                        return;
                    }
                    // Initialize info.
                    segInfoMap[segment.id] = {
                        superCalled: (segment.prevSegments.length > 0 &&
                            segment.prevSegments.every(isCalled)),
                        invalidNodes: []
                    };
                },
                /**
                 * Update information of the code path segment when a code path was
                 * looped.
                 * @param {CodePathSegment} fromSegment The code path segment of the
                 *      end of a loop.
                 * @param {CodePathSegment} toSegment A code path segment of the head
                 *      of a loop.
                 * @returns {void}
                 */
                onCodePathSegmentLoop(fromSegment, toSegment) {
                    if (!isInConstructorOfDerivedClass()) {
                        return;
                    }
                    // Update information inside of the loop.
                    funcInfo.codePath.traverseSegments({ first: toSegment, last: fromSegment }, (segment, controller) => {
                        const info = segInfoMap[segment.id];
                        if (info.superCalled) {
                            info.invalidNodes = [];
                            controller.skip();
                        }
                        else if (segment.prevSegments.length > 0 &&
                            segment.prevSegments.every(isCalled)) {
                            info.superCalled = true;
                            info.invalidNodes = [];
                        }
                    });
                },
                /**
                 * Reports if this is before `super()`.
                 * @param {ASTNode} node A target node.
                 * @returns {void}
                 */
                ThisExpression(node) {
                    if (isBeforeCallOfSuper()) {
                        setInvalid(node);
                    }
                },
                /**
                 * Reports if this is before `super()`.
                 * @param {ASTNode} node A target node.
                 * @returns {void}
                 */
                Super(node) {
                    if (!astUtils.isCallee(node) && isBeforeCallOfSuper()) {
                        setInvalid(node);
                    }
                },
                /**
                 * Marks `super()` called.
                 * @param {ASTNode} node A target node.
                 * @returns {void}
                 */
                "CallExpression:exit"(node) {
                    if (node.callee.type === "Super" && isBeforeCallOfSuper()) {
                        setSuperCalled();
                    }
                },
                /**
                 * Resets state.
                 * @returns {void}
                 */
                "Program:exit"() {
                    segInfoMap = Object.create(null);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-throw-literal.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to restrict what can be thrown as an exception.
     * @author Dieter Oberkofler
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow throwing literals as exceptions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-throw-literal"
            },
            schema: [],
            messages: {
                object: "Expected an error object to be thrown.",
                undef: "Do not throw undefined."
            }
        },
        create(context) {
            return {
                ThrowStatement(node) {
                    if (!astUtils.couldBeError(node.argument)) {
                        context.report({ node, messageId: "object" });
                    }
                    else if (node.argument.type === "Identifier") {
                        if (node.argument.name === "undefined") {
                            context.report({ node, messageId: "undef" });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-trailing-spaces.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow trailing spaces at the end of lines.
     * @author Nodeca Team <https://github.com/nodeca>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Disallow trailing whitespace at the end of lines",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-trailing-spaces"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        skipBlankLines: {
                            type: "boolean",
                            default: false
                        },
                        ignoreComments: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                trailingSpace: "Trailing spaces not allowed."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const BLANK_CLASS = "[ \t\u00a0\u2000-\u200b\u3000]", SKIP_BLANK = `^${BLANK_CLASS}*$`, NONBLANK = `${BLANK_CLASS}+$`;
            const options = context.options[0] || {}, skipBlankLines = options.skipBlankLines || false, ignoreComments = options.ignoreComments || false;
            /**
             * Report the error message
             * @param {ASTNode} node node to report
             * @param {int[]} location range information
             * @param {int[]} fixRange Range based on the whole program
             * @returns {void}
             */
            function report(node, location, fixRange) {
                /*
                 * Passing node is a bit dirty, because message data will contain big
                 * text in `source`. But... who cares :) ?
                 * One more kludge will not make worse the bloody wizardry of this
                 * plugin.
                 */
                context.report({
                    node,
                    loc: location,
                    messageId: "trailingSpace",
                    fix(fixer) {
                        return fixer.removeRange(fixRange);
                    }
                });
            }
            /**
             * Given a list of comment nodes, return the line numbers for those comments.
             * @param {Array} comments An array of comment nodes.
             * @returns {number[]} An array of line numbers containing comments.
             */
            function getCommentLineNumbers(comments) {
                const lines = new Set();
                comments.forEach(comment => {
                    const endLine = comment.type === "Block"
                        ? comment.loc.end.line - 1
                        : comment.loc.end.line;
                    for (let i = comment.loc.start.line; i <= endLine; i++) {
                        lines.add(i);
                    }
                });
                return lines;
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program: function checkTrailingSpaces(node) {
                    /*
                     * Let's hack. Since Espree does not return whitespace nodes,
                     * fetch the source code and do matching via regexps.
                     */
                    const re = new RegExp(NONBLANK, "u"), skipMatch = new RegExp(SKIP_BLANK, "u"), lines = sourceCode.lines, linebreaks = sourceCode.getText().match(astUtils.createGlobalLinebreakMatcher()), comments = sourceCode.getAllComments(), commentLineNumbers = getCommentLineNumbers(comments);
                    let totalLength = 0, fixRange = [];
                    for (let i = 0, ii = lines.length; i < ii; i++) {
                        const lineNumber = i + 1;
                        /*
                         * Always add linebreak length to line length to accommodate for line break (\n or \r\n)
                         * Because during the fix time they also reserve one spot in the array.
                         * Usually linebreak length is 2 for \r\n (CRLF) and 1 for \n (LF)
                         */
                        const linebreakLength = linebreaks && linebreaks[i] ? linebreaks[i].length : 1;
                        const lineLength = lines[i].length + linebreakLength;
                        const matches = re.exec(lines[i]);
                        if (matches) {
                            const location = {
                                start: {
                                    line: lineNumber,
                                    column: matches.index
                                },
                                end: {
                                    line: lineNumber,
                                    column: lineLength - linebreakLength
                                }
                            };
                            const rangeStart = totalLength + location.start.column;
                            const rangeEnd = totalLength + location.end.column;
                            const containingNode = sourceCode.getNodeByRangeIndex(rangeStart);
                            if (containingNode && containingNode.type === "TemplateElement" &&
                                rangeStart > containingNode.parent.range[0] &&
                                rangeEnd < containingNode.parent.range[1]) {
                                totalLength += lineLength;
                                continue;
                            }
                            /*
                             * If the line has only whitespace, and skipBlankLines
                             * is true, don't report it
                             */
                            if (skipBlankLines && skipMatch.test(lines[i])) {
                                totalLength += lineLength;
                                continue;
                            }
                            fixRange = [rangeStart, rangeEnd];
                            if (!ignoreComments || !commentLineNumbers.has(lineNumber)) {
                                report(node, location, fixRange);
                            }
                        }
                        totalLength += lineLength;
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-undef.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag references to undeclared variables.
     * @author Mark Macdonald
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks if the given node is the argument of a typeof operator.
     * @param {ASTNode} node The AST node being checked.
     * @returns {boolean} Whether or not the node is the argument of a typeof operator.
     */
    function hasTypeOfOperator(node) {
        const parent = node.parent;
        return parent.type === "UnaryExpression" && parent.operator === "typeof";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow the use of undeclared variables unless mentioned in `/*global */` comments",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-undef"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        typeof: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                undef: "'{{name}}' is not defined."
            }
        },
        create(context) {
            const options = context.options[0];
            const considerTypeOf = options && options.typeof === true || false;
            return {
                "Program:exit"( /* node */) {
                    const globalScope = context.getScope();
                    globalScope.through.forEach(ref => {
                        const identifier = ref.identifier;
                        if (!considerTypeOf && hasTypeOfOperator(identifier)) {
                            return;
                        }
                        context.report({
                            node: identifier,
                            messageId: "undef",
                            data: identifier
                        });
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-undef-init.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when initializing to undefined
     * @author Ilya Volodin
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow initializing variables to `undefined`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-undef-init"
            },
            schema: [],
            fixable: "code",
            messages: {
                unnecessaryUndefinedInit: "It's not necessary to initialize '{{name}}' to undefined."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                VariableDeclarator(node) {
                    const name = sourceCode.getText(node.id), init = node.init && node.init.name, scope = context.getScope(), undefinedVar = astUtils.getVariableByName(scope, "undefined"), shadowed = undefinedVar && undefinedVar.defs.length > 0, lastToken = sourceCode.getLastToken(node);
                    if (init === "undefined" && node.parent.kind !== "const" && !shadowed) {
                        context.report({
                            node,
                            messageId: "unnecessaryUndefinedInit",
                            data: { name },
                            fix(fixer) {
                                if (node.parent.kind === "var") {
                                    return null;
                                }
                                if (node.id.type === "ArrayPattern" || node.id.type === "ObjectPattern") {
                                    // Don't fix destructuring assignment to `undefined`.
                                    return null;
                                }
                                if (sourceCode.commentsExistBetween(node.id, lastToken)) {
                                    return null;
                                }
                                return fixer.removeRange([node.id.range[1], node.range[1]]);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-undefined.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag references to the undefined variable.
     * @author Michael Ficarra
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the use of `undefined` as an identifier",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-undefined"
            },
            schema: [],
            messages: {
                unexpectedUndefined: "Unexpected use of undefined."
            }
        },
        create(context) {
            /**
             * Report an invalid "undefined" identifier node.
             * @param {ASTNode} node The node to report.
             * @returns {void}
             */
            function report(node) {
                context.report({
                    node,
                    messageId: "unexpectedUndefined"
                });
            }
            /**
             * Checks the given scope for references to `undefined` and reports
             * all references found.
             * @param {eslint-scope.Scope} scope The scope to check.
             * @returns {void}
             */
            function checkScope(scope) {
                const undefinedVar = scope.set.get("undefined");
                if (!undefinedVar) {
                    return;
                }
                const references = undefinedVar.references;
                const defs = undefinedVar.defs;
                // Report non-initializing references (those are covered in defs below)
                references
                    .filter(ref => !ref.init)
                    .forEach(ref => report(ref.identifier));
                defs.forEach(def => report(def.name));
            }
            return {
                "Program:exit"() {
                    const globalScope = context.getScope();
                    const stack = [globalScope];
                    while (stack.length) {
                        const scope = stack.pop();
                        stack.push(...scope.childScopes);
                        checkScope(scope);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-underscore-dangle.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag dangling underscores in variable declarations.
     * @author Matt DuVall <http://www.mattduvall.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow dangling underscores in identifiers",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-underscore-dangle"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allow: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        },
                        allowAfterThis: {
                            type: "boolean",
                            default: false
                        },
                        allowAfterSuper: {
                            type: "boolean",
                            default: false
                        },
                        allowAfterThisConstructor: {
                            type: "boolean",
                            default: false
                        },
                        enforceInMethodNames: {
                            type: "boolean",
                            default: false
                        },
                        allowFunctionParams: {
                            type: "boolean",
                            default: true
                        },
                        enforceInClassFields: {
                            type: "boolean",
                            default: false
                        },
                        allowInArrayDestructuring: {
                            type: "boolean",
                            default: true
                        },
                        allowInObjectDestructuring: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedUnderscore: "Unexpected dangling '_' in '{{identifier}}'."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const ALLOWED_VARIABLES = options.allow ? options.allow : [];
            const allowAfterThis = typeof options.allowAfterThis !== "undefined" ? options.allowAfterThis : false;
            const allowAfterSuper = typeof options.allowAfterSuper !== "undefined" ? options.allowAfterSuper : false;
            const allowAfterThisConstructor = typeof options.allowAfterThisConstructor !== "undefined" ? options.allowAfterThisConstructor : false;
            const enforceInMethodNames = typeof options.enforceInMethodNames !== "undefined" ? options.enforceInMethodNames : false;
            const enforceInClassFields = typeof options.enforceInClassFields !== "undefined" ? options.enforceInClassFields : false;
            const allowFunctionParams = typeof options.allowFunctionParams !== "undefined" ? options.allowFunctionParams : true;
            const allowInArrayDestructuring = typeof options.allowInArrayDestructuring !== "undefined" ? options.allowInArrayDestructuring : true;
            const allowInObjectDestructuring = typeof options.allowInObjectDestructuring !== "undefined" ? options.allowInObjectDestructuring : true;
            //-------------------------------------------------------------------------
            // Helpers
            //-------------------------------------------------------------------------
            /**
             * Check if identifier is present inside the allowed option
             * @param {string} identifier name of the node
             * @returns {boolean} true if its is present
             * @private
             */
            function isAllowed(identifier) {
                return ALLOWED_VARIABLES.includes(identifier);
            }
            /**
             * Check if identifier has a dangling underscore
             * @param {string} identifier name of the node
             * @returns {boolean} true if its is present
             * @private
             */
            function hasDanglingUnderscore(identifier) {
                const len = identifier.length;
                return identifier !== "_" && (identifier[0] === "_" || identifier[len - 1] === "_");
            }
            /**
             * Check if identifier is a special case member expression
             * @param {string} identifier name of the node
             * @returns {boolean} true if its is a special case
             * @private
             */
            function isSpecialCaseIdentifierForMemberExpression(identifier) {
                return identifier === "__proto__";
            }
            /**
             * Check if identifier is a special case variable expression
             * @param {string} identifier name of the node
             * @returns {boolean} true if its is a special case
             * @private
             */
            function isSpecialCaseIdentifierInVariableExpression(identifier) {
                // Checks for the underscore library usage here
                return identifier === "_";
            }
            /**
             * Check if a node is a member reference of this.constructor
             * @param {ASTNode} node node to evaluate
             * @returns {boolean} true if it is a reference on this.constructor
             * @private
             */
            function isThisConstructorReference(node) {
                return node.object.type === "MemberExpression" &&
                    node.object.property.name === "constructor" &&
                    node.object.object.type === "ThisExpression";
            }
            /**
             * Check if function parameter has a dangling underscore.
             * @param {ASTNode} node function node to evaluate
             * @returns {void}
             * @private
             */
            function checkForDanglingUnderscoreInFunctionParameters(node) {
                if (!allowFunctionParams) {
                    node.params.forEach(param => {
                        const { type } = param;
                        let nodeToCheck;
                        if (type === "RestElement") {
                            nodeToCheck = param.argument;
                        }
                        else if (type === "AssignmentPattern") {
                            nodeToCheck = param.left;
                        }
                        else {
                            nodeToCheck = param;
                        }
                        if (nodeToCheck.type === "Identifier") {
                            const identifier = nodeToCheck.name;
                            if (hasDanglingUnderscore(identifier) && !isAllowed(identifier)) {
                                context.report({
                                    node: param,
                                    messageId: "unexpectedUnderscore",
                                    data: {
                                        identifier
                                    }
                                });
                            }
                        }
                    });
                }
            }
            /**
             * Check if function has a dangling underscore
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkForDanglingUnderscoreInFunction(node) {
                if (node.type === "FunctionDeclaration" && node.id) {
                    const identifier = node.id.name;
                    if (typeof identifier !== "undefined" && hasDanglingUnderscore(identifier) && !isAllowed(identifier)) {
                        context.report({
                            node,
                            messageId: "unexpectedUnderscore",
                            data: {
                                identifier
                            }
                        });
                    }
                }
                checkForDanglingUnderscoreInFunctionParameters(node);
            }
            /**
             * Check if variable expression has a dangling underscore
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkForDanglingUnderscoreInVariableExpression(node) {
                context.getDeclaredVariables(node).forEach(variable => {
                    const definition = variable.defs.find(def => def.node === node);
                    const identifierNode = definition.name;
                    const identifier = identifierNode.name;
                    let parent = identifierNode.parent;
                    while (!["VariableDeclarator", "ArrayPattern", "ObjectPattern"].includes(parent.type)) {
                        parent = parent.parent;
                    }
                    if (hasDanglingUnderscore(identifier) &&
                        !isSpecialCaseIdentifierInVariableExpression(identifier) &&
                        !isAllowed(identifier) &&
                        !(allowInArrayDestructuring && parent.type === "ArrayPattern") &&
                        !(allowInObjectDestructuring && parent.type === "ObjectPattern")) {
                        context.report({
                            node,
                            messageId: "unexpectedUnderscore",
                            data: {
                                identifier
                            }
                        });
                    }
                });
            }
            /**
             * Check if member expression has a dangling underscore
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkForDanglingUnderscoreInMemberExpression(node) {
                const identifier = node.property.name, isMemberOfThis = node.object.type === "ThisExpression", isMemberOfSuper = node.object.type === "Super", isMemberOfThisConstructor = isThisConstructorReference(node);
                if (typeof identifier !== "undefined" && hasDanglingUnderscore(identifier) &&
                    !(isMemberOfThis && allowAfterThis) &&
                    !(isMemberOfSuper && allowAfterSuper) &&
                    !(isMemberOfThisConstructor && allowAfterThisConstructor) &&
                    !isSpecialCaseIdentifierForMemberExpression(identifier) && !isAllowed(identifier)) {
                    context.report({
                        node,
                        messageId: "unexpectedUnderscore",
                        data: {
                            identifier
                        }
                    });
                }
            }
            /**
             * Check if method declaration or method property has a dangling underscore
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkForDanglingUnderscoreInMethod(node) {
                const identifier = node.key.name;
                const isMethod = node.type === "MethodDefinition" || node.type === "Property" && node.method;
                if (typeof identifier !== "undefined" && enforceInMethodNames && isMethod && hasDanglingUnderscore(identifier) && !isAllowed(identifier)) {
                    context.report({
                        node,
                        messageId: "unexpectedUnderscore",
                        data: {
                            identifier: node.key.type === "PrivateIdentifier"
                                ? `#${identifier}`
                                : identifier
                        }
                    });
                }
            }
            /**
             * Check if a class field has a dangling underscore
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkForDanglingUnderscoreInClassField(node) {
                const identifier = node.key.name;
                if (typeof identifier !== "undefined" && hasDanglingUnderscore(identifier) &&
                    enforceInClassFields &&
                    !isAllowed(identifier)) {
                    context.report({
                        node,
                        messageId: "unexpectedUnderscore",
                        data: {
                            identifier: node.key.type === "PrivateIdentifier"
                                ? `#${identifier}`
                                : identifier
                        }
                    });
                }
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                FunctionDeclaration: checkForDanglingUnderscoreInFunction,
                VariableDeclarator: checkForDanglingUnderscoreInVariableExpression,
                MemberExpression: checkForDanglingUnderscoreInMemberExpression,
                MethodDefinition: checkForDanglingUnderscoreInMethod,
                PropertyDefinition: checkForDanglingUnderscoreInClassField,
                Property: checkForDanglingUnderscoreInMethod,
                FunctionExpression: checkForDanglingUnderscoreInFunction,
                ArrowFunctionExpression: checkForDanglingUnderscoreInFunction
            };
        }
    };
},
/* eslint/lib/rules/no-unexpected-multiline.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to spot scenarios where a newline looks like it is ending a statement, but is not.
     * @author Glen Mailer
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow confusing multiline expressions",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-unexpected-multiline"
            },
            schema: [],
            messages: {
                function: "Unexpected newline between function and ( of function call.",
                property: "Unexpected newline between object and [ of property access.",
                taggedTemplate: "Unexpected newline between template tag and template literal.",
                division: "Unexpected newline between numerator and division operator."
            }
        },
        create(context) {
            const REGEX_FLAG_MATCHER = /^[gimsuy]+$/u;
            const sourceCode = context.getSourceCode();
            /**
             * Check to see if there is a newline between the node and the following open bracket
             * line's expression
             * @param {ASTNode} node The node to check.
             * @param {string} messageId The error messageId to use.
             * @returns {void}
             * @private
             */
            function checkForBreakAfter(node, messageId) {
                const openParen = sourceCode.getTokenAfter(node, astUtils.isNotClosingParenToken);
                const nodeExpressionEnd = sourceCode.getTokenBefore(openParen);
                if (openParen.loc.start.line !== nodeExpressionEnd.loc.end.line) {
                    context.report({
                        node,
                        loc: openParen.loc,
                        messageId
                    });
                }
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                MemberExpression(node) {
                    if (!node.computed || node.optional) {
                        return;
                    }
                    checkForBreakAfter(node.object, "property");
                },
                TaggedTemplateExpression(node) {
                    const { quasi } = node;
                    // handles common tags, parenthesized tags, and typescript's generic type arguments
                    const tokenBefore = sourceCode.getTokenBefore(quasi);
                    if (tokenBefore.loc.end.line !== quasi.loc.start.line) {
                        context.report({
                            node,
                            loc: {
                                start: quasi.loc.start,
                                end: {
                                    line: quasi.loc.start.line,
                                    column: quasi.loc.start.column + 1
                                }
                            },
                            messageId: "taggedTemplate"
                        });
                    }
                },
                CallExpression(node) {
                    if (node.arguments.length === 0 || node.optional) {
                        return;
                    }
                    checkForBreakAfter(node.callee, "function");
                },
                "BinaryExpression[operator='/'] > BinaryExpression[operator='/'].left"(node) {
                    const secondSlash = sourceCode.getTokenAfter(node, token => token.value === "/");
                    const tokenAfterOperator = sourceCode.getTokenAfter(secondSlash);
                    if (tokenAfterOperator.type === "Identifier" &&
                        REGEX_FLAG_MATCHER.test(tokenAfterOperator.value) &&
                        secondSlash.range[1] === tokenAfterOperator.range[0]) {
                        checkForBreakAfter(node.left, "division");
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-unmodified-loop-condition.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow use of unmodified expressions in loop conditions
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const Traverser = require(313) /* ../shared/traverser */, astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const SENTINEL_PATTERN = /(?:(?:Call|Class|Function|Member|New|Yield)Expression|Statement|Declaration)$/u;
    const LOOP_PATTERN = /^(?:DoWhile|For|While)Statement$/u; // for-in/of statements don't have `test` property.
    const GROUP_PATTERN = /^(?:BinaryExpression|ConditionalExpression)$/u;
    const SKIP_PATTERN = /^(?:ArrowFunction|Class|Function)Expression$/u;
    const DYNAMIC_PATTERN = /^(?:Call|Member|New|TaggedTemplate|Yield)Expression$/u;
    /**
     * @typedef {Object} LoopConditionInfo
     * @property {eslint-scope.Reference} reference - The reference.
     * @property {ASTNode} group - BinaryExpression or ConditionalExpression nodes
     *      that the reference is belonging to.
     * @property {Function} isInLoop - The predicate which checks a given reference
     *      is in this loop.
     * @property {boolean} modified - The flag that the reference is modified in
     *      this loop.
     */
    /**
     * Checks whether or not a given reference is a write reference.
     * @param {eslint-scope.Reference} reference A reference to check.
     * @returns {boolean} `true` if the reference is a write reference.
     */
    function isWriteReference(reference) {
        if (reference.init) {
            const def = reference.resolved && reference.resolved.defs[0];
            if (!def || def.type !== "Variable" || def.parent.kind !== "var") {
                return false;
            }
        }
        return reference.isWrite();
    }
    /**
     * Checks whether or not a given loop condition info does not have the modified
     * flag.
     * @param {LoopConditionInfo} condition A loop condition info to check.
     * @returns {boolean} `true` if the loop condition info is "unmodified".
     */
    function isUnmodified(condition) {
        return !condition.modified;
    }
    /**
     * Checks whether or not a given loop condition info does not have the modified
     * flag and does not have the group this condition belongs to.
     * @param {LoopConditionInfo} condition A loop condition info to check.
     * @returns {boolean} `true` if the loop condition info is "unmodified".
     */
    function isUnmodifiedAndNotBelongToGroup(condition) {
        return !(condition.modified || condition.group);
    }
    /**
     * Checks whether or not a given reference is inside of a given node.
     * @param {ASTNode} node A node to check.
     * @param {eslint-scope.Reference} reference A reference to check.
     * @returns {boolean} `true` if the reference is inside of the node.
     */
    function isInRange(node, reference) {
        const or = node.range;
        const ir = reference.identifier.range;
        return or[0] <= ir[0] && ir[1] <= or[1];
    }
    /**
     * Checks whether or not a given reference is inside of a loop node's condition.
     * @param {ASTNode} node A node to check.
     * @param {eslint-scope.Reference} reference A reference to check.
     * @returns {boolean} `true` if the reference is inside of the loop node's
     *      condition.
     */
    const isInLoop = {
        WhileStatement: isInRange,
        DoWhileStatement: isInRange,
        ForStatement(node, reference) {
            return (isInRange(node, reference) &&
                !(node.init && isInRange(node.init, reference)));
        }
    };
    /**
     * Gets the function which encloses a given reference.
     * This supports only FunctionDeclaration.
     * @param {eslint-scope.Reference} reference A reference to get.
     * @returns {ASTNode|null} The function node or null.
     */
    function getEncloseFunctionDeclaration(reference) {
        let node = reference.identifier;
        while (node) {
            if (node.type === "FunctionDeclaration") {
                return node.id ? node : null;
            }
            node = node.parent;
        }
        return null;
    }
    /**
     * Updates the "modified" flags of given loop conditions with given modifiers.
     * @param {LoopConditionInfo[]} conditions The loop conditions to be updated.
     * @param {eslint-scope.Reference[]} modifiers The references to update.
     * @returns {void}
     */
    function updateModifiedFlag(conditions, modifiers) {
        for (let i = 0; i < conditions.length; ++i) {
            const condition = conditions[i];
            for (let j = 0; !condition.modified && j < modifiers.length; ++j) {
                const modifier = modifiers[j];
                let funcNode, funcVar;
                /*
                 * Besides checking for the condition being in the loop, we want to
                 * check the function that this modifier is belonging to is called
                 * in the loop.
                 * FIXME: This should probably be extracted to a function.
                 */
                const inLoop = condition.isInLoop(modifier) || Boolean((funcNode = getEncloseFunctionDeclaration(modifier)) &&
                    (funcVar = astUtils.getVariableByName(modifier.from.upper, funcNode.id.name)) &&
                    funcVar.references.some(condition.isInLoop));
                condition.modified = inLoop;
            }
        }
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow unmodified loop conditions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-unmodified-loop-condition"
            },
            schema: [],
            messages: {
                loopConditionNotModified: "'{{name}}' is not modified in this loop."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            let groupMap = null;
            /**
             * Reports a given condition info.
             * @param {LoopConditionInfo} condition A loop condition info to report.
             * @returns {void}
             */
            function report(condition) {
                const node = condition.reference.identifier;
                context.report({
                    node,
                    messageId: "loopConditionNotModified",
                    data: node
                });
            }
            /**
             * Registers given conditions to the group the condition belongs to.
             * @param {LoopConditionInfo[]} conditions A loop condition info to
             *      register.
             * @returns {void}
             */
            function registerConditionsToGroup(conditions) {
                for (let i = 0; i < conditions.length; ++i) {
                    const condition = conditions[i];
                    if (condition.group) {
                        let group = groupMap.get(condition.group);
                        if (!group) {
                            group = [];
                            groupMap.set(condition.group, group);
                        }
                        group.push(condition);
                    }
                }
            }
            /**
             * Reports references which are inside of unmodified groups.
             * @param {LoopConditionInfo[]} conditions A loop condition info to report.
             * @returns {void}
             */
            function checkConditionsInGroup(conditions) {
                if (conditions.every(isUnmodified)) {
                    conditions.forEach(report);
                }
            }
            /**
             * Checks whether or not a given group node has any dynamic elements.
             * @param {ASTNode} root A node to check.
             *      This node is one of BinaryExpression or ConditionalExpression.
             * @returns {boolean} `true` if the node is dynamic.
             */
            function hasDynamicExpressions(root) {
                let retv = false;
                Traverser.traverse(root, {
                    visitorKeys: sourceCode.visitorKeys,
                    enter(node) {
                        if (DYNAMIC_PATTERN.test(node.type)) {
                            retv = true;
                            this.break();
                        }
                        else if (SKIP_PATTERN.test(node.type)) {
                            this.skip();
                        }
                    }
                });
                return retv;
            }
            /**
             * Creates the loop condition information from a given reference.
             * @param {eslint-scope.Reference} reference A reference to create.
             * @returns {LoopConditionInfo|null} Created loop condition info, or null.
             */
            function toLoopCondition(reference) {
                if (reference.init) {
                    return null;
                }
                let group = null;
                let child = reference.identifier;
                let node = child.parent;
                while (node) {
                    if (SENTINEL_PATTERN.test(node.type)) {
                        if (LOOP_PATTERN.test(node.type) && node.test === child) {
                            // This reference is inside of a loop condition.
                            return {
                                reference,
                                group,
                                isInLoop: isInLoop[node.type].bind(null, node),
                                modified: false
                            };
                        }
                        // This reference is outside of a loop condition.
                        break;
                    }
                    /*
                     * If it's inside of a group, OK if either operand is modified.
                     * So stores the group this reference belongs to.
                     */
                    if (GROUP_PATTERN.test(node.type)) {
                        // If this expression is dynamic, no need to check.
                        if (hasDynamicExpressions(node)) {
                            break;
                        }
                        else {
                            group = node;
                        }
                    }
                    child = node;
                    node = node.parent;
                }
                return null;
            }
            /**
             * Finds unmodified references which are inside of a loop condition.
             * Then reports the references which are outside of groups.
             * @param {eslint-scope.Variable} variable A variable to report.
             * @returns {void}
             */
            function checkReferences(variable) {
                // Gets references that exist in loop conditions.
                const conditions = variable
                    .references
                    .map(toLoopCondition)
                    .filter(Boolean);
                if (conditions.length === 0) {
                    return;
                }
                // Registers the conditions to belonging groups.
                registerConditionsToGroup(conditions);
                // Check the conditions are modified.
                const modifiers = variable.references.filter(isWriteReference);
                if (modifiers.length > 0) {
                    updateModifiedFlag(conditions, modifiers);
                }
                /*
                 * Reports the conditions which are not belonging to groups.
                 * Others will be reported after all variables are done.
                 */
                conditions
                    .filter(isUnmodifiedAndNotBelongToGroup)
                    .forEach(report);
            }
            return {
                "Program:exit"() {
                    const queue = [context.getScope()];
                    groupMap = new Map();
                    let scope;
                    while ((scope = queue.pop())) {
                        queue.push(...scope.childScopes);
                        scope.variables.forEach(checkReferences);
                    }
                    groupMap.forEach(checkConditionsInGroup);
                    groupMap = null;
                }
            };
        }
    };
},
/* eslint/lib/rules/no-unneeded-ternary.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag no-unneeded-ternary
     * @author Gyandeep Singh
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    // Operators that always result in a boolean value
    const BOOLEAN_OPERATORS = new Set(["==", "===", "!=", "!==", ">", ">=", "<", "<=", "in", "instanceof"]);
    const OPERATOR_INVERSES = {
        "==": "!=",
        "!=": "==",
        "===": "!==",
        "!==": "==="
        // Operators like < and >= are not true inverses, since both will return false with NaN.
    };
    const OR_PRECEDENCE = astUtils.getPrecedence({ type: "LogicalExpression", operator: "||" });
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow ternary operators when simpler alternatives exist",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-unneeded-ternary"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        defaultAssignment: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "code",
            messages: {
                unnecessaryConditionalExpression: "Unnecessary use of boolean literals in conditional expression.",
                unnecessaryConditionalAssignment: "Unnecessary use of conditional expression for default assignment."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const defaultAssignment = options.defaultAssignment !== false;
            const sourceCode = context.getSourceCode();
            /**
             * Test if the node is a boolean literal
             * @param {ASTNode} node The node to report.
             * @returns {boolean} True if the its a boolean literal
             * @private
             */
            function isBooleanLiteral(node) {
                return node.type === "Literal" && typeof node.value === "boolean";
            }
            /**
             * Creates an expression that represents the boolean inverse of the expression represented by the original node
             * @param {ASTNode} node A node representing an expression
             * @returns {string} A string representing an inverted expression
             */
            function invertExpression(node) {
                if (node.type === "BinaryExpression" && Object.prototype.hasOwnProperty.call(OPERATOR_INVERSES, node.operator)) {
                    const operatorToken = sourceCode.getFirstTokenBetween(node.left, node.right, token => token.value === node.operator);
                    const text = sourceCode.getText();
                    return text.slice(node.range[0], operatorToken.range[0]) + OPERATOR_INVERSES[node.operator] + text.slice(operatorToken.range[1], node.range[1]);
                }
                if (astUtils.getPrecedence(node) < astUtils.getPrecedence({ type: "UnaryExpression" })) {
                    return `!(${astUtils.getParenthesisedText(sourceCode, node)})`;
                }
                return `!${astUtils.getParenthesisedText(sourceCode, node)}`;
            }
            /**
             * Tests if a given node always evaluates to a boolean value
             * @param {ASTNode} node An expression node
             * @returns {boolean} True if it is determined that the node will always evaluate to a boolean value
             */
            function isBooleanExpression(node) {
                return node.type === "BinaryExpression" && BOOLEAN_OPERATORS.has(node.operator) ||
                    node.type === "UnaryExpression" && node.operator === "!";
            }
            /**
             * Test if the node matches the pattern id ? id : expression
             * @param {ASTNode} node The ConditionalExpression to check.
             * @returns {boolean} True if the pattern is matched, and false otherwise
             * @private
             */
            function matchesDefaultAssignment(node) {
                return node.test.type === "Identifier" &&
                    node.consequent.type === "Identifier" &&
                    node.test.name === node.consequent.name;
            }
            return {
                ConditionalExpression(node) {
                    if (isBooleanLiteral(node.alternate) && isBooleanLiteral(node.consequent)) {
                        context.report({
                            node,
                            messageId: "unnecessaryConditionalExpression",
                            fix(fixer) {
                                if (node.consequent.value === node.alternate.value) {
                                    // Replace `foo ? true : true` with just `true`, but don't replace `foo() ? true : true`
                                    return node.test.type === "Identifier" ? fixer.replaceText(node, node.consequent.value.toString()) : null;
                                }
                                if (node.alternate.value) {
                                    // Replace `foo() ? false : true` with `!(foo())`
                                    return fixer.replaceText(node, invertExpression(node.test));
                                }
                                // Replace `foo ? true : false` with `foo` if `foo` is guaranteed to be a boolean, or `!!foo` otherwise.
                                return fixer.replaceText(node, isBooleanExpression(node.test) ? astUtils.getParenthesisedText(sourceCode, node.test) : `!${invertExpression(node.test)}`);
                            }
                        });
                    }
                    else if (!defaultAssignment && matchesDefaultAssignment(node)) {
                        context.report({
                            node,
                            messageId: "unnecessaryConditionalAssignment",
                            fix(fixer) {
                                const shouldParenthesizeAlternate = (astUtils.getPrecedence(node.alternate) < OR_PRECEDENCE ||
                                    astUtils.isCoalesceExpression(node.alternate)) &&
                                    !astUtils.isParenthesised(sourceCode, node.alternate);
                                const alternateText = shouldParenthesizeAlternate
                                    ? `(${sourceCode.getText(node.alternate)})`
                                    : astUtils.getParenthesisedText(sourceCode, node.alternate);
                                const testText = astUtils.getParenthesisedText(sourceCode, node.test);
                                return fixer.replaceText(node, `${testText} || ${alternateText}`);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-unreachable.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Checks for unreachable code due to return, throws, break, and continue.
     * @author Joel Feenstra
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * @typedef {Object} ConstructorInfo
     * @property {ConstructorInfo | null} upper Info about the constructor that encloses this constructor.
     * @property {boolean} hasSuperCall The flag about having `super()` expressions.
     */
    /**
     * Checks whether or not a given variable declarator has the initializer.
     * @param {ASTNode} node A VariableDeclarator node to check.
     * @returns {boolean} `true` if the node has the initializer.
     */
    function isInitialized(node) {
        return Boolean(node.init);
    }
    /**
     * Checks whether or not a given code path segment is unreachable.
     * @param {CodePathSegment} segment A CodePathSegment to check.
     * @returns {boolean} `true` if the segment is unreachable.
     */
    function isUnreachable(segment) {
        return !segment.reachable;
    }
    /**
     * The class to distinguish consecutive unreachable statements.
     */
    class ConsecutiveRange {
        constructor(sourceCode) {
            this.sourceCode = sourceCode;
            this.startNode = null;
            this.endNode = null;
        }
        /**
         * The location object of this range.
         * @type {Object}
         */
        get location() {
            return {
                start: this.startNode.loc.start,
                end: this.endNode.loc.end
            };
        }
        /**
         * `true` if this range is empty.
         * @type {boolean}
         */
        get isEmpty() {
            return !(this.startNode && this.endNode);
        }
        /**
         * Checks whether the given node is inside of this range.
         * @param {ASTNode|Token} node The node to check.
         * @returns {boolean} `true` if the node is inside of this range.
         */
        contains(node) {
            return (node.range[0] >= this.startNode.range[0] &&
                node.range[1] <= this.endNode.range[1]);
        }
        /**
         * Checks whether the given node is consecutive to this range.
         * @param {ASTNode} node The node to check.
         * @returns {boolean} `true` if the node is consecutive to this range.
         */
        isConsecutive(node) {
            return this.contains(this.sourceCode.getTokenBefore(node));
        }
        /**
         * Merges the given node to this range.
         * @param {ASTNode} node The node to merge.
         * @returns {void}
         */
        merge(node) {
            this.endNode = node;
        }
        /**
         * Resets this range by the given node or null.
         * @param {ASTNode|null} node The node to reset, or null.
         * @returns {void}
         */
        reset(node) {
            this.startNode = this.endNode = node;
        }
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow unreachable code after `return`, `throw`, `continue`, and `break` statements",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-unreachable"
            },
            schema: [],
            messages: {
                unreachableCode: "Unreachable code."
            }
        },
        create(context) {
            let currentCodePath = null;
            /** @type {ConstructorInfo | null} */
            let constructorInfo = null;
            /** @type {ConsecutiveRange} */
            const range = new ConsecutiveRange(context.getSourceCode());
            /**
             * Reports a given node if it's unreachable.
             * @param {ASTNode} node A statement node to report.
             * @returns {void}
             */
            function reportIfUnreachable(node) {
                let nextNode = null;
                if (node && (node.type === "PropertyDefinition" || currentCodePath.currentSegments.every(isUnreachable))) {
                    // Store this statement to distinguish consecutive statements.
                    if (range.isEmpty) {
                        range.reset(node);
                        return;
                    }
                    // Skip if this statement is inside of the current range.
                    if (range.contains(node)) {
                        return;
                    }
                    // Merge if this statement is consecutive to the current range.
                    if (range.isConsecutive(node)) {
                        range.merge(node);
                        return;
                    }
                    nextNode = node;
                }
                /*
                 * Report the current range since this statement is reachable or is
                 * not consecutive to the current range.
                 */
                if (!range.isEmpty) {
                    context.report({
                        messageId: "unreachableCode",
                        loc: range.location,
                        node: range.startNode
                    });
                }
                // Update the current range.
                range.reset(nextNode);
            }
            return {
                // Manages the current code path.
                onCodePathStart(codePath) {
                    currentCodePath = codePath;
                },
                onCodePathEnd() {
                    currentCodePath = currentCodePath.upper;
                },
                // Registers for all statement nodes (excludes FunctionDeclaration).
                BlockStatement: reportIfUnreachable,
                BreakStatement: reportIfUnreachable,
                ClassDeclaration: reportIfUnreachable,
                ContinueStatement: reportIfUnreachable,
                DebuggerStatement: reportIfUnreachable,
                DoWhileStatement: reportIfUnreachable,
                ExpressionStatement: reportIfUnreachable,
                ForInStatement: reportIfUnreachable,
                ForOfStatement: reportIfUnreachable,
                ForStatement: reportIfUnreachable,
                IfStatement: reportIfUnreachable,
                ImportDeclaration: reportIfUnreachable,
                LabeledStatement: reportIfUnreachable,
                ReturnStatement: reportIfUnreachable,
                SwitchStatement: reportIfUnreachable,
                ThrowStatement: reportIfUnreachable,
                TryStatement: reportIfUnreachable,
                VariableDeclaration(node) {
                    if (node.kind !== "var" || node.declarations.some(isInitialized)) {
                        reportIfUnreachable(node);
                    }
                },
                WhileStatement: reportIfUnreachable,
                WithStatement: reportIfUnreachable,
                ExportNamedDeclaration: reportIfUnreachable,
                ExportDefaultDeclaration: reportIfUnreachable,
                ExportAllDeclaration: reportIfUnreachable,
                "Program:exit"() {
                    reportIfUnreachable();
                },
                /*
                 * Instance fields defined in a subclass are never created if the constructor of the subclass
                 * doesn't call `super()`, so their definitions are unreachable code.
                 */
                "MethodDefinition[kind='constructor']"() {
                    constructorInfo = {
                        upper: constructorInfo,
                        hasSuperCall: false
                    };
                },
                "MethodDefinition[kind='constructor']:exit"(node) {
                    const { hasSuperCall } = constructorInfo;
                    constructorInfo = constructorInfo.upper;
                    // skip typescript constructors without the body
                    if (!node.value.body) {
                        return;
                    }
                    const classDefinition = node.parent.parent;
                    if (classDefinition.superClass && !hasSuperCall) {
                        for (const element of classDefinition.body.body) {
                            if (element.type === "PropertyDefinition" && !element.static) {
                                reportIfUnreachable(element);
                            }
                        }
                    }
                },
                "CallExpression > Super.callee"() {
                    if (constructorInfo) {
                        constructorInfo.hasSuperCall = true;
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-unreachable-loop.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow loops with a body that allows only one iteration
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const allLoopTypes = ["WhileStatement", "DoWhileStatement", "ForStatement", "ForInStatement", "ForOfStatement"];
    /**
     * Determines whether the given node is the first node in the code path to which a loop statement
     * 'loops' for the next iteration.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is a looping target.
     */
    function isLoopingTarget(node) {
        const parent = node.parent;
        if (parent) {
            switch (parent.type) {
                case "WhileStatement":
                    return node === parent.test;
                case "DoWhileStatement":
                    return node === parent.body;
                case "ForStatement":
                    return node === (parent.update || parent.test || parent.body);
                case "ForInStatement":
                case "ForOfStatement":
                    return node === parent.left;
                // no default
            }
        }
        return false;
    }
    /**
     * Creates an array with elements from the first given array that are not included in the second given array.
     * @param {Array} arrA The array to compare from.
     * @param {Array} arrB The array to compare against.
     * @returns {Array} a new array that represents `arrA \ arrB`.
     */
    function getDifference(arrA, arrB) {
        return arrA.filter(a => !arrB.includes(a));
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow loops with a body that allows only one iteration",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-unreachable-loop"
            },
            schema: [{
                    type: "object",
                    properties: {
                        ignore: {
                            type: "array",
                            items: {
                                enum: allLoopTypes
                            },
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                invalid: "Invalid loop. Its body allows only one iteration."
            }
        },
        create(context) {
            const ignoredLoopTypes = context.options[0] && context.options[0].ignore || [], loopTypesToCheck = getDifference(allLoopTypes, ignoredLoopTypes), loopSelector = loopTypesToCheck.join(","), loopsByTargetSegments = new Map(), loopsToReport = new Set();
            let currentCodePath = null;
            return {
                onCodePathStart(codePath) {
                    currentCodePath = codePath;
                },
                onCodePathEnd() {
                    currentCodePath = currentCodePath.upper;
                },
                [loopSelector](node) {
                    /**
                     * Ignore unreachable loop statements to avoid unnecessary complexity in the implementation, or false positives otherwise.
                     * For unreachable segments, the code path analysis does not raise events required for this implementation.
                     */
                    if (currentCodePath.currentSegments.some(segment => segment.reachable)) {
                        loopsToReport.add(node);
                    }
                },
                onCodePathSegmentStart(segment, node) {
                    if (isLoopingTarget(node)) {
                        const loop = node.parent;
                        loopsByTargetSegments.set(segment, loop);
                    }
                },
                onCodePathSegmentLoop(_, toSegment, node) {
                    const loop = loopsByTargetSegments.get(toSegment);
                    /**
                     * The second iteration is reachable, meaning that the loop is valid by the logic of this rule,
                     * only if there is at least one loop event with the appropriate target (which has been already
                     * determined in the `loopsByTargetSegments` map), raised from either:
                     *
                     * - the end of the loop's body (in which case `node === loop`)
                     * - a `continue` statement
                     *
                     * This condition skips loop events raised from `ForInStatement > .right` and `ForOfStatement > .right` nodes.
                     */
                    if (node === loop || node.type === "ContinueStatement") {
                        // Removes loop if it exists in the set. Otherwise, `Set#delete` has no effect and doesn't throw.
                        loopsToReport.delete(loop);
                    }
                },
                "Program:exit"() {
                    loopsToReport.forEach(node => context.report({ node, messageId: "invalid" }));
                }
            };
        }
    };
},
/* eslint/lib/rules/no-unsafe-finally.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag unsafe statements in finally block
     * @author Onur Temizkan
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const SENTINEL_NODE_TYPE_RETURN_THROW = /^(?:Program|(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression)$/u;
    const SENTINEL_NODE_TYPE_BREAK = /^(?:Program|(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression|DoWhileStatement|WhileStatement|ForOfStatement|ForInStatement|ForStatement|SwitchStatement)$/u;
    const SENTINEL_NODE_TYPE_CONTINUE = /^(?:Program|(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression|DoWhileStatement|WhileStatement|ForOfStatement|ForInStatement|ForStatement)$/u;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow control flow statements in `finally` blocks",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-unsafe-finally"
            },
            schema: [],
            messages: {
                unsafeUsage: "Unsafe usage of {{nodeType}}."
            }
        },
        create(context) {
            /**
             * Checks if the node is the finalizer of a TryStatement
             * @param {ASTNode} node node to check.
             * @returns {boolean} - true if the node is the finalizer of a TryStatement
             */
            function isFinallyBlock(node) {
                return node.parent.type === "TryStatement" && node.parent.finalizer === node;
            }
            /**
             * Climbs up the tree if the node is not a sentinel node
             * @param {ASTNode} node node to check.
             * @param {string} label label of the break or continue statement
             * @returns {boolean} - return whether the node is a finally block or a sentinel node
             */
            function isInFinallyBlock(node, label) {
                let labelInside = false;
                let sentinelNodeType;
                if (node.type === "BreakStatement" && !node.label) {
                    sentinelNodeType = SENTINEL_NODE_TYPE_BREAK;
                }
                else if (node.type === "ContinueStatement") {
                    sentinelNodeType = SENTINEL_NODE_TYPE_CONTINUE;
                }
                else {
                    sentinelNodeType = SENTINEL_NODE_TYPE_RETURN_THROW;
                }
                for (let currentNode = node; currentNode && !sentinelNodeType.test(currentNode.type); currentNode = currentNode.parent) {
                    if (currentNode.parent.label && label && (currentNode.parent.label.name === label.name)) {
                        labelInside = true;
                    }
                    if (isFinallyBlock(currentNode)) {
                        if (label && labelInside) {
                            return false;
                        }
                        return true;
                    }
                }
                return false;
            }
            /**
             * Checks whether the possibly-unsafe statement is inside a finally block.
             * @param {ASTNode} node node to check.
             * @returns {void}
             */
            function check(node) {
                if (isInFinallyBlock(node, node.label)) {
                    context.report({
                        messageId: "unsafeUsage",
                        data: {
                            nodeType: node.type
                        },
                        node,
                        line: node.loc.line,
                        column: node.loc.column
                    });
                }
            }
            return {
                ReturnStatement: check,
                ThrowStatement: check,
                BreakStatement: check,
                ContinueStatement: check
            };
        }
    };
},
/* eslint/lib/rules/no-unsafe-negation.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow negating the left operand of relational operators
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether the given operator is `in` or `instanceof`
     * @param {string} op The operator type to check.
     * @returns {boolean} `true` if the operator is `in` or `instanceof`
     */
    function isInOrInstanceOfOperator(op) {
        return op === "in" || op === "instanceof";
    }
    /**
     * Checks whether the given operator is an ordering relational operator or not.
     * @param {string} op The operator type to check.
     * @returns {boolean} `true` if the operator is an ordering relational operator.
     */
    function isOrderingRelationalOperator(op) {
        return op === "<" || op === ">" || op === ">=" || op === "<=";
    }
    /**
     * Checks whether the given node is a logical negation expression or not.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is a logical negation expression.
     */
    function isNegation(node) {
        return node.type === "UnaryExpression" && node.operator === "!";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow negating the left operand of relational operators",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-unsafe-negation"
            },
            hasSuggestions: true,
            schema: [
                {
                    type: "object",
                    properties: {
                        enforceForOrderingRelations: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: null,
            messages: {
                unexpected: "Unexpected negating the left operand of '{{operator}}' operator.",
                suggestNegatedExpression: "Negate '{{operator}}' expression instead of its left operand. This changes the current behavior.",
                suggestParenthesisedNegation: "Wrap negation in '()' to make the intention explicit. This preserves the current behavior."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const options = context.options[0] || {};
            const enforceForOrderingRelations = options.enforceForOrderingRelations === true;
            return {
                BinaryExpression(node) {
                    const operator = node.operator;
                    const orderingRelationRuleApplies = enforceForOrderingRelations && isOrderingRelationalOperator(operator);
                    if ((isInOrInstanceOfOperator(operator) || orderingRelationRuleApplies) &&
                        isNegation(node.left) &&
                        !astUtils.isParenthesised(sourceCode, node.left)) {
                        context.report({
                            node,
                            loc: node.left.loc,
                            messageId: "unexpected",
                            data: { operator },
                            suggest: [
                                {
                                    messageId: "suggestNegatedExpression",
                                    data: { operator },
                                    fix(fixer) {
                                        const negationToken = sourceCode.getFirstToken(node.left);
                                        const fixRange = [negationToken.range[1], node.range[1]];
                                        const text = sourceCode.text.slice(fixRange[0], fixRange[1]);
                                        return fixer.replaceTextRange(fixRange, `(${text})`);
                                    }
                                },
                                {
                                    messageId: "suggestParenthesisedNegation",
                                    fix(fixer) {
                                        return fixer.replaceText(node.left, `(${sourceCode.getText(node.left)})`);
                                    }
                                }
                            ]
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-unsafe-optional-chaining.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow unsafe optional chaining
     * @author Yeon JuAn
     */
    "use strict";
    const UNSAFE_ARITHMETIC_OPERATORS = new Set(["+", "-", "/", "*", "%", "**"]);
    const UNSAFE_ASSIGNMENT_OPERATORS = new Set(["+=", "-=", "/=", "*=", "%=", "**="]);
    const UNSAFE_RELATIONAL_OPERATORS = new Set(["in", "instanceof"]);
    /**
     * Checks whether a node is a destructuring pattern or not
     * @param {ASTNode} node node to check
     * @returns {boolean} `true` if a node is a destructuring pattern, otherwise `false`
     */
    function isDestructuringPattern(node) {
        return node.type === "ObjectPattern" || node.type === "ArrayPattern";
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow use of optional chaining in contexts where the `undefined` value is not allowed",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-unsafe-optional-chaining"
            },
            schema: [{
                    type: "object",
                    properties: {
                        disallowArithmeticOperators: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }],
            fixable: null,
            messages: {
                unsafeOptionalChain: "Unsafe usage of optional chaining. If it short-circuits with 'undefined' the evaluation will throw TypeError.",
                unsafeArithmetic: "Unsafe arithmetic operation on optional chaining. It can result in NaN."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const disallowArithmeticOperators = (options.disallowArithmeticOperators) || false;
            /**
             * Reports unsafe usage of optional chaining
             * @param {ASTNode} node node to report
             * @returns {void}
             */
            function reportUnsafeUsage(node) {
                context.report({
                    messageId: "unsafeOptionalChain",
                    node
                });
            }
            /**
             * Reports unsafe arithmetic operation on optional chaining
             * @param {ASTNode} node node to report
             * @returns {void}
             */
            function reportUnsafeArithmetic(node) {
                context.report({
                    messageId: "unsafeArithmetic",
                    node
                });
            }
            /**
             * Checks and reports if a node can short-circuit with `undefined` by optional chaining.
             * @param {ASTNode} [node] node to check
             * @param {Function} reportFunc report function
             * @returns {void}
             */
            function checkUndefinedShortCircuit(node, reportFunc) {
                if (!node) {
                    return;
                }
                switch (node.type) {
                    case "LogicalExpression":
                        if (node.operator === "||" || node.operator === "??") {
                            checkUndefinedShortCircuit(node.right, reportFunc);
                        }
                        else if (node.operator === "&&") {
                            checkUndefinedShortCircuit(node.left, reportFunc);
                            checkUndefinedShortCircuit(node.right, reportFunc);
                        }
                        break;
                    case "SequenceExpression":
                        checkUndefinedShortCircuit(node.expressions[node.expressions.length - 1], reportFunc);
                        break;
                    case "ConditionalExpression":
                        checkUndefinedShortCircuit(node.consequent, reportFunc);
                        checkUndefinedShortCircuit(node.alternate, reportFunc);
                        break;
                    case "AwaitExpression":
                        checkUndefinedShortCircuit(node.argument, reportFunc);
                        break;
                    case "ChainExpression":
                        reportFunc(node);
                        break;
                    default:
                        break;
                }
            }
            /**
             * Checks unsafe usage of optional chaining
             * @param {ASTNode} node node to check
             * @returns {void}
             */
            function checkUnsafeUsage(node) {
                checkUndefinedShortCircuit(node, reportUnsafeUsage);
            }
            /**
             * Checks unsafe arithmetic operations on optional chaining
             * @param {ASTNode} node node to check
             * @returns {void}
             */
            function checkUnsafeArithmetic(node) {
                checkUndefinedShortCircuit(node, reportUnsafeArithmetic);
            }
            return {
                "AssignmentExpression, AssignmentPattern"(node) {
                    if (isDestructuringPattern(node.left)) {
                        checkUnsafeUsage(node.right);
                    }
                },
                "ClassDeclaration, ClassExpression"(node) {
                    checkUnsafeUsage(node.superClass);
                },
                CallExpression(node) {
                    if (!node.optional) {
                        checkUnsafeUsage(node.callee);
                    }
                },
                NewExpression(node) {
                    checkUnsafeUsage(node.callee);
                },
                VariableDeclarator(node) {
                    if (isDestructuringPattern(node.id)) {
                        checkUnsafeUsage(node.init);
                    }
                },
                MemberExpression(node) {
                    if (!node.optional) {
                        checkUnsafeUsage(node.object);
                    }
                },
                TaggedTemplateExpression(node) {
                    checkUnsafeUsage(node.tag);
                },
                ForOfStatement(node) {
                    checkUnsafeUsage(node.right);
                },
                SpreadElement(node) {
                    if (node.parent && node.parent.type !== "ObjectExpression") {
                        checkUnsafeUsage(node.argument);
                    }
                },
                BinaryExpression(node) {
                    if (UNSAFE_RELATIONAL_OPERATORS.has(node.operator)) {
                        checkUnsafeUsage(node.right);
                    }
                    if (disallowArithmeticOperators &&
                        UNSAFE_ARITHMETIC_OPERATORS.has(node.operator)) {
                        checkUnsafeArithmetic(node.right);
                        checkUnsafeArithmetic(node.left);
                    }
                },
                WithStatement(node) {
                    checkUnsafeUsage(node.object);
                },
                UnaryExpression(node) {
                    if (disallowArithmeticOperators &&
                        UNSAFE_ARITHMETIC_OPERATORS.has(node.operator)) {
                        checkUnsafeArithmetic(node.argument);
                    }
                },
                AssignmentExpression(node) {
                    if (disallowArithmeticOperators &&
                        UNSAFE_ASSIGNMENT_OPERATORS.has(node.operator)) {
                        checkUnsafeArithmetic(node.right);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-unused-expressions.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Flag expressions in statement position that do not side effect
     * @author Michael Ficarra
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /**
     * Returns `true`.
     * @returns {boolean} `true`.
     */
    function alwaysTrue() {
        return true;
    }
    /**
     * Returns `false`.
     * @returns {boolean} `false`.
     */
    function alwaysFalse() {
        return false;
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unused expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-unused-expressions"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowShortCircuit: {
                            type: "boolean",
                            default: false
                        },
                        allowTernary: {
                            type: "boolean",
                            default: false
                        },
                        allowTaggedTemplates: {
                            type: "boolean",
                            default: false
                        },
                        enforceForJSX: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unusedExpression: "Expected an assignment or function call and instead saw an expression."
            }
        },
        create(context) {
            const config = context.options[0] || {}, allowShortCircuit = config.allowShortCircuit || false, allowTernary = config.allowTernary || false, allowTaggedTemplates = config.allowTaggedTemplates || false, enforceForJSX = config.enforceForJSX || false;
            /**
             * Has AST suggesting a directive.
             * @param {ASTNode} node any node
             * @returns {boolean} whether the given node structurally represents a directive
             */
            function looksLikeDirective(node) {
                return node.type === "ExpressionStatement" &&
                    node.expression.type === "Literal" && typeof node.expression.value === "string";
            }
            /**
             * Gets the leading sequence of members in a list that pass the predicate.
             * @param {Function} predicate ([a] -> Boolean) the function used to make the determination
             * @param {a[]} list the input list
             * @returns {a[]} the leading sequence of members in the given list that pass the given predicate
             */
            function takeWhile(predicate, list) {
                for (let i = 0; i < list.length; ++i) {
                    if (!predicate(list[i])) {
                        return list.slice(0, i);
                    }
                }
                return list.slice();
            }
            /**
             * Gets leading directives nodes in a Node body.
             * @param {ASTNode} node a Program or BlockStatement node
             * @returns {ASTNode[]} the leading sequence of directive nodes in the given node's body
             */
            function directives(node) {
                return takeWhile(looksLikeDirective, node.body);
            }
            /**
             * Detect if a Node is a directive.
             * @param {ASTNode} node any node
             * @param {ASTNode[]} ancestors the given node's ancestors
             * @returns {boolean} whether the given node is considered a directive in its current position
             */
            function isDirective(node, ancestors) {
                const parent = ancestors[ancestors.length - 1], grandparent = ancestors[ancestors.length - 2];
                /**
                 * https://tc39.es/ecma262/#directive-prologue
                 *
                 * Only `FunctionBody`, `ScriptBody` and `ModuleBody` can have directive prologue.
                 * Class static blocks do not have directive prologue.
                 */
                return (parent.type === "Program" || parent.type === "BlockStatement" &&
                    (/Function/u.test(grandparent.type))) &&
                    directives(parent).includes(node);
            }
            /**
             * The member functions return `true` if the type has no side-effects.
             * Unknown nodes are handled as `false`, then this rule ignores those.
             */
            const Checker = Object.assign(Object.create(null), {
                isDisallowed(node) {
                    return (Checker[node.type] || alwaysFalse)(node);
                },
                ArrayExpression: alwaysTrue,
                ArrowFunctionExpression: alwaysTrue,
                BinaryExpression: alwaysTrue,
                ChainExpression(node) {
                    return Checker.isDisallowed(node.expression);
                },
                ClassExpression: alwaysTrue,
                ConditionalExpression(node) {
                    if (allowTernary) {
                        return Checker.isDisallowed(node.consequent) || Checker.isDisallowed(node.alternate);
                    }
                    return true;
                },
                FunctionExpression: alwaysTrue,
                Identifier: alwaysTrue,
                JSXElement() {
                    return enforceForJSX;
                },
                JSXFragment() {
                    return enforceForJSX;
                },
                Literal: alwaysTrue,
                LogicalExpression(node) {
                    if (allowShortCircuit) {
                        return Checker.isDisallowed(node.right);
                    }
                    return true;
                },
                MemberExpression: alwaysTrue,
                MetaProperty: alwaysTrue,
                ObjectExpression: alwaysTrue,
                SequenceExpression: alwaysTrue,
                TaggedTemplateExpression() {
                    return !allowTaggedTemplates;
                },
                TemplateLiteral: alwaysTrue,
                ThisExpression: alwaysTrue,
                UnaryExpression(node) {
                    return node.operator !== "void" && node.operator !== "delete";
                }
            });
            return {
                ExpressionStatement(node) {
                    if (Checker.isDisallowed(node.expression) && !isDirective(node, context.getAncestors())) {
                        context.report({ node, messageId: "unusedExpression" });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-unused-labels.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow unused labels.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unused labels",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-unused-labels"
            },
            schema: [],
            fixable: "code",
            messages: {
                unused: "'{{name}}:' is defined but never used."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            let scopeInfo = null;
            /**
             * Adds a scope info to the stack.
             * @param {ASTNode} node A node to add. This is a LabeledStatement.
             * @returns {void}
             */
            function enterLabeledScope(node) {
                scopeInfo = {
                    label: node.label.name,
                    used: false,
                    upper: scopeInfo
                };
            }
            /**
             * Removes the top of the stack.
             * At the same time, this reports the label if it's never used.
             * @param {ASTNode} node A node to report. This is a LabeledStatement.
             * @returns {void}
             */
            function exitLabeledScope(node) {
                if (!scopeInfo.used) {
                    context.report({
                        node: node.label,
                        messageId: "unused",
                        data: node.label,
                        fix(fixer) {
                            /*
                             * Only perform a fix if there are no comments between the label and the body. This will be the case
                             * when there is exactly one token/comment (the ":") between the label and the body.
                             */
                            if (sourceCode.getTokenAfter(node.label, { includeComments: true }) ===
                                sourceCode.getTokenBefore(node.body, { includeComments: true })) {
                                return fixer.removeRange([node.range[0], node.body.range[0]]);
                            }
                            return null;
                        }
                    });
                }
                scopeInfo = scopeInfo.upper;
            }
            /**
             * Marks the label of a given node as used.
             * @param {ASTNode} node A node to mark. This is a BreakStatement or
             *      ContinueStatement.
             * @returns {void}
             */
            function markAsUsed(node) {
                if (!node.label) {
                    return;
                }
                const label = node.label.name;
                let info = scopeInfo;
                while (info) {
                    if (info.label === label) {
                        info.used = true;
                        break;
                    }
                    info = info.upper;
                }
            }
            return {
                LabeledStatement: enterLabeledScope,
                "LabeledStatement:exit": exitLabeledScope,
                BreakStatement: markAsUsed,
                ContinueStatement: markAsUsed
            };
        }
    };
},
/* eslint/lib/rules/no-unused-private-class-members.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag declared but unused private class members
     * @author Tim van der Lippe
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow unused private class members",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-unused-private-class-members"
            },
            schema: [],
            messages: {
                unusedPrivateClassMember: "'{{classMemberName}}' is defined but never used."
            }
        },
        create(context) {
            const trackedClasses = [];
            /**
             * Check whether the current node is in a write only assignment.
             * @param {ASTNode} privateIdentifierNode Node referring to a private identifier
             * @returns {boolean} Whether the node is in a write only assignment
             * @private
             */
            function isWriteOnlyAssignment(privateIdentifierNode) {
                const parentStatement = privateIdentifierNode.parent.parent;
                const isAssignmentExpression = parentStatement.type === "AssignmentExpression";
                if (!isAssignmentExpression &&
                    parentStatement.type !== "ForInStatement" &&
                    parentStatement.type !== "ForOfStatement" &&
                    parentStatement.type !== "AssignmentPattern") {
                    return false;
                }
                // It is a write-only usage, since we still allow usages on the right for reads
                if (parentStatement.left !== privateIdentifierNode.parent) {
                    return false;
                }
                // For any other operator (such as '+=') we still consider it a read operation
                if (isAssignmentExpression && parentStatement.operator !== "=") {
                    /*
                     * However, if the read operation is "discarded" in an empty statement, then
                     * we consider it write only.
                     */
                    return parentStatement.parent.type === "ExpressionStatement";
                }
                return true;
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                // Collect all declared members up front and assume they are all unused
                ClassBody(classBodyNode) {
                    const privateMembers = new Map();
                    trackedClasses.unshift(privateMembers);
                    for (const bodyMember of classBodyNode.body) {
                        if (bodyMember.type === "PropertyDefinition" || bodyMember.type === "MethodDefinition") {
                            if (bodyMember.key.type === "PrivateIdentifier") {
                                privateMembers.set(bodyMember.key.name, {
                                    declaredNode: bodyMember,
                                    isAccessor: bodyMember.type === "MethodDefinition" &&
                                        (bodyMember.kind === "set" || bodyMember.kind === "get")
                                });
                            }
                        }
                    }
                },
                /*
                 * Process all usages of the private identifier and remove a member from
                 * `declaredAndUnusedPrivateMembers` if we deem it used.
                 */
                PrivateIdentifier(privateIdentifierNode) {
                    const classBody = trackedClasses.find(classProperties => classProperties.has(privateIdentifierNode.name));
                    // Can't happen, as it is a parser to have a missing class body, but let's code defensively here.
                    if (!classBody) {
                        return;
                    }
                    // In case any other usage was already detected, we can short circuit the logic here.
                    const memberDefinition = classBody.get(privateIdentifierNode.name);
                    if (memberDefinition.isUsed) {
                        return;
                    }
                    // The definition of the class member itself
                    if (privateIdentifierNode.parent.type === "PropertyDefinition" ||
                        privateIdentifierNode.parent.type === "MethodDefinition") {
                        return;
                    }
                    /*
                     * Any usage of an accessor is considered a read, as the getter/setter can have
                     * side-effects in its definition.
                     */
                    if (memberDefinition.isAccessor) {
                        memberDefinition.isUsed = true;
                        return;
                    }
                    // Any assignments to this member, except for assignments that also read
                    if (isWriteOnlyAssignment(privateIdentifierNode)) {
                        return;
                    }
                    const wrappingExpressionType = privateIdentifierNode.parent.parent.type;
                    const parentOfWrappingExpressionType = privateIdentifierNode.parent.parent.parent.type;
                    // A statement which only increments (`this.#x++;`)
                    if (wrappingExpressionType === "UpdateExpression" &&
                        parentOfWrappingExpressionType === "ExpressionStatement") {
                        return;
                    }
                    /*
                     * ({ x: this.#usedInDestructuring } = bar);
                     *
                     * But should treat the following as a read:
                     * ({ [this.#x]: a } = foo);
                     */
                    if (wrappingExpressionType === "Property" &&
                        parentOfWrappingExpressionType === "ObjectPattern" &&
                        privateIdentifierNode.parent.parent.value === privateIdentifierNode.parent) {
                        return;
                    }
                    // [...this.#unusedInRestPattern] = bar;
                    if (wrappingExpressionType === "RestElement") {
                        return;
                    }
                    // [this.#unusedInAssignmentPattern] = bar;
                    if (wrappingExpressionType === "ArrayPattern") {
                        return;
                    }
                    /*
                     * We can't delete the memberDefinition, as we need to keep track of which member we are marking as used.
                     * In the case of nested classes, we only mark the first member we encounter as used. If you were to delete
                     * the member, then any subsequent usage could incorrectly mark the member of an encapsulating parent class
                     * as used, which is incorrect.
                     */
                    memberDefinition.isUsed = true;
                },
                /*
                 * Post-process the class members and report any remaining members.
                 * Since private members can only be accessed in the current class context,
                 * we can safely assume that all usages are within the current class body.
                 */
                "ClassBody:exit"() {
                    const unusedPrivateMembers = trackedClasses.shift();
                    for (const [classMemberName, { declaredNode, isUsed }] of unusedPrivateMembers.entries()) {
                        if (isUsed) {
                            continue;
                        }
                        context.report({
                            node: declaredNode,
                            loc: declaredNode.key.loc,
                            messageId: "unusedPrivateClassMember",
                            data: {
                                classMemberName: `#${classMemberName}`
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-unused-vars.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag declared but unused variables
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /**
     * Bag of data used for formatting the `unusedVar` lint message.
     * @typedef {Object} UnusedVarMessageData
     * @property {string} varName The name of the unused var.
     * @property {'defined'|'assigned a value'} action Description of the vars state.
     * @property {string} additional Any additional info to be appended at the end.
     */
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow unused variables",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-unused-vars"
            },
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["all", "local"]
                        },
                        {
                            type: "object",
                            properties: {
                                vars: {
                                    enum: ["all", "local"]
                                },
                                varsIgnorePattern: {
                                    type: "string"
                                },
                                args: {
                                    enum: ["all", "after-used", "none"]
                                },
                                ignoreRestSiblings: {
                                    type: "boolean"
                                },
                                argsIgnorePattern: {
                                    type: "string"
                                },
                                caughtErrors: {
                                    enum: ["all", "none"]
                                },
                                caughtErrorsIgnorePattern: {
                                    type: "string"
                                },
                                destructuredArrayIgnorePattern: {
                                    type: "string"
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                unusedVar: "'{{varName}}' is {{action}} but never used{{additional}}."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const REST_PROPERTY_TYPE = /^(?:RestElement|(?:Experimental)?RestProperty)$/u;
            const config = {
                vars: "all",
                args: "after-used",
                ignoreRestSiblings: false,
                caughtErrors: "none"
            };
            const firstOption = context.options[0];
            if (firstOption) {
                if (typeof firstOption === "string") {
                    config.vars = firstOption;
                }
                else {
                    config.vars = firstOption.vars || config.vars;
                    config.args = firstOption.args || config.args;
                    config.ignoreRestSiblings = firstOption.ignoreRestSiblings || config.ignoreRestSiblings;
                    config.caughtErrors = firstOption.caughtErrors || config.caughtErrors;
                    if (firstOption.varsIgnorePattern) {
                        config.varsIgnorePattern = new RegExp(firstOption.varsIgnorePattern, "u");
                    }
                    if (firstOption.argsIgnorePattern) {
                        config.argsIgnorePattern = new RegExp(firstOption.argsIgnorePattern, "u");
                    }
                    if (firstOption.caughtErrorsIgnorePattern) {
                        config.caughtErrorsIgnorePattern = new RegExp(firstOption.caughtErrorsIgnorePattern, "u");
                    }
                    if (firstOption.destructuredArrayIgnorePattern) {
                        config.destructuredArrayIgnorePattern = new RegExp(firstOption.destructuredArrayIgnorePattern, "u");
                    }
                }
            }
            /**
             * Generates the message data about the variable being defined and unused,
             * including the ignore pattern if configured.
             * @param {Variable} unusedVar eslint-scope variable object.
             * @returns {UnusedVarMessageData} The message data to be used with this unused variable.
             */
            function getDefinedMessageData(unusedVar) {
                const defType = unusedVar.defs && unusedVar.defs[0] && unusedVar.defs[0].type;
                let type;
                let pattern;
                if (defType === "CatchClause" && config.caughtErrorsIgnorePattern) {
                    type = "args";
                    pattern = config.caughtErrorsIgnorePattern.toString();
                }
                else if (defType === "Parameter" && config.argsIgnorePattern) {
                    type = "args";
                    pattern = config.argsIgnorePattern.toString();
                }
                else if (defType !== "Parameter" && config.varsIgnorePattern) {
                    type = "vars";
                    pattern = config.varsIgnorePattern.toString();
                }
                const additional = type ? `. Allowed unused ${type} must match ${pattern}` : "";
                return {
                    varName: unusedVar.name,
                    action: "defined",
                    additional
                };
            }
            /**
             * Generate the warning message about the variable being
             * assigned and unused, including the ignore pattern if configured.
             * @param {Variable} unusedVar eslint-scope variable object.
             * @returns {UnusedVarMessageData} The message data to be used with this unused variable.
             */
            function getAssignedMessageData(unusedVar) {
                const def = unusedVar.defs[0];
                let additional = "";
                if (config.destructuredArrayIgnorePattern && def && def.name.parent.type === "ArrayPattern") {
                    additional = `. Allowed unused elements of array destructuring patterns must match ${config.destructuredArrayIgnorePattern.toString()}`;
                }
                else if (config.varsIgnorePattern) {
                    additional = `. Allowed unused vars must match ${config.varsIgnorePattern.toString()}`;
                }
                return {
                    varName: unusedVar.name,
                    action: "assigned a value",
                    additional
                };
            }
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            const STATEMENT_TYPE = /(?:Statement|Declaration)$/u;
            /**
             * Determines if a given variable is being exported from a module.
             * @param {Variable} variable eslint-scope variable object.
             * @returns {boolean} True if the variable is exported, false if not.
             * @private
             */
            function isExported(variable) {
                const definition = variable.defs[0];
                if (definition) {
                    let node = definition.node;
                    if (node.type === "VariableDeclarator") {
                        node = node.parent;
                    }
                    else if (definition.type === "Parameter") {
                        return false;
                    }
                    return node.parent.type.indexOf("Export") === 0;
                }
                return false;
            }
            /**
             * Checks whether a node is a sibling of the rest property or not.
             * @param {ASTNode} node a node to check
             * @returns {boolean} True if the node is a sibling of the rest property, otherwise false.
             */
            function hasRestSibling(node) {
                return node.type === "Property" &&
                    node.parent.type === "ObjectPattern" &&
                    REST_PROPERTY_TYPE.test(node.parent.properties[node.parent.properties.length - 1].type);
            }
            /**
             * Determines if a variable has a sibling rest property
             * @param {Variable} variable eslint-scope variable object.
             * @returns {boolean} True if the variable is exported, false if not.
             * @private
             */
            function hasRestSpreadSibling(variable) {
                if (config.ignoreRestSiblings) {
                    const hasRestSiblingDefinition = variable.defs.some(def => hasRestSibling(def.name.parent));
                    const hasRestSiblingReference = variable.references.some(ref => hasRestSibling(ref.identifier.parent));
                    return hasRestSiblingDefinition || hasRestSiblingReference;
                }
                return false;
            }
            /**
             * Determines if a reference is a read operation.
             * @param {Reference} ref An eslint-scope Reference
             * @returns {boolean} whether the given reference represents a read operation
             * @private
             */
            function isReadRef(ref) {
                return ref.isRead();
            }
            /**
             * Determine if an identifier is referencing an enclosing function name.
             * @param {Reference} ref The reference to check.
             * @param {ASTNode[]} nodes The candidate function nodes.
             * @returns {boolean} True if it's a self-reference, false if not.
             * @private
             */
            function isSelfReference(ref, nodes) {
                let scope = ref.from;
                while (scope) {
                    if (nodes.includes(scope.block)) {
                        return true;
                    }
                    scope = scope.upper;
                }
                return false;
            }
            /**
             * Gets a list of function definitions for a specified variable.
             * @param {Variable} variable eslint-scope variable object.
             * @returns {ASTNode[]} Function nodes.
             * @private
             */
            function getFunctionDefinitions(variable) {
                const functionDefinitions = [];
                variable.defs.forEach(def => {
                    const { type, node } = def;
                    // FunctionDeclarations
                    if (type === "FunctionName") {
                        functionDefinitions.push(node);
                    }
                    // FunctionExpressions
                    if (type === "Variable" && node.init &&
                        (node.init.type === "FunctionExpression" || node.init.type === "ArrowFunctionExpression")) {
                        functionDefinitions.push(node.init);
                    }
                });
                return functionDefinitions;
            }
            /**
             * Checks the position of given nodes.
             * @param {ASTNode} inner A node which is expected as inside.
             * @param {ASTNode} outer A node which is expected as outside.
             * @returns {boolean} `true` if the `inner` node exists in the `outer` node.
             * @private
             */
            function isInside(inner, outer) {
                return (inner.range[0] >= outer.range[0] &&
                    inner.range[1] <= outer.range[1]);
            }
            /**
             * Checks whether a given node is unused expression or not.
             * @param {ASTNode} node The node itself
             * @returns {boolean} The node is an unused expression.
             * @private
             */
            function isUnusedExpression(node) {
                const parent = node.parent;
                if (parent.type === "ExpressionStatement") {
                    return true;
                }
                if (parent.type === "SequenceExpression") {
                    const isLastExpression = parent.expressions[parent.expressions.length - 1] === node;
                    if (!isLastExpression) {
                        return true;
                    }
                    return isUnusedExpression(parent);
                }
                return false;
            }
            /**
             * If a given reference is left-hand side of an assignment, this gets
             * the right-hand side node of the assignment.
             *
             * In the following cases, this returns null.
             *
             * - The reference is not the LHS of an assignment expression.
             * - The reference is inside of a loop.
             * - The reference is inside of a function scope which is different from
             *   the declaration.
             * @param {eslint-scope.Reference} ref A reference to check.
             * @param {ASTNode} prevRhsNode The previous RHS node.
             * @returns {ASTNode|null} The RHS node or null.
             * @private
             */
            function getRhsNode(ref, prevRhsNode) {
                const id = ref.identifier;
                const parent = id.parent;
                const refScope = ref.from.variableScope;
                const varScope = ref.resolved.scope.variableScope;
                const canBeUsedLater = refScope !== varScope || astUtils.isInLoop(id);
                /*
                 * Inherits the previous node if this reference is in the node.
                 * This is for `a = a + a`-like code.
                 */
                if (prevRhsNode && isInside(id, prevRhsNode)) {
                    return prevRhsNode;
                }
                if (parent.type === "AssignmentExpression" &&
                    isUnusedExpression(parent) &&
                    id === parent.left &&
                    !canBeUsedLater) {
                    return parent.right;
                }
                return null;
            }
            /**
             * Checks whether a given function node is stored to somewhere or not.
             * If the function node is stored, the function can be used later.
             * @param {ASTNode} funcNode A function node to check.
             * @param {ASTNode} rhsNode The RHS node of the previous assignment.
             * @returns {boolean} `true` if under the following conditions:
             *      - the funcNode is assigned to a variable.
             *      - the funcNode is bound as an argument of a function call.
             *      - the function is bound to a property and the object satisfies above conditions.
             * @private
             */
            function isStorableFunction(funcNode, rhsNode) {
                let node = funcNode;
                let parent = funcNode.parent;
                while (parent && isInside(parent, rhsNode)) {
                    switch (parent.type) {
                        case "SequenceExpression":
                            if (parent.expressions[parent.expressions.length - 1] !== node) {
                                return false;
                            }
                            break;
                        case "CallExpression":
                        case "NewExpression":
                            return parent.callee !== node;
                        case "AssignmentExpression":
                        case "TaggedTemplateExpression":
                        case "YieldExpression":
                            return true;
                        default:
                            if (STATEMENT_TYPE.test(parent.type)) {
                                /*
                                 * If it encountered statements, this is a complex pattern.
                                 * Since analyzing complex patterns is hard, this returns `true` to avoid false positive.
                                 */
                                return true;
                            }
                    }
                    node = parent;
                    parent = parent.parent;
                }
                return false;
            }
            /**
             * Checks whether a given Identifier node exists inside of a function node which can be used later.
             *
             * "can be used later" means:
             * - the function is assigned to a variable.
             * - the function is bound to a property and the object can be used later.
             * - the function is bound as an argument of a function call.
             *
             * If a reference exists in a function which can be used later, the reference is read when the function is called.
             * @param {ASTNode} id An Identifier node to check.
             * @param {ASTNode} rhsNode The RHS node of the previous assignment.
             * @returns {boolean} `true` if the `id` node exists inside of a function node which can be used later.
             * @private
             */
            function isInsideOfStorableFunction(id, rhsNode) {
                const funcNode = astUtils.getUpperFunction(id);
                return (funcNode &&
                    isInside(funcNode, rhsNode) &&
                    isStorableFunction(funcNode, rhsNode));
            }
            /**
             * Checks whether a given reference is a read to update itself or not.
             * @param {eslint-scope.Reference} ref A reference to check.
             * @param {ASTNode} rhsNode The RHS node of the previous assignment.
             * @returns {boolean} The reference is a read to update itself.
             * @private
             */
            function isReadForItself(ref, rhsNode) {
                const id = ref.identifier;
                const parent = id.parent;
                return ref.isRead() && (
                // self update. e.g. `a += 1`, `a++`
                ((parent.type === "AssignmentExpression" &&
                    parent.left === id &&
                    isUnusedExpression(parent)) ||
                    (parent.type === "UpdateExpression" &&
                        isUnusedExpression(parent))) ||
                    // in RHS of an assignment for itself. e.g. `a = a + 1`
                    (rhsNode &&
                        isInside(id, rhsNode) &&
                        !isInsideOfStorableFunction(id, rhsNode)));
            }
            /**
             * Determine if an identifier is used either in for-in or for-of loops.
             * @param {Reference} ref The reference to check.
             * @returns {boolean} whether reference is used in the for-in loops
             * @private
             */
            function isForInOfRef(ref) {
                let target = ref.identifier.parent;
                // "for (var ...) { return; }"
                if (target.type === "VariableDeclarator") {
                    target = target.parent.parent;
                }
                if (target.type !== "ForInStatement" && target.type !== "ForOfStatement") {
                    return false;
                }
                // "for (...) { return; }"
                if (target.body.type === "BlockStatement") {
                    target = target.body.body[0];
                    // "for (...) return;"
                }
                else {
                    target = target.body;
                }
                // For empty loop body
                if (!target) {
                    return false;
                }
                return target.type === "ReturnStatement";
            }
            /**
             * Determines if the variable is used.
             * @param {Variable} variable The variable to check.
             * @returns {boolean} True if the variable is used
             * @private
             */
            function isUsedVariable(variable) {
                const functionNodes = getFunctionDefinitions(variable), isFunctionDefinition = functionNodes.length > 0;
                let rhsNode = null;
                return variable.references.some(ref => {
                    if (isForInOfRef(ref)) {
                        return true;
                    }
                    const forItself = isReadForItself(ref, rhsNode);
                    rhsNode = getRhsNode(ref, rhsNode);
                    return (isReadRef(ref) &&
                        !forItself &&
                        !(isFunctionDefinition && isSelfReference(ref, functionNodes)));
                });
            }
            /**
             * Checks whether the given variable is after the last used parameter.
             * @param {eslint-scope.Variable} variable The variable to check.
             * @returns {boolean} `true` if the variable is defined after the last
             * used parameter.
             */
            function isAfterLastUsedArg(variable) {
                const def = variable.defs[0];
                const params = context.getDeclaredVariables(def.node);
                const posteriorParams = params.slice(params.indexOf(variable) + 1);
                // If any used parameters occur after this parameter, do not report.
                return !posteriorParams.some(v => v.references.length > 0 || v.eslintUsed);
            }
            /**
             * Gets an array of variables without read references.
             * @param {Scope} scope an eslint-scope Scope object.
             * @param {Variable[]} unusedVars an array that saving result.
             * @returns {Variable[]} unused variables of the scope and descendant scopes.
             * @private
             */
            function collectUnusedVariables(scope, unusedVars) {
                const variables = scope.variables;
                const childScopes = scope.childScopes;
                let i, l;
                if (scope.type !== "global" || config.vars === "all") {
                    for (i = 0, l = variables.length; i < l; ++i) {
                        const variable = variables[i];
                        // skip a variable of class itself name in the class scope
                        if (scope.type === "class" && scope.block.id === variable.identifiers[0]) {
                            continue;
                        }
                        // skip function expression names and variables marked with markVariableAsUsed()
                        if (scope.functionExpressionScope || variable.eslintUsed) {
                            continue;
                        }
                        // skip implicit "arguments" variable
                        if (scope.type === "function" && variable.name === "arguments" && variable.identifiers.length === 0) {
                            continue;
                        }
                        // explicit global variables don't have definitions.
                        const def = variable.defs[0];
                        if (def) {
                            const type = def.type;
                            const refUsedInArrayPatterns = variable.references.some(ref => ref.identifier.parent.type === "ArrayPattern");
                            // skip elements of array destructuring patterns
                            if ((def.name.parent.type === "ArrayPattern" ||
                                refUsedInArrayPatterns) &&
                                config.destructuredArrayIgnorePattern &&
                                config.destructuredArrayIgnorePattern.test(def.name.name)) {
                                continue;
                            }
                            // skip catch variables
                            if (type === "CatchClause") {
                                if (config.caughtErrors === "none") {
                                    continue;
                                }
                                // skip ignored parameters
                                if (config.caughtErrorsIgnorePattern && config.caughtErrorsIgnorePattern.test(def.name.name)) {
                                    continue;
                                }
                            }
                            if (type === "Parameter") {
                                // skip any setter argument
                                if ((def.node.parent.type === "Property" || def.node.parent.type === "MethodDefinition") && def.node.parent.kind === "set") {
                                    continue;
                                }
                                // if "args" option is "none", skip any parameter
                                if (config.args === "none") {
                                    continue;
                                }
                                // skip ignored parameters
                                if (config.argsIgnorePattern && config.argsIgnorePattern.test(def.name.name)) {
                                    continue;
                                }
                                // if "args" option is "after-used", skip used variables
                                if (config.args === "after-used" && astUtils.isFunction(def.name.parent) && !isAfterLastUsedArg(variable)) {
                                    continue;
                                }
                            }
                            else {
                                // skip ignored variables
                                if (config.varsIgnorePattern && config.varsIgnorePattern.test(def.name.name)) {
                                    continue;
                                }
                            }
                        }
                        if (!isUsedVariable(variable) && !isExported(variable) && !hasRestSpreadSibling(variable)) {
                            unusedVars.push(variable);
                        }
                    }
                }
                for (i = 0, l = childScopes.length; i < l; ++i) {
                    collectUnusedVariables(childScopes[i], unusedVars);
                }
                return unusedVars;
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                "Program:exit"(programNode) {
                    const unusedVars = collectUnusedVariables(context.getScope(), []);
                    for (let i = 0, l = unusedVars.length; i < l; ++i) {
                        const unusedVar = unusedVars[i];
                        // Report the first declaration.
                        if (unusedVar.defs.length > 0) {
                            // report last write reference, https://github.com/eslint/eslint/issues/14324
                            const writeReferences = unusedVar.references.filter(ref => ref.isWrite() && ref.from.variableScope === unusedVar.scope.variableScope);
                            let referenceToReport;
                            if (writeReferences.length > 0) {
                                referenceToReport = writeReferences[writeReferences.length - 1];
                            }
                            context.report({
                                node: referenceToReport ? referenceToReport.identifier : unusedVar.identifiers[0],
                                messageId: "unusedVar",
                                data: unusedVar.references.some(ref => ref.isWrite())
                                    ? getAssignedMessageData(unusedVar)
                                    : getDefinedMessageData(unusedVar)
                            });
                            // If there are no regular declaration, report the first `/*globals*/` comment directive.
                        }
                        else if (unusedVar.eslintExplicitGlobalComments) {
                            const directiveComment = unusedVar.eslintExplicitGlobalComments[0];
                            context.report({
                                node: programNode,
                                loc: astUtils.getNameLocationInGlobalDirectiveComment(sourceCode, directiveComment, unusedVar.name),
                                messageId: "unusedVar",
                                data: getDefinedMessageData(unusedVar)
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-use-before-define.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of variables before they are defined
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const SENTINEL_TYPE = /^(?:(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression|CatchClause|ImportDeclaration|ExportNamedDeclaration)$/u;
    const FOR_IN_OF_TYPE = /^For(?:In|Of)Statement$/u;
    /**
     * Parses a given value as options.
     * @param {any} options A value to parse.
     * @returns {Object} The parsed options.
     */
    function parseOptions(options) {
        let functions = true;
        let classes = true;
        let variables = true;
        let allowNamedExports = false;
        if (typeof options === "string") {
            functions = (options !== "nofunc");
        }
        else if (typeof options === "object" && options !== null) {
            functions = options.functions !== false;
            classes = options.classes !== false;
            variables = options.variables !== false;
            allowNamedExports = !!options.allowNamedExports;
        }
        return { functions, classes, variables, allowNamedExports };
    }
    /**
     * Checks whether or not a given location is inside of the range of a given node.
     * @param {ASTNode} node An node to check.
     * @param {number} location A location to check.
     * @returns {boolean} `true` if the location is inside of the range of the node.
     */
    function isInRange(node, location) {
        return node && node.range[0] <= location && location <= node.range[1];
    }
    /**
     * Checks whether or not a given location is inside of the range of a class static initializer.
     * Static initializers are static blocks and initializers of static fields.
     * @param {ASTNode} node `ClassBody` node to check static initializers.
     * @param {number} location A location to check.
     * @returns {boolean} `true` if the location is inside of a class static initializer.
     */
    function isInClassStaticInitializerRange(node, location) {
        return node.body.some(classMember => ((classMember.type === "StaticBlock" &&
            isInRange(classMember, location)) ||
            (classMember.type === "PropertyDefinition" &&
                classMember.static &&
                classMember.value &&
                isInRange(classMember.value, location))));
    }
    /**
     * Checks whether a given scope is the scope of a class static initializer.
     * Static initializers are static blocks and initializers of static fields.
     * @param {eslint-scope.Scope} scope A scope to check.
     * @returns {boolean} `true` if the scope is a class static initializer scope.
     */
    function isClassStaticInitializerScope(scope) {
        if (scope.type === "class-static-block") {
            return true;
        }
        if (scope.type === "class-field-initializer") {
            // `scope.block` is PropertyDefinition#value node
            const propertyDefinition = scope.block.parent;
            return propertyDefinition.static;
        }
        return false;
    }
    /**
     * Checks whether a given reference is evaluated in an execution context
     * that isn't the one where the variable it refers to is defined.
     * Execution contexts are:
     * - top-level
     * - functions
     * - class field initializers (implicit functions)
     * - class static blocks (implicit functions)
     * Static class field initializers and class static blocks are automatically run during the class definition evaluation,
     * and therefore we'll consider them as a part of the parent execution context.
     * Example:
     *
     *   const x = 1;
     *
     *   x; // returns `false`
     *   () => x; // returns `true`
     *
     *   class C {
     *       field = x; // returns `true`
     *       static field = x; // returns `false`
     *
     *       method() {
     *           x; // returns `true`
     *       }
     *
     *       static method() {
     *           x; // returns `true`
     *       }
     *
     *       static {
     *           x; // returns `false`
     *       }
     *   }
     * @param {eslint-scope.Reference} reference A reference to check.
     * @returns {boolean} `true` if the reference is from a separate execution context.
     */
    function isFromSeparateExecutionContext(reference) {
        const variable = reference.resolved;
        let scope = reference.from;
        // Scope#variableScope represents execution context
        while (variable.scope.variableScope !== scope.variableScope) {
            if (isClassStaticInitializerScope(scope.variableScope)) {
                scope = scope.variableScope.upper;
            }
            else {
                return true;
            }
        }
        return false;
    }
    /**
     * Checks whether or not a given reference is evaluated during the initialization of its variable.
     *
     * This returns `true` in the following cases:
     *
     *     var a = a
     *     var [a = a] = list
     *     var {a = a} = obj
     *     for (var a in a) {}
     *     for (var a of a) {}
     *     var C = class { [C]; };
     *     var C = class { static foo = C; };
     *     var C = class { static { foo = C; } };
     *     class C extends C {}
     *     class C extends (class { static foo = C; }) {}
     *     class C { [C]; }
     * @param {Reference} reference A reference to check.
     * @returns {boolean} `true` if the reference is evaluated during the initialization.
     */
    function isEvaluatedDuringInitialization(reference) {
        if (isFromSeparateExecutionContext(reference)) {
            /*
             * Even if the reference appears in the initializer, it isn't evaluated during the initialization.
             * For example, `const x = () => x;` is valid.
             */
            return false;
        }
        const location = reference.identifier.range[1];
        const definition = reference.resolved.defs[0];
        if (definition.type === "ClassName") {
            // `ClassDeclaration` or `ClassExpression`
            const classDefinition = definition.node;
            return (isInRange(classDefinition, location) &&
                /*
                 * Class binding is initialized before running static initializers.
                 * For example, `class C { static foo = C; static { bar = C; } }` is valid.
                 */
                !isInClassStaticInitializerRange(classDefinition.body, location));
        }
        let node = definition.name.parent;
        while (node) {
            if (node.type === "VariableDeclarator") {
                if (isInRange(node.init, location)) {
                    return true;
                }
                if (FOR_IN_OF_TYPE.test(node.parent.parent.type) &&
                    isInRange(node.parent.parent.right, location)) {
                    return true;
                }
                break;
            }
            else if (node.type === "AssignmentPattern") {
                if (isInRange(node.right, location)) {
                    return true;
                }
            }
            else if (SENTINEL_TYPE.test(node.type)) {
                break;
            }
            node = node.parent;
        }
        return false;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow the use of variables before they are defined",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-use-before-define"
            },
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["nofunc"]
                        },
                        {
                            type: "object",
                            properties: {
                                functions: { type: "boolean" },
                                classes: { type: "boolean" },
                                variables: { type: "boolean" },
                                allowNamedExports: { type: "boolean" }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                usedBeforeDefined: "'{{name}}' was used before it was defined."
            }
        },
        create(context) {
            const options = parseOptions(context.options[0]);
            /**
             * Determines whether a given reference should be checked.
             *
             * Returns `false` if the reference is:
             * - initialization's (e.g., `let a = 1`).
             * - referring to an undefined variable (i.e., if it's an unresolved reference).
             * - referring to a variable that is defined, but not in the given source code
             *   (e.g., global environment variable or `arguments` in functions).
             * - allowed by options.
             * @param {eslint-scope.Reference} reference The reference
             * @returns {boolean} `true` if the reference should be checked
             */
            function shouldCheck(reference) {
                if (reference.init) {
                    return false;
                }
                const { identifier } = reference;
                if (options.allowNamedExports &&
                    identifier.parent.type === "ExportSpecifier" &&
                    identifier.parent.local === identifier) {
                    return false;
                }
                const variable = reference.resolved;
                if (!variable || variable.defs.length === 0) {
                    return false;
                }
                const definitionType = variable.defs[0].type;
                if (!options.functions && definitionType === "FunctionName") {
                    return false;
                }
                if ((!options.variables && definitionType === "Variable" ||
                    !options.classes && definitionType === "ClassName") &&
                    // don't skip checking the reference if it's in the same execution context, because of TDZ
                    isFromSeparateExecutionContext(reference)) {
                    return false;
                }
                return true;
            }
            /**
             * Finds and validates all references in a given scope and its child scopes.
             * @param {eslint-scope.Scope} scope The scope object.
             * @returns {void}
             */
            function checkReferencesInScope(scope) {
                scope.references.filter(shouldCheck).forEach(reference => {
                    const variable = reference.resolved;
                    const definitionIdentifier = variable.defs[0].name;
                    if (reference.identifier.range[1] < definitionIdentifier.range[1] ||
                        isEvaluatedDuringInitialization(reference)) {
                        context.report({
                            node: reference.identifier,
                            messageId: "usedBeforeDefined",
                            data: reference.identifier
                        });
                    }
                });
                scope.childScopes.forEach(checkReferencesInScope);
            }
            return {
                Program() {
                    checkReferencesInScope(context.getScope());
                }
            };
        }
    };
},
/* eslint/lib/rules/no-useless-backreference.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow useless backreferences in regular expressions
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { CALL, CONSTRUCT, ReferenceTracker, getStringIfConstant } = require(316) /* @eslint-community/eslint-utils */;
    const { RegExpParser, visitRegExpAST } = require(485) /* @eslint-community/regexpp */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const parser = new RegExpParser();
    /**
     * Finds the path from the given `regexpp` AST node to the root node.
     * @param {regexpp.Node} node Node.
     * @returns {regexpp.Node[]} Array that starts with the given node and ends with the root node.
     */
    function getPathToRoot(node) {
        const path = [];
        let current = node;
        do {
            path.push(current);
            current = current.parent;
        } while (current);
        return path;
    }
    /**
     * Determines whether the given `regexpp` AST node is a lookaround node.
     * @param {regexpp.Node} node Node.
     * @returns {boolean} `true` if it is a lookaround node.
     */
    function isLookaround(node) {
        return node.type === "Assertion" &&
            (node.kind === "lookahead" || node.kind === "lookbehind");
    }
    /**
     * Determines whether the given `regexpp` AST node is a negative lookaround node.
     * @param {regexpp.Node} node Node.
     * @returns {boolean} `true` if it is a negative lookaround node.
     */
    function isNegativeLookaround(node) {
        return isLookaround(node) && node.negate;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow useless backreferences in regular expressions",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-useless-backreference"
            },
            schema: [],
            messages: {
                nested: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' from within that group.",
                forward: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' which appears later in the pattern.",
                backward: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' which appears before in the same lookbehind.",
                disjunctive: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' which is in another alternative.",
                intoNegativeLookaround: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' which is in a negative lookaround."
            }
        },
        create(context) {
            /**
             * Checks and reports useless backreferences in the given regular expression.
             * @param {ASTNode} node Node that represents regular expression. A regex literal or RegExp constructor call.
             * @param {string} pattern Regular expression pattern.
             * @param {string} flags Regular expression flags.
             * @returns {void}
             */
            function checkRegex(node, pattern, flags) {
                let regExpAST;
                try {
                    regExpAST = parser.parsePattern(pattern, 0, pattern.length, flags.includes("u"));
                }
                catch {
                    // Ignore regular expressions with syntax errors
                    return;
                }
                visitRegExpAST(regExpAST, {
                    onBackreferenceEnter(bref) {
                        const group = bref.resolved, brefPath = getPathToRoot(bref), groupPath = getPathToRoot(group);
                        let messageId = null;
                        if (brefPath.includes(group)) {
                            // group is bref's ancestor => bref is nested ('nested reference') => group hasn't matched yet when bref starts to match.
                            messageId = "nested";
                        }
                        else {
                            // Start from the root to find the lowest common ancestor.
                            let i = brefPath.length - 1, j = groupPath.length - 1;
                            do {
                                i--;
                                j--;
                            } while (brefPath[i] === groupPath[j]);
                            const indexOfLowestCommonAncestor = j + 1, groupCut = groupPath.slice(0, indexOfLowestCommonAncestor), commonPath = groupPath.slice(indexOfLowestCommonAncestor), lowestCommonLookaround = commonPath.find(isLookaround), isMatchingBackward = lowestCommonLookaround && lowestCommonLookaround.kind === "lookbehind";
                            if (!isMatchingBackward && bref.end <= group.start) {
                                // bref is left, group is right ('forward reference') => group hasn't matched yet when bref starts to match.
                                messageId = "forward";
                            }
                            else if (isMatchingBackward && group.end <= bref.start) {
                                // the opposite of the previous when the regex is matching backward in a lookbehind context.
                                messageId = "backward";
                            }
                            else if (groupCut[groupCut.length - 1].type === "Alternative") {
                                // group's and bref's ancestor nodes below the lowest common ancestor are sibling alternatives => they're disjunctive.
                                messageId = "disjunctive";
                            }
                            else if (groupCut.some(isNegativeLookaround)) {
                                // group is in a negative lookaround which isn't bref's ancestor => group has already failed when bref starts to match.
                                messageId = "intoNegativeLookaround";
                            }
                        }
                        if (messageId) {
                            context.report({
                                node,
                                messageId,
                                data: {
                                    bref: bref.raw,
                                    group: group.raw
                                }
                            });
                        }
                    }
                });
            }
            return {
                "Literal[regex]"(node) {
                    const { pattern, flags } = node.regex;
                    checkRegex(node, pattern, flags);
                },
                Program() {
                    const scope = context.getScope(), tracker = new ReferenceTracker(scope), traceMap = {
                        RegExp: {
                            [CALL]: true,
                            [CONSTRUCT]: true
                        }
                    };
                    for (const { node } of tracker.iterateGlobalReferences(traceMap)) {
                        const [patternNode, flagsNode] = node.arguments, pattern = getStringIfConstant(patternNode, scope), flags = getStringIfConstant(flagsNode, scope);
                        if (typeof pattern === "string") {
                            checkRegex(node, pattern, flags || "");
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-useless-call.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to disallow unnecessary `.call()` and `.apply()`.
     * @author Toru Nagashima
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a node is a `.call()`/`.apply()`.
     * @param {ASTNode} node A CallExpression node to check.
     * @returns {boolean} Whether or not the node is a `.call()`/`.apply()`.
     */
    function isCallOrNonVariadicApply(node) {
        const callee = astUtils.skipChainExpression(node.callee);
        return (callee.type === "MemberExpression" &&
            callee.property.type === "Identifier" &&
            callee.computed === false &&
            ((callee.property.name === "call" && node.arguments.length >= 1) ||
                (callee.property.name === "apply" && node.arguments.length === 2 && node.arguments[1].type === "ArrayExpression")));
    }
    /**
     * Checks whether or not `thisArg` is not changed by `.call()`/`.apply()`.
     * @param {ASTNode|null} expectedThis The node that is the owner of the applied function.
     * @param {ASTNode} thisArg The node that is given to the first argument of the `.call()`/`.apply()`.
     * @param {SourceCode} sourceCode The ESLint source code object.
     * @returns {boolean} Whether or not `thisArg` is not changed by `.call()`/`.apply()`.
     */
    function isValidThisArg(expectedThis, thisArg, sourceCode) {
        if (!expectedThis) {
            return astUtils.isNullOrUndefined(thisArg);
        }
        return astUtils.equalTokens(expectedThis, thisArg, sourceCode);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary calls to `.call()` and `.apply()`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-useless-call"
            },
            schema: [],
            messages: {
                unnecessaryCall: "Unnecessary '.{{name}}()'."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                CallExpression(node) {
                    if (!isCallOrNonVariadicApply(node)) {
                        return;
                    }
                    const callee = astUtils.skipChainExpression(node.callee);
                    const applied = astUtils.skipChainExpression(callee.object);
                    const expectedThis = (applied.type === "MemberExpression") ? applied.object : null;
                    const thisArg = node.arguments[0];
                    if (isValidThisArg(expectedThis, thisArg, sourceCode)) {
                        context.report({ node, messageId: "unnecessaryCall", data: { name: callee.property.name } });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-useless-catch.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Reports useless `catch` clauses that just rethrow their error.
     * @author Teddy Katz
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary `catch` clauses",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-useless-catch"
            },
            schema: [],
            messages: {
                unnecessaryCatchClause: "Unnecessary catch clause.",
                unnecessaryCatch: "Unnecessary try/catch wrapper."
            }
        },
        create(context) {
            return {
                CatchClause(node) {
                    if (node.param &&
                        node.param.type === "Identifier" &&
                        node.body.body.length &&
                        node.body.body[0].type === "ThrowStatement" &&
                        node.body.body[0].argument.type === "Identifier" &&
                        node.body.body[0].argument.name === node.param.name) {
                        if (node.parent.finalizer) {
                            context.report({
                                node,
                                messageId: "unnecessaryCatchClause"
                            });
                        }
                        else {
                            context.report({
                                node: node.parent,
                                messageId: "unnecessaryCatch"
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-useless-computed-key.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to disallow unnecessary computed property keys in object literals
     * @author Burak Yigit Kaya
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Determines whether the computed key syntax is unnecessarily used for the given node.
     * In particular, it determines whether removing the square brackets and using the content between them
     * directly as the key (e.g. ['foo'] -> 'foo') would produce valid syntax and preserve the same behavior.
     * Valid non-computed keys are only: identifiers, number literals and string literals.
     * Only literals can preserve the same behavior, with a few exceptions for specific node types:
     * Property
     *   - { ["__proto__"]: foo } defines a property named "__proto__"
     *     { "__proto__": foo } defines object's prototype
     * PropertyDefinition
     *   - class C { ["constructor"]; } defines an instance field named "constructor"
     *     class C { "constructor"; } produces a parsing error
     *   - class C { static ["constructor"]; } defines a static field named "constructor"
     *     class C { static "constructor"; } produces a parsing error
     *   - class C { static ["prototype"]; } produces a runtime error (doesn't break the whole script)
     *     class C { static "prototype"; } produces a parsing error (breaks the whole script)
     * MethodDefinition
     *   - class C { ["constructor"]() {} } defines a prototype method named "constructor"
     *     class C { "constructor"() {} } defines the constructor
     *   - class C { static ["prototype"]() {} } produces a runtime error (doesn't break the whole script)
     *     class C { static "prototype"() {} } produces a parsing error (breaks the whole script)
     * @param {ASTNode} node The node to check. It can be `Property`, `PropertyDefinition` or `MethodDefinition`.
     * @throws {Error} (Unreachable.)
     * @returns {void} `true` if the node has useless computed key.
     */
    function hasUselessComputedKey(node) {
        if (!node.computed) {
            return false;
        }
        const { key } = node;
        if (key.type !== "Literal") {
            return false;
        }
        const { value } = key;
        if (typeof value !== "number" && typeof value !== "string") {
            return false;
        }
        switch (node.type) {
            case "Property":
                return value !== "__proto__";
            case "PropertyDefinition":
                if (node.static) {
                    return value !== "constructor" && value !== "prototype";
                }
                return value !== "constructor";
            case "MethodDefinition":
                if (node.static) {
                    return value !== "prototype";
                }
                return value !== "constructor";
            /* c8 ignore next */
            default:
                throw new Error(`Unexpected node type: ${node.type}`);
        }
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary computed property keys in objects and classes",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-useless-computed-key"
            },
            schema: [{
                    type: "object",
                    properties: {
                        enforceForClassMembers: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }],
            fixable: "code",
            messages: {
                unnecessarilyComputedProperty: "Unnecessarily computed property [{{property}}] found."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const enforceForClassMembers = context.options[0] && context.options[0].enforceForClassMembers;
            /**
             * Reports a given node if it violated this rule.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             */
            function check(node) {
                if (hasUselessComputedKey(node)) {
                    const { key } = node;
                    context.report({
                        node,
                        messageId: "unnecessarilyComputedProperty",
                        data: { property: sourceCode.getText(key) },
                        fix(fixer) {
                            const leftSquareBracket = sourceCode.getTokenBefore(key, astUtils.isOpeningBracketToken);
                            const rightSquareBracket = sourceCode.getTokenAfter(key, astUtils.isClosingBracketToken);
                            // If there are comments between the brackets and the property name, don't do a fix.
                            if (sourceCode.commentsExistBetween(leftSquareBracket, rightSquareBracket)) {
                                return null;
                            }
                            const tokenBeforeLeftBracket = sourceCode.getTokenBefore(leftSquareBracket);
                            // Insert a space before the key to avoid changing identifiers, e.g. ({ get[2]() {} }) to ({ get2() {} })
                            const needsSpaceBeforeKey = tokenBeforeLeftBracket.range[1] === leftSquareBracket.range[0] &&
                                !astUtils.canTokensBeAdjacent(tokenBeforeLeftBracket, sourceCode.getFirstToken(key));
                            const replacementKey = (needsSpaceBeforeKey ? " " : "") + key.raw;
                            return fixer.replaceTextRange([leftSquareBracket.range[0], rightSquareBracket.range[1]], replacementKey);
                        }
                    });
                }
            }
            /**
             * A no-op function to act as placeholder for checking a node when the `enforceForClassMembers` option is `false`.
             * @returns {void}
             * @private
             */
            function noop() { }
            return {
                Property: check,
                MethodDefinition: enforceForClassMembers ? check : noop,
                PropertyDefinition: enforceForClassMembers ? check : noop
            };
        }
    };
},
/* eslint/lib/rules/no-useless-concat.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview disallow unnecessary concatenation of template strings
     * @author Henry Zhu
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a given node is a concatenation.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node is a concatenation.
     */
    function isConcatenation(node) {
        return node.type === "BinaryExpression" && node.operator === "+";
    }
    /**
     * Checks if the given token is a `+` token or not.
     * @param {Token} token The token to check.
     * @returns {boolean} `true` if the token is a `+` token.
     */
    function isConcatOperatorToken(token) {
        return token.value === "+" && token.type === "Punctuator";
    }
    /**
     * Get's the right most node on the left side of a BinaryExpression with + operator.
     * @param {ASTNode} node A BinaryExpression node to check.
     * @returns {ASTNode} node
     */
    function getLeft(node) {
        let left = node.left;
        while (isConcatenation(left)) {
            left = left.right;
        }
        return left;
    }
    /**
     * Get's the left most node on the right side of a BinaryExpression with + operator.
     * @param {ASTNode} node A BinaryExpression node to check.
     * @returns {ASTNode} node
     */
    function getRight(node) {
        let right = node.right;
        while (isConcatenation(right)) {
            right = right.left;
        }
        return right;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary concatenation of literals or template literals",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-useless-concat"
            },
            schema: [],
            messages: {
                unexpectedConcat: "Unexpected string concatenation of literals."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                BinaryExpression(node) {
                    // check if not concatenation
                    if (node.operator !== "+") {
                        return;
                    }
                    // account for the `foo + "a" + "b"` case
                    const left = getLeft(node);
                    const right = getRight(node);
                    if (astUtils.isStringLiteral(left) &&
                        astUtils.isStringLiteral(right) &&
                        astUtils.isTokenOnSameLine(left, right)) {
                        const operatorToken = sourceCode.getFirstTokenBetween(left, right, isConcatOperatorToken);
                        context.report({
                            node,
                            loc: operatorToken.loc,
                            messageId: "unexpectedConcat"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-useless-constructor.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag the use of redundant constructors in classes.
     * @author Alberto Rodríguez
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether a given array of statements is a single call of `super`.
     * @param {ASTNode[]} body An array of statements to check.
     * @returns {boolean} `true` if the body is a single call of `super`.
     */
    function isSingleSuperCall(body) {
        return (body.length === 1 &&
            body[0].type === "ExpressionStatement" &&
            body[0].expression.type === "CallExpression" &&
            body[0].expression.callee.type === "Super");
    }
    /**
     * Checks whether a given node is a pattern which doesn't have any side effects.
     * Default parameters and Destructuring parameters can have side effects.
     * @param {ASTNode} node A pattern node.
     * @returns {boolean} `true` if the node doesn't have any side effects.
     */
    function isSimple(node) {
        return node.type === "Identifier" || node.type === "RestElement";
    }
    /**
     * Checks whether a given array of expressions is `...arguments` or not.
     * `super(...arguments)` passes all arguments through.
     * @param {ASTNode[]} superArgs An array of expressions to check.
     * @returns {boolean} `true` if the superArgs is `...arguments`.
     */
    function isSpreadArguments(superArgs) {
        return (superArgs.length === 1 &&
            superArgs[0].type === "SpreadElement" &&
            superArgs[0].argument.type === "Identifier" &&
            superArgs[0].argument.name === "arguments");
    }
    /**
     * Checks whether given 2 nodes are identifiers which have the same name or not.
     * @param {ASTNode} ctorParam A node to check.
     * @param {ASTNode} superArg A node to check.
     * @returns {boolean} `true` if the nodes are identifiers which have the same
     *      name.
     */
    function isValidIdentifierPair(ctorParam, superArg) {
        return (ctorParam.type === "Identifier" &&
            superArg.type === "Identifier" &&
            ctorParam.name === superArg.name);
    }
    /**
     * Checks whether given 2 nodes are a rest/spread pair which has the same values.
     * @param {ASTNode} ctorParam A node to check.
     * @param {ASTNode} superArg A node to check.
     * @returns {boolean} `true` if the nodes are a rest/spread pair which has the
     *      same values.
     */
    function isValidRestSpreadPair(ctorParam, superArg) {
        return (ctorParam.type === "RestElement" &&
            superArg.type === "SpreadElement" &&
            isValidIdentifierPair(ctorParam.argument, superArg.argument));
    }
    /**
     * Checks whether given 2 nodes have the same value or not.
     * @param {ASTNode} ctorParam A node to check.
     * @param {ASTNode} superArg A node to check.
     * @returns {boolean} `true` if the nodes have the same value or not.
     */
    function isValidPair(ctorParam, superArg) {
        return (isValidIdentifierPair(ctorParam, superArg) ||
            isValidRestSpreadPair(ctorParam, superArg));
    }
    /**
     * Checks whether the parameters of a constructor and the arguments of `super()`
     * have the same values or not.
     * @param {ASTNode} ctorParams The parameters of a constructor to check.
     * @param {ASTNode} superArgs The arguments of `super()` to check.
     * @returns {boolean} `true` if those have the same values.
     */
    function isPassingThrough(ctorParams, superArgs) {
        if (ctorParams.length !== superArgs.length) {
            return false;
        }
        for (let i = 0; i < ctorParams.length; ++i) {
            if (!isValidPair(ctorParams[i], superArgs[i])) {
                return false;
            }
        }
        return true;
    }
    /**
     * Checks whether the constructor body is a redundant super call.
     * @param {Array} body constructor body content.
     * @param {Array} ctorParams The params to check against super call.
     * @returns {boolean} true if the constructor body is redundant
     */
    function isRedundantSuperCall(body, ctorParams) {
        return (isSingleSuperCall(body) &&
            ctorParams.every(isSimple) &&
            (isSpreadArguments(body[0].expression.arguments) ||
                isPassingThrough(ctorParams, body[0].expression.arguments)));
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary constructors",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-useless-constructor"
            },
            schema: [],
            messages: {
                noUselessConstructor: "Useless constructor."
            }
        },
        create(context) {
            /**
             * Checks whether a node is a redundant constructor
             * @param {ASTNode} node node to check
             * @returns {void}
             */
            function checkForConstructor(node) {
                if (node.kind !== "constructor") {
                    return;
                }
                /*
                 * Prevent crashing on parsers which do not require class constructor
                 * to have a body, e.g. typescript and flow
                 */
                if (!node.value.body) {
                    return;
                }
                const body = node.value.body.body;
                const ctorParams = node.value.params;
                const superClass = node.parent.parent.superClass;
                if (superClass ? isRedundantSuperCall(body, ctorParams) : (body.length === 0)) {
                    context.report({
                        node,
                        messageId: "noUselessConstructor"
                    });
                }
            }
            return {
                MethodDefinition: checkForConstructor
            };
        }
    };
},
/* eslint/lib/rules/no-useless-escape.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Look for useless escapes in strings and regexes
     * @author Onur Temizkan
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /**
     * Returns the union of two sets.
     * @param {Set} setA The first set
     * @param {Set} setB The second set
     * @returns {Set} The union of the two sets
     */
    function union(setA, setB) {
        return new Set(function* () {
            yield* setA;
            yield* setB;
        }());
    }
    const VALID_STRING_ESCAPES = union(new Set("\\nrvtbfux"), astUtils.LINEBREAKS);
    const REGEX_GENERAL_ESCAPES = new Set("\\bcdDfnpPrsStvwWxu0123456789]");
    const REGEX_NON_CHARCLASS_ESCAPES = union(REGEX_GENERAL_ESCAPES, new Set("^/.$*+?[{}|()Bk"));
    /**
     * Parses a regular expression into a list of characters with character class info.
     * @param {string} regExpText The raw text used to create the regular expression
     * @returns {Object[]} A list of characters, each with info on escaping and whether they're in a character class.
     * @example
     *
     * parseRegExp("a\\b[cd-]");
     *
     * // returns:
     * [
     *     { text: "a", index: 0, escaped: false, inCharClass: false, startsCharClass: false, endsCharClass: false },
     *     { text: "b", index: 2, escaped: true, inCharClass: false, startsCharClass: false, endsCharClass: false },
     *     { text: "c", index: 4, escaped: false, inCharClass: true, startsCharClass: true, endsCharClass: false },
     *     { text: "d", index: 5, escaped: false, inCharClass: true, startsCharClass: false, endsCharClass: false },
     *     { text: "-", index: 6, escaped: false, inCharClass: true, startsCharClass: false, endsCharClass: false }
     * ];
     *
     */
    function parseRegExp(regExpText) {
        const charList = [];
        regExpText.split("").reduce((state, char, index) => {
            if (!state.escapeNextChar) {
                if (char === "\\") {
                    return Object.assign(state, { escapeNextChar: true });
                }
                if (char === "[" && !state.inCharClass) {
                    return Object.assign(state, { inCharClass: true, startingCharClass: true });
                }
                if (char === "]" && state.inCharClass) {
                    if (charList.length && charList[charList.length - 1].inCharClass) {
                        charList[charList.length - 1].endsCharClass = true;
                    }
                    return Object.assign(state, { inCharClass: false, startingCharClass: false });
                }
            }
            charList.push({
                text: char,
                index,
                escaped: state.escapeNextChar,
                inCharClass: state.inCharClass,
                startsCharClass: state.startingCharClass,
                endsCharClass: false
            });
            return Object.assign(state, { escapeNextChar: false, startingCharClass: false });
        }, { escapeNextChar: false, inCharClass: false, startingCharClass: false });
        return charList;
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow unnecessary escape characters",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-useless-escape"
            },
            hasSuggestions: true,
            messages: {
                unnecessaryEscape: "Unnecessary escape character: \\{{character}}.",
                removeEscape: "Remove the `\\`. This maintains the current functionality.",
                escapeBackslash: "Replace the `\\` with `\\\\` to include the actual backslash character."
            },
            schema: []
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Reports a node
             * @param {ASTNode} node The node to report
             * @param {number} startOffset The backslash's offset from the start of the node
             * @param {string} character The uselessly escaped character (not including the backslash)
             * @returns {void}
             */
            function report(node, startOffset, character) {
                const rangeStart = node.range[0] + startOffset;
                const range = [rangeStart, rangeStart + 1];
                const start = sourceCode.getLocFromIndex(rangeStart);
                context.report({
                    node,
                    loc: {
                        start,
                        end: { line: start.line, column: start.column + 1 }
                    },
                    messageId: "unnecessaryEscape",
                    data: { character },
                    suggest: [
                        {
                            messageId: "removeEscape",
                            fix(fixer) {
                                return fixer.removeRange(range);
                            }
                        },
                        {
                            messageId: "escapeBackslash",
                            fix(fixer) {
                                return fixer.insertTextBeforeRange(range, "\\");
                            }
                        }
                    ]
                });
            }
            /**
             * Checks if the escape character in given string slice is unnecessary.
             * @private
             * @param {ASTNode} node node to validate.
             * @param {string} match string slice to validate.
             * @returns {void}
             */
            function validateString(node, match) {
                const isTemplateElement = node.type === "TemplateElement";
                const escapedChar = match[0][1];
                let isUnnecessaryEscape = !VALID_STRING_ESCAPES.has(escapedChar);
                let isQuoteEscape;
                if (isTemplateElement) {
                    isQuoteEscape = escapedChar === "`";
                    if (escapedChar === "$") {
                        // Warn if `\$` is not followed by `{`
                        isUnnecessaryEscape = match.input[match.index + 2] !== "{";
                    }
                    else if (escapedChar === "{") {
                        /*
                         * Warn if `\{` is not preceded by `$`. If preceded by `$`, escaping
                         * is necessary and the rule should not warn. If preceded by `/$`, the rule
                         * will warn for the `/$` instead, as it is the first unnecessarily escaped character.
                         */
                        isUnnecessaryEscape = match.input[match.index - 1] !== "$";
                    }
                }
                else {
                    isQuoteEscape = escapedChar === node.raw[0];
                }
                if (isUnnecessaryEscape && !isQuoteEscape) {
                    report(node, match.index, match[0].slice(1));
                }
            }
            /**
             * Checks if a node has an escape.
             * @param {ASTNode} node node to check.
             * @returns {void}
             */
            function check(node) {
                const isTemplateElement = node.type === "TemplateElement";
                if (isTemplateElement &&
                    node.parent &&
                    node.parent.parent &&
                    node.parent.parent.type === "TaggedTemplateExpression" &&
                    node.parent === node.parent.parent.quasi) {
                    // Don't report tagged template literals, because the backslash character is accessible to the tag function.
                    return;
                }
                if (typeof node.value === "string" || isTemplateElement) {
                    /*
                     * JSXAttribute doesn't have any escape sequence: https://facebook.github.io/jsx/.
                     * In addition, backticks are not supported by JSX yet: https://github.com/facebook/jsx/issues/25.
                     */
                    if (node.parent.type === "JSXAttribute" || node.parent.type === "JSXElement" || node.parent.type === "JSXFragment") {
                        return;
                    }
                    const value = isTemplateElement ? sourceCode.getText(node) : node.raw;
                    const pattern = /\\[^\d]/gu;
                    let match;
                    while ((match = pattern.exec(value))) {
                        validateString(node, match);
                    }
                }
                else if (node.regex) {
                    parseRegExp(node.regex.pattern)
                        /*
                         * The '-' character is a special case, because it's only valid to escape it if it's in a character
                         * class, and is not at either edge of the character class. To account for this, don't consider '-'
                         * characters to be valid in general, and filter out '-' characters that appear in the middle of a
                         * character class.
                         */
                        .filter(charInfo => !(charInfo.text === "-" && charInfo.inCharClass && !charInfo.startsCharClass && !charInfo.endsCharClass))
                        /*
                         * The '^' character is also a special case; it must always be escaped outside of character classes, but
                         * it only needs to be escaped in character classes if it's at the beginning of the character class. To
                         * account for this, consider it to be a valid escape character outside of character classes, and filter
                         * out '^' characters that appear at the start of a character class.
                         */
                        .filter(charInfo => !(charInfo.text === "^" && charInfo.startsCharClass))
                        // Filter out characters that aren't escaped.
                        .filter(charInfo => charInfo.escaped)
                        // Filter out characters that are valid to escape, based on their position in the regular expression.
                        .filter(charInfo => !(charInfo.inCharClass ? REGEX_GENERAL_ESCAPES : REGEX_NON_CHARCLASS_ESCAPES).has(charInfo.text))
                        // Report all the remaining characters.
                        .forEach(charInfo => report(node, charInfo.index, charInfo.text));
                }
            }
            return {
                Literal: check,
                TemplateElement: check
            };
        }
    };
},
/* eslint/lib/rules/no-useless-rename.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Disallow renaming import, export, and destructured assignments to the same name.
     * @author Kai Cataldo
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow renaming import, export, and destructured assignments to the same name",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-useless-rename"
            },
            fixable: "code",
            schema: [
                {
                    type: "object",
                    properties: {
                        ignoreDestructuring: { type: "boolean", default: false },
                        ignoreImport: { type: "boolean", default: false },
                        ignoreExport: { type: "boolean", default: false }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unnecessarilyRenamed: "{{type}} {{name}} unnecessarily renamed."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode(), options = context.options[0] || {}, ignoreDestructuring = options.ignoreDestructuring === true, ignoreImport = options.ignoreImport === true, ignoreExport = options.ignoreExport === true;
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Reports error for unnecessarily renamed assignments
             * @param {ASTNode} node node to report
             * @param {ASTNode} initial node with initial name value
             * @param {string} type the type of the offending node
             * @returns {void}
             */
            function reportError(node, initial, type) {
                const name = initial.type === "Identifier" ? initial.name : initial.value;
                return context.report({
                    node,
                    messageId: "unnecessarilyRenamed",
                    data: {
                        name,
                        type
                    },
                    fix(fixer) {
                        const replacementNode = node.type === "Property" ? node.value : node.local;
                        if (sourceCode.getCommentsInside(node).length > sourceCode.getCommentsInside(replacementNode).length) {
                            return null;
                        }
                        // Don't autofix code such as `({foo: (foo) = a} = obj);`, parens are not allowed in shorthand properties.
                        if (replacementNode.type === "AssignmentPattern" &&
                            astUtils.isParenthesised(sourceCode, replacementNode.left)) {
                            return null;
                        }
                        return fixer.replaceText(node, sourceCode.getText(replacementNode));
                    }
                });
            }
            /**
             * Checks whether a destructured assignment is unnecessarily renamed
             * @param {ASTNode} node node to check
             * @returns {void}
             */
            function checkDestructured(node) {
                if (ignoreDestructuring) {
                    return;
                }
                for (const property of node.properties) {
                    /**
                     * Properties using shorthand syntax and rest elements can not be renamed.
                     * If the property is computed, we have no idea if a rename is useless or not.
                     */
                    if (property.type !== "Property" || property.shorthand || property.computed) {
                        continue;
                    }
                    const key = (property.key.type === "Identifier" && property.key.name) || (property.key.type === "Literal" && property.key.value);
                    const renamedKey = property.value.type === "AssignmentPattern" ? property.value.left.name : property.value.name;
                    if (key === renamedKey) {
                        reportError(property, property.key, "Destructuring assignment");
                    }
                }
            }
            /**
             * Checks whether an import is unnecessarily renamed
             * @param {ASTNode} node node to check
             * @returns {void}
             */
            function checkImport(node) {
                if (ignoreImport) {
                    return;
                }
                if (node.imported.range[0] !== node.local.range[0] &&
                    astUtils.getModuleExportName(node.imported) === node.local.name) {
                    reportError(node, node.imported, "Import");
                }
            }
            /**
             * Checks whether an export is unnecessarily renamed
             * @param {ASTNode} node node to check
             * @returns {void}
             */
            function checkExport(node) {
                if (ignoreExport) {
                    return;
                }
                if (node.local.range[0] !== node.exported.range[0] &&
                    astUtils.getModuleExportName(node.local) === astUtils.getModuleExportName(node.exported)) {
                    reportError(node, node.local, "Export");
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                ObjectPattern: checkDestructured,
                ImportSpecifier: checkImport,
                ExportSpecifier: checkExport
            };
        }
    };
},
/* eslint/lib/rules/no-useless-return.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallow redundant return statements
     * @author Teddy Katz
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */, FixTracker = require(496) /* ./utils/fix-tracker */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Removes the given element from the array.
     * @param {Array} array The source array to remove.
     * @param {any} element The target item to remove.
     * @returns {void}
     */
    function remove(array, element) {
        const index = array.indexOf(element);
        if (index !== -1) {
            array.splice(index, 1);
        }
    }
    /**
     * Checks whether it can remove the given return statement or not.
     * @param {ASTNode} node The return statement node to check.
     * @returns {boolean} `true` if the node is removable.
     */
    function isRemovable(node) {
        return astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type);
    }
    /**
     * Checks whether the given return statement is in a `finally` block or not.
     * @param {ASTNode} node The return statement node to check.
     * @returns {boolean} `true` if the node is in a `finally` block.
     */
    function isInFinally(node) {
        for (let currentNode = node; currentNode && currentNode.parent && !astUtils.isFunction(currentNode); currentNode = currentNode.parent) {
            if (currentNode.parent.type === "TryStatement" && currentNode.parent.finalizer === currentNode) {
                return true;
            }
        }
        return false;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow redundant return statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-useless-return"
            },
            fixable: "code",
            schema: [],
            messages: {
                unnecessaryReturn: "Unnecessary return statement."
            }
        },
        create(context) {
            const segmentInfoMap = new WeakMap();
            const usedUnreachableSegments = new WeakSet();
            const sourceCode = context.getSourceCode();
            let scopeInfo = null;
            /**
             * Checks whether the given segment is terminated by a return statement or not.
             * @param {CodePathSegment} segment The segment to check.
             * @returns {boolean} `true` if the segment is terminated by a return statement, or if it's still a part of unreachable.
             */
            function isReturned(segment) {
                const info = segmentInfoMap.get(segment);
                return !info || info.returned;
            }
            /**
             * Collects useless return statements from the given previous segments.
             *
             * A previous segment may be an unreachable segment.
             * In that case, the information object of the unreachable segment is not
             * initialized because `onCodePathSegmentStart` event is not notified for
             * unreachable segments.
             * This goes to the previous segments of the unreachable segment recursively
             * if the unreachable segment was generated by a return statement. Otherwise,
             * this ignores the unreachable segment.
             *
             * This behavior would simulate code paths for the case that the return
             * statement does not exist.
             * @param {ASTNode[]} uselessReturns The collected return statements.
             * @param {CodePathSegment[]} prevSegments The previous segments to traverse.
             * @param {WeakSet<CodePathSegment>} [providedTraversedSegments] A set of segments that have already been traversed in this call
             * @returns {ASTNode[]} `uselessReturns`.
             */
            function getUselessReturns(uselessReturns, prevSegments, providedTraversedSegments) {
                const traversedSegments = providedTraversedSegments || new WeakSet();
                for (const segment of prevSegments) {
                    if (!segment.reachable) {
                        if (!traversedSegments.has(segment)) {
                            traversedSegments.add(segment);
                            getUselessReturns(uselessReturns, segment.allPrevSegments.filter(isReturned), traversedSegments);
                        }
                        continue;
                    }
                    uselessReturns.push(...segmentInfoMap.get(segment).uselessReturns);
                }
                return uselessReturns;
            }
            /**
             * Removes the return statements on the given segment from the useless return
             * statement list.
             *
             * This segment may be an unreachable segment.
             * In that case, the information object of the unreachable segment is not
             * initialized because `onCodePathSegmentStart` event is not notified for
             * unreachable segments.
             * This goes to the previous segments of the unreachable segment recursively
             * if the unreachable segment was generated by a return statement. Otherwise,
             * this ignores the unreachable segment.
             *
             * This behavior would simulate code paths for the case that the return
             * statement does not exist.
             * @param {CodePathSegment} segment The segment to get return statements.
             * @returns {void}
             */
            function markReturnStatementsOnSegmentAsUsed(segment) {
                if (!segment.reachable) {
                    usedUnreachableSegments.add(segment);
                    segment.allPrevSegments
                        .filter(isReturned)
                        .filter(prevSegment => !usedUnreachableSegments.has(prevSegment))
                        .forEach(markReturnStatementsOnSegmentAsUsed);
                    return;
                }
                const info = segmentInfoMap.get(segment);
                for (const node of info.uselessReturns) {
                    remove(scopeInfo.uselessReturns, node);
                }
                info.uselessReturns = [];
            }
            /**
             * Removes the return statements on the current segments from the useless
             * return statement list.
             *
             * This function will be called at every statement except FunctionDeclaration,
             * BlockStatement, and BreakStatement.
             *
             * - FunctionDeclarations are always executed whether it's returned or not.
             * - BlockStatements do nothing.
             * - BreakStatements go the next merely.
             * @returns {void}
             */
            function markReturnStatementsOnCurrentSegmentsAsUsed() {
                scopeInfo
                    .codePath
                    .currentSegments
                    .forEach(markReturnStatementsOnSegmentAsUsed);
            }
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                // Makes and pushes a new scope information.
                onCodePathStart(codePath) {
                    scopeInfo = {
                        upper: scopeInfo,
                        uselessReturns: [],
                        codePath
                    };
                },
                // Reports useless return statements if exist.
                onCodePathEnd() {
                    for (const node of scopeInfo.uselessReturns) {
                        context.report({
                            node,
                            loc: node.loc,
                            messageId: "unnecessaryReturn",
                            fix(fixer) {
                                if (isRemovable(node) && !sourceCode.getCommentsInside(node).length) {
                                    /*
                                     * Extend the replacement range to include the
                                     * entire function to avoid conflicting with
                                     * no-else-return.
                                     * https://github.com/eslint/eslint/issues/8026
                                     */
                                    return new FixTracker(fixer, sourceCode)
                                        .retainEnclosingFunction(node)
                                        .remove(node);
                                }
                                return null;
                            }
                        });
                    }
                    scopeInfo = scopeInfo.upper;
                },
                /*
                 * Initializes segments.
                 * NOTE: This event is notified for only reachable segments.
                 */
                onCodePathSegmentStart(segment) {
                    const info = {
                        uselessReturns: getUselessReturns([], segment.allPrevSegments),
                        returned: false
                    };
                    // Stores the info.
                    segmentInfoMap.set(segment, info);
                },
                // Adds ReturnStatement node to check whether it's useless or not.
                ReturnStatement(node) {
                    if (node.argument) {
                        markReturnStatementsOnCurrentSegmentsAsUsed();
                    }
                    if (node.argument ||
                        astUtils.isInLoop(node) ||
                        isInFinally(node) ||
                        // Ignore `return` statements in unreachable places (https://github.com/eslint/eslint/issues/11647).
                        !scopeInfo.codePath.currentSegments.some(s => s.reachable)) {
                        return;
                    }
                    for (const segment of scopeInfo.codePath.currentSegments) {
                        const info = segmentInfoMap.get(segment);
                        if (info) {
                            info.uselessReturns.push(node);
                            info.returned = true;
                        }
                    }
                    scopeInfo.uselessReturns.push(node);
                },
                /*
                 * Registers for all statement nodes except FunctionDeclaration, BlockStatement, BreakStatement.
                 * Removes return statements of the current segments from the useless return statement list.
                 */
                ClassDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
                ContinueStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                DebuggerStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                DoWhileStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                EmptyStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                ExpressionStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                ForInStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                ForOfStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                ForStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                IfStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                ImportDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
                LabeledStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                SwitchStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                ThrowStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                TryStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                VariableDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
                WhileStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                WithStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
                ExportNamedDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
                ExportDefaultDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
                ExportAllDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed
            };
        }
    };
},
/* eslint/lib/rules/no-var.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check for the usage of var.
     * @author Jamund Ferguson
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Check whether a given variable is a global variable or not.
     * @param {eslint-scope.Variable} variable The variable to check.
     * @returns {boolean} `true` if the variable is a global variable.
     */
    function isGlobal(variable) {
        return Boolean(variable.scope) && variable.scope.type === "global";
    }
    /**
     * Finds the nearest function scope or global scope walking up the scope
     * hierarchy.
     * @param {eslint-scope.Scope} scope The scope to traverse.
     * @returns {eslint-scope.Scope} a function scope or global scope containing the given
     *      scope.
     */
    function getEnclosingFunctionScope(scope) {
        let currentScope = scope;
        while (currentScope.type !== "function" && currentScope.type !== "global") {
            currentScope = currentScope.upper;
        }
        return currentScope;
    }
    /**
     * Checks whether the given variable has any references from a more specific
     * function expression (i.e. a closure).
     * @param {eslint-scope.Variable} variable A variable to check.
     * @returns {boolean} `true` if the variable is used from a closure.
     */
    function isReferencedInClosure(variable) {
        const enclosingFunctionScope = getEnclosingFunctionScope(variable.scope);
        return variable.references.some(reference => getEnclosingFunctionScope(reference.from) !== enclosingFunctionScope);
    }
    /**
     * Checks whether the given node is the assignee of a loop.
     * @param {ASTNode} node A VariableDeclaration node to check.
     * @returns {boolean} `true` if the declaration is assigned as part of loop
     *      iteration.
     */
    function isLoopAssignee(node) {
        return (node.parent.type === "ForOfStatement" || node.parent.type === "ForInStatement") &&
            node === node.parent.left;
    }
    /**
     * Checks whether the given variable declaration is immediately initialized.
     * @param {ASTNode} node A VariableDeclaration node to check.
     * @returns {boolean} `true` if the declaration has an initializer.
     */
    function isDeclarationInitialized(node) {
        return node.declarations.every(declarator => declarator.init !== null);
    }
    const SCOPE_NODE_TYPE = /^(?:Program|BlockStatement|SwitchStatement|ForStatement|ForInStatement|ForOfStatement)$/u;
    /**
     * Gets the scope node which directly contains a given node.
     * @param {ASTNode} node A node to get. This is a `VariableDeclaration` or
     *      an `Identifier`.
     * @returns {ASTNode} A scope node. This is one of `Program`, `BlockStatement`,
     *      `SwitchStatement`, `ForStatement`, `ForInStatement`, and
     *      `ForOfStatement`.
     */
    function getScopeNode(node) {
        for (let currentNode = node; currentNode; currentNode = currentNode.parent) {
            if (SCOPE_NODE_TYPE.test(currentNode.type)) {
                return currentNode;
            }
        }
        /* c8 ignore next */
        return null;
    }
    /**
     * Checks whether a given variable is redeclared or not.
     * @param {eslint-scope.Variable} variable A variable to check.
     * @returns {boolean} `true` if the variable is redeclared.
     */
    function isRedeclared(variable) {
        return variable.defs.length >= 2;
    }
    /**
     * Checks whether a given variable is used from outside of the specified scope.
     * @param {ASTNode} scopeNode A scope node to check.
     * @returns {Function} The predicate function which checks whether a given
     *      variable is used from outside of the specified scope.
     */
    function isUsedFromOutsideOf(scopeNode) {
        /**
         * Checks whether a given reference is inside of the specified scope or not.
         * @param {eslint-scope.Reference} reference A reference to check.
         * @returns {boolean} `true` if the reference is inside of the specified
         *      scope.
         */
        function isOutsideOfScope(reference) {
            const scope = scopeNode.range;
            const id = reference.identifier.range;
            return id[0] < scope[0] || id[1] > scope[1];
        }
        return function (variable) {
            return variable.references.some(isOutsideOfScope);
        };
    }
    /**
     * Creates the predicate function which checks whether a variable has their references in TDZ.
     *
     * The predicate function would return `true`:
     *
     * - if a reference is before the declarator. E.g. (var a = b, b = 1;)(var {a = b, b} = {};)
     * - if a reference is in the expression of their default value.  E.g. (var {a = a} = {};)
     * - if a reference is in the expression of their initializer.  E.g. (var a = a;)
     * @param {ASTNode} node The initializer node of VariableDeclarator.
     * @returns {Function} The predicate function.
     * @private
     */
    function hasReferenceInTDZ(node) {
        const initStart = node.range[0];
        const initEnd = node.range[1];
        return variable => {
            const id = variable.defs[0].name;
            const idStart = id.range[0];
            const defaultValue = (id.parent.type === "AssignmentPattern" ? id.parent.right : null);
            const defaultStart = defaultValue && defaultValue.range[0];
            const defaultEnd = defaultValue && defaultValue.range[1];
            return variable.references.some(reference => {
                const start = reference.identifier.range[0];
                const end = reference.identifier.range[1];
                return !reference.init && (start < idStart ||
                    (defaultValue !== null && start >= defaultStart && end <= defaultEnd) ||
                    (!astUtils.isFunction(node) && start >= initStart && end <= initEnd));
            });
        };
    }
    /**
     * Checks whether a given variable has name that is allowed for 'var' declarations,
     * but disallowed for `let` declarations.
     * @param {eslint-scope.Variable} variable The variable to check.
     * @returns {boolean} `true` if the variable has a disallowed name.
     */
    function hasNameDisallowedForLetDeclarations(variable) {
        return variable.name === "let";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require `let` or `const` instead of `var`",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-var"
            },
            schema: [],
            fixable: "code",
            messages: {
                unexpectedVar: "Unexpected var, use let or const instead."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Checks whether the variables which are defined by the given declarator node have their references in TDZ.
             * @param {ASTNode} declarator The VariableDeclarator node to check.
             * @returns {boolean} `true` if one of the variables which are defined by the given declarator node have their references in TDZ.
             */
            function hasSelfReferenceInTDZ(declarator) {
                if (!declarator.init) {
                    return false;
                }
                const variables = context.getDeclaredVariables(declarator);
                return variables.some(hasReferenceInTDZ(declarator.init));
            }
            /**
             * Checks whether it can fix a given variable declaration or not.
             * It cannot fix if the following cases:
             *
             * - A variable is a global variable.
             * - A variable is declared on a SwitchCase node.
             * - A variable is redeclared.
             * - A variable is used from outside the scope.
             * - A variable is used from a closure within a loop.
             * - A variable might be used before it is assigned within a loop.
             * - A variable might be used in TDZ.
             * - A variable is declared in statement position (e.g. a single-line `IfStatement`)
             * - A variable has name that is disallowed for `let` declarations.
             *
             * ## A variable is declared on a SwitchCase node.
             *
             * If this rule modifies 'var' declarations on a SwitchCase node, it
             * would generate the warnings of 'no-case-declarations' rule. And the
             * 'eslint:recommended' preset includes 'no-case-declarations' rule, so
             * this rule doesn't modify those declarations.
             *
             * ## A variable is redeclared.
             *
             * The language spec disallows redeclarations of `let` declarations.
             * Those variables would cause syntax errors.
             *
             * ## A variable is used from outside the scope.
             *
             * The language spec disallows accesses from outside of the scope for
             * `let` declarations. Those variables would cause reference errors.
             *
             * ## A variable is used from a closure within a loop.
             *
             * A `var` declaration within a loop shares the same variable instance
             * across all loop iterations, while a `let` declaration creates a new
             * instance for each iteration. This means if a variable in a loop is
             * referenced by any closure, changing it from `var` to `let` would
             * change the behavior in a way that is generally unsafe.
             *
             * ## A variable might be used before it is assigned within a loop.
             *
             * Within a loop, a `let` declaration without an initializer will be
             * initialized to null, while a `var` declaration will retain its value
             * from the previous iteration, so it is only safe to change `var` to
             * `let` if we can statically determine that the variable is always
             * assigned a value before its first access in the loop body. To keep
             * the implementation simple, we only convert `var` to `let` within
             * loops when the variable is a loop assignee or the declaration has an
             * initializer.
             * @param {ASTNode} node A variable declaration node to check.
             * @returns {boolean} `true` if it can fix the node.
             */
            function canFix(node) {
                const variables = context.getDeclaredVariables(node);
                const scopeNode = getScopeNode(node);
                if (node.parent.type === "SwitchCase" ||
                    node.declarations.some(hasSelfReferenceInTDZ) ||
                    variables.some(isGlobal) ||
                    variables.some(isRedeclared) ||
                    variables.some(isUsedFromOutsideOf(scopeNode)) ||
                    variables.some(hasNameDisallowedForLetDeclarations)) {
                    return false;
                }
                if (astUtils.isInLoop(node)) {
                    if (variables.some(isReferencedInClosure)) {
                        return false;
                    }
                    if (!isLoopAssignee(node) && !isDeclarationInitialized(node)) {
                        return false;
                    }
                }
                if (!isLoopAssignee(node) &&
                    !(node.parent.type === "ForStatement" && node.parent.init === node) &&
                    !astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type)) {
                    // If the declaration is not in a block, e.g. `if (foo) var bar = 1;`, then it can't be fixed.
                    return false;
                }
                return true;
            }
            /**
             * Reports a given variable declaration node.
             * @param {ASTNode} node A variable declaration node to report.
             * @returns {void}
             */
            function report(node) {
                context.report({
                    node,
                    messageId: "unexpectedVar",
                    fix(fixer) {
                        const varToken = sourceCode.getFirstToken(node, { filter: t => t.value === "var" });
                        return canFix(node)
                            ? fixer.replaceText(varToken, "let")
                            : null;
                    }
                });
            }
            return {
                "VariableDeclaration:exit"(node) {
                    if (node.kind === "var") {
                        report(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-void.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to disallow use of void operator.
     * @author Mike Sidorov
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `void` operators",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-void"
            },
            messages: {
                noVoid: "Expected 'undefined' and instead saw 'void'."
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowAsStatement: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ]
        },
        create(context) {
            const allowAsStatement = context.options[0] && context.options[0].allowAsStatement;
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                'UnaryExpression[operator="void"]'(node) {
                    if (allowAsStatement &&
                        node.parent &&
                        node.parent.type === "ExpressionStatement") {
                        return;
                    }
                    context.report({
                        node,
                        messageId: "noVoid"
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/no-warning-comments.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule that warns about used warning comments
     * @author Alexander Schmidt <https://github.com/lxanders>
     */
    "use strict";
    const escapeRegExp = require(285) /* escape-string-regexp */;
    const astUtils = require(360) /* ./utils/ast-utils */;
    const CHAR_LIMIT = 40;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow specified warning terms in comments",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-warning-comments"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        terms: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        },
                        location: {
                            enum: ["start", "anywhere"]
                        },
                        decoration: {
                            type: "array",
                            items: {
                                type: "string",
                                pattern: "^\\S$"
                            },
                            minItems: 1,
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedComment: "Unexpected '{{matchedTerm}}' comment: '{{comment}}'."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode(), configuration = context.options[0] || {}, warningTerms = configuration.terms || ["todo", "fixme", "xxx"], location = configuration.location || "start", decoration = [...configuration.decoration || []].join(""), selfConfigRegEx = /\bno-warning-comments\b/u;
            /**
             * Convert a warning term into a RegExp which will match a comment containing that whole word in the specified
             * location ("start" or "anywhere"). If the term starts or ends with non word characters, then the match will not
             * require word boundaries on that side.
             * @param {string} term A term to convert to a RegExp
             * @returns {RegExp} The term converted to a RegExp
             */
            function convertToRegExp(term) {
                const escaped = escapeRegExp(term);
                const escapedDecoration = escapeRegExp(decoration);
                /*
                 * When matching at the start, ignore leading whitespace, and
                 * there's no need to worry about word boundaries.
                 *
                 * These expressions for the prefix and suffix are designed as follows:
                 * ^   handles any terms at the beginning of a comment.
                 *     e.g. terms ["TODO"] matches `//TODO something`
                 * $   handles any terms at the end of a comment
                 *     e.g. terms ["TODO"] matches `// something TODO`
                 * \b  handles terms preceded/followed by word boundary
                 *     e.g. terms: ["!FIX", "FIX!"] matches `// FIX!something` or `// something!FIX`
                 *          terms: ["FIX"] matches `// FIX!` or `// !FIX`, but not `// fixed or affix`
                 *
                 * For location start:
                 * [\s]* handles optional leading spaces
                 *     e.g. terms ["TODO"] matches `//    TODO something`
                 * [\s\*]* (where "\*" is the escaped string of decoration)
                 *     handles optional leading spaces or decoration characters (for "start" location only)
                 *     e.g. terms ["TODO"] matches `/**** TODO something ... `
                 */
                const wordBoundary = "\\b";
                let prefix = "";
                if (location === "start") {
                    prefix = `^[\\s${escapedDecoration}]*`;
                }
                else if (/^\w/u.test(term)) {
                    prefix = wordBoundary;
                }
                const suffix = /\w$/u.test(term) ? wordBoundary : "";
                const flags = "iu"; // Case-insensitive with Unicode case folding.
                /*
                 * For location "start", the typical regex is:
                 *   /^[\s]*ESCAPED_TERM\b/iu.
                 * Or if decoration characters are specified (e.g. "*"), then any of
                 * those characters may appear in any order at the start:
                 *   /^[\s\*]*ESCAPED_TERM\b/iu.
                 *
                 * For location "anywhere" the typical regex is
                 *   /\bESCAPED_TERM\b/iu
                 *
                 * If it starts or ends with non-word character, the prefix and suffix are empty, respectively.
                 */
                return new RegExp(`${prefix}${escaped}${suffix}`, flags);
            }
            const warningRegExps = warningTerms.map(convertToRegExp);
            /**
             * Checks the specified comment for matches of the configured warning terms and returns the matches.
             * @param {string} comment The comment which is checked.
             * @returns {Array} All matched warning terms for this comment.
             */
            function commentContainsWarningTerm(comment) {
                const matches = [];
                warningRegExps.forEach((regex, index) => {
                    if (regex.test(comment)) {
                        matches.push(warningTerms[index]);
                    }
                });
                return matches;
            }
            /**
             * Checks the specified node for matching warning comments and reports them.
             * @param {ASTNode} node The AST node being checked.
             * @returns {void} undefined.
             */
            function checkComment(node) {
                const comment = node.value;
                if (astUtils.isDirectiveComment(node) &&
                    selfConfigRegEx.test(comment)) {
                    return;
                }
                const matches = commentContainsWarningTerm(comment);
                matches.forEach(matchedTerm => {
                    let commentToDisplay = "";
                    let truncated = false;
                    for (const c of comment.trim().split(/\s+/u)) {
                        const tmp = commentToDisplay ? `${commentToDisplay} ${c}` : c;
                        if (tmp.length <= CHAR_LIMIT) {
                            commentToDisplay = tmp;
                        }
                        else {
                            truncated = true;
                            break;
                        }
                    }
                    context.report({
                        node,
                        messageId: "unexpectedComment",
                        data: {
                            matchedTerm,
                            comment: `${commentToDisplay}${truncated ? "..." : ""}`
                        }
                    });
                });
            }
            return {
                Program() {
                    const comments = sourceCode.getAllComments();
                    comments
                        .filter(token => token.type !== "Shebang")
                        .forEach(checkComment);
                }
            };
        }
    };
},
/* eslint/lib/rules/no-whitespace-before-property.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to disallow whitespace before properties
     * @author Kai Cataldo
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Disallow whitespace before properties",
                recommended: false,
                url: "https://eslint.org/docs/rules/no-whitespace-before-property"
            },
            fixable: "whitespace",
            schema: [],
            messages: {
                unexpectedWhitespace: "Unexpected whitespace before property {{propName}}."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Reports whitespace before property token
             * @param {ASTNode} node the node to report in the event of an error
             * @param {Token} leftToken the left token
             * @param {Token} rightToken the right token
             * @returns {void}
             * @private
             */
            function reportError(node, leftToken, rightToken) {
                context.report({
                    node,
                    messageId: "unexpectedWhitespace",
                    data: {
                        propName: sourceCode.getText(node.property)
                    },
                    fix(fixer) {
                        let replacementText = "";
                        if (!node.computed && !node.optional && astUtils.isDecimalInteger(node.object)) {
                            /*
                             * If the object is a number literal, fixing it to something like 5.toString() would cause a SyntaxError.
                             * Don't fix this case.
                             */
                            return null;
                        }
                        // Don't fix if comments exist.
                        if (sourceCode.commentsExistBetween(leftToken, rightToken)) {
                            return null;
                        }
                        if (node.optional) {
                            replacementText = "?.";
                        }
                        else if (!node.computed) {
                            replacementText = ".";
                        }
                        return fixer.replaceTextRange([leftToken.range[1], rightToken.range[0]], replacementText);
                    }
                });
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                MemberExpression(node) {
                    let rightToken;
                    let leftToken;
                    if (!astUtils.isTokenOnSameLine(node.object, node.property)) {
                        return;
                    }
                    if (node.computed) {
                        rightToken = sourceCode.getTokenBefore(node.property, astUtils.isOpeningBracketToken);
                        leftToken = sourceCode.getTokenBefore(rightToken, node.optional ? 1 : 0);
                    }
                    else {
                        rightToken = sourceCode.getFirstToken(node.property);
                        leftToken = sourceCode.getTokenBefore(rightToken, 1);
                    }
                    if (sourceCode.isSpaceBetweenTokens(leftToken, rightToken)) {
                        reportError(node, leftToken, rightToken);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/no-with.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of with statement
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `with` statements",
                recommended: true,
                url: "https://eslint.org/docs/rules/no-with"
            },
            schema: [],
            messages: {
                unexpectedWith: "Unexpected use of 'with' statement."
            }
        },
        create(context) {
            return {
                WithStatement(node) {
                    context.report({ node, messageId: "unexpectedWith" });
                }
            };
        }
    };
},
/* eslint/lib/rules/nonblock-statement-body-position.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview enforce the location of single-line statements
     * @author Teddy Katz
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const POSITION_SCHEMA = { enum: ["beside", "below", "any"] };
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce the location of single-line statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/nonblock-statement-body-position"
            },
            fixable: "whitespace",
            schema: [
                POSITION_SCHEMA,
                {
                    properties: {
                        overrides: {
                            properties: {
                                if: POSITION_SCHEMA,
                                else: POSITION_SCHEMA,
                                while: POSITION_SCHEMA,
                                do: POSITION_SCHEMA,
                                for: POSITION_SCHEMA
                            },
                            additionalProperties: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                expectNoLinebreak: "Expected no linebreak before this statement.",
                expectLinebreak: "Expected a linebreak before this statement."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            //----------------------------------------------------------------------
            // Helpers
            //----------------------------------------------------------------------
            /**
             * Gets the applicable preference for a particular keyword
             * @param {string} keywordName The name of a keyword, e.g. 'if'
             * @returns {string} The applicable option for the keyword, e.g. 'beside'
             */
            function getOption(keywordName) {
                return context.options[1] && context.options[1].overrides && context.options[1].overrides[keywordName] ||
                    context.options[0] ||
                    "beside";
            }
            /**
             * Validates the location of a single-line statement
             * @param {ASTNode} node The single-line statement
             * @param {string} keywordName The applicable keyword name for the single-line statement
             * @returns {void}
             */
            function validateStatement(node, keywordName) {
                const option = getOption(keywordName);
                if (node.type === "BlockStatement" || option === "any") {
                    return;
                }
                const tokenBefore = sourceCode.getTokenBefore(node);
                if (tokenBefore.loc.end.line === node.loc.start.line && option === "below") {
                    context.report({
                        node,
                        messageId: "expectLinebreak",
                        fix: fixer => fixer.insertTextBefore(node, "\n")
                    });
                }
                else if (tokenBefore.loc.end.line !== node.loc.start.line && option === "beside") {
                    context.report({
                        node,
                        messageId: "expectNoLinebreak",
                        fix(fixer) {
                            if (sourceCode.getText().slice(tokenBefore.range[1], node.range[0]).trim()) {
                                return null;
                            }
                            return fixer.replaceTextRange([tokenBefore.range[1], node.range[0]], " ");
                        }
                    });
                }
            }
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                IfStatement(node) {
                    validateStatement(node.consequent, "if");
                    // Check the `else` node, but don't check 'else if' statements.
                    if (node.alternate && node.alternate.type !== "IfStatement") {
                        validateStatement(node.alternate, "else");
                    }
                },
                WhileStatement: node => validateStatement(node.body, "while"),
                DoWhileStatement: node => validateStatement(node.body, "do"),
                ForStatement: node => validateStatement(node.body, "for"),
                ForInStatement: node => validateStatement(node.body, "for"),
                ForOfStatement: node => validateStatement(node.body, "for")
            };
        }
    };
},
/* eslint/lib/rules/object-curly-newline.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to require or disallow line breaks inside braces.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    // Schema objects.
    const OPTION_VALUE = {
        oneOf: [
            {
                enum: ["always", "never"]
            },
            {
                type: "object",
                properties: {
                    multiline: {
                        type: "boolean"
                    },
                    minProperties: {
                        type: "integer",
                        minimum: 0
                    },
                    consistent: {
                        type: "boolean"
                    }
                },
                additionalProperties: false,
                minProperties: 1
            }
        ]
    };
    /**
     * Normalizes a given option value.
     * @param {string|Object|undefined} value An option value to parse.
     * @returns {{multiline: boolean, minProperties: number, consistent: boolean}} Normalized option object.
     */
    function normalizeOptionValue(value) {
        let multiline = false;
        let minProperties = Number.POSITIVE_INFINITY;
        let consistent = false;
        if (value) {
            if (value === "always") {
                minProperties = 0;
            }
            else if (value === "never") {
                minProperties = Number.POSITIVE_INFINITY;
            }
            else {
                multiline = Boolean(value.multiline);
                minProperties = value.minProperties || Number.POSITIVE_INFINITY;
                consistent = Boolean(value.consistent);
            }
        }
        else {
            consistent = true;
        }
        return { multiline, minProperties, consistent };
    }
    /**
     * Checks if a value is an object.
     * @param {any} value The value to check
     * @returns {boolean} `true` if the value is an object, otherwise `false`
     */
    function isObject(value) {
        return typeof value === "object" && value !== null;
    }
    /**
     * Checks if an option is a node-specific option
     * @param {any} option The option to check
     * @returns {boolean} `true` if the option is node-specific, otherwise `false`
     */
    function isNodeSpecificOption(option) {
        return isObject(option) || typeof option === "string";
    }
    /**
     * Normalizes a given option value.
     * @param {string|Object|undefined} options An option value to parse.
     * @returns {{
     *   ObjectExpression: {multiline: boolean, minProperties: number, consistent: boolean},
     *   ObjectPattern: {multiline: boolean, minProperties: number, consistent: boolean},
     *   ImportDeclaration: {multiline: boolean, minProperties: number, consistent: boolean},
     *   ExportNamedDeclaration : {multiline: boolean, minProperties: number, consistent: boolean}
     * }} Normalized option object.
     */
    function normalizeOptions(options) {
        if (isObject(options) && Object.values(options).some(isNodeSpecificOption)) {
            return {
                ObjectExpression: normalizeOptionValue(options.ObjectExpression),
                ObjectPattern: normalizeOptionValue(options.ObjectPattern),
                ImportDeclaration: normalizeOptionValue(options.ImportDeclaration),
                ExportNamedDeclaration: normalizeOptionValue(options.ExportDeclaration)
            };
        }
        const value = normalizeOptionValue(options);
        return { ObjectExpression: value, ObjectPattern: value, ImportDeclaration: value, ExportNamedDeclaration: value };
    }
    /**
     * Determines if ObjectExpression, ObjectPattern, ImportDeclaration or ExportNamedDeclaration
     * node needs to be checked for missing line breaks
     * @param {ASTNode} node Node under inspection
     * @param {Object} options option specific to node type
     * @param {Token} first First object property
     * @param {Token} last Last object property
     * @returns {boolean} `true` if node needs to be checked for missing line breaks
     */
    function areLineBreaksRequired(node, options, first, last) {
        let objectProperties;
        if (node.type === "ObjectExpression" || node.type === "ObjectPattern") {
            objectProperties = node.properties;
        }
        else {
            // is ImportDeclaration or ExportNamedDeclaration
            objectProperties = node.specifiers
                .filter(s => s.type === "ImportSpecifier" || s.type === "ExportSpecifier");
        }
        return objectProperties.length >= options.minProperties ||
            (options.multiline &&
                objectProperties.length > 0 &&
                first.loc.start.line !== last.loc.end.line);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent line breaks after opening and before closing braces",
                recommended: false,
                url: "https://eslint.org/docs/rules/object-curly-newline"
            },
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        OPTION_VALUE,
                        {
                            type: "object",
                            properties: {
                                ObjectExpression: OPTION_VALUE,
                                ObjectPattern: OPTION_VALUE,
                                ImportDeclaration: OPTION_VALUE,
                                ExportDeclaration: OPTION_VALUE
                            },
                            additionalProperties: false,
                            minProperties: 1
                        }
                    ]
                }
            ],
            messages: {
                unexpectedLinebreakBeforeClosingBrace: "Unexpected line break before this closing brace.",
                unexpectedLinebreakAfterOpeningBrace: "Unexpected line break after this opening brace.",
                expectedLinebreakBeforeClosingBrace: "Expected a line break before this closing brace.",
                expectedLinebreakAfterOpeningBrace: "Expected a line break after this opening brace."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const normalizedOptions = normalizeOptions(context.options[0]);
            /**
             * Reports a given node if it violated this rule.
             * @param {ASTNode} node A node to check. This is an ObjectExpression, ObjectPattern, ImportDeclaration or ExportNamedDeclaration node.
             * @returns {void}
             */
            function check(node) {
                const options = normalizedOptions[node.type];
                if ((node.type === "ImportDeclaration" &&
                    !node.specifiers.some(specifier => specifier.type === "ImportSpecifier")) ||
                    (node.type === "ExportNamedDeclaration" &&
                        !node.specifiers.some(specifier => specifier.type === "ExportSpecifier"))) {
                    return;
                }
                const openBrace = sourceCode.getFirstToken(node, token => token.value === "{");
                let closeBrace;
                if (node.typeAnnotation) {
                    closeBrace = sourceCode.getTokenBefore(node.typeAnnotation);
                }
                else {
                    closeBrace = sourceCode.getLastToken(node, token => token.value === "}");
                }
                let first = sourceCode.getTokenAfter(openBrace, { includeComments: true });
                let last = sourceCode.getTokenBefore(closeBrace, { includeComments: true });
                const needsLineBreaks = areLineBreaksRequired(node, options, first, last);
                const hasCommentsFirstToken = astUtils.isCommentToken(first);
                const hasCommentsLastToken = astUtils.isCommentToken(last);
                /*
                 * Use tokens or comments to check multiline or not.
                 * But use only tokens to check whether line breaks are needed.
                 * This allows:
                 *     var obj = { // eslint-disable-line foo
                 *         a: 1
                 *     }
                 */
                first = sourceCode.getTokenAfter(openBrace);
                last = sourceCode.getTokenBefore(closeBrace);
                if (needsLineBreaks) {
                    if (astUtils.isTokenOnSameLine(openBrace, first)) {
                        context.report({
                            messageId: "expectedLinebreakAfterOpeningBrace",
                            node,
                            loc: openBrace.loc,
                            fix(fixer) {
                                if (hasCommentsFirstToken) {
                                    return null;
                                }
                                return fixer.insertTextAfter(openBrace, "\n");
                            }
                        });
                    }
                    if (astUtils.isTokenOnSameLine(last, closeBrace)) {
                        context.report({
                            messageId: "expectedLinebreakBeforeClosingBrace",
                            node,
                            loc: closeBrace.loc,
                            fix(fixer) {
                                if (hasCommentsLastToken) {
                                    return null;
                                }
                                return fixer.insertTextBefore(closeBrace, "\n");
                            }
                        });
                    }
                }
                else {
                    const consistent = options.consistent;
                    const hasLineBreakBetweenOpenBraceAndFirst = !astUtils.isTokenOnSameLine(openBrace, first);
                    const hasLineBreakBetweenCloseBraceAndLast = !astUtils.isTokenOnSameLine(last, closeBrace);
                    if ((!consistent && hasLineBreakBetweenOpenBraceAndFirst) ||
                        (consistent && hasLineBreakBetweenOpenBraceAndFirst && !hasLineBreakBetweenCloseBraceAndLast)) {
                        context.report({
                            messageId: "unexpectedLinebreakAfterOpeningBrace",
                            node,
                            loc: openBrace.loc,
                            fix(fixer) {
                                if (hasCommentsFirstToken) {
                                    return null;
                                }
                                return fixer.removeRange([
                                    openBrace.range[1],
                                    first.range[0]
                                ]);
                            }
                        });
                    }
                    if ((!consistent && hasLineBreakBetweenCloseBraceAndLast) ||
                        (consistent && !hasLineBreakBetweenOpenBraceAndFirst && hasLineBreakBetweenCloseBraceAndLast)) {
                        context.report({
                            messageId: "unexpectedLinebreakBeforeClosingBrace",
                            node,
                            loc: closeBrace.loc,
                            fix(fixer) {
                                if (hasCommentsLastToken) {
                                    return null;
                                }
                                return fixer.removeRange([
                                    last.range[1],
                                    closeBrace.range[0]
                                ]);
                            }
                        });
                    }
                }
            }
            return {
                ObjectExpression: check,
                ObjectPattern: check,
                ImportDeclaration: check,
                ExportNamedDeclaration: check
            };
        }
    };
},
/* eslint/lib/rules/object-curly-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallows or enforces spaces inside of object literals.
     * @author Jamund Ferguson
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing inside braces",
                recommended: false,
                url: "https://eslint.org/docs/rules/object-curly-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never"]
                },
                {
                    type: "object",
                    properties: {
                        arraysInObjects: {
                            type: "boolean"
                        },
                        objectsInObjects: {
                            type: "boolean"
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                requireSpaceBefore: "A space is required before '{{token}}'.",
                requireSpaceAfter: "A space is required after '{{token}}'.",
                unexpectedSpaceBefore: "There should be no space before '{{token}}'.",
                unexpectedSpaceAfter: "There should be no space after '{{token}}'."
            }
        },
        create(context) {
            const spaced = context.options[0] === "always", sourceCode = context.getSourceCode();
            /**
             * Determines whether an option is set, relative to the spacing option.
             * If spaced is "always", then check whether option is set to false.
             * If spaced is "never", then check whether option is set to true.
             * @param {Object} option The option to exclude.
             * @returns {boolean} Whether or not the property is excluded.
             */
            function isOptionSet(option) {
                return context.options[1] ? context.options[1][option] === !spaced : false;
            }
            const options = {
                spaced,
                arraysInObjectsException: isOptionSet("arraysInObjects"),
                objectsInObjectsException: isOptionSet("objectsInObjects")
            };
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Reports that there shouldn't be a space after the first token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportNoBeginningSpace(node, token) {
                const nextToken = context.getSourceCode().getTokenAfter(token, { includeComments: true });
                context.report({
                    node,
                    loc: { start: token.loc.end, end: nextToken.loc.start },
                    messageId: "unexpectedSpaceAfter",
                    data: {
                        token: token.value
                    },
                    fix(fixer) {
                        return fixer.removeRange([token.range[1], nextToken.range[0]]);
                    }
                });
            }
            /**
             * Reports that there shouldn't be a space before the last token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportNoEndingSpace(node, token) {
                const previousToken = context.getSourceCode().getTokenBefore(token, { includeComments: true });
                context.report({
                    node,
                    loc: { start: previousToken.loc.end, end: token.loc.start },
                    messageId: "unexpectedSpaceBefore",
                    data: {
                        token: token.value
                    },
                    fix(fixer) {
                        return fixer.removeRange([previousToken.range[1], token.range[0]]);
                    }
                });
            }
            /**
             * Reports that there should be a space after the first token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportRequiredBeginningSpace(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "requireSpaceAfter",
                    data: {
                        token: token.value
                    },
                    fix(fixer) {
                        return fixer.insertTextAfter(token, " ");
                    }
                });
            }
            /**
             * Reports that there should be a space before the last token
             * @param {ASTNode} node The node to report in the event of an error.
             * @param {Token} token The token to use for the report.
             * @returns {void}
             */
            function reportRequiredEndingSpace(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: "requireSpaceBefore",
                    data: {
                        token: token.value
                    },
                    fix(fixer) {
                        return fixer.insertTextBefore(token, " ");
                    }
                });
            }
            /**
             * Determines if spacing in curly braces is valid.
             * @param {ASTNode} node The AST node to check.
             * @param {Token} first The first token to check (should be the opening brace)
             * @param {Token} second The second token to check (should be first after the opening brace)
             * @param {Token} penultimate The penultimate token to check (should be last before closing brace)
             * @param {Token} last The last token to check (should be closing brace)
             * @returns {void}
             */
            function validateBraceSpacing(node, first, second, penultimate, last) {
                if (astUtils.isTokenOnSameLine(first, second)) {
                    const firstSpaced = sourceCode.isSpaceBetweenTokens(first, second);
                    if (options.spaced && !firstSpaced) {
                        reportRequiredBeginningSpace(node, first);
                    }
                    if (!options.spaced && firstSpaced && second.type !== "Line") {
                        reportNoBeginningSpace(node, first);
                    }
                }
                if (astUtils.isTokenOnSameLine(penultimate, last)) {
                    const shouldCheckPenultimate = (options.arraysInObjectsException && astUtils.isClosingBracketToken(penultimate) ||
                        options.objectsInObjectsException && astUtils.isClosingBraceToken(penultimate));
                    const penultimateType = shouldCheckPenultimate && sourceCode.getNodeByRangeIndex(penultimate.range[0]).type;
                    const closingCurlyBraceMustBeSpaced = (options.arraysInObjectsException && penultimateType === "ArrayExpression" ||
                        options.objectsInObjectsException && (penultimateType === "ObjectExpression" || penultimateType === "ObjectPattern")) ? !options.spaced : options.spaced;
                    const lastSpaced = sourceCode.isSpaceBetweenTokens(penultimate, last);
                    if (closingCurlyBraceMustBeSpaced && !lastSpaced) {
                        reportRequiredEndingSpace(node, last);
                    }
                    if (!closingCurlyBraceMustBeSpaced && lastSpaced) {
                        reportNoEndingSpace(node, last);
                    }
                }
            }
            /**
             * Gets '}' token of an object node.
             *
             * Because the last token of object patterns might be a type annotation,
             * this traverses tokens preceded by the last property, then returns the
             * first '}' token.
             * @param {ASTNode} node The node to get. This node is an
             *      ObjectExpression or an ObjectPattern. And this node has one or
             *      more properties.
             * @returns {Token} '}' token.
             */
            function getClosingBraceOfObject(node) {
                const lastProperty = node.properties[node.properties.length - 1];
                return sourceCode.getTokenAfter(lastProperty, astUtils.isClosingBraceToken);
            }
            /**
             * Reports a given object node if spacing in curly braces is invalid.
             * @param {ASTNode} node An ObjectExpression or ObjectPattern node to check.
             * @returns {void}
             */
            function checkForObject(node) {
                if (node.properties.length === 0) {
                    return;
                }
                const first = sourceCode.getFirstToken(node), last = getClosingBraceOfObject(node), second = sourceCode.getTokenAfter(first, { includeComments: true }), penultimate = sourceCode.getTokenBefore(last, { includeComments: true });
                validateBraceSpacing(node, first, second, penultimate, last);
            }
            /**
             * Reports a given import node if spacing in curly braces is invalid.
             * @param {ASTNode} node An ImportDeclaration node to check.
             * @returns {void}
             */
            function checkForImport(node) {
                if (node.specifiers.length === 0) {
                    return;
                }
                let firstSpecifier = node.specifiers[0];
                const lastSpecifier = node.specifiers[node.specifiers.length - 1];
                if (lastSpecifier.type !== "ImportSpecifier") {
                    return;
                }
                if (firstSpecifier.type !== "ImportSpecifier") {
                    firstSpecifier = node.specifiers[1];
                }
                const first = sourceCode.getTokenBefore(firstSpecifier), last = sourceCode.getTokenAfter(lastSpecifier, astUtils.isNotCommaToken), second = sourceCode.getTokenAfter(first, { includeComments: true }), penultimate = sourceCode.getTokenBefore(last, { includeComments: true });
                validateBraceSpacing(node, first, second, penultimate, last);
            }
            /**
             * Reports a given export node if spacing in curly braces is invalid.
             * @param {ASTNode} node An ExportNamedDeclaration node to check.
             * @returns {void}
             */
            function checkForExport(node) {
                if (node.specifiers.length === 0) {
                    return;
                }
                const firstSpecifier = node.specifiers[0], lastSpecifier = node.specifiers[node.specifiers.length - 1], first = sourceCode.getTokenBefore(firstSpecifier), last = sourceCode.getTokenAfter(lastSpecifier, astUtils.isNotCommaToken), second = sourceCode.getTokenAfter(first, { includeComments: true }), penultimate = sourceCode.getTokenBefore(last, { includeComments: true });
                validateBraceSpacing(node, first, second, penultimate, last);
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                // var {x} = y;
                ObjectPattern: checkForObject,
                // var y = {x: 'y'}
                ObjectExpression: checkForObject,
                // import {y} from 'x';
                ImportDeclaration: checkForImport,
                // export {name} from 'yo';
                ExportNamedDeclaration: checkForExport
            };
        }
    };
},
/* eslint/lib/rules/object-property-newline.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce placing object properties on separate lines.
     * @author Vitor Balocco
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce placing object properties on separate lines",
                recommended: false,
                url: "https://eslint.org/docs/rules/object-property-newline"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowAllPropertiesOnSameLine: {
                            type: "boolean",
                            default: false
                        },
                        allowMultiplePropertiesPerLine: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "whitespace",
            messages: {
                propertiesOnNewlineAll: "Object properties must go on a new line if they aren't all on the same line.",
                propertiesOnNewline: "Object properties must go on a new line."
            }
        },
        create(context) {
            const allowSameLine = context.options[0] && ((context.options[0].allowAllPropertiesOnSameLine || context.options[0].allowMultiplePropertiesPerLine /* Deprecated */));
            const messageId = allowSameLine
                ? "propertiesOnNewlineAll"
                : "propertiesOnNewline";
            const sourceCode = context.getSourceCode();
            return {
                ObjectExpression(node) {
                    if (allowSameLine) {
                        if (node.properties.length > 1) {
                            const firstTokenOfFirstProperty = sourceCode.getFirstToken(node.properties[0]);
                            const lastTokenOfLastProperty = sourceCode.getLastToken(node.properties[node.properties.length - 1]);
                            if (firstTokenOfFirstProperty.loc.end.line === lastTokenOfLastProperty.loc.start.line) {
                                // All keys and values are on the same line
                                return;
                            }
                        }
                    }
                    for (let i = 1; i < node.properties.length; i++) {
                        const lastTokenOfPreviousProperty = sourceCode.getLastToken(node.properties[i - 1]);
                        const firstTokenOfCurrentProperty = sourceCode.getFirstToken(node.properties[i]);
                        if (lastTokenOfPreviousProperty.loc.end.line === firstTokenOfCurrentProperty.loc.start.line) {
                            context.report({
                                node,
                                loc: firstTokenOfCurrentProperty.loc,
                                messageId,
                                fix(fixer) {
                                    const comma = sourceCode.getTokenBefore(firstTokenOfCurrentProperty);
                                    const rangeAfterComma = [comma.range[1], firstTokenOfCurrentProperty.range[0]];
                                    // Don't perform a fix if there are any comments between the comma and the next property.
                                    if (sourceCode.text.slice(rangeAfterComma[0], rangeAfterComma[1]).trim()) {
                                        return null;
                                    }
                                    return fixer.replaceTextRange(rangeAfterComma, "\n");
                                }
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/object-shorthand.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce concise object methods and properties.
     * @author Jamund Ferguson
     */
    "use strict";
    const OPTIONS = {
        always: "always",
        never: "never",
        methods: "methods",
        properties: "properties",
        consistent: "consistent",
        consistentAsNeeded: "consistent-as-needed"
    };
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require or disallow method and property shorthand syntax for object literals",
                recommended: false,
                url: "https://eslint.org/docs/rules/object-shorthand"
            },
            fixable: "code",
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always", "methods", "properties", "never", "consistent", "consistent-as-needed"]
                            }
                        ],
                        minItems: 0,
                        maxItems: 1
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always", "methods", "properties"]
                            },
                            {
                                type: "object",
                                properties: {
                                    avoidQuotes: {
                                        type: "boolean"
                                    }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always", "methods"]
                            },
                            {
                                type: "object",
                                properties: {
                                    ignoreConstructors: {
                                        type: "boolean"
                                    },
                                    methodsIgnorePattern: {
                                        type: "string"
                                    },
                                    avoidQuotes: {
                                        type: "boolean"
                                    },
                                    avoidExplicitReturnArrows: {
                                        type: "boolean"
                                    }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    }
                ]
            },
            messages: {
                expectedAllPropertiesShorthanded: "Expected shorthand for all properties.",
                expectedLiteralMethodLongform: "Expected longform method syntax for string literal keys.",
                expectedPropertyShorthand: "Expected property shorthand.",
                expectedPropertyLongform: "Expected longform property syntax.",
                expectedMethodShorthand: "Expected method shorthand.",
                expectedMethodLongform: "Expected longform method syntax.",
                unexpectedMix: "Unexpected mix of shorthand and non-shorthand properties."
            }
        },
        create(context) {
            const APPLY = context.options[0] || OPTIONS.always;
            const APPLY_TO_METHODS = APPLY === OPTIONS.methods || APPLY === OPTIONS.always;
            const APPLY_TO_PROPS = APPLY === OPTIONS.properties || APPLY === OPTIONS.always;
            const APPLY_NEVER = APPLY === OPTIONS.never;
            const APPLY_CONSISTENT = APPLY === OPTIONS.consistent;
            const APPLY_CONSISTENT_AS_NEEDED = APPLY === OPTIONS.consistentAsNeeded;
            const PARAMS = context.options[1] || {};
            const IGNORE_CONSTRUCTORS = PARAMS.ignoreConstructors;
            const METHODS_IGNORE_PATTERN = PARAMS.methodsIgnorePattern
                ? new RegExp(PARAMS.methodsIgnorePattern, "u")
                : null;
            const AVOID_QUOTES = PARAMS.avoidQuotes;
            const AVOID_EXPLICIT_RETURN_ARROWS = !!PARAMS.avoidExplicitReturnArrows;
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            const CTOR_PREFIX_REGEX = /[^_$0-9]/u;
            /**
             * Determines if the first character of the name is a capital letter.
             * @param {string} name The name of the node to evaluate.
             * @returns {boolean} True if the first character of the property name is a capital letter, false if not.
             * @private
             */
            function isConstructor(name) {
                const match = CTOR_PREFIX_REGEX.exec(name);
                // Not a constructor if name has no characters apart from '_', '$' and digits e.g. '_', '$$', '_8'
                if (!match) {
                    return false;
                }
                const firstChar = name.charAt(match.index);
                return firstChar === firstChar.toUpperCase();
            }
            /**
             * Determines if the property can have a shorthand form.
             * @param {ASTNode} property Property AST node
             * @returns {boolean} True if the property can have a shorthand form
             * @private
             */
            function canHaveShorthand(property) {
                return (property.kind !== "set" && property.kind !== "get" && property.type !== "SpreadElement" && property.type !== "SpreadProperty" && property.type !== "ExperimentalSpreadProperty");
            }
            /**
             * Checks whether a node is a string literal.
             * @param {ASTNode} node Any AST node.
             * @returns {boolean} `true` if it is a string literal.
             */
            function isStringLiteral(node) {
                return node.type === "Literal" && typeof node.value === "string";
            }
            /**
             * Determines if the property is a shorthand or not.
             * @param {ASTNode} property Property AST node
             * @returns {boolean} True if the property is considered shorthand, false if not.
             * @private
             */
            function isShorthand(property) {
                // property.method is true when `{a(){}}`.
                return (property.shorthand || property.method);
            }
            /**
             * Determines if the property's key and method or value are named equally.
             * @param {ASTNode} property Property AST node
             * @returns {boolean} True if the key and value are named equally, false if not.
             * @private
             */
            function isRedundant(property) {
                const value = property.value;
                if (value.type === "FunctionExpression") {
                    return !value.id; // Only anonymous should be shorthand method.
                }
                if (value.type === "Identifier") {
                    return astUtils.getStaticPropertyName(property) === value.name;
                }
                return false;
            }
            /**
             * Ensures that an object's properties are consistently shorthand, or not shorthand at all.
             * @param {ASTNode} node Property AST node
             * @param {boolean} checkRedundancy Whether to check longform redundancy
             * @returns {void}
             */
            function checkConsistency(node, checkRedundancy) {
                // We are excluding getters/setters and spread properties as they are considered neither longform nor shorthand.
                const properties = node.properties.filter(canHaveShorthand);
                // Do we still have properties left after filtering the getters and setters?
                if (properties.length > 0) {
                    const shorthandProperties = properties.filter(isShorthand);
                    /*
                     * If we do not have an equal number of longform properties as
                     * shorthand properties, we are using the annotations inconsistently
                     */
                    if (shorthandProperties.length !== properties.length) {
                        // We have at least 1 shorthand property
                        if (shorthandProperties.length > 0) {
                            context.report({ node, messageId: "unexpectedMix" });
                        }
                        else if (checkRedundancy) {
                            /*
                             * If all properties of the object contain a method or value with a name matching it's key,
                             * all the keys are redundant.
                             */
                            const canAlwaysUseShorthand = properties.every(isRedundant);
                            if (canAlwaysUseShorthand) {
                                context.report({ node, messageId: "expectedAllPropertiesShorthanded" });
                            }
                        }
                    }
                }
            }
            /**
             * Fixes a FunctionExpression node by making it into a shorthand property.
             * @param {SourceCodeFixer} fixer The fixer object
             * @param {ASTNode} node A `Property` node that has a `FunctionExpression` or `ArrowFunctionExpression` as its value
             * @returns {Object} A fix for this node
             */
            function makeFunctionShorthand(fixer, node) {
                const firstKeyToken = node.computed
                    ? sourceCode.getFirstToken(node, astUtils.isOpeningBracketToken)
                    : sourceCode.getFirstToken(node.key);
                const lastKeyToken = node.computed
                    ? sourceCode.getFirstTokenBetween(node.key, node.value, astUtils.isClosingBracketToken)
                    : sourceCode.getLastToken(node.key);
                const keyText = sourceCode.text.slice(firstKeyToken.range[0], lastKeyToken.range[1]);
                let keyPrefix = "";
                // key: /* */ () => {}
                if (sourceCode.commentsExistBetween(lastKeyToken, node.value)) {
                    return null;
                }
                if (node.value.async) {
                    keyPrefix += "async ";
                }
                if (node.value.generator) {
                    keyPrefix += "*";
                }
                const fixRange = [firstKeyToken.range[0], node.range[1]];
                const methodPrefix = keyPrefix + keyText;
                if (node.value.type === "FunctionExpression") {
                    const functionToken = sourceCode.getTokens(node.value).find(token => token.type === "Keyword" && token.value === "function");
                    const tokenBeforeParams = node.value.generator ? sourceCode.getTokenAfter(functionToken) : functionToken;
                    return fixer.replaceTextRange(fixRange, methodPrefix + sourceCode.text.slice(tokenBeforeParams.range[1], node.value.range[1]));
                }
                const arrowToken = sourceCode.getTokenBefore(node.value.body, astUtils.isArrowToken);
                const fnBody = sourceCode.text.slice(arrowToken.range[1], node.value.range[1]);
                let shouldAddParensAroundParameters = false;
                let tokenBeforeParams;
                if (node.value.params.length === 0) {
                    tokenBeforeParams = sourceCode.getFirstToken(node.value, astUtils.isOpeningParenToken);
                }
                else {
                    tokenBeforeParams = sourceCode.getTokenBefore(node.value.params[0]);
                }
                if (node.value.params.length === 1) {
                    const hasParen = astUtils.isOpeningParenToken(tokenBeforeParams);
                    const isTokenOutsideNode = tokenBeforeParams.range[0] < node.range[0];
                    shouldAddParensAroundParameters = !hasParen || isTokenOutsideNode;
                }
                const sliceStart = shouldAddParensAroundParameters
                    ? node.value.params[0].range[0]
                    : tokenBeforeParams.range[0];
                const sliceEnd = sourceCode.getTokenBefore(arrowToken).range[1];
                const oldParamText = sourceCode.text.slice(sliceStart, sliceEnd);
                const newParamText = shouldAddParensAroundParameters ? `(${oldParamText})` : oldParamText;
                return fixer.replaceTextRange(fixRange, methodPrefix + newParamText + fnBody);
            }
            /**
             * Fixes a FunctionExpression node by making it into a longform property.
             * @param {SourceCodeFixer} fixer The fixer object
             * @param {ASTNode} node A `Property` node that has a `FunctionExpression` as its value
             * @returns {Object} A fix for this node
             */
            function makeFunctionLongform(fixer, node) {
                const firstKeyToken = node.computed ? sourceCode.getTokens(node).find(token => token.value === "[") : sourceCode.getFirstToken(node.key);
                const lastKeyToken = node.computed ? sourceCode.getTokensBetween(node.key, node.value).find(token => token.value === "]") : sourceCode.getLastToken(node.key);
                const keyText = sourceCode.text.slice(firstKeyToken.range[0], lastKeyToken.range[1]);
                let functionHeader = "function";
                if (node.value.async) {
                    functionHeader = `async ${functionHeader}`;
                }
                if (node.value.generator) {
                    functionHeader = `${functionHeader}*`;
                }
                return fixer.replaceTextRange([node.range[0], lastKeyToken.range[1]], `${keyText}: ${functionHeader}`);
            }
            /*
             * To determine whether a given arrow function has a lexical identifier (`this`, `arguments`, `super`, or `new.target`),
             * create a stack of functions that define these identifiers (i.e. all functions except arrow functions) as the AST is
             * traversed. Whenever a new function is encountered, create a new entry on the stack (corresponding to a different lexical
             * scope of `this`), and whenever a function is exited, pop that entry off the stack. When an arrow function is entered,
             * keep a reference to it on the current stack entry, and remove that reference when the arrow function is exited.
             * When a lexical identifier is encountered, mark all the arrow functions on the current stack entry by adding them
             * to an `arrowsWithLexicalIdentifiers` set. Any arrow function in that set will not be reported by this rule,
             * because converting it into a method would change the value of one of the lexical identifiers.
             */
            const lexicalScopeStack = [];
            const arrowsWithLexicalIdentifiers = new WeakSet();
            const argumentsIdentifiers = new WeakSet();
            /**
             * Enters a function. This creates a new lexical identifier scope, so a new Set of arrow functions is pushed onto the stack.
             * Also, this marks all `arguments` identifiers so that they can be detected later.
             * @returns {void}
             */
            function enterFunction() {
                lexicalScopeStack.unshift(new Set());
                context.getScope().variables.filter(variable => variable.name === "arguments").forEach(variable => {
                    variable.references.map(ref => ref.identifier).forEach(identifier => argumentsIdentifiers.add(identifier));
                });
            }
            /**
             * Exits a function. This pops the current set of arrow functions off the lexical scope stack.
             * @returns {void}
             */
            function exitFunction() {
                lexicalScopeStack.shift();
            }
            /**
             * Marks the current function as having a lexical keyword. This implies that all arrow functions
             * in the current lexical scope contain a reference to this lexical keyword.
             * @returns {void}
             */
            function reportLexicalIdentifier() {
                lexicalScopeStack[0].forEach(arrowFunction => arrowsWithLexicalIdentifiers.add(arrowFunction));
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program: enterFunction,
                FunctionDeclaration: enterFunction,
                FunctionExpression: enterFunction,
                "Program:exit": exitFunction,
                "FunctionDeclaration:exit": exitFunction,
                "FunctionExpression:exit": exitFunction,
                ArrowFunctionExpression(node) {
                    lexicalScopeStack[0].add(node);
                },
                "ArrowFunctionExpression:exit"(node) {
                    lexicalScopeStack[0].delete(node);
                },
                ThisExpression: reportLexicalIdentifier,
                Super: reportLexicalIdentifier,
                MetaProperty(node) {
                    if (node.meta.name === "new" && node.property.name === "target") {
                        reportLexicalIdentifier();
                    }
                },
                Identifier(node) {
                    if (argumentsIdentifiers.has(node)) {
                        reportLexicalIdentifier();
                    }
                },
                ObjectExpression(node) {
                    if (APPLY_CONSISTENT) {
                        checkConsistency(node, false);
                    }
                    else if (APPLY_CONSISTENT_AS_NEEDED) {
                        checkConsistency(node, true);
                    }
                },
                "Property:exit"(node) {
                    const isConciseProperty = node.method || node.shorthand;
                    // Ignore destructuring assignment
                    if (node.parent.type === "ObjectPattern") {
                        return;
                    }
                    // getters and setters are ignored
                    if (node.kind === "get" || node.kind === "set") {
                        return;
                    }
                    // only computed methods can fail the following checks
                    if (node.computed && node.value.type !== "FunctionExpression" && node.value.type !== "ArrowFunctionExpression") {
                        return;
                    }
                    //--------------------------------------------------------------
                    // Checks for property/method shorthand.
                    if (isConciseProperty) {
                        if (node.method && (APPLY_NEVER || AVOID_QUOTES && isStringLiteral(node.key))) {
                            const messageId = APPLY_NEVER ? "expectedMethodLongform" : "expectedLiteralMethodLongform";
                            // { x() {} } should be written as { x: function() {} }
                            context.report({
                                node,
                                messageId,
                                fix: fixer => makeFunctionLongform(fixer, node)
                            });
                        }
                        else if (APPLY_NEVER) {
                            // { x } should be written as { x: x }
                            context.report({
                                node,
                                messageId: "expectedPropertyLongform",
                                fix: fixer => fixer.insertTextAfter(node.key, `: ${node.key.name}`)
                            });
                        }
                    }
                    else if (APPLY_TO_METHODS && !node.value.id && (node.value.type === "FunctionExpression" || node.value.type === "ArrowFunctionExpression")) {
                        if (IGNORE_CONSTRUCTORS && node.key.type === "Identifier" && isConstructor(node.key.name)) {
                            return;
                        }
                        if (METHODS_IGNORE_PATTERN) {
                            const propertyName = astUtils.getStaticPropertyName(node);
                            if (propertyName !== null && METHODS_IGNORE_PATTERN.test(propertyName)) {
                                return;
                            }
                        }
                        if (AVOID_QUOTES && isStringLiteral(node.key)) {
                            return;
                        }
                        // {[x]: function(){}} should be written as {[x]() {}}
                        if (node.value.type === "FunctionExpression" ||
                            node.value.type === "ArrowFunctionExpression" &&
                                node.value.body.type === "BlockStatement" &&
                                AVOID_EXPLICIT_RETURN_ARROWS &&
                                !arrowsWithLexicalIdentifiers.has(node.value)) {
                            context.report({
                                node,
                                messageId: "expectedMethodShorthand",
                                fix: fixer => makeFunctionShorthand(fixer, node)
                            });
                        }
                    }
                    else if (node.value.type === "Identifier" && node.key.name === node.value.name && APPLY_TO_PROPS) {
                        // {x: x} should be written as {x}
                        context.report({
                            node,
                            messageId: "expectedPropertyShorthand",
                            fix(fixer) {
                                return fixer.replaceText(node, node.value.name);
                            }
                        });
                    }
                    else if (node.value.type === "Identifier" && node.key.type === "Literal" && node.key.value === node.value.name && APPLY_TO_PROPS) {
                        if (AVOID_QUOTES) {
                            return;
                        }
                        // {"x": x} should be written as {x}
                        context.report({
                            node,
                            messageId: "expectedPropertyShorthand",
                            fix(fixer) {
                                return fixer.replaceText(node, node.value.name);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/one-var.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to control the use of single variable declarations.
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Determines whether the given node is in a statement list.
     * @param {ASTNode} node node to check
     * @returns {boolean} `true` if the given node is in a statement list
     */
    function isInStatementList(node) {
        return astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce variables to be declared either together or separately in functions",
                recommended: false,
                url: "https://eslint.org/docs/rules/one-var"
            },
            fixable: "code",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["always", "never", "consecutive"]
                        },
                        {
                            type: "object",
                            properties: {
                                separateRequires: {
                                    type: "boolean"
                                },
                                var: {
                                    enum: ["always", "never", "consecutive"]
                                },
                                let: {
                                    enum: ["always", "never", "consecutive"]
                                },
                                const: {
                                    enum: ["always", "never", "consecutive"]
                                }
                            },
                            additionalProperties: false
                        },
                        {
                            type: "object",
                            properties: {
                                initialized: {
                                    enum: ["always", "never", "consecutive"]
                                },
                                uninitialized: {
                                    enum: ["always", "never", "consecutive"]
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                combineUninitialized: "Combine this with the previous '{{type}}' statement with uninitialized variables.",
                combineInitialized: "Combine this with the previous '{{type}}' statement with initialized variables.",
                splitUninitialized: "Split uninitialized '{{type}}' declarations into multiple statements.",
                splitInitialized: "Split initialized '{{type}}' declarations into multiple statements.",
                splitRequires: "Split requires to be separated into a single block.",
                combine: "Combine this with the previous '{{type}}' statement.",
                split: "Split '{{type}}' declarations into multiple statements."
            }
        },
        create(context) {
            const MODE_ALWAYS = "always";
            const MODE_NEVER = "never";
            const MODE_CONSECUTIVE = "consecutive";
            const mode = context.options[0] || MODE_ALWAYS;
            const options = {};
            if (typeof mode === "string") { // simple options configuration with just a string
                options.var = { uninitialized: mode, initialized: mode };
                options.let = { uninitialized: mode, initialized: mode };
                options.const = { uninitialized: mode, initialized: mode };
            }
            else if (typeof mode === "object") { // options configuration is an object
                options.separateRequires = !!mode.separateRequires;
                options.var = { uninitialized: mode.var, initialized: mode.var };
                options.let = { uninitialized: mode.let, initialized: mode.let };
                options.const = { uninitialized: mode.const, initialized: mode.const };
                if (Object.prototype.hasOwnProperty.call(mode, "uninitialized")) {
                    options.var.uninitialized = mode.uninitialized;
                    options.let.uninitialized = mode.uninitialized;
                    options.const.uninitialized = mode.uninitialized;
                }
                if (Object.prototype.hasOwnProperty.call(mode, "initialized")) {
                    options.var.initialized = mode.initialized;
                    options.let.initialized = mode.initialized;
                    options.const.initialized = mode.initialized;
                }
            }
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            const functionStack = [];
            const blockStack = [];
            /**
             * Increments the blockStack counter.
             * @returns {void}
             * @private
             */
            function startBlock() {
                blockStack.push({
                    let: { initialized: false, uninitialized: false },
                    const: { initialized: false, uninitialized: false }
                });
            }
            /**
             * Increments the functionStack counter.
             * @returns {void}
             * @private
             */
            function startFunction() {
                functionStack.push({ initialized: false, uninitialized: false });
                startBlock();
            }
            /**
             * Decrements the blockStack counter.
             * @returns {void}
             * @private
             */
            function endBlock() {
                blockStack.pop();
            }
            /**
             * Decrements the functionStack counter.
             * @returns {void}
             * @private
             */
            function endFunction() {
                functionStack.pop();
                endBlock();
            }
            /**
             * Check if a variable declaration is a require.
             * @param {ASTNode} decl variable declaration Node
             * @returns {bool} if decl is a require, return true; else return false.
             * @private
             */
            function isRequire(decl) {
                return decl.init && decl.init.type === "CallExpression" && decl.init.callee.name === "require";
            }
            /**
             * Records whether initialized/uninitialized/required variables are defined in current scope.
             * @param {string} statementType node.kind, one of: "var", "let", or "const"
             * @param {ASTNode[]} declarations List of declarations
             * @param {Object} currentScope The scope being investigated
             * @returns {void}
             * @private
             */
            function recordTypes(statementType, declarations, currentScope) {
                for (let i = 0; i < declarations.length; i++) {
                    if (declarations[i].init === null) {
                        if (options[statementType] && options[statementType].uninitialized === MODE_ALWAYS) {
                            currentScope.uninitialized = true;
                        }
                    }
                    else {
                        if (options[statementType] && options[statementType].initialized === MODE_ALWAYS) {
                            if (options.separateRequires && isRequire(declarations[i])) {
                                currentScope.required = true;
                            }
                            else {
                                currentScope.initialized = true;
                            }
                        }
                    }
                }
            }
            /**
             * Determines the current scope (function or block)
             * @param {string} statementType node.kind, one of: "var", "let", or "const"
             * @returns {Object} The scope associated with statementType
             */
            function getCurrentScope(statementType) {
                let currentScope;
                if (statementType === "var") {
                    currentScope = functionStack[functionStack.length - 1];
                }
                else if (statementType === "let") {
                    currentScope = blockStack[blockStack.length - 1].let;
                }
                else if (statementType === "const") {
                    currentScope = blockStack[blockStack.length - 1].const;
                }
                return currentScope;
            }
            /**
             * Counts the number of initialized and uninitialized declarations in a list of declarations
             * @param {ASTNode[]} declarations List of declarations
             * @returns {Object} Counts of 'uninitialized' and 'initialized' declarations
             * @private
             */
            function countDeclarations(declarations) {
                const counts = { uninitialized: 0, initialized: 0 };
                for (let i = 0; i < declarations.length; i++) {
                    if (declarations[i].init === null) {
                        counts.uninitialized++;
                    }
                    else {
                        counts.initialized++;
                    }
                }
                return counts;
            }
            /**
             * Determines if there is more than one var statement in the current scope.
             * @param {string} statementType node.kind, one of: "var", "let", or "const"
             * @param {ASTNode[]} declarations List of declarations
             * @returns {boolean} Returns true if it is the first var declaration, false if not.
             * @private
             */
            function hasOnlyOneStatement(statementType, declarations) {
                const declarationCounts = countDeclarations(declarations);
                const currentOptions = options[statementType] || {};
                const currentScope = getCurrentScope(statementType);
                const hasRequires = declarations.some(isRequire);
                if (currentOptions.uninitialized === MODE_ALWAYS && currentOptions.initialized === MODE_ALWAYS) {
                    if (currentScope.uninitialized || currentScope.initialized) {
                        if (!hasRequires) {
                            return false;
                        }
                    }
                }
                if (declarationCounts.uninitialized > 0) {
                    if (currentOptions.uninitialized === MODE_ALWAYS && currentScope.uninitialized) {
                        return false;
                    }
                }
                if (declarationCounts.initialized > 0) {
                    if (currentOptions.initialized === MODE_ALWAYS && currentScope.initialized) {
                        if (!hasRequires) {
                            return false;
                        }
                    }
                }
                if (currentScope.required && hasRequires) {
                    return false;
                }
                recordTypes(statementType, declarations, currentScope);
                return true;
            }
            /**
             * Fixer to join VariableDeclaration's into a single declaration
             * @param {VariableDeclarator[]} declarations The `VariableDeclaration` to join
             * @returns {Function} The fixer function
             */
            function joinDeclarations(declarations) {
                const declaration = declarations[0];
                const body = Array.isArray(declaration.parent.parent.body) ? declaration.parent.parent.body : [];
                const currentIndex = body.findIndex(node => node.range[0] === declaration.parent.range[0]);
                const previousNode = body[currentIndex - 1];
                return fixer => {
                    const type = sourceCode.getTokenBefore(declaration);
                    const prevSemi = sourceCode.getTokenBefore(type);
                    const res = [];
                    if (previousNode && previousNode.kind === sourceCode.getText(type)) {
                        if (prevSemi.value === ";") {
                            res.push(fixer.replaceText(prevSemi, ","));
                        }
                        else {
                            res.push(fixer.insertTextAfter(prevSemi, ","));
                        }
                        res.push(fixer.replaceText(type, ""));
                    }
                    return res;
                };
            }
            /**
             * Fixer to split a VariableDeclaration into individual declarations
             * @param {VariableDeclaration} declaration The `VariableDeclaration` to split
             * @returns {Function|null} The fixer function
             */
            function splitDeclarations(declaration) {
                const { parent } = declaration;
                // don't autofix code such as: if (foo) var x, y;
                if (!isInStatementList(parent.type === "ExportNamedDeclaration" ? parent : declaration)) {
                    return null;
                }
                return fixer => declaration.declarations.map(declarator => {
                    const tokenAfterDeclarator = sourceCode.getTokenAfter(declarator);
                    if (tokenAfterDeclarator === null) {
                        return null;
                    }
                    const afterComma = sourceCode.getTokenAfter(tokenAfterDeclarator, { includeComments: true });
                    if (tokenAfterDeclarator.value !== ",") {
                        return null;
                    }
                    const exportPlacement = declaration.parent.type === "ExportNamedDeclaration" ? "export " : "";
                    /*
                     * `var x,y`
                     * tokenAfterDeclarator ^^ afterComma
                     */
                    if (afterComma.range[0] === tokenAfterDeclarator.range[1]) {
                        return fixer.replaceText(tokenAfterDeclarator, `; ${exportPlacement}${declaration.kind} `);
                    }
                    /*
                     * `var x,
                     * tokenAfterDeclarator ^
                     *      y`
                     *      ^ afterComma
                     */
                    if (afterComma.loc.start.line > tokenAfterDeclarator.loc.end.line ||
                        afterComma.type === "Line" ||
                        afterComma.type === "Block") {
                        let lastComment = afterComma;
                        while (lastComment.type === "Line" || lastComment.type === "Block") {
                            lastComment = sourceCode.getTokenAfter(lastComment, { includeComments: true });
                        }
                        return fixer.replaceTextRange([tokenAfterDeclarator.range[0], lastComment.range[0]], `;${sourceCode.text.slice(tokenAfterDeclarator.range[1], lastComment.range[0])}${exportPlacement}${declaration.kind} `);
                    }
                    return fixer.replaceText(tokenAfterDeclarator, `; ${exportPlacement}${declaration.kind}`);
                }).filter(x => x);
            }
            /**
             * Checks a given VariableDeclaration node for errors.
             * @param {ASTNode} node The VariableDeclaration node to check
             * @returns {void}
             * @private
             */
            function checkVariableDeclaration(node) {
                const parent = node.parent;
                const type = node.kind;
                if (!options[type]) {
                    return;
                }
                const declarations = node.declarations;
                const declarationCounts = countDeclarations(declarations);
                const mixedRequires = declarations.some(isRequire) && !declarations.every(isRequire);
                if (options[type].initialized === MODE_ALWAYS) {
                    if (options.separateRequires && mixedRequires) {
                        context.report({
                            node,
                            messageId: "splitRequires"
                        });
                    }
                }
                // consecutive
                const nodeIndex = (parent.body && parent.body.length > 0 && parent.body.indexOf(node)) || 0;
                if (nodeIndex > 0) {
                    const previousNode = parent.body[nodeIndex - 1];
                    const isPreviousNodeDeclaration = previousNode.type === "VariableDeclaration";
                    const declarationsWithPrevious = declarations.concat(previousNode.declarations || []);
                    if (isPreviousNodeDeclaration &&
                        previousNode.kind === type &&
                        !(declarationsWithPrevious.some(isRequire) && !declarationsWithPrevious.every(isRequire))) {
                        const previousDeclCounts = countDeclarations(previousNode.declarations);
                        if (options[type].initialized === MODE_CONSECUTIVE && options[type].uninitialized === MODE_CONSECUTIVE) {
                            context.report({
                                node,
                                messageId: "combine",
                                data: {
                                    type
                                },
                                fix: joinDeclarations(declarations)
                            });
                        }
                        else if (options[type].initialized === MODE_CONSECUTIVE && declarationCounts.initialized > 0 && previousDeclCounts.initialized > 0) {
                            context.report({
                                node,
                                messageId: "combineInitialized",
                                data: {
                                    type
                                },
                                fix: joinDeclarations(declarations)
                            });
                        }
                        else if (options[type].uninitialized === MODE_CONSECUTIVE &&
                            declarationCounts.uninitialized > 0 &&
                            previousDeclCounts.uninitialized > 0) {
                            context.report({
                                node,
                                messageId: "combineUninitialized",
                                data: {
                                    type
                                },
                                fix: joinDeclarations(declarations)
                            });
                        }
                    }
                }
                // always
                if (!hasOnlyOneStatement(type, declarations)) {
                    if (options[type].initialized === MODE_ALWAYS && options[type].uninitialized === MODE_ALWAYS) {
                        context.report({
                            node,
                            messageId: "combine",
                            data: {
                                type
                            },
                            fix: joinDeclarations(declarations)
                        });
                    }
                    else {
                        if (options[type].initialized === MODE_ALWAYS && declarationCounts.initialized > 0) {
                            context.report({
                                node,
                                messageId: "combineInitialized",
                                data: {
                                    type
                                },
                                fix: joinDeclarations(declarations)
                            });
                        }
                        if (options[type].uninitialized === MODE_ALWAYS && declarationCounts.uninitialized > 0) {
                            if (node.parent.left === node && (node.parent.type === "ForInStatement" || node.parent.type === "ForOfStatement")) {
                                return;
                            }
                            context.report({
                                node,
                                messageId: "combineUninitialized",
                                data: {
                                    type
                                },
                                fix: joinDeclarations(declarations)
                            });
                        }
                    }
                }
                // never
                if (parent.type !== "ForStatement" || parent.init !== node) {
                    const totalDeclarations = declarationCounts.uninitialized + declarationCounts.initialized;
                    if (totalDeclarations > 1) {
                        if (options[type].initialized === MODE_NEVER && options[type].uninitialized === MODE_NEVER) {
                            // both initialized and uninitialized
                            context.report({
                                node,
                                messageId: "split",
                                data: {
                                    type
                                },
                                fix: splitDeclarations(node)
                            });
                        }
                        else if (options[type].initialized === MODE_NEVER && declarationCounts.initialized > 0) {
                            // initialized
                            context.report({
                                node,
                                messageId: "splitInitialized",
                                data: {
                                    type
                                },
                                fix: splitDeclarations(node)
                            });
                        }
                        else if (options[type].uninitialized === MODE_NEVER && declarationCounts.uninitialized > 0) {
                            // uninitialized
                            context.report({
                                node,
                                messageId: "splitUninitialized",
                                data: {
                                    type
                                },
                                fix: splitDeclarations(node)
                            });
                        }
                    }
                }
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                Program: startFunction,
                FunctionDeclaration: startFunction,
                FunctionExpression: startFunction,
                ArrowFunctionExpression: startFunction,
                StaticBlock: startFunction,
                BlockStatement: startBlock,
                ForStatement: startBlock,
                ForInStatement: startBlock,
                ForOfStatement: startBlock,
                SwitchStatement: startBlock,
                VariableDeclaration: checkVariableDeclaration,
                "ForStatement:exit": endBlock,
                "ForOfStatement:exit": endBlock,
                "ForInStatement:exit": endBlock,
                "SwitchStatement:exit": endBlock,
                "BlockStatement:exit": endBlock,
                "Program:exit": endFunction,
                "FunctionDeclaration:exit": endFunction,
                "FunctionExpression:exit": endFunction,
                "ArrowFunctionExpression:exit": endFunction,
                "StaticBlock:exit": endFunction
            };
        }
    };
},
/* eslint/lib/rules/one-var-declaration-per-line.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to check multiple var declarations per line
     * @author Alberto Rodríguez
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require or disallow newlines around variable declarations",
                recommended: false,
                url: "https://eslint.org/docs/rules/one-var-declaration-per-line"
            },
            schema: [
                {
                    enum: ["always", "initializations"]
                }
            ],
            fixable: "whitespace",
            messages: {
                expectVarOnNewline: "Expected variable declaration to be on a new line."
            }
        },
        create(context) {
            const always = context.options[0] === "always";
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Determine if provided keyword is a variant of for specifiers
             * @private
             * @param {string} keyword keyword to test
             * @returns {boolean} True if `keyword` is a variant of for specifier
             */
            function isForTypeSpecifier(keyword) {
                return keyword === "ForStatement" || keyword === "ForInStatement" || keyword === "ForOfStatement";
            }
            /**
             * Checks newlines around variable declarations.
             * @private
             * @param {ASTNode} node `VariableDeclaration` node to test
             * @returns {void}
             */
            function checkForNewLine(node) {
                if (isForTypeSpecifier(node.parent.type)) {
                    return;
                }
                const declarations = node.declarations;
                let prev;
                declarations.forEach(current => {
                    if (prev && prev.loc.end.line === current.loc.start.line) {
                        if (always || prev.init || current.init) {
                            context.report({
                                node,
                                messageId: "expectVarOnNewline",
                                loc: current.loc,
                                fix: fixer => fixer.insertTextBefore(current, "\n")
                            });
                        }
                    }
                    prev = current;
                });
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                VariableDeclaration: checkForNewLine
            };
        }
    };
},
/* eslint/lib/rules/operator-assignment.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to replace assignment expressions with operator assignment
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether an operator is commutative and has an operator assignment
     * shorthand form.
     * @param {string} operator Operator to check.
     * @returns {boolean} True if the operator is commutative and has a
     *     shorthand form.
     */
    function isCommutativeOperatorWithShorthand(operator) {
        return ["*", "&", "^", "|"].includes(operator);
    }
    /**
     * Checks whether an operator is not commutative and has an operator assignment
     * shorthand form.
     * @param {string} operator Operator to check.
     * @returns {boolean} True if the operator is not commutative and has
     *     a shorthand form.
     */
    function isNonCommutativeOperatorWithShorthand(operator) {
        return ["+", "-", "/", "%", "<<", ">>", ">>>", "**"].includes(operator);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /**
     * Determines if the left side of a node can be safely fixed (i.e. if it activates the same getters/setters and)
     * toString calls regardless of whether assignment shorthand is used)
     * @param {ASTNode} node The node on the left side of the expression
     * @returns {boolean} `true` if the node can be fixed
     */
    function canBeFixed(node) {
        return (node.type === "Identifier" ||
            (node.type === "MemberExpression" &&
                (node.object.type === "Identifier" || node.object.type === "ThisExpression") &&
                (!node.computed || node.property.type === "Literal")));
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require or disallow assignment operator shorthand where possible",
                recommended: false,
                url: "https://eslint.org/docs/rules/operator-assignment"
            },
            schema: [
                {
                    enum: ["always", "never"]
                }
            ],
            fixable: "code",
            messages: {
                replaced: "Assignment (=) can be replaced with operator assignment ({{operator}}).",
                unexpected: "Unexpected operator assignment ({{operator}}) shorthand."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Returns the operator token of an AssignmentExpression or BinaryExpression
             * @param {ASTNode} node An AssignmentExpression or BinaryExpression node
             * @returns {Token} The operator token in the node
             */
            function getOperatorToken(node) {
                return sourceCode.getFirstTokenBetween(node.left, node.right, token => token.value === node.operator);
            }
            /**
             * Ensures that an assignment uses the shorthand form where possible.
             * @param {ASTNode} node An AssignmentExpression node.
             * @returns {void}
             */
            function verify(node) {
                if (node.operator !== "=" || node.right.type !== "BinaryExpression") {
                    return;
                }
                const left = node.left;
                const expr = node.right;
                const operator = expr.operator;
                if (isCommutativeOperatorWithShorthand(operator) || isNonCommutativeOperatorWithShorthand(operator)) {
                    const replacementOperator = `${operator}=`;
                    if (astUtils.isSameReference(left, expr.left, true)) {
                        context.report({
                            node,
                            messageId: "replaced",
                            data: { operator: replacementOperator },
                            fix(fixer) {
                                if (canBeFixed(left) && canBeFixed(expr.left)) {
                                    const equalsToken = getOperatorToken(node);
                                    const operatorToken = getOperatorToken(expr);
                                    const leftText = sourceCode.getText().slice(node.range[0], equalsToken.range[0]);
                                    const rightText = sourceCode.getText().slice(operatorToken.range[1], node.right.range[1]);
                                    // Check for comments that would be removed.
                                    if (sourceCode.commentsExistBetween(equalsToken, operatorToken)) {
                                        return null;
                                    }
                                    return fixer.replaceText(node, `${leftText}${replacementOperator}${rightText}`);
                                }
                                return null;
                            }
                        });
                    }
                    else if (astUtils.isSameReference(left, expr.right, true) && isCommutativeOperatorWithShorthand(operator)) {
                        /*
                         * This case can't be fixed safely.
                         * If `a` and `b` both have custom valueOf() behavior, then fixing `a = b * a` to `a *= b` would
                         * change the execution order of the valueOf() functions.
                         */
                        context.report({
                            node,
                            messageId: "replaced",
                            data: { operator: replacementOperator }
                        });
                    }
                }
            }
            /**
             * Warns if an assignment expression uses operator assignment shorthand.
             * @param {ASTNode} node An AssignmentExpression node.
             * @returns {void}
             */
            function prohibit(node) {
                if (node.operator !== "=" && !astUtils.isLogicalAssignmentOperator(node.operator)) {
                    context.report({
                        node,
                        messageId: "unexpected",
                        data: { operator: node.operator },
                        fix(fixer) {
                            if (canBeFixed(node.left)) {
                                const firstToken = sourceCode.getFirstToken(node);
                                const operatorToken = getOperatorToken(node);
                                const leftText = sourceCode.getText().slice(node.range[0], operatorToken.range[0]);
                                const newOperator = node.operator.slice(0, -1);
                                let rightText;
                                // Check for comments that would be duplicated.
                                if (sourceCode.commentsExistBetween(firstToken, operatorToken)) {
                                    return null;
                                }
                                // If this change would modify precedence (e.g. `foo *= bar + 1` => `foo = foo * (bar + 1)`), parenthesize the right side.
                                if (astUtils.getPrecedence(node.right) <= astUtils.getPrecedence({ type: "BinaryExpression", operator: newOperator }) &&
                                    !astUtils.isParenthesised(sourceCode, node.right)) {
                                    rightText = `${sourceCode.text.slice(operatorToken.range[1], node.right.range[0])}(${sourceCode.getText(node.right)})`;
                                }
                                else {
                                    const tokenAfterOperator = sourceCode.getTokenAfter(operatorToken, { includeComments: true });
                                    let rightTextPrefix = "";
                                    if (operatorToken.range[1] === tokenAfterOperator.range[0] &&
                                        !astUtils.canTokensBeAdjacent({ type: "Punctuator", value: newOperator }, tokenAfterOperator)) {
                                        rightTextPrefix = " "; // foo+=+bar -> foo= foo+ +bar
                                    }
                                    rightText = `${rightTextPrefix}${sourceCode.text.slice(operatorToken.range[1], node.range[1])}`;
                                }
                                return fixer.replaceText(node, `${leftText}= ${leftText}${newOperator}${rightText}`);
                            }
                            return null;
                        }
                    });
                }
            }
            return {
                AssignmentExpression: context.options[0] !== "never" ? verify : prohibit
            };
        }
    };
},
/* eslint/lib/rules/operator-linebreak.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Operator linebreak - enforces operator linebreak style of two types: after and before
     * @author Benoît Zugmeyer
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent linebreak style for operators",
                recommended: false,
                url: "https://eslint.org/docs/rules/operator-linebreak"
            },
            schema: [
                {
                    enum: ["after", "before", "none", null]
                },
                {
                    type: "object",
                    properties: {
                        overrides: {
                            type: "object",
                            additionalProperties: {
                                enum: ["after", "before", "none", "ignore"]
                            }
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "code",
            messages: {
                operatorAtBeginning: "'{{operator}}' should be placed at the beginning of the line.",
                operatorAtEnd: "'{{operator}}' should be placed at the end of the line.",
                badLinebreak: "Bad line breaking before and after '{{operator}}'.",
                noLinebreak: "There should be no line break before or after '{{operator}}'."
            }
        },
        create(context) {
            const usedDefaultGlobal = !context.options[0];
            const globalStyle = context.options[0] || "after";
            const options = context.options[1] || {};
            const styleOverrides = options.overrides ? Object.assign({}, options.overrides) : {};
            if (usedDefaultGlobal && !styleOverrides["?"]) {
                styleOverrides["?"] = "before";
            }
            if (usedDefaultGlobal && !styleOverrides[":"]) {
                styleOverrides[":"] = "before";
            }
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Gets a fixer function to fix rule issues
             * @param {Token} operatorToken The operator token of an expression
             * @param {string} desiredStyle The style for the rule. One of 'before', 'after', 'none'
             * @returns {Function} A fixer function
             */
            function getFixer(operatorToken, desiredStyle) {
                return fixer => {
                    const tokenBefore = sourceCode.getTokenBefore(operatorToken);
                    const tokenAfter = sourceCode.getTokenAfter(operatorToken);
                    const textBefore = sourceCode.text.slice(tokenBefore.range[1], operatorToken.range[0]);
                    const textAfter = sourceCode.text.slice(operatorToken.range[1], tokenAfter.range[0]);
                    const hasLinebreakBefore = !astUtils.isTokenOnSameLine(tokenBefore, operatorToken);
                    const hasLinebreakAfter = !astUtils.isTokenOnSameLine(operatorToken, tokenAfter);
                    let newTextBefore, newTextAfter;
                    if (hasLinebreakBefore !== hasLinebreakAfter && desiredStyle !== "none") {
                        // If there is a comment before and after the operator, don't do a fix.
                        if (sourceCode.getTokenBefore(operatorToken, { includeComments: true }) !== tokenBefore &&
                            sourceCode.getTokenAfter(operatorToken, { includeComments: true }) !== tokenAfter) {
                            return null;
                        }
                        /*
                         * If there is only one linebreak and it's on the wrong side of the operator, swap the text before and after the operator.
                         * foo &&
                         *           bar
                         * would get fixed to
                         * foo
                         *        && bar
                         */
                        newTextBefore = textAfter;
                        newTextAfter = textBefore;
                    }
                    else {
                        const LINEBREAK_REGEX = astUtils.createGlobalLinebreakMatcher();
                        // Otherwise, if no linebreak is desired and no comments interfere, replace the linebreaks with empty strings.
                        newTextBefore = desiredStyle === "before" || textBefore.trim() ? textBefore : textBefore.replace(LINEBREAK_REGEX, "");
                        newTextAfter = desiredStyle === "after" || textAfter.trim() ? textAfter : textAfter.replace(LINEBREAK_REGEX, "");
                        // If there was no change (due to interfering comments), don't output a fix.
                        if (newTextBefore === textBefore && newTextAfter === textAfter) {
                            return null;
                        }
                    }
                    if (newTextAfter === "" && tokenAfter.type === "Punctuator" && "+-".includes(operatorToken.value) && tokenAfter.value === operatorToken.value) {
                        // To avoid accidentally creating a ++ or -- operator, insert a space if the operator is a +/- and the following token is a unary +/-.
                        newTextAfter += " ";
                    }
                    return fixer.replaceTextRange([tokenBefore.range[1], tokenAfter.range[0]], newTextBefore + operatorToken.value + newTextAfter);
                };
            }
            /**
             * Checks the operator placement
             * @param {ASTNode} node The node to check
             * @param {ASTNode} rightSide The node that comes after the operator in `node`
             * @param {string} operator The operator
             * @private
             * @returns {void}
             */
            function validateNode(node, rightSide, operator) {
                /*
                 * Find the operator token by searching from the right side, because between the left side and the operator
                 * there could be additional tokens from type annotations. Search specifically for the token which
                 * value equals the operator, in order to skip possible opening parentheses before the right side node.
                 */
                const operatorToken = sourceCode.getTokenBefore(rightSide, token => token.value === operator);
                const leftToken = sourceCode.getTokenBefore(operatorToken);
                const rightToken = sourceCode.getTokenAfter(operatorToken);
                const operatorStyleOverride = styleOverrides[operator];
                const style = operatorStyleOverride || globalStyle;
                const fix = getFixer(operatorToken, style);
                // if single line
                if (astUtils.isTokenOnSameLine(leftToken, operatorToken) &&
                    astUtils.isTokenOnSameLine(operatorToken, rightToken)) {
                    // do nothing.
                }
                else if (operatorStyleOverride !== "ignore" && !astUtils.isTokenOnSameLine(leftToken, operatorToken) &&
                    !astUtils.isTokenOnSameLine(operatorToken, rightToken)) {
                    // lone operator
                    context.report({
                        node,
                        loc: operatorToken.loc,
                        messageId: "badLinebreak",
                        data: {
                            operator
                        },
                        fix
                    });
                }
                else if (style === "before" && astUtils.isTokenOnSameLine(leftToken, operatorToken)) {
                    context.report({
                        node,
                        loc: operatorToken.loc,
                        messageId: "operatorAtBeginning",
                        data: {
                            operator
                        },
                        fix
                    });
                }
                else if (style === "after" && astUtils.isTokenOnSameLine(operatorToken, rightToken)) {
                    context.report({
                        node,
                        loc: operatorToken.loc,
                        messageId: "operatorAtEnd",
                        data: {
                            operator
                        },
                        fix
                    });
                }
                else if (style === "none") {
                    context.report({
                        node,
                        loc: operatorToken.loc,
                        messageId: "noLinebreak",
                        data: {
                            operator
                        },
                        fix
                    });
                }
            }
            /**
             * Validates a binary expression using `validateNode`
             * @param {BinaryExpression|LogicalExpression|AssignmentExpression} node node to be validated
             * @returns {void}
             */
            function validateBinaryExpression(node) {
                validateNode(node, node.right, node.operator);
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                BinaryExpression: validateBinaryExpression,
                LogicalExpression: validateBinaryExpression,
                AssignmentExpression: validateBinaryExpression,
                VariableDeclarator(node) {
                    if (node.init) {
                        validateNode(node, node.init, "=");
                    }
                },
                PropertyDefinition(node) {
                    if (node.value) {
                        validateNode(node, node.value, "=");
                    }
                },
                ConditionalExpression(node) {
                    validateNode(node, node.consequent, "?");
                    validateNode(node, node.alternate, ":");
                }
            };
        }
    };
},
/* eslint/lib/rules/padded-blocks.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to ensure blank lines within blocks.
     * @author Mathias Schreck <https://github.com/lo1tuma>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow padding within blocks",
                recommended: false,
                url: "https://eslint.org/docs/rules/padded-blocks"
            },
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["always", "never"]
                        },
                        {
                            type: "object",
                            properties: {
                                blocks: {
                                    enum: ["always", "never"]
                                },
                                switches: {
                                    enum: ["always", "never"]
                                },
                                classes: {
                                    enum: ["always", "never"]
                                }
                            },
                            additionalProperties: false,
                            minProperties: 1
                        }
                    ]
                },
                {
                    type: "object",
                    properties: {
                        allowSingleLineBlocks: {
                            type: "boolean"
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                alwaysPadBlock: "Block must be padded by blank lines.",
                neverPadBlock: "Block must not be padded by blank lines."
            }
        },
        create(context) {
            const options = {};
            const typeOptions = context.options[0] || "always";
            const exceptOptions = context.options[1] || {};
            if (typeof typeOptions === "string") {
                const shouldHavePadding = typeOptions === "always";
                options.blocks = shouldHavePadding;
                options.switches = shouldHavePadding;
                options.classes = shouldHavePadding;
            }
            else {
                if (Object.prototype.hasOwnProperty.call(typeOptions, "blocks")) {
                    options.blocks = typeOptions.blocks === "always";
                }
                if (Object.prototype.hasOwnProperty.call(typeOptions, "switches")) {
                    options.switches = typeOptions.switches === "always";
                }
                if (Object.prototype.hasOwnProperty.call(typeOptions, "classes")) {
                    options.classes = typeOptions.classes === "always";
                }
            }
            if (Object.prototype.hasOwnProperty.call(exceptOptions, "allowSingleLineBlocks")) {
                options.allowSingleLineBlocks = exceptOptions.allowSingleLineBlocks === true;
            }
            const sourceCode = context.getSourceCode();
            /**
             * Gets the open brace token from a given node.
             * @param {ASTNode} node A BlockStatement or SwitchStatement node from which to get the open brace.
             * @returns {Token} The token of the open brace.
             */
            function getOpenBrace(node) {
                if (node.type === "SwitchStatement") {
                    return sourceCode.getTokenBefore(node.cases[0]);
                }
                if (node.type === "StaticBlock") {
                    return sourceCode.getFirstToken(node, { skip: 1 }); // skip the `static` token
                }
                // `BlockStatement` or `ClassBody`
                return sourceCode.getFirstToken(node);
            }
            /**
             * Checks if the given parameter is a comment node
             * @param {ASTNode|Token} node An AST node or token
             * @returns {boolean} True if node is a comment
             */
            function isComment(node) {
                return node.type === "Line" || node.type === "Block";
            }
            /**
             * Checks if there is padding between two tokens
             * @param {Token} first The first token
             * @param {Token} second The second token
             * @returns {boolean} True if there is at least a line between the tokens
             */
            function isPaddingBetweenTokens(first, second) {
                return second.loc.start.line - first.loc.end.line >= 2;
            }
            /**
             * Checks if the given token has a blank line after it.
             * @param {Token} token The token to check.
             * @returns {boolean} Whether or not the token is followed by a blank line.
             */
            function getFirstBlockToken(token) {
                let prev, first = token;
                do {
                    prev = first;
                    first = sourceCode.getTokenAfter(first, { includeComments: true });
                } while (isComment(first) && first.loc.start.line === prev.loc.end.line);
                return first;
            }
            /**
             * Checks if the given token is preceded by a blank line.
             * @param {Token} token The token to check
             * @returns {boolean} Whether or not the token is preceded by a blank line
             */
            function getLastBlockToken(token) {
                let last = token, next;
                do {
                    next = last;
                    last = sourceCode.getTokenBefore(last, { includeComments: true });
                } while (isComment(last) && last.loc.end.line === next.loc.start.line);
                return last;
            }
            /**
             * Checks if a node should be padded, according to the rule config.
             * @param {ASTNode} node The AST node to check.
             * @throws {Error} (Unreachable)
             * @returns {boolean} True if the node should be padded, false otherwise.
             */
            function requirePaddingFor(node) {
                switch (node.type) {
                    case "BlockStatement":
                    case "StaticBlock":
                        return options.blocks;
                    case "SwitchStatement":
                        return options.switches;
                    case "ClassBody":
                        return options.classes;
                    /* c8 ignore next */
                    default:
                        throw new Error("unreachable");
                }
            }
            /**
             * Checks the given BlockStatement node to be padded if the block is not empty.
             * @param {ASTNode} node The AST node of a BlockStatement.
             * @returns {void} undefined.
             */
            function checkPadding(node) {
                const openBrace = getOpenBrace(node), firstBlockToken = getFirstBlockToken(openBrace), tokenBeforeFirst = sourceCode.getTokenBefore(firstBlockToken, { includeComments: true }), closeBrace = sourceCode.getLastToken(node), lastBlockToken = getLastBlockToken(closeBrace), tokenAfterLast = sourceCode.getTokenAfter(lastBlockToken, { includeComments: true }), blockHasTopPadding = isPaddingBetweenTokens(tokenBeforeFirst, firstBlockToken), blockHasBottomPadding = isPaddingBetweenTokens(lastBlockToken, tokenAfterLast);
                if (options.allowSingleLineBlocks && astUtils.isTokenOnSameLine(tokenBeforeFirst, tokenAfterLast)) {
                    return;
                }
                if (requirePaddingFor(node)) {
                    if (!blockHasTopPadding) {
                        context.report({
                            node,
                            loc: {
                                start: tokenBeforeFirst.loc.start,
                                end: firstBlockToken.loc.start
                            },
                            fix(fixer) {
                                return fixer.insertTextAfter(tokenBeforeFirst, "\n");
                            },
                            messageId: "alwaysPadBlock"
                        });
                    }
                    if (!blockHasBottomPadding) {
                        context.report({
                            node,
                            loc: {
                                end: tokenAfterLast.loc.start,
                                start: lastBlockToken.loc.end
                            },
                            fix(fixer) {
                                return fixer.insertTextBefore(tokenAfterLast, "\n");
                            },
                            messageId: "alwaysPadBlock"
                        });
                    }
                }
                else {
                    if (blockHasTopPadding) {
                        context.report({
                            node,
                            loc: {
                                start: tokenBeforeFirst.loc.start,
                                end: firstBlockToken.loc.start
                            },
                            fix(fixer) {
                                return fixer.replaceTextRange([tokenBeforeFirst.range[1], firstBlockToken.range[0] - firstBlockToken.loc.start.column], "\n");
                            },
                            messageId: "neverPadBlock"
                        });
                    }
                    if (blockHasBottomPadding) {
                        context.report({
                            node,
                            loc: {
                                end: tokenAfterLast.loc.start,
                                start: lastBlockToken.loc.end
                            },
                            messageId: "neverPadBlock",
                            fix(fixer) {
                                return fixer.replaceTextRange([lastBlockToken.range[1], tokenAfterLast.range[0] - tokenAfterLast.loc.start.column], "\n");
                            }
                        });
                    }
                }
            }
            const rule = {};
            if (Object.prototype.hasOwnProperty.call(options, "switches")) {
                rule.SwitchStatement = function (node) {
                    if (node.cases.length === 0) {
                        return;
                    }
                    checkPadding(node);
                };
            }
            if (Object.prototype.hasOwnProperty.call(options, "blocks")) {
                rule.BlockStatement = function (node) {
                    if (node.body.length === 0) {
                        return;
                    }
                    checkPadding(node);
                };
                rule.StaticBlock = rule.BlockStatement;
            }
            if (Object.prototype.hasOwnProperty.call(options, "classes")) {
                rule.ClassBody = function (node) {
                    if (node.body.length === 0) {
                        return;
                    }
                    checkPadding(node);
                };
            }
            return rule;
        }
    };
},
/* eslint/lib/rules/padding-line-between-statements.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to require or disallow newlines between statements
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const LT = `[${Array.from(astUtils.LINEBREAKS).join("")}]`;
    const PADDING_LINE_SEQUENCE = new RegExp(String.raw `^(\s*?${LT})\s*${LT}(\s*;?)$`, "u");
    const CJS_EXPORT = /^(?:module\s*\.\s*)?exports(?:\s*\.|\s*\[|$)/u;
    const CJS_IMPORT = /^require\(/u;
    /**
     * Creates tester which check if a node starts with specific keyword.
     * @param {string} keyword The keyword to test.
     * @returns {Object} the created tester.
     * @private
     */
    function newKeywordTester(keyword) {
        return {
            test: (node, sourceCode) => sourceCode.getFirstToken(node).value === keyword
        };
    }
    /**
     * Creates tester which check if a node starts with specific keyword and spans a single line.
     * @param {string} keyword The keyword to test.
     * @returns {Object} the created tester.
     * @private
     */
    function newSinglelineKeywordTester(keyword) {
        return {
            test: (node, sourceCode) => node.loc.start.line === node.loc.end.line &&
                sourceCode.getFirstToken(node).value === keyword
        };
    }
    /**
     * Creates tester which check if a node starts with specific keyword and spans multiple lines.
     * @param {string} keyword The keyword to test.
     * @returns {Object} the created tester.
     * @private
     */
    function newMultilineKeywordTester(keyword) {
        return {
            test: (node, sourceCode) => node.loc.start.line !== node.loc.end.line &&
                sourceCode.getFirstToken(node).value === keyword
        };
    }
    /**
     * Creates tester which check if a node is specific type.
     * @param {string} type The node type to test.
     * @returns {Object} the created tester.
     * @private
     */
    function newNodeTypeTester(type) {
        return {
            test: node => node.type === type
        };
    }
    /**
     * Checks the given node is an expression statement of IIFE.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is an expression statement of IIFE.
     * @private
     */
    function isIIFEStatement(node) {
        if (node.type === "ExpressionStatement") {
            let call = astUtils.skipChainExpression(node.expression);
            if (call.type === "UnaryExpression") {
                call = astUtils.skipChainExpression(call.argument);
            }
            return call.type === "CallExpression" && astUtils.isFunction(call.callee);
        }
        return false;
    }
    /**
     * Checks whether the given node is a block-like statement.
     * This checks the last token of the node is the closing brace of a block.
     * @param {SourceCode} sourceCode The source code to get tokens.
     * @param {ASTNode} node The node to check.
     * @returns {boolean} `true` if the node is a block-like statement.
     * @private
     */
    function isBlockLikeStatement(sourceCode, node) {
        // do-while with a block is a block-like statement.
        if (node.type === "DoWhileStatement" && node.body.type === "BlockStatement") {
            return true;
        }
        /*
         * IIFE is a block-like statement specially from
         * JSCS#disallowPaddingNewLinesAfterBlocks.
         */
        if (isIIFEStatement(node)) {
            return true;
        }
        // Checks the last token is a closing brace of blocks.
        const lastToken = sourceCode.getLastToken(node, astUtils.isNotSemicolonToken);
        const belongingNode = lastToken && astUtils.isClosingBraceToken(lastToken)
            ? sourceCode.getNodeByRangeIndex(lastToken.range[0])
            : null;
        return Boolean(belongingNode) && (belongingNode.type === "BlockStatement" ||
            belongingNode.type === "SwitchStatement");
    }
    /**
     * Check whether the given node is a directive or not.
     * @param {ASTNode} node The node to check.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {boolean} `true` if the node is a directive.
     */
    function isDirective(node, sourceCode) {
        return (node.type === "ExpressionStatement" &&
            (node.parent.type === "Program" ||
                (node.parent.type === "BlockStatement" &&
                    astUtils.isFunction(node.parent.parent))) &&
            node.expression.type === "Literal" &&
            typeof node.expression.value === "string" &&
            !astUtils.isParenthesised(sourceCode, node.expression));
    }
    /**
     * Check whether the given node is a part of directive prologue or not.
     * @param {ASTNode} node The node to check.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {boolean} `true` if the node is a part of directive prologue.
     */
    function isDirectivePrologue(node, sourceCode) {
        if (isDirective(node, sourceCode)) {
            for (const sibling of node.parent.body) {
                if (sibling === node) {
                    break;
                }
                if (!isDirective(sibling, sourceCode)) {
                    return false;
                }
            }
            return true;
        }
        return false;
    }
    /**
     * Gets the actual last token.
     *
     * If a semicolon is semicolon-less style's semicolon, this ignores it.
     * For example:
     *
     *     foo()
     *     ;[1, 2, 3].forEach(bar)
     * @param {SourceCode} sourceCode The source code to get tokens.
     * @param {ASTNode} node The node to get.
     * @returns {Token} The actual last token.
     * @private
     */
    function getActualLastToken(sourceCode, node) {
        const semiToken = sourceCode.getLastToken(node);
        const prevToken = sourceCode.getTokenBefore(semiToken);
        const nextToken = sourceCode.getTokenAfter(semiToken);
        const isSemicolonLessStyle = Boolean(prevToken &&
            nextToken &&
            prevToken.range[0] >= node.range[0] &&
            astUtils.isSemicolonToken(semiToken) &&
            semiToken.loc.start.line !== prevToken.loc.end.line &&
            semiToken.loc.end.line === nextToken.loc.start.line);
        return isSemicolonLessStyle ? prevToken : semiToken;
    }
    /**
     * This returns the concatenation of the first 2 captured strings.
     * @param {string} _ Unused. Whole matched string.
     * @param {string} trailingSpaces The trailing spaces of the first line.
     * @param {string} indentSpaces The indentation spaces of the last line.
     * @returns {string} The concatenation of trailingSpaces and indentSpaces.
     * @private
     */
    function replacerToRemovePaddingLines(_, trailingSpaces, indentSpaces) {
        return trailingSpaces + indentSpaces;
    }
    /**
     * Check and report statements for `any` configuration.
     * It does nothing.
     * @returns {void}
     * @private
     */
    function verifyForAny() {
    }
    /**
     * Check and report statements for `never` configuration.
     * This autofix removes blank lines between the given 2 statements.
     * However, if comments exist between 2 blank lines, it does not remove those
     * blank lines automatically.
     * @param {RuleContext} context The rule context to report.
     * @param {ASTNode} _ Unused. The previous node to check.
     * @param {ASTNode} nextNode The next node to check.
     * @param {Array<Token[]>} paddingLines The array of token pairs that blank
     * lines exist between the pair.
     * @returns {void}
     * @private
     */
    function verifyForNever(context, _, nextNode, paddingLines) {
        if (paddingLines.length === 0) {
            return;
        }
        context.report({
            node: nextNode,
            messageId: "unexpectedBlankLine",
            fix(fixer) {
                if (paddingLines.length >= 2) {
                    return null;
                }
                const prevToken = paddingLines[0][0];
                const nextToken = paddingLines[0][1];
                const start = prevToken.range[1];
                const end = nextToken.range[0];
                const text = context.getSourceCode().text
                    .slice(start, end)
                    .replace(PADDING_LINE_SEQUENCE, replacerToRemovePaddingLines);
                return fixer.replaceTextRange([start, end], text);
            }
        });
    }
    /**
     * Check and report statements for `always` configuration.
     * This autofix inserts a blank line between the given 2 statements.
     * If the `prevNode` has trailing comments, it inserts a blank line after the
     * trailing comments.
     * @param {RuleContext} context The rule context to report.
     * @param {ASTNode} prevNode The previous node to check.
     * @param {ASTNode} nextNode The next node to check.
     * @param {Array<Token[]>} paddingLines The array of token pairs that blank
     * lines exist between the pair.
     * @returns {void}
     * @private
     */
    function verifyForAlways(context, prevNode, nextNode, paddingLines) {
        if (paddingLines.length > 0) {
            return;
        }
        context.report({
            node: nextNode,
            messageId: "expectedBlankLine",
            fix(fixer) {
                const sourceCode = context.getSourceCode();
                let prevToken = getActualLastToken(sourceCode, prevNode);
                const nextToken = sourceCode.getFirstTokenBetween(prevToken, nextNode, {
                    includeComments: true,
                    /**
                     * Skip the trailing comments of the previous node.
                     * This inserts a blank line after the last trailing comment.
                     *
                     * For example:
                     *
                     *     foo(); // trailing comment.
                     *     // comment.
                     *     bar();
                     *
                     * Get fixed to:
                     *
                     *     foo(); // trailing comment.
                     *
                     *     // comment.
                     *     bar();
                     * @param {Token} token The token to check.
                     * @returns {boolean} `true` if the token is not a trailing comment.
                     * @private
                     */
                    filter(token) {
                        if (astUtils.isTokenOnSameLine(prevToken, token)) {
                            prevToken = token;
                            return false;
                        }
                        return true;
                    }
                }) || nextNode;
                const insertText = astUtils.isTokenOnSameLine(prevToken, nextToken)
                    ? "\n\n"
                    : "\n";
                return fixer.insertTextAfter(prevToken, insertText);
            }
        });
    }
    /**
     * Types of blank lines.
     * `any`, `never`, and `always` are defined.
     * Those have `verify` method to check and report statements.
     * @private
     */
    const PaddingTypes = {
        any: { verify: verifyForAny },
        never: { verify: verifyForNever },
        always: { verify: verifyForAlways }
    };
    /**
     * Types of statements.
     * Those have `test` method to check it matches to the given statement.
     * @private
     */
    const StatementTypes = {
        "*": { test: () => true },
        "block-like": {
            test: (node, sourceCode) => isBlockLikeStatement(sourceCode, node)
        },
        "cjs-export": {
            test: (node, sourceCode) => node.type === "ExpressionStatement" &&
                node.expression.type === "AssignmentExpression" &&
                CJS_EXPORT.test(sourceCode.getText(node.expression.left))
        },
        "cjs-import": {
            test: (node, sourceCode) => node.type === "VariableDeclaration" &&
                node.declarations.length > 0 &&
                Boolean(node.declarations[0].init) &&
                CJS_IMPORT.test(sourceCode.getText(node.declarations[0].init))
        },
        directive: {
            test: isDirectivePrologue
        },
        expression: {
            test: (node, sourceCode) => node.type === "ExpressionStatement" &&
                !isDirectivePrologue(node, sourceCode)
        },
        iife: {
            test: isIIFEStatement
        },
        "multiline-block-like": {
            test: (node, sourceCode) => node.loc.start.line !== node.loc.end.line &&
                isBlockLikeStatement(sourceCode, node)
        },
        "multiline-expression": {
            test: (node, sourceCode) => node.loc.start.line !== node.loc.end.line &&
                node.type === "ExpressionStatement" &&
                !isDirectivePrologue(node, sourceCode)
        },
        "multiline-const": newMultilineKeywordTester("const"),
        "multiline-let": newMultilineKeywordTester("let"),
        "multiline-var": newMultilineKeywordTester("var"),
        "singleline-const": newSinglelineKeywordTester("const"),
        "singleline-let": newSinglelineKeywordTester("let"),
        "singleline-var": newSinglelineKeywordTester("var"),
        block: newNodeTypeTester("BlockStatement"),
        empty: newNodeTypeTester("EmptyStatement"),
        function: newNodeTypeTester("FunctionDeclaration"),
        break: newKeywordTester("break"),
        case: newKeywordTester("case"),
        class: newKeywordTester("class"),
        const: newKeywordTester("const"),
        continue: newKeywordTester("continue"),
        debugger: newKeywordTester("debugger"),
        default: newKeywordTester("default"),
        do: newKeywordTester("do"),
        export: newKeywordTester("export"),
        for: newKeywordTester("for"),
        if: newKeywordTester("if"),
        import: newKeywordTester("import"),
        let: newKeywordTester("let"),
        return: newKeywordTester("return"),
        switch: newKeywordTester("switch"),
        throw: newKeywordTester("throw"),
        try: newKeywordTester("try"),
        var: newKeywordTester("var"),
        while: newKeywordTester("while"),
        with: newKeywordTester("with")
    };
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow padding lines between statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/padding-line-between-statements"
            },
            fixable: "whitespace",
            schema: {
                definitions: {
                    paddingType: {
                        enum: Object.keys(PaddingTypes)
                    },
                    statementType: {
                        anyOf: [
                            { enum: Object.keys(StatementTypes) },
                            {
                                type: "array",
                                items: { enum: Object.keys(StatementTypes) },
                                minItems: 1,
                                uniqueItems: true
                            }
                        ]
                    }
                },
                type: "array",
                items: {
                    type: "object",
                    properties: {
                        blankLine: { $ref: "#/definitions/paddingType" },
                        prev: { $ref: "#/definitions/statementType" },
                        next: { $ref: "#/definitions/statementType" }
                    },
                    additionalProperties: false,
                    required: ["blankLine", "prev", "next"]
                }
            },
            messages: {
                unexpectedBlankLine: "Unexpected blank line before this statement.",
                expectedBlankLine: "Expected blank line before this statement."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const configureList = context.options || [];
            let scopeInfo = null;
            /**
             * Processes to enter to new scope.
             * This manages the current previous statement.
             * @returns {void}
             * @private
             */
            function enterScope() {
                scopeInfo = {
                    upper: scopeInfo,
                    prevNode: null
                };
            }
            /**
             * Processes to exit from the current scope.
             * @returns {void}
             * @private
             */
            function exitScope() {
                scopeInfo = scopeInfo.upper;
            }
            /**
             * Checks whether the given node matches the given type.
             * @param {ASTNode} node The statement node to check.
             * @param {string|string[]} type The statement type to check.
             * @returns {boolean} `true` if the statement node matched the type.
             * @private
             */
            function match(node, type) {
                let innerStatementNode = node;
                while (innerStatementNode.type === "LabeledStatement") {
                    innerStatementNode = innerStatementNode.body;
                }
                if (Array.isArray(type)) {
                    return type.some(match.bind(null, innerStatementNode));
                }
                return StatementTypes[type].test(innerStatementNode, sourceCode);
            }
            /**
             * Finds the last matched configure from configureList.
             * @param {ASTNode} prevNode The previous statement to match.
             * @param {ASTNode} nextNode The current statement to match.
             * @returns {Object} The tester of the last matched configure.
             * @private
             */
            function getPaddingType(prevNode, nextNode) {
                for (let i = configureList.length - 1; i >= 0; --i) {
                    const configure = configureList[i];
                    const matched = match(prevNode, configure.prev) &&
                        match(nextNode, configure.next);
                    if (matched) {
                        return PaddingTypes[configure.blankLine];
                    }
                }
                return PaddingTypes.any;
            }
            /**
             * Gets padding line sequences between the given 2 statements.
             * Comments are separators of the padding line sequences.
             * @param {ASTNode} prevNode The previous statement to count.
             * @param {ASTNode} nextNode The current statement to count.
             * @returns {Array<Token[]>} The array of token pairs.
             * @private
             */
            function getPaddingLineSequences(prevNode, nextNode) {
                const pairs = [];
                let prevToken = getActualLastToken(sourceCode, prevNode);
                if (nextNode.loc.start.line - prevToken.loc.end.line >= 2) {
                    do {
                        const token = sourceCode.getTokenAfter(prevToken, { includeComments: true });
                        if (token.loc.start.line - prevToken.loc.end.line >= 2) {
                            pairs.push([prevToken, token]);
                        }
                        prevToken = token;
                    } while (prevToken.range[0] < nextNode.range[0]);
                }
                return pairs;
            }
            /**
             * Verify padding lines between the given node and the previous node.
             * @param {ASTNode} node The node to verify.
             * @returns {void}
             * @private
             */
            function verify(node) {
                const parentType = node.parent.type;
                const validParent = astUtils.STATEMENT_LIST_PARENTS.has(parentType) ||
                    parentType === "SwitchStatement";
                if (!validParent) {
                    return;
                }
                // Save this node as the current previous statement.
                const prevNode = scopeInfo.prevNode;
                // Verify.
                if (prevNode) {
                    const type = getPaddingType(prevNode, node);
                    const paddingLines = getPaddingLineSequences(prevNode, node);
                    type.verify(context, prevNode, node, paddingLines);
                }
                scopeInfo.prevNode = node;
            }
            /**
             * Verify padding lines between the given node and the previous node.
             * Then process to enter to new scope.
             * @param {ASTNode} node The node to verify.
             * @returns {void}
             * @private
             */
            function verifyThenEnterScope(node) {
                verify(node);
                enterScope();
            }
            return {
                Program: enterScope,
                BlockStatement: enterScope,
                SwitchStatement: enterScope,
                StaticBlock: enterScope,
                "Program:exit": exitScope,
                "BlockStatement:exit": exitScope,
                "SwitchStatement:exit": exitScope,
                "StaticBlock:exit": exitScope,
                ":statement": verify,
                SwitchCase: verifyThenEnterScope,
                "SwitchCase:exit": exitScope
            };
        }
    };
},
/* eslint/lib/rules/prefer-arrow-callback.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to suggest using arrow functions as callbacks.
     * @author Toru Nagashima
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a given variable is a function name.
     * @param {eslint-scope.Variable} variable A variable to check.
     * @returns {boolean} `true` if the variable is a function name.
     */
    function isFunctionName(variable) {
        return variable && variable.defs[0].type === "FunctionName";
    }
    /**
     * Checks whether or not a given MetaProperty node equals to a given value.
     * @param {ASTNode} node A MetaProperty node to check.
     * @param {string} metaName The name of `MetaProperty.meta`.
     * @param {string} propertyName The name of `MetaProperty.property`.
     * @returns {boolean} `true` if the node is the specific value.
     */
    function checkMetaProperty(node, metaName, propertyName) {
        return node.meta.name === metaName && node.property.name === propertyName;
    }
    /**
     * Gets the variable object of `arguments` which is defined implicitly.
     * @param {eslint-scope.Scope} scope A scope to get.
     * @returns {eslint-scope.Variable} The found variable object.
     */
    function getVariableOfArguments(scope) {
        const variables = scope.variables;
        for (let i = 0; i < variables.length; ++i) {
            const variable = variables[i];
            if (variable.name === "arguments") {
                /*
                 * If there was a parameter which is named "arguments", the
                 * implicit "arguments" is not defined.
                 * So does fast return with null.
                 */
                return (variable.identifiers.length === 0) ? variable : null;
            }
        }
        /* c8 ignore next */
        return null;
    }
    /**
     * Checks whether or not a given node is a callback.
     * @param {ASTNode} node A node to check.
     * @throws {Error} (Unreachable.)
     * @returns {Object}
     *   {boolean} retv.isCallback - `true` if the node is a callback.
     *   {boolean} retv.isLexicalThis - `true` if the node is with `.bind(this)`.
     */
    function getCallbackInfo(node) {
        const retv = { isCallback: false, isLexicalThis: false };
        let currentNode = node;
        let parent = node.parent;
        let bound = false;
        while (currentNode) {
            switch (parent.type) {
                // Checks parents recursively.
                case "LogicalExpression":
                case "ChainExpression":
                case "ConditionalExpression":
                    break;
                // Checks whether the parent node is `.bind(this)` call.
                case "MemberExpression":
                    if (parent.object === currentNode &&
                        !parent.property.computed &&
                        parent.property.type === "Identifier" &&
                        parent.property.name === "bind") {
                        const maybeCallee = parent.parent.type === "ChainExpression"
                            ? parent.parent
                            : parent;
                        if (astUtils.isCallee(maybeCallee)) {
                            if (!bound) {
                                bound = true; // Use only the first `.bind()` to make `isLexicalThis` value.
                                retv.isLexicalThis = (maybeCallee.parent.arguments.length === 1 &&
                                    maybeCallee.parent.arguments[0].type === "ThisExpression");
                            }
                            parent = maybeCallee.parent;
                        }
                        else {
                            return retv;
                        }
                    }
                    else {
                        return retv;
                    }
                    break;
                // Checks whether the node is a callback.
                case "CallExpression":
                case "NewExpression":
                    if (parent.callee !== currentNode) {
                        retv.isCallback = true;
                    }
                    return retv;
                default:
                    return retv;
            }
            currentNode = parent;
            parent = parent.parent;
        }
        /* c8 ignore next */
        throw new Error("unreachable");
    }
    /**
     * Checks whether a simple list of parameters contains any duplicates. This does not handle complex
     * parameter lists (e.g. with destructuring), since complex parameter lists are a SyntaxError with duplicate
     * parameter names anyway. Instead, it always returns `false` for complex parameter lists.
     * @param {ASTNode[]} paramsList The list of parameters for a function
     * @returns {boolean} `true` if the list of parameters contains any duplicates
     */
    function hasDuplicateParams(paramsList) {
        return paramsList.every(param => param.type === "Identifier") && paramsList.length !== new Set(paramsList.map(param => param.name)).size;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require using arrow functions for callbacks",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-arrow-callback"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        allowNamedFunctions: {
                            type: "boolean",
                            default: false
                        },
                        allowUnboundThis: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "code",
            messages: {
                preferArrowCallback: "Unexpected function expression."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const allowUnboundThis = options.allowUnboundThis !== false; // default to true
            const allowNamedFunctions = options.allowNamedFunctions;
            const sourceCode = context.getSourceCode();
            /*
             * {Array<{this: boolean, super: boolean, meta: boolean}>}
             * - this - A flag which shows there are one or more ThisExpression.
             * - super - A flag which shows there are one or more Super.
             * - meta - A flag which shows there are one or more MethProperty.
             */
            let stack = [];
            /**
             * Pushes new function scope with all `false` flags.
             * @returns {void}
             */
            function enterScope() {
                stack.push({ this: false, super: false, meta: false });
            }
            /**
             * Pops a function scope from the stack.
             * @returns {{this: boolean, super: boolean, meta: boolean}} The information of the last scope.
             */
            function exitScope() {
                return stack.pop();
            }
            return {
                // Reset internal state.
                Program() {
                    stack = [];
                },
                // If there are below, it cannot replace with arrow functions merely.
                ThisExpression() {
                    const info = stack[stack.length - 1];
                    if (info) {
                        info.this = true;
                    }
                },
                Super() {
                    const info = stack[stack.length - 1];
                    if (info) {
                        info.super = true;
                    }
                },
                MetaProperty(node) {
                    const info = stack[stack.length - 1];
                    if (info && checkMetaProperty(node, "new", "target")) {
                        info.meta = true;
                    }
                },
                // To skip nested scopes.
                FunctionDeclaration: enterScope,
                "FunctionDeclaration:exit": exitScope,
                // Main.
                FunctionExpression: enterScope,
                "FunctionExpression:exit"(node) {
                    const scopeInfo = exitScope();
                    // Skip named function expressions
                    if (allowNamedFunctions && node.id && node.id.name) {
                        return;
                    }
                    // Skip generators.
                    if (node.generator) {
                        return;
                    }
                    // Skip recursive functions.
                    const nameVar = context.getDeclaredVariables(node)[0];
                    if (isFunctionName(nameVar) && nameVar.references.length > 0) {
                        return;
                    }
                    // Skip if it's using arguments.
                    const variable = getVariableOfArguments(context.getScope());
                    if (variable && variable.references.length > 0) {
                        return;
                    }
                    // Reports if it's a callback which can replace with arrows.
                    const callbackInfo = getCallbackInfo(node);
                    if (callbackInfo.isCallback &&
                        (!allowUnboundThis || !scopeInfo.this || callbackInfo.isLexicalThis) &&
                        !scopeInfo.super &&
                        !scopeInfo.meta) {
                        context.report({
                            node,
                            messageId: "preferArrowCallback",
                            *fix(fixer) {
                                if ((!callbackInfo.isLexicalThis && scopeInfo.this) || hasDuplicateParams(node.params)) {
                                    /*
                                     * If the callback function does not have .bind(this) and contains a reference to `this`, there
                                     * is no way to determine what `this` should be, so don't perform any fixes.
                                     * If the callback function has duplicates in its list of parameters (possible in sloppy mode),
                                     * don't replace it with an arrow function, because this is a SyntaxError with arrow functions.
                                     */
                                    return;
                                }
                                // Remove `.bind(this)` if exists.
                                if (callbackInfo.isLexicalThis) {
                                    const memberNode = node.parent;
                                    /*
                                     * If `.bind(this)` exists but the parent is not `.bind(this)`, don't remove it automatically.
                                     * E.g. `(foo || function(){}).bind(this)`
                                     */
                                    if (memberNode.type !== "MemberExpression") {
                                        return;
                                    }
                                    const callNode = memberNode.parent;
                                    const firstTokenToRemove = sourceCode.getTokenAfter(memberNode.object, astUtils.isNotClosingParenToken);
                                    const lastTokenToRemove = sourceCode.getLastToken(callNode);
                                    /*
                                     * If the member expression is parenthesized, don't remove the right paren.
                                     * E.g. `(function(){}.bind)(this)`
                                     *                    ^^^^^^^^^^^^
                                     */
                                    if (astUtils.isParenthesised(sourceCode, memberNode)) {
                                        return;
                                    }
                                    // If comments exist in the `.bind(this)`, don't remove those.
                                    if (sourceCode.commentsExistBetween(firstTokenToRemove, lastTokenToRemove)) {
                                        return;
                                    }
                                    yield fixer.removeRange([firstTokenToRemove.range[0], lastTokenToRemove.range[1]]);
                                }
                                // Convert the function expression to an arrow function.
                                const functionToken = sourceCode.getFirstToken(node, node.async ? 1 : 0);
                                const leftParenToken = sourceCode.getTokenAfter(functionToken, astUtils.isOpeningParenToken);
                                const tokenBeforeBody = sourceCode.getTokenBefore(node.body);
                                if (sourceCode.commentsExistBetween(functionToken, leftParenToken)) {
                                    // Remove only extra tokens to keep comments.
                                    yield fixer.remove(functionToken);
                                    if (node.id) {
                                        yield fixer.remove(node.id);
                                    }
                                }
                                else {
                                    // Remove extra tokens and spaces.
                                    yield fixer.removeRange([functionToken.range[0], leftParenToken.range[0]]);
                                }
                                yield fixer.insertTextAfter(tokenBeforeBody, " =>");
                                // Get the node that will become the new arrow function.
                                let replacedNode = callbackInfo.isLexicalThis ? node.parent.parent : node;
                                if (replacedNode.type === "ChainExpression") {
                                    replacedNode = replacedNode.parent;
                                }
                                /*
                                 * If the replaced node is part of a BinaryExpression, LogicalExpression, or MemberExpression, then
                                 * the arrow function needs to be parenthesized, because `foo || () => {}` is invalid syntax even
                                 * though `foo || function() {}` is valid.
                                 */
                                if (replacedNode.parent.type !== "CallExpression" &&
                                    replacedNode.parent.type !== "ConditionalExpression" &&
                                    !astUtils.isParenthesised(sourceCode, replacedNode) &&
                                    !astUtils.isParenthesised(sourceCode, node)) {
                                    yield fixer.insertTextBefore(replacedNode, "(");
                                    yield fixer.insertTextAfter(replacedNode, ")");
                                }
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-const.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to suggest using of const declaration for variables that are never reassigned after declared.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const FixTracker = require(496) /* ./utils/fix-tracker */;
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const PATTERN_TYPE = /^(?:.+?Pattern|RestElement|SpreadProperty|ExperimentalRestProperty|Property)$/u;
    const DECLARATION_HOST_TYPE = /^(?:Program|BlockStatement|StaticBlock|SwitchCase)$/u;
    const DESTRUCTURING_HOST_TYPE = /^(?:VariableDeclarator|AssignmentExpression)$/u;
    /**
     * Checks whether a given node is located at `ForStatement.init` or not.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node is located at `ForStatement.init`.
     */
    function isInitOfForStatement(node) {
        return node.parent.type === "ForStatement" && node.parent.init === node;
    }
    /**
     * Checks whether a given Identifier node becomes a VariableDeclaration or not.
     * @param {ASTNode} identifier An Identifier node to check.
     * @returns {boolean} `true` if the node can become a VariableDeclaration.
     */
    function canBecomeVariableDeclaration(identifier) {
        let node = identifier.parent;
        while (PATTERN_TYPE.test(node.type)) {
            node = node.parent;
        }
        return (node.type === "VariableDeclarator" ||
            (node.type === "AssignmentExpression" &&
                node.parent.type === "ExpressionStatement" &&
                DECLARATION_HOST_TYPE.test(node.parent.parent.type)));
    }
    /**
     * Checks if an property or element is from outer scope or function parameters
     * in destructing pattern.
     * @param {string} name A variable name to be checked.
     * @param {eslint-scope.Scope} initScope A scope to start find.
     * @returns {boolean} Indicates if the variable is from outer scope or function parameters.
     */
    function isOuterVariableInDestructing(name, initScope) {
        if (initScope.through.some(ref => ref.resolved && ref.resolved.name === name)) {
            return true;
        }
        const variable = astUtils.getVariableByName(initScope, name);
        if (variable !== null) {
            return variable.defs.some(def => def.type === "Parameter");
        }
        return false;
    }
    /**
     * Gets the VariableDeclarator/AssignmentExpression node that a given reference
     * belongs to.
     * This is used to detect a mix of reassigned and never reassigned in a
     * destructuring.
     * @param {eslint-scope.Reference} reference A reference to get.
     * @returns {ASTNode|null} A VariableDeclarator/AssignmentExpression node or
     *      null.
     */
    function getDestructuringHost(reference) {
        if (!reference.isWrite()) {
            return null;
        }
        let node = reference.identifier.parent;
        while (PATTERN_TYPE.test(node.type)) {
            node = node.parent;
        }
        if (!DESTRUCTURING_HOST_TYPE.test(node.type)) {
            return null;
        }
        return node;
    }
    /**
     * Determines if a destructuring assignment node contains
     * any MemberExpression nodes. This is used to determine if a
     * variable that is only written once using destructuring can be
     * safely converted into a const declaration.
     * @param {ASTNode} node The ObjectPattern or ArrayPattern node to check.
     * @returns {boolean} True if the destructuring pattern contains
     *      a MemberExpression, false if not.
     */
    function hasMemberExpressionAssignment(node) {
        switch (node.type) {
            case "ObjectPattern":
                return node.properties.some(prop => {
                    if (prop) {
                        /*
                         * Spread elements have an argument property while
                         * others have a value property. Because different
                         * parsers use different node types for spread elements,
                         * we just check if there is an argument property.
                         */
                        return hasMemberExpressionAssignment(prop.argument || prop.value);
                    }
                    return false;
                });
            case "ArrayPattern":
                return node.elements.some(element => {
                    if (element) {
                        return hasMemberExpressionAssignment(element);
                    }
                    return false;
                });
            case "AssignmentPattern":
                return hasMemberExpressionAssignment(node.left);
            case "MemberExpression":
                return true;
            // no default
        }
        return false;
    }
    /**
     * Gets an identifier node of a given variable.
     *
     * If the initialization exists or one or more reading references exist before
     * the first assignment, the identifier node is the node of the declaration.
     * Otherwise, the identifier node is the node of the first assignment.
     *
     * If the variable should not change to const, this function returns null.
     * - If the variable is reassigned.
     * - If the variable is never initialized nor assigned.
     * - If the variable is initialized in a different scope from the declaration.
     * - If the unique assignment of the variable cannot change to a declaration.
     *   e.g. `if (a) b = 1` / `return (b = 1)`
     * - If the variable is declared in the global scope and `eslintUsed` is `true`.
     *   `/*exported foo` directive comment makes such variables. This rule does not
     *   warn such variables because this rule cannot distinguish whether the
     *   exported variables are reassigned or not.
     * @param {eslint-scope.Variable} variable A variable to get.
     * @param {boolean} ignoreReadBeforeAssign
     *      The value of `ignoreReadBeforeAssign` option.
     * @returns {ASTNode|null}
     *      An Identifier node if the variable should change to const.
     *      Otherwise, null.
     */
    function getIdentifierIfShouldBeConst(variable, ignoreReadBeforeAssign) {
        if (variable.eslintUsed && variable.scope.type === "global") {
            return null;
        }
        // Finds the unique WriteReference.
        let writer = null;
        let isReadBeforeInit = false;
        const references = variable.references;
        for (let i = 0; i < references.length; ++i) {
            const reference = references[i];
            if (reference.isWrite()) {
                const isReassigned = (writer !== null &&
                    writer.identifier !== reference.identifier);
                if (isReassigned) {
                    return null;
                }
                const destructuringHost = getDestructuringHost(reference);
                if (destructuringHost !== null && destructuringHost.left !== void 0) {
                    const leftNode = destructuringHost.left;
                    let hasOuterVariables = false, hasNonIdentifiers = false;
                    if (leftNode.type === "ObjectPattern") {
                        const properties = leftNode.properties;
                        hasOuterVariables = properties
                            .filter(prop => prop.value)
                            .map(prop => prop.value.name)
                            .some(name => isOuterVariableInDestructing(name, variable.scope));
                        hasNonIdentifiers = hasMemberExpressionAssignment(leftNode);
                    }
                    else if (leftNode.type === "ArrayPattern") {
                        const elements = leftNode.elements;
                        hasOuterVariables = elements
                            .map(element => element && element.name)
                            .some(name => isOuterVariableInDestructing(name, variable.scope));
                        hasNonIdentifiers = hasMemberExpressionAssignment(leftNode);
                    }
                    if (hasOuterVariables || hasNonIdentifiers) {
                        return null;
                    }
                }
                writer = reference;
            }
            else if (reference.isRead() && writer === null) {
                if (ignoreReadBeforeAssign) {
                    return null;
                }
                isReadBeforeInit = true;
            }
        }
        /*
         * If the assignment is from a different scope, ignore it.
         * If the assignment cannot change to a declaration, ignore it.
         */
        const shouldBeConst = (writer !== null &&
            writer.from === variable.scope &&
            canBecomeVariableDeclaration(writer.identifier));
        if (!shouldBeConst) {
            return null;
        }
        if (isReadBeforeInit) {
            return variable.defs[0].name;
        }
        return writer.identifier;
    }
    /**
     * Groups by the VariableDeclarator/AssignmentExpression node that each
     * reference of given variables belongs to.
     * This is used to detect a mix of reassigned and never reassigned in a
     * destructuring.
     * @param {eslint-scope.Variable[]} variables Variables to group by destructuring.
     * @param {boolean} ignoreReadBeforeAssign
     *      The value of `ignoreReadBeforeAssign` option.
     * @returns {Map<ASTNode, ASTNode[]>} Grouped identifier nodes.
     */
    function groupByDestructuring(variables, ignoreReadBeforeAssign) {
        const identifierMap = new Map();
        for (let i = 0; i < variables.length; ++i) {
            const variable = variables[i];
            const references = variable.references;
            const identifier = getIdentifierIfShouldBeConst(variable, ignoreReadBeforeAssign);
            let prevId = null;
            for (let j = 0; j < references.length; ++j) {
                const reference = references[j];
                const id = reference.identifier;
                /*
                 * Avoid counting a reference twice or more for default values of
                 * destructuring.
                 */
                if (id === prevId) {
                    continue;
                }
                prevId = id;
                // Add the identifier node into the destructuring group.
                const group = getDestructuringHost(reference);
                if (group) {
                    if (identifierMap.has(group)) {
                        identifierMap.get(group).push(identifier);
                    }
                    else {
                        identifierMap.set(group, [identifier]);
                    }
                }
            }
        }
        return identifierMap;
    }
    /**
     * Finds the nearest parent of node with a given type.
     * @param {ASTNode} node The node to search from.
     * @param {string} type The type field of the parent node.
     * @param {Function} shouldStop A predicate that returns true if the traversal should stop, and false otherwise.
     * @returns {ASTNode} The closest ancestor with the specified type; null if no such ancestor exists.
     */
    function findUp(node, type, shouldStop) {
        if (!node || shouldStop(node)) {
            return null;
        }
        if (node.type === type) {
            return node;
        }
        return findUp(node.parent, type, shouldStop);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require `const` declarations for variables that are never reassigned after declared",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-const"
            },
            fixable: "code",
            schema: [
                {
                    type: "object",
                    properties: {
                        destructuring: { enum: ["any", "all"], default: "any" },
                        ignoreReadBeforeAssign: { type: "boolean", default: false }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                useConst: "'{{name}}' is never reassigned. Use 'const' instead."
            }
        },
        create(context) {
            const options = context.options[0] || {};
            const sourceCode = context.getSourceCode();
            const shouldMatchAnyDestructuredVariable = options.destructuring !== "all";
            const ignoreReadBeforeAssign = options.ignoreReadBeforeAssign === true;
            const variables = [];
            let reportCount = 0;
            let checkedId = null;
            let checkedName = "";
            /**
             * Reports given identifier nodes if all of the nodes should be declared
             * as const.
             *
             * The argument 'nodes' is an array of Identifier nodes.
             * This node is the result of 'getIdentifierIfShouldBeConst()', so it's
             * nullable. In simple declaration or assignment cases, the length of
             * the array is 1. In destructuring cases, the length of the array can
             * be 2 or more.
             * @param {(eslint-scope.Reference|null)[]} nodes
             *      References which are grouped by destructuring to report.
             * @returns {void}
             */
            function checkGroup(nodes) {
                const nodesToReport = nodes.filter(Boolean);
                if (nodes.length && (shouldMatchAnyDestructuredVariable || nodesToReport.length === nodes.length)) {
                    const varDeclParent = findUp(nodes[0], "VariableDeclaration", parentNode => parentNode.type.endsWith("Statement"));
                    const isVarDecParentNull = varDeclParent === null;
                    if (!isVarDecParentNull && varDeclParent.declarations.length > 0) {
                        const firstDeclaration = varDeclParent.declarations[0];
                        if (firstDeclaration.init) {
                            const firstDecParent = firstDeclaration.init.parent;
                            /*
                             * First we check the declaration type and then depending on
                             * if the type is a "VariableDeclarator" or its an "ObjectPattern"
                             * we compare the name and id from the first identifier, if the names are different
                             * we assign the new name, id and reset the count of reportCount and nodeCount in
                             * order to check each block for the number of reported errors and base our fix
                             * based on comparing nodes.length and nodesToReport.length.
                             */
                            if (firstDecParent.type === "VariableDeclarator") {
                                if (firstDecParent.id.name !== checkedName) {
                                    checkedName = firstDecParent.id.name;
                                    reportCount = 0;
                                }
                                if (firstDecParent.id.type === "ObjectPattern") {
                                    if (firstDecParent.init.name !== checkedName) {
                                        checkedName = firstDecParent.init.name;
                                        reportCount = 0;
                                    }
                                }
                                if (firstDecParent.id !== checkedId) {
                                    checkedId = firstDecParent.id;
                                    reportCount = 0;
                                }
                            }
                        }
                    }
                    let shouldFix = varDeclParent &&
                        // Don't do a fix unless all variables in the declarations are initialized (or it's in a for-in or for-of loop)
                        (varDeclParent.parent.type === "ForInStatement" || varDeclParent.parent.type === "ForOfStatement" ||
                            varDeclParent.declarations.every(declaration => declaration.init)) &&
                        /*
                         * If options.destructuring is "all", then this warning will not occur unless
                         * every assignment in the destructuring should be const. In that case, it's safe
                         * to apply the fix.
                         */
                        nodesToReport.length === nodes.length;
                    if (!isVarDecParentNull && varDeclParent.declarations && varDeclParent.declarations.length !== 1) {
                        if (varDeclParent && varDeclParent.declarations && varDeclParent.declarations.length >= 1) {
                            /*
                             * Add nodesToReport.length to a count, then comparing the count to the length
                             * of the declarations in the current block.
                             */
                            reportCount += nodesToReport.length;
                            let totalDeclarationsCount = 0;
                            varDeclParent.declarations.forEach(declaration => {
                                if (declaration.id.type === "ObjectPattern") {
                                    totalDeclarationsCount += declaration.id.properties.length;
                                }
                                else if (declaration.id.type === "ArrayPattern") {
                                    totalDeclarationsCount += declaration.id.elements.length;
                                }
                                else {
                                    totalDeclarationsCount += 1;
                                }
                            });
                            shouldFix = shouldFix && (reportCount === totalDeclarationsCount);
                        }
                    }
                    nodesToReport.forEach(node => {
                        context.report({
                            node,
                            messageId: "useConst",
                            data: node,
                            fix: shouldFix
                                ? fixer => {
                                    const letKeywordToken = sourceCode.getFirstToken(varDeclParent, t => t.value === varDeclParent.kind);
                                    /**
                                     * Extend the replacement range to the whole declaration,
                                     * in order to prevent other fixes in the same pass
                                     * https://github.com/eslint/eslint/issues/13899
                                     */
                                    return new FixTracker(fixer, sourceCode)
                                        .retainRange(varDeclParent.range)
                                        .replaceTextRange(letKeywordToken.range, "const");
                                }
                                : null
                        });
                    });
                }
            }
            return {
                "Program:exit"() {
                    groupByDestructuring(variables, ignoreReadBeforeAssign).forEach(checkGroup);
                },
                VariableDeclaration(node) {
                    if (node.kind === "let" && !isInitOfForStatement(node)) {
                        variables.push(...context.getDeclaredVariables(node));
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-destructuring.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Prefer destructuring from arrays and objects
     * @author Alex LaFroscia
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const PRECEDENCE_OF_ASSIGNMENT_EXPR = astUtils.getPrecedence({ type: "AssignmentExpression" });
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require destructuring from arrays and/or objects",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-destructuring"
            },
            fixable: "code",
            schema: [
                {
                    /*
                     * old support {array: Boolean, object: Boolean}
                     * new support {VariableDeclarator: {}, AssignmentExpression: {}}
                     */
                    oneOf: [
                        {
                            type: "object",
                            properties: {
                                VariableDeclarator: {
                                    type: "object",
                                    properties: {
                                        array: {
                                            type: "boolean"
                                        },
                                        object: {
                                            type: "boolean"
                                        }
                                    },
                                    additionalProperties: false
                                },
                                AssignmentExpression: {
                                    type: "object",
                                    properties: {
                                        array: {
                                            type: "boolean"
                                        },
                                        object: {
                                            type: "boolean"
                                        }
                                    },
                                    additionalProperties: false
                                }
                            },
                            additionalProperties: false
                        },
                        {
                            type: "object",
                            properties: {
                                array: {
                                    type: "boolean"
                                },
                                object: {
                                    type: "boolean"
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                },
                {
                    type: "object",
                    properties: {
                        enforceForRenamedProperties: {
                            type: "boolean"
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                preferDestructuring: "Use {{type}} destructuring."
            }
        },
        create(context) {
            const enabledTypes = context.options[0];
            const enforceForRenamedProperties = context.options[1] && context.options[1].enforceForRenamedProperties;
            let normalizedOptions = {
                VariableDeclarator: { array: true, object: true },
                AssignmentExpression: { array: true, object: true }
            };
            if (enabledTypes) {
                normalizedOptions = typeof enabledTypes.array !== "undefined" || typeof enabledTypes.object !== "undefined"
                    ? { VariableDeclarator: enabledTypes, AssignmentExpression: enabledTypes }
                    : enabledTypes;
            }
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Checks if destructuring type should be checked.
             * @param {string} nodeType "AssignmentExpression" or "VariableDeclarator"
             * @param {string} destructuringType "array" or "object"
             * @returns {boolean} `true` if the destructuring type should be checked for the given node
             */
            function shouldCheck(nodeType, destructuringType) {
                return normalizedOptions &&
                    normalizedOptions[nodeType] &&
                    normalizedOptions[nodeType][destructuringType];
            }
            /**
             * Determines if the given node is accessing an array index
             *
             * This is used to differentiate array index access from object property
             * access.
             * @param {ASTNode} node the node to evaluate
             * @returns {boolean} whether or not the node is an integer
             */
            function isArrayIndexAccess(node) {
                return Number.isInteger(node.property.value);
            }
            /**
             * Report that the given node should use destructuring
             * @param {ASTNode} reportNode the node to report
             * @param {string} type the type of destructuring that should have been done
             * @param {Function|null} fix the fix function or null to pass to context.report
             * @returns {void}
             */
            function report(reportNode, type, fix) {
                context.report({
                    node: reportNode,
                    messageId: "preferDestructuring",
                    data: { type },
                    fix
                });
            }
            /**
             * Determines if a node should be fixed into object destructuring
             *
             * The fixer only fixes the simplest case of object destructuring,
             * like: `let x = a.x`;
             *
             * Assignment expression is not fixed.
             * Array destructuring is not fixed.
             * Renamed property is not fixed.
             * @param {ASTNode} node the node to evaluate
             * @returns {boolean} whether or not the node should be fixed
             */
            function shouldFix(node) {
                return node.type === "VariableDeclarator" &&
                    node.id.type === "Identifier" &&
                    node.init.type === "MemberExpression" &&
                    !node.init.computed &&
                    node.init.property.type === "Identifier" &&
                    node.id.name === node.init.property.name;
            }
            /**
             * Fix a node into object destructuring.
             * This function only handles the simplest case of object destructuring,
             * see {@link shouldFix}.
             * @param {SourceCodeFixer} fixer the fixer object
             * @param {ASTNode} node the node to be fixed.
             * @returns {Object} a fix for the node
             */
            function fixIntoObjectDestructuring(fixer, node) {
                const rightNode = node.init;
                const sourceCode = context.getSourceCode();
                // Don't fix if that would remove any comments. Only comments inside `rightNode.object` can be preserved.
                if (sourceCode.getCommentsInside(node).length > sourceCode.getCommentsInside(rightNode.object).length) {
                    return null;
                }
                let objectText = sourceCode.getText(rightNode.object);
                if (astUtils.getPrecedence(rightNode.object) < PRECEDENCE_OF_ASSIGNMENT_EXPR) {
                    objectText = `(${objectText})`;
                }
                return fixer.replaceText(node, `{${rightNode.property.name}} = ${objectText}`);
            }
            /**
             * Check that the `prefer-destructuring` rules are followed based on the
             * given left- and right-hand side of the assignment.
             *
             * Pulled out into a separate method so that VariableDeclarators and
             * AssignmentExpressions can share the same verification logic.
             * @param {ASTNode} leftNode the left-hand side of the assignment
             * @param {ASTNode} rightNode the right-hand side of the assignment
             * @param {ASTNode} reportNode the node to report the error on
             * @returns {void}
             */
            function performCheck(leftNode, rightNode, reportNode) {
                if (rightNode.type !== "MemberExpression" ||
                    rightNode.object.type === "Super" ||
                    rightNode.property.type === "PrivateIdentifier") {
                    return;
                }
                if (isArrayIndexAccess(rightNode)) {
                    if (shouldCheck(reportNode.type, "array")) {
                        report(reportNode, "array", null);
                    }
                    return;
                }
                const fix = shouldFix(reportNode)
                    ? fixer => fixIntoObjectDestructuring(fixer, reportNode)
                    : null;
                if (shouldCheck(reportNode.type, "object") && enforceForRenamedProperties) {
                    report(reportNode, "object", fix);
                    return;
                }
                if (shouldCheck(reportNode.type, "object")) {
                    const property = rightNode.property;
                    if ((property.type === "Literal" && leftNode.name === property.value) ||
                        (property.type === "Identifier" && leftNode.name === property.name && !rightNode.computed)) {
                        report(reportNode, "object", fix);
                    }
                }
            }
            /**
             * Check if a given variable declarator is coming from an property access
             * that should be using destructuring instead
             * @param {ASTNode} node the variable declarator to check
             * @returns {void}
             */
            function checkVariableDeclarator(node) {
                // Skip if variable is declared without assignment
                if (!node.init) {
                    return;
                }
                // We only care about member expressions past this point
                if (node.init.type !== "MemberExpression") {
                    return;
                }
                performCheck(node.id, node.init, node);
            }
            /**
             * Run the `prefer-destructuring` check on an AssignmentExpression
             * @param {ASTNode} node the AssignmentExpression node
             * @returns {void}
             */
            function checkAssignmentExpression(node) {
                if (node.operator === "=") {
                    performCheck(node.left, node.right, node);
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                VariableDeclarator: checkVariableDeclarator,
                AssignmentExpression: checkAssignmentExpression
            };
        }
    };
},
/* eslint/lib/rules/prefer-exponentiation-operator.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow Math.pow in favor of the ** operator
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const { CALL, ReferenceTracker } = require(316) /* @eslint-community/eslint-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const PRECEDENCE_OF_EXPONENTIATION_EXPR = astUtils.getPrecedence({ type: "BinaryExpression", operator: "**" });
    /**
     * Determines whether the given node needs parens if used as the base in an exponentiation binary expression.
     * @param {ASTNode} base The node to check.
     * @returns {boolean} `true` if the node needs to be parenthesised.
     */
    function doesBaseNeedParens(base) {
        return (
        // '**' is right-associative, parens are needed when Math.pow(a ** b, c) is converted to (a ** b) ** c
        astUtils.getPrecedence(base) <= PRECEDENCE_OF_EXPONENTIATION_EXPR ||
            // An unary operator cannot be used immediately before an exponentiation expression
            base.type === "AwaitExpression" ||
            base.type === "UnaryExpression");
    }
    /**
     * Determines whether the given node needs parens if used as the exponent in an exponentiation binary expression.
     * @param {ASTNode} exponent The node to check.
     * @returns {boolean} `true` if the node needs to be parenthesised.
     */
    function doesExponentNeedParens(exponent) {
        // '**' is right-associative, there is no need for parens when Math.pow(a, b ** c) is converted to a ** b ** c
        return astUtils.getPrecedence(exponent) < PRECEDENCE_OF_EXPONENTIATION_EXPR;
    }
    /**
     * Determines whether an exponentiation binary expression at the place of the given node would need parens.
     * @param {ASTNode} node A node that would be replaced by an exponentiation binary expression.
     * @param {SourceCode} sourceCode A SourceCode object.
     * @returns {boolean} `true` if the expression needs to be parenthesised.
     */
    function doesExponentiationExpressionNeedParens(node, sourceCode) {
        const parent = node.parent.type === "ChainExpression" ? node.parent.parent : node.parent;
        const needsParens = (parent.type === "ClassDeclaration" ||
            (parent.type.endsWith("Expression") &&
                astUtils.getPrecedence(parent) >= PRECEDENCE_OF_EXPONENTIATION_EXPR &&
                !(parent.type === "BinaryExpression" && parent.operator === "**" && parent.right === node) &&
                !((parent.type === "CallExpression" || parent.type === "NewExpression") && parent.arguments.includes(node)) &&
                !(parent.type === "MemberExpression" && parent.computed && parent.property === node) &&
                !(parent.type === "ArrayExpression")));
        return needsParens && !astUtils.isParenthesised(sourceCode, node);
    }
    /**
     * Optionally parenthesizes given text.
     * @param {string} text The text to parenthesize.
     * @param {boolean} shouldParenthesize If `true`, the text will be parenthesised.
     * @returns {string} parenthesised or unchanged text.
     */
    function parenthesizeIfShould(text, shouldParenthesize) {
        return shouldParenthesize ? `(${text})` : text;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow the use of `Math.pow` in favor of the `**` operator",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-exponentiation-operator"
            },
            schema: [],
            fixable: "code",
            messages: {
                useExponentiation: "Use the '**' operator instead of 'Math.pow'."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Reports the given node.
             * @param {ASTNode} node 'Math.pow()' node to report.
             * @returns {void}
             */
            function report(node) {
                context.report({
                    node,
                    messageId: "useExponentiation",
                    fix(fixer) {
                        if (node.arguments.length !== 2 ||
                            node.arguments.some(arg => arg.type === "SpreadElement") ||
                            sourceCode.getCommentsInside(node).length > 0) {
                            return null;
                        }
                        const base = node.arguments[0], exponent = node.arguments[1], baseText = sourceCode.getText(base), exponentText = sourceCode.getText(exponent), shouldParenthesizeBase = doesBaseNeedParens(base), shouldParenthesizeExponent = doesExponentNeedParens(exponent), shouldParenthesizeAll = doesExponentiationExpressionNeedParens(node, sourceCode);
                        let prefix = "", suffix = "";
                        if (!shouldParenthesizeAll) {
                            if (!shouldParenthesizeBase) {
                                const firstReplacementToken = sourceCode.getFirstToken(base), tokenBefore = sourceCode.getTokenBefore(node);
                                if (tokenBefore &&
                                    tokenBefore.range[1] === node.range[0] &&
                                    !astUtils.canTokensBeAdjacent(tokenBefore, firstReplacementToken)) {
                                    prefix = " "; // a+Math.pow(++b, c) -> a+ ++b**c
                                }
                            }
                            if (!shouldParenthesizeExponent) {
                                const lastReplacementToken = sourceCode.getLastToken(exponent), tokenAfter = sourceCode.getTokenAfter(node);
                                if (tokenAfter &&
                                    node.range[1] === tokenAfter.range[0] &&
                                    !astUtils.canTokensBeAdjacent(lastReplacementToken, tokenAfter)) {
                                    suffix = " "; // Math.pow(a, b)in c -> a**b in c
                                }
                            }
                        }
                        const baseReplacement = parenthesizeIfShould(baseText, shouldParenthesizeBase), exponentReplacement = parenthesizeIfShould(exponentText, shouldParenthesizeExponent), replacement = parenthesizeIfShould(`${baseReplacement}**${exponentReplacement}`, shouldParenthesizeAll);
                        return fixer.replaceText(node, `${prefix}${replacement}${suffix}`);
                    }
                });
            }
            return {
                Program() {
                    const scope = context.getScope();
                    const tracker = new ReferenceTracker(scope);
                    const trackMap = {
                        Math: {
                            pow: { [CALL]: true }
                        }
                    };
                    for (const { node } of tracker.iterateGlobalReferences(trackMap)) {
                        report(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-named-capture-group.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce requiring named capture groups in regular expression.
     * @author Pig Fang <https://github.com/g-plane>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { CALL, CONSTRUCT, ReferenceTracker, getStringIfConstant } = require(316) /* @eslint-community/eslint-utils */;
    const regexpp = require(485) /* @eslint-community/regexpp */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const parser = new regexpp.RegExpParser();
    /**
     * Creates fixer suggestions for the regex, if statically determinable.
     * @param {number} groupStart Starting index of the regex group.
     * @param {string} pattern The regular expression pattern to be checked.
     * @param {string} rawText Source text of the regexNode.
     * @param {ASTNode} regexNode AST node which contains the regular expression.
     * @returns {Array<SuggestionResult>} Fixer suggestions for the regex, if statically determinable.
     */
    function suggestIfPossible(groupStart, pattern, rawText, regexNode) {
        switch (regexNode.type) {
            case "Literal":
                if (typeof regexNode.value === "string" && rawText.includes("\\")) {
                    return null;
                }
                break;
            case "TemplateLiteral":
                if (regexNode.expressions.length || rawText.slice(1, -1) !== pattern) {
                    return null;
                }
                break;
            default:
                return null;
        }
        const start = regexNode.range[0] + groupStart + 2;
        return [
            {
                fix(fixer) {
                    const existingTemps = pattern.match(/temp\d+/gu) || [];
                    const highestTempCount = existingTemps.reduce((previous, next) => Math.max(previous, Number(next.slice("temp".length))), 0);
                    return fixer.insertTextBeforeRange([start, start], `?<temp${highestTempCount + 1}>`);
                },
                messageId: "addGroupName"
            },
            {
                fix(fixer) {
                    return fixer.insertTextBeforeRange([start, start], "?:");
                },
                messageId: "addNonCapture"
            }
        ];
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce using named capture group in regular expression",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-named-capture-group"
            },
            hasSuggestions: true,
            schema: [],
            messages: {
                addGroupName: "Add name to capture group.",
                addNonCapture: "Convert group to non-capturing.",
                required: "Capture group '{{group}}' should be converted to a named or non-capturing group."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Function to check regular expression.
             * @param {string} pattern The regular expression pattern to be checked.
             * @param {ASTNode} node AST node which contains the regular expression or a call/new expression.
             * @param {ASTNode} regexNode AST node which contains the regular expression.
             * @param {boolean} uFlag Flag indicates whether unicode mode is enabled or not.
             * @returns {void}
             */
            function checkRegex(pattern, node, regexNode, uFlag) {
                let ast;
                try {
                    ast = parser.parsePattern(pattern, 0, pattern.length, uFlag);
                }
                catch {
                    // ignore regex syntax errors
                    return;
                }
                regexpp.visitRegExpAST(ast, {
                    onCapturingGroupEnter(group) {
                        if (!group.name) {
                            const rawText = sourceCode.getText(regexNode);
                            const suggest = suggestIfPossible(group.start, pattern, rawText, regexNode);
                            context.report({
                                node,
                                messageId: "required",
                                data: {
                                    group: group.raw
                                },
                                suggest
                            });
                        }
                    }
                });
            }
            return {
                Literal(node) {
                    if (node.regex) {
                        checkRegex(node.regex.pattern, node, node, node.regex.flags.includes("u"));
                    }
                },
                Program() {
                    const scope = context.getScope();
                    const tracker = new ReferenceTracker(scope);
                    const traceMap = {
                        RegExp: {
                            [CALL]: true,
                            [CONSTRUCT]: true
                        }
                    };
                    for (const { node } of tracker.iterateGlobalReferences(traceMap)) {
                        const regex = getStringIfConstant(node.arguments[0]);
                        const flags = getStringIfConstant(node.arguments[1]);
                        if (regex) {
                            checkRegex(regex, node, node.arguments[0], flags && flags.includes("u"));
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-numeric-literals.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow `parseInt()` in favor of binary, octal, and hexadecimal literals
     * @author Annie Zhang, Henry Zhu
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const radixMap = new Map([
        [2, { system: "binary", literalPrefix: "0b" }],
        [8, { system: "octal", literalPrefix: "0o" }],
        [16, { system: "hexadecimal", literalPrefix: "0x" }]
    ]);
    /**
     * Checks to see if a CallExpression's callee node is `parseInt` or
     * `Number.parseInt`.
     * @param {ASTNode} calleeNode The callee node to evaluate.
     * @returns {boolean} True if the callee is `parseInt` or `Number.parseInt`,
     * false otherwise.
     */
    function isParseInt(calleeNode) {
        return (astUtils.isSpecificId(calleeNode, "parseInt") ||
            astUtils.isSpecificMemberAccess(calleeNode, "Number", "parseInt"));
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow `parseInt()` and `Number.parseInt()` in favor of binary, octal, and hexadecimal literals",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-numeric-literals"
            },
            schema: [],
            messages: {
                useLiteral: "Use {{system}} literals instead of {{functionName}}()."
            },
            fixable: "code"
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                "CallExpression[arguments.length=2]"(node) {
                    const [strNode, radixNode] = node.arguments, str = astUtils.getStaticStringValue(strNode), radix = radixNode.value;
                    if (str !== null &&
                        astUtils.isStringLiteral(strNode) &&
                        radixNode.type === "Literal" &&
                        typeof radix === "number" &&
                        radixMap.has(radix) &&
                        isParseInt(node.callee)) {
                        const { system, literalPrefix } = radixMap.get(radix);
                        context.report({
                            node,
                            messageId: "useLiteral",
                            data: {
                                system,
                                functionName: sourceCode.getText(node.callee)
                            },
                            fix(fixer) {
                                if (sourceCode.getCommentsInside(node).length) {
                                    return null;
                                }
                                const replacement = `${literalPrefix}${str}`;
                                if (+replacement !== parseInt(str, radix)) {
                                    /*
                                     * If the newly-produced literal would be invalid, (e.g. 0b1234),
                                     * or it would yield an incorrect parseInt result for some other reason, don't make a fix.
                                     *
                                     * If `str` had numeric separators, `+replacement` will evaluate to `NaN` because unary `+`
                                     * per the specification doesn't support numeric separators. Thus, the above condition will be `true`
                                     * (`NaN !== anything` is always `true`) regardless of the `parseInt(str, radix)` value.
                                     * Consequently, no autofixes will be made. This is correct behavior because `parseInt` also
                                     * doesn't support numeric separators, but it does parse part of the string before the first `_`,
                                     * so the autofix would be invalid:
                                     *
                                     *   parseInt("1_1", 2) // === 1
                                     *   0b1_1 // === 3
                                     */
                                    return null;
                                }
                                const tokenBefore = sourceCode.getTokenBefore(node), tokenAfter = sourceCode.getTokenAfter(node);
                                let prefix = "", suffix = "";
                                if (tokenBefore &&
                                    tokenBefore.range[1] === node.range[0] &&
                                    !astUtils.canTokensBeAdjacent(tokenBefore, replacement)) {
                                    prefix = " ";
                                }
                                if (tokenAfter &&
                                    node.range[1] === tokenAfter.range[0] &&
                                    !astUtils.canTokensBeAdjacent(replacement, tokenAfter)) {
                                    suffix = " ";
                                }
                                return fixer.replaceText(node, `${prefix}${replacement}${suffix}`);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-object-has-own.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Prefers Object.hasOwn() instead of Object.prototype.hasOwnProperty.call()
     * @author Nitin Kumar
     * @author Gautam Arora
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks if the given node is considered to be an access to a property of `Object.prototype`.
     * @param {ASTNode} node `MemberExpression` node to evaluate.
     * @returns {boolean} `true` if `node.object` is `Object`, `Object.prototype`, or `{}` (empty 'ObjectExpression' node).
     */
    function hasLeftHandObject(node) {
        /*
         * ({}).hasOwnProperty.call(obj, prop) - `true`
         * ({ foo }.hasOwnProperty.call(obj, prop)) - `false`, object literal should be empty
         */
        if (node.object.type === "ObjectExpression" && node.object.properties.length === 0) {
            return true;
        }
        const objectNodeToCheck = node.object.type === "MemberExpression" && astUtils.getStaticPropertyName(node.object) === "prototype" ? node.object.object : node.object;
        if (objectNodeToCheck.type === "Identifier" && objectNodeToCheck.name === "Object") {
            return true;
        }
        return false;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow use of `Object.prototype.hasOwnProperty.call()` and prefer use of `Object.hasOwn()`",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-object-has-own"
            },
            schema: [],
            messages: {
                useHasOwn: "Use 'Object.hasOwn()' instead of 'Object.prototype.hasOwnProperty.call()'."
            },
            fixable: "code"
        },
        create(context) {
            return {
                CallExpression(node) {
                    if (!(node.callee.type === "MemberExpression" && node.callee.object.type === "MemberExpression")) {
                        return;
                    }
                    const calleePropertyName = astUtils.getStaticPropertyName(node.callee);
                    const objectPropertyName = astUtils.getStaticPropertyName(node.callee.object);
                    const isObject = hasLeftHandObject(node.callee.object);
                    // check `Object` scope
                    const scope = context.getScope();
                    const variable = astUtils.getVariableByName(scope, "Object");
                    if (calleePropertyName === "call" &&
                        objectPropertyName === "hasOwnProperty" &&
                        isObject &&
                        variable && variable.scope.type === "global") {
                        context.report({
                            node,
                            messageId: "useHasOwn",
                            fix(fixer) {
                                const sourceCode = context.getSourceCode();
                                if (sourceCode.getCommentsInside(node.callee).length > 0) {
                                    return null;
                                }
                                const tokenJustBeforeNode = sourceCode.getTokenBefore(node.callee, { includeComments: true });
                                // for https://github.com/eslint/eslint/pull/15346#issuecomment-991417335
                                if (tokenJustBeforeNode &&
                                    tokenJustBeforeNode.range[1] === node.callee.range[0] &&
                                    !astUtils.canTokensBeAdjacent(tokenJustBeforeNode, "Object.hasOwn")) {
                                    return fixer.replaceText(node.callee, " Object.hasOwn");
                                }
                                return fixer.replaceText(node.callee, "Object.hasOwn");
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-object-spread.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Prefers object spread property over Object.assign
     * @author Sharmila Jesupaul
     * See LICENSE file in root directory for full license.
     */
    "use strict";
    const { CALL, ReferenceTracker } = require(316) /* @eslint-community/eslint-utils */;
    const { isCommaToken, isOpeningParenToken, isClosingParenToken, isParenthesised } = require(360) /* ./utils/ast-utils */;
    const ANY_SPACE = /\s/u;
    /**
     * Helper that checks if the Object.assign call has array spread
     * @param {ASTNode} node The node that the rule warns on
     * @returns {boolean} - Returns true if the Object.assign call has array spread
     */
    function hasArraySpread(node) {
        return node.arguments.some(arg => arg.type === "SpreadElement");
    }
    /**
     * Determines whether the given node is an accessor property (getter/setter).
     * @param {ASTNode} node Node to check.
     * @returns {boolean} `true` if the node is a getter or a setter.
     */
    function isAccessorProperty(node) {
        return node.type === "Property" &&
            (node.kind === "get" || node.kind === "set");
    }
    /**
     * Determines whether the given object expression node has accessor properties (getters/setters).
     * @param {ASTNode} node `ObjectExpression` node to check.
     * @returns {boolean} `true` if the node has at least one getter/setter.
     */
    function hasAccessors(node) {
        return node.properties.some(isAccessorProperty);
    }
    /**
     * Determines whether the given call expression node has object expression arguments with accessor properties (getters/setters).
     * @param {ASTNode} node `CallExpression` node to check.
     * @returns {boolean} `true` if the node has at least one argument that is an object expression with at least one getter/setter.
     */
    function hasArgumentsWithAccessors(node) {
        return node.arguments
            .filter(arg => arg.type === "ObjectExpression")
            .some(hasAccessors);
    }
    /**
     * Helper that checks if the node needs parentheses to be valid JS.
     * The default is to wrap the node in parentheses to avoid parsing errors.
     * @param {ASTNode} node The node that the rule warns on
     * @param {Object} sourceCode in context sourcecode object
     * @returns {boolean} - Returns true if the node needs parentheses
     */
    function needsParens(node, sourceCode) {
        const parent = node.parent;
        switch (parent.type) {
            case "VariableDeclarator":
            case "ArrayExpression":
            case "ReturnStatement":
            case "CallExpression":
            case "Property":
                return false;
            case "AssignmentExpression":
                return parent.left === node && !isParenthesised(sourceCode, node);
            default:
                return !isParenthesised(sourceCode, node);
        }
    }
    /**
     * Determines if an argument needs parentheses. The default is to not add parens.
     * @param {ASTNode} node The node to be checked.
     * @param {Object} sourceCode in context sourcecode object
     * @returns {boolean} True if the node needs parentheses
     */
    function argNeedsParens(node, sourceCode) {
        switch (node.type) {
            case "AssignmentExpression":
            case "ArrowFunctionExpression":
            case "ConditionalExpression":
                return !isParenthesised(sourceCode, node);
            default:
                return false;
        }
    }
    /**
     * Get the parenthesis tokens of a given ObjectExpression node.
     * This includes the braces of the object literal and enclosing parentheses.
     * @param {ASTNode} node The node to get.
     * @param {Token} leftArgumentListParen The opening paren token of the argument list.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {Token[]} The parenthesis tokens of the node. This is sorted by the location.
     */
    function getParenTokens(node, leftArgumentListParen, sourceCode) {
        const parens = [sourceCode.getFirstToken(node), sourceCode.getLastToken(node)];
        let leftNext = sourceCode.getTokenBefore(node);
        let rightNext = sourceCode.getTokenAfter(node);
        // Note: don't include the parens of the argument list.
        while (leftNext &&
            rightNext &&
            leftNext.range[0] > leftArgumentListParen.range[0] &&
            isOpeningParenToken(leftNext) &&
            isClosingParenToken(rightNext)) {
            parens.push(leftNext, rightNext);
            leftNext = sourceCode.getTokenBefore(leftNext);
            rightNext = sourceCode.getTokenAfter(rightNext);
        }
        return parens.sort((a, b) => a.range[0] - b.range[0]);
    }
    /**
     * Get the range of a given token and around whitespaces.
     * @param {Token} token The token to get range.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {number} The end of the range of the token and around whitespaces.
     */
    function getStartWithSpaces(token, sourceCode) {
        const text = sourceCode.text;
        let start = token.range[0];
        // If the previous token is a line comment then skip this step to avoid commenting this token out.
        {
            const prevToken = sourceCode.getTokenBefore(token, { includeComments: true });
            if (prevToken && prevToken.type === "Line") {
                return start;
            }
        }
        // Detect spaces before the token.
        while (ANY_SPACE.test(text[start - 1] || "")) {
            start -= 1;
        }
        return start;
    }
    /**
     * Get the range of a given token and around whitespaces.
     * @param {Token} token The token to get range.
     * @param {SourceCode} sourceCode The source code object to get tokens.
     * @returns {number} The start of the range of the token and around whitespaces.
     */
    function getEndWithSpaces(token, sourceCode) {
        const text = sourceCode.text;
        let end = token.range[1];
        // Detect spaces after the token.
        while (ANY_SPACE.test(text[end] || "")) {
            end += 1;
        }
        return end;
    }
    /**
     * Autofixes the Object.assign call to use an object spread instead.
     * @param {ASTNode|null} node The node that the rule warns on, i.e. the Object.assign call
     * @param {string} sourceCode sourceCode of the Object.assign call
     * @returns {Function} autofixer - replaces the Object.assign with a spread object.
     */
    function defineFixer(node, sourceCode) {
        return function* (fixer) {
            const leftParen = sourceCode.getTokenAfter(node.callee, isOpeningParenToken);
            const rightParen = sourceCode.getLastToken(node);
            // Remove everything before the opening paren: callee `Object.assign`, type arguments, and whitespace between the callee and the paren.
            yield fixer.removeRange([node.range[0], leftParen.range[0]]);
            // Replace the parens of argument list to braces.
            if (needsParens(node, sourceCode)) {
                yield fixer.replaceText(leftParen, "({");
                yield fixer.replaceText(rightParen, "})");
            }
            else {
                yield fixer.replaceText(leftParen, "{");
                yield fixer.replaceText(rightParen, "}");
            }
            // Process arguments.
            for (const argNode of node.arguments) {
                const innerParens = getParenTokens(argNode, leftParen, sourceCode);
                const left = innerParens.shift();
                const right = innerParens.pop();
                if (argNode.type === "ObjectExpression") {
                    const maybeTrailingComma = sourceCode.getLastToken(argNode, 1);
                    const maybeArgumentComma = sourceCode.getTokenAfter(right);
                    /*
                     * Make bare this object literal.
                     * And remove spaces inside of the braces for better formatting.
                     */
                    for (const innerParen of innerParens) {
                        yield fixer.remove(innerParen);
                    }
                    const leftRange = [left.range[0], getEndWithSpaces(left, sourceCode)];
                    const rightRange = [
                        Math.max(getStartWithSpaces(right, sourceCode), leftRange[1]),
                        right.range[1]
                    ];
                    yield fixer.removeRange(leftRange);
                    yield fixer.removeRange(rightRange);
                    // Remove the comma of this argument if it's duplication.
                    if ((argNode.properties.length === 0 || isCommaToken(maybeTrailingComma)) &&
                        isCommaToken(maybeArgumentComma)) {
                        yield fixer.remove(maybeArgumentComma);
                    }
                }
                else {
                    // Make spread.
                    if (argNeedsParens(argNode, sourceCode)) {
                        yield fixer.insertTextBefore(left, "...(");
                        yield fixer.insertTextAfter(right, ")");
                    }
                    else {
                        yield fixer.insertTextBefore(left, "...");
                    }
                }
            }
        };
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow using Object.assign with an object literal as the first argument and prefer the use of object spread instead",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-object-spread"
            },
            schema: [],
            fixable: "code",
            messages: {
                useSpreadMessage: "Use an object spread instead of `Object.assign` eg: `{ ...foo }`.",
                useLiteralMessage: "Use an object literal instead of `Object.assign`. eg: `{ foo: bar }`."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                Program() {
                    const scope = context.getScope();
                    const tracker = new ReferenceTracker(scope);
                    const trackMap = {
                        Object: {
                            assign: { [CALL]: true }
                        }
                    };
                    // Iterate all calls of `Object.assign` (only of the global variable `Object`).
                    for (const { node } of tracker.iterateGlobalReferences(trackMap)) {
                        if (node.arguments.length >= 1 &&
                            node.arguments[0].type === "ObjectExpression" &&
                            !hasArraySpread(node) &&
                            !(node.arguments.length > 1 &&
                                hasArgumentsWithAccessors(node))) {
                            const messageId = node.arguments.length === 1
                                ? "useLiteralMessage"
                                : "useSpreadMessage";
                            const fix = defineFixer(node, sourceCode);
                            context.report({ node, messageId, fix });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-promise-reject-errors.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview restrict values that can be used as Promise rejection reasons
     * @author Teddy Katz
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require using Error objects as Promise rejection reasons",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-promise-reject-errors"
            },
            fixable: null,
            schema: [
                {
                    type: "object",
                    properties: {
                        allowEmptyReject: { type: "boolean", default: false }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                rejectAnError: "Expected the Promise rejection reason to be an Error."
            }
        },
        create(context) {
            const ALLOW_EMPTY_REJECT = context.options.length && context.options[0].allowEmptyReject;
            //----------------------------------------------------------------------
            // Helpers
            //----------------------------------------------------------------------
            /**
             * Checks the argument of a reject() or Promise.reject() CallExpression, and reports it if it can't be an Error
             * @param {ASTNode} callExpression A CallExpression node which is used to reject a Promise
             * @returns {void}
             */
            function checkRejectCall(callExpression) {
                if (!callExpression.arguments.length && ALLOW_EMPTY_REJECT) {
                    return;
                }
                if (!callExpression.arguments.length ||
                    !astUtils.couldBeError(callExpression.arguments[0]) ||
                    callExpression.arguments[0].type === "Identifier" && callExpression.arguments[0].name === "undefined") {
                    context.report({
                        node: callExpression,
                        messageId: "rejectAnError"
                    });
                }
            }
            /**
             * Determines whether a function call is a Promise.reject() call
             * @param {ASTNode} node A CallExpression node
             * @returns {boolean} `true` if the call is a Promise.reject() call
             */
            function isPromiseRejectCall(node) {
                return astUtils.isSpecificMemberAccess(node.callee, "Promise", "reject");
            }
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                // Check `Promise.reject(value)` calls.
                CallExpression(node) {
                    if (isPromiseRejectCall(node)) {
                        checkRejectCall(node);
                    }
                },
                /*
                 * Check for `new Promise((resolve, reject) => {})`, and check for reject() calls.
                 * This function is run on "NewExpression:exit" instead of "NewExpression" to ensure that
                 * the nodes in the expression already have the `parent` property.
                 */
                "NewExpression:exit"(node) {
                    if (node.callee.type === "Identifier" && node.callee.name === "Promise" &&
                        node.arguments.length && astUtils.isFunction(node.arguments[0]) &&
                        node.arguments[0].params.length > 1 && node.arguments[0].params[1].type === "Identifier") {
                        context.getDeclaredVariables(node.arguments[0])
                            /*
                             * Find the first variable that matches the second parameter's name.
                             * If the first parameter has the same name as the second parameter, then the variable will actually
                             * be "declared" when the first parameter is evaluated, but then it will be immediately overwritten
                             * by the second parameter. It's not possible for an expression with the variable to be evaluated before
                             * the variable is overwritten, because functions with duplicate parameters cannot have destructuring or
                             * default assignments in their parameter lists. Therefore, it's not necessary to explicitly account for
                             * this case.
                             */
                            .find(variable => variable.name === node.arguments[0].params[1].name)
                            // Get the references to that variable.
                            .references
                            // Only check the references that read the parameter's value.
                            .filter(ref => ref.isRead())
                            // Only check the references that are used as the callee in a function call, e.g. `reject(foo)`.
                            .filter(ref => ref.identifier.parent.type === "CallExpression" && ref.identifier === ref.identifier.parent.callee)
                            // Check the argument of the function call to determine whether it's an Error.
                            .forEach(ref => checkRejectCall(ref.identifier.parent));
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-reflect.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to suggest using "Reflect" api over Function/Object methods
     * @author Keith Cirkel <http://keithcirkel.co.uk>
     * @deprecated in ESLint v3.9.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require `Reflect` methods where applicable",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-reflect"
            },
            deprecated: true,
            replacedBy: [],
            schema: [
                {
                    type: "object",
                    properties: {
                        exceptions: {
                            type: "array",
                            items: {
                                enum: [
                                    "apply",
                                    "call",
                                    "delete",
                                    "defineProperty",
                                    "getOwnPropertyDescriptor",
                                    "getPrototypeOf",
                                    "setPrototypeOf",
                                    "isExtensible",
                                    "getOwnPropertyNames",
                                    "preventExtensions"
                                ]
                            },
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                preferReflect: "Avoid using {{existing}}, instead use {{substitute}}."
            }
        },
        create(context) {
            const existingNames = {
                apply: "Function.prototype.apply",
                call: "Function.prototype.call",
                defineProperty: "Object.defineProperty",
                getOwnPropertyDescriptor: "Object.getOwnPropertyDescriptor",
                getPrototypeOf: "Object.getPrototypeOf",
                setPrototypeOf: "Object.setPrototypeOf",
                isExtensible: "Object.isExtensible",
                getOwnPropertyNames: "Object.getOwnPropertyNames",
                preventExtensions: "Object.preventExtensions"
            };
            const reflectSubstitutes = {
                apply: "Reflect.apply",
                call: "Reflect.apply",
                defineProperty: "Reflect.defineProperty",
                getOwnPropertyDescriptor: "Reflect.getOwnPropertyDescriptor",
                getPrototypeOf: "Reflect.getPrototypeOf",
                setPrototypeOf: "Reflect.setPrototypeOf",
                isExtensible: "Reflect.isExtensible",
                getOwnPropertyNames: "Reflect.getOwnPropertyNames",
                preventExtensions: "Reflect.preventExtensions"
            };
            const exceptions = (context.options[0] || {}).exceptions || [];
            /**
             * Reports the Reflect violation based on the `existing` and `substitute`
             * @param {Object} node The node that violates the rule.
             * @param {string} existing The existing method name that has been used.
             * @param {string} substitute The Reflect substitute that should be used.
             * @returns {void}
             */
            function report(node, existing, substitute) {
                context.report({
                    node,
                    messageId: "preferReflect",
                    data: {
                        existing,
                        substitute
                    }
                });
            }
            return {
                CallExpression(node) {
                    const methodName = (node.callee.property || {}).name;
                    const isReflectCall = (node.callee.object || {}).name === "Reflect";
                    const hasReflectSubstitute = Object.prototype.hasOwnProperty.call(reflectSubstitutes, methodName);
                    const userConfiguredException = exceptions.includes(methodName);
                    if (hasReflectSubstitute && !isReflectCall && !userConfiguredException) {
                        report(node, existingNames[methodName], reflectSubstitutes[methodName]);
                    }
                },
                UnaryExpression(node) {
                    const isDeleteOperator = node.operator === "delete";
                    const targetsIdentifier = node.argument.type === "Identifier";
                    const userConfiguredException = exceptions.includes("delete");
                    if (isDeleteOperator && !targetsIdentifier && !userConfiguredException) {
                        report(node, "the delete keyword", "Reflect.deleteProperty");
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-regex-literals.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow use of the `RegExp` constructor in favor of regular expression literals
     * @author Milos Djermanovic
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const { CALL, CONSTRUCT, ReferenceTracker, findVariable } = require(316) /* @eslint-community/eslint-utils */;
    const { RegExpValidator, visitRegExpAST, RegExpParser } = require(485) /* @eslint-community/regexpp */;
    const { canTokensBeAdjacent } = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const REGEXPP_LATEST_ECMA_VERSION = 2022;
    /**
     * Determines whether the given node is a string literal.
     * @param {ASTNode} node Node to check.
     * @returns {boolean} True if the node is a string literal.
     */
    function isStringLiteral(node) {
        return node.type === "Literal" && typeof node.value === "string";
    }
    /**
     * Determines whether the given node is a regex literal.
     * @param {ASTNode} node Node to check.
     * @returns {boolean} True if the node is a regex literal.
     */
    function isRegexLiteral(node) {
        return node.type === "Literal" && Object.prototype.hasOwnProperty.call(node, "regex");
    }
    /**
     * Determines whether the given node is a template literal without expressions.
     * @param {ASTNode} node Node to check.
     * @returns {boolean} True if the node is a template literal without expressions.
     */
    function isStaticTemplateLiteral(node) {
        return node.type === "TemplateLiteral" && node.expressions.length === 0;
    }
    const validPrecedingTokens = new Set([
        "(",
        ";",
        "[",
        ",",
        "=",
        "+",
        "*",
        "-",
        "?",
        "~",
        "%",
        "**",
        "!",
        "typeof",
        "instanceof",
        "&&",
        "||",
        "??",
        "return",
        "...",
        "delete",
        "void",
        "in",
        "<",
        ">",
        "<=",
        ">=",
        "==",
        "===",
        "!=",
        "!==",
        "<<",
        ">>",
        ">>>",
        "&",
        "|",
        "^",
        ":",
        "{",
        "=>",
        "*=",
        "<<=",
        ">>=",
        ">>>=",
        "^=",
        "|=",
        "&=",
        "??=",
        "||=",
        "&&=",
        "**=",
        "+=",
        "-=",
        "/=",
        "%=",
        "/",
        "do",
        "break",
        "continue",
        "debugger",
        "case",
        "throw"
    ]);
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow use of the `RegExp` constructor in favor of regular expression literals",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-regex-literals"
            },
            hasSuggestions: true,
            schema: [
                {
                    type: "object",
                    properties: {
                        disallowRedundantWrapping: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedRegExp: "Use a regular expression literal instead of the 'RegExp' constructor.",
                replaceWithLiteral: "Replace with an equivalent regular expression literal.",
                replaceWithLiteralAndFlags: "Replace with an equivalent regular expression literal with flags '{{ flags }}'.",
                replaceWithIntendedLiteralAndFlags: "Replace with a regular expression literal with flags '{{ flags }}'.",
                unexpectedRedundantRegExp: "Regular expression literal is unnecessarily wrapped within a 'RegExp' constructor.",
                unexpectedRedundantRegExpWithFlags: "Use regular expression literal with flags instead of the 'RegExp' constructor."
            }
        },
        create(context) {
            const [{ disallowRedundantWrapping = false } = {}] = context.options;
            const sourceCode = context.getSourceCode();
            /**
             * Determines whether the given identifier node is a reference to a global variable.
             * @param {ASTNode} node `Identifier` node to check.
             * @returns {boolean} True if the identifier is a reference to a global variable.
             */
            function isGlobalReference(node) {
                const scope = context.getScope();
                const variable = findVariable(scope, node);
                return variable !== null && variable.scope.type === "global" && variable.defs.length === 0;
            }
            /**
             * Determines whether the given node is a String.raw`` tagged template expression
             * with a static template literal.
             * @param {ASTNode} node Node to check.
             * @returns {boolean} True if the node is String.raw`` with a static template.
             */
            function isStringRawTaggedStaticTemplateLiteral(node) {
                return node.type === "TaggedTemplateExpression" &&
                    astUtils.isSpecificMemberAccess(node.tag, "String", "raw") &&
                    isGlobalReference(astUtils.skipChainExpression(node.tag).object) &&
                    isStaticTemplateLiteral(node.quasi);
            }
            /**
             * Gets the value of a string
             * @param {ASTNode} node The node to get the string of.
             * @returns {string|null} The value of the node.
             */
            function getStringValue(node) {
                if (isStringLiteral(node)) {
                    return node.value;
                }
                if (isStaticTemplateLiteral(node)) {
                    return node.quasis[0].value.cooked;
                }
                if (isStringRawTaggedStaticTemplateLiteral(node)) {
                    return node.quasi.quasis[0].value.raw;
                }
                return null;
            }
            /**
             * Determines whether the given node is considered to be a static string by the logic of this rule.
             * @param {ASTNode} node Node to check.
             * @returns {boolean} True if the node is a static string.
             */
            function isStaticString(node) {
                return isStringLiteral(node) ||
                    isStaticTemplateLiteral(node) ||
                    isStringRawTaggedStaticTemplateLiteral(node);
            }
            /**
             * Determines whether the relevant arguments of the given are all static string literals.
             * @param {ASTNode} node Node to check.
             * @returns {boolean} True if all arguments are static strings.
             */
            function hasOnlyStaticStringArguments(node) {
                const args = node.arguments;
                if ((args.length === 1 || args.length === 2) && args.every(isStaticString)) {
                    return true;
                }
                return false;
            }
            /**
             * Determines whether the arguments of the given node indicate that a regex literal is unnecessarily wrapped.
             * @param {ASTNode} node Node to check.
             * @returns {boolean} True if the node already contains a regex literal argument.
             */
            function isUnnecessarilyWrappedRegexLiteral(node) {
                const args = node.arguments;
                if (args.length === 1 && isRegexLiteral(args[0])) {
                    return true;
                }
                if (args.length === 2 && isRegexLiteral(args[0]) && isStaticString(args[1])) {
                    return true;
                }
                return false;
            }
            /**
             * Returns a ecmaVersion compatible for regexpp.
             * @param {number} ecmaVersion The ecmaVersion to convert.
             * @returns {import("regexpp/ecma-versions").EcmaVersion} The resulting ecmaVersion compatible for regexpp.
             */
            function getRegexppEcmaVersion(ecmaVersion) {
                if (ecmaVersion <= 5) {
                    return 5;
                }
                return Math.min(ecmaVersion, REGEXPP_LATEST_ECMA_VERSION);
            }
            const regexppEcmaVersion = getRegexppEcmaVersion(context.languageOptions.ecmaVersion);
            /**
             * Makes a character escaped or else returns null.
             * @param {string} character The character to escape.
             * @returns {string} The resulting escaped character.
             */
            function resolveEscapes(character) {
                switch (character) {
                    case "\n":
                    case "\\\n":
                        return "\\n";
                    case "\r":
                    case "\\\r":
                        return "\\r";
                    case "\t":
                    case "\\\t":
                        return "\\t";
                    case "\v":
                    case "\\\v":
                        return "\\v";
                    case "\f":
                    case "\\\f":
                        return "\\f";
                    case "/":
                        return "\\/";
                    default:
                        return null;
                }
            }
            /**
             * Checks whether the given regex and flags are valid for the ecma version or not.
             * @param {string} pattern The regex pattern to check.
             * @param {string | undefined} flags The regex flags to check.
             * @returns {boolean} True if the given regex pattern and flags are valid for the ecma version.
             */
            function isValidRegexForEcmaVersion(pattern, flags) {
                const validator = new RegExpValidator({ ecmaVersion: regexppEcmaVersion });
                try {
                    validator.validatePattern(pattern, 0, pattern.length, flags ? flags.includes("u") : false);
                    if (flags) {
                        validator.validateFlags(flags);
                    }
                    return true;
                }
                catch {
                    return false;
                }
            }
            /**
             * Checks whether two given regex flags contain the same flags or not.
             * @param {string} flagsA The regex flags.
             * @param {string} flagsB The regex flags.
             * @returns {boolean} True if two regex flags contain same flags.
             */
            function areFlagsEqual(flagsA, flagsB) {
                return [...flagsA].sort().join("") === [...flagsB].sort().join("");
            }
            /**
             * Merges two regex flags.
             * @param {string} flagsA The regex flags.
             * @param {string} flagsB The regex flags.
             * @returns {string} The merged regex flags.
             */
            function mergeRegexFlags(flagsA, flagsB) {
                const flagsSet = new Set([
                    ...flagsA,
                    ...flagsB
                ]);
                return [...flagsSet].join("");
            }
            /**
             * Checks whether a give node can be fixed to the given regex pattern and flags.
             * @param {ASTNode} node The node to check.
             * @param {string} pattern The regex pattern to check.
             * @param {string} flags The regex flags
             * @returns {boolean} True if a node can be fixed to the given regex pattern and flags.
             */
            function canFixTo(node, pattern, flags) {
                const tokenBefore = sourceCode.getTokenBefore(node);
                return sourceCode.getCommentsInside(node).length === 0 &&
                    (!tokenBefore || validPrecedingTokens.has(tokenBefore.value)) &&
                    isValidRegexForEcmaVersion(pattern, flags);
            }
            /**
             * Returns a safe output code considering the before and after tokens.
             * @param {ASTNode} node The regex node.
             * @param {string} newRegExpValue The new regex expression value.
             * @returns {string} The output code.
             */
            function getSafeOutput(node, newRegExpValue) {
                const tokenBefore = sourceCode.getTokenBefore(node);
                const tokenAfter = sourceCode.getTokenAfter(node);
                return (tokenBefore && !canTokensBeAdjacent(tokenBefore, newRegExpValue) && tokenBefore.range[1] === node.range[0] ? " " : "") +
                    newRegExpValue +
                    (tokenAfter && !canTokensBeAdjacent(newRegExpValue, tokenAfter) && node.range[1] === tokenAfter.range[0] ? " " : "");
            }
            return {
                Program() {
                    const scope = context.getScope();
                    const tracker = new ReferenceTracker(scope);
                    const traceMap = {
                        RegExp: {
                            [CALL]: true,
                            [CONSTRUCT]: true
                        }
                    };
                    for (const { node } of tracker.iterateGlobalReferences(traceMap)) {
                        if (disallowRedundantWrapping && isUnnecessarilyWrappedRegexLiteral(node)) {
                            const regexNode = node.arguments[0];
                            if (node.arguments.length === 2) {
                                const suggests = [];
                                const argFlags = getStringValue(node.arguments[1]) || "";
                                if (canFixTo(node, regexNode.regex.pattern, argFlags)) {
                                    suggests.push({
                                        messageId: "replaceWithLiteralAndFlags",
                                        pattern: regexNode.regex.pattern,
                                        flags: argFlags
                                    });
                                }
                                const literalFlags = regexNode.regex.flags || "";
                                const mergedFlags = mergeRegexFlags(literalFlags, argFlags);
                                if (!areFlagsEqual(mergedFlags, argFlags) &&
                                    canFixTo(node, regexNode.regex.pattern, mergedFlags)) {
                                    suggests.push({
                                        messageId: "replaceWithIntendedLiteralAndFlags",
                                        pattern: regexNode.regex.pattern,
                                        flags: mergedFlags
                                    });
                                }
                                context.report({
                                    node,
                                    messageId: "unexpectedRedundantRegExpWithFlags",
                                    suggest: suggests.map(({ flags, pattern, messageId }) => ({
                                        messageId,
                                        data: {
                                            flags
                                        },
                                        fix(fixer) {
                                            return fixer.replaceText(node, getSafeOutput(node, `/${pattern}/${flags}`));
                                        }
                                    }))
                                });
                            }
                            else {
                                const outputs = [];
                                if (canFixTo(node, regexNode.regex.pattern, regexNode.regex.flags)) {
                                    outputs.push(sourceCode.getText(regexNode));
                                }
                                context.report({
                                    node,
                                    messageId: "unexpectedRedundantRegExp",
                                    suggest: outputs.map(output => ({
                                        messageId: "replaceWithLiteral",
                                        fix(fixer) {
                                            return fixer.replaceText(node, getSafeOutput(node, output));
                                        }
                                    }))
                                });
                            }
                        }
                        else if (hasOnlyStaticStringArguments(node)) {
                            let regexContent = getStringValue(node.arguments[0]);
                            let noFix = false;
                            let flags;
                            if (node.arguments[1]) {
                                flags = getStringValue(node.arguments[1]);
                            }
                            if (!canFixTo(node, regexContent, flags)) {
                                noFix = true;
                            }
                            if (!/^[-a-zA-Z0-9\\[\](){} \t\r\n\v\f!@#$%^&*+^_=/~`.><?,'"|:;]*$/u.test(regexContent)) {
                                noFix = true;
                            }
                            if (regexContent && !noFix) {
                                let charIncrease = 0;
                                const ast = new RegExpParser({ ecmaVersion: regexppEcmaVersion }).parsePattern(regexContent, 0, regexContent.length, flags ? flags.includes("u") : false);
                                visitRegExpAST(ast, {
                                    onCharacterEnter(characterNode) {
                                        const escaped = resolveEscapes(characterNode.raw);
                                        if (escaped) {
                                            regexContent =
                                                regexContent.slice(0, characterNode.start + charIncrease) +
                                                    escaped +
                                                    regexContent.slice(characterNode.end + charIncrease);
                                            if (characterNode.raw.length === 1) {
                                                charIncrease += 1;
                                            }
                                        }
                                    }
                                });
                            }
                            const newRegExpValue = `/${regexContent || "(?:)"}/${flags || ""}`;
                            context.report({
                                node,
                                messageId: "unexpectedRegExp",
                                suggest: noFix ? [] : [{
                                        messageId: "replaceWithLiteral",
                                        fix(fixer) {
                                            return fixer.replaceText(node, getSafeOutput(node, newRegExpValue));
                                        }
                                    }]
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-rest-params.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Gets the variable object of `arguments` which is defined implicitly.
     * @param {eslint-scope.Scope} scope A scope to get.
     * @returns {eslint-scope.Variable} The found variable object.
     */
    function getVariableOfArguments(scope) {
        const variables = scope.variables;
        for (let i = 0; i < variables.length; ++i) {
            const variable = variables[i];
            if (variable.name === "arguments") {
                /*
                 * If there was a parameter which is named "arguments", the implicit "arguments" is not defined.
                 * So does fast return with null.
                 */
                return (variable.identifiers.length === 0) ? variable : null;
            }
        }
        /* c8 ignore next */
        return null;
    }
    /**
     * Checks if the given reference is not normal member access.
     *
     * - arguments         .... true    // not member access
     * - arguments[i]      .... true    // computed member access
     * - arguments[0]      .... true    // computed member access
     * - arguments.length  .... false   // normal member access
     * @param {eslint-scope.Reference} reference The reference to check.
     * @returns {boolean} `true` if the reference is not normal member access.
     */
    function isNotNormalMemberAccess(reference) {
        const id = reference.identifier;
        const parent = id.parent;
        return !(parent.type === "MemberExpression" &&
            parent.object === id &&
            !parent.computed);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require rest parameters instead of `arguments`",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-rest-params"
            },
            schema: [],
            messages: {
                preferRestParams: "Use the rest parameters instead of 'arguments'."
            }
        },
        create(context) {
            /**
             * Reports a given reference.
             * @param {eslint-scope.Reference} reference A reference to report.
             * @returns {void}
             */
            function report(reference) {
                context.report({
                    node: reference.identifier,
                    loc: reference.identifier.loc,
                    messageId: "preferRestParams"
                });
            }
            /**
             * Reports references of the implicit `arguments` variable if exist.
             * @returns {void}
             */
            function checkForArguments() {
                const argumentsVar = getVariableOfArguments(context.getScope());
                if (argumentsVar) {
                    argumentsVar
                        .references
                        .filter(isNotNormalMemberAccess)
                        .forEach(report);
                }
            }
            return {
                "FunctionDeclaration:exit": checkForArguments,
                "FunctionExpression:exit": checkForArguments
            };
        }
    };
},
/* eslint/lib/rules/prefer-spread.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to suggest using of the spread operator instead of `.apply()`.
     * @author Toru Nagashima
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a node is a `.apply()` for variadic.
     * @param {ASTNode} node A CallExpression node to check.
     * @returns {boolean} Whether or not the node is a `.apply()` for variadic.
     */
    function isVariadicApplyCalling(node) {
        return (astUtils.isSpecificMemberAccess(node.callee, null, "apply") &&
            node.arguments.length === 2 &&
            node.arguments[1].type !== "ArrayExpression" &&
            node.arguments[1].type !== "SpreadElement");
    }
    /**
     * Checks whether or not `thisArg` is not changed by `.apply()`.
     * @param {ASTNode|null} expectedThis The node that is the owner of the applied function.
     * @param {ASTNode} thisArg The node that is given to the first argument of the `.apply()`.
     * @param {RuleContext} context The ESLint rule context object.
     * @returns {boolean} Whether or not `thisArg` is not changed by `.apply()`.
     */
    function isValidThisArg(expectedThis, thisArg, context) {
        if (!expectedThis) {
            return astUtils.isNullOrUndefined(thisArg);
        }
        return astUtils.equalTokens(expectedThis, thisArg, context);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require spread operators instead of `.apply()`",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-spread"
            },
            schema: [],
            fixable: null,
            messages: {
                preferSpread: "Use the spread operator instead of '.apply()'."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                CallExpression(node) {
                    if (!isVariadicApplyCalling(node)) {
                        return;
                    }
                    const applied = astUtils.skipChainExpression(astUtils.skipChainExpression(node.callee).object);
                    const expectedThis = (applied.type === "MemberExpression") ? applied.object : null;
                    const thisArg = node.arguments[0];
                    if (isValidThisArg(expectedThis, thisArg, sourceCode)) {
                        context.report({
                            node,
                            messageId: "preferSpread"
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/prefer-template.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to suggest using template literals instead of string concatenation.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether or not a given node is a concatenation.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node is a concatenation.
     */
    function isConcatenation(node) {
        return node.type === "BinaryExpression" && node.operator === "+";
    }
    /**
     * Gets the top binary expression node for concatenation in parents of a given node.
     * @param {ASTNode} node A node to get.
     * @returns {ASTNode} the top binary expression node in parents of a given node.
     */
    function getTopConcatBinaryExpression(node) {
        let currentNode = node;
        while (isConcatenation(currentNode.parent)) {
            currentNode = currentNode.parent;
        }
        return currentNode;
    }
    /**
     * Checks whether or not a node contains a string literal with an octal or non-octal decimal escape sequence
     * @param {ASTNode} node A node to check
     * @returns {boolean} `true` if at least one string literal within the node contains
     * an octal or non-octal decimal escape sequence
     */
    function hasOctalOrNonOctalDecimalEscapeSequence(node) {
        if (isConcatenation(node)) {
            return (hasOctalOrNonOctalDecimalEscapeSequence(node.left) ||
                hasOctalOrNonOctalDecimalEscapeSequence(node.right));
        }
        // No need to check TemplateLiterals – would throw parsing error
        if (node.type === "Literal" && typeof node.value === "string") {
            return astUtils.hasOctalOrNonOctalDecimalEscapeSequence(node.raw);
        }
        return false;
    }
    /**
     * Checks whether or not a given binary expression has string literals.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node has string literals.
     */
    function hasStringLiteral(node) {
        if (isConcatenation(node)) {
            // `left` is deeper than `right` normally.
            return hasStringLiteral(node.right) || hasStringLiteral(node.left);
        }
        return astUtils.isStringLiteral(node);
    }
    /**
     * Checks whether or not a given binary expression has non string literals.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node has non string literals.
     */
    function hasNonStringLiteral(node) {
        if (isConcatenation(node)) {
            // `left` is deeper than `right` normally.
            return hasNonStringLiteral(node.right) || hasNonStringLiteral(node.left);
        }
        return !astUtils.isStringLiteral(node);
    }
    /**
     * Determines whether a given node will start with a template curly expression (`${}`) when being converted to a template literal.
     * @param {ASTNode} node The node that will be fixed to a template literal
     * @returns {boolean} `true` if the node will start with a template curly.
     */
    function startsWithTemplateCurly(node) {
        if (node.type === "BinaryExpression") {
            return startsWithTemplateCurly(node.left);
        }
        if (node.type === "TemplateLiteral") {
            return node.expressions.length && node.quasis.length && node.quasis[0].range[0] === node.quasis[0].range[1];
        }
        return node.type !== "Literal" || typeof node.value !== "string";
    }
    /**
     * Determines whether a given node end with a template curly expression (`${}`) when being converted to a template literal.
     * @param {ASTNode} node The node that will be fixed to a template literal
     * @returns {boolean} `true` if the node will end with a template curly.
     */
    function endsWithTemplateCurly(node) {
        if (node.type === "BinaryExpression") {
            return startsWithTemplateCurly(node.right);
        }
        if (node.type === "TemplateLiteral") {
            return node.expressions.length && node.quasis.length && node.quasis[node.quasis.length - 1].range[0] === node.quasis[node.quasis.length - 1].range[1];
        }
        return node.type !== "Literal" || typeof node.value !== "string";
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require template literals instead of string concatenation",
                recommended: false,
                url: "https://eslint.org/docs/rules/prefer-template"
            },
            schema: [],
            fixable: "code",
            messages: {
                unexpectedStringConcatenation: "Unexpected string concatenation."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            let done = Object.create(null);
            /**
             * Gets the non-token text between two nodes, ignoring any other tokens that appear between the two tokens.
             * @param {ASTNode} node1 The first node
             * @param {ASTNode} node2 The second node
             * @returns {string} The text between the nodes, excluding other tokens
             */
            function getTextBetween(node1, node2) {
                const allTokens = [node1].concat(sourceCode.getTokensBetween(node1, node2)).concat(node2);
                const sourceText = sourceCode.getText();
                return allTokens.slice(0, -1).reduce((accumulator, token, index) => accumulator + sourceText.slice(token.range[1], allTokens[index + 1].range[0]), "");
            }
            /**
             * Returns a template literal form of the given node.
             * @param {ASTNode} currentNode A node that should be converted to a template literal
             * @param {string} textBeforeNode Text that should appear before the node
             * @param {string} textAfterNode Text that should appear after the node
             * @returns {string} A string form of this node, represented as a template literal
             */
            function getTemplateLiteral(currentNode, textBeforeNode, textAfterNode) {
                if (currentNode.type === "Literal" && typeof currentNode.value === "string") {
                    /*
                     * If the current node is a string literal, escape any instances of ${ or ` to prevent them from being interpreted
                     * as a template placeholder. However, if the code already contains a backslash before the ${ or `
                     * for some reason, don't add another backslash, because that would change the meaning of the code (it would cause
                     * an actual backslash character to appear before the dollar sign).
                     */
                    return `\`${currentNode.raw.slice(1, -1).replace(/\\*(\$\{|`)/gu, matched => {
                        if (matched.lastIndexOf("\\") % 2) {
                            return `\\${matched}`;
                        }
                        return matched;
                        // Unescape any quotes that appear in the original Literal that no longer need to be escaped.
                    }).replace(new RegExp(`\\\\${currentNode.raw[0]}`, "gu"), currentNode.raw[0])}\``;
                }
                if (currentNode.type === "TemplateLiteral") {
                    return sourceCode.getText(currentNode);
                }
                if (isConcatenation(currentNode) && hasStringLiteral(currentNode)) {
                    const plusSign = sourceCode.getFirstTokenBetween(currentNode.left, currentNode.right, token => token.value === "+");
                    const textBeforePlus = getTextBetween(currentNode.left, plusSign);
                    const textAfterPlus = getTextBetween(plusSign, currentNode.right);
                    const leftEndsWithCurly = endsWithTemplateCurly(currentNode.left);
                    const rightStartsWithCurly = startsWithTemplateCurly(currentNode.right);
                    if (leftEndsWithCurly) {
                        // If the left side of the expression ends with a template curly, add the extra text to the end of the curly bracket.
                        // `foo${bar}` /* comment */ + 'baz' --> `foo${bar /* comment */  }${baz}`
                        return getTemplateLiteral(currentNode.left, textBeforeNode, textBeforePlus + textAfterPlus).slice(0, -1) +
                            getTemplateLiteral(currentNode.right, null, textAfterNode).slice(1);
                    }
                    if (rightStartsWithCurly) {
                        // Otherwise, if the right side of the expression starts with a template curly, add the text there.
                        // 'foo' /* comment */ + `${bar}baz` --> `foo${ /* comment */  bar}baz`
                        return getTemplateLiteral(currentNode.left, textBeforeNode, null).slice(0, -1) +
                            getTemplateLiteral(currentNode.right, textBeforePlus + textAfterPlus, textAfterNode).slice(1);
                    }
                    /*
                     * Otherwise, these nodes should not be combined into a template curly, since there is nowhere to put
                     * the text between them.
                     */
                    return `${getTemplateLiteral(currentNode.left, textBeforeNode, null)}${textBeforePlus}+${textAfterPlus}${getTemplateLiteral(currentNode.right, textAfterNode, null)}`;
                }
                return `\`\${${textBeforeNode || ""}${sourceCode.getText(currentNode)}${textAfterNode || ""}}\``;
            }
            /**
             * Returns a fixer object that converts a non-string binary expression to a template literal
             * @param {SourceCodeFixer} fixer The fixer object
             * @param {ASTNode} node A node that should be converted to a template literal
             * @returns {Object} A fix for this binary expression
             */
            function fixNonStringBinaryExpression(fixer, node) {
                const topBinaryExpr = getTopConcatBinaryExpression(node.parent);
                if (hasOctalOrNonOctalDecimalEscapeSequence(topBinaryExpr)) {
                    return null;
                }
                return fixer.replaceText(topBinaryExpr, getTemplateLiteral(topBinaryExpr, null, null));
            }
            /**
             * Reports if a given node is string concatenation with non string literals.
             * @param {ASTNode} node A node to check.
             * @returns {void}
             */
            function checkForStringConcat(node) {
                if (!astUtils.isStringLiteral(node) || !isConcatenation(node.parent)) {
                    return;
                }
                const topBinaryExpr = getTopConcatBinaryExpression(node.parent);
                // Checks whether or not this node had been checked already.
                if (done[topBinaryExpr.range[0]]) {
                    return;
                }
                done[topBinaryExpr.range[0]] = true;
                if (hasNonStringLiteral(topBinaryExpr)) {
                    context.report({
                        node: topBinaryExpr,
                        messageId: "unexpectedStringConcatenation",
                        fix: fixer => fixNonStringBinaryExpression(fixer, node)
                    });
                }
            }
            return {
                Program() {
                    done = Object.create(null);
                },
                Literal: checkForStringConcat,
                TemplateLiteral: checkForStringConcat
            };
        }
    };
},
/* eslint/lib/rules/quote-props.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag non-quoted property names in object literals.
     * @author Mathias Bynens <http://mathiasbynens.be/>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const espree = require(305) /* espree */;
    const astUtils = require(360) /* ./utils/ast-utils */;
    const keywords = require(395) /* ./utils/keywords */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require quotes around object literal property names",
                recommended: false,
                url: "https://eslint.org/docs/rules/quote-props"
            },
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always", "as-needed", "consistent", "consistent-as-needed"]
                            }
                        ],
                        minItems: 0,
                        maxItems: 1
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always", "as-needed", "consistent", "consistent-as-needed"]
                            },
                            {
                                type: "object",
                                properties: {
                                    keywords: {
                                        type: "boolean"
                                    },
                                    unnecessary: {
                                        type: "boolean"
                                    },
                                    numbers: {
                                        type: "boolean"
                                    }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    }
                ]
            },
            fixable: "code",
            messages: {
                requireQuotesDueToReservedWord: "Properties should be quoted as '{{property}}' is a reserved word.",
                inconsistentlyQuotedProperty: "Inconsistently quoted property '{{key}}' found.",
                unnecessarilyQuotedProperty: "Unnecessarily quoted property '{{property}}' found.",
                unquotedReservedProperty: "Unquoted reserved word '{{property}}' used as key.",
                unquotedNumericProperty: "Unquoted number literal '{{property}}' used as key.",
                unquotedPropertyFound: "Unquoted property '{{property}}' found.",
                redundantQuoting: "Properties shouldn't be quoted as all quotes are redundant."
            }
        },
        create(context) {
            const MODE = context.options[0], KEYWORDS = context.options[1] && context.options[1].keywords, CHECK_UNNECESSARY = !context.options[1] || context.options[1].unnecessary !== false, NUMBERS = context.options[1] && context.options[1].numbers, sourceCode = context.getSourceCode();
            /**
             * Checks whether a certain string constitutes an ES3 token
             * @param {string} tokenStr The string to be checked.
             * @returns {boolean} `true` if it is an ES3 token.
             */
            function isKeyword(tokenStr) {
                return keywords.includes(tokenStr);
            }
            /**
             * Checks if an espree-tokenized key has redundant quotes (i.e. whether quotes are unnecessary)
             * @param {string} rawKey The raw key value from the source
             * @param {espreeTokens} tokens The espree-tokenized node key
             * @param {boolean} [skipNumberLiterals=false] Indicates whether number literals should be checked
             * @returns {boolean} Whether or not a key has redundant quotes.
             * @private
             */
            function areQuotesRedundant(rawKey, tokens, skipNumberLiterals) {
                return tokens.length === 1 && tokens[0].start === 0 && tokens[0].end === rawKey.length &&
                    (["Identifier", "Keyword", "Null", "Boolean"].includes(tokens[0].type) ||
                        (tokens[0].type === "Numeric" && !skipNumberLiterals && String(+tokens[0].value) === tokens[0].value));
            }
            /**
             * Returns a string representation of a property node with quotes removed
             * @param {ASTNode} key Key AST Node, which may or may not be quoted
             * @returns {string} A replacement string for this property
             */
            function getUnquotedKey(key) {
                return key.type === "Identifier" ? key.name : key.value;
            }
            /**
             * Returns a string representation of a property node with quotes added
             * @param {ASTNode} key Key AST Node, which may or may not be quoted
             * @returns {string} A replacement string for this property
             */
            function getQuotedKey(key) {
                if (key.type === "Literal" && typeof key.value === "string") {
                    // If the key is already a string literal, don't replace the quotes with double quotes.
                    return sourceCode.getText(key);
                }
                // Otherwise, the key is either an identifier or a number literal.
                return `"${key.type === "Identifier" ? key.name : key.value}"`;
            }
            /**
             * Ensures that a property's key is quoted only when necessary
             * @param {ASTNode} node Property AST node
             * @returns {void}
             */
            function checkUnnecessaryQuotes(node) {
                const key = node.key;
                if (node.method || node.computed || node.shorthand) {
                    return;
                }
                if (key.type === "Literal" && typeof key.value === "string") {
                    let tokens;
                    try {
                        tokens = espree.tokenize(key.value);
                    }
                    catch {
                        return;
                    }
                    if (tokens.length !== 1) {
                        return;
                    }
                    const isKeywordToken = isKeyword(tokens[0].value);
                    if (isKeywordToken && KEYWORDS) {
                        return;
                    }
                    if (CHECK_UNNECESSARY && areQuotesRedundant(key.value, tokens, NUMBERS)) {
                        context.report({
                            node,
                            messageId: "unnecessarilyQuotedProperty",
                            data: { property: key.value },
                            fix: fixer => fixer.replaceText(key, getUnquotedKey(key))
                        });
                    }
                }
                else if (KEYWORDS && key.type === "Identifier" && isKeyword(key.name)) {
                    context.report({
                        node,
                        messageId: "unquotedReservedProperty",
                        data: { property: key.name },
                        fix: fixer => fixer.replaceText(key, getQuotedKey(key))
                    });
                }
                else if (NUMBERS && key.type === "Literal" && astUtils.isNumericLiteral(key)) {
                    context.report({
                        node,
                        messageId: "unquotedNumericProperty",
                        data: { property: key.value },
                        fix: fixer => fixer.replaceText(key, getQuotedKey(key))
                    });
                }
            }
            /**
             * Ensures that a property's key is quoted
             * @param {ASTNode} node Property AST node
             * @returns {void}
             */
            function checkOmittedQuotes(node) {
                const key = node.key;
                if (!node.method && !node.computed && !node.shorthand && !(key.type === "Literal" && typeof key.value === "string")) {
                    context.report({
                        node,
                        messageId: "unquotedPropertyFound",
                        data: { property: key.name || key.value },
                        fix: fixer => fixer.replaceText(key, getQuotedKey(key))
                    });
                }
            }
            /**
             * Ensures that an object's keys are consistently quoted, optionally checks for redundancy of quotes
             * @param {ASTNode} node Property AST node
             * @param {boolean} checkQuotesRedundancy Whether to check quotes' redundancy
             * @returns {void}
             */
            function checkConsistency(node, checkQuotesRedundancy) {
                const quotedProps = [], unquotedProps = [];
                let keywordKeyName = null, necessaryQuotes = false;
                node.properties.forEach(property => {
                    const key = property.key;
                    if (!key || property.method || property.computed || property.shorthand) {
                        return;
                    }
                    if (key.type === "Literal" && typeof key.value === "string") {
                        quotedProps.push(property);
                        if (checkQuotesRedundancy) {
                            let tokens;
                            try {
                                tokens = espree.tokenize(key.value);
                            }
                            catch {
                                necessaryQuotes = true;
                                return;
                            }
                            necessaryQuotes = necessaryQuotes || !areQuotesRedundant(key.value, tokens) || KEYWORDS && isKeyword(tokens[0].value);
                        }
                    }
                    else if (KEYWORDS && checkQuotesRedundancy && key.type === "Identifier" && isKeyword(key.name)) {
                        unquotedProps.push(property);
                        necessaryQuotes = true;
                        keywordKeyName = key.name;
                    }
                    else {
                        unquotedProps.push(property);
                    }
                });
                if (checkQuotesRedundancy && quotedProps.length && !necessaryQuotes) {
                    quotedProps.forEach(property => {
                        context.report({
                            node: property,
                            messageId: "redundantQuoting",
                            fix: fixer => fixer.replaceText(property.key, getUnquotedKey(property.key))
                        });
                    });
                }
                else if (unquotedProps.length && keywordKeyName) {
                    unquotedProps.forEach(property => {
                        context.report({
                            node: property,
                            messageId: "requireQuotesDueToReservedWord",
                            data: { property: keywordKeyName },
                            fix: fixer => fixer.replaceText(property.key, getQuotedKey(property.key))
                        });
                    });
                }
                else if (quotedProps.length && unquotedProps.length) {
                    unquotedProps.forEach(property => {
                        context.report({
                            node: property,
                            messageId: "inconsistentlyQuotedProperty",
                            data: { key: property.key.name || property.key.value },
                            fix: fixer => fixer.replaceText(property.key, getQuotedKey(property.key))
                        });
                    });
                }
            }
            return {
                Property(node) {
                    if (MODE === "always" || !MODE) {
                        checkOmittedQuotes(node);
                    }
                    if (MODE === "as-needed") {
                        checkUnnecessaryQuotes(node);
                    }
                },
                ObjectExpression(node) {
                    if (MODE === "consistent") {
                        checkConsistency(node, false);
                    }
                    if (MODE === "consistent-as-needed") {
                        checkConsistency(node, true);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/quotes.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to choose between single and double quote marks
     * @author Matt DuVall <http://www.mattduvall.com/>, Brandon Payton
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Constants
    //------------------------------------------------------------------------------
    const QUOTE_SETTINGS = {
        double: {
            quote: "\"",
            alternateQuote: "'",
            description: "doublequote"
        },
        single: {
            quote: "'",
            alternateQuote: "\"",
            description: "singlequote"
        },
        backtick: {
            quote: "`",
            alternateQuote: "\"",
            description: "backtick"
        }
    };
    // An unescaped newline is a newline preceded by an even number of backslashes.
    const UNESCAPED_LINEBREAK_PATTERN = new RegExp(String.raw `(^|[^\\])(\\\\)*[${Array.from(astUtils.LINEBREAKS).join("")}]`, "u");
    /**
     * Switches quoting of javascript string between ' " and `
     * escaping and unescaping as necessary.
     * Only escaping of the minimal set of characters is changed.
     * Note: escaping of newlines when switching from backtick to other quotes is not handled.
     * @param {string} str A string to convert.
     * @returns {string} The string with changed quotes.
     * @private
     */
    QUOTE_SETTINGS.double.convert =
        QUOTE_SETTINGS.single.convert =
            QUOTE_SETTINGS.backtick.convert = function (str) {
                const newQuote = this.quote;
                const oldQuote = str[0];
                if (newQuote === oldQuote) {
                    return str;
                }
                return newQuote + str.slice(1, -1).replace(/\\(\$\{|\r\n?|\n|.)|["'`]|\$\{|(\r\n?|\n)/gu, (match, escaped, newline) => {
                    if (escaped === oldQuote || oldQuote === "`" && escaped === "${") {
                        return escaped; // unescape
                    }
                    if (match === newQuote || newQuote === "`" && match === "${") {
                        return `\\${match}`; // escape
                    }
                    if (newline && oldQuote === "`") {
                        return "\\n"; // escape newlines
                    }
                    return match;
                }) + newQuote;
            };
    const AVOID_ESCAPE = "avoid-escape";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce the consistent use of either backticks, double, or single quotes",
                recommended: false,
                url: "https://eslint.org/docs/rules/quotes"
            },
            fixable: "code",
            schema: [
                {
                    enum: ["single", "double", "backtick"]
                },
                {
                    anyOf: [
                        {
                            enum: ["avoid-escape"]
                        },
                        {
                            type: "object",
                            properties: {
                                avoidEscape: {
                                    type: "boolean"
                                },
                                allowTemplateLiterals: {
                                    type: "boolean"
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                wrongQuotes: "Strings must use {{description}}."
            }
        },
        create(context) {
            const quoteOption = context.options[0], settings = QUOTE_SETTINGS[quoteOption || "double"], options = context.options[1], allowTemplateLiterals = options && options.allowTemplateLiterals === true, sourceCode = context.getSourceCode();
            let avoidEscape = options && options.avoidEscape === true;
            // deprecated
            if (options === AVOID_ESCAPE) {
                avoidEscape = true;
            }
            /**
             * Determines if a given node is part of JSX syntax.
             *
             * This function returns `true` in the following cases:
             *
             * - `<div className="foo"></div>` ... If the literal is an attribute value, the parent of the literal is `JSXAttribute`.
             * - `<div>foo</div>` ... If the literal is a text content, the parent of the literal is `JSXElement`.
             * - `<>foo</>` ... If the literal is a text content, the parent of the literal is `JSXFragment`.
             *
             * In particular, this function returns `false` in the following cases:
             *
             * - `<div className={"foo"}></div>`
             * - `<div>{"foo"}</div>`
             *
             * In both cases, inside of the braces is handled as normal JavaScript.
             * The braces are `JSXExpressionContainer` nodes.
             * @param {ASTNode} node The Literal node to check.
             * @returns {boolean} True if the node is a part of JSX, false if not.
             * @private
             */
            function isJSXLiteral(node) {
                return node.parent.type === "JSXAttribute" || node.parent.type === "JSXElement" || node.parent.type === "JSXFragment";
            }
            /**
             * Checks whether or not a given node is a directive.
             * The directive is a `ExpressionStatement` which has only a string literal.
             * @param {ASTNode} node A node to check.
             * @returns {boolean} Whether or not the node is a directive.
             * @private
             */
            function isDirective(node) {
                return (node.type === "ExpressionStatement" &&
                    node.expression.type === "Literal" &&
                    typeof node.expression.value === "string");
            }
            /**
             * Checks whether or not a given node is a part of directive prologues.
             * See also: http://www.ecma-international.org/ecma-262/6.0/#sec-directive-prologues-and-the-use-strict-directive
             * @param {ASTNode} node A node to check.
             * @returns {boolean} Whether or not the node is a part of directive prologues.
             * @private
             */
            function isPartOfDirectivePrologue(node) {
                const block = node.parent.parent;
                if (block.type !== "Program" && (block.type !== "BlockStatement" || !astUtils.isFunction(block.parent))) {
                    return false;
                }
                // Check the node is at a prologue.
                for (let i = 0; i < block.body.length; ++i) {
                    const statement = block.body[i];
                    if (statement === node.parent) {
                        return true;
                    }
                    if (!isDirective(statement)) {
                        break;
                    }
                }
                return false;
            }
            /**
             * Checks whether or not a given node is allowed as non backtick.
             * @param {ASTNode} node A node to check.
             * @returns {boolean} Whether or not the node is allowed as non backtick.
             * @private
             */
            function isAllowedAsNonBacktick(node) {
                const parent = node.parent;
                switch (parent.type) {
                    // Directive Prologues.
                    case "ExpressionStatement":
                        return isPartOfDirectivePrologue(node);
                    // LiteralPropertyName.
                    case "Property":
                    case "PropertyDefinition":
                    case "MethodDefinition":
                        return parent.key === node && !parent.computed;
                    // ModuleSpecifier.
                    case "ImportDeclaration":
                    case "ExportNamedDeclaration":
                        return parent.source === node;
                    // ModuleExportName or ModuleSpecifier.
                    case "ExportAllDeclaration":
                        return parent.exported === node || parent.source === node;
                    // ModuleExportName.
                    case "ImportSpecifier":
                        return parent.imported === node;
                    // ModuleExportName.
                    case "ExportSpecifier":
                        return parent.local === node || parent.exported === node;
                    // Others don't allow.
                    default:
                        return false;
                }
            }
            /**
             * Checks whether or not a given TemplateLiteral node is actually using any of the special features provided by template literal strings.
             * @param {ASTNode} node A TemplateLiteral node to check.
             * @returns {boolean} Whether or not the TemplateLiteral node is using any of the special features provided by template literal strings.
             * @private
             */
            function isUsingFeatureOfTemplateLiteral(node) {
                const hasTag = node.parent.type === "TaggedTemplateExpression" && node === node.parent.quasi;
                if (hasTag) {
                    return true;
                }
                const hasStringInterpolation = node.expressions.length > 0;
                if (hasStringInterpolation) {
                    return true;
                }
                const isMultilineString = node.quasis.length >= 1 && UNESCAPED_LINEBREAK_PATTERN.test(node.quasis[0].value.raw);
                if (isMultilineString) {
                    return true;
                }
                return false;
            }
            return {
                Literal(node) {
                    const val = node.value, rawVal = node.raw;
                    if (settings && typeof val === "string") {
                        let isValid = (quoteOption === "backtick" && isAllowedAsNonBacktick(node)) ||
                            isJSXLiteral(node) ||
                            astUtils.isSurroundedBy(rawVal, settings.quote);
                        if (!isValid && avoidEscape) {
                            isValid = astUtils.isSurroundedBy(rawVal, settings.alternateQuote) && rawVal.includes(settings.quote);
                        }
                        if (!isValid) {
                            context.report({
                                node,
                                messageId: "wrongQuotes",
                                data: {
                                    description: settings.description
                                },
                                fix(fixer) {
                                    if (quoteOption === "backtick" && astUtils.hasOctalOrNonOctalDecimalEscapeSequence(rawVal)) {
                                        /*
                                         * An octal or non-octal decimal escape sequence in a template literal would
                                         * produce syntax error, even in non-strict mode.
                                         */
                                        return null;
                                    }
                                    return fixer.replaceText(node, settings.convert(node.raw));
                                }
                            });
                        }
                    }
                },
                TemplateLiteral(node) {
                    // Don't throw an error if backticks are expected or a template literal feature is in use.
                    if (allowTemplateLiterals ||
                        quoteOption === "backtick" ||
                        isUsingFeatureOfTemplateLiteral(node)) {
                        return;
                    }
                    context.report({
                        node,
                        messageId: "wrongQuotes",
                        data: {
                            description: settings.description
                        },
                        fix(fixer) {
                            if (isPartOfDirectivePrologue(node)) {
                                /*
                                 * TemplateLiterals in a directive prologue aren't actually directives, but if they're
                                 * in the directive prologue, then fixing them might turn them into directives and change
                                 * the behavior of the code.
                                 */
                                return null;
                            }
                            return fixer.replaceText(node, settings.convert(sourceCode.getText(node)));
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/radix.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag use of parseInt without a radix argument
     * @author James Allardice
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const MODE_ALWAYS = "always", MODE_AS_NEEDED = "as-needed";
    const validRadixValues = new Set(Array.from({ length: 37 - 2 }, (_, index) => index + 2));
    /**
     * Checks whether a given variable is shadowed or not.
     * @param {eslint-scope.Variable} variable A variable to check.
     * @returns {boolean} `true` if the variable is shadowed.
     */
    function isShadowed(variable) {
        return variable.defs.length >= 1;
    }
    /**
     * Checks whether a given node is a MemberExpression of `parseInt` method or not.
     * @param {ASTNode} node A node to check.
     * @returns {boolean} `true` if the node is a MemberExpression of `parseInt`
     *      method.
     */
    function isParseIntMethod(node) {
        return (node.type === "MemberExpression" &&
            !node.computed &&
            node.property.type === "Identifier" &&
            node.property.name === "parseInt");
    }
    /**
     * Checks whether a given node is a valid value of radix or not.
     *
     * The following values are invalid.
     *
     * - A literal except integers between 2 and 36.
     * - undefined.
     * @param {ASTNode} radix A node of radix to check.
     * @returns {boolean} `true` if the node is valid.
     */
    function isValidRadix(radix) {
        return !((radix.type === "Literal" && !validRadixValues.has(radix.value)) ||
            (radix.type === "Identifier" && radix.name === "undefined"));
    }
    /**
     * Checks whether a given node is a default value of radix or not.
     * @param {ASTNode} radix A node of radix to check.
     * @returns {boolean} `true` if the node is the literal node of `10`.
     */
    function isDefaultRadix(radix) {
        return radix.type === "Literal" && radix.value === 10;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce the consistent use of the radix argument when using `parseInt()`",
                recommended: false,
                url: "https://eslint.org/docs/rules/radix"
            },
            hasSuggestions: true,
            schema: [
                {
                    enum: ["always", "as-needed"]
                }
            ],
            messages: {
                missingParameters: "Missing parameters.",
                redundantRadix: "Redundant radix parameter.",
                missingRadix: "Missing radix parameter.",
                invalidRadix: "Invalid radix parameter, must be an integer between 2 and 36.",
                addRadixParameter10: "Add radix parameter `10` for parsing decimal numbers."
            }
        },
        create(context) {
            const mode = context.options[0] || MODE_ALWAYS;
            /**
             * Checks the arguments of a given CallExpression node and reports it if it
             * offends this rule.
             * @param {ASTNode} node A CallExpression node to check.
             * @returns {void}
             */
            function checkArguments(node) {
                const args = node.arguments;
                switch (args.length) {
                    case 0:
                        context.report({
                            node,
                            messageId: "missingParameters"
                        });
                        break;
                    case 1:
                        if (mode === MODE_ALWAYS) {
                            context.report({
                                node,
                                messageId: "missingRadix",
                                suggest: [
                                    {
                                        messageId: "addRadixParameter10",
                                        fix(fixer) {
                                            const sourceCode = context.getSourceCode();
                                            const tokens = sourceCode.getTokens(node);
                                            const lastToken = tokens[tokens.length - 1]; // Parenthesis.
                                            const secondToLastToken = tokens[tokens.length - 2]; // May or may not be a comma.
                                            const hasTrailingComma = secondToLastToken.type === "Punctuator" && secondToLastToken.value === ",";
                                            return fixer.insertTextBefore(lastToken, hasTrailingComma ? " 10," : ", 10");
                                        }
                                    }
                                ]
                            });
                        }
                        break;
                    default:
                        if (mode === MODE_AS_NEEDED && isDefaultRadix(args[1])) {
                            context.report({
                                node,
                                messageId: "redundantRadix"
                            });
                        }
                        else if (!isValidRadix(args[1])) {
                            context.report({
                                node,
                                messageId: "invalidRadix"
                            });
                        }
                        break;
                }
            }
            return {
                "Program:exit"() {
                    const scope = context.getScope();
                    let variable;
                    // Check `parseInt()`
                    variable = astUtils.getVariableByName(scope, "parseInt");
                    if (variable && !isShadowed(variable)) {
                        variable.references.forEach(reference => {
                            const node = reference.identifier;
                            if (astUtils.isCallee(node)) {
                                checkArguments(node.parent);
                            }
                        });
                    }
                    // Check `Number.parseInt()`
                    variable = astUtils.getVariableByName(scope, "Number");
                    if (variable && !isShadowed(variable)) {
                        variable.references.forEach(reference => {
                            const node = reference.identifier.parent;
                            const maybeCallee = node.parent.type === "ChainExpression"
                                ? node.parent
                                : node;
                            if (isParseIntMethod(node) && astUtils.isCallee(maybeCallee)) {
                                checkArguments(maybeCallee.parent);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/require-atomic-updates.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview disallow assignments that can lead to race conditions due to usage of `await` or `yield`
     * @author Teddy Katz
     * @author Toru Nagashima
     */
    "use strict";
    /**
     * Make the map from identifiers to each reference.
     * @param {escope.Scope} scope The scope to get references.
     * @param {Map<Identifier, escope.Reference>} [outReferenceMap] The map from identifier nodes to each reference object.
     * @returns {Map<Identifier, escope.Reference>} `referenceMap`.
     */
    function createReferenceMap(scope, outReferenceMap = new Map()) {
        for (const reference of scope.references) {
            if (reference.resolved === null) {
                continue;
            }
            outReferenceMap.set(reference.identifier, reference);
        }
        for (const childScope of scope.childScopes) {
            if (childScope.type !== "function") {
                createReferenceMap(childScope, outReferenceMap);
            }
        }
        return outReferenceMap;
    }
    /**
     * Get `reference.writeExpr` of a given reference.
     * If it's the read reference of MemberExpression in LHS, returns RHS in order to address `a.b = await a`
     * @param {escope.Reference} reference The reference to get.
     * @returns {Expression|null} The `reference.writeExpr`.
     */
    function getWriteExpr(reference) {
        if (reference.writeExpr) {
            return reference.writeExpr;
        }
        let node = reference.identifier;
        while (node) {
            const t = node.parent.type;
            if (t === "AssignmentExpression" && node.parent.left === node) {
                return node.parent.right;
            }
            if (t === "MemberExpression" && node.parent.object === node) {
                node = node.parent;
                continue;
            }
            break;
        }
        return null;
    }
    /**
     * Checks if an expression is a variable that can only be observed within the given function.
     * @param {Variable|null} variable The variable to check
     * @param {boolean} isMemberAccess If `true` then this is a member access.
     * @returns {boolean} `true` if the variable is local to the given function, and is never referenced in a closure.
     */
    function isLocalVariableWithoutEscape(variable, isMemberAccess) {
        if (!variable) {
            return false; // A global variable which was not defined.
        }
        // If the reference is a property access and the variable is a parameter, it handles the variable is not local.
        if (isMemberAccess && variable.defs.some(d => d.type === "Parameter")) {
            return false;
        }
        const functionScope = variable.scope.variableScope;
        return variable.references.every(reference => reference.from.variableScope === functionScope);
    }
    /**
     * Represents segment information.
     */
    class SegmentInfo {
        constructor() {
            this.info = new WeakMap();
        }
        /**
         * Initialize the segment information.
         * @param {PathSegment} segment The segment to initialize.
         * @returns {void}
         */
        initialize(segment) {
            const outdatedReadVariables = new Set();
            const freshReadVariables = new Set();
            for (const prevSegment of segment.prevSegments) {
                const info = this.info.get(prevSegment);
                if (info) {
                    info.outdatedReadVariables.forEach(Set.prototype.add, outdatedReadVariables);
                    info.freshReadVariables.forEach(Set.prototype.add, freshReadVariables);
                }
            }
            this.info.set(segment, { outdatedReadVariables, freshReadVariables });
        }
        /**
         * Mark a given variable as read on given segments.
         * @param {PathSegment[]} segments The segments that it read the variable on.
         * @param {Variable} variable The variable to be read.
         * @returns {void}
         */
        markAsRead(segments, variable) {
            for (const segment of segments) {
                const info = this.info.get(segment);
                if (info) {
                    info.freshReadVariables.add(variable);
                    // If a variable is freshly read again, then it's no more out-dated.
                    info.outdatedReadVariables.delete(variable);
                }
            }
        }
        /**
         * Move `freshReadVariables` to `outdatedReadVariables`.
         * @param {PathSegment[]} segments The segments to process.
         * @returns {void}
         */
        makeOutdated(segments) {
            for (const segment of segments) {
                const info = this.info.get(segment);
                if (info) {
                    info.freshReadVariables.forEach(Set.prototype.add, info.outdatedReadVariables);
                    info.freshReadVariables.clear();
                }
            }
        }
        /**
         * Check if a given variable is outdated on the current segments.
         * @param {PathSegment[]} segments The current segments.
         * @param {Variable} variable The variable to check.
         * @returns {boolean} `true` if the variable is outdated on the segments.
         */
        isOutdated(segments, variable) {
            for (const segment of segments) {
                const info = this.info.get(segment);
                if (info && info.outdatedReadVariables.has(variable)) {
                    return true;
                }
            }
            return false;
        }
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Disallow assignments that can lead to race conditions due to usage of `await` or `yield`",
                recommended: false,
                url: "https://eslint.org/docs/rules/require-atomic-updates"
            },
            fixable: null,
            schema: [{
                    type: "object",
                    properties: {
                        allowProperties: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }],
            messages: {
                nonAtomicUpdate: "Possible race condition: `{{value}}` might be reassigned based on an outdated value of `{{value}}`.",
                nonAtomicObjectUpdate: "Possible race condition: `{{value}}` might be assigned based on an outdated state of `{{object}}`."
            }
        },
        create(context) {
            const allowProperties = !!context.options[0] && context.options[0].allowProperties;
            const sourceCode = context.getSourceCode();
            const assignmentReferences = new Map();
            const segmentInfo = new SegmentInfo();
            let stack = null;
            return {
                onCodePathStart(codePath) {
                    const scope = context.getScope();
                    const shouldVerify = scope.type === "function" &&
                        (scope.block.async || scope.block.generator);
                    stack = {
                        upper: stack,
                        codePath,
                        referenceMap: shouldVerify ? createReferenceMap(scope) : null
                    };
                },
                onCodePathEnd() {
                    stack = stack.upper;
                },
                // Initialize the segment information.
                onCodePathSegmentStart(segment) {
                    segmentInfo.initialize(segment);
                },
                // Handle references to prepare verification.
                Identifier(node) {
                    const { codePath, referenceMap } = stack;
                    const reference = referenceMap && referenceMap.get(node);
                    // Ignore if this is not a valid variable reference.
                    if (!reference) {
                        return;
                    }
                    const variable = reference.resolved;
                    const writeExpr = getWriteExpr(reference);
                    const isMemberAccess = reference.identifier.parent.type === "MemberExpression";
                    // Add a fresh read variable.
                    if (reference.isRead() && !(writeExpr && writeExpr.parent.operator === "=")) {
                        segmentInfo.markAsRead(codePath.currentSegments, variable);
                    }
                    /*
                     * Register the variable to verify after ESLint traversed the `writeExpr` node
                     * if this reference is an assignment to a variable which is referred from other closure.
                     */
                    if (writeExpr &&
                        writeExpr.parent.right === writeExpr && // ← exclude variable declarations.
                        !isLocalVariableWithoutEscape(variable, isMemberAccess)) {
                        let refs = assignmentReferences.get(writeExpr);
                        if (!refs) {
                            refs = [];
                            assignmentReferences.set(writeExpr, refs);
                        }
                        refs.push(reference);
                    }
                },
                /*
                 * Verify assignments.
                 * If the reference exists in `outdatedReadVariables` list, report it.
                 */
                ":expression:exit"(node) {
                    const { codePath, referenceMap } = stack;
                    // referenceMap exists if this is in a resumable function scope.
                    if (!referenceMap) {
                        return;
                    }
                    // Mark the read variables on this code path as outdated.
                    if (node.type === "AwaitExpression" || node.type === "YieldExpression") {
                        segmentInfo.makeOutdated(codePath.currentSegments);
                    }
                    // Verify.
                    const references = assignmentReferences.get(node);
                    if (references) {
                        assignmentReferences.delete(node);
                        for (const reference of references) {
                            const variable = reference.resolved;
                            if (segmentInfo.isOutdated(codePath.currentSegments, variable)) {
                                if (node.parent.left === reference.identifier) {
                                    context.report({
                                        node: node.parent,
                                        messageId: "nonAtomicUpdate",
                                        data: {
                                            value: variable.name
                                        }
                                    });
                                }
                                else if (!allowProperties) {
                                    context.report({
                                        node: node.parent,
                                        messageId: "nonAtomicObjectUpdate",
                                        data: {
                                            value: sourceCode.getText(node.parent.left),
                                            object: variable.name
                                        }
                                    });
                                }
                            }
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/require-await.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to disallow async functions which have no `await` expression.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Capitalize the 1st letter of the given text.
     * @param {string} text The text to capitalize.
     * @returns {string} The text that the 1st letter was capitalized.
     */
    function capitalizeFirstLetter(text) {
        return text[0].toUpperCase() + text.slice(1);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Disallow async functions which have no `await` expression",
                recommended: false,
                url: "https://eslint.org/docs/rules/require-await"
            },
            schema: [],
            messages: {
                missingAwait: "{{name}} has no 'await' expression."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            let scopeInfo = null;
            /**
             * Push the scope info object to the stack.
             * @returns {void}
             */
            function enterFunction() {
                scopeInfo = {
                    upper: scopeInfo,
                    hasAwait: false
                };
            }
            /**
             * Pop the top scope info object from the stack.
             * Also, it reports the function if needed.
             * @param {ASTNode} node The node to report.
             * @returns {void}
             */
            function exitFunction(node) {
                if (!node.generator && node.async && !scopeInfo.hasAwait && !astUtils.isEmptyFunction(node)) {
                    context.report({
                        node,
                        loc: astUtils.getFunctionHeadLoc(node, sourceCode),
                        messageId: "missingAwait",
                        data: {
                            name: capitalizeFirstLetter(astUtils.getFunctionNameWithKind(node))
                        }
                    });
                }
                scopeInfo = scopeInfo.upper;
            }
            return {
                FunctionDeclaration: enterFunction,
                FunctionExpression: enterFunction,
                ArrowFunctionExpression: enterFunction,
                "FunctionDeclaration:exit": exitFunction,
                "FunctionExpression:exit": exitFunction,
                "ArrowFunctionExpression:exit": exitFunction,
                AwaitExpression() {
                    if (!scopeInfo) {
                        return;
                    }
                    scopeInfo.hasAwait = true;
                },
                ForOfStatement(node) {
                    if (!scopeInfo) {
                        return;
                    }
                    if (node.await) {
                        scopeInfo.hasAwait = true;
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/require-jsdoc.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to check for jsdoc presence.
     * @author Gyandeep Singh
     * @deprecated in ESLint v5.10.0
     */
    "use strict";
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require JSDoc comments",
                recommended: false,
                url: "https://eslint.org/docs/rules/require-jsdoc"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        require: {
                            type: "object",
                            properties: {
                                ClassDeclaration: {
                                    type: "boolean",
                                    default: false
                                },
                                MethodDefinition: {
                                    type: "boolean",
                                    default: false
                                },
                                FunctionDeclaration: {
                                    type: "boolean",
                                    default: true
                                },
                                ArrowFunctionExpression: {
                                    type: "boolean",
                                    default: false
                                },
                                FunctionExpression: {
                                    type: "boolean",
                                    default: false
                                }
                            },
                            additionalProperties: false,
                            default: {}
                        }
                    },
                    additionalProperties: false
                }
            ],
            deprecated: true,
            replacedBy: [],
            messages: {
                missingJSDocComment: "Missing JSDoc comment."
            }
        },
        create(context) {
            const source = context.getSourceCode();
            const DEFAULT_OPTIONS = {
                FunctionDeclaration: true,
                MethodDefinition: false,
                ClassDeclaration: false,
                ArrowFunctionExpression: false,
                FunctionExpression: false
            };
            const options = Object.assign(DEFAULT_OPTIONS, context.options[0] && context.options[0].require);
            /**
             * Report the error message
             * @param {ASTNode} node node to report
             * @returns {void}
             */
            function report(node) {
                context.report({ node, messageId: "missingJSDocComment" });
            }
            /**
             * Check if the jsdoc comment is present or not.
             * @param {ASTNode} node node to examine
             * @returns {void}
             */
            function checkJsDoc(node) {
                const jsdocComment = source.getJSDocComment(node);
                if (!jsdocComment) {
                    report(node);
                }
            }
            return {
                FunctionDeclaration(node) {
                    if (options.FunctionDeclaration) {
                        checkJsDoc(node);
                    }
                },
                FunctionExpression(node) {
                    if ((options.MethodDefinition && node.parent.type === "MethodDefinition") ||
                        (options.FunctionExpression && (node.parent.type === "VariableDeclarator" || (node.parent.type === "Property" && node === node.parent.value)))) {
                        checkJsDoc(node);
                    }
                },
                ClassDeclaration(node) {
                    if (options.ClassDeclaration) {
                        checkJsDoc(node);
                    }
                },
                ArrowFunctionExpression(node) {
                    if (options.ArrowFunctionExpression && node.parent.type === "VariableDeclarator") {
                        checkJsDoc(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/require-unicode-regexp.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce the use of `u` flag on RegExp.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const { CALL, CONSTRUCT, ReferenceTracker, getStringIfConstant } = require(316) /* @eslint-community/eslint-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce the use of `u` flag on RegExp",
                recommended: false,
                url: "https://eslint.org/docs/rules/require-unicode-regexp"
            },
            messages: {
                requireUFlag: "Use the 'u' flag."
            },
            schema: []
        },
        create(context) {
            return {
                "Literal[regex]"(node) {
                    const flags = node.regex.flags || "";
                    if (!flags.includes("u")) {
                        context.report({ node, messageId: "requireUFlag" });
                    }
                },
                Program() {
                    const scope = context.getScope();
                    const tracker = new ReferenceTracker(scope);
                    const trackMap = {
                        RegExp: { [CALL]: true, [CONSTRUCT]: true }
                    };
                    for (const { node } of tracker.iterateGlobalReferences(trackMap)) {
                        const flagsNode = node.arguments[1];
                        const flags = getStringIfConstant(flagsNode, scope);
                        if (!flagsNode || (typeof flags === "string" && !flags.includes("u"))) {
                            context.report({ node, messageId: "requireUFlag" });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/require-yield.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag the generator functions that does not have yield.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require generator functions to contain `yield`",
                recommended: true,
                url: "https://eslint.org/docs/rules/require-yield"
            },
            schema: [],
            messages: {
                missingYield: "This generator function does not have 'yield'."
            }
        },
        create(context) {
            const stack = [];
            /**
             * If the node is a generator function, start counting `yield` keywords.
             * @param {Node} node A function node to check.
             * @returns {void}
             */
            function beginChecking(node) {
                if (node.generator) {
                    stack.push(0);
                }
            }
            /**
             * If the node is a generator function, end counting `yield` keywords, then
             * reports result.
             * @param {Node} node A function node to check.
             * @returns {void}
             */
            function endChecking(node) {
                if (!node.generator) {
                    return;
                }
                const countYield = stack.pop();
                if (countYield === 0 && node.body.body.length > 0) {
                    context.report({ node, messageId: "missingYield" });
                }
            }
            return {
                FunctionDeclaration: beginChecking,
                "FunctionDeclaration:exit": endChecking,
                FunctionExpression: beginChecking,
                "FunctionExpression:exit": endChecking,
                // Increases the count of `yield` keyword.
                YieldExpression() {
                    if (stack.length > 0) {
                        stack[stack.length - 1] += 1;
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/rest-spread-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Enforce spacing between rest and spread operators and their expressions.
     * @author Kai Cataldo
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce spacing between rest and spread operators and their expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/rest-spread-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never"]
                }
            ],
            messages: {
                unexpectedWhitespace: "Unexpected whitespace after {{type}} operator.",
                expectedWhitespace: "Expected whitespace after {{type}} operator."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode(), alwaysSpace = context.options[0] === "always";
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Checks whitespace between rest/spread operators and their expressions
             * @param {ASTNode} node The node to check
             * @returns {void}
             */
            function checkWhiteSpace(node) {
                const operator = sourceCode.getFirstToken(node), nextToken = sourceCode.getTokenAfter(operator), hasWhitespace = sourceCode.isSpaceBetweenTokens(operator, nextToken);
                let type;
                switch (node.type) {
                    case "SpreadElement":
                        type = "spread";
                        if (node.parent.type === "ObjectExpression") {
                            type += " property";
                        }
                        break;
                    case "RestElement":
                        type = "rest";
                        if (node.parent.type === "ObjectPattern") {
                            type += " property";
                        }
                        break;
                    case "ExperimentalSpreadProperty":
                        type = "spread property";
                        break;
                    case "ExperimentalRestProperty":
                        type = "rest property";
                        break;
                    default:
                        return;
                }
                if (alwaysSpace && !hasWhitespace) {
                    context.report({
                        node,
                        loc: operator.loc,
                        messageId: "expectedWhitespace",
                        data: {
                            type
                        },
                        fix(fixer) {
                            return fixer.replaceTextRange([operator.range[1], nextToken.range[0]], " ");
                        }
                    });
                }
                else if (!alwaysSpace && hasWhitespace) {
                    context.report({
                        node,
                        loc: {
                            start: operator.loc.end,
                            end: nextToken.loc.start
                        },
                        messageId: "unexpectedWhitespace",
                        data: {
                            type
                        },
                        fix(fixer) {
                            return fixer.removeRange([operator.range[1], nextToken.range[0]]);
                        }
                    });
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                SpreadElement: checkWhiteSpace,
                RestElement: checkWhiteSpace,
                ExperimentalSpreadProperty: checkWhiteSpace,
                ExperimentalRestProperty: checkWhiteSpace
            };
        }
    };
},
/* eslint/lib/rules/semi.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to flag missing semicolons.
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const FixTracker = require(496) /* ./utils/fix-tracker */;
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow semicolons instead of ASI",
                recommended: false,
                url: "https://eslint.org/docs/rules/semi"
            },
            fixable: "code",
            schema: {
                anyOf: [
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["never"]
                            },
                            {
                                type: "object",
                                properties: {
                                    beforeStatementContinuationChars: {
                                        enum: ["always", "any", "never"]
                                    }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    },
                    {
                        type: "array",
                        items: [
                            {
                                enum: ["always"]
                            },
                            {
                                type: "object",
                                properties: {
                                    omitLastInOneLineBlock: { type: "boolean" }
                                },
                                additionalProperties: false
                            }
                        ],
                        minItems: 0,
                        maxItems: 2
                    }
                ]
            },
            messages: {
                missingSemi: "Missing semicolon.",
                extraSemi: "Extra semicolon."
            }
        },
        create(context) {
            const OPT_OUT_PATTERN = /^[-[(/+`]/u; // One of [(/+-`
            const unsafeClassFieldNames = new Set(["get", "set", "static"]);
            const unsafeClassFieldFollowers = new Set(["*", "in", "instanceof"]);
            const options = context.options[1];
            const never = context.options[0] === "never";
            const exceptOneLine = Boolean(options && options.omitLastInOneLineBlock);
            const beforeStatementContinuationChars = options && options.beforeStatementContinuationChars || "any";
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Reports a semicolon error with appropriate location and message.
             * @param {ASTNode} node The node with an extra or missing semicolon.
             * @param {boolean} missing True if the semicolon is missing.
             * @returns {void}
             */
            function report(node, missing) {
                const lastToken = sourceCode.getLastToken(node);
                let messageId, fix, loc;
                if (!missing) {
                    messageId = "missingSemi";
                    loc = {
                        start: lastToken.loc.end,
                        end: astUtils.getNextLocation(sourceCode, lastToken.loc.end)
                    };
                    fix = function (fixer) {
                        return fixer.insertTextAfter(lastToken, ";");
                    };
                }
                else {
                    messageId = "extraSemi";
                    loc = lastToken.loc;
                    fix = function (fixer) {
                        /*
                         * Expand the replacement range to include the surrounding
                         * tokens to avoid conflicting with no-extra-semi.
                         * https://github.com/eslint/eslint/issues/7928
                         */
                        return new FixTracker(fixer, sourceCode)
                            .retainSurroundingTokens(lastToken)
                            .remove(lastToken);
                    };
                }
                context.report({
                    node,
                    loc,
                    messageId,
                    fix
                });
            }
            /**
             * Check whether a given semicolon token is redundant.
             * @param {Token} semiToken A semicolon token to check.
             * @returns {boolean} `true` if the next token is `;` or `}`.
             */
            function isRedundantSemi(semiToken) {
                const nextToken = sourceCode.getTokenAfter(semiToken);
                return (!nextToken ||
                    astUtils.isClosingBraceToken(nextToken) ||
                    astUtils.isSemicolonToken(nextToken));
            }
            /**
             * Check whether a given token is the closing brace of an arrow function.
             * @param {Token} lastToken A token to check.
             * @returns {boolean} `true` if the token is the closing brace of an arrow function.
             */
            function isEndOfArrowBlock(lastToken) {
                if (!astUtils.isClosingBraceToken(lastToken)) {
                    return false;
                }
                const node = sourceCode.getNodeByRangeIndex(lastToken.range[0]);
                return (node.type === "BlockStatement" &&
                    node.parent.type === "ArrowFunctionExpression");
            }
            /**
             * Checks if a given PropertyDefinition node followed by a semicolon
             * can safely remove that semicolon. It is not to safe to remove if
             * the class field name is "get", "set", or "static", or if
             * followed by a generator method.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} `true` if the node cannot have the semicolon
             *      removed.
             */
            function maybeClassFieldAsiHazard(node) {
                if (node.type !== "PropertyDefinition") {
                    return false;
                }
                /*
                 * Computed property names and non-identifiers are always safe
                 * as they can be distinguished from keywords easily.
                 */
                const needsNameCheck = !node.computed && node.key.type === "Identifier";
                /*
                 * Certain names are problematic unless they also have a
                 * a way to distinguish between keywords and property
                 * names.
                 */
                if (needsNameCheck && unsafeClassFieldNames.has(node.key.name)) {
                    /*
                     * Special case: If the field name is `static`,
                     * it is only valid if the field is marked as static,
                     * so "static static" is okay but "static" is not.
                     */
                    const isStaticStatic = node.static && node.key.name === "static";
                    /*
                     * For other unsafe names, we only care if there is no
                     * initializer. No initializer = hazard.
                     */
                    if (!isStaticStatic && !node.value) {
                        return true;
                    }
                }
                const followingToken = sourceCode.getTokenAfter(node);
                return unsafeClassFieldFollowers.has(followingToken.value);
            }
            /**
             * Check whether a given node is on the same line with the next token.
             * @param {Node} node A statement node to check.
             * @returns {boolean} `true` if the node is on the same line with the next token.
             */
            function isOnSameLineWithNextToken(node) {
                const prevToken = sourceCode.getLastToken(node, 1);
                const nextToken = sourceCode.getTokenAfter(node);
                return !!nextToken && astUtils.isTokenOnSameLine(prevToken, nextToken);
            }
            /**
             * Check whether a given node can connect the next line if the next line is unreliable.
             * @param {Node} node A statement node to check.
             * @returns {boolean} `true` if the node can connect the next line.
             */
            function maybeAsiHazardAfter(node) {
                const t = node.type;
                if (t === "DoWhileStatement" ||
                    t === "BreakStatement" ||
                    t === "ContinueStatement" ||
                    t === "DebuggerStatement" ||
                    t === "ImportDeclaration" ||
                    t === "ExportAllDeclaration") {
                    return false;
                }
                if (t === "ReturnStatement") {
                    return Boolean(node.argument);
                }
                if (t === "ExportNamedDeclaration") {
                    return Boolean(node.declaration);
                }
                if (isEndOfArrowBlock(sourceCode.getLastToken(node, 1))) {
                    return false;
                }
                return true;
            }
            /**
             * Check whether a given token can connect the previous statement.
             * @param {Token} token A token to check.
             * @returns {boolean} `true` if the token is one of `[`, `(`, `/`, `+`, `-`, ```, `++`, and `--`.
             */
            function maybeAsiHazardBefore(token) {
                return (Boolean(token) &&
                    OPT_OUT_PATTERN.test(token.value) &&
                    token.value !== "++" &&
                    token.value !== "--");
            }
            /**
             * Check if the semicolon of a given node is unnecessary, only true if:
             *   - next token is a valid statement divider (`;` or `}`).
             *   - next token is on a new line and the node is not connectable to the new line.
             * @param {Node} node A statement node to check.
             * @returns {boolean} whether the semicolon is unnecessary.
             */
            function canRemoveSemicolon(node) {
                if (isRedundantSemi(sourceCode.getLastToken(node))) {
                    return true; // `;;` or `;}`
                }
                if (maybeClassFieldAsiHazard(node)) {
                    return false;
                }
                if (isOnSameLineWithNextToken(node)) {
                    return false; // One liner.
                }
                // continuation characters should not apply to class fields
                if (node.type !== "PropertyDefinition" &&
                    beforeStatementContinuationChars === "never" &&
                    !maybeAsiHazardAfter(node)) {
                    return true; // ASI works. This statement doesn't connect to the next.
                }
                if (!maybeAsiHazardBefore(sourceCode.getTokenAfter(node))) {
                    return true; // ASI works. The next token doesn't connect to this statement.
                }
                return false;
            }
            /**
             * Checks a node to see if it's the last item in a one-liner block.
             * Block is any `BlockStatement` or `StaticBlock` node. Block is a one-liner if its
             * braces (and consequently everything between them) are on the same line.
             * @param {ASTNode} node The node to check.
             * @returns {boolean} whether the node is the last item in a one-liner block.
             */
            function isLastInOneLinerBlock(node) {
                const parent = node.parent;
                const nextToken = sourceCode.getTokenAfter(node);
                if (!nextToken || nextToken.value !== "}") {
                    return false;
                }
                if (parent.type === "BlockStatement") {
                    return parent.loc.start.line === parent.loc.end.line;
                }
                if (parent.type === "StaticBlock") {
                    const openingBrace = sourceCode.getFirstToken(parent, { skip: 1 }); // skip the `static` token
                    return openingBrace.loc.start.line === parent.loc.end.line;
                }
                return false;
            }
            /**
             * Checks a node to see if it's followed by a semicolon.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             */
            function checkForSemicolon(node) {
                const isSemi = astUtils.isSemicolonToken(sourceCode.getLastToken(node));
                if (never) {
                    if (isSemi && canRemoveSemicolon(node)) {
                        report(node, true);
                    }
                    else if (!isSemi && beforeStatementContinuationChars === "always" &&
                        node.type !== "PropertyDefinition" &&
                        maybeAsiHazardBefore(sourceCode.getTokenAfter(node))) {
                        report(node);
                    }
                }
                else {
                    const oneLinerBlock = (exceptOneLine && isLastInOneLinerBlock(node));
                    if (isSemi && oneLinerBlock) {
                        report(node, true);
                    }
                    else if (!isSemi && !oneLinerBlock) {
                        report(node);
                    }
                }
            }
            /**
             * Checks to see if there's a semicolon after a variable declaration.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             */
            function checkForSemicolonForVariableDeclaration(node) {
                const parent = node.parent;
                if ((parent.type !== "ForStatement" || parent.init !== node) &&
                    (!/^For(?:In|Of)Statement/u.test(parent.type) || parent.left !== node)) {
                    checkForSemicolon(node);
                }
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                VariableDeclaration: checkForSemicolonForVariableDeclaration,
                ExpressionStatement: checkForSemicolon,
                ReturnStatement: checkForSemicolon,
                ThrowStatement: checkForSemicolon,
                DoWhileStatement: checkForSemicolon,
                DebuggerStatement: checkForSemicolon,
                BreakStatement: checkForSemicolon,
                ContinueStatement: checkForSemicolon,
                ImportDeclaration: checkForSemicolon,
                ExportAllDeclaration: checkForSemicolon,
                ExportNamedDeclaration(node) {
                    if (!node.declaration) {
                        checkForSemicolon(node);
                    }
                },
                ExportDefaultDeclaration(node) {
                    if (!/(?:Class|Function)Declaration/u.test(node.declaration.type)) {
                        checkForSemicolon(node);
                    }
                },
                PropertyDefinition: checkForSemicolon
            };
        }
    };
},
/* eslint/lib/rules/semi-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Validates spacing before and after semicolon
     * @author Mathias Schreck
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing before and after semicolons",
                recommended: false,
                url: "https://eslint.org/docs/rules/semi-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        before: {
                            type: "boolean",
                            default: false
                        },
                        after: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedWhitespaceBefore: "Unexpected whitespace before semicolon.",
                unexpectedWhitespaceAfter: "Unexpected whitespace after semicolon.",
                missingWhitespaceBefore: "Missing whitespace before semicolon.",
                missingWhitespaceAfter: "Missing whitespace after semicolon."
            }
        },
        create(context) {
            const config = context.options[0], sourceCode = context.getSourceCode();
            let requireSpaceBefore = false, requireSpaceAfter = true;
            if (typeof config === "object") {
                requireSpaceBefore = config.before;
                requireSpaceAfter = config.after;
            }
            /**
             * Checks if a given token has leading whitespace.
             * @param {Object} token The token to check.
             * @returns {boolean} True if the given token has leading space, false if not.
             */
            function hasLeadingSpace(token) {
                const tokenBefore = sourceCode.getTokenBefore(token);
                return tokenBefore && astUtils.isTokenOnSameLine(tokenBefore, token) && sourceCode.isSpaceBetweenTokens(tokenBefore, token);
            }
            /**
             * Checks if a given token has trailing whitespace.
             * @param {Object} token The token to check.
             * @returns {boolean} True if the given token has trailing space, false if not.
             */
            function hasTrailingSpace(token) {
                const tokenAfter = sourceCode.getTokenAfter(token);
                return tokenAfter && astUtils.isTokenOnSameLine(token, tokenAfter) && sourceCode.isSpaceBetweenTokens(token, tokenAfter);
            }
            /**
             * Checks if the given token is the last token in its line.
             * @param {Token} token The token to check.
             * @returns {boolean} Whether or not the token is the last in its line.
             */
            function isLastTokenInCurrentLine(token) {
                const tokenAfter = sourceCode.getTokenAfter(token);
                return !(tokenAfter && astUtils.isTokenOnSameLine(token, tokenAfter));
            }
            /**
             * Checks if the given token is the first token in its line
             * @param {Token} token The token to check.
             * @returns {boolean} Whether or not the token is the first in its line.
             */
            function isFirstTokenInCurrentLine(token) {
                const tokenBefore = sourceCode.getTokenBefore(token);
                return !(tokenBefore && astUtils.isTokenOnSameLine(token, tokenBefore));
            }
            /**
             * Checks if the next token of a given token is a closing parenthesis.
             * @param {Token} token The token to check.
             * @returns {boolean} Whether or not the next token of a given token is a closing parenthesis.
             */
            function isBeforeClosingParen(token) {
                const nextToken = sourceCode.getTokenAfter(token);
                return (nextToken && astUtils.isClosingBraceToken(nextToken) || astUtils.isClosingParenToken(nextToken));
            }
            /**
             * Report location example :
             *
             * for unexpected space `before`
             *
             * var a = 'b'   ;
             *            ^^^
             *
             * for unexpected space `after`
             *
             * var a = 'b';  c = 10;
             *             ^^
             *
             * Reports if the given token has invalid spacing.
             * @param {Token} token The semicolon token to check.
             * @param {ASTNode} node The corresponding node of the token.
             * @returns {void}
             */
            function checkSemicolonSpacing(token, node) {
                if (astUtils.isSemicolonToken(token)) {
                    if (hasLeadingSpace(token)) {
                        if (!requireSpaceBefore) {
                            const tokenBefore = sourceCode.getTokenBefore(token);
                            const loc = {
                                start: tokenBefore.loc.end,
                                end: token.loc.start
                            };
                            context.report({
                                node,
                                loc,
                                messageId: "unexpectedWhitespaceBefore",
                                fix(fixer) {
                                    return fixer.removeRange([tokenBefore.range[1], token.range[0]]);
                                }
                            });
                        }
                    }
                    else {
                        if (requireSpaceBefore) {
                            const loc = token.loc;
                            context.report({
                                node,
                                loc,
                                messageId: "missingWhitespaceBefore",
                                fix(fixer) {
                                    return fixer.insertTextBefore(token, " ");
                                }
                            });
                        }
                    }
                    if (!isFirstTokenInCurrentLine(token) && !isLastTokenInCurrentLine(token) && !isBeforeClosingParen(token)) {
                        if (hasTrailingSpace(token)) {
                            if (!requireSpaceAfter) {
                                const tokenAfter = sourceCode.getTokenAfter(token);
                                const loc = {
                                    start: token.loc.end,
                                    end: tokenAfter.loc.start
                                };
                                context.report({
                                    node,
                                    loc,
                                    messageId: "unexpectedWhitespaceAfter",
                                    fix(fixer) {
                                        return fixer.removeRange([token.range[1], tokenAfter.range[0]]);
                                    }
                                });
                            }
                        }
                        else {
                            if (requireSpaceAfter) {
                                const loc = token.loc;
                                context.report({
                                    node,
                                    loc,
                                    messageId: "missingWhitespaceAfter",
                                    fix(fixer) {
                                        return fixer.insertTextAfter(token, " ");
                                    }
                                });
                            }
                        }
                    }
                }
            }
            /**
             * Checks the spacing of the semicolon with the assumption that the last token is the semicolon.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             */
            function checkNode(node) {
                const token = sourceCode.getLastToken(node);
                checkSemicolonSpacing(token, node);
            }
            return {
                VariableDeclaration: checkNode,
                ExpressionStatement: checkNode,
                BreakStatement: checkNode,
                ContinueStatement: checkNode,
                DebuggerStatement: checkNode,
                DoWhileStatement: checkNode,
                ReturnStatement: checkNode,
                ThrowStatement: checkNode,
                ImportDeclaration: checkNode,
                ExportNamedDeclaration: checkNode,
                ExportAllDeclaration: checkNode,
                ExportDefaultDeclaration: checkNode,
                ForStatement(node) {
                    if (node.init) {
                        checkSemicolonSpacing(sourceCode.getTokenAfter(node.init), node);
                    }
                    if (node.test) {
                        checkSemicolonSpacing(sourceCode.getTokenAfter(node.test), node);
                    }
                },
                PropertyDefinition: checkNode
            };
        }
    };
},
/* eslint/lib/rules/semi-style.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce location of semicolons.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    const SELECTOR = [
        "BreakStatement", "ContinueStatement", "DebuggerStatement",
        "DoWhileStatement", "ExportAllDeclaration",
        "ExportDefaultDeclaration", "ExportNamedDeclaration",
        "ExpressionStatement", "ImportDeclaration", "ReturnStatement",
        "ThrowStatement", "VariableDeclaration", "PropertyDefinition"
    ].join(",");
    /**
     * Get the child node list of a given node.
     * This returns `BlockStatement#body`, `StaticBlock#body`, `Program#body`,
     * `ClassBody#body`, or `SwitchCase#consequent`.
     * This is used to check whether a node is the first/last child.
     * @param {Node} node A node to get child node list.
     * @returns {Node[]|null} The child node list.
     */
    function getChildren(node) {
        const t = node.type;
        if (t === "BlockStatement" ||
            t === "StaticBlock" ||
            t === "Program" ||
            t === "ClassBody") {
            return node.body;
        }
        if (t === "SwitchCase") {
            return node.consequent;
        }
        return null;
    }
    /**
     * Check whether a given node is the last statement in the parent block.
     * @param {Node} node A node to check.
     * @returns {boolean} `true` if the node is the last statement in the parent block.
     */
    function isLastChild(node) {
        const t = node.parent.type;
        if (t === "IfStatement" && node.parent.consequent === node && node.parent.alternate) { // before `else` keyword.
            return true;
        }
        if (t === "DoWhileStatement") { // before `while` keyword.
            return true;
        }
        const nodeList = getChildren(node.parent);
        return nodeList !== null && nodeList[nodeList.length - 1] === node; // before `}` or etc.
    }
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce location of semicolons",
                recommended: false,
                url: "https://eslint.org/docs/rules/semi-style"
            },
            schema: [{ enum: ["last", "first"] }],
            fixable: "whitespace",
            messages: {
                expectedSemiColon: "Expected this semicolon to be at {{pos}}."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const option = context.options[0] || "last";
            /**
             * Check the given semicolon token.
             * @param {Token} semiToken The semicolon token to check.
             * @param {"first"|"last"} expected The expected location to check.
             * @returns {void}
             */
            function check(semiToken, expected) {
                const prevToken = sourceCode.getTokenBefore(semiToken);
                const nextToken = sourceCode.getTokenAfter(semiToken);
                const prevIsSameLine = !prevToken || astUtils.isTokenOnSameLine(prevToken, semiToken);
                const nextIsSameLine = !nextToken || astUtils.isTokenOnSameLine(semiToken, nextToken);
                if ((expected === "last" && !prevIsSameLine) || (expected === "first" && !nextIsSameLine)) {
                    context.report({
                        loc: semiToken.loc,
                        messageId: "expectedSemiColon",
                        data: {
                            pos: (expected === "last")
                                ? "the end of the previous line"
                                : "the beginning of the next line"
                        },
                        fix(fixer) {
                            if (prevToken && nextToken && sourceCode.commentsExistBetween(prevToken, nextToken)) {
                                return null;
                            }
                            const start = prevToken ? prevToken.range[1] : semiToken.range[0];
                            const end = nextToken ? nextToken.range[0] : semiToken.range[1];
                            const text = (expected === "last") ? ";\n" : "\n;";
                            return fixer.replaceTextRange([start, end], text);
                        }
                    });
                }
            }
            return {
                [SELECTOR](node) {
                    if (option === "first" && isLastChild(node)) {
                        return;
                    }
                    const lastToken = sourceCode.getLastToken(node);
                    if (astUtils.isSemicolonToken(lastToken)) {
                        check(lastToken, option);
                    }
                },
                ForStatement(node) {
                    const firstSemi = node.init && sourceCode.getTokenAfter(node.init, astUtils.isSemicolonToken);
                    const secondSemi = node.test && sourceCode.getTokenAfter(node.test, astUtils.isSemicolonToken);
                    if (firstSemi) {
                        check(firstSemi, "last");
                    }
                    if (secondSemi) {
                        check(secondSemi, "last");
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/sort-imports.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to require sorting of import declarations
     * @author Christian Schuller
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce sorted import declarations within modules",
                recommended: false,
                url: "https://eslint.org/docs/rules/sort-imports"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        ignoreCase: {
                            type: "boolean",
                            default: false
                        },
                        memberSyntaxSortOrder: {
                            type: "array",
                            items: {
                                enum: ["none", "all", "multiple", "single"]
                            },
                            uniqueItems: true,
                            minItems: 4,
                            maxItems: 4
                        },
                        ignoreDeclarationSort: {
                            type: "boolean",
                            default: false
                        },
                        ignoreMemberSort: {
                            type: "boolean",
                            default: false
                        },
                        allowSeparatedGroups: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "code",
            messages: {
                sortImportsAlphabetically: "Imports should be sorted alphabetically.",
                sortMembersAlphabetically: "Member '{{memberName}}' of the import declaration should be sorted alphabetically.",
                unexpectedSyntaxOrder: "Expected '{{syntaxA}}' syntax before '{{syntaxB}}' syntax."
            }
        },
        create(context) {
            const configuration = context.options[0] || {}, ignoreCase = configuration.ignoreCase || false, ignoreDeclarationSort = configuration.ignoreDeclarationSort || false, ignoreMemberSort = configuration.ignoreMemberSort || false, memberSyntaxSortOrder = configuration.memberSyntaxSortOrder || ["none", "all", "multiple", "single"], allowSeparatedGroups = configuration.allowSeparatedGroups || false, sourceCode = context.getSourceCode();
            let previousDeclaration = null;
            /**
             * Gets the used member syntax style.
             *
             * import "my-module.js" --> none
             * import * as myModule from "my-module.js" --> all
             * import {myMember} from "my-module.js" --> single
             * import {foo, bar} from  "my-module.js" --> multiple
             * @param {ASTNode} node the ImportDeclaration node.
             * @returns {string} used member parameter style, ["all", "multiple", "single"]
             */
            function usedMemberSyntax(node) {
                if (node.specifiers.length === 0) {
                    return "none";
                }
                if (node.specifiers[0].type === "ImportNamespaceSpecifier") {
                    return "all";
                }
                if (node.specifiers.length === 1) {
                    return "single";
                }
                return "multiple";
            }
            /**
             * Gets the group by member parameter index for given declaration.
             * @param {ASTNode} node the ImportDeclaration node.
             * @returns {number} the declaration group by member index.
             */
            function getMemberParameterGroupIndex(node) {
                return memberSyntaxSortOrder.indexOf(usedMemberSyntax(node));
            }
            /**
             * Gets the local name of the first imported module.
             * @param {ASTNode} node the ImportDeclaration node.
             * @returns {?string} the local name of the first imported module.
             */
            function getFirstLocalMemberName(node) {
                if (node.specifiers[0]) {
                    return node.specifiers[0].local.name;
                }
                return null;
            }
            /**
             * Calculates number of lines between two nodes. It is assumed that the given `left` node appears before
             * the given `right` node in the source code. Lines are counted from the end of the `left` node till the
             * start of the `right` node. If the given nodes are on the same line, it returns `0`, same as if they were
             * on two consecutive lines.
             * @param {ASTNode} left node that appears before the given `right` node.
             * @param {ASTNode} right node that appears after the given `left` node.
             * @returns {number} number of lines between nodes.
             */
            function getNumberOfLinesBetween(left, right) {
                return Math.max(right.loc.start.line - left.loc.end.line - 1, 0);
            }
            return {
                ImportDeclaration(node) {
                    if (!ignoreDeclarationSort) {
                        if (previousDeclaration &&
                            allowSeparatedGroups &&
                            getNumberOfLinesBetween(previousDeclaration, node) > 0) {
                            // reset declaration sort
                            previousDeclaration = null;
                        }
                        if (previousDeclaration) {
                            const currentMemberSyntaxGroupIndex = getMemberParameterGroupIndex(node), previousMemberSyntaxGroupIndex = getMemberParameterGroupIndex(previousDeclaration);
                            let currentLocalMemberName = getFirstLocalMemberName(node), previousLocalMemberName = getFirstLocalMemberName(previousDeclaration);
                            if (ignoreCase) {
                                previousLocalMemberName = previousLocalMemberName && previousLocalMemberName.toLowerCase();
                                currentLocalMemberName = currentLocalMemberName && currentLocalMemberName.toLowerCase();
                            }
                            /*
                             * When the current declaration uses a different member syntax,
                             * then check if the ordering is correct.
                             * Otherwise, make a default string compare (like rule sort-vars to be consistent) of the first used local member name.
                             */
                            if (currentMemberSyntaxGroupIndex !== previousMemberSyntaxGroupIndex) {
                                if (currentMemberSyntaxGroupIndex < previousMemberSyntaxGroupIndex) {
                                    context.report({
                                        node,
                                        messageId: "unexpectedSyntaxOrder",
                                        data: {
                                            syntaxA: memberSyntaxSortOrder[currentMemberSyntaxGroupIndex],
                                            syntaxB: memberSyntaxSortOrder[previousMemberSyntaxGroupIndex]
                                        }
                                    });
                                }
                            }
                            else {
                                if (previousLocalMemberName &&
                                    currentLocalMemberName &&
                                    currentLocalMemberName < previousLocalMemberName) {
                                    context.report({
                                        node,
                                        messageId: "sortImportsAlphabetically"
                                    });
                                }
                            }
                        }
                        previousDeclaration = node;
                    }
                    if (!ignoreMemberSort) {
                        const importSpecifiers = node.specifiers.filter(specifier => specifier.type === "ImportSpecifier");
                        const getSortableName = ignoreCase ? specifier => specifier.local.name.toLowerCase() : specifier => specifier.local.name;
                        const firstUnsortedIndex = importSpecifiers.map(getSortableName).findIndex((name, index, array) => array[index - 1] > name);
                        if (firstUnsortedIndex !== -1) {
                            context.report({
                                node: importSpecifiers[firstUnsortedIndex],
                                messageId: "sortMembersAlphabetically",
                                data: { memberName: importSpecifiers[firstUnsortedIndex].local.name },
                                fix(fixer) {
                                    if (importSpecifiers.some(specifier => sourceCode.getCommentsBefore(specifier).length || sourceCode.getCommentsAfter(specifier).length)) {
                                        // If there are comments in the ImportSpecifier list, don't rearrange the specifiers.
                                        return null;
                                    }
                                    return fixer.replaceTextRange([importSpecifiers[0].range[0], importSpecifiers[importSpecifiers.length - 1].range[1]], importSpecifiers
                                        // Clone the importSpecifiers array to avoid mutating it
                                        .slice()
                                        // Sort the array into the desired order
                                        .sort((specifierA, specifierB) => {
                                        const aName = getSortableName(specifierA);
                                        const bName = getSortableName(specifierB);
                                        return aName > bName ? 1 : -1;
                                    })
                                        // Build a string out of the sorted list of import specifiers and the text between the originals
                                        .reduce((sourceText, specifier, index) => {
                                        const textAfterSpecifier = index === importSpecifiers.length - 1
                                            ? ""
                                            : sourceCode.getText().slice(importSpecifiers[index].range[1], importSpecifiers[index + 1].range[0]);
                                        return sourceText + sourceCode.getText(specifier) + textAfterSpecifier;
                                    }, ""));
                                }
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/sort-keys.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to require object keys to be sorted
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */, naturalCompare = require(664) /* natural-compare */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Gets the property name of the given `Property` node.
     *
     * - If the property's key is an `Identifier` node, this returns the key's name
     *   whether it's a computed property or not.
     * - If the property has a static name, this returns the static name.
     * - Otherwise, this returns null.
     * @param {ASTNode} node The `Property` node to get.
     * @returns {string|null} The property name or null.
     * @private
     */
    function getPropertyName(node) {
        const staticName = astUtils.getStaticPropertyName(node);
        if (staticName !== null) {
            return staticName;
        }
        return node.key.name || null;
    }
    /**
     * Functions which check that the given 2 names are in specific order.
     *
     * Postfix `I` is meant insensitive.
     * Postfix `N` is meant natural.
     * @private
     */
    const isValidOrders = {
        asc(a, b) {
            return a <= b;
        },
        ascI(a, b) {
            return a.toLowerCase() <= b.toLowerCase();
        },
        ascN(a, b) {
            return naturalCompare(a, b) <= 0;
        },
        ascIN(a, b) {
            return naturalCompare(a.toLowerCase(), b.toLowerCase()) <= 0;
        },
        desc(a, b) {
            return isValidOrders.asc(b, a);
        },
        descI(a, b) {
            return isValidOrders.ascI(b, a);
        },
        descN(a, b) {
            return isValidOrders.ascN(b, a);
        },
        descIN(a, b) {
            return isValidOrders.ascIN(b, a);
        }
    };
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require object keys to be sorted",
                recommended: false,
                url: "https://eslint.org/docs/rules/sort-keys"
            },
            schema: [
                {
                    enum: ["asc", "desc"]
                },
                {
                    type: "object",
                    properties: {
                        caseSensitive: {
                            type: "boolean",
                            default: true
                        },
                        natural: {
                            type: "boolean",
                            default: false
                        },
                        minKeys: {
                            type: "integer",
                            minimum: 2,
                            default: 2
                        },
                        allowLineSeparatedGroups: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                sortKeys: "Expected object keys to be in {{natural}}{{insensitive}}{{order}}ending order. '{{thisName}}' should be before '{{prevName}}'."
            }
        },
        create(context) {
            // Parse options.
            const order = context.options[0] || "asc";
            const options = context.options[1];
            const insensitive = options && options.caseSensitive === false;
            const natural = options && options.natural;
            const minKeys = options && options.minKeys;
            const allowLineSeparatedGroups = options && options.allowLineSeparatedGroups || false;
            const isValidOrder = isValidOrders[order + (insensitive ? "I" : "") + (natural ? "N" : "")];
            // The stack to save the previous property's name for each object literals.
            let stack = null;
            const sourceCode = context.getSourceCode();
            return {
                ObjectExpression(node) {
                    stack = {
                        upper: stack,
                        prevNode: null,
                        prevBlankLine: false,
                        prevName: null,
                        numKeys: node.properties.length
                    };
                },
                "ObjectExpression:exit"() {
                    stack = stack.upper;
                },
                SpreadElement(node) {
                    if (node.parent.type === "ObjectExpression") {
                        stack.prevName = null;
                    }
                },
                Property(node) {
                    if (node.parent.type === "ObjectPattern") {
                        return;
                    }
                    const prevName = stack.prevName;
                    const numKeys = stack.numKeys;
                    const thisName = getPropertyName(node);
                    // Get tokens between current node and previous node
                    const tokens = stack.prevNode && sourceCode
                        .getTokensBetween(stack.prevNode, node, { includeComments: true });
                    let isBlankLineBetweenNodes = stack.prevBlankLine;
                    if (tokens) {
                        // check blank line between tokens
                        tokens.forEach((token, index) => {
                            const previousToken = tokens[index - 1];
                            if (previousToken && (token.loc.start.line - previousToken.loc.end.line > 1)) {
                                isBlankLineBetweenNodes = true;
                            }
                        });
                        // check blank line between the current node and the last token
                        if (!isBlankLineBetweenNodes && (node.loc.start.line - tokens[tokens.length - 1].loc.end.line > 1)) {
                            isBlankLineBetweenNodes = true;
                        }
                        // check blank line between the first token and the previous node
                        if (!isBlankLineBetweenNodes && (tokens[0].loc.start.line - stack.prevNode.loc.end.line > 1)) {
                            isBlankLineBetweenNodes = true;
                        }
                    }
                    stack.prevNode = node;
                    if (thisName !== null) {
                        stack.prevName = thisName;
                    }
                    if (allowLineSeparatedGroups && isBlankLineBetweenNodes) {
                        stack.prevBlankLine = thisName === null;
                        return;
                    }
                    if (prevName === null || thisName === null || numKeys < minKeys) {
                        return;
                    }
                    if (!isValidOrder(prevName, thisName)) {
                        context.report({
                            node,
                            loc: node.key.loc,
                            messageId: "sortKeys",
                            data: {
                                thisName,
                                prevName,
                                order,
                                insensitive: insensitive ? "insensitive " : "",
                                natural: natural ? "natural " : ""
                            }
                        });
                    }
                }
            };
        }
    };
},
/* natural-compare/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
     * @version    1.4.0
     * @date       2015-10-26
     * @stability  3 - Stable
     * @author     Lauri Rooden (https://github.com/litejs/natural-compare-lite)
     * @license    MIT License
     */
    var naturalCompare = function (a, b) {
        var i, codeA, codeB = 1, posA = 0, posB = 0, alphabet = String.alphabet;
        function getCode(str, pos, code) {
            if (code) {
                for (i = pos; code = getCode(str, i), code < 76 && code > 65;)
                    ++i;
                return +str.slice(pos - 1, i);
            }
            code = alphabet && alphabet.indexOf(str.charAt(pos));
            return code > -1 ? code + 76 : ((code = str.charCodeAt(pos) || 0), code < 45 || code > 127) ? code
                : code < 46 ? 65 // -
                    : code < 48 ? code - 1
                        : code < 58 ? code + 18 // 0-9
                            : code < 65 ? code - 11
                                : code < 91 ? code + 11 // A-Z
                                    : code < 97 ? code - 37
                                        : code < 123 ? code + 5 // a-z
                                            : code - 63;
        }
        if ((a += "") != (b += ""))
            for (; codeB;) {
                codeA = getCode(a, posA++);
                codeB = getCode(b, posB++);
                if (codeA < 76 && codeB < 76 && codeA > 66 && codeB > 66) {
                    codeA = getCode(a, posA, posA);
                    codeB = getCode(b, posB, posA = i);
                    posB = i;
                }
                if (codeA != codeB)
                    return (codeA < codeB) ? -1 : 1;
            }
        return 0;
    };
    try {
        module.exports = naturalCompare;
    }
    catch (e) {
        String.naturalCompare = naturalCompare;
    }
},
/* eslint/lib/rules/sort-vars.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to require sorting of variables within a single Variable Declaration block
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require variables within the same declaration block to be sorted",
                recommended: false,
                url: "https://eslint.org/docs/rules/sort-vars"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        ignoreCase: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "code",
            messages: {
                sortVars: "Variables within the same declaration block should be sorted alphabetically."
            }
        },
        create(context) {
            const configuration = context.options[0] || {}, ignoreCase = configuration.ignoreCase || false, sourceCode = context.getSourceCode();
            return {
                VariableDeclaration(node) {
                    const idDeclarations = node.declarations.filter(decl => decl.id.type === "Identifier");
                    const getSortableName = ignoreCase ? decl => decl.id.name.toLowerCase() : decl => decl.id.name;
                    const unfixable = idDeclarations.some(decl => decl.init !== null && decl.init.type !== "Literal");
                    let fixed = false;
                    idDeclarations.slice(1).reduce((memo, decl) => {
                        const lastVariableName = getSortableName(memo), currentVariableName = getSortableName(decl);
                        if (currentVariableName < lastVariableName) {
                            context.report({
                                node: decl,
                                messageId: "sortVars",
                                fix(fixer) {
                                    if (unfixable || fixed) {
                                        return null;
                                    }
                                    return fixer.replaceTextRange([idDeclarations[0].range[0], idDeclarations[idDeclarations.length - 1].range[1]], idDeclarations
                                        // Clone the idDeclarations array to avoid mutating it
                                        .slice()
                                        // Sort the array into the desired order
                                        .sort((declA, declB) => {
                                        const aName = getSortableName(declA);
                                        const bName = getSortableName(declB);
                                        return aName > bName ? 1 : -1;
                                    })
                                        // Build a string out of the sorted list of identifier declarations and the text between the originals
                                        .reduce((sourceText, identifier, index) => {
                                        const textAfterIdentifier = index === idDeclarations.length - 1
                                            ? ""
                                            : sourceCode.getText().slice(idDeclarations[index].range[1], idDeclarations[index + 1].range[0]);
                                        return sourceText + sourceCode.getText(identifier) + textAfterIdentifier;
                                    }, ""));
                                }
                            });
                            fixed = true;
                            return memo;
                        }
                        return decl;
                    }, idDeclarations[0]);
                }
            };
        }
    };
},
/* eslint/lib/rules/space-before-blocks.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A rule to ensure whitespace before blocks.
     * @author Mathias Schreck <https://github.com/lo1tuma>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Checks whether the given node represents the body of a function.
     * @param {ASTNode} node the node to check.
     * @returns {boolean} `true` if the node is function body.
     */
    function isFunctionBody(node) {
        const parent = node.parent;
        return (node.type === "BlockStatement" &&
            astUtils.isFunction(parent) &&
            parent.body === node);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing before blocks",
                recommended: false,
                url: "https://eslint.org/docs/rules/space-before-blocks"
            },
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["always", "never"]
                        },
                        {
                            type: "object",
                            properties: {
                                keywords: {
                                    enum: ["always", "never", "off"]
                                },
                                functions: {
                                    enum: ["always", "never", "off"]
                                },
                                classes: {
                                    enum: ["always", "never", "off"]
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                unexpectedSpace: "Unexpected space before opening brace.",
                missingSpace: "Missing space before opening brace."
            }
        },
        create(context) {
            const config = context.options[0], sourceCode = context.getSourceCode();
            let alwaysFunctions = true, alwaysKeywords = true, alwaysClasses = true, neverFunctions = false, neverKeywords = false, neverClasses = false;
            if (typeof config === "object") {
                alwaysFunctions = config.functions === "always";
                alwaysKeywords = config.keywords === "always";
                alwaysClasses = config.classes === "always";
                neverFunctions = config.functions === "never";
                neverKeywords = config.keywords === "never";
                neverClasses = config.classes === "never";
            }
            else if (config === "never") {
                alwaysFunctions = false;
                alwaysKeywords = false;
                alwaysClasses = false;
                neverFunctions = true;
                neverKeywords = true;
                neverClasses = true;
            }
            /**
             * Checks whether the spacing before the given block is already controlled by another rule:
             * - `arrow-spacing` checks spaces after `=>`.
             * - `keyword-spacing` checks spaces after keywords in certain contexts.
             * - `switch-colon-spacing` checks spaces after `:` of switch cases.
             * @param {Token} precedingToken first token before the block.
             * @param {ASTNode|Token} node `BlockStatement` node or `{` token of a `SwitchStatement` node.
             * @returns {boolean} `true` if requiring or disallowing spaces before the given block could produce conflicts with other rules.
             */
            function isConflicted(precedingToken, node) {
                return (astUtils.isArrowToken(precedingToken) ||
                    (astUtils.isKeywordToken(precedingToken) &&
                        !isFunctionBody(node)) ||
                    (astUtils.isColonToken(precedingToken) &&
                        node.parent &&
                        node.parent.type === "SwitchCase" &&
                        precedingToken === astUtils.getSwitchCaseColonToken(node.parent, sourceCode)));
            }
            /**
             * Checks the given BlockStatement node has a preceding space if it doesn’t start on a new line.
             * @param {ASTNode|Token} node The AST node of a BlockStatement.
             * @returns {void} undefined.
             */
            function checkPrecedingSpace(node) {
                const precedingToken = sourceCode.getTokenBefore(node);
                if (precedingToken && !isConflicted(precedingToken, node) && astUtils.isTokenOnSameLine(precedingToken, node)) {
                    const hasSpace = sourceCode.isSpaceBetweenTokens(precedingToken, node);
                    let requireSpace;
                    let requireNoSpace;
                    if (isFunctionBody(node)) {
                        requireSpace = alwaysFunctions;
                        requireNoSpace = neverFunctions;
                    }
                    else if (node.type === "ClassBody") {
                        requireSpace = alwaysClasses;
                        requireNoSpace = neverClasses;
                    }
                    else {
                        requireSpace = alwaysKeywords;
                        requireNoSpace = neverKeywords;
                    }
                    if (requireSpace && !hasSpace) {
                        context.report({
                            node,
                            messageId: "missingSpace",
                            fix(fixer) {
                                return fixer.insertTextBefore(node, " ");
                            }
                        });
                    }
                    else if (requireNoSpace && hasSpace) {
                        context.report({
                            node,
                            messageId: "unexpectedSpace",
                            fix(fixer) {
                                return fixer.removeRange([precedingToken.range[1], node.range[0]]);
                            }
                        });
                    }
                }
            }
            /**
             * Checks if the CaseBlock of an given SwitchStatement node has a preceding space.
             * @param {ASTNode} node The node of a SwitchStatement.
             * @returns {void} undefined.
             */
            function checkSpaceBeforeCaseBlock(node) {
                const cases = node.cases;
                let openingBrace;
                if (cases.length > 0) {
                    openingBrace = sourceCode.getTokenBefore(cases[0]);
                }
                else {
                    openingBrace = sourceCode.getLastToken(node, 1);
                }
                checkPrecedingSpace(openingBrace);
            }
            return {
                BlockStatement: checkPrecedingSpace,
                ClassBody: checkPrecedingSpace,
                SwitchStatement: checkSpaceBeforeCaseBlock
            };
        }
    };
},
/* eslint/lib/rules/space-before-function-paren.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to validate spacing before function paren.
     * @author Mathias Schreck <https://github.com/lo1tuma>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing before `function` definition opening parenthesis",
                recommended: false,
                url: "https://eslint.org/docs/rules/space-before-function-paren"
            },
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["always", "never"]
                        },
                        {
                            type: "object",
                            properties: {
                                anonymous: {
                                    enum: ["always", "never", "ignore"]
                                },
                                named: {
                                    enum: ["always", "never", "ignore"]
                                },
                                asyncArrow: {
                                    enum: ["always", "never", "ignore"]
                                }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                unexpectedSpace: "Unexpected space before function parentheses.",
                missingSpace: "Missing space before function parentheses."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const baseConfig = typeof context.options[0] === "string" ? context.options[0] : "always";
            const overrideConfig = typeof context.options[0] === "object" ? context.options[0] : {};
            /**
             * Determines whether a function has a name.
             * @param {ASTNode} node The function node.
             * @returns {boolean} Whether the function has a name.
             */
            function isNamedFunction(node) {
                if (node.id) {
                    return true;
                }
                const parent = node.parent;
                return parent.type === "MethodDefinition" ||
                    (parent.type === "Property" &&
                        (parent.kind === "get" ||
                            parent.kind === "set" ||
                            parent.method));
            }
            /**
             * Gets the config for a given function
             * @param {ASTNode} node The function node
             * @returns {string} "always", "never", or "ignore"
             */
            function getConfigForFunction(node) {
                if (node.type === "ArrowFunctionExpression") {
                    // Always ignore non-async functions and arrow functions without parens, e.g. async foo => bar
                    if (node.async && astUtils.isOpeningParenToken(sourceCode.getFirstToken(node, { skip: 1 }))) {
                        return overrideConfig.asyncArrow || baseConfig;
                    }
                }
                else if (isNamedFunction(node)) {
                    return overrideConfig.named || baseConfig;
                    // `generator-star-spacing` should warn anonymous generators. E.g. `function* () {}`
                }
                else if (!node.generator) {
                    return overrideConfig.anonymous || baseConfig;
                }
                return "ignore";
            }
            /**
             * Checks the parens of a function node
             * @param {ASTNode} node A function node
             * @returns {void}
             */
            function checkFunction(node) {
                const functionConfig = getConfigForFunction(node);
                if (functionConfig === "ignore") {
                    return;
                }
                const rightToken = sourceCode.getFirstToken(node, astUtils.isOpeningParenToken);
                const leftToken = sourceCode.getTokenBefore(rightToken);
                const hasSpacing = sourceCode.isSpaceBetweenTokens(leftToken, rightToken);
                if (hasSpacing && functionConfig === "never") {
                    context.report({
                        node,
                        loc: {
                            start: leftToken.loc.end,
                            end: rightToken.loc.start
                        },
                        messageId: "unexpectedSpace",
                        fix(fixer) {
                            const comments = sourceCode.getCommentsBefore(rightToken);
                            // Don't fix anything if there's a single line comment between the left and the right token
                            if (comments.some(comment => comment.type === "Line")) {
                                return null;
                            }
                            return fixer.replaceTextRange([leftToken.range[1], rightToken.range[0]], comments.reduce((text, comment) => text + sourceCode.getText(comment), ""));
                        }
                    });
                }
                else if (!hasSpacing && functionConfig === "always") {
                    context.report({
                        node,
                        loc: rightToken.loc,
                        messageId: "missingSpace",
                        fix: fixer => fixer.insertTextAfter(leftToken, " ")
                    });
                }
            }
            return {
                ArrowFunctionExpression: checkFunction,
                FunctionDeclaration: checkFunction,
                FunctionExpression: checkFunction
            };
        }
    };
},
/* eslint/lib/rules/space-in-parens.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Disallows or enforces spaces inside of parentheses.
     * @author Jonathan Rajavuori
     */
    "use strict";
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing inside parentheses",
                recommended: false,
                url: "https://eslint.org/docs/rules/space-in-parens"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never"]
                },
                {
                    type: "object",
                    properties: {
                        exceptions: {
                            type: "array",
                            items: {
                                enum: ["{}", "[]", "()", "empty"]
                            },
                            uniqueItems: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                missingOpeningSpace: "There must be a space after this paren.",
                missingClosingSpace: "There must be a space before this paren.",
                rejectedOpeningSpace: "There should be no space after this paren.",
                rejectedClosingSpace: "There should be no space before this paren."
            }
        },
        create(context) {
            const ALWAYS = context.options[0] === "always", exceptionsArrayOptions = (context.options[1] && context.options[1].exceptions) || [], options = {};
            let exceptions;
            if (exceptionsArrayOptions.length) {
                options.braceException = exceptionsArrayOptions.includes("{}");
                options.bracketException = exceptionsArrayOptions.includes("[]");
                options.parenException = exceptionsArrayOptions.includes("()");
                options.empty = exceptionsArrayOptions.includes("empty");
            }
            /**
             * Produces an object with the opener and closer exception values
             * @returns {Object} `openers` and `closers` exception values
             * @private
             */
            function getExceptions() {
                const openers = [], closers = [];
                if (options.braceException) {
                    openers.push("{");
                    closers.push("}");
                }
                if (options.bracketException) {
                    openers.push("[");
                    closers.push("]");
                }
                if (options.parenException) {
                    openers.push("(");
                    closers.push(")");
                }
                if (options.empty) {
                    openers.push(")");
                    closers.push("(");
                }
                return {
                    openers,
                    closers
                };
            }
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            const sourceCode = context.getSourceCode();
            /**
             * Determines if a token is one of the exceptions for the opener paren
             * @param {Object} token The token to check
             * @returns {boolean} True if the token is one of the exceptions for the opener paren
             */
            function isOpenerException(token) {
                return exceptions.openers.includes(token.value);
            }
            /**
             * Determines if a token is one of the exceptions for the closer paren
             * @param {Object} token The token to check
             * @returns {boolean} True if the token is one of the exceptions for the closer paren
             */
            function isCloserException(token) {
                return exceptions.closers.includes(token.value);
            }
            /**
             * Determines if an opening paren is immediately followed by a required space
             * @param {Object} openingParenToken The paren token
             * @param {Object} tokenAfterOpeningParen The token after it
             * @returns {boolean} True if the opening paren is missing a required space
             */
            function openerMissingSpace(openingParenToken, tokenAfterOpeningParen) {
                if (sourceCode.isSpaceBetweenTokens(openingParenToken, tokenAfterOpeningParen)) {
                    return false;
                }
                if (!options.empty && astUtils.isClosingParenToken(tokenAfterOpeningParen)) {
                    return false;
                }
                if (ALWAYS) {
                    return !isOpenerException(tokenAfterOpeningParen);
                }
                return isOpenerException(tokenAfterOpeningParen);
            }
            /**
             * Determines if an opening paren is immediately followed by a disallowed space
             * @param {Object} openingParenToken The paren token
             * @param {Object} tokenAfterOpeningParen The token after it
             * @returns {boolean} True if the opening paren has a disallowed space
             */
            function openerRejectsSpace(openingParenToken, tokenAfterOpeningParen) {
                if (!astUtils.isTokenOnSameLine(openingParenToken, tokenAfterOpeningParen)) {
                    return false;
                }
                if (tokenAfterOpeningParen.type === "Line") {
                    return false;
                }
                if (!sourceCode.isSpaceBetweenTokens(openingParenToken, tokenAfterOpeningParen)) {
                    return false;
                }
                if (ALWAYS) {
                    return isOpenerException(tokenAfterOpeningParen);
                }
                return !isOpenerException(tokenAfterOpeningParen);
            }
            /**
             * Determines if a closing paren is immediately preceded by a required space
             * @param {Object} tokenBeforeClosingParen The token before the paren
             * @param {Object} closingParenToken The paren token
             * @returns {boolean} True if the closing paren is missing a required space
             */
            function closerMissingSpace(tokenBeforeClosingParen, closingParenToken) {
                if (sourceCode.isSpaceBetweenTokens(tokenBeforeClosingParen, closingParenToken)) {
                    return false;
                }
                if (!options.empty && astUtils.isOpeningParenToken(tokenBeforeClosingParen)) {
                    return false;
                }
                if (ALWAYS) {
                    return !isCloserException(tokenBeforeClosingParen);
                }
                return isCloserException(tokenBeforeClosingParen);
            }
            /**
             * Determines if a closer paren is immediately preceded by a disallowed space
             * @param {Object} tokenBeforeClosingParen The token before the paren
             * @param {Object} closingParenToken The paren token
             * @returns {boolean} True if the closing paren has a disallowed space
             */
            function closerRejectsSpace(tokenBeforeClosingParen, closingParenToken) {
                if (!astUtils.isTokenOnSameLine(tokenBeforeClosingParen, closingParenToken)) {
                    return false;
                }
                if (!sourceCode.isSpaceBetweenTokens(tokenBeforeClosingParen, closingParenToken)) {
                    return false;
                }
                if (ALWAYS) {
                    return isCloserException(tokenBeforeClosingParen);
                }
                return !isCloserException(tokenBeforeClosingParen);
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program: function checkParenSpaces(node) {
                    exceptions = getExceptions();
                    const tokens = sourceCode.tokensAndComments;
                    tokens.forEach((token, i) => {
                        const prevToken = tokens[i - 1];
                        const nextToken = tokens[i + 1];
                        // if token is not an opening or closing paren token, do nothing
                        if (!astUtils.isOpeningParenToken(token) && !astUtils.isClosingParenToken(token)) {
                            return;
                        }
                        // if token is an opening paren and is not followed by a required space
                        if (token.value === "(" && openerMissingSpace(token, nextToken)) {
                            context.report({
                                node,
                                loc: token.loc,
                                messageId: "missingOpeningSpace",
                                fix(fixer) {
                                    return fixer.insertTextAfter(token, " ");
                                }
                            });
                        }
                        // if token is an opening paren and is followed by a disallowed space
                        if (token.value === "(" && openerRejectsSpace(token, nextToken)) {
                            context.report({
                                node,
                                loc: { start: token.loc.end, end: nextToken.loc.start },
                                messageId: "rejectedOpeningSpace",
                                fix(fixer) {
                                    return fixer.removeRange([token.range[1], nextToken.range[0]]);
                                }
                            });
                        }
                        // if token is a closing paren and is not preceded by a required space
                        if (token.value === ")" && closerMissingSpace(prevToken, token)) {
                            context.report({
                                node,
                                loc: token.loc,
                                messageId: "missingClosingSpace",
                                fix(fixer) {
                                    return fixer.insertTextBefore(token, " ");
                                }
                            });
                        }
                        // if token is a closing paren and is preceded by a disallowed space
                        if (token.value === ")" && closerRejectsSpace(prevToken, token)) {
                            context.report({
                                node,
                                loc: { start: prevToken.loc.end, end: token.loc.start },
                                messageId: "rejectedClosingSpace",
                                fix(fixer) {
                                    return fixer.removeRange([prevToken.range[1], token.range[0]]);
                                }
                            });
                        }
                    });
                }
            };
        }
    };
},
/* eslint/lib/rules/space-infix-ops.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Require spaces around infix operators
     * @author Michael Ficarra
     */
    "use strict";
    const { isEqToken } = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require spacing around infix operators",
                recommended: false,
                url: "https://eslint.org/docs/rules/space-infix-ops"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        int32Hint: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                missingSpace: "Operator '{{operator}}' must be spaced."
            }
        },
        create(context) {
            const int32Hint = context.options[0] ? context.options[0].int32Hint === true : false;
            const sourceCode = context.getSourceCode();
            /**
             * Returns the first token which violates the rule
             * @param {ASTNode} left The left node of the main node
             * @param {ASTNode} right The right node of the main node
             * @param {string} op The operator of the main node
             * @returns {Object} The violator token or null
             * @private
             */
            function getFirstNonSpacedToken(left, right, op) {
                const operator = sourceCode.getFirstTokenBetween(left, right, token => token.value === op);
                const prev = sourceCode.getTokenBefore(operator);
                const next = sourceCode.getTokenAfter(operator);
                if (!sourceCode.isSpaceBetweenTokens(prev, operator) || !sourceCode.isSpaceBetweenTokens(operator, next)) {
                    return operator;
                }
                return null;
            }
            /**
             * Reports an AST node as a rule violation
             * @param {ASTNode} mainNode The node to report
             * @param {Object} culpritToken The token which has a problem
             * @returns {void}
             * @private
             */
            function report(mainNode, culpritToken) {
                context.report({
                    node: mainNode,
                    loc: culpritToken.loc,
                    messageId: "missingSpace",
                    data: {
                        operator: culpritToken.value
                    },
                    fix(fixer) {
                        const previousToken = sourceCode.getTokenBefore(culpritToken);
                        const afterToken = sourceCode.getTokenAfter(culpritToken);
                        let fixString = "";
                        if (culpritToken.range[0] - previousToken.range[1] === 0) {
                            fixString = " ";
                        }
                        fixString += culpritToken.value;
                        if (afterToken.range[0] - culpritToken.range[1] === 0) {
                            fixString += " ";
                        }
                        return fixer.replaceText(culpritToken, fixString);
                    }
                });
            }
            /**
             * Check if the node is binary then report
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkBinary(node) {
                const leftNode = (node.left.typeAnnotation) ? node.left.typeAnnotation : node.left;
                const rightNode = node.right;
                // search for = in AssignmentPattern nodes
                const operator = node.operator || "=";
                const nonSpacedNode = getFirstNonSpacedToken(leftNode, rightNode, operator);
                if (nonSpacedNode) {
                    if (!(int32Hint && sourceCode.getText(node).endsWith("|0"))) {
                        report(node, nonSpacedNode);
                    }
                }
            }
            /**
             * Check if the node is conditional
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkConditional(node) {
                const nonSpacedConsequentNode = getFirstNonSpacedToken(node.test, node.consequent, "?");
                const nonSpacedAlternateNode = getFirstNonSpacedToken(node.consequent, node.alternate, ":");
                if (nonSpacedConsequentNode) {
                    report(node, nonSpacedConsequentNode);
                }
                if (nonSpacedAlternateNode) {
                    report(node, nonSpacedAlternateNode);
                }
            }
            /**
             * Check if the node is a variable
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkVar(node) {
                const leftNode = (node.id.typeAnnotation) ? node.id.typeAnnotation : node.id;
                const rightNode = node.init;
                if (rightNode) {
                    const nonSpacedNode = getFirstNonSpacedToken(leftNode, rightNode, "=");
                    if (nonSpacedNode) {
                        report(node, nonSpacedNode);
                    }
                }
            }
            return {
                AssignmentExpression: checkBinary,
                AssignmentPattern: checkBinary,
                BinaryExpression: checkBinary,
                LogicalExpression: checkBinary,
                ConditionalExpression: checkConditional,
                VariableDeclarator: checkVar,
                PropertyDefinition(node) {
                    if (!node.value) {
                        return;
                    }
                    /*
                     * Because of computed properties and type annotations, some
                     * tokens may exist between `node.key` and `=`.
                     * Therefore, find the `=` from the right.
                     */
                    const operatorToken = sourceCode.getTokenBefore(node.value, isEqToken);
                    const leftToken = sourceCode.getTokenBefore(operatorToken);
                    const rightToken = sourceCode.getTokenAfter(operatorToken);
                    if (!sourceCode.isSpaceBetweenTokens(leftToken, operatorToken) ||
                        !sourceCode.isSpaceBetweenTokens(operatorToken, rightToken)) {
                        report(node, operatorToken);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/space-unary-ops.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview This rule should require or disallow spaces before or after unary operations.
     * @author Marcin Kumorek
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce consistent spacing before or after unary operators",
                recommended: false,
                url: "https://eslint.org/docs/rules/space-unary-ops"
            },
            fixable: "whitespace",
            schema: [
                {
                    type: "object",
                    properties: {
                        words: {
                            type: "boolean",
                            default: true
                        },
                        nonwords: {
                            type: "boolean",
                            default: false
                        },
                        overrides: {
                            type: "object",
                            additionalProperties: {
                                type: "boolean"
                            }
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedBefore: "Unexpected space before unary operator '{{operator}}'.",
                unexpectedAfter: "Unexpected space after unary operator '{{operator}}'.",
                unexpectedAfterWord: "Unexpected space after unary word operator '{{word}}'.",
                wordOperator: "Unary word operator '{{word}}' must be followed by whitespace.",
                operator: "Unary operator '{{operator}}' must be followed by whitespace.",
                beforeUnaryExpressions: "Space is required before unary expressions '{{token}}'."
            }
        },
        create(context) {
            const options = context.options[0] || { words: true, nonwords: false };
            const sourceCode = context.getSourceCode();
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Check if the node is the first "!" in a "!!" convert to Boolean expression
             * @param {ASTnode} node AST node
             * @returns {boolean} Whether or not the node is first "!" in "!!"
             */
            function isFirstBangInBangBangExpression(node) {
                return node && node.type === "UnaryExpression" && node.argument.operator === "!" &&
                    node.argument && node.argument.type === "UnaryExpression" && node.argument.operator === "!";
            }
            /**
             * Checks if an override exists for a given operator.
             * @param {string} operator Operator
             * @returns {boolean} Whether or not an override has been provided for the operator
             */
            function overrideExistsForOperator(operator) {
                return options.overrides && Object.prototype.hasOwnProperty.call(options.overrides, operator);
            }
            /**
             * Gets the value that the override was set to for this operator
             * @param {string} operator Operator
             * @returns {boolean} Whether or not an override enforces a space with this operator
             */
            function overrideEnforcesSpaces(operator) {
                return options.overrides[operator];
            }
            /**
             * Verify Unary Word Operator has spaces after the word operator
             * @param {ASTnode} node AST node
             * @param {Object} firstToken first token from the AST node
             * @param {Object} secondToken second token from the AST node
             * @param {string} word The word to be used for reporting
             * @returns {void}
             */
            function verifyWordHasSpaces(node, firstToken, secondToken, word) {
                if (secondToken.range[0] === firstToken.range[1]) {
                    context.report({
                        node,
                        messageId: "wordOperator",
                        data: {
                            word
                        },
                        fix(fixer) {
                            return fixer.insertTextAfter(firstToken, " ");
                        }
                    });
                }
            }
            /**
             * Verify Unary Word Operator doesn't have spaces after the word operator
             * @param {ASTnode} node AST node
             * @param {Object} firstToken first token from the AST node
             * @param {Object} secondToken second token from the AST node
             * @param {string} word The word to be used for reporting
             * @returns {void}
             */
            function verifyWordDoesntHaveSpaces(node, firstToken, secondToken, word) {
                if (astUtils.canTokensBeAdjacent(firstToken, secondToken)) {
                    if (secondToken.range[0] > firstToken.range[1]) {
                        context.report({
                            node,
                            messageId: "unexpectedAfterWord",
                            data: {
                                word
                            },
                            fix(fixer) {
                                return fixer.removeRange([firstToken.range[1], secondToken.range[0]]);
                            }
                        });
                    }
                }
            }
            /**
             * Check Unary Word Operators for spaces after the word operator
             * @param {ASTnode} node AST node
             * @param {Object} firstToken first token from the AST node
             * @param {Object} secondToken second token from the AST node
             * @param {string} word The word to be used for reporting
             * @returns {void}
             */
            function checkUnaryWordOperatorForSpaces(node, firstToken, secondToken, word) {
                if (overrideExistsForOperator(word)) {
                    if (overrideEnforcesSpaces(word)) {
                        verifyWordHasSpaces(node, firstToken, secondToken, word);
                    }
                    else {
                        verifyWordDoesntHaveSpaces(node, firstToken, secondToken, word);
                    }
                }
                else if (options.words) {
                    verifyWordHasSpaces(node, firstToken, secondToken, word);
                }
                else {
                    verifyWordDoesntHaveSpaces(node, firstToken, secondToken, word);
                }
            }
            /**
             * Verifies YieldExpressions satisfy spacing requirements
             * @param {ASTnode} node AST node
             * @returns {void}
             */
            function checkForSpacesAfterYield(node) {
                const tokens = sourceCode.getFirstTokens(node, 3), word = "yield";
                if (!node.argument || node.delegate) {
                    return;
                }
                checkUnaryWordOperatorForSpaces(node, tokens[0], tokens[1], word);
            }
            /**
             * Verifies AwaitExpressions satisfy spacing requirements
             * @param {ASTNode} node AwaitExpression AST node
             * @returns {void}
             */
            function checkForSpacesAfterAwait(node) {
                const tokens = sourceCode.getFirstTokens(node, 3);
                checkUnaryWordOperatorForSpaces(node, tokens[0], tokens[1], "await");
            }
            /**
             * Verifies UnaryExpression, UpdateExpression and NewExpression have spaces before or after the operator
             * @param {ASTnode} node AST node
             * @param {Object} firstToken First token in the expression
             * @param {Object} secondToken Second token in the expression
             * @returns {void}
             */
            function verifyNonWordsHaveSpaces(node, firstToken, secondToken) {
                if (node.prefix) {
                    if (isFirstBangInBangBangExpression(node)) {
                        return;
                    }
                    if (firstToken.range[1] === secondToken.range[0]) {
                        context.report({
                            node,
                            messageId: "operator",
                            data: {
                                operator: firstToken.value
                            },
                            fix(fixer) {
                                return fixer.insertTextAfter(firstToken, " ");
                            }
                        });
                    }
                }
                else {
                    if (firstToken.range[1] === secondToken.range[0]) {
                        context.report({
                            node,
                            messageId: "beforeUnaryExpressions",
                            data: {
                                token: secondToken.value
                            },
                            fix(fixer) {
                                return fixer.insertTextBefore(secondToken, " ");
                            }
                        });
                    }
                }
            }
            /**
             * Verifies UnaryExpression, UpdateExpression and NewExpression don't have spaces before or after the operator
             * @param {ASTnode} node AST node
             * @param {Object} firstToken First token in the expression
             * @param {Object} secondToken Second token in the expression
             * @returns {void}
             */
            function verifyNonWordsDontHaveSpaces(node, firstToken, secondToken) {
                if (node.prefix) {
                    if (secondToken.range[0] > firstToken.range[1]) {
                        context.report({
                            node,
                            messageId: "unexpectedAfter",
                            data: {
                                operator: firstToken.value
                            },
                            fix(fixer) {
                                if (astUtils.canTokensBeAdjacent(firstToken, secondToken)) {
                                    return fixer.removeRange([firstToken.range[1], secondToken.range[0]]);
                                }
                                return null;
                            }
                        });
                    }
                }
                else {
                    if (secondToken.range[0] > firstToken.range[1]) {
                        context.report({
                            node,
                            messageId: "unexpectedBefore",
                            data: {
                                operator: secondToken.value
                            },
                            fix(fixer) {
                                return fixer.removeRange([firstToken.range[1], secondToken.range[0]]);
                            }
                        });
                    }
                }
            }
            /**
             * Verifies UnaryExpression, UpdateExpression and NewExpression satisfy spacing requirements
             * @param {ASTnode} node AST node
             * @returns {void}
             */
            function checkForSpaces(node) {
                const tokens = node.type === "UpdateExpression" && !node.prefix
                    ? sourceCode.getLastTokens(node, 2)
                    : sourceCode.getFirstTokens(node, 2);
                const firstToken = tokens[0];
                const secondToken = tokens[1];
                if ((node.type === "NewExpression" || node.prefix) && firstToken.type === "Keyword") {
                    checkUnaryWordOperatorForSpaces(node, firstToken, secondToken, firstToken.value);
                    return;
                }
                const operator = node.prefix ? tokens[0].value : tokens[1].value;
                if (overrideExistsForOperator(operator)) {
                    if (overrideEnforcesSpaces(operator)) {
                        verifyNonWordsHaveSpaces(node, firstToken, secondToken);
                    }
                    else {
                        verifyNonWordsDontHaveSpaces(node, firstToken, secondToken);
                    }
                }
                else if (options.nonwords) {
                    verifyNonWordsHaveSpaces(node, firstToken, secondToken);
                }
                else {
                    verifyNonWordsDontHaveSpaces(node, firstToken, secondToken);
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                UnaryExpression: checkForSpaces,
                UpdateExpression: checkForSpaces,
                NewExpression: checkForSpaces,
                YieldExpression: checkForSpacesAfterYield,
                AwaitExpression: checkForSpacesAfterAwait
            };
        }
    };
},
/* eslint/lib/rules/spaced-comment.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Source code for spaced-comments rule
     * @author Gyandeep Singh
     */
    "use strict";
    const escapeRegExp = require(285) /* escape-string-regexp */;
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Escapes the control characters of a given string.
     * @param {string} s A string to escape.
     * @returns {string} An escaped string.
     */
    function escape(s) {
        return `(?:${escapeRegExp(s)})`;
    }
    /**
     * Escapes the control characters of a given string.
     * And adds a repeat flag.
     * @param {string} s A string to escape.
     * @returns {string} An escaped string.
     */
    function escapeAndRepeat(s) {
        return `${escape(s)}+`;
    }
    /**
     * Parses `markers` option.
     * If markers don't include `"*"`, this adds `"*"` to allow JSDoc comments.
     * @param {string[]} [markers] A marker list.
     * @returns {string[]} A marker list.
     */
    function parseMarkersOption(markers) {
        // `*` is a marker for JSDoc comments.
        if (!markers.includes("*")) {
            return markers.concat("*");
        }
        return markers;
    }
    /**
     * Creates string pattern for exceptions.
     * Generated pattern:
     *
     * 1. A space or an exception pattern sequence.
     * @param {string[]} exceptions An exception pattern list.
     * @returns {string} A regular expression string for exceptions.
     */
    function createExceptionsPattern(exceptions) {
        let pattern = "";
        /*
         * A space or an exception pattern sequence.
         * []                 ==> "\s"
         * ["-"]              ==> "(?:\s|\-+$)"
         * ["-", "="]         ==> "(?:\s|(?:\-+|=+)$)"
         * ["-", "=", "--=="] ==> "(?:\s|(?:\-+|=+|(?:\-\-==)+)$)" ==> https://jex.im/regulex/#!embed=false&flags=&re=(%3F%3A%5Cs%7C(%3F%3A%5C-%2B%7C%3D%2B%7C(%3F%3A%5C-%5C-%3D%3D)%2B)%24)
         */
        if (exceptions.length === 0) {
            // a space.
            pattern += "\\s";
        }
        else {
            // a space or...
            pattern += "(?:\\s|";
            if (exceptions.length === 1) {
                // a sequence of the exception pattern.
                pattern += escapeAndRepeat(exceptions[0]);
            }
            else {
                // a sequence of one of the exception patterns.
                pattern += "(?:";
                pattern += exceptions.map(escapeAndRepeat).join("|");
                pattern += ")";
            }
            pattern += `(?:$|[${Array.from(astUtils.LINEBREAKS).join("")}]))`;
        }
        return pattern;
    }
    /**
     * Creates RegExp object for `always` mode.
     * Generated pattern for beginning of comment:
     *
     * 1. First, a marker or nothing.
     * 2. Next, a space or an exception pattern sequence.
     * @param {string[]} markers A marker list.
     * @param {string[]} exceptions An exception pattern list.
     * @returns {RegExp} A RegExp object for the beginning of a comment in `always` mode.
     */
    function createAlwaysStylePattern(markers, exceptions) {
        let pattern = "^";
        /*
         * A marker or nothing.
         * ["*"]            ==> "\*?"
         * ["*", "!"]       ==> "(?:\*|!)?"
         * ["*", "/", "!<"] ==> "(?:\*|\/|(?:!<))?" ==> https://jex.im/regulex/#!embed=false&flags=&re=(%3F%3A%5C*%7C%5C%2F%7C(%3F%3A!%3C))%3F
         */
        if (markers.length === 1) {
            // the marker.
            pattern += escape(markers[0]);
        }
        else {
            // one of markers.
            pattern += "(?:";
            pattern += markers.map(escape).join("|");
            pattern += ")";
        }
        pattern += "?"; // or nothing.
        pattern += createExceptionsPattern(exceptions);
        return new RegExp(pattern, "u");
    }
    /**
     * Creates RegExp object for `never` mode.
     * Generated pattern for beginning of comment:
     *
     * 1. First, a marker or nothing (captured).
     * 2. Next, a space or a tab.
     * @param {string[]} markers A marker list.
     * @returns {RegExp} A RegExp object for `never` mode.
     */
    function createNeverStylePattern(markers) {
        const pattern = `^(${markers.map(escape).join("|")})?[ \t]+`;
        return new RegExp(pattern, "u");
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce consistent spacing after the `//` or `/*` in a comment",
                recommended: false,
                url: "https://eslint.org/docs/rules/spaced-comment"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never"]
                },
                {
                    type: "object",
                    properties: {
                        exceptions: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        },
                        markers: {
                            type: "array",
                            items: {
                                type: "string"
                            }
                        },
                        line: {
                            type: "object",
                            properties: {
                                exceptions: {
                                    type: "array",
                                    items: {
                                        type: "string"
                                    }
                                },
                                markers: {
                                    type: "array",
                                    items: {
                                        type: "string"
                                    }
                                }
                            },
                            additionalProperties: false
                        },
                        block: {
                            type: "object",
                            properties: {
                                exceptions: {
                                    type: "array",
                                    items: {
                                        type: "string"
                                    }
                                },
                                markers: {
                                    type: "array",
                                    items: {
                                        type: "string"
                                    }
                                },
                                balanced: {
                                    type: "boolean",
                                    default: false
                                }
                            },
                            additionalProperties: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                unexpectedSpaceAfterMarker: "Unexpected space or tab after marker ({{refChar}}) in comment.",
                expectedExceptionAfter: "Expected exception block, space or tab after '{{refChar}}' in comment.",
                unexpectedSpaceBefore: "Unexpected space or tab before '*/' in comment.",
                unexpectedSpaceAfter: "Unexpected space or tab after '{{refChar}}' in comment.",
                expectedSpaceBefore: "Expected space or tab before '*/' in comment.",
                expectedSpaceAfter: "Expected space or tab after '{{refChar}}' in comment."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            // Unless the first option is never, require a space
            const requireSpace = context.options[0] !== "never";
            /*
             * Parse the second options.
             * If markers don't include `"*"`, it's added automatically for JSDoc
             * comments.
             */
            const config = context.options[1] || {};
            const balanced = config.block && config.block.balanced;
            const styleRules = ["block", "line"].reduce((rule, type) => {
                const markers = parseMarkersOption(config[type] && config[type].markers || config.markers || []);
                const exceptions = config[type] && config[type].exceptions || config.exceptions || [];
                const endNeverPattern = "[ \t]+$";
                // Create RegExp object for valid patterns.
                rule[type] = {
                    beginRegex: requireSpace ? createAlwaysStylePattern(markers, exceptions) : createNeverStylePattern(markers),
                    endRegex: balanced && requireSpace ? new RegExp(`${createExceptionsPattern(exceptions)}$`, "u") : new RegExp(endNeverPattern, "u"),
                    hasExceptions: exceptions.length > 0,
                    captureMarker: new RegExp(`^(${markers.map(escape).join("|")})`, "u"),
                    markers: new Set(markers)
                };
                return rule;
            }, {});
            /**
             * Reports a beginning spacing error with an appropriate message.
             * @param {ASTNode} node A comment node to check.
             * @param {string} messageId An error message to report.
             * @param {Array} match An array of match results for markers.
             * @param {string} refChar Character used for reference in the error message.
             * @returns {void}
             */
            function reportBegin(node, messageId, match, refChar) {
                const type = node.type.toLowerCase(), commentIdentifier = type === "block" ? "/*" : "//";
                context.report({
                    node,
                    fix(fixer) {
                        const start = node.range[0];
                        let end = start + 2;
                        if (requireSpace) {
                            if (match) {
                                end += match[0].length;
                            }
                            return fixer.insertTextAfterRange([start, end], " ");
                        }
                        end += match[0].length;
                        return fixer.replaceTextRange([start, end], commentIdentifier + (match[1] ? match[1] : ""));
                    },
                    messageId,
                    data: { refChar }
                });
            }
            /**
             * Reports an ending spacing error with an appropriate message.
             * @param {ASTNode} node A comment node to check.
             * @param {string} messageId An error message to report.
             * @param {string} match An array of the matched whitespace characters.
             * @returns {void}
             */
            function reportEnd(node, messageId, match) {
                context.report({
                    node,
                    fix(fixer) {
                        if (requireSpace) {
                            return fixer.insertTextAfterRange([node.range[0], node.range[1] - 2], " ");
                        }
                        const end = node.range[1] - 2, start = end - match[0].length;
                        return fixer.replaceTextRange([start, end], "");
                    },
                    messageId
                });
            }
            /**
             * Reports a given comment if it's invalid.
             * @param {ASTNode} node a comment node to check.
             * @returns {void}
             */
            function checkCommentForSpace(node) {
                const type = node.type.toLowerCase(), rule = styleRules[type], commentIdentifier = type === "block" ? "/*" : "//";
                // Ignores empty comments and comments that consist only of a marker.
                if (node.value.length === 0 || rule.markers.has(node.value)) {
                    return;
                }
                const beginMatch = rule.beginRegex.exec(node.value);
                const endMatch = rule.endRegex.exec(node.value);
                // Checks.
                if (requireSpace) {
                    if (!beginMatch) {
                        const hasMarker = rule.captureMarker.exec(node.value);
                        const marker = hasMarker ? commentIdentifier + hasMarker[0] : commentIdentifier;
                        if (rule.hasExceptions) {
                            reportBegin(node, "expectedExceptionAfter", hasMarker, marker);
                        }
                        else {
                            reportBegin(node, "expectedSpaceAfter", hasMarker, marker);
                        }
                    }
                    if (balanced && type === "block" && !endMatch) {
                        reportEnd(node, "expectedSpaceBefore");
                    }
                }
                else {
                    if (beginMatch) {
                        if (!beginMatch[1]) {
                            reportBegin(node, "unexpectedSpaceAfter", beginMatch, commentIdentifier);
                        }
                        else {
                            reportBegin(node, "unexpectedSpaceAfterMarker", beginMatch, beginMatch[1]);
                        }
                    }
                    if (balanced && type === "block" && endMatch) {
                        reportEnd(node, "unexpectedSpaceBefore", endMatch);
                    }
                }
            }
            return {
                Program() {
                    const comments = sourceCode.getAllComments();
                    comments.filter(token => token.type !== "Shebang").forEach(checkCommentForSpace);
                }
            };
        }
    };
},
/* eslint/lib/rules/strict.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to control usage of strict mode directives.
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Gets all of the Use Strict Directives in the Directive Prologue of a group of
     * statements.
     * @param {ASTNode[]} statements Statements in the program or function body.
     * @returns {ASTNode[]} All of the Use Strict Directives.
     */
    function getUseStrictDirectives(statements) {
        const directives = [];
        for (let i = 0; i < statements.length; i++) {
            const statement = statements[i];
            if (statement.type === "ExpressionStatement" &&
                statement.expression.type === "Literal" &&
                statement.expression.value === "use strict") {
                directives[i] = statement;
            }
            else {
                break;
            }
        }
        return directives;
    }
    /**
     * Checks whether a given parameter is a simple parameter.
     * @param {ASTNode} node A pattern node to check.
     * @returns {boolean} `true` if the node is an Identifier node.
     */
    function isSimpleParameter(node) {
        return node.type === "Identifier";
    }
    /**
     * Checks whether a given parameter list is a simple parameter list.
     * @param {ASTNode[]} params A parameter list to check.
     * @returns {boolean} `true` if the every parameter is an Identifier node.
     */
    function isSimpleParameterList(params) {
        return params.every(isSimpleParameter);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require or disallow strict mode directives",
                recommended: false,
                url: "https://eslint.org/docs/rules/strict"
            },
            schema: [
                {
                    enum: ["never", "global", "function", "safe"]
                }
            ],
            fixable: "code",
            messages: {
                function: "Use the function form of 'use strict'.",
                global: "Use the global form of 'use strict'.",
                multiple: "Multiple 'use strict' directives.",
                never: "Strict mode is not permitted.",
                unnecessary: "Unnecessary 'use strict' directive.",
                module: "'use strict' is unnecessary inside of modules.",
                implied: "'use strict' is unnecessary when implied strict mode is enabled.",
                unnecessaryInClasses: "'use strict' is unnecessary inside of classes.",
                nonSimpleParameterList: "'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016.",
                wrap: "Wrap {{name}} in a function with 'use strict' directive."
            }
        },
        create(context) {
            const ecmaFeatures = context.parserOptions.ecmaFeatures || {}, scopes = [], classScopes = [];
            let mode = context.options[0] || "safe";
            if (ecmaFeatures.impliedStrict) {
                mode = "implied";
            }
            else if (mode === "safe") {
                mode = ecmaFeatures.globalReturn || context.languageOptions.sourceType === "commonjs" ? "global" : "function";
            }
            /**
             * Determines whether a reported error should be fixed, depending on the error type.
             * @param {string} errorType The type of error
             * @returns {boolean} `true` if the reported error should be fixed
             */
            function shouldFix(errorType) {
                return errorType === "multiple" || errorType === "unnecessary" || errorType === "module" || errorType === "implied" || errorType === "unnecessaryInClasses";
            }
            /**
             * Gets a fixer function to remove a given 'use strict' directive.
             * @param {ASTNode} node The directive that should be removed
             * @returns {Function} A fixer function
             */
            function getFixFunction(node) {
                return fixer => fixer.remove(node);
            }
            /**
             * Report a slice of an array of nodes with a given message.
             * @param {ASTNode[]} nodes Nodes.
             * @param {string} start Index to start from.
             * @param {string} end Index to end before.
             * @param {string} messageId Message to display.
             * @param {boolean} fix `true` if the directive should be fixed (i.e. removed)
             * @returns {void}
             */
            function reportSlice(nodes, start, end, messageId, fix) {
                nodes.slice(start, end).forEach(node => {
                    context.report({ node, messageId, fix: fix ? getFixFunction(node) : null });
                });
            }
            /**
             * Report all nodes in an array with a given message.
             * @param {ASTNode[]} nodes Nodes.
             * @param {string} messageId Message id to display.
             * @param {boolean} fix `true` if the directive should be fixed (i.e. removed)
             * @returns {void}
             */
            function reportAll(nodes, messageId, fix) {
                reportSlice(nodes, 0, nodes.length, messageId, fix);
            }
            /**
             * Report all nodes in an array, except the first, with a given message.
             * @param {ASTNode[]} nodes Nodes.
             * @param {string} messageId Message id to display.
             * @param {boolean} fix `true` if the directive should be fixed (i.e. removed)
             * @returns {void}
             */
            function reportAllExceptFirst(nodes, messageId, fix) {
                reportSlice(nodes, 1, nodes.length, messageId, fix);
            }
            /**
             * Entering a function in 'function' mode pushes a new nested scope onto the
             * stack. The new scope is true if the nested function is strict mode code.
             * @param {ASTNode} node The function declaration or expression.
             * @param {ASTNode[]} useStrictDirectives The Use Strict Directives of the node.
             * @returns {void}
             */
            function enterFunctionInFunctionMode(node, useStrictDirectives) {
                const isInClass = classScopes.length > 0, isParentGlobal = scopes.length === 0 && classScopes.length === 0, isParentStrict = scopes.length > 0 && scopes[scopes.length - 1], isStrict = useStrictDirectives.length > 0;
                if (isStrict) {
                    if (!isSimpleParameterList(node.params)) {
                        context.report({ node: useStrictDirectives[0], messageId: "nonSimpleParameterList" });
                    }
                    else if (isParentStrict) {
                        context.report({ node: useStrictDirectives[0], messageId: "unnecessary", fix: getFixFunction(useStrictDirectives[0]) });
                    }
                    else if (isInClass) {
                        context.report({ node: useStrictDirectives[0], messageId: "unnecessaryInClasses", fix: getFixFunction(useStrictDirectives[0]) });
                    }
                    reportAllExceptFirst(useStrictDirectives, "multiple", true);
                }
                else if (isParentGlobal) {
                    if (isSimpleParameterList(node.params)) {
                        context.report({ node, messageId: "function" });
                    }
                    else {
                        context.report({
                            node,
                            messageId: "wrap",
                            data: { name: astUtils.getFunctionNameWithKind(node) }
                        });
                    }
                }
                scopes.push(isParentStrict || isStrict);
            }
            /**
             * Exiting a function in 'function' mode pops its scope off the stack.
             * @returns {void}
             */
            function exitFunctionInFunctionMode() {
                scopes.pop();
            }
            /**
             * Enter a function and either:
             * - Push a new nested scope onto the stack (in 'function' mode).
             * - Report all the Use Strict Directives (in the other modes).
             * @param {ASTNode} node The function declaration or expression.
             * @returns {void}
             */
            function enterFunction(node) {
                const isBlock = node.body.type === "BlockStatement", useStrictDirectives = isBlock
                    ? getUseStrictDirectives(node.body.body) : [];
                if (mode === "function") {
                    enterFunctionInFunctionMode(node, useStrictDirectives);
                }
                else if (useStrictDirectives.length > 0) {
                    if (isSimpleParameterList(node.params)) {
                        reportAll(useStrictDirectives, mode, shouldFix(mode));
                    }
                    else {
                        context.report({ node: useStrictDirectives[0], messageId: "nonSimpleParameterList" });
                        reportAllExceptFirst(useStrictDirectives, "multiple", true);
                    }
                }
            }
            const rule = {
                Program(node) {
                    const useStrictDirectives = getUseStrictDirectives(node.body);
                    if (node.sourceType === "module") {
                        mode = "module";
                    }
                    if (mode === "global") {
                        if (node.body.length > 0 && useStrictDirectives.length === 0) {
                            context.report({ node, messageId: "global" });
                        }
                        reportAllExceptFirst(useStrictDirectives, "multiple", true);
                    }
                    else {
                        reportAll(useStrictDirectives, mode, shouldFix(mode));
                    }
                },
                FunctionDeclaration: enterFunction,
                FunctionExpression: enterFunction,
                ArrowFunctionExpression: enterFunction
            };
            if (mode === "function") {
                Object.assign(rule, {
                    // Inside of class bodies are always strict mode.
                    ClassBody() {
                        classScopes.push(true);
                    },
                    "ClassBody:exit"() {
                        classScopes.pop();
                    },
                    "FunctionDeclaration:exit": exitFunctionInFunctionMode,
                    "FunctionExpression:exit": exitFunctionInFunctionMode,
                    "ArrowFunctionExpression:exit": exitFunctionInFunctionMode
                });
            }
            return rule;
        }
    };
},
/* eslint/lib/rules/switch-colon-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce spacing around colons of switch statements.
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Enforce spacing around colons of switch statements",
                recommended: false,
                url: "https://eslint.org/docs/rules/switch-colon-spacing"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        before: { type: "boolean", default: false },
                        after: { type: "boolean", default: true }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "whitespace",
            messages: {
                expectedBefore: "Expected space(s) before this colon.",
                expectedAfter: "Expected space(s) after this colon.",
                unexpectedBefore: "Unexpected space(s) before this colon.",
                unexpectedAfter: "Unexpected space(s) after this colon."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const options = context.options[0] || {};
            const beforeSpacing = options.before === true; // false by default
            const afterSpacing = options.after !== false; // true by default
            /**
             * Check whether the spacing between the given 2 tokens is valid or not.
             * @param {Token} left The left token to check.
             * @param {Token} right The right token to check.
             * @param {boolean} expected The expected spacing to check. `true` if there should be a space.
             * @returns {boolean} `true` if the spacing between the tokens is valid.
             */
            function isValidSpacing(left, right, expected) {
                return (astUtils.isClosingBraceToken(right) ||
                    !astUtils.isTokenOnSameLine(left, right) ||
                    sourceCode.isSpaceBetweenTokens(left, right) === expected);
            }
            /**
             * Check whether comments exist between the given 2 tokens.
             * @param {Token} left The left token to check.
             * @param {Token} right The right token to check.
             * @returns {boolean} `true` if comments exist between the given 2 tokens.
             */
            function commentsExistBetween(left, right) {
                return sourceCode.getFirstTokenBetween(left, right, {
                    includeComments: true,
                    filter: astUtils.isCommentToken
                }) !== null;
            }
            /**
             * Fix the spacing between the given 2 tokens.
             * @param {RuleFixer} fixer The fixer to fix.
             * @param {Token} left The left token of fix range.
             * @param {Token} right The right token of fix range.
             * @param {boolean} spacing The spacing style. `true` if there should be a space.
             * @returns {Fix|null} The fix object.
             */
            function fix(fixer, left, right, spacing) {
                if (commentsExistBetween(left, right)) {
                    return null;
                }
                if (spacing) {
                    return fixer.insertTextAfter(left, " ");
                }
                return fixer.removeRange([left.range[1], right.range[0]]);
            }
            return {
                SwitchCase(node) {
                    const colonToken = astUtils.getSwitchCaseColonToken(node, sourceCode);
                    const beforeToken = sourceCode.getTokenBefore(colonToken);
                    const afterToken = sourceCode.getTokenAfter(colonToken);
                    if (!isValidSpacing(beforeToken, colonToken, beforeSpacing)) {
                        context.report({
                            node,
                            loc: colonToken.loc,
                            messageId: beforeSpacing ? "expectedBefore" : "unexpectedBefore",
                            fix: fixer => fix(fixer, beforeToken, colonToken, beforeSpacing)
                        });
                    }
                    if (!isValidSpacing(colonToken, afterToken, afterSpacing)) {
                        context.report({
                            node,
                            loc: colonToken.loc,
                            messageId: afterSpacing ? "expectedAfter" : "unexpectedAfter",
                            fix: fixer => fix(fixer, colonToken, afterToken, afterSpacing)
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/symbol-description.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce description with the `Symbol` object
     * @author Jarek Rencz
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require symbol descriptions",
                recommended: false,
                url: "https://eslint.org/docs/rules/symbol-description"
            },
            fixable: null,
            schema: [],
            messages: {
                expected: "Expected Symbol to have a description."
            }
        },
        create(context) {
            /**
             * Reports if node does not conform the rule in case rule is set to
             * report missing description
             * @param {ASTNode} node A CallExpression node to check.
             * @returns {void}
             */
            function checkArgument(node) {
                if (node.arguments.length === 0) {
                    context.report({
                        node,
                        messageId: "expected"
                    });
                }
            }
            return {
                "Program:exit"() {
                    const scope = context.getScope();
                    const variable = astUtils.getVariableByName(scope, "Symbol");
                    if (variable && variable.defs.length === 0) {
                        variable.references.forEach(reference => {
                            const node = reference.identifier;
                            if (astUtils.isCallee(node)) {
                                checkArgument(node.parent);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/template-curly-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to enforce spacing around embedded expressions of template strings
     * @author Toru Nagashima
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow spacing around embedded expressions of template strings",
                recommended: false,
                url: "https://eslint.org/docs/rules/template-curly-spacing"
            },
            fixable: "whitespace",
            schema: [
                { enum: ["always", "never"] }
            ],
            messages: {
                expectedBefore: "Expected space(s) before '}'.",
                expectedAfter: "Expected space(s) after '${'.",
                unexpectedBefore: "Unexpected space(s) before '}'.",
                unexpectedAfter: "Unexpected space(s) after '${'."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const always = context.options[0] === "always";
            /**
             * Checks spacing before `}` of a given token.
             * @param {Token} token A token to check. This is a Template token.
             * @returns {void}
             */
            function checkSpacingBefore(token) {
                if (!token.value.startsWith("}")) {
                    return; // starts with a backtick, this is the first template element in the template literal
                }
                const prevToken = sourceCode.getTokenBefore(token, { includeComments: true }), hasSpace = sourceCode.isSpaceBetween(prevToken, token);
                if (!astUtils.isTokenOnSameLine(prevToken, token)) {
                    return;
                }
                if (always && !hasSpace) {
                    context.report({
                        loc: {
                            start: token.loc.start,
                            end: {
                                line: token.loc.start.line,
                                column: token.loc.start.column + 1
                            }
                        },
                        messageId: "expectedBefore",
                        fix: fixer => fixer.insertTextBefore(token, " ")
                    });
                }
                if (!always && hasSpace) {
                    context.report({
                        loc: {
                            start: prevToken.loc.end,
                            end: token.loc.start
                        },
                        messageId: "unexpectedBefore",
                        fix: fixer => fixer.removeRange([prevToken.range[1], token.range[0]])
                    });
                }
            }
            /**
             * Checks spacing after `${` of a given token.
             * @param {Token} token A token to check. This is a Template token.
             * @returns {void}
             */
            function checkSpacingAfter(token) {
                if (!token.value.endsWith("${")) {
                    return; // ends with a backtick, this is the last template element in the template literal
                }
                const nextToken = sourceCode.getTokenAfter(token, { includeComments: true }), hasSpace = sourceCode.isSpaceBetween(token, nextToken);
                if (!astUtils.isTokenOnSameLine(token, nextToken)) {
                    return;
                }
                if (always && !hasSpace) {
                    context.report({
                        loc: {
                            start: {
                                line: token.loc.end.line,
                                column: token.loc.end.column - 2
                            },
                            end: token.loc.end
                        },
                        messageId: "expectedAfter",
                        fix: fixer => fixer.insertTextAfter(token, " ")
                    });
                }
                if (!always && hasSpace) {
                    context.report({
                        loc: {
                            start: token.loc.end,
                            end: nextToken.loc.start
                        },
                        messageId: "unexpectedAfter",
                        fix: fixer => fixer.removeRange([token.range[1], nextToken.range[0]])
                    });
                }
            }
            return {
                TemplateElement(node) {
                    const token = sourceCode.getFirstToken(node);
                    checkSpacingBefore(token);
                    checkSpacingAfter(token);
                }
            };
        }
    };
},
/* eslint/lib/rules/template-tag-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check spacing between template tags and their literals
     * @author Jonathan Wilsson
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow spacing between template tags and their literals",
                recommended: false,
                url: "https://eslint.org/docs/rules/template-tag-spacing"
            },
            fixable: "whitespace",
            schema: [
                { enum: ["always", "never"] }
            ],
            messages: {
                unexpected: "Unexpected space between template tag and template literal.",
                missing: "Missing space between template tag and template literal."
            }
        },
        create(context) {
            const never = context.options[0] !== "always";
            const sourceCode = context.getSourceCode();
            /**
             * Check if a space is present between a template tag and its literal
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkSpacing(node) {
                const tagToken = sourceCode.getTokenBefore(node.quasi);
                const literalToken = sourceCode.getFirstToken(node.quasi);
                const hasWhitespace = sourceCode.isSpaceBetweenTokens(tagToken, literalToken);
                if (never && hasWhitespace) {
                    context.report({
                        node,
                        loc: {
                            start: tagToken.loc.end,
                            end: literalToken.loc.start
                        },
                        messageId: "unexpected",
                        fix(fixer) {
                            const comments = sourceCode.getCommentsBefore(node.quasi);
                            // Don't fix anything if there's a single line comment after the template tag
                            if (comments.some(comment => comment.type === "Line")) {
                                return null;
                            }
                            return fixer.replaceTextRange([tagToken.range[1], literalToken.range[0]], comments.reduce((text, comment) => text + sourceCode.getText(comment), ""));
                        }
                    });
                }
                else if (!never && !hasWhitespace) {
                    context.report({
                        node,
                        loc: {
                            start: node.loc.start,
                            end: literalToken.loc.start
                        },
                        messageId: "missing",
                        fix(fixer) {
                            return fixer.insertTextAfter(tagToken, " ");
                        }
                    });
                }
            }
            return {
                TaggedTemplateExpression: checkSpacing
            };
        }
    };
},
/* eslint/lib/rules/unicode-bom.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Require or disallow Unicode BOM
     * @author Andrew Johnston <https://github.com/ehjay>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow Unicode byte order mark (BOM)",
                recommended: false,
                url: "https://eslint.org/docs/rules/unicode-bom"
            },
            fixable: "whitespace",
            schema: [
                {
                    enum: ["always", "never"]
                }
            ],
            messages: {
                expected: "Expected Unicode BOM (Byte Order Mark).",
                unexpected: "Unexpected Unicode BOM (Byte Order Mark)."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program: function checkUnicodeBOM(node) {
                    const sourceCode = context.getSourceCode(), location = { column: 0, line: 1 }, requireBOM = context.options[0] || "never";
                    if (!sourceCode.hasBOM && (requireBOM === "always")) {
                        context.report({
                            node,
                            loc: location,
                            messageId: "expected",
                            fix(fixer) {
                                return fixer.insertTextBeforeRange([0, 1], "\uFEFF");
                            }
                        });
                    }
                    else if (sourceCode.hasBOM && (requireBOM === "never")) {
                        context.report({
                            node,
                            loc: location,
                            messageId: "unexpected",
                            fix(fixer) {
                                return fixer.removeRange([-1, 0]);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/use-isnan.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag comparisons to the value NaN
     * @author James Allardice
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Determines if the given node is a NaN `Identifier` node.
     * @param {ASTNode|null} node The node to check.
     * @returns {boolean} `true` if the node is 'NaN' identifier.
     */
    function isNaNIdentifier(node) {
        return Boolean(node) && (astUtils.isSpecificId(node, "NaN") ||
            astUtils.isSpecificMemberAccess(node, "Number", "NaN"));
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Require calls to `isNaN()` when checking for `NaN`",
                recommended: true,
                url: "https://eslint.org/docs/rules/use-isnan"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        enforceForSwitchCase: {
                            type: "boolean",
                            default: true
                        },
                        enforceForIndexOf: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                comparisonWithNaN: "Use the isNaN function to compare with NaN.",
                switchNaN: "'switch(NaN)' can never match a case clause. Use Number.isNaN instead of the switch.",
                caseNaN: "'case NaN' can never match. Use Number.isNaN before the switch.",
                indexOfNaN: "Array prototype method '{{ methodName }}' cannot find NaN."
            }
        },
        create(context) {
            const enforceForSwitchCase = !context.options[0] || context.options[0].enforceForSwitchCase;
            const enforceForIndexOf = context.options[0] && context.options[0].enforceForIndexOf;
            /**
             * Checks the given `BinaryExpression` node for `foo === NaN` and other comparisons.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             */
            function checkBinaryExpression(node) {
                if (/^(?:[<>]|[!=]=)=?$/u.test(node.operator) &&
                    (isNaNIdentifier(node.left) || isNaNIdentifier(node.right))) {
                    context.report({ node, messageId: "comparisonWithNaN" });
                }
            }
            /**
             * Checks the discriminant and all case clauses of the given `SwitchStatement` node for `switch(NaN)` and `case NaN:`
             * @param {ASTNode} node The node to check.
             * @returns {void}
             */
            function checkSwitchStatement(node) {
                if (isNaNIdentifier(node.discriminant)) {
                    context.report({ node, messageId: "switchNaN" });
                }
                for (const switchCase of node.cases) {
                    if (isNaNIdentifier(switchCase.test)) {
                        context.report({ node: switchCase, messageId: "caseNaN" });
                    }
                }
            }
            /**
             * Checks the given `CallExpression` node for `.indexOf(NaN)` and `.lastIndexOf(NaN)`.
             * @param {ASTNode} node The node to check.
             * @returns {void}
             */
            function checkCallExpression(node) {
                const callee = astUtils.skipChainExpression(node.callee);
                if (callee.type === "MemberExpression") {
                    const methodName = astUtils.getStaticPropertyName(callee);
                    if ((methodName === "indexOf" || methodName === "lastIndexOf") &&
                        node.arguments.length === 1 &&
                        isNaNIdentifier(node.arguments[0])) {
                        context.report({ node, messageId: "indexOfNaN", data: { methodName } });
                    }
                }
            }
            const listeners = {
                BinaryExpression: checkBinaryExpression
            };
            if (enforceForSwitchCase) {
                listeners.SwitchStatement = checkSwitchStatement;
            }
            if (enforceForIndexOf) {
                listeners.CallExpression = checkCallExpression;
            }
            return listeners;
        }
    };
},
/* eslint/lib/rules/valid-jsdoc.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Validates JSDoc comments are syntactically correct
     * @author Nicholas C. Zakas
     * @deprecated in ESLint v5.10.0
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const doctrine = require(680) /* doctrine */;
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Enforce valid JSDoc comments",
                recommended: false,
                url: "https://eslint.org/docs/rules/valid-jsdoc"
            },
            schema: [
                {
                    type: "object",
                    properties: {
                        prefer: {
                            type: "object",
                            additionalProperties: {
                                type: "string"
                            }
                        },
                        preferType: {
                            type: "object",
                            additionalProperties: {
                                type: "string"
                            }
                        },
                        requireReturn: {
                            type: "boolean",
                            default: true
                        },
                        requireParamDescription: {
                            type: "boolean",
                            default: true
                        },
                        requireReturnDescription: {
                            type: "boolean",
                            default: true
                        },
                        matchDescription: {
                            type: "string"
                        },
                        requireReturnType: {
                            type: "boolean",
                            default: true
                        },
                        requireParamType: {
                            type: "boolean",
                            default: true
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "code",
            messages: {
                unexpectedTag: "Unexpected @{{title}} tag; function has no return statement.",
                expected: "Expected JSDoc for '{{name}}' but found '{{jsdocName}}'.",
                use: "Use @{{name}} instead.",
                useType: "Use '{{expectedTypeName}}' instead of '{{currentTypeName}}'.",
                syntaxError: "JSDoc syntax error.",
                missingBrace: "JSDoc type missing brace.",
                missingParamDesc: "Missing JSDoc parameter description for '{{name}}'.",
                missingParamType: "Missing JSDoc parameter type for '{{name}}'.",
                missingReturnType: "Missing JSDoc return type.",
                missingReturnDesc: "Missing JSDoc return description.",
                missingReturn: "Missing JSDoc @{{returns}} for function.",
                missingParam: "Missing JSDoc for parameter '{{name}}'.",
                duplicateParam: "Duplicate JSDoc parameter '{{name}}'.",
                unsatisfiedDesc: "JSDoc description does not satisfy the regex pattern."
            },
            deprecated: true,
            replacedBy: []
        },
        create(context) {
            const options = context.options[0] || {}, prefer = options.prefer || {}, sourceCode = context.getSourceCode(), 
            // these both default to true, so you have to explicitly make them false
            requireReturn = options.requireReturn !== false, requireParamDescription = options.requireParamDescription !== false, requireReturnDescription = options.requireReturnDescription !== false, requireReturnType = options.requireReturnType !== false, requireParamType = options.requireParamType !== false, preferType = options.preferType || {}, checkPreferType = Object.keys(preferType).length !== 0;
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            // Using a stack to store if a function returns or not (handling nested functions)
            const fns = [];
            /**
             * Check if node type is a Class
             * @param {ASTNode} node node to check.
             * @returns {boolean} True is its a class
             * @private
             */
            function isTypeClass(node) {
                return node.type === "ClassExpression" || node.type === "ClassDeclaration";
            }
            /**
             * When parsing a new function, store it in our function stack.
             * @param {ASTNode} node A function node to check.
             * @returns {void}
             * @private
             */
            function startFunction(node) {
                fns.push({
                    returnPresent: (node.type === "ArrowFunctionExpression" && node.body.type !== "BlockStatement") ||
                        isTypeClass(node) || node.async
                });
            }
            /**
             * Indicate that return has been found in the current function.
             * @param {ASTNode} node The return node.
             * @returns {void}
             * @private
             */
            function addReturn(node) {
                const functionState = fns[fns.length - 1];
                if (functionState && node.argument !== null) {
                    functionState.returnPresent = true;
                }
            }
            /**
             * Check if return tag type is void or undefined
             * @param {Object} tag JSDoc tag
             * @returns {boolean} True if its of type void or undefined
             * @private
             */
            function isValidReturnType(tag) {
                return tag.type === null || tag.type.name === "void" || tag.type.type === "UndefinedLiteral";
            }
            /**
             * Check if type should be validated based on some exceptions
             * @param {Object} type JSDoc tag
             * @returns {boolean} True if it can be validated
             * @private
             */
            function canTypeBeValidated(type) {
                return type !== "UndefinedLiteral" && // {undefined} as there is no name property available.
                    type !== "NullLiteral" && // {null}
                    type !== "NullableLiteral" && // {?}
                    type !== "FunctionType" && // {function(a)}
                    type !== "AllLiteral"; // {*}
            }
            /**
             * Extract the current and expected type based on the input type object
             * @param {Object} type JSDoc tag
             * @returns {{currentType: Doctrine.Type, expectedTypeName: string}} The current type annotation and
             * the expected name of the annotation
             * @private
             */
            function getCurrentExpectedTypes(type) {
                let currentType;
                if (type.name) {
                    currentType = type;
                }
                else if (type.expression) {
                    currentType = type.expression;
                }
                return {
                    currentType,
                    expectedTypeName: currentType && preferType[currentType.name]
                };
            }
            /**
             * Gets the location of a JSDoc node in a file
             * @param {Token} jsdocComment The comment that this node is parsed from
             * @param {{range: number[]}} parsedJsdocNode A tag or other node which was parsed from this comment
             * @returns {{start: SourceLocation, end: SourceLocation}} The 0-based source location for the tag
             */
            function getAbsoluteRange(jsdocComment, parsedJsdocNode) {
                return {
                    start: sourceCode.getLocFromIndex(jsdocComment.range[0] + 2 + parsedJsdocNode.range[0]),
                    end: sourceCode.getLocFromIndex(jsdocComment.range[0] + 2 + parsedJsdocNode.range[1])
                };
            }
            /**
             * Validate type for a given JSDoc node
             * @param {Object} jsdocNode JSDoc node
             * @param {Object} type JSDoc tag
             * @returns {void}
             * @private
             */
            function validateType(jsdocNode, type) {
                if (!type || !canTypeBeValidated(type.type)) {
                    return;
                }
                const typesToCheck = [];
                let elements = [];
                switch (type.type) {
                    case "TypeApplication": // {Array.<String>}
                        elements = type.applications[0].type === "UnionType" ? type.applications[0].elements : type.applications;
                        typesToCheck.push(getCurrentExpectedTypes(type));
                        break;
                    case "RecordType": // {{20:String}}
                        elements = type.fields;
                        break;
                    case "UnionType": // {String|number|Test}
                    case "ArrayType": // {[String, number, Test]}
                        elements = type.elements;
                        break;
                    case "FieldType": // Array.<{count: number, votes: number}>
                        if (type.value) {
                            typesToCheck.push(getCurrentExpectedTypes(type.value));
                        }
                        break;
                    default:
                        typesToCheck.push(getCurrentExpectedTypes(type));
                }
                elements.forEach(validateType.bind(null, jsdocNode));
                typesToCheck.forEach(typeToCheck => {
                    if (typeToCheck.expectedTypeName &&
                        typeToCheck.expectedTypeName !== typeToCheck.currentType.name) {
                        context.report({
                            node: jsdocNode,
                            messageId: "useType",
                            loc: getAbsoluteRange(jsdocNode, typeToCheck.currentType),
                            data: {
                                currentTypeName: typeToCheck.currentType.name,
                                expectedTypeName: typeToCheck.expectedTypeName
                            },
                            fix(fixer) {
                                return fixer.replaceTextRange(typeToCheck.currentType.range.map(indexInComment => jsdocNode.range[0] + 2 + indexInComment), typeToCheck.expectedTypeName);
                            }
                        });
                    }
                });
            }
            /**
             * Validate the JSDoc node and output warnings if anything is wrong.
             * @param {ASTNode} node The AST node to check.
             * @returns {void}
             * @private
             */
            function checkJSDoc(node) {
                const jsdocNode = sourceCode.getJSDocComment(node), functionData = fns.pop(), paramTagsByName = Object.create(null), paramTags = [];
                let hasReturns = false, returnsTag, hasConstructor = false, isInterface = false, isOverride = false, isAbstract = false;
                // make sure only to validate JSDoc comments
                if (jsdocNode) {
                    let jsdoc;
                    try {
                        jsdoc = doctrine.parse(jsdocNode.value, {
                            strict: true,
                            unwrap: true,
                            sloppy: true,
                            range: true
                        });
                    }
                    catch (ex) {
                        if (/braces/iu.test(ex.message)) {
                            context.report({ node: jsdocNode, messageId: "missingBrace" });
                        }
                        else {
                            context.report({ node: jsdocNode, messageId: "syntaxError" });
                        }
                        return;
                    }
                    jsdoc.tags.forEach(tag => {
                        switch (tag.title.toLowerCase()) {
                            case "param":
                            case "arg":
                            case "argument":
                                paramTags.push(tag);
                                break;
                            case "return":
                            case "returns":
                                hasReturns = true;
                                returnsTag = tag;
                                break;
                            case "constructor":
                            case "class":
                                hasConstructor = true;
                                break;
                            case "override":
                            case "inheritdoc":
                                isOverride = true;
                                break;
                            case "abstract":
                            case "virtual":
                                isAbstract = true;
                                break;
                            case "interface":
                                isInterface = true;
                                break;
                            // no default
                        }
                        // check tag preferences
                        if (Object.prototype.hasOwnProperty.call(prefer, tag.title) && tag.title !== prefer[tag.title]) {
                            const entireTagRange = getAbsoluteRange(jsdocNode, tag);
                            context.report({
                                node: jsdocNode,
                                messageId: "use",
                                loc: {
                                    start: entireTagRange.start,
                                    end: {
                                        line: entireTagRange.start.line,
                                        column: entireTagRange.start.column + `@${tag.title}`.length
                                    }
                                },
                                data: { name: prefer[tag.title] },
                                fix(fixer) {
                                    return fixer.replaceTextRange([
                                        jsdocNode.range[0] + tag.range[0] + 3,
                                        jsdocNode.range[0] + tag.range[0] + tag.title.length + 3
                                    ], prefer[tag.title]);
                                }
                            });
                        }
                        // validate the types
                        if (checkPreferType && tag.type) {
                            validateType(jsdocNode, tag.type);
                        }
                    });
                    paramTags.forEach(param => {
                        if (requireParamType && !param.type) {
                            context.report({
                                node: jsdocNode,
                                messageId: "missingParamType",
                                loc: getAbsoluteRange(jsdocNode, param),
                                data: { name: param.name }
                            });
                        }
                        if (!param.description && requireParamDescription) {
                            context.report({
                                node: jsdocNode,
                                messageId: "missingParamDesc",
                                loc: getAbsoluteRange(jsdocNode, param),
                                data: { name: param.name }
                            });
                        }
                        if (paramTagsByName[param.name]) {
                            context.report({
                                node: jsdocNode,
                                messageId: "duplicateParam",
                                loc: getAbsoluteRange(jsdocNode, param),
                                data: { name: param.name }
                            });
                        }
                        else if (!param.name.includes(".")) {
                            paramTagsByName[param.name] = param;
                        }
                    });
                    if (hasReturns) {
                        if (!requireReturn && !functionData.returnPresent && (returnsTag.type === null || !isValidReturnType(returnsTag)) && !isAbstract) {
                            context.report({
                                node: jsdocNode,
                                messageId: "unexpectedTag",
                                loc: getAbsoluteRange(jsdocNode, returnsTag),
                                data: {
                                    title: returnsTag.title
                                }
                            });
                        }
                        else {
                            if (requireReturnType && !returnsTag.type) {
                                context.report({ node: jsdocNode, messageId: "missingReturnType" });
                            }
                            if (!isValidReturnType(returnsTag) && !returnsTag.description && requireReturnDescription) {
                                context.report({ node: jsdocNode, messageId: "missingReturnDesc" });
                            }
                        }
                    }
                    // check for functions missing @returns
                    if (!isOverride && !hasReturns && !hasConstructor && !isInterface &&
                        node.parent.kind !== "get" && node.parent.kind !== "constructor" &&
                        node.parent.kind !== "set" && !isTypeClass(node)) {
                        if (requireReturn || (functionData.returnPresent && !node.async)) {
                            context.report({
                                node: jsdocNode,
                                messageId: "missingReturn",
                                data: {
                                    returns: prefer.returns || "returns"
                                }
                            });
                        }
                    }
                    // check the parameters
                    const jsdocParamNames = Object.keys(paramTagsByName);
                    if (node.params) {
                        node.params.forEach((param, paramsIndex) => {
                            const bindingParam = param.type === "AssignmentPattern"
                                ? param.left
                                : param;
                            // TODO(nzakas): Figure out logical things to do with destructured, default, rest params
                            if (bindingParam.type === "Identifier") {
                                const name = bindingParam.name;
                                if (jsdocParamNames[paramsIndex] && (name !== jsdocParamNames[paramsIndex])) {
                                    context.report({
                                        node: jsdocNode,
                                        messageId: "expected",
                                        loc: getAbsoluteRange(jsdocNode, paramTagsByName[jsdocParamNames[paramsIndex]]),
                                        data: {
                                            name,
                                            jsdocName: jsdocParamNames[paramsIndex]
                                        }
                                    });
                                }
                                else if (!paramTagsByName[name] && !isOverride) {
                                    context.report({
                                        node: jsdocNode,
                                        messageId: "missingParam",
                                        data: {
                                            name
                                        }
                                    });
                                }
                            }
                        });
                    }
                    if (options.matchDescription) {
                        const regex = new RegExp(options.matchDescription, "u");
                        if (!regex.test(jsdoc.description)) {
                            context.report({ node: jsdocNode, messageId: "unsatisfiedDesc" });
                        }
                    }
                }
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                ArrowFunctionExpression: startFunction,
                FunctionExpression: startFunction,
                FunctionDeclaration: startFunction,
                ClassExpression: startFunction,
                ClassDeclaration: startFunction,
                "ArrowFunctionExpression:exit": checkJSDoc,
                "FunctionExpression:exit": checkJSDoc,
                "FunctionDeclaration:exit": checkJSDoc,
                "ClassExpression:exit": checkJSDoc,
                "ClassDeclaration:exit": checkJSDoc,
                ReturnStatement: addReturn
            };
        }
    };
},
/* doctrine/lib/doctrine.js */ function _(require, module, exports, __esModule, __esExport) {/*
     * @fileoverview Main Doctrine object
     * @author Yusuke Suzuki <utatane.tea@gmail.com>
     * @author Dan Tao <daniel.tao@gmail.com>
     * @author Andrew Eisenberg <andrew@eisenberg.as>
     */
    (function () {
        'use strict';
        var typed, utility, jsdoc, esutils, hasOwnProperty;
        esutils = require(361) /* esutils */;
        typed = require(681) /* ./typed */;
        utility = require(682) /* ./utility */;
        function sliceSource(source, index, last) {
            return source.slice(index, last);
        }
        hasOwnProperty = (function () {
            var func = Object.prototype.hasOwnProperty;
            return function hasOwnProperty(obj, name) {
                return func.call(obj, name);
            };
        }());
        function shallowCopy(obj) {
            var ret = {}, key;
            for (key in obj) {
                if (obj.hasOwnProperty(key)) {
                    ret[key] = obj[key];
                }
            }
            return ret;
        }
        function isASCIIAlphanumeric(ch) {
            return (ch >= 0x61 /* 'a' */ && ch <= 0x7A /* 'z' */) ||
                (ch >= 0x41 /* 'A' */ && ch <= 0x5A /* 'Z' */) ||
                (ch >= 0x30 /* '0' */ && ch <= 0x39 /* '9' */);
        }
        function isParamTitle(title) {
            return title === 'param' || title === 'argument' || title === 'arg';
        }
        function isReturnTitle(title) {
            return title === 'return' || title === 'returns';
        }
        function isProperty(title) {
            return title === 'property' || title === 'prop';
        }
        function isNameParameterRequired(title) {
            return isParamTitle(title) || isProperty(title) ||
                title === 'alias' || title === 'this' || title === 'mixes' || title === 'requires';
        }
        function isAllowedName(title) {
            return isNameParameterRequired(title) || title === 'const' || title === 'constant';
        }
        function isAllowedNested(title) {
            return isProperty(title) || isParamTitle(title);
        }
        function isAllowedOptional(title) {
            return isProperty(title) || isParamTitle(title);
        }
        function isTypeParameterRequired(title) {
            return isParamTitle(title) || isReturnTitle(title) ||
                title === 'define' || title === 'enum' ||
                title === 'implements' || title === 'this' ||
                title === 'type' || title === 'typedef' || isProperty(title);
        }
        // Consider deprecation instead using 'isTypeParameterRequired' and 'Rules' declaration to pick when a type is optional/required
        // This would require changes to 'parseType'
        function isAllowedType(title) {
            return isTypeParameterRequired(title) || title === 'throws' || title === 'const' || title === 'constant' ||
                title === 'namespace' || title === 'member' || title === 'var' || title === 'module' ||
                title === 'constructor' || title === 'class' || title === 'extends' || title === 'augments' ||
                title === 'public' || title === 'private' || title === 'protected';
        }
        // A regex character class that contains all whitespace except linebreak characters (\r, \n, \u2028, \u2029)
        var WHITESPACE = '[ \\f\\t\\v\\u00a0\\u1680\\u180e\\u2000-\\u200a\\u202f\\u205f\\u3000\\ufeff]';
        var STAR_MATCHER = '(' + WHITESPACE + '*(?:\\*' + WHITESPACE + '?)?)(.+|[\r\n\u2028\u2029])';
        function unwrapComment(doc) {
            // JSDoc comment is following form
            //   /**
            //    * .......
            //    */
            return doc.
                // remove /**
                replace(/^\/\*\*?/, '').
                // remove */
                replace(/\*\/$/, '').
                // remove ' * ' at the beginning of a line
                replace(new RegExp(STAR_MATCHER, 'g'), '$2').
                // remove trailing whitespace
                replace(/\s*$/, '');
        }
        /**
         * Converts an index in an "unwrapped" JSDoc comment to the corresponding index in the original "wrapped" version
         * @param {string} originalSource The original wrapped comment
         * @param {number} unwrappedIndex The index of a character in the unwrapped string
         * @returns {number} The index of the corresponding character in the original wrapped string
         */
        function convertUnwrappedCommentIndex(originalSource, unwrappedIndex) {
            var replacedSource = originalSource.replace(/^\/\*\*?/, '');
            var numSkippedChars = 0;
            var matcher = new RegExp(STAR_MATCHER, 'g');
            var match;
            while ((match = matcher.exec(replacedSource))) {
                numSkippedChars += match[1].length;
                if (match.index + match[0].length > unwrappedIndex + numSkippedChars) {
                    return unwrappedIndex + numSkippedChars + originalSource.length - replacedSource.length;
                }
            }
            return originalSource.replace(/\*\/$/, '').replace(/\s*$/, '').length;
        }
        // JSDoc Tag Parser
        (function (exports) {
            var Rules, index, lineNumber, length, source, originalSource, recoverable, sloppy, strict;
            function advance() {
                var ch = source.charCodeAt(index);
                index += 1;
                if (esutils.code.isLineTerminator(ch) && !(ch === 0x0D /* '\r' */ && source.charCodeAt(index) === 0x0A /* '\n' */)) {
                    lineNumber += 1;
                }
                return String.fromCharCode(ch);
            }
            function scanTitle() {
                var title = '';
                // waste '@'
                advance();
                while (index < length && isASCIIAlphanumeric(source.charCodeAt(index))) {
                    title += advance();
                }
                return title;
            }
            function seekContent() {
                var ch, waiting, last = index;
                waiting = false;
                while (last < length) {
                    ch = source.charCodeAt(last);
                    if (esutils.code.isLineTerminator(ch) && !(ch === 0x0D /* '\r' */ && source.charCodeAt(last + 1) === 0x0A /* '\n' */)) {
                        waiting = true;
                    }
                    else if (waiting) {
                        if (ch === 0x40 /* '@' */) {
                            break;
                        }
                        if (!esutils.code.isWhiteSpace(ch)) {
                            waiting = false;
                        }
                    }
                    last += 1;
                }
                return last;
            }
            // type expression may have nest brace, such as,
            // { { ok: string } }
            //
            // therefore, scanning type expression with balancing braces.
            function parseType(title, last, addRange) {
                var ch, brace, type, startIndex, direct = false;
                // search '{'
                while (index < last) {
                    ch = source.charCodeAt(index);
                    if (esutils.code.isWhiteSpace(ch)) {
                        advance();
                    }
                    else if (ch === 0x7B /* '{' */) {
                        advance();
                        break;
                    }
                    else {
                        // this is direct pattern
                        direct = true;
                        break;
                    }
                }
                if (direct) {
                    return null;
                }
                // type expression { is found
                brace = 1;
                type = '';
                while (index < last) {
                    ch = source.charCodeAt(index);
                    if (esutils.code.isLineTerminator(ch)) {
                        advance();
                    }
                    else {
                        if (ch === 0x7D /* '}' */) {
                            brace -= 1;
                            if (brace === 0) {
                                advance();
                                break;
                            }
                        }
                        else if (ch === 0x7B /* '{' */) {
                            brace += 1;
                        }
                        if (type === '') {
                            startIndex = index;
                        }
                        type += advance();
                    }
                }
                if (brace !== 0) {
                    // braces is not balanced
                    return utility.throwError('Braces are not balanced');
                }
                if (isAllowedOptional(title)) {
                    return typed.parseParamType(type, { startIndex: convertIndex(startIndex), range: addRange });
                }
                return typed.parseType(type, { startIndex: convertIndex(startIndex), range: addRange });
            }
            function scanIdentifier(last) {
                var identifier;
                if (!esutils.code.isIdentifierStartES5(source.charCodeAt(index)) && !source[index].match(/[0-9]/)) {
                    return null;
                }
                identifier = advance();
                while (index < last && esutils.code.isIdentifierPartES5(source.charCodeAt(index))) {
                    identifier += advance();
                }
                return identifier;
            }
            function skipWhiteSpace(last) {
                while (index < last && (esutils.code.isWhiteSpace(source.charCodeAt(index)) || esutils.code.isLineTerminator(source.charCodeAt(index)))) {
                    advance();
                }
            }
            function parseName(last, allowBrackets, allowNestedParams) {
                var name = '', useBrackets, insideString;
                skipWhiteSpace(last);
                if (index >= last) {
                    return null;
                }
                if (source.charCodeAt(index) === 0x5B /* '[' */) {
                    if (allowBrackets) {
                        useBrackets = true;
                        name = advance();
                    }
                    else {
                        return null;
                    }
                }
                name += scanIdentifier(last);
                if (allowNestedParams) {
                    if (source.charCodeAt(index) === 0x3A /* ':' */ && (name === 'module' ||
                        name === 'external' ||
                        name === 'event')) {
                        name += advance();
                        name += scanIdentifier(last);
                    }
                    if (source.charCodeAt(index) === 0x5B /* '[' */ && source.charCodeAt(index + 1) === 0x5D /* ']' */) {
                        name += advance();
                        name += advance();
                    }
                    while (source.charCodeAt(index) === 0x2E /* '.' */ ||
                        source.charCodeAt(index) === 0x2F /* '/' */ ||
                        source.charCodeAt(index) === 0x23 /* '#' */ ||
                        source.charCodeAt(index) === 0x2D /* '-' */ ||
                        source.charCodeAt(index) === 0x7E /* '~' */) {
                        name += advance();
                        name += scanIdentifier(last);
                    }
                }
                if (useBrackets) {
                    skipWhiteSpace(last);
                    // do we have a default value for this?
                    if (source.charCodeAt(index) === 0x3D /* '=' */) {
                        // consume the '='' symbol
                        name += advance();
                        skipWhiteSpace(last);
                        var ch;
                        var bracketDepth = 1;
                        // scan in the default value
                        while (index < last) {
                            ch = source.charCodeAt(index);
                            if (esutils.code.isWhiteSpace(ch)) {
                                if (!insideString) {
                                    skipWhiteSpace(last);
                                    ch = source.charCodeAt(index);
                                }
                            }
                            if (ch === 0x27 /* ''' */) {
                                if (!insideString) {
                                    insideString = '\'';
                                }
                                else {
                                    if (insideString === '\'') {
                                        insideString = '';
                                    }
                                }
                            }
                            if (ch === 0x22 /* '"' */) {
                                if (!insideString) {
                                    insideString = '"';
                                }
                                else {
                                    if (insideString === '"') {
                                        insideString = '';
                                    }
                                }
                            }
                            if (ch === 0x5B /* '[' */) {
                                bracketDepth++;
                            }
                            else if (ch === 0x5D /* ']' */ &&
                                --bracketDepth === 0) {
                                break;
                            }
                            name += advance();
                        }
                    }
                    skipWhiteSpace(last);
                    if (index >= last || source.charCodeAt(index) !== 0x5D /* ']' */) {
                        // we never found a closing ']'
                        return null;
                    }
                    // collect the last ']'
                    name += advance();
                }
                return name;
            }
            function skipToTag() {
                while (index < length && source.charCodeAt(index) !== 0x40 /* '@' */) {
                    advance();
                }
                if (index >= length) {
                    return false;
                }
                utility.assert(source.charCodeAt(index) === 0x40 /* '@' */);
                return true;
            }
            function convertIndex(rangeIndex) {
                if (source === originalSource) {
                    return rangeIndex;
                }
                return convertUnwrappedCommentIndex(originalSource, rangeIndex);
            }
            function TagParser(options, title) {
                this._options = options;
                this._title = title.toLowerCase();
                this._tag = {
                    title: title,
                    description: null
                };
                if (this._options.lineNumbers) {
                    this._tag.lineNumber = lineNumber;
                }
                this._first = index - title.length - 1;
                this._last = 0;
                // space to save special information for title parsers.
                this._extra = {};
            }
            // addError(err, ...)
            TagParser.prototype.addError = function addError(errorText) {
                var args = Array.prototype.slice.call(arguments, 1), msg = errorText.replace(/%(\d)/g, function (whole, index) {
                    utility.assert(index < args.length, 'Message reference must be in range');
                    return args[index];
                });
                if (!this._tag.errors) {
                    this._tag.errors = [];
                }
                if (strict) {
                    utility.throwError(msg);
                }
                this._tag.errors.push(msg);
                return recoverable;
            };
            TagParser.prototype.parseType = function () {
                // type required titles
                if (isTypeParameterRequired(this._title)) {
                    try {
                        this._tag.type = parseType(this._title, this._last, this._options.range);
                        if (!this._tag.type) {
                            if (!isParamTitle(this._title) && !isReturnTitle(this._title)) {
                                if (!this.addError('Missing or invalid tag type')) {
                                    return false;
                                }
                            }
                        }
                    }
                    catch (error) {
                        this._tag.type = null;
                        if (!this.addError(error.message)) {
                            return false;
                        }
                    }
                }
                else if (isAllowedType(this._title)) {
                    // optional types
                    try {
                        this._tag.type = parseType(this._title, this._last, this._options.range);
                    }
                    catch (e) {
                        //For optional types, lets drop the thrown error when we hit the end of the file
                    }
                }
                return true;
            };
            TagParser.prototype._parseNamePath = function (optional) {
                var name;
                name = parseName(this._last, sloppy && isAllowedOptional(this._title), true);
                if (!name) {
                    if (!optional) {
                        if (!this.addError('Missing or invalid tag name')) {
                            return false;
                        }
                    }
                }
                this._tag.name = name;
                return true;
            };
            TagParser.prototype.parseNamePath = function () {
                return this._parseNamePath(false);
            };
            TagParser.prototype.parseNamePathOptional = function () {
                return this._parseNamePath(true);
            };
            TagParser.prototype.parseName = function () {
                var assign, name;
                // param, property requires name
                if (isAllowedName(this._title)) {
                    this._tag.name = parseName(this._last, sloppy && isAllowedOptional(this._title), isAllowedNested(this._title));
                    if (!this._tag.name) {
                        if (!isNameParameterRequired(this._title)) {
                            return true;
                        }
                        // it's possible the name has already been parsed but interpreted as a type
                        // it's also possible this is a sloppy declaration, in which case it will be
                        // fixed at the end
                        if (isParamTitle(this._title) && this._tag.type && this._tag.type.name) {
                            this._extra.name = this._tag.type;
                            this._tag.name = this._tag.type.name;
                            this._tag.type = null;
                        }
                        else {
                            if (!this.addError('Missing or invalid tag name')) {
                                return false;
                            }
                        }
                    }
                    else {
                        name = this._tag.name;
                        if (name.charAt(0) === '[' && name.charAt(name.length - 1) === ']') {
                            // extract the default value if there is one
                            // example: @param {string} [somebody=John Doe] description
                            assign = name.substring(1, name.length - 1).split('=');
                            if (assign.length > 1) {
                                this._tag['default'] = assign.slice(1).join('=');
                            }
                            this._tag.name = assign[0];
                            // convert to an optional type
                            if (this._tag.type && this._tag.type.type !== 'OptionalType') {
                                this._tag.type = {
                                    type: 'OptionalType',
                                    expression: this._tag.type
                                };
                            }
                        }
                    }
                }
                return true;
            };
            TagParser.prototype.parseDescription = function parseDescription() {
                var description = sliceSource(source, index, this._last).trim();
                if (description) {
                    if ((/^-\s+/).test(description)) {
                        description = description.substring(2);
                    }
                    this._tag.description = description;
                }
                return true;
            };
            TagParser.prototype.parseCaption = function parseDescription() {
                var description = sliceSource(source, index, this._last).trim();
                var captionStartTag = '<caption>';
                var captionEndTag = '</caption>';
                var captionStart = description.indexOf(captionStartTag);
                var captionEnd = description.indexOf(captionEndTag);
                if (captionStart >= 0 && captionEnd >= 0) {
                    this._tag.caption = description.substring(captionStart + captionStartTag.length, captionEnd).trim();
                    this._tag.description = description.substring(captionEnd + captionEndTag.length).trim();
                }
                else {
                    this._tag.description = description;
                }
                return true;
            };
            TagParser.prototype.parseKind = function parseKind() {
                var kind, kinds;
                kinds = {
                    'class': true,
                    'constant': true,
                    'event': true,
                    'external': true,
                    'file': true,
                    'function': true,
                    'member': true,
                    'mixin': true,
                    'module': true,
                    'namespace': true,
                    'typedef': true
                };
                kind = sliceSource(source, index, this._last).trim();
                this._tag.kind = kind;
                if (!hasOwnProperty(kinds, kind)) {
                    if (!this.addError('Invalid kind name \'%0\'', kind)) {
                        return false;
                    }
                }
                return true;
            };
            TagParser.prototype.parseAccess = function parseAccess() {
                var access;
                access = sliceSource(source, index, this._last).trim();
                this._tag.access = access;
                if (access !== 'private' && access !== 'protected' && access !== 'public') {
                    if (!this.addError('Invalid access name \'%0\'', access)) {
                        return false;
                    }
                }
                return true;
            };
            TagParser.prototype.parseThis = function parseThis() {
                // this name may be a name expression (e.g. {foo.bar}),
                // an union (e.g. {foo.bar|foo.baz}) or a name path (e.g. foo.bar)
                var value = sliceSource(source, index, this._last).trim();
                if (value && value.charAt(0) === '{') {
                    var gotType = this.parseType();
                    if (gotType && this._tag.type.type === 'NameExpression' || this._tag.type.type === 'UnionType') {
                        this._tag.name = this._tag.type.name;
                        return true;
                    }
                    else {
                        return this.addError('Invalid name for this');
                    }
                }
                else {
                    return this.parseNamePath();
                }
            };
            TagParser.prototype.parseVariation = function parseVariation() {
                var variation, text;
                text = sliceSource(source, index, this._last).trim();
                variation = parseFloat(text, 10);
                this._tag.variation = variation;
                if (isNaN(variation)) {
                    if (!this.addError('Invalid variation \'%0\'', text)) {
                        return false;
                    }
                }
                return true;
            };
            TagParser.prototype.ensureEnd = function () {
                var shouldBeEmpty = sliceSource(source, index, this._last).trim();
                if (shouldBeEmpty) {
                    if (!this.addError('Unknown content \'%0\'', shouldBeEmpty)) {
                        return false;
                    }
                }
                return true;
            };
            TagParser.prototype.epilogue = function epilogue() {
                var description;
                description = this._tag.description;
                // un-fix potentially sloppy declaration
                if (isAllowedOptional(this._title) && !this._tag.type && description && description.charAt(0) === '[') {
                    this._tag.type = this._extra.name;
                    if (!this._tag.name) {
                        this._tag.name = undefined;
                    }
                    if (!sloppy) {
                        if (!this.addError('Missing or invalid tag name')) {
                            return false;
                        }
                    }
                }
                return true;
            };
            Rules = {
                // http://usejsdoc.org/tags-access.html
                'access': ['parseAccess'],
                // http://usejsdoc.org/tags-alias.html
                'alias': ['parseNamePath', 'ensureEnd'],
                // http://usejsdoc.org/tags-augments.html
                'augments': ['parseType', 'parseNamePathOptional', 'ensureEnd'],
                // http://usejsdoc.org/tags-constructor.html
                'constructor': ['parseType', 'parseNamePathOptional', 'ensureEnd'],
                // Synonym: http://usejsdoc.org/tags-constructor.html
                'class': ['parseType', 'parseNamePathOptional', 'ensureEnd'],
                // Synonym: http://usejsdoc.org/tags-extends.html
                'extends': ['parseType', 'parseNamePathOptional', 'ensureEnd'],
                // http://usejsdoc.org/tags-example.html
                'example': ['parseCaption'],
                // http://usejsdoc.org/tags-deprecated.html
                'deprecated': ['parseDescription'],
                // http://usejsdoc.org/tags-global.html
                'global': ['ensureEnd'],
                // http://usejsdoc.org/tags-inner.html
                'inner': ['ensureEnd'],
                // http://usejsdoc.org/tags-instance.html
                'instance': ['ensureEnd'],
                // http://usejsdoc.org/tags-kind.html
                'kind': ['parseKind'],
                // http://usejsdoc.org/tags-mixes.html
                'mixes': ['parseNamePath', 'ensureEnd'],
                // http://usejsdoc.org/tags-mixin.html
                'mixin': ['parseNamePathOptional', 'ensureEnd'],
                // http://usejsdoc.org/tags-member.html
                'member': ['parseType', 'parseNamePathOptional', 'ensureEnd'],
                // http://usejsdoc.org/tags-method.html
                'method': ['parseNamePathOptional', 'ensureEnd'],
                // http://usejsdoc.org/tags-module.html
                'module': ['parseType', 'parseNamePathOptional', 'ensureEnd'],
                // Synonym: http://usejsdoc.org/tags-method.html
                'func': ['parseNamePathOptional', 'ensureEnd'],
                // Synonym: http://usejsdoc.org/tags-method.html
                'function': ['parseNamePathOptional', 'ensureEnd'],
                // Synonym: http://usejsdoc.org/tags-member.html
                'var': ['parseType', 'parseNamePathOptional', 'ensureEnd'],
                // http://usejsdoc.org/tags-name.html
                'name': ['parseNamePath', 'ensureEnd'],
                // http://usejsdoc.org/tags-namespace.html
                'namespace': ['parseType', 'parseNamePathOptional', 'ensureEnd'],
                // http://usejsdoc.org/tags-private.html
                'private': ['parseType', 'parseDescription'],
                // http://usejsdoc.org/tags-protected.html
                'protected': ['parseType', 'parseDescription'],
                // http://usejsdoc.org/tags-public.html
                'public': ['parseType', 'parseDescription'],
                // http://usejsdoc.org/tags-readonly.html
                'readonly': ['ensureEnd'],
                // http://usejsdoc.org/tags-requires.html
                'requires': ['parseNamePath', 'ensureEnd'],
                // http://usejsdoc.org/tags-since.html
                'since': ['parseDescription'],
                // http://usejsdoc.org/tags-static.html
                'static': ['ensureEnd'],
                // http://usejsdoc.org/tags-summary.html
                'summary': ['parseDescription'],
                // http://usejsdoc.org/tags-this.html
                'this': ['parseThis', 'ensureEnd'],
                // http://usejsdoc.org/tags-todo.html
                'todo': ['parseDescription'],
                // http://usejsdoc.org/tags-typedef.html
                'typedef': ['parseType', 'parseNamePathOptional'],
                // http://usejsdoc.org/tags-variation.html
                'variation': ['parseVariation'],
                // http://usejsdoc.org/tags-version.html
                'version': ['parseDescription']
            };
            TagParser.prototype.parse = function parse() {
                var i, iz, sequences, method;
                // empty title
                if (!this._title) {
                    if (!this.addError('Missing or invalid title')) {
                        return null;
                    }
                }
                // Seek to content last index.
                this._last = seekContent(this._title);
                if (this._options.range) {
                    this._tag.range = [this._first, source.slice(0, this._last).replace(/\s*$/, '').length].map(convertIndex);
                }
                if (hasOwnProperty(Rules, this._title)) {
                    sequences = Rules[this._title];
                }
                else {
                    // default sequences
                    sequences = ['parseType', 'parseName', 'parseDescription', 'epilogue'];
                }
                for (i = 0, iz = sequences.length; i < iz; ++i) {
                    method = sequences[i];
                    if (!this[method]()) {
                        return null;
                    }
                }
                return this._tag;
            };
            function parseTag(options) {
                var title, parser, tag;
                // skip to tag
                if (!skipToTag()) {
                    return null;
                }
                // scan title
                title = scanTitle();
                // construct tag parser
                parser = new TagParser(options, title);
                tag = parser.parse();
                // Seek global index to end of this tag.
                while (index < parser._last) {
                    advance();
                }
                return tag;
            }
            //
            // Parse JSDoc
            //
            function scanJSDocDescription(preserveWhitespace) {
                var description = '', ch, atAllowed;
                atAllowed = true;
                while (index < length) {
                    ch = source.charCodeAt(index);
                    if (atAllowed && ch === 0x40 /* '@' */) {
                        break;
                    }
                    if (esutils.code.isLineTerminator(ch)) {
                        atAllowed = true;
                    }
                    else if (atAllowed && !esutils.code.isWhiteSpace(ch)) {
                        atAllowed = false;
                    }
                    description += advance();
                }
                return preserveWhitespace ? description : description.trim();
            }
            function parse(comment, options) {
                var tags = [], tag, description, interestingTags, i, iz;
                if (options === undefined) {
                    options = {};
                }
                if (typeof options.unwrap === 'boolean' && options.unwrap) {
                    source = unwrapComment(comment);
                }
                else {
                    source = comment;
                }
                originalSource = comment;
                // array of relevant tags
                if (options.tags) {
                    if (Array.isArray(options.tags)) {
                        interestingTags = {};
                        for (i = 0, iz = options.tags.length; i < iz; i++) {
                            if (typeof options.tags[i] === 'string') {
                                interestingTags[options.tags[i]] = true;
                            }
                            else {
                                utility.throwError('Invalid "tags" parameter: ' + options.tags);
                            }
                        }
                    }
                    else {
                        utility.throwError('Invalid "tags" parameter: ' + options.tags);
                    }
                }
                length = source.length;
                index = 0;
                lineNumber = 0;
                recoverable = options.recoverable;
                sloppy = options.sloppy;
                strict = options.strict;
                description = scanJSDocDescription(options.preserveWhitespace);
                while (true) {
                    tag = parseTag(options);
                    if (!tag) {
                        break;
                    }
                    if (!interestingTags || interestingTags.hasOwnProperty(tag.title)) {
                        tags.push(tag);
                    }
                }
                return {
                    description: description,
                    tags: tags
                };
            }
            exports.parse = parse;
        }(jsdoc = {}));
        exports.version = utility.VERSION;
        exports.parse = jsdoc.parse;
        exports.parseType = typed.parseType;
        exports.parseParamType = typed.parseParamType;
        exports.unwrapComment = unwrapComment;
        exports.Syntax = shallowCopy(typed.Syntax);
        exports.Error = utility.DoctrineError;
        exports.type = {
            Syntax: exports.Syntax,
            parseType: typed.parseType,
            parseParamType: typed.parseParamType,
            stringify: typed.stringify
        };
    }());
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* doctrine/lib/typed.js */ function _(require, module, exports, __esModule, __esExport) {/*
     * @fileoverview Type expression parser.
     * @author Yusuke Suzuki <utatane.tea@gmail.com>
     * @author Dan Tao <daniel.tao@gmail.com>
     * @author Andrew Eisenberg <andrew@eisenberg.as>
     */
    // "typed", the Type Expression Parser for doctrine.
    (function () {
        'use strict';
        var Syntax, Token, source, length, index, previous, token, value, esutils, utility, rangeOffset, addRange;
        esutils = require(361) /* esutils */;
        utility = require(682) /* ./utility */;
        Syntax = {
            NullableLiteral: 'NullableLiteral',
            AllLiteral: 'AllLiteral',
            NullLiteral: 'NullLiteral',
            UndefinedLiteral: 'UndefinedLiteral',
            VoidLiteral: 'VoidLiteral',
            UnionType: 'UnionType',
            ArrayType: 'ArrayType',
            RecordType: 'RecordType',
            FieldType: 'FieldType',
            FunctionType: 'FunctionType',
            ParameterType: 'ParameterType',
            RestType: 'RestType',
            NonNullableType: 'NonNullableType',
            OptionalType: 'OptionalType',
            NullableType: 'NullableType',
            NameExpression: 'NameExpression',
            TypeApplication: 'TypeApplication',
            StringLiteralType: 'StringLiteralType',
            NumericLiteralType: 'NumericLiteralType',
            BooleanLiteralType: 'BooleanLiteralType'
        };
        Token = {
            ILLEGAL: 0,
            DOT_LT: 1,
            REST: 2,
            LT: 3,
            GT: 4,
            LPAREN: 5,
            RPAREN: 6,
            LBRACE: 7,
            RBRACE: 8,
            LBRACK: 9,
            RBRACK: 10,
            COMMA: 11,
            COLON: 12,
            STAR: 13,
            PIPE: 14,
            QUESTION: 15,
            BANG: 16,
            EQUAL: 17,
            NAME: 18,
            STRING: 19,
            NUMBER: 20,
            EOF: 21
        };
        function isTypeName(ch) {
            return '><(){}[],:*|?!='.indexOf(String.fromCharCode(ch)) === -1 && !esutils.code.isWhiteSpace(ch) && !esutils.code.isLineTerminator(ch);
        }
        function Context(previous, index, token, value) {
            this._previous = previous;
            this._index = index;
            this._token = token;
            this._value = value;
        }
        Context.prototype.restore = function () {
            previous = this._previous;
            index = this._index;
            token = this._token;
            value = this._value;
        };
        Context.save = function () {
            return new Context(previous, index, token, value);
        };
        function maybeAddRange(node, range) {
            if (addRange) {
                node.range = [range[0] + rangeOffset, range[1] + rangeOffset];
            }
            return node;
        }
        function advance() {
            var ch = source.charAt(index);
            index += 1;
            return ch;
        }
        function scanHexEscape(prefix) {
            var i, len, ch, code = 0;
            len = (prefix === 'u') ? 4 : 2;
            for (i = 0; i < len; ++i) {
                if (index < length && esutils.code.isHexDigit(source.charCodeAt(index))) {
                    ch = advance();
                    code = code * 16 + '0123456789abcdef'.indexOf(ch.toLowerCase());
                }
                else {
                    return '';
                }
            }
            return String.fromCharCode(code);
        }
        function scanString() {
            var str = '', quote, ch, code, unescaped, restore; //TODO review removal octal = false
            quote = source.charAt(index);
            ++index;
            while (index < length) {
                ch = advance();
                if (ch === quote) {
                    quote = '';
                    break;
                }
                else if (ch === '\\') {
                    ch = advance();
                    if (!esutils.code.isLineTerminator(ch.charCodeAt(0))) {
                        switch (ch) {
                            case 'n':
                                str += '\n';
                                break;
                            case 'r':
                                str += '\r';
                                break;
                            case 't':
                                str += '\t';
                                break;
                            case 'u':
                            case 'x':
                                restore = index;
                                unescaped = scanHexEscape(ch);
                                if (unescaped) {
                                    str += unescaped;
                                }
                                else {
                                    index = restore;
                                    str += ch;
                                }
                                break;
                            case 'b':
                                str += '\b';
                                break;
                            case 'f':
                                str += '\f';
                                break;
                            case 'v':
                                str += '\v';
                                break;
                            default:
                                if (esutils.code.isOctalDigit(ch.charCodeAt(0))) {
                                    code = '01234567'.indexOf(ch);
                                    // \0 is not octal escape sequence
                                    // Deprecating unused code. TODO review removal
                                    //if (code !== 0) {
                                    //    octal = true;
                                    //}
                                    if (index < length && esutils.code.isOctalDigit(source.charCodeAt(index))) {
                                        //TODO Review Removal octal = true;
                                        code = code * 8 + '01234567'.indexOf(advance());
                                        // 3 digits are only allowed when string starts
                                        // with 0, 1, 2, 3
                                        if ('0123'.indexOf(ch) >= 0 &&
                                            index < length &&
                                            esutils.code.isOctalDigit(source.charCodeAt(index))) {
                                            code = code * 8 + '01234567'.indexOf(advance());
                                        }
                                    }
                                    str += String.fromCharCode(code);
                                }
                                else {
                                    str += ch;
                                }
                                break;
                        }
                    }
                    else {
                        if (ch === '\r' && source.charCodeAt(index) === 0x0A /* '\n' */) {
                            ++index;
                        }
                    }
                }
                else if (esutils.code.isLineTerminator(ch.charCodeAt(0))) {
                    break;
                }
                else {
                    str += ch;
                }
            }
            if (quote !== '') {
                utility.throwError('unexpected quote');
            }
            value = str;
            return Token.STRING;
        }
        function scanNumber() {
            var number, ch;
            number = '';
            ch = source.charCodeAt(index);
            if (ch !== 0x2E /* '.' */) {
                number = advance();
                ch = source.charCodeAt(index);
                if (number === '0') {
                    if (ch === 0x78 /* 'x' */ || ch === 0x58 /* 'X' */) {
                        number += advance();
                        while (index < length) {
                            ch = source.charCodeAt(index);
                            if (!esutils.code.isHexDigit(ch)) {
                                break;
                            }
                            number += advance();
                        }
                        if (number.length <= 2) {
                            // only 0x
                            utility.throwError('unexpected token');
                        }
                        if (index < length) {
                            ch = source.charCodeAt(index);
                            if (esutils.code.isIdentifierStartES5(ch)) {
                                utility.throwError('unexpected token');
                            }
                        }
                        value = parseInt(number, 16);
                        return Token.NUMBER;
                    }
                    if (esutils.code.isOctalDigit(ch)) {
                        number += advance();
                        while (index < length) {
                            ch = source.charCodeAt(index);
                            if (!esutils.code.isOctalDigit(ch)) {
                                break;
                            }
                            number += advance();
                        }
                        if (index < length) {
                            ch = source.charCodeAt(index);
                            if (esutils.code.isIdentifierStartES5(ch) || esutils.code.isDecimalDigit(ch)) {
                                utility.throwError('unexpected token');
                            }
                        }
                        value = parseInt(number, 8);
                        return Token.NUMBER;
                    }
                    if (esutils.code.isDecimalDigit(ch)) {
                        utility.throwError('unexpected token');
                    }
                }
                while (index < length) {
                    ch = source.charCodeAt(index);
                    if (!esutils.code.isDecimalDigit(ch)) {
                        break;
                    }
                    number += advance();
                }
            }
            if (ch === 0x2E /* '.' */) {
                number += advance();
                while (index < length) {
                    ch = source.charCodeAt(index);
                    if (!esutils.code.isDecimalDigit(ch)) {
                        break;
                    }
                    number += advance();
                }
            }
            if (ch === 0x65 /* 'e' */ || ch === 0x45 /* 'E' */) {
                number += advance();
                ch = source.charCodeAt(index);
                if (ch === 0x2B /* '+' */ || ch === 0x2D /* '-' */) {
                    number += advance();
                }
                ch = source.charCodeAt(index);
                if (esutils.code.isDecimalDigit(ch)) {
                    number += advance();
                    while (index < length) {
                        ch = source.charCodeAt(index);
                        if (!esutils.code.isDecimalDigit(ch)) {
                            break;
                        }
                        number += advance();
                    }
                }
                else {
                    utility.throwError('unexpected token');
                }
            }
            if (index < length) {
                ch = source.charCodeAt(index);
                if (esutils.code.isIdentifierStartES5(ch)) {
                    utility.throwError('unexpected token');
                }
            }
            value = parseFloat(number);
            return Token.NUMBER;
        }
        function scanTypeName() {
            var ch, ch2;
            value = advance();
            while (index < length && isTypeName(source.charCodeAt(index))) {
                ch = source.charCodeAt(index);
                if (ch === 0x2E /* '.' */) {
                    if ((index + 1) >= length) {
                        return Token.ILLEGAL;
                    }
                    ch2 = source.charCodeAt(index + 1);
                    if (ch2 === 0x3C /* '<' */) {
                        break;
                    }
                }
                value += advance();
            }
            return Token.NAME;
        }
        function next() {
            var ch;
            previous = index;
            while (index < length && esutils.code.isWhiteSpace(source.charCodeAt(index))) {
                advance();
            }
            if (index >= length) {
                token = Token.EOF;
                return token;
            }
            ch = source.charCodeAt(index);
            switch (ch) {
                case 0x27: /* ''' */
                case 0x22: /* '"' */
                    token = scanString();
                    return token;
                case 0x3A: /* ':' */
                    advance();
                    token = Token.COLON;
                    return token;
                case 0x2C: /* ',' */
                    advance();
                    token = Token.COMMA;
                    return token;
                case 0x28: /* '(' */
                    advance();
                    token = Token.LPAREN;
                    return token;
                case 0x29: /* ')' */
                    advance();
                    token = Token.RPAREN;
                    return token;
                case 0x5B: /* '[' */
                    advance();
                    token = Token.LBRACK;
                    return token;
                case 0x5D: /* ']' */
                    advance();
                    token = Token.RBRACK;
                    return token;
                case 0x7B: /* '{' */
                    advance();
                    token = Token.LBRACE;
                    return token;
                case 0x7D: /* '}' */
                    advance();
                    token = Token.RBRACE;
                    return token;
                case 0x2E: /* '.' */
                    if (index + 1 < length) {
                        ch = source.charCodeAt(index + 1);
                        if (ch === 0x3C /* '<' */) {
                            advance(); // '.'
                            advance(); // '<'
                            token = Token.DOT_LT;
                            return token;
                        }
                        if (ch === 0x2E /* '.' */ && index + 2 < length && source.charCodeAt(index + 2) === 0x2E /* '.' */) {
                            advance(); // '.'
                            advance(); // '.'
                            advance(); // '.'
                            token = Token.REST;
                            return token;
                        }
                        if (esutils.code.isDecimalDigit(ch)) {
                            token = scanNumber();
                            return token;
                        }
                    }
                    token = Token.ILLEGAL;
                    return token;
                case 0x3C: /* '<' */
                    advance();
                    token = Token.LT;
                    return token;
                case 0x3E: /* '>' */
                    advance();
                    token = Token.GT;
                    return token;
                case 0x2A: /* '*' */
                    advance();
                    token = Token.STAR;
                    return token;
                case 0x7C: /* '|' */
                    advance();
                    token = Token.PIPE;
                    return token;
                case 0x3F: /* '?' */
                    advance();
                    token = Token.QUESTION;
                    return token;
                case 0x21: /* '!' */
                    advance();
                    token = Token.BANG;
                    return token;
                case 0x3D: /* '=' */
                    advance();
                    token = Token.EQUAL;
                    return token;
                case 0x2D: /* '-' */
                    token = scanNumber();
                    return token;
                default:
                    if (esutils.code.isDecimalDigit(ch)) {
                        token = scanNumber();
                        return token;
                    }
                    // type string permits following case,
                    //
                    // namespace.module.MyClass
                    //
                    // this reduced 1 token TK_NAME
                    utility.assert(isTypeName(ch));
                    token = scanTypeName();
                    return token;
            }
        }
        function consume(target, text) {
            utility.assert(token === target, text || 'consumed token not matched');
            next();
        }
        function expect(target, message) {
            if (token !== target) {
                utility.throwError(message || 'unexpected token');
            }
            next();
        }
        // UnionType := '(' TypeUnionList ')'
        //
        // TypeUnionList :=
        //     <<empty>>
        //   | NonemptyTypeUnionList
        //
        // NonemptyTypeUnionList :=
        //     TypeExpression
        //   | TypeExpression '|' NonemptyTypeUnionList
        function parseUnionType() {
            var elements, startIndex = index - 1;
            consume(Token.LPAREN, 'UnionType should start with (');
            elements = [];
            if (token !== Token.RPAREN) {
                while (true) {
                    elements.push(parseTypeExpression());
                    if (token === Token.RPAREN) {
                        break;
                    }
                    expect(Token.PIPE);
                }
            }
            consume(Token.RPAREN, 'UnionType should end with )');
            return maybeAddRange({
                type: Syntax.UnionType,
                elements: elements
            }, [startIndex, previous]);
        }
        // ArrayType := '[' ElementTypeList ']'
        //
        // ElementTypeList :=
        //     <<empty>>
        //  | TypeExpression
        //  | '...' TypeExpression
        //  | TypeExpression ',' ElementTypeList
        function parseArrayType() {
            var elements, startIndex = index - 1, restStartIndex;
            consume(Token.LBRACK, 'ArrayType should start with [');
            elements = [];
            while (token !== Token.RBRACK) {
                if (token === Token.REST) {
                    restStartIndex = index - 3;
                    consume(Token.REST);
                    elements.push(maybeAddRange({
                        type: Syntax.RestType,
                        expression: parseTypeExpression()
                    }, [restStartIndex, previous]));
                    break;
                }
                else {
                    elements.push(parseTypeExpression());
                }
                if (token !== Token.RBRACK) {
                    expect(Token.COMMA);
                }
            }
            expect(Token.RBRACK);
            return maybeAddRange({
                type: Syntax.ArrayType,
                elements: elements
            }, [startIndex, previous]);
        }
        function parseFieldName() {
            var v = value;
            if (token === Token.NAME || token === Token.STRING) {
                next();
                return v;
            }
            if (token === Token.NUMBER) {
                consume(Token.NUMBER);
                return String(v);
            }
            utility.throwError('unexpected token');
        }
        // FieldType :=
        //     FieldName
        //   | FieldName ':' TypeExpression
        //
        // FieldName :=
        //     NameExpression
        //   | StringLiteral
        //   | NumberLiteral
        //   | ReservedIdentifier
        function parseFieldType() {
            var key, rangeStart = previous;
            key = parseFieldName();
            if (token === Token.COLON) {
                consume(Token.COLON);
                return maybeAddRange({
                    type: Syntax.FieldType,
                    key: key,
                    value: parseTypeExpression()
                }, [rangeStart, previous]);
            }
            return maybeAddRange({
                type: Syntax.FieldType,
                key: key,
                value: null
            }, [rangeStart, previous]);
        }
        // RecordType := '{' FieldTypeList '}'
        //
        // FieldTypeList :=
        //     <<empty>>
        //   | FieldType
        //   | FieldType ',' FieldTypeList
        function parseRecordType() {
            var fields, rangeStart = index - 1, rangeEnd;
            consume(Token.LBRACE, 'RecordType should start with {');
            fields = [];
            if (token === Token.COMMA) {
                consume(Token.COMMA);
            }
            else {
                while (token !== Token.RBRACE) {
                    fields.push(parseFieldType());
                    if (token !== Token.RBRACE) {
                        expect(Token.COMMA);
                    }
                }
            }
            rangeEnd = index;
            expect(Token.RBRACE);
            return maybeAddRange({
                type: Syntax.RecordType,
                fields: fields
            }, [rangeStart, rangeEnd]);
        }
        // NameExpression :=
        //    Identifier
        //  | TagIdentifier ':' Identifier
        //
        // Tag identifier is one of "module", "external" or "event"
        // Identifier is the same as Token.NAME, including any dots, something like
        // namespace.module.MyClass
        function parseNameExpression() {
            var name = value, rangeStart = index - name.length;
            expect(Token.NAME);
            if (token === Token.COLON && (name === 'module' ||
                name === 'external' ||
                name === 'event')) {
                consume(Token.COLON);
                name += ':' + value;
                expect(Token.NAME);
            }
            return maybeAddRange({
                type: Syntax.NameExpression,
                name: name
            }, [rangeStart, previous]);
        }
        // TypeExpressionList :=
        //     TopLevelTypeExpression
        //   | TopLevelTypeExpression ',' TypeExpressionList
        function parseTypeExpressionList() {
            var elements = [];
            elements.push(parseTop());
            while (token === Token.COMMA) {
                consume(Token.COMMA);
                elements.push(parseTop());
            }
            return elements;
        }
        // TypeName :=
        //     NameExpression
        //   | NameExpression TypeApplication
        //
        // TypeApplication :=
        //     '.<' TypeExpressionList '>'
        //   | '<' TypeExpressionList '>'   // this is extension of doctrine
        function parseTypeName() {
            var expr, applications, startIndex = index - value.length;
            expr = parseNameExpression();
            if (token === Token.DOT_LT || token === Token.LT) {
                next();
                applications = parseTypeExpressionList();
                expect(Token.GT);
                return maybeAddRange({
                    type: Syntax.TypeApplication,
                    expression: expr,
                    applications: applications
                }, [startIndex, previous]);
            }
            return expr;
        }
        // ResultType :=
        //     <<empty>>
        //   | ':' void
        //   | ':' TypeExpression
        //
        // BNF is above
        // but, we remove <<empty>> pattern, so token is always TypeToken::COLON
        function parseResultType() {
            consume(Token.COLON, 'ResultType should start with :');
            if (token === Token.NAME && value === 'void') {
                consume(Token.NAME);
                return {
                    type: Syntax.VoidLiteral
                };
            }
            return parseTypeExpression();
        }
        // ParametersType :=
        //     RestParameterType
        //   | NonRestParametersType
        //   | NonRestParametersType ',' RestParameterType
        //
        // RestParameterType :=
        //     '...'
        //     '...' Identifier
        //
        // NonRestParametersType :=
        //     ParameterType ',' NonRestParametersType
        //   | ParameterType
        //   | OptionalParametersType
        //
        // OptionalParametersType :=
        //     OptionalParameterType
        //   | OptionalParameterType, OptionalParametersType
        //
        // OptionalParameterType := ParameterType=
        //
        // ParameterType := TypeExpression | Identifier ':' TypeExpression
        //
        // Identifier is "new" or "this"
        function parseParametersType() {
            var params = [], optionalSequence = false, expr, rest = false, startIndex, restStartIndex = index - 3, nameStartIndex;
            while (token !== Token.RPAREN) {
                if (token === Token.REST) {
                    // RestParameterType
                    consume(Token.REST);
                    rest = true;
                }
                startIndex = previous;
                expr = parseTypeExpression();
                if (expr.type === Syntax.NameExpression && token === Token.COLON) {
                    nameStartIndex = previous - expr.name.length;
                    // Identifier ':' TypeExpression
                    consume(Token.COLON);
                    expr = maybeAddRange({
                        type: Syntax.ParameterType,
                        name: expr.name,
                        expression: parseTypeExpression()
                    }, [nameStartIndex, previous]);
                }
                if (token === Token.EQUAL) {
                    consume(Token.EQUAL);
                    expr = maybeAddRange({
                        type: Syntax.OptionalType,
                        expression: expr
                    }, [startIndex, previous]);
                    optionalSequence = true;
                }
                else {
                    if (optionalSequence) {
                        utility.throwError('unexpected token');
                    }
                }
                if (rest) {
                    expr = maybeAddRange({
                        type: Syntax.RestType,
                        expression: expr
                    }, [restStartIndex, previous]);
                }
                params.push(expr);
                if (token !== Token.RPAREN) {
                    expect(Token.COMMA);
                }
            }
            return params;
        }
        // FunctionType := 'function' FunctionSignatureType
        //
        // FunctionSignatureType :=
        //   | TypeParameters '(' ')' ResultType
        //   | TypeParameters '(' ParametersType ')' ResultType
        //   | TypeParameters '(' 'this' ':' TypeName ')' ResultType
        //   | TypeParameters '(' 'this' ':' TypeName ',' ParametersType ')' ResultType
        function parseFunctionType() {
            var isNew, thisBinding, params, result, fnType, startIndex = index - value.length;
            utility.assert(token === Token.NAME && value === 'function', 'FunctionType should start with \'function\'');
            consume(Token.NAME);
            // Google Closure Compiler is not implementing TypeParameters.
            // So we do not. if we don't get '(', we see it as error.
            expect(Token.LPAREN);
            isNew = false;
            params = [];
            thisBinding = null;
            if (token !== Token.RPAREN) {
                // ParametersType or 'this'
                if (token === Token.NAME &&
                    (value === 'this' || value === 'new')) {
                    // 'this' or 'new'
                    // 'new' is Closure Compiler extension
                    isNew = value === 'new';
                    consume(Token.NAME);
                    expect(Token.COLON);
                    thisBinding = parseTypeName();
                    if (token === Token.COMMA) {
                        consume(Token.COMMA);
                        params = parseParametersType();
                    }
                }
                else {
                    params = parseParametersType();
                }
            }
            expect(Token.RPAREN);
            result = null;
            if (token === Token.COLON) {
                result = parseResultType();
            }
            fnType = maybeAddRange({
                type: Syntax.FunctionType,
                params: params,
                result: result
            }, [startIndex, previous]);
            if (thisBinding) {
                // avoid adding null 'new' and 'this' properties
                fnType['this'] = thisBinding;
                if (isNew) {
                    fnType['new'] = true;
                }
            }
            return fnType;
        }
        // BasicTypeExpression :=
        //     '*'
        //   | 'null'
        //   | 'undefined'
        //   | TypeName
        //   | FunctionType
        //   | UnionType
        //   | RecordType
        //   | ArrayType
        function parseBasicTypeExpression() {
            var context, startIndex;
            switch (token) {
                case Token.STAR:
                    consume(Token.STAR);
                    return maybeAddRange({
                        type: Syntax.AllLiteral
                    }, [previous - 1, previous]);
                case Token.LPAREN:
                    return parseUnionType();
                case Token.LBRACK:
                    return parseArrayType();
                case Token.LBRACE:
                    return parseRecordType();
                case Token.NAME:
                    startIndex = index - value.length;
                    if (value === 'null') {
                        consume(Token.NAME);
                        return maybeAddRange({
                            type: Syntax.NullLiteral
                        }, [startIndex, previous]);
                    }
                    if (value === 'undefined') {
                        consume(Token.NAME);
                        return maybeAddRange({
                            type: Syntax.UndefinedLiteral
                        }, [startIndex, previous]);
                    }
                    if (value === 'true' || value === 'false') {
                        consume(Token.NAME);
                        return maybeAddRange({
                            type: Syntax.BooleanLiteralType,
                            value: value === 'true'
                        }, [startIndex, previous]);
                    }
                    context = Context.save();
                    if (value === 'function') {
                        try {
                            return parseFunctionType();
                        }
                        catch (e) {
                            context.restore();
                        }
                    }
                    return parseTypeName();
                case Token.STRING:
                    next();
                    return maybeAddRange({
                        type: Syntax.StringLiteralType,
                        value: value
                    }, [previous - value.length - 2, previous]);
                case Token.NUMBER:
                    next();
                    return maybeAddRange({
                        type: Syntax.NumericLiteralType,
                        value: value
                    }, [previous - String(value).length, previous]);
                default:
                    utility.throwError('unexpected token');
            }
        }
        // TypeExpression :=
        //     BasicTypeExpression
        //   | '?' BasicTypeExpression
        //   | '!' BasicTypeExpression
        //   | BasicTypeExpression '?'
        //   | BasicTypeExpression '!'
        //   | '?'
        //   | BasicTypeExpression '[]'
        function parseTypeExpression() {
            var expr, rangeStart;
            if (token === Token.QUESTION) {
                rangeStart = index - 1;
                consume(Token.QUESTION);
                if (token === Token.COMMA || token === Token.EQUAL || token === Token.RBRACE ||
                    token === Token.RPAREN || token === Token.PIPE || token === Token.EOF ||
                    token === Token.RBRACK || token === Token.GT) {
                    return maybeAddRange({
                        type: Syntax.NullableLiteral
                    }, [rangeStart, previous]);
                }
                return maybeAddRange({
                    type: Syntax.NullableType,
                    expression: parseBasicTypeExpression(),
                    prefix: true
                }, [rangeStart, previous]);
            }
            else if (token === Token.BANG) {
                rangeStart = index - 1;
                consume(Token.BANG);
                return maybeAddRange({
                    type: Syntax.NonNullableType,
                    expression: parseBasicTypeExpression(),
                    prefix: true
                }, [rangeStart, previous]);
            }
            else {
                rangeStart = previous;
            }
            expr = parseBasicTypeExpression();
            if (token === Token.BANG) {
                consume(Token.BANG);
                return maybeAddRange({
                    type: Syntax.NonNullableType,
                    expression: expr,
                    prefix: false
                }, [rangeStart, previous]);
            }
            if (token === Token.QUESTION) {
                consume(Token.QUESTION);
                return maybeAddRange({
                    type: Syntax.NullableType,
                    expression: expr,
                    prefix: false
                }, [rangeStart, previous]);
            }
            if (token === Token.LBRACK) {
                consume(Token.LBRACK);
                expect(Token.RBRACK, 'expected an array-style type declaration (' + value + '[])');
                return maybeAddRange({
                    type: Syntax.TypeApplication,
                    expression: maybeAddRange({
                        type: Syntax.NameExpression,
                        name: 'Array'
                    }, [rangeStart, previous]),
                    applications: [expr]
                }, [rangeStart, previous]);
            }
            return expr;
        }
        // TopLevelTypeExpression :=
        //      TypeExpression
        //    | TypeUnionList
        //
        // This rule is Google Closure Compiler extension, not ES4
        // like,
        //   { number | string }
        // If strict to ES4, we should write it as
        //   { (number|string) }
        function parseTop() {
            var expr, elements;
            expr = parseTypeExpression();
            if (token !== Token.PIPE) {
                return expr;
            }
            elements = [expr];
            consume(Token.PIPE);
            while (true) {
                elements.push(parseTypeExpression());
                if (token !== Token.PIPE) {
                    break;
                }
                consume(Token.PIPE);
            }
            return maybeAddRange({
                type: Syntax.UnionType,
                elements: elements
            }, [0, index]);
        }
        function parseTopParamType() {
            var expr;
            if (token === Token.REST) {
                consume(Token.REST);
                return maybeAddRange({
                    type: Syntax.RestType,
                    expression: parseTop()
                }, [0, index]);
            }
            expr = parseTop();
            if (token === Token.EQUAL) {
                consume(Token.EQUAL);
                return maybeAddRange({
                    type: Syntax.OptionalType,
                    expression: expr
                }, [0, index]);
            }
            return expr;
        }
        function parseType(src, opt) {
            var expr;
            source = src;
            length = source.length;
            index = 0;
            previous = 0;
            addRange = opt && opt.range;
            rangeOffset = opt && opt.startIndex || 0;
            next();
            expr = parseTop();
            if (opt && opt.midstream) {
                return {
                    expression: expr,
                    index: previous
                };
            }
            if (token !== Token.EOF) {
                utility.throwError('not reach to EOF');
            }
            return expr;
        }
        function parseParamType(src, opt) {
            var expr;
            source = src;
            length = source.length;
            index = 0;
            previous = 0;
            addRange = opt && opt.range;
            rangeOffset = opt && opt.startIndex || 0;
            next();
            expr = parseTopParamType();
            if (opt && opt.midstream) {
                return {
                    expression: expr,
                    index: previous
                };
            }
            if (token !== Token.EOF) {
                utility.throwError('not reach to EOF');
            }
            return expr;
        }
        function stringifyImpl(node, compact, topLevel) {
            var result, i, iz;
            switch (node.type) {
                case Syntax.NullableLiteral:
                    result = '?';
                    break;
                case Syntax.AllLiteral:
                    result = '*';
                    break;
                case Syntax.NullLiteral:
                    result = 'null';
                    break;
                case Syntax.UndefinedLiteral:
                    result = 'undefined';
                    break;
                case Syntax.VoidLiteral:
                    result = 'void';
                    break;
                case Syntax.UnionType:
                    if (!topLevel) {
                        result = '(';
                    }
                    else {
                        result = '';
                    }
                    for (i = 0, iz = node.elements.length; i < iz; ++i) {
                        result += stringifyImpl(node.elements[i], compact);
                        if ((i + 1) !== iz) {
                            result += compact ? '|' : ' | ';
                        }
                    }
                    if (!topLevel) {
                        result += ')';
                    }
                    break;
                case Syntax.ArrayType:
                    result = '[';
                    for (i = 0, iz = node.elements.length; i < iz; ++i) {
                        result += stringifyImpl(node.elements[i], compact);
                        if ((i + 1) !== iz) {
                            result += compact ? ',' : ', ';
                        }
                    }
                    result += ']';
                    break;
                case Syntax.RecordType:
                    result = '{';
                    for (i = 0, iz = node.fields.length; i < iz; ++i) {
                        result += stringifyImpl(node.fields[i], compact);
                        if ((i + 1) !== iz) {
                            result += compact ? ',' : ', ';
                        }
                    }
                    result += '}';
                    break;
                case Syntax.FieldType:
                    if (node.value) {
                        result = node.key + (compact ? ':' : ': ') + stringifyImpl(node.value, compact);
                    }
                    else {
                        result = node.key;
                    }
                    break;
                case Syntax.FunctionType:
                    result = compact ? 'function(' : 'function (';
                    if (node['this']) {
                        if (node['new']) {
                            result += (compact ? 'new:' : 'new: ');
                        }
                        else {
                            result += (compact ? 'this:' : 'this: ');
                        }
                        result += stringifyImpl(node['this'], compact);
                        if (node.params.length !== 0) {
                            result += compact ? ',' : ', ';
                        }
                    }
                    for (i = 0, iz = node.params.length; i < iz; ++i) {
                        result += stringifyImpl(node.params[i], compact);
                        if ((i + 1) !== iz) {
                            result += compact ? ',' : ', ';
                        }
                    }
                    result += ')';
                    if (node.result) {
                        result += (compact ? ':' : ': ') + stringifyImpl(node.result, compact);
                    }
                    break;
                case Syntax.ParameterType:
                    result = node.name + (compact ? ':' : ': ') + stringifyImpl(node.expression, compact);
                    break;
                case Syntax.RestType:
                    result = '...';
                    if (node.expression) {
                        result += stringifyImpl(node.expression, compact);
                    }
                    break;
                case Syntax.NonNullableType:
                    if (node.prefix) {
                        result = '!' + stringifyImpl(node.expression, compact);
                    }
                    else {
                        result = stringifyImpl(node.expression, compact) + '!';
                    }
                    break;
                case Syntax.OptionalType:
                    result = stringifyImpl(node.expression, compact) + '=';
                    break;
                case Syntax.NullableType:
                    if (node.prefix) {
                        result = '?' + stringifyImpl(node.expression, compact);
                    }
                    else {
                        result = stringifyImpl(node.expression, compact) + '?';
                    }
                    break;
                case Syntax.NameExpression:
                    result = node.name;
                    break;
                case Syntax.TypeApplication:
                    result = stringifyImpl(node.expression, compact) + '.<';
                    for (i = 0, iz = node.applications.length; i < iz; ++i) {
                        result += stringifyImpl(node.applications[i], compact);
                        if ((i + 1) !== iz) {
                            result += compact ? ',' : ', ';
                        }
                    }
                    result += '>';
                    break;
                case Syntax.StringLiteralType:
                    result = '"' + node.value + '"';
                    break;
                case Syntax.NumericLiteralType:
                    result = String(node.value);
                    break;
                case Syntax.BooleanLiteralType:
                    result = String(node.value);
                    break;
                default:
                    utility.throwError('Unknown type ' + node.type);
            }
            return result;
        }
        function stringify(node, options) {
            if (options == null) {
                options = {};
            }
            return stringifyImpl(node, options.compact, options.topLevel);
        }
        exports.parseType = parseType;
        exports.parseParamType = parseParamType;
        exports.stringify = stringify;
        exports.Syntax = Syntax;
    }());
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* doctrine/lib/utility.js */ function _(require, module, exports, __esModule, __esExport) {/*
     * @fileoverview Utilities for Doctrine
     * @author Yusuke Suzuki <utatane.tea@gmail.com>
     */
    (function () {
        'use strict';
        var VERSION;
        VERSION = require(683) /* ../package.json */.version;
        exports.VERSION = VERSION;
        function DoctrineError(message) {
            this.name = 'DoctrineError';
            this.message = message;
        }
        DoctrineError.prototype = (function () {
            var Middle = function () { };
            Middle.prototype = Error.prototype;
            return new Middle();
        }());
        DoctrineError.prototype.constructor = DoctrineError;
        exports.DoctrineError = DoctrineError;
        function throwError(message) {
            throw new DoctrineError(message);
        }
        exports.throwError = throwError;
        exports.assert = require('assert');
    }());
    /* vim: set sw=4 ts=4 et tw=80 : */
},
/* doctrine/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "doctrine",
        "description": "JSDoc parser",
        "homepage": "https://github.com/eslint/doctrine",
        "main": "lib/doctrine.js",
        "version": "3.0.0",
        "engines": {
            "node": ">=6.0.0"
        },
        "directories": {
            "lib": "./lib"
        },
        "files": [
            "lib"
        ],
        "maintainers": [
            {
                "name": "Nicholas C. Zakas",
                "email": "nicholas+npm@nczconsulting.com",
                "web": "https://www.nczonline.net"
            },
            {
                "name": "Yusuke Suzuki",
                "email": "utatane.tea@gmail.com",
                "web": "https://github.com/Constellation"
            }
        ],
        "repository": "eslint/doctrine",
        "devDependencies": {
            "coveralls": "^3.0.1",
            "dateformat": "^1.0.11",
            "eslint": "^1.10.3",
            "eslint-release": "^1.0.0",
            "linefix": "^0.1.1",
            "mocha": "^3.4.2",
            "npm-license": "^0.3.1",
            "nyc": "^10.3.2",
            "semver": "^5.0.3",
            "shelljs": "^0.5.3",
            "shelljs-nodecli": "^0.1.1",
            "should": "^5.0.1"
        },
        "license": "Apache-2.0",
        "scripts": {
            "pretest": "npm run lint",
            "test": "nyc mocha",
            "coveralls": "nyc report --reporter=text-lcov | coveralls",
            "lint": "eslint lib/",
            "generate-release": "eslint-generate-release",
            "generate-alpharelease": "eslint-generate-prerelease alpha",
            "generate-betarelease": "eslint-generate-prerelease beta",
            "generate-rcrelease": "eslint-generate-prerelease rc",
            "publish-release": "eslint-publish-release"
        },
        "dependencies": {
            "esutils": "^2.0.2"
        }
    };
    module.exports = json;
},
/* eslint/lib/rules/valid-typeof.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Ensures that the results of typeof are compared against a valid string
     * @author Ian Christian Myers
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "problem",
            docs: {
                description: "Enforce comparing `typeof` expressions against valid strings",
                recommended: true,
                url: "https://eslint.org/docs/rules/valid-typeof"
            },
            hasSuggestions: true,
            schema: [
                {
                    type: "object",
                    properties: {
                        requireStringLiterals: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            messages: {
                invalidValue: "Invalid typeof comparison value.",
                notString: "Typeof comparisons should be to string literals.",
                suggestString: 'Use `"{{type}}"` instead of `{{type}}`.'
            }
        },
        create(context) {
            const VALID_TYPES = new Set(["symbol", "undefined", "object", "boolean", "number", "string", "function", "bigint"]), OPERATORS = new Set(["==", "===", "!=", "!=="]);
            const requireStringLiterals = context.options[0] && context.options[0].requireStringLiterals;
            let globalScope;
            /**
             * Checks whether the given node represents a reference to a global variable that is not declared in the source code.
             * These identifiers will be allowed, as it is assumed that user has no control over the names of external global variables.
             * @param {ASTNode} node `Identifier` node to check.
             * @returns {boolean} `true` if the node is a reference to a global variable.
             */
            function isReferenceToGlobalVariable(node) {
                const variable = globalScope.set.get(node.name);
                return variable && variable.defs.length === 0 &&
                    variable.references.some(ref => ref.identifier === node);
            }
            /**
             * Determines whether a node is a typeof expression.
             * @param {ASTNode} node The node
             * @returns {boolean} `true` if the node is a typeof expression
             */
            function isTypeofExpression(node) {
                return node.type === "UnaryExpression" && node.operator === "typeof";
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                Program() {
                    globalScope = context.getScope();
                },
                UnaryExpression(node) {
                    if (isTypeofExpression(node)) {
                        const parent = context.getAncestors().pop();
                        if (parent.type === "BinaryExpression" && OPERATORS.has(parent.operator)) {
                            const sibling = parent.left === node ? parent.right : parent.left;
                            if (sibling.type === "Literal" || sibling.type === "TemplateLiteral" && !sibling.expressions.length) {
                                const value = sibling.type === "Literal" ? sibling.value : sibling.quasis[0].value.cooked;
                                if (!VALID_TYPES.has(value)) {
                                    context.report({ node: sibling, messageId: "invalidValue" });
                                }
                            }
                            else if (sibling.type === "Identifier" && sibling.name === "undefined" && isReferenceToGlobalVariable(sibling)) {
                                context.report({
                                    node: sibling,
                                    messageId: requireStringLiterals ? "notString" : "invalidValue",
                                    suggest: [
                                        {
                                            messageId: "suggestString",
                                            data: { type: "undefined" },
                                            fix(fixer) {
                                                return fixer.replaceText(sibling, '"undefined"');
                                            }
                                        }
                                    ]
                                });
                            }
                            else if (requireStringLiterals && !isTypeofExpression(sibling)) {
                                context.report({ node: sibling, messageId: "notString" });
                            }
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/vars-on-top.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to enforce var declarations are only at the top of a function.
     * @author Danny Fritz
     * @author Gyandeep Singh
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: "Require `var` declarations be placed at the top of their containing scope",
                recommended: false,
                url: "https://eslint.org/docs/rules/vars-on-top"
            },
            schema: [],
            messages: {
                top: "All 'var' declarations must be at the top of the function scope."
            }
        },
        create(context) {
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Has AST suggesting a directive.
             * @param {ASTNode} node any node
             * @returns {boolean} whether the given node structurally represents a directive
             */
            function looksLikeDirective(node) {
                return node.type === "ExpressionStatement" &&
                    node.expression.type === "Literal" && typeof node.expression.value === "string";
            }
            /**
             * Check to see if its a ES6 import declaration
             * @param {ASTNode} node any node
             * @returns {boolean} whether the given node represents a import declaration
             */
            function looksLikeImport(node) {
                return node.type === "ImportDeclaration" || node.type === "ImportSpecifier" ||
                    node.type === "ImportDefaultSpecifier" || node.type === "ImportNamespaceSpecifier";
            }
            /**
             * Checks whether a given node is a variable declaration or not.
             * @param {ASTNode} node any node
             * @returns {boolean} `true` if the node is a variable declaration.
             */
            function isVariableDeclaration(node) {
                return (node.type === "VariableDeclaration" ||
                    (node.type === "ExportNamedDeclaration" &&
                        node.declaration &&
                        node.declaration.type === "VariableDeclaration"));
            }
            /**
             * Checks whether this variable is on top of the block body
             * @param {ASTNode} node The node to check
             * @param {ASTNode[]} statements collection of ASTNodes for the parent node block
             * @returns {boolean} True if var is on top otherwise false
             */
            function isVarOnTop(node, statements) {
                const l = statements.length;
                let i = 0;
                // Skip over directives and imports. Static blocks don't have either.
                if (node.parent.type !== "StaticBlock") {
                    for (; i < l; ++i) {
                        if (!looksLikeDirective(statements[i]) && !looksLikeImport(statements[i])) {
                            break;
                        }
                    }
                }
                for (; i < l; ++i) {
                    if (!isVariableDeclaration(statements[i])) {
                        return false;
                    }
                    if (statements[i] === node) {
                        return true;
                    }
                }
                return false;
            }
            /**
             * Checks whether variable is on top at the global level
             * @param {ASTNode} node The node to check
             * @param {ASTNode} parent Parent of the node
             * @returns {void}
             */
            function globalVarCheck(node, parent) {
                if (!isVarOnTop(node, parent.body)) {
                    context.report({ node, messageId: "top" });
                }
            }
            /**
             * Checks whether variable is on top at functional block scope level
             * @param {ASTNode} node The node to check
             * @returns {void}
             */
            function blockScopeVarCheck(node) {
                const { parent } = node;
                if (parent.type === "BlockStatement" &&
                    /Function/u.test(parent.parent.type) &&
                    isVarOnTop(node, parent.body)) {
                    return;
                }
                if (parent.type === "StaticBlock" &&
                    isVarOnTop(node, parent.body)) {
                    return;
                }
                context.report({ node, messageId: "top" });
            }
            //--------------------------------------------------------------------------
            // Public API
            //--------------------------------------------------------------------------
            return {
                "VariableDeclaration[kind='var']"(node) {
                    if (node.parent.type === "ExportNamedDeclaration") {
                        globalVarCheck(node.parent, node.parent.parent);
                    }
                    else if (node.parent.type === "Program") {
                        globalVarCheck(node, node.parent);
                    }
                    else {
                        blockScopeVarCheck(node);
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/wrap-iife.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when IIFE is not wrapped in parens
     * @author Ilya Volodin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    const eslintUtils = require(316) /* @eslint-community/eslint-utils */;
    //----------------------------------------------------------------------
    // Helpers
    //----------------------------------------------------------------------
    /**
     * Check if the given node is callee of a `NewExpression` node
     * @param {ASTNode} node node to check
     * @returns {boolean} True if the node is callee of a `NewExpression` node
     * @private
     */
    function isCalleeOfNewExpression(node) {
        const maybeCallee = node.parent.type === "ChainExpression"
            ? node.parent
            : node;
        return (maybeCallee.parent.type === "NewExpression" &&
            maybeCallee.parent.callee === maybeCallee);
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require parentheses around immediate `function` invocations",
                recommended: false,
                url: "https://eslint.org/docs/rules/wrap-iife"
            },
            schema: [
                {
                    enum: ["outside", "inside", "any"]
                },
                {
                    type: "object",
                    properties: {
                        functionPrototypeMethods: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "code",
            messages: {
                wrapInvocation: "Wrap an immediate function invocation in parentheses.",
                wrapExpression: "Wrap only the function expression in parens.",
                moveInvocation: "Move the invocation into the parens that contain the function."
            }
        },
        create(context) {
            const style = context.options[0] || "outside";
            const includeFunctionPrototypeMethods = context.options[1] && context.options[1].functionPrototypeMethods;
            const sourceCode = context.getSourceCode();
            /**
             * Check if the node is wrapped in any (). All parens count: grouping parens and parens for constructs such as if()
             * @param {ASTNode} node node to evaluate
             * @returns {boolean} True if it is wrapped in any parens
             * @private
             */
            function isWrappedInAnyParens(node) {
                return astUtils.isParenthesised(sourceCode, node);
            }
            /**
             * Check if the node is wrapped in grouping (). Parens for constructs such as if() don't count
             * @param {ASTNode} node node to evaluate
             * @returns {boolean} True if it is wrapped in grouping parens
             * @private
             */
            function isWrappedInGroupingParens(node) {
                return eslintUtils.isParenthesized(1, node, sourceCode);
            }
            /**
             * Get the function node from an IIFE
             * @param {ASTNode} node node to evaluate
             * @returns {ASTNode} node that is the function expression of the given IIFE, or null if none exist
             */
            function getFunctionNodeFromIIFE(node) {
                const callee = astUtils.skipChainExpression(node.callee);
                if (callee.type === "FunctionExpression") {
                    return callee;
                }
                if (includeFunctionPrototypeMethods &&
                    callee.type === "MemberExpression" &&
                    callee.object.type === "FunctionExpression" &&
                    (astUtils.getStaticPropertyName(callee) === "call" || astUtils.getStaticPropertyName(callee) === "apply")) {
                    return callee.object;
                }
                return null;
            }
            return {
                CallExpression(node) {
                    const innerNode = getFunctionNodeFromIIFE(node);
                    if (!innerNode) {
                        return;
                    }
                    const isCallExpressionWrapped = isWrappedInAnyParens(node), isFunctionExpressionWrapped = isWrappedInAnyParens(innerNode);
                    if (!isCallExpressionWrapped && !isFunctionExpressionWrapped) {
                        context.report({
                            node,
                            messageId: "wrapInvocation",
                            fix(fixer) {
                                const nodeToSurround = style === "inside" ? innerNode : node;
                                return fixer.replaceText(nodeToSurround, `(${sourceCode.getText(nodeToSurround)})`);
                            }
                        });
                    }
                    else if (style === "inside" && !isFunctionExpressionWrapped) {
                        context.report({
                            node,
                            messageId: "wrapExpression",
                            fix(fixer) {
                                // The outer call expression will always be wrapped at this point.
                                if (isWrappedInGroupingParens(node) && !isCalleeOfNewExpression(node)) {
                                    /*
                                     * Parenthesize the function expression and remove unnecessary grouping parens around the call expression.
                                     * Replace the range between the end of the function expression and the end of the call expression.
                                     * for example, in `(function(foo) {}(bar))`, the range `(bar))` should get replaced with `)(bar)`.
                                     */
                                    const parenAfter = sourceCode.getTokenAfter(node);
                                    return fixer.replaceTextRange([innerNode.range[1], parenAfter.range[1]], `)${sourceCode.getText().slice(innerNode.range[1], parenAfter.range[0])}`);
                                }
                                /*
                                 * Call expression is wrapped in mandatory parens such as if(), or in necessary grouping parens.
                                 * These parens cannot be removed, so just parenthesize the function expression.
                                 */
                                return fixer.replaceText(innerNode, `(${sourceCode.getText(innerNode)})`);
                            }
                        });
                    }
                    else if (style === "outside" && !isCallExpressionWrapped) {
                        context.report({
                            node,
                            messageId: "moveInvocation",
                            fix(fixer) {
                                /*
                                 * The inner function expression will always be wrapped at this point.
                                 * It's only necessary to replace the range between the end of the function expression
                                 * and the call expression. For example, in `(function(foo) {})(bar)`, the range `)(bar)`
                                 * should get replaced with `(bar))`.
                                 */
                                const parenAfter = sourceCode.getTokenAfter(innerNode);
                                return fixer.replaceTextRange([parenAfter.range[0], node.range[1]], `${sourceCode.getText().slice(parenAfter.range[1], node.range[1])})`);
                            }
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/wrap-regex.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to flag when regex literals are not wrapped in parens
     * @author Matt DuVall <http://www.mattduvall.com>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require parenthesis around regex literals",
                recommended: false,
                url: "https://eslint.org/docs/rules/wrap-regex"
            },
            schema: [],
            fixable: "code",
            messages: {
                requireParens: "Wrap the regexp literal in parens to disambiguate the slash."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                Literal(node) {
                    const token = sourceCode.getFirstToken(node), nodeType = token.type;
                    if (nodeType === "RegularExpression") {
                        const beforeToken = sourceCode.getTokenBefore(node);
                        const afterToken = sourceCode.getTokenAfter(node);
                        const ancestors = context.getAncestors();
                        const grandparent = ancestors[ancestors.length - 1];
                        if (grandparent.type === "MemberExpression" && grandparent.object === node &&
                            !(beforeToken && beforeToken.value === "(" && afterToken && afterToken.value === ")")) {
                            context.report({
                                node,
                                messageId: "requireParens",
                                fix: fixer => fixer.replaceText(node, `(${sourceCode.getText(node)})`)
                            });
                        }
                    }
                }
            };
        }
    };
},
/* eslint/lib/rules/yield-star-spacing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule to check the spacing around the * in yield* expressions.
     * @author Bryan Smith
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "layout",
            docs: {
                description: "Require or disallow spacing around the `*` in `yield*` expressions",
                recommended: false,
                url: "https://eslint.org/docs/rules/yield-star-spacing"
            },
            fixable: "whitespace",
            schema: [
                {
                    oneOf: [
                        {
                            enum: ["before", "after", "both", "neither"]
                        },
                        {
                            type: "object",
                            properties: {
                                before: { type: "boolean" },
                                after: { type: "boolean" }
                            },
                            additionalProperties: false
                        }
                    ]
                }
            ],
            messages: {
                missingBefore: "Missing space before *.",
                missingAfter: "Missing space after *.",
                unexpectedBefore: "Unexpected space before *.",
                unexpectedAfter: "Unexpected space after *."
            }
        },
        create(context) {
            const sourceCode = context.getSourceCode();
            const mode = (function (option) {
                if (!option || typeof option === "string") {
                    return {
                        before: { before: true, after: false },
                        after: { before: false, after: true },
                        both: { before: true, after: true },
                        neither: { before: false, after: false }
                    }[option || "after"];
                }
                return option;
            }(context.options[0]));
            /**
             * Checks the spacing between two tokens before or after the star token.
             * @param {string} side Either "before" or "after".
             * @param {Token} leftToken `function` keyword token if side is "before", or
             *     star token if side is "after".
             * @param {Token} rightToken Star token if side is "before", or identifier
             *     token if side is "after".
             * @returns {void}
             */
            function checkSpacing(side, leftToken, rightToken) {
                if (sourceCode.isSpaceBetweenTokens(leftToken, rightToken) !== mode[side]) {
                    const after = leftToken.value === "*";
                    const spaceRequired = mode[side];
                    const node = after ? leftToken : rightToken;
                    let messageId = "";
                    if (spaceRequired) {
                        messageId = side === "before" ? "missingBefore" : "missingAfter";
                    }
                    else {
                        messageId = side === "before" ? "unexpectedBefore" : "unexpectedAfter";
                    }
                    context.report({
                        node,
                        messageId,
                        fix(fixer) {
                            if (spaceRequired) {
                                if (after) {
                                    return fixer.insertTextAfter(node, " ");
                                }
                                return fixer.insertTextBefore(node, " ");
                            }
                            return fixer.removeRange([leftToken.range[1], rightToken.range[0]]);
                        }
                    });
                }
            }
            /**
             * Enforces the spacing around the star if node is a yield* expression.
             * @param {ASTNode} node A yield expression node.
             * @returns {void}
             */
            function checkExpression(node) {
                if (!node.delegate) {
                    return;
                }
                const tokens = sourceCode.getFirstTokens(node, 3);
                const yieldToken = tokens[0];
                const starToken = tokens[1];
                const nextToken = tokens[2];
                checkSpacing("before", yieldToken, starToken);
                checkSpacing("after", starToken, nextToken);
            }
            return {
                YieldExpression: checkExpression
            };
        }
    };
},
/* eslint/lib/rules/yoda.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Rule to require or disallow yoda comparisons
     * @author Nicholas C. Zakas
     */
    "use strict";
    //--------------------------------------------------------------------------
    // Requirements
    //--------------------------------------------------------------------------
    const astUtils = require(360) /* ./utils/ast-utils */;
    //--------------------------------------------------------------------------
    // Helpers
    //--------------------------------------------------------------------------
    /**
     * Determines whether an operator is a comparison operator.
     * @param {string} operator The operator to check.
     * @returns {boolean} Whether or not it is a comparison operator.
     */
    function isComparisonOperator(operator) {
        return /^(==|===|!=|!==|<|>|<=|>=)$/u.test(operator);
    }
    /**
     * Determines whether an operator is an equality operator.
     * @param {string} operator The operator to check.
     * @returns {boolean} Whether or not it is an equality operator.
     */
    function isEqualityOperator(operator) {
        return /^(==|===)$/u.test(operator);
    }
    /**
     * Determines whether an operator is one used in a range test.
     * Allowed operators are `<` and `<=`.
     * @param {string} operator The operator to check.
     * @returns {boolean} Whether the operator is used in range tests.
     */
    function isRangeTestOperator(operator) {
        return ["<", "<="].includes(operator);
    }
    /**
     * Determines whether a non-Literal node is a negative number that should be
     * treated as if it were a single Literal node.
     * @param {ASTNode} node Node to test.
     * @returns {boolean} True if the node is a negative number that looks like a
     *                    real literal and should be treated as such.
     */
    function isNegativeNumericLiteral(node) {
        return (node.type === "UnaryExpression" &&
            node.operator === "-" &&
            node.prefix &&
            astUtils.isNumericLiteral(node.argument));
    }
    /**
     * Determines whether a node is a Template Literal which can be determined statically.
     * @param {ASTNode} node Node to test
     * @returns {boolean} True if the node is a Template Literal without expression.
     */
    function isStaticTemplateLiteral(node) {
        return node.type === "TemplateLiteral" && node.expressions.length === 0;
    }
    /**
     * Determines whether a non-Literal node should be treated as a single Literal node.
     * @param {ASTNode} node Node to test
     * @returns {boolean} True if the node should be treated as a single Literal node.
     */
    function looksLikeLiteral(node) {
        return isNegativeNumericLiteral(node) || isStaticTemplateLiteral(node);
    }
    /**
     * Attempts to derive a Literal node from nodes that are treated like literals.
     * @param {ASTNode} node Node to normalize.
     * @returns {ASTNode} One of the following options.
     *  1. The original node if the node is already a Literal
     *  2. A normalized Literal node with the negative number as the value if the
     *     node represents a negative number literal.
     *  3. A normalized Literal node with the string as the value if the node is
     *     a Template Literal without expression.
     *  4. Otherwise `null`.
     */
    function getNormalizedLiteral(node) {
        if (node.type === "Literal") {
            return node;
        }
        if (isNegativeNumericLiteral(node)) {
            return {
                type: "Literal",
                value: -node.argument.value,
                raw: `-${node.argument.value}`
            };
        }
        if (isStaticTemplateLiteral(node)) {
            return {
                type: "Literal",
                value: node.quasis[0].value.cooked,
                raw: node.quasis[0].value.raw
            };
        }
        return null;
    }
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    /** @type {import('../shared/types').Rule} */
    module.exports = {
        meta: {
            type: "suggestion",
            docs: {
                description: 'Require or disallow "Yoda" conditions',
                recommended: false,
                url: "https://eslint.org/docs/rules/yoda"
            },
            schema: [
                {
                    enum: ["always", "never"]
                },
                {
                    type: "object",
                    properties: {
                        exceptRange: {
                            type: "boolean",
                            default: false
                        },
                        onlyEquality: {
                            type: "boolean",
                            default: false
                        }
                    },
                    additionalProperties: false
                }
            ],
            fixable: "code",
            messages: {
                expected: "Expected literal to be on the {{expectedSide}} side of {{operator}}."
            }
        },
        create(context) {
            // Default to "never" (!always) if no option
            const always = context.options[0] === "always";
            const exceptRange = context.options[1] && context.options[1].exceptRange;
            const onlyEquality = context.options[1] && context.options[1].onlyEquality;
            const sourceCode = context.getSourceCode();
            /**
             * Determines whether node represents a range test.
             * A range test is a "between" test like `(0 <= x && x < 1)` or an "outside"
             * test like `(x < 0 || 1 <= x)`. It must be wrapped in parentheses, and
             * both operators must be `<` or `<=`. Finally, the literal on the left side
             * must be less than or equal to the literal on the right side so that the
             * test makes any sense.
             * @param {ASTNode} node LogicalExpression node to test.
             * @returns {boolean} Whether node is a range test.
             */
            function isRangeTest(node) {
                const left = node.left, right = node.right;
                /**
                 * Determines whether node is of the form `0 <= x && x < 1`.
                 * @returns {boolean} Whether node is a "between" range test.
                 */
                function isBetweenTest() {
                    if (node.operator === "&&" && astUtils.isSameReference(left.right, right.left)) {
                        const leftLiteral = getNormalizedLiteral(left.left);
                        const rightLiteral = getNormalizedLiteral(right.right);
                        if (leftLiteral === null && rightLiteral === null) {
                            return false;
                        }
                        if (rightLiteral === null || leftLiteral === null) {
                            return true;
                        }
                        if (leftLiteral.value <= rightLiteral.value) {
                            return true;
                        }
                    }
                    return false;
                }
                /**
                 * Determines whether node is of the form `x < 0 || 1 <= x`.
                 * @returns {boolean} Whether node is an "outside" range test.
                 */
                function isOutsideTest() {
                    if (node.operator === "||" && astUtils.isSameReference(left.left, right.right)) {
                        const leftLiteral = getNormalizedLiteral(left.right);
                        const rightLiteral = getNormalizedLiteral(right.left);
                        if (leftLiteral === null && rightLiteral === null) {
                            return false;
                        }
                        if (rightLiteral === null || leftLiteral === null) {
                            return true;
                        }
                        if (leftLiteral.value <= rightLiteral.value) {
                            return true;
                        }
                    }
                    return false;
                }
                /**
                 * Determines whether node is wrapped in parentheses.
                 * @returns {boolean} Whether node is preceded immediately by an open
                 *                    paren token and followed immediately by a close
                 *                    paren token.
                 */
                function isParenWrapped() {
                    return astUtils.isParenthesised(sourceCode, node);
                }
                return (node.type === "LogicalExpression" &&
                    left.type === "BinaryExpression" &&
                    right.type === "BinaryExpression" &&
                    isRangeTestOperator(left.operator) &&
                    isRangeTestOperator(right.operator) &&
                    (isBetweenTest() || isOutsideTest()) &&
                    isParenWrapped());
            }
            const OPERATOR_FLIP_MAP = {
                "===": "===",
                "!==": "!==",
                "==": "==",
                "!=": "!=",
                "<": ">",
                ">": "<",
                "<=": ">=",
                ">=": "<="
            };
            /**
             * Returns a string representation of a BinaryExpression node with its sides/operator flipped around.
             * @param {ASTNode} node The BinaryExpression node
             * @returns {string} A string representation of the node with the sides and operator flipped
             */
            function getFlippedString(node) {
                const operatorToken = sourceCode.getFirstTokenBetween(node.left, node.right, token => token.value === node.operator);
                const lastLeftToken = sourceCode.getTokenBefore(operatorToken);
                const firstRightToken = sourceCode.getTokenAfter(operatorToken);
                const source = sourceCode.getText();
                const leftText = source.slice(node.range[0], lastLeftToken.range[1]);
                const textBeforeOperator = source.slice(lastLeftToken.range[1], operatorToken.range[0]);
                const textAfterOperator = source.slice(operatorToken.range[1], firstRightToken.range[0]);
                const rightText = source.slice(firstRightToken.range[0], node.range[1]);
                const tokenBefore = sourceCode.getTokenBefore(node);
                const tokenAfter = sourceCode.getTokenAfter(node);
                let prefix = "";
                let suffix = "";
                if (tokenBefore &&
                    tokenBefore.range[1] === node.range[0] &&
                    !astUtils.canTokensBeAdjacent(tokenBefore, firstRightToken)) {
                    prefix = " ";
                }
                if (tokenAfter &&
                    node.range[1] === tokenAfter.range[0] &&
                    !astUtils.canTokensBeAdjacent(lastLeftToken, tokenAfter)) {
                    suffix = " ";
                }
                return (prefix +
                    rightText +
                    textBeforeOperator +
                    OPERATOR_FLIP_MAP[operatorToken.value] +
                    textAfterOperator +
                    leftText +
                    suffix);
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            return {
                BinaryExpression(node) {
                    const expectedLiteral = always ? node.left : node.right;
                    const expectedNonLiteral = always ? node.right : node.left;
                    // If `expectedLiteral` is not a literal, and `expectedNonLiteral` is a literal, raise an error.
                    if ((expectedNonLiteral.type === "Literal" ||
                        looksLikeLiteral(expectedNonLiteral)) &&
                        !(expectedLiteral.type === "Literal" ||
                            looksLikeLiteral(expectedLiteral)) &&
                        !(!isEqualityOperator(node.operator) && onlyEquality) &&
                        isComparisonOperator(node.operator) &&
                        !(exceptRange && isRangeTest(context.getAncestors().pop()))) {
                        context.report({
                            node,
                            messageId: "expected",
                            data: {
                                operator: node.operator,
                                expectedSide: always ? "left" : "right"
                            },
                            fix: fixer => fixer.replaceText(node, getFlippedString(node))
                        });
                    }
                }
            };
        }
    };
},
/* eslint/lib/linter/safe-emitter.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview A variant of EventEmitter which does not give listeners information about each other
     * @author Teddy Katz
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /**
     * An event emitter
     * @typedef {Object} SafeEmitter
     * @property {(eventName: string, listenerFunc: Function) => void} on Adds a listener for a given event name
     * @property {(eventName: string, arg1?: any, arg2?: any, arg3?: any) => void} emit Emits an event with a given name.
     * This calls all the listeners that were listening for that name, with `arg1`, `arg2`, and `arg3` as arguments.
     * @property {function(): string[]} eventNames Gets the list of event names that have registered listeners.
     */
    /**
     * Creates an object which can listen for and emit events.
     * This is similar to the EventEmitter API in Node's standard library, but it has a few differences.
     * The goal is to allow multiple modules to attach arbitrary listeners to the same emitter, without
     * letting the modules know about each other at all.
     * 1. It has no special keys like `error` and `newListener`, which would allow modules to detect when
     * another module throws an error or registers a listener.
     * 2. It calls listener functions without any `this` value. (`EventEmitter` calls listeners with a
     * `this` value of the emitter instance, which would give listeners access to other listeners.)
     * @returns {SafeEmitter} An emitter
     */
    module.exports = () => {
        const listeners = Object.create(null);
        return Object.freeze({
            on(eventName, listener) {
                if (eventName in listeners) {
                    listeners[eventName].push(listener);
                }
                else {
                    listeners[eventName] = [listener];
                }
            },
            emit(eventName, ...args) {
                if (eventName in listeners) {
                    listeners[eventName].forEach(listener => listener(...args));
                }
            },
            eventNames() {
                return Object.keys(listeners);
            }
        });
    };
},
/* eslint/lib/linter/source-code-fixer.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview An object that caches and applies source code fixes.
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const debug = require(72) /* debug */("eslint:source-code-fixer");
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const BOM = "\uFEFF";
    /**
     * Compares items in a messages array by range.
     * @param {Message} a The first message.
     * @param {Message} b The second message.
     * @returns {int} -1 if a comes before b, 1 if a comes after b, 0 if equal.
     * @private
     */
    function compareMessagesByFixRange(a, b) {
        return a.fix.range[0] - b.fix.range[0] || a.fix.range[1] - b.fix.range[1];
    }
    /**
     * Compares items in a messages array by line and column.
     * @param {Message} a The first message.
     * @param {Message} b The second message.
     * @returns {int} -1 if a comes before b, 1 if a comes after b, 0 if equal.
     * @private
     */
    function compareMessagesByLocation(a, b) {
        return a.line - b.line || a.column - b.column;
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * Utility for apply fixes to source code.
     * @constructor
     */
    function SourceCodeFixer() {
        Object.freeze(this);
    }
    /**
     * Applies the fixes specified by the messages to the given text. Tries to be
     * smart about the fixes and won't apply fixes over the same area in the text.
     * @param {string} sourceText The text to apply the changes to.
     * @param {Message[]} messages The array of messages reported by ESLint.
     * @param {boolean|Function} [shouldFix=true] Determines whether each message should be fixed
     * @returns {Object} An object containing the fixed text and any unfixed messages.
     */
    SourceCodeFixer.applyFixes = function (sourceText, messages, shouldFix) {
        debug("Applying fixes");
        if (shouldFix === false) {
            debug("shouldFix parameter was false, not attempting fixes");
            return {
                fixed: false,
                messages,
                output: sourceText
            };
        }
        // clone the array
        const remainingMessages = [], fixes = [], bom = sourceText.startsWith(BOM) ? BOM : "", text = bom ? sourceText.slice(1) : sourceText;
        let lastPos = Number.NEGATIVE_INFINITY, output = bom;
        /**
         * Try to use the 'fix' from a problem.
         * @param {Message} problem The message object to apply fixes from
         * @returns {boolean} Whether fix was successfully applied
         */
        function attemptFix(problem) {
            const fix = problem.fix;
            const start = fix.range[0];
            const end = fix.range[1];
            // Remain it as a problem if it's overlapped or it's a negative range
            if (lastPos >= start || start > end) {
                remainingMessages.push(problem);
                return false;
            }
            // Remove BOM.
            if ((start < 0 && end >= 0) || (start === 0 && fix.text.startsWith(BOM))) {
                output = "";
            }
            // Make output to this fix.
            output += text.slice(Math.max(0, lastPos), Math.max(0, start));
            output += fix.text;
            lastPos = end;
            return true;
        }
        messages.forEach(problem => {
            if (Object.prototype.hasOwnProperty.call(problem, "fix")) {
                fixes.push(problem);
            }
            else {
                remainingMessages.push(problem);
            }
        });
        if (fixes.length) {
            debug("Found fixes to apply");
            let fixesWereApplied = false;
            for (const problem of fixes.sort(compareMessagesByFixRange)) {
                if (typeof shouldFix !== "function" || shouldFix(problem)) {
                    attemptFix(problem);
                    /*
                     * The only time attemptFix will fail is if a previous fix was
                     * applied which conflicts with it.  So we can mark this as true.
                     */
                    fixesWereApplied = true;
                }
                else {
                    remainingMessages.push(problem);
                }
            }
            output += text.slice(Math.max(0, lastPos));
            return {
                fixed: fixesWereApplied,
                messages: remainingMessages.sort(compareMessagesByLocation),
                output
            };
        }
        debug("No fixes to apply");
        return {
            fixed: false,
            messages,
            output: bom + text
        };
    };
    module.exports = SourceCodeFixer;
},
/* eslint/lib/linter/timing.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Tracks performance of individual rules.
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /* c8 ignore next */
    /**
     * Align the string to left
     * @param {string} str string to evaluate
     * @param {int} len length of the string
     * @param {string} ch delimiter character
     * @returns {string} modified string
     * @private
     */
    function alignLeft(str, len, ch) {
        return str + new Array(len - str.length + 1).join(ch || " ");
    }
    /* c8 ignore next */
    /**
     * Align the string to right
     * @param {string} str string to evaluate
     * @param {int} len length of the string
     * @param {string} ch delimiter character
     * @returns {string} modified string
     * @private
     */
    function alignRight(str, len, ch) {
        return new Array(len - str.length + 1).join(ch || " ") + str;
    }
    //------------------------------------------------------------------------------
    // Module definition
    //------------------------------------------------------------------------------
    const enabled = !!process.env.TIMING;
    const HEADERS = ["Rule", "Time (ms)", "Relative"];
    const ALIGN = [alignLeft, alignRight, alignRight];
    /**
     * Decide how many rules to show in the output list.
     * @returns {number} the number of rules to show
     */
    function getListSize() {
        const MINIMUM_SIZE = 10;
        if (typeof process.env.TIMING !== "string") {
            return MINIMUM_SIZE;
        }
        if (process.env.TIMING.toLowerCase() === "all") {
            return Number.POSITIVE_INFINITY;
        }
        const TIMING_ENV_VAR_AS_INTEGER = Number.parseInt(process.env.TIMING, 10);
        return TIMING_ENV_VAR_AS_INTEGER > 10 ? TIMING_ENV_VAR_AS_INTEGER : MINIMUM_SIZE;
    }
    /* c8 ignore next */
    /**
     * display the data
     * @param {Object} data Data object to be displayed
     * @returns {void} prints modified string with console.log
     * @private
     */
    function display(data) {
        let total = 0;
        const rows = Object.keys(data)
            .map(key => {
            const time = data[key];
            total += time;
            return [key, time];
        })
            .sort((a, b) => b[1] - a[1])
            .slice(0, getListSize());
        rows.forEach(row => {
            row.push(`${(row[1] * 100 / total).toFixed(1)}%`);
            row[1] = row[1].toFixed(3);
        });
        rows.unshift(HEADERS);
        const widths = [];
        rows.forEach(row => {
            const len = row.length;
            for (let i = 0; i < len; i++) {
                const n = row[i].length;
                if (!widths[i] || n > widths[i]) {
                    widths[i] = n;
                }
            }
        });
        const table = rows.map(row => (row
            .map((cell, index) => ALIGN[index](cell, widths[index]))
            .join(" | ")));
        table.splice(1, 0, widths.map((width, index) => {
            const extraAlignment = index !== 0 && index !== widths.length - 1 ? 2 : 1;
            return ALIGN[index](":", width + extraAlignment, "-");
        }).join("|"));
        console.log(table.join("\n")); // eslint-disable-line no-console -- Debugging function
    }
    /* c8 ignore next */
    module.exports = (function () {
        const data = Object.create(null);
        /**
         * Time the run
         * @param {any} key key from the data object
         * @param {Function} fn function to be called
         * @returns {Function} function to be executed
         * @private
         */
        function time(key, fn) {
            if (typeof data[key] === "undefined") {
                data[key] = 0;
            }
            return function (...args) {
                let t = process.hrtime();
                const result = fn(...args);
                t = process.hrtime(t);
                data[key] += t[0] * 1e3 + t[1] / 1e6;
                return result;
            };
        }
        if (enabled) {
            process.on("exit", () => {
                display(data);
            });
        }
        return {
            time,
            enabled,
            getListSize
        };
    }());
},
/* eslint/conf/replacements.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "rules": {
            "generator-star": ["generator-star-spacing"],
            "global-strict": ["strict"],
            "no-arrow-condition": ["no-confusing-arrow", "no-constant-condition"],
            "no-comma-dangle": ["comma-dangle"],
            "no-empty-class": ["no-empty-character-class"],
            "no-empty-label": ["no-labels"],
            "no-extra-strict": ["strict"],
            "no-reserved-keys": ["quote-props"],
            "no-space-before-semi": ["semi-spacing"],
            "no-wrap-func": ["no-extra-parens"],
            "space-after-function-name": ["space-before-function-paren"],
            "space-after-keywords": ["keyword-spacing"],
            "space-before-function-parentheses": ["space-before-function-paren"],
            "space-before-keywords": ["keyword-spacing"],
            "space-in-brackets": ["object-curly-spacing", "array-bracket-spacing", "computed-property-spacing"],
            "space-return-throw-case": ["keyword-spacing"],
            "space-unary-word-ops": ["space-unary-ops"],
            "spaced-line-comment": ["spaced-comment"]
        }
    };
    module.exports = json;
},
/* eslint/lib/config/flat-config-helpers.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Shared functions to work with configs.
     * @author Nicholas C. Zakas
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Functions
    //-----------------------------------------------------------------------------
    /**
     * Parses a ruleId into its plugin and rule parts.
     * @param {string} ruleId The rule ID to parse.
     * @returns {{pluginName:string,ruleName:string}} The plugin and rule
     *      parts of the ruleId;
     */
    function parseRuleId(ruleId) {
        let pluginName, ruleName;
        // distinguish between core rules and plugin rules
        if (ruleId.includes("/")) {
            // mimic scoped npm packages
            if (ruleId.startsWith("@")) {
                pluginName = ruleId.slice(0, ruleId.lastIndexOf("/"));
            }
            else {
                pluginName = ruleId.slice(0, ruleId.indexOf("/"));
            }
            ruleName = ruleId.slice(pluginName.length + 1);
        }
        else {
            pluginName = "@";
            ruleName = ruleId;
        }
        return {
            pluginName,
            ruleName
        };
    }
    /**
     * Retrieves a rule instance from a given config based on the ruleId.
     * @param {string} ruleId The rule ID to look for.
     * @param {FlatConfig} config The config to search.
     * @returns {import("../shared/types").Rule|undefined} The rule if found
     *      or undefined if not.
     */
    function getRuleFromConfig(ruleId, config) {
        const { pluginName, ruleName } = parseRuleId(ruleId);
        const plugin = config.plugins && config.plugins[pluginName];
        let rule = plugin && plugin.rules && plugin.rules[ruleName];
        // normalize function rules into objects
        if (rule && typeof rule === "function") {
            rule = {
                create: rule
            };
        }
        return rule;
    }
    /**
     * Gets a complete options schema for a rule.
     * @param {{create: Function, schema: (Array|null)}} rule A new-style rule object
     * @returns {Object} JSON Schema for the rule's options.
     */
    function getRuleOptionsSchema(rule) {
        if (!rule) {
            return null;
        }
        const schema = rule.schema || rule.meta && rule.meta.schema;
        if (Array.isArray(schema)) {
            if (schema.length) {
                return {
                    type: "array",
                    items: schema,
                    minItems: 0,
                    maxItems: schema.length
                };
            }
            return {
                type: "array",
                minItems: 0,
                maxItems: 0
            };
        }
        // Given a full schema, leave it alone
        return schema || null;
    }
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    module.exports = {
        parseRuleId,
        getRuleFromConfig,
        getRuleOptionsSchema
    };
},
/* eslint/lib/config/flat-config-array.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Flat Config Array
     * @author Nicholas C. Zakas
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Requirements
    //-----------------------------------------------------------------------------
    const { ConfigArray, ConfigArraySymbol } = require(696) /* @humanwhocodes/config-array */;
    const { flatConfigSchema } = require(701) /* ./flat-config-schema */;
    const { RuleValidator } = require(702) /* ./rule-validator */;
    const { defaultConfig } = require(705) /* ./default-config */;
    const jsPlugin = require(286) /* @eslint/js */;
    //-----------------------------------------------------------------------------
    // Helpers
    //-----------------------------------------------------------------------------
    const ruleValidator = new RuleValidator();
    /**
     * Splits a plugin identifier in the form a/b/c into two parts: a/b and c.
     * @param {string} identifier The identifier to parse.
     * @returns {{objectName: string, pluginName: string}} The parts of the plugin
     *      name.
     */
    function splitPluginIdentifier(identifier) {
        const parts = identifier.split("/");
        return {
            objectName: parts.pop(),
            pluginName: parts.join("/")
        };
    }
    /**
     * Returns the name of an object in the config by reading its `meta` key.
     * @param {Object} object The object to check.
     * @returns {string?} The name of the object if found or `null` if there
     *      is no name.
     */
    function getObjectId(object) {
        // first check old-style name
        let name = object.name;
        if (!name) {
            if (!object.meta) {
                return null;
            }
            name = object.meta.name;
            if (!name) {
                return null;
            }
        }
        // now check for old-style version
        let version = object.version;
        if (!version) {
            version = object.meta && object.meta.version;
        }
        // if there's a version then append that
        if (version) {
            return `${name}@${version}`;
        }
        return name;
    }
    const originalBaseConfig = Symbol("originalBaseConfig");
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    /**
     * Represents an array containing configuration information for ESLint.
     */
    class FlatConfigArray extends ConfigArray {
        /**
         * Creates a new instance.
         * @param {*[]} configs An array of configuration information.
         * @param {{basePath: string, shouldIgnore: boolean, baseConfig: FlatConfig}} options The options
         *      to use for the config array instance.
         */
        constructor(configs, { basePath, shouldIgnore = true, baseConfig = defaultConfig } = {}) {
            super(configs, {
                basePath,
                schema: flatConfigSchema
            });
            if (baseConfig[Symbol.iterator]) {
                this.unshift(...baseConfig);
            }
            else {
                this.unshift(baseConfig);
            }
            /**
             * The base config used to build the config array.
             * @type {Array<FlatConfig>}
             */
            this[originalBaseConfig] = baseConfig;
            Object.defineProperty(this, originalBaseConfig, { writable: false });
            /**
             * Determines if `ignores` fields should be honored.
             * If true, then all `ignores` fields are honored.
             * if false, then only `ignores` fields in the baseConfig are honored.
             * @type {boolean}
             */
            this.shouldIgnore = shouldIgnore;
            Object.defineProperty(this, "shouldIgnore", { writable: false });
        }
        /* eslint-disable class-methods-use-this -- Desired as instance method */
        /**
         * Replaces a config with another config to allow us to put strings
         * in the config array that will be replaced by objects before
         * normalization.
         * @param {Object} config The config to preprocess.
         * @returns {Object} The preprocessed config.
         */
        [ConfigArraySymbol.preprocessConfig](config) {
            if (config === "eslint:recommended") {
                // if we are in a Node.js environment warn the user
                if (typeof process !== "undefined" && process.emitWarning) {
                    process.emitWarning("The 'eslint:recommended' string configuration is deprecated and will be replaced by the @eslint/js package's 'recommended' config.");
                }
                return jsPlugin.configs.recommended;
            }
            if (config === "eslint:all") {
                // if we are in a Node.js environment warn the user
                if (typeof process !== "undefined" && process.emitWarning) {
                    process.emitWarning("The 'eslint:all' string configuration is deprecated and will be replaced by the @eslint/js package's 'all' config.");
                }
                return jsPlugin.configs.all;
            }
            /*
             * If `shouldIgnore` is false, we remove any ignore patterns specified
             * in the config so long as it's not a default config and it doesn't
             * have a `files` entry.
             */
            if (!this.shouldIgnore &&
                !this[originalBaseConfig].includes(config) &&
                config.ignores &&
                !config.files) {
                /* eslint-disable-next-line no-unused-vars -- need to strip off other keys */
                const { ignores, ...otherKeys } = config;
                return otherKeys;
            }
            return config;
        }
        /**
         * Finalizes the config by replacing plugin references with their objects
         * and validating rule option schemas.
         * @param {Object} config The config to finalize.
         * @returns {Object} The finalized config.
         * @throws {TypeError} If the config is invalid.
         */
        [ConfigArraySymbol.finalizeConfig](config) {
            const { plugins, languageOptions, processor } = config;
            let parserName, processorName;
            let invalidParser = false, invalidProcessor = false;
            // Check parser value
            if (languageOptions && languageOptions.parser) {
                const { parser } = languageOptions;
                if (typeof parser === "string") {
                    const { pluginName, objectName: localParserName } = splitPluginIdentifier(parser);
                    parserName = parser;
                    if (!plugins || !plugins[pluginName] || !plugins[pluginName].parsers || !plugins[pluginName].parsers[localParserName]) {
                        throw new TypeError(`Key "parser": Could not find "${localParserName}" in plugin "${pluginName}".`);
                    }
                    languageOptions.parser = plugins[pluginName].parsers[localParserName];
                }
                else if (typeof parser === "object") {
                    parserName = getObjectId(parser);
                    if (!parserName) {
                        invalidParser = true;
                    }
                }
                else {
                    invalidParser = true;
                }
            }
            // Check processor value
            if (processor) {
                if (typeof processor === "string") {
                    const { pluginName, objectName: localProcessorName } = splitPluginIdentifier(processor);
                    processorName = processor;
                    if (!plugins || !plugins[pluginName] || !plugins[pluginName].processors || !plugins[pluginName].processors[localProcessorName]) {
                        throw new TypeError(`Key "processor": Could not find "${localProcessorName}" in plugin "${pluginName}".`);
                    }
                    config.processor = plugins[pluginName].processors[localProcessorName];
                }
                else if (typeof processor === "object") {
                    processorName = getObjectId(processor);
                    if (!processorName) {
                        invalidProcessor = true;
                    }
                }
                else {
                    invalidProcessor = true;
                }
            }
            ruleValidator.validate(config);
            // apply special logic for serialization into JSON
            /* eslint-disable object-shorthand -- shorthand would change "this" value */
            Object.defineProperty(config, "toJSON", {
                value: function () {
                    if (invalidParser) {
                        throw new Error("Could not serialize parser object (missing 'meta' object).");
                    }
                    if (invalidProcessor) {
                        throw new Error("Could not serialize processor object (missing 'meta' object).");
                    }
                    return {
                        ...this,
                        plugins: Object.keys(plugins),
                        languageOptions: {
                            ...languageOptions,
                            parser: parserName
                        },
                        processor: processorName
                    };
                }
            });
            /* eslint-enable object-shorthand -- ok to enable now */
            return config;
        }
    }
    exports.FlatConfigArray = FlatConfigArray;
},
/* @humanwhocodes/config-array/api.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    function _interopDefault(ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }
    var path = _interopDefault(require('path'));
    var minimatch = _interopDefault(require(229) /* minimatch */);
    var createDebug = _interopDefault(require(72) /* debug */);
    var objectSchema = require(697) /* @humanwhocodes/object-schema */;
    /**
     * @fileoverview ConfigSchema
     * @author Nicholas C. Zakas
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    /**
     * Assets that a given value is an array.
     * @param {*} value The value to check.
     * @returns {void}
     * @throws {TypeError} When the value is not an array.
     */
    function assertIsArray(value) {
        if (!Array.isArray(value)) {
            throw new TypeError('Expected value to be an array.');
        }
    }
    /**
     * Assets that a given value is an array containing only strings and functions.
     * @param {*} value The value to check.
     * @returns {void}
     * @throws {TypeError} When the value is not an array of strings and functions.
     */
    function assertIsArrayOfStringsAndFunctions(value, name) {
        assertIsArray(value);
        if (value.some(item => typeof item !== 'string' && typeof item !== 'function')) {
            throw new TypeError('Expected array to only contain strings.');
        }
    }
    //------------------------------------------------------------------------------
    // Exports
    //------------------------------------------------------------------------------
    /**
     * The base schema that every ConfigArray uses.
     * @type Object
     */
    const baseSchema = Object.freeze({
        name: {
            required: false,
            merge() {
                return undefined;
            },
            validate(value) {
                if (typeof value !== 'string') {
                    throw new TypeError('Property must be a string.');
                }
            }
        },
        files: {
            required: false,
            merge() {
                return undefined;
            },
            validate(value) {
                // first check if it's an array
                assertIsArray(value);
                // then check each member
                value.forEach(item => {
                    if (Array.isArray(item)) {
                        assertIsArrayOfStringsAndFunctions(item);
                    }
                    else if (typeof item !== 'string' && typeof item !== 'function') {
                        throw new TypeError('Items must be a string, a function, or an array of strings and functions.');
                    }
                });
            }
        },
        ignores: {
            required: false,
            merge() {
                return undefined;
            },
            validate: assertIsArrayOfStringsAndFunctions
        }
    });
    /**
     * @fileoverview ConfigArray
     * @author Nicholas C. Zakas
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const Minimatch = minimatch.Minimatch;
    const minimatchCache = new Map();
    const negatedMinimatchCache = new Map();
    const debug = createDebug('@hwc/config-array');
    const MINIMATCH_OPTIONS = {
        // matchBase: true,
        dot: true
    };
    const CONFIG_TYPES = new Set(['array', 'function']);
    /**
     * Shorthand for checking if a value is a string.
     * @param {any} value The value to check.
     * @returns {boolean} True if a string, false if not.
     */
    function isString(value) {
        return typeof value === 'string';
    }
    /**
     * Asserts that the files key of a config object is a nonempty array.
     * @param {object} config The config object to check.
     * @returns {void}
     * @throws {TypeError} If the files key isn't a nonempty array.
     */
    function assertNonEmptyFilesArray(config) {
        if (!Array.isArray(config.files) || config.files.length === 0) {
            throw new TypeError('The files key must be a non-empty array.');
        }
    }
    /**
     * Wrapper around minimatch that caches minimatch patterns for
     * faster matching speed over multiple file path evaluations.
     * @param {string} filepath The file path to match.
     * @param {string} pattern The glob pattern to match against.
     * @param {object} options The minimatch options to use.
     * @returns
     */
    function doMatch(filepath, pattern, options = {}) {
        let cache = minimatchCache;
        if (options.flipNegate) {
            cache = negatedMinimatchCache;
        }
        let matcher = cache.get(pattern);
        if (!matcher) {
            matcher = new Minimatch(pattern, Object.assign({}, MINIMATCH_OPTIONS, options));
            cache.set(pattern, matcher);
        }
        return matcher.match(filepath);
    }
    /**
     * Normalizes a `ConfigArray` by flattening it and executing any functions
     * that are found inside.
     * @param {Array} items The items in a `ConfigArray`.
     * @param {Object} context The context object to pass into any function
     *      found.
     * @param {Array<string>} extraConfigTypes The config types to check.
     * @returns {Promise<Array>} A flattened array containing only config objects.
     * @throws {TypeError} When a config function returns a function.
     */
    async function normalize(items, context, extraConfigTypes) {
        const allowFunctions = extraConfigTypes.includes('function');
        const allowArrays = extraConfigTypes.includes('array');
        async function* flatTraverse(array) {
            for (let item of array) {
                if (typeof item === 'function') {
                    if (!allowFunctions) {
                        throw new TypeError('Unexpected function.');
                    }
                    item = item(context);
                    if (item.then) {
                        item = await item;
                    }
                }
                if (Array.isArray(item)) {
                    if (!allowArrays) {
                        throw new TypeError('Unexpected array.');
                    }
                    yield* flatTraverse(item);
                }
                else if (typeof item === 'function') {
                    throw new TypeError('A config function can only return an object or array.');
                }
                else {
                    yield item;
                }
            }
        }
        /*
         * Async iterables cannot be used with the spread operator, so we need to manually
         * create the array to return.
         */
        const asyncIterable = await flatTraverse(items);
        const configs = [];
        for await (const config of asyncIterable) {
            configs.push(config);
        }
        return configs;
    }
    /**
     * Normalizes a `ConfigArray` by flattening it and executing any functions
     * that are found inside.
     * @param {Array} items The items in a `ConfigArray`.
     * @param {Object} context The context object to pass into any function
     *      found.
     * @param {Array<string>} extraConfigTypes The config types to check.
     * @returns {Array} A flattened array containing only config objects.
     * @throws {TypeError} When a config function returns a function.
     */
    function normalizeSync(items, context, extraConfigTypes) {
        const allowFunctions = extraConfigTypes.includes('function');
        const allowArrays = extraConfigTypes.includes('array');
        function* flatTraverse(array) {
            for (let item of array) {
                if (typeof item === 'function') {
                    if (!allowFunctions) {
                        throw new TypeError('Unexpected function.');
                    }
                    item = item(context);
                    if (item.then) {
                        throw new TypeError('Async config functions are not supported.');
                    }
                }
                if (Array.isArray(item)) {
                    if (!allowArrays) {
                        throw new TypeError('Unexpected array.');
                    }
                    yield* flatTraverse(item);
                }
                else if (typeof item === 'function') {
                    throw new TypeError('A config function can only return an object or array.');
                }
                else {
                    yield item;
                }
            }
        }
        return [...flatTraverse(items)];
    }
    /**
     * Determines if a given file path should be ignored based on the given
     * matcher.
     * @param {Array<string|() => boolean>} ignores The ignore patterns to check.
     * @param {string} filePath The absolute path of the file to check.
     * @param {string} relativeFilePath The relative path of the file to check.
     * @returns {boolean} True if the path should be ignored and false if not.
     */
    function shouldIgnorePath(ignores, filePath, relativeFilePath) {
        // all files outside of the basePath are ignored
        if (relativeFilePath.startsWith('..')) {
            return true;
        }
        return ignores.reduce((ignored, matcher) => {
            if (!ignored) {
                if (typeof matcher === 'function') {
                    return matcher(filePath);
                }
                // don't check negated patterns because we're not ignored yet
                if (!matcher.startsWith('!')) {
                    return doMatch(relativeFilePath, matcher);
                }
                // otherwise we're still not ignored
                return false;
            }
            // only need to check negated patterns because we're ignored
            if (typeof matcher === 'string' && matcher.startsWith('!')) {
                return !doMatch(relativeFilePath, matcher, {
                    flipNegate: true
                });
            }
            return ignored;
        }, false);
    }
    /**
     * Determines if a given file path is matched by a config. If the config
     * has no `files` field, then it matches; otherwise, if a `files` field
     * is present then we match the globs in `files` and exclude any globs in
     * `ignores`.
     * @param {string} filePath The absolute file path to check.
     * @param {Object} config The config object to check.
     * @returns {boolean} True if the file path is matched by the config,
     *      false if not.
     */
    function pathMatches(filePath, basePath, config) {
        /*
         * For both files and ignores, functions are passed the absolute
         * file path while strings are compared against the relative
         * file path.
         */
        const relativeFilePath = path.relative(basePath, filePath);
        // if files isn't an array, throw an error
        assertNonEmptyFilesArray(config);
        // match both strings and functions
        const match = pattern => {
            if (isString(pattern)) {
                return doMatch(relativeFilePath, pattern);
            }
            if (typeof pattern === 'function') {
                return pattern(filePath);
            }
            throw new TypeError(`Unexpected matcher type ${pattern}.`);
        };
        // check for all matches to config.files
        let filePathMatchesPattern = config.files.some(pattern => {
            if (Array.isArray(pattern)) {
                return pattern.every(match);
            }
            return match(pattern);
        });
        /*
         * If the file path matches the config.files patterns, then check to see
         * if there are any files to ignore.
         */
        if (filePathMatchesPattern && config.ignores) {
            filePathMatchesPattern = !shouldIgnorePath(config.ignores, filePath, relativeFilePath);
        }
        return filePathMatchesPattern;
    }
    /**
     * Ensures that a ConfigArray has been normalized.
     * @param {ConfigArray} configArray The ConfigArray to check.
     * @returns {void}
     * @throws {Error} When the `ConfigArray` is not normalized.
     */
    function assertNormalized(configArray) {
        // TODO: Throw more verbose error
        if (!configArray.isNormalized()) {
            throw new Error('ConfigArray must be normalized to perform this operation.');
        }
    }
    /**
     * Ensures that config types are valid.
     * @param {Array<string>} extraConfigTypes The config types to check.
     * @returns {void}
     * @throws {Error} When the config types array is invalid.
     */
    function assertExtraConfigTypes(extraConfigTypes) {
        if (extraConfigTypes.length > 2) {
            throw new TypeError('configTypes must be an array with at most two items.');
        }
        for (const configType of extraConfigTypes) {
            if (!CONFIG_TYPES.has(configType)) {
                throw new TypeError(`Unexpected config type "${configType}" found. Expected one of: "object", "array", "function".`);
            }
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    const ConfigArraySymbol = {
        isNormalized: Symbol('isNormalized'),
        configCache: Symbol('configCache'),
        schema: Symbol('schema'),
        finalizeConfig: Symbol('finalizeConfig'),
        preprocessConfig: Symbol('preprocessConfig')
    };
    // used to store calculate data for faster lookup
    const dataCache = new WeakMap();
    /**
     * Represents an array of config objects and provides method for working with
     * those config objects.
     */
    class ConfigArray extends Array {
        /**
         * Creates a new instance of ConfigArray.
         * @param {Iterable|Function|Object} configs An iterable yielding config
         *      objects, or a config function, or a config object.
         * @param {string} [options.basePath=""] The path of the config file
         * @param {boolean} [options.normalized=false] Flag indicating if the
         *      configs have already been normalized.
         * @param {Object} [options.schema] The additional schema
         *      definitions to use for the ConfigArray schema.
         * @param {Array<string>} [options.configTypes] List of config types supported.
         */
        constructor(configs, { basePath = '', normalized = false, schema: customSchema, extraConfigTypes = [] } = {}) {
            super();
            /**
             * Tracks if the array has been normalized.
             * @property isNormalized
             * @type boolean
             * @private
             */
            this[ConfigArraySymbol.isNormalized] = normalized;
            /**
             * The schema used for validating and merging configs.
             * @property schema
             * @type ObjectSchema
             * @private
             */
            this[ConfigArraySymbol.schema] = new objectSchema.ObjectSchema(Object.assign({}, customSchema, baseSchema));
            /**
             * The path of the config file that this array was loaded from.
             * This is used to calculate filename matches.
             * @property basePath
             * @type string
             */
            this.basePath = basePath;
            assertExtraConfigTypes(extraConfigTypes);
            /**
             * The supported config types.
             * @property configTypes
             * @type Array<string>
             */
            this.extraConfigTypes = Object.freeze([...extraConfigTypes]);
            /**
             * A cache to store calculated configs for faster repeat lookup.
             * @property configCache
             * @type Map
             * @private
             */
            this[ConfigArraySymbol.configCache] = new Map();
            // init cache
            dataCache.set(this, {
                explicitMatches: new Map(),
                directoryMatches: new Map(),
                files: undefined,
                ignores: undefined
            });
            // load the configs into this array
            if (Array.isArray(configs)) {
                this.push(...configs);
            }
            else {
                this.push(configs);
            }
        }
        /**
         * Prevent normal array methods from creating a new `ConfigArray` instance.
         * This is to ensure that methods such as `slice()` won't try to create a
         * new instance of `ConfigArray` behind the scenes as doing so may throw
         * an error due to the different constructor signature.
         * @returns {Function} The `Array` constructor.
         */
        static get [Symbol.species]() {
            return Array;
        }
        /**
         * Returns the `files` globs from every config object in the array.
         * This can be used to determine which files will be matched by a
         * config array or to use as a glob pattern when no patterns are provided
         * for a command line interface.
         * @returns {Array<string|Function>} An array of matchers.
         */
        get files() {
            assertNormalized(this);
            // if this data has been cached, retrieve it
            const cache = dataCache.get(this);
            if (cache.files) {
                return cache.files;
            }
            // otherwise calculate it
            const result = [];
            for (const config of this) {
                if (config.files) {
                    config.files.forEach(filePattern => {
                        result.push(filePattern);
                    });
                }
            }
            // store result
            cache.files = result;
            dataCache.set(this, cache);
            return result;
        }
        /**
         * Returns ignore matchers that should always be ignored regardless of
         * the matching `files` fields in any configs. This is necessary to mimic
         * the behavior of things like .gitignore and .eslintignore, allowing a
         * globbing operation to be faster.
         * @returns {string[]} An array of string patterns and functions to be ignored.
         */
        get ignores() {
            assertNormalized(this);
            // if this data has been cached, retrieve it
            const cache = dataCache.get(this);
            if (cache.ignores) {
                return cache.ignores;
            }
            // otherwise calculate it
            const result = [];
            for (const config of this) {
                /*
                 * We only count ignores if there are no other keys in the object.
                 * In this case, it acts list a globally ignored pattern. If there
                 * are additional keys, then ignores act like exclusions.
                 */
                if (config.ignores && Object.keys(config).length === 1) {
                    /*
                     * If there are directory ignores, then we need to double up
                     * the patterns to be ignored. For instance, `foo` will also
                     * need `foo/**` in order to account for subdirectories.
                     */
                    config.ignores.forEach(ignore => {
                        result.push(ignore);
                        if (typeof ignore === 'string') {
                            // unignoring files won't work unless we unignore directories too
                            if (ignore.startsWith('!')) {
                                if (ignore.endsWith('/**')) {
                                    result.push(ignore.slice(0, ignore.length - 3));
                                }
                                else if (ignore.endsWith('/*')) {
                                    result.push(ignore.slice(0, ignore.length - 2));
                                }
                            }
                            // directories should work with or without a trailing slash
                            if (ignore.endsWith('/')) {
                                result.push(ignore.slice(0, ignore.length - 1));
                                result.push(ignore + '**');
                            }
                            else if (!ignore.endsWith('*')) {
                                result.push(ignore + '/**');
                            }
                        }
                    });
                }
            }
            // store result
            cache.ignores = result;
            dataCache.set(this, cache);
            return result;
        }
        /**
         * Indicates if the config array has been normalized.
         * @returns {boolean} True if the config array is normalized, false if not.
         */
        isNormalized() {
            return this[ConfigArraySymbol.isNormalized];
        }
        /**
         * Normalizes a config array by flattening embedded arrays and executing
         * config functions.
         * @param {ConfigContext} context The context object for config functions.
         * @returns {Promise<ConfigArray>} The current ConfigArray instance.
         */
        async normalize(context = {}) {
            if (!this.isNormalized()) {
                const normalizedConfigs = await normalize(this, context, this.extraConfigTypes);
                this.length = 0;
                this.push(...normalizedConfigs.map(this[ConfigArraySymbol.preprocessConfig].bind(this)));
                this[ConfigArraySymbol.isNormalized] = true;
                // prevent further changes
                Object.freeze(this);
            }
            return this;
        }
        /**
         * Normalizes a config array by flattening embedded arrays and executing
         * config functions.
         * @param {ConfigContext} context The context object for config functions.
         * @returns {ConfigArray} The current ConfigArray instance.
         */
        normalizeSync(context = {}) {
            if (!this.isNormalized()) {
                const normalizedConfigs = normalizeSync(this, context, this.extraConfigTypes);
                this.length = 0;
                this.push(...normalizedConfigs.map(this[ConfigArraySymbol.preprocessConfig].bind(this)));
                this[ConfigArraySymbol.isNormalized] = true;
                // prevent further changes
                Object.freeze(this);
            }
            return this;
        }
        /**
         * Finalizes the state of a config before being cached and returned by
         * `getConfig()`. Does nothing by default but is provided to be
         * overridden by subclasses as necessary.
         * @param {Object} config The config to finalize.
         * @returns {Object} The finalized config.
         */
        [ConfigArraySymbol.finalizeConfig](config) {
            return config;
        }
        /**
         * Preprocesses a config during the normalization process. This is the
         * method to override if you want to convert an array item before it is
         * validated for the first time. For example, if you want to replace a
         * string with an object, this is the method to override.
         * @param {Object} config The config to preprocess.
         * @returns {Object} The config to use in place of the argument.
         */
        [ConfigArraySymbol.preprocessConfig](config) {
            return config;
        }
        /**
         * Determines if a given file path explicitly matches a `files` entry
         * and also doesn't match an `ignores` entry. Configs that don't have
         * a `files` property are not considered an explicit match.
         * @param {string} filePath The complete path of a file to check.
         * @returns {boolean} True if the file path matches a `files` entry
         * 		or false if not.
         */
        isExplicitMatch(filePath) {
            assertNormalized(this);
            const cache = dataCache.get(this);
            // first check the cache to avoid duplicate work
            let result = cache.explicitMatches.get(filePath);
            if (typeof result == 'boolean') {
                return result;
            }
            // TODO: Maybe move elsewhere? Maybe combine with getConfig() logic?
            const relativeFilePath = path.relative(this.basePath, filePath);
            if (shouldIgnorePath(this.ignores, filePath, relativeFilePath)) {
                debug(`Ignoring ${filePath}`);
                // cache and return result
                cache.explicitMatches.set(filePath, false);
                return false;
            }
            // filePath isn't automatically ignored, so try to find a match
            for (const config of this) {
                if (!config.files) {
                    continue;
                }
                if (pathMatches(filePath, this.basePath, config)) {
                    debug(`Matching config found for ${filePath}`);
                    cache.explicitMatches.set(filePath, true);
                    return true;
                }
            }
            return false;
        }
        /**
         * Returns the config object for a given file path.
         * @param {string} filePath The complete path of a file to get a config for.
         * @returns {Object} The config object for this file.
         */
        getConfig(filePath) {
            assertNormalized(this);
            const cache = this[ConfigArraySymbol.configCache];
            // first check the cache for a filename match to avoid duplicate work
            let finalConfig = cache.get(filePath);
            if (finalConfig) {
                return finalConfig;
            }
            // next check to see if the file should be ignored
            // check if this should be ignored due to its directory
            if (this.isDirectoryIgnored(path.dirname(filePath))) {
                debug(`Ignoring ${filePath} based on directory pattern`);
                // cache and return result - finalConfig is undefined at this point
                cache.set(filePath, finalConfig);
                return finalConfig;
            }
            // TODO: Maybe move elsewhere?
            const relativeFilePath = path.relative(this.basePath, filePath);
            if (shouldIgnorePath(this.ignores, filePath, relativeFilePath)) {
                debug(`Ignoring ${filePath} based on file pattern`);
                // cache and return result - finalConfig is undefined at this point
                cache.set(filePath, finalConfig);
                return finalConfig;
            }
            // filePath isn't automatically ignored, so try to construct config
            const matchingConfigIndices = [];
            let matchFound = false;
            const universalPattern = /\/\*{1,2}$/;
            this.forEach((config, index) => {
                if (!config.files) {
                    debug(`Anonymous universal config found for ${filePath}`);
                    matchingConfigIndices.push(index);
                    return;
                }
                assertNonEmptyFilesArray(config);
                /*
                 * If a config has a files pattern ending in /** or /*, and the
                 * filePath only matches those patterns, then the config is only
                 * applied if there is another config where the filePath matches
                 * a file with a specific extensions such as *.js.
                 */
                const universalFiles = config.files.filter(pattern => universalPattern.test(pattern));
                // universal patterns were found so we need to check the config twice
                if (universalFiles.length) {
                    debug('Universal files patterns found. Checking carefully.');
                    const nonUniversalFiles = config.files.filter(pattern => !universalPattern.test(pattern));
                    // check that the config matches without the non-universal files first
                    if (nonUniversalFiles.length &&
                        pathMatches(filePath, this.basePath, { files: nonUniversalFiles, ignores: config.ignores })) {
                        debug(`Matching config found for ${filePath}`);
                        matchingConfigIndices.push(index);
                        matchFound = true;
                        return;
                    }
                    // if there wasn't a match then check if it matches with universal files
                    if (universalFiles.length &&
                        pathMatches(filePath, this.basePath, { files: universalFiles, ignores: config.ignores })) {
                        debug(`Matching config found for ${filePath}`);
                        matchingConfigIndices.push(index);
                        return;
                    }
                    // if we make here, then there was no match
                    return;
                }
                // the normal case
                if (pathMatches(filePath, this.basePath, config)) {
                    debug(`Matching config found for ${filePath}`);
                    matchingConfigIndices.push(index);
                    matchFound = true;
                    return;
                }
            });
            // if matching both files and ignores, there will be no config to create
            if (!matchFound) {
                debug(`No matching configs found for ${filePath}`);
                // cache and return result - finalConfig is undefined at this point
                cache.set(filePath, finalConfig);
                return finalConfig;
            }
            // check to see if there is a config cached by indices
            finalConfig = cache.get(matchingConfigIndices.toString());
            if (finalConfig) {
                // also store for filename for faster lookup next time
                cache.set(filePath, finalConfig);
                return finalConfig;
            }
            // otherwise construct the config
            finalConfig = matchingConfigIndices.reduce((result, index) => {
                return this[ConfigArraySymbol.schema].merge(result, this[index]);
            }, {}, this);
            finalConfig = this[ConfigArraySymbol.finalizeConfig](finalConfig);
            cache.set(filePath, finalConfig);
            cache.set(matchingConfigIndices.toString(), finalConfig);
            return finalConfig;
        }
        /**
         * Determines if the given filepath is ignored based on the configs.
         * @param {string} filePath The complete path of a file to check.
         * @returns {boolean} True if the path is ignored, false if not.
         * @deprecated Use `isFileIgnored` instead.
         */
        isIgnored(filePath) {
            return this.isFileIgnored(filePath);
        }
        /**
         * Determines if the given filepath is ignored based on the configs.
         * @param {string} filePath The complete path of a file to check.
         * @returns {boolean} True if the path is ignored, false if not.
         */
        isFileIgnored(filePath) {
            return this.getConfig(filePath) === undefined;
        }
        /**
         * Determines if the given directory is ignored based on the configs.
         * This checks only default `ignores` that don't have `files` in the
         * same config. A pattern such as `/foo` be considered to ignore the directory
         * while a pattern such as `/foo/**` is not considered to ignore the
         * directory because it is matching files.
         * @param {string} directoryPath The complete path of a directory to check.
         * @returns {boolean} True if the directory is ignored, false if not. Will
         * 		return true for any directory that is not inside of `basePath`.
         * @throws {Error} When the `ConfigArray` is not normalized.
         */
        isDirectoryIgnored(directoryPath) {
            assertNormalized(this);
            const relativeDirectoryPath = path.relative(this.basePath, directoryPath)
                .replace(/\\/g, '/');
            if (relativeDirectoryPath.startsWith('..')) {
                return true;
            }
            // first check the cache
            const cache = dataCache.get(this).directoryMatches;
            if (cache.has(relativeDirectoryPath)) {
                return cache.get(relativeDirectoryPath);
            }
            const directoryParts = relativeDirectoryPath.split('/');
            let relativeDirectoryToCheck = '';
            let result = false;
            /*
             * In order to get the correct gitignore-style ignores, where an
             * ignored parent directory cannot have any descendants unignored,
             * we need to check every directory starting at the parent all
             * the way down to the actual requested directory.
             *
             * We aggressively cache all of this info to make sure we don't
             * have to recalculate everything for every call.
             */
            do {
                relativeDirectoryToCheck += directoryParts.shift() + '/';
                result = shouldIgnorePath(this.ignores, path.join(this.basePath, relativeDirectoryToCheck), relativeDirectoryToCheck);
                cache.set(relativeDirectoryToCheck, result);
            } while (!result && directoryParts.length);
            // also cache the result for the requested path
            cache.set(relativeDirectoryPath, result);
            return result;
        }
    }
    exports.ConfigArray = ConfigArray;
    exports.ConfigArraySymbol = ConfigArraySymbol;
},
/* @humanwhocodes/object-schema/src/index.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @filedescription Object Schema Package
     */
    exports.ObjectSchema = require(698) /* ./object-schema */.ObjectSchema;
    exports.MergeStrategy = require(699) /* ./merge-strategy */.MergeStrategy;
    exports.ValidationStrategy = require(700) /* ./validation-strategy */.ValidationStrategy;
},
/* @humanwhocodes/object-schema/src/object-schema.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @filedescription Object Schema
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Requirements
    //-----------------------------------------------------------------------------
    const { MergeStrategy } = require(699) /* ./merge-strategy */;
    const { ValidationStrategy } = require(700) /* ./validation-strategy */;
    //-----------------------------------------------------------------------------
    // Private
    //-----------------------------------------------------------------------------
    const strategies = Symbol("strategies");
    const requiredKeys = Symbol("requiredKeys");
    /**
     * Validates a schema strategy.
     * @param {string} name The name of the key this strategy is for.
     * @param {Object} strategy The strategy for the object key.
     * @param {boolean} [strategy.required=true] Whether the key is required.
     * @param {string[]} [strategy.requires] Other keys that are required when
     *      this key is present.
     * @param {Function} strategy.merge A method to call when merging two objects
     *      with the same key.
     * @param {Function} strategy.validate A method to call when validating an
     *      object with the key.
     * @returns {void}
     * @throws {Error} When the strategy is missing a name.
     * @throws {Error} When the strategy is missing a merge() method.
     * @throws {Error} When the strategy is missing a validate() method.
     */
    function validateDefinition(name, strategy) {
        let hasSchema = false;
        if (strategy.schema) {
            if (typeof strategy.schema === "object") {
                hasSchema = true;
            }
            else {
                throw new TypeError("Schema must be an object.");
            }
        }
        if (typeof strategy.merge === "string") {
            if (!(strategy.merge in MergeStrategy)) {
                throw new TypeError(`Definition for key "${name}" missing valid merge strategy.`);
            }
        }
        else if (!hasSchema && typeof strategy.merge !== "function") {
            throw new TypeError(`Definition for key "${name}" must have a merge property.`);
        }
        if (typeof strategy.validate === "string") {
            if (!(strategy.validate in ValidationStrategy)) {
                throw new TypeError(`Definition for key "${name}" missing valid validation strategy.`);
            }
        }
        else if (!hasSchema && typeof strategy.validate !== "function") {
            throw new TypeError(`Definition for key "${name}" must have a validate() method.`);
        }
    }
    //-----------------------------------------------------------------------------
    // Class
    //-----------------------------------------------------------------------------
    /**
     * Represents an object validation/merging schema.
     */
    class ObjectSchema {
        /**
         * Creates a new instance.
         */
        constructor(definitions) {
            if (!definitions) {
                throw new Error("Schema definitions missing.");
            }
            /**
             * Track all strategies in the schema by key.
             * @type {Map}
             * @property strategies
             */
            this[strategies] = new Map();
            /**
             * Separately track any keys that are required for faster validation.
             * @type {Map}
             * @property requiredKeys
             */
            this[requiredKeys] = new Map();
            // add in all strategies
            for (const key of Object.keys(definitions)) {
                validateDefinition(key, definitions[key]);
                // normalize merge and validate methods if subschema is present
                if (typeof definitions[key].schema === "object") {
                    const schema = new ObjectSchema(definitions[key].schema);
                    definitions[key] = {
                        ...definitions[key],
                        merge(first = {}, second = {}) {
                            return schema.merge(first, second);
                        },
                        validate(value) {
                            ValidationStrategy.object(value);
                            schema.validate(value);
                        }
                    };
                }
                // normalize the merge method in case there's a string
                if (typeof definitions[key].merge === "string") {
                    definitions[key] = {
                        ...definitions[key],
                        merge: MergeStrategy[definitions[key].merge]
                    };
                }
                ;
                // normalize the validate method in case there's a string
                if (typeof definitions[key].validate === "string") {
                    definitions[key] = {
                        ...definitions[key],
                        validate: ValidationStrategy[definitions[key].validate]
                    };
                }
                ;
                this[strategies].set(key, definitions[key]);
                if (definitions[key].required) {
                    this[requiredKeys].set(key, definitions[key]);
                }
            }
        }
        /**
         * Determines if a strategy has been registered for the given object key.
         * @param {string} key The object key to find a strategy for.
         * @returns {boolean} True if the key has a strategy registered, false if not.
         */
        hasKey(key) {
            return this[strategies].has(key);
        }
        /**
         * Merges objects together to create a new object comprised of the keys
         * of the all objects. Keys are merged based on the each key's merge
         * strategy.
         * @param {...Object} objects The objects to merge.
         * @returns {Object} A new object with a mix of all objects' keys.
         * @throws {Error} If any object is invalid.
         */
        merge(...objects) {
            // double check arguments
            if (objects.length < 2) {
                throw new Error("merge() requires at least two arguments.");
            }
            if (objects.some(object => (object == null || typeof object !== "object"))) {
                throw new Error("All arguments must be objects.");
            }
            return objects.reduce((result, object) => {
                this.validate(object);
                for (const [key, strategy] of this[strategies]) {
                    try {
                        if (key in result || key in object) {
                            const value = strategy.merge.call(this, result[key], object[key]);
                            if (value !== undefined) {
                                result[key] = value;
                            }
                        }
                    }
                    catch (ex) {
                        ex.message = `Key "${key}": ` + ex.message;
                        throw ex;
                    }
                }
                return result;
            }, {});
        }
        /**
         * Validates an object's keys based on the validate strategy for each key.
         * @param {Object} object The object to validate.
         * @returns {void}
         * @throws {Error} When the object is invalid.
         */
        validate(object) {
            // check existing keys first
            for (const key of Object.keys(object)) {
                // check to see if the key is defined
                if (!this.hasKey(key)) {
                    throw new Error(`Unexpected key "${key}" found.`);
                }
                // validate existing keys
                const strategy = this[strategies].get(key);
                // first check to see if any other keys are required
                if (Array.isArray(strategy.requires)) {
                    if (!strategy.requires.every(otherKey => otherKey in object)) {
                        throw new Error(`Key "${key}" requires keys "${strategy.requires.join("\", \"")}".`);
                    }
                }
                // now apply remaining validation strategy
                try {
                    strategy.validate.call(strategy, object[key]);
                }
                catch (ex) {
                    ex.message = `Key "${key}": ` + ex.message;
                    throw ex;
                }
            }
            // ensure required keys aren't missing
            for (const [key] of this[requiredKeys]) {
                if (!(key in object)) {
                    throw new Error(`Missing required key "${key}".`);
                }
            }
        }
    }
    exports.ObjectSchema = ObjectSchema;
},
/* @humanwhocodes/object-schema/src/merge-strategy.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @filedescription Merge Strategy
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Class
    //-----------------------------------------------------------------------------
    /**
     * Container class for several different merge strategies.
     */
    class MergeStrategy {
        /**
         * Merges two keys by overwriting the first with the second.
         * @param {*} value1 The value from the first object key.
         * @param {*} value2 The value from the second object key.
         * @returns {*} The second value.
         */
        static overwrite(value1, value2) {
            return value2;
        }
        /**
         * Merges two keys by replacing the first with the second only if the
         * second is defined.
         * @param {*} value1 The value from the first object key.
         * @param {*} value2 The value from the second object key.
         * @returns {*} The second value if it is defined.
         */
        static replace(value1, value2) {
            if (typeof value2 !== "undefined") {
                return value2;
            }
            return value1;
        }
        /**
         * Merges two properties by assigning properties from the second to the first.
         * @param {*} value1 The value from the first object key.
         * @param {*} value2 The value from the second object key.
         * @returns {*} A new object containing properties from both value1 and
         *      value2.
         */
        static assign(value1, value2) {
            return Object.assign({}, value1, value2);
        }
    }
    exports.MergeStrategy = MergeStrategy;
},
/* @humanwhocodes/object-schema/src/validation-strategy.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @filedescription Validation Strategy
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Class
    //-----------------------------------------------------------------------------
    /**
     * Container class for several different validation strategies.
     */
    class ValidationStrategy {
        /**
         * Validates that a value is an array.
         * @param {*} value The value to validate.
         * @returns {void}
         * @throws {TypeError} If the value is invalid.
         */
        static array(value) {
            if (!Array.isArray(value)) {
                throw new TypeError("Expected an array.");
            }
        }
        /**
         * Validates that a value is a boolean.
         * @param {*} value The value to validate.
         * @returns {void}
         * @throws {TypeError} If the value is invalid.
         */
        static boolean(value) {
            if (typeof value !== "boolean") {
                throw new TypeError("Expected a Boolean.");
            }
        }
        /**
         * Validates that a value is a number.
         * @param {*} value The value to validate.
         * @returns {void}
         * @throws {TypeError} If the value is invalid.
         */
        static number(value) {
            if (typeof value !== "number") {
                throw new TypeError("Expected a number.");
            }
        }
        /**
         * Validates that a value is a object.
         * @param {*} value The value to validate.
         * @returns {void}
         * @throws {TypeError} If the value is invalid.
         */
        static object(value) {
            if (!value || typeof value !== "object") {
                throw new TypeError("Expected an object.");
            }
        }
        /**
         * Validates that a value is a object or null.
         * @param {*} value The value to validate.
         * @returns {void}
         * @throws {TypeError} If the value is invalid.
         */
        static "object?"(value) {
            if (typeof value !== "object") {
                throw new TypeError("Expected an object or null.");
            }
        }
        /**
         * Validates that a value is a string.
         * @param {*} value The value to validate.
         * @returns {void}
         * @throws {TypeError} If the value is invalid.
         */
        static string(value) {
            if (typeof value !== "string") {
                throw new TypeError("Expected a string.");
            }
        }
        /**
         * Validates that a value is a non-empty string.
         * @param {*} value The value to validate.
         * @returns {void}
         * @throws {TypeError} If the value is invalid.
         */
        static "string!"(value) {
            if (typeof value !== "string" || value.length === 0) {
                throw new TypeError("Expected a non-empty string.");
            }
        }
    }
    exports.ValidationStrategy = ValidationStrategy;
},
/* eslint/lib/config/flat-config-schema.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Flat config schema
     * @author Nicholas C. Zakas
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Type Definitions
    //-----------------------------------------------------------------------------
    /**
     * @typedef ObjectPropertySchema
     * @property {Function|string} merge The function or name of the function to call
     *      to merge multiple objects with this property.
     * @property {Function|string} validate The function or name of the function to call
     *      to validate the value of this property.
     */
    //-----------------------------------------------------------------------------
    // Helpers
    //-----------------------------------------------------------------------------
    const ruleSeverities = new Map([
        [0, 0], ["off", 0],
        [1, 1], ["warn", 1],
        [2, 2], ["error", 2]
    ]);
    const globalVariablesValues = new Set([
        true, "true", "writable", "writeable",
        false, "false", "readonly", "readable", null,
        "off"
    ]);
    /**
     * Check if a value is a non-null object.
     * @param {any} value The value to check.
     * @returns {boolean} `true` if the value is a non-null object.
     */
    function isNonNullObject(value) {
        return typeof value === "object" && value !== null;
    }
    /**
     * Check if a value is undefined.
     * @param {any} value The value to check.
     * @returns {boolean} `true` if the value is undefined.
     */
    function isUndefined(value) {
        return typeof value === "undefined";
    }
    /**
     * Deeply merges two objects.
     * @param {Object} first The base object.
     * @param {Object} second The overrides object.
     * @returns {Object} An object with properties from both first and second.
     */
    function deepMerge(first = {}, second = {}) {
        /*
         * If the second value is an array, just return it. We don't merge
         * arrays because order matters and we can't know the correct order.
         */
        if (Array.isArray(second)) {
            return second;
        }
        /*
         * First create a result object where properties from the second object
         * overwrite properties from the first. This sets up a baseline to use
         * later rather than needing to inspect and change every property
         * individually.
         */
        const result = {
            ...first,
            ...second
        };
        for (const key of Object.keys(second)) {
            // avoid hairy edge case
            if (key === "__proto__") {
                continue;
            }
            const firstValue = first[key];
            const secondValue = second[key];
            if (isNonNullObject(firstValue)) {
                result[key] = deepMerge(firstValue, secondValue);
            }
            else if (isUndefined(firstValue)) {
                if (isNonNullObject(secondValue)) {
                    result[key] = deepMerge(Array.isArray(secondValue) ? [] : {}, secondValue);
                }
                else if (!isUndefined(secondValue)) {
                    result[key] = secondValue;
                }
            }
        }
        return result;
    }
    /**
     * Normalizes the rule options config for a given rule by ensuring that
     * it is an array and that the first item is 0, 1, or 2.
     * @param {Array|string|number} ruleOptions The rule options config.
     * @returns {Array} An array of rule options.
     */
    function normalizeRuleOptions(ruleOptions) {
        const finalOptions = Array.isArray(ruleOptions)
            ? ruleOptions.slice(0)
            : [ruleOptions];
        finalOptions[0] = ruleSeverities.get(finalOptions[0]);
        return finalOptions;
    }
    //-----------------------------------------------------------------------------
    // Assertions
    //-----------------------------------------------------------------------------
    /**
     * Validates that a value is a valid rule options entry.
     * @param {any} value The value to check.
     * @returns {void}
     * @throws {TypeError} If the value isn't a valid rule options.
     */
    function assertIsRuleOptions(value) {
        if (typeof value !== "string" && typeof value !== "number" && !Array.isArray(value)) {
            throw new TypeError("Expected a string, number, or array.");
        }
    }
    /**
     * Validates that a value is valid rule severity.
     * @param {any} value The value to check.
     * @returns {void}
     * @throws {TypeError} If the value isn't a valid rule severity.
     */
    function assertIsRuleSeverity(value) {
        const severity = typeof value === "string"
            ? ruleSeverities.get(value.toLowerCase())
            : ruleSeverities.get(value);
        if (typeof severity === "undefined") {
            throw new TypeError("Expected severity of \"off\", 0, \"warn\", 1, \"error\", or 2.");
        }
    }
    /**
     * Validates that a given string is the form pluginName/objectName.
     * @param {string} value The string to check.
     * @returns {void}
     * @throws {TypeError} If the string isn't in the correct format.
     */
    function assertIsPluginMemberName(value) {
        if (!/[@a-z0-9-_$]+(?:\/(?:[a-z0-9-_$]+))+$/iu.test(value)) {
            throw new TypeError(`Expected string in the form "pluginName/objectName" but found "${value}".`);
        }
    }
    /**
     * Validates that a value is an object.
     * @param {any} value The value to check.
     * @returns {void}
     * @throws {TypeError} If the value isn't an object.
     */
    function assertIsObject(value) {
        if (!isNonNullObject(value)) {
            throw new TypeError("Expected an object.");
        }
    }
    /**
     * Validates that a value is an object or a string.
     * @param {any} value The value to check.
     * @returns {void}
     * @throws {TypeError} If the value isn't an object or a string.
     */
    function assertIsObjectOrString(value) {
        if ((!value || typeof value !== "object") && typeof value !== "string") {
            throw new TypeError("Expected an object or string.");
        }
    }
    //-----------------------------------------------------------------------------
    // Low-Level Schemas
    //-----------------------------------------------------------------------------
    /** @type {ObjectPropertySchema} */
    const booleanSchema = {
        merge: "replace",
        validate: "boolean"
    };
    /** @type {ObjectPropertySchema} */
    const deepObjectAssignSchema = {
        merge(first = {}, second = {}) {
            return deepMerge(first, second);
        },
        validate: "object"
    };
    //-----------------------------------------------------------------------------
    // High-Level Schemas
    //-----------------------------------------------------------------------------
    /** @type {ObjectPropertySchema} */
    const globalsSchema = {
        merge: "assign",
        validate(value) {
            assertIsObject(value);
            for (const key of Object.keys(value)) {
                // avoid hairy edge case
                if (key === "__proto__") {
                    continue;
                }
                if (key !== key.trim()) {
                    throw new TypeError(`Global "${key}" has leading or trailing whitespace.`);
                }
                if (!globalVariablesValues.has(value[key])) {
                    throw new TypeError(`Key "${key}": Expected "readonly", "writable", or "off".`);
                }
            }
        }
    };
    /** @type {ObjectPropertySchema} */
    const parserSchema = {
        merge: "replace",
        validate(value) {
            assertIsObjectOrString(value);
            if (typeof value === "object" && typeof value.parse !== "function" && typeof value.parseForESLint !== "function") {
                throw new TypeError("Expected object to have a parse() or parseForESLint() method.");
            }
            if (typeof value === "string") {
                assertIsPluginMemberName(value);
            }
        }
    };
    /** @type {ObjectPropertySchema} */
    const pluginsSchema = {
        merge(first = {}, second = {}) {
            const keys = new Set([...Object.keys(first), ...Object.keys(second)]);
            const result = {};
            // manually validate that plugins are not redefined
            for (const key of keys) {
                // avoid hairy edge case
                if (key === "__proto__") {
                    continue;
                }
                if (key in first && key in second && first[key] !== second[key]) {
                    throw new TypeError(`Cannot redefine plugin "${key}".`);
                }
                result[key] = second[key] || first[key];
            }
            return result;
        },
        validate(value) {
            // first check the value to be sure it's an object
            if (value === null || typeof value !== "object") {
                throw new TypeError("Expected an object.");
            }
            // second check the keys to make sure they are objects
            for (const key of Object.keys(value)) {
                // avoid hairy edge case
                if (key === "__proto__") {
                    continue;
                }
                if (value[key] === null || typeof value[key] !== "object") {
                    throw new TypeError(`Key "${key}": Expected an object.`);
                }
            }
        }
    };
    /** @type {ObjectPropertySchema} */
    const processorSchema = {
        merge: "replace",
        validate(value) {
            if (typeof value === "string") {
                assertIsPluginMemberName(value);
            }
            else if (value && typeof value === "object") {
                if (typeof value.preprocess !== "function" || typeof value.postprocess !== "function") {
                    throw new TypeError("Object must have a preprocess() and a postprocess() method.");
                }
            }
            else {
                throw new TypeError("Expected an object or a string.");
            }
        }
    };
    /** @type {ObjectPropertySchema} */
    const rulesSchema = {
        merge(first = {}, second = {}) {
            const result = {
                ...first,
                ...second
            };
            for (const ruleId of Object.keys(result)) {
                // avoid hairy edge case
                if (ruleId === "__proto__") {
                    /* eslint-disable-next-line no-proto -- Though deprecated, may still be present */
                    delete result.__proto__;
                    continue;
                }
                result[ruleId] = normalizeRuleOptions(result[ruleId]);
                /*
                 * If either rule config is missing, then the correct
                 * config is already present and we just need to normalize
                 * the severity.
                 */
                if (!(ruleId in first) || !(ruleId in second)) {
                    continue;
                }
                const firstRuleOptions = normalizeRuleOptions(first[ruleId]);
                const secondRuleOptions = normalizeRuleOptions(second[ruleId]);
                /*
                 * If the second rule config only has a severity (length of 1),
                 * then use that severity and keep the rest of the options from
                 * the first rule config.
                 */
                if (secondRuleOptions.length === 1) {
                    result[ruleId] = [secondRuleOptions[0], ...firstRuleOptions.slice(1)];
                    continue;
                }
                /*
                 * In any other situation, then the second rule config takes
                 * precedence. That means the value at `result[ruleId]` is
                 * already correct and no further work is necessary.
                 */
            }
            return result;
        },
        validate(value) {
            assertIsObject(value);
            let lastRuleId;
            // Performance: One try-catch has less overhead than one per loop iteration
            try {
                /*
                 * We are not checking the rule schema here because there is no
                 * guarantee that the rule definition is present at this point. Instead
                 * we wait and check the rule schema during the finalization step
                 * of calculating a config.
                 */
                for (const ruleId of Object.keys(value)) {
                    // avoid hairy edge case
                    if (ruleId === "__proto__") {
                        continue;
                    }
                    lastRuleId = ruleId;
                    const ruleOptions = value[ruleId];
                    assertIsRuleOptions(ruleOptions);
                    if (Array.isArray(ruleOptions)) {
                        assertIsRuleSeverity(ruleOptions[0]);
                    }
                    else {
                        assertIsRuleSeverity(ruleOptions);
                    }
                }
            }
            catch (error) {
                error.message = `Key "${lastRuleId}": ${error.message}`;
                throw error;
            }
        }
    };
    /** @type {ObjectPropertySchema} */
    const ecmaVersionSchema = {
        merge: "replace",
        validate(value) {
            if (typeof value === "number" || value === "latest") {
                return;
            }
            throw new TypeError("Expected a number or \"latest\".");
        }
    };
    /** @type {ObjectPropertySchema} */
    const sourceTypeSchema = {
        merge: "replace",
        validate(value) {
            if (typeof value !== "string" || !/^(?:script|module|commonjs)$/u.test(value)) {
                throw new TypeError("Expected \"script\", \"module\", or \"commonjs\".");
            }
        }
    };
    //-----------------------------------------------------------------------------
    // Full schema
    //-----------------------------------------------------------------------------
    exports.flatConfigSchema = {
        settings: deepObjectAssignSchema,
        linterOptions: {
            schema: {
                noInlineConfig: booleanSchema,
                reportUnusedDisableDirectives: booleanSchema
            }
        },
        languageOptions: {
            schema: {
                ecmaVersion: ecmaVersionSchema,
                sourceType: sourceTypeSchema,
                globals: globalsSchema,
                parser: parserSchema,
                parserOptions: deepObjectAssignSchema
            }
        },
        processor: processorSchema,
        plugins: pluginsSchema,
        rules: rulesSchema
    };
},
/* eslint/lib/config/rule-validator.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Rule Validator
     * @author Nicholas C. Zakas
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Requirements
    //-----------------------------------------------------------------------------
    const ajv = require(703) /* ../shared/ajv */();
    const { parseRuleId, getRuleFromConfig, getRuleOptionsSchema } = require(694) /* ./flat-config-helpers */;
    const ruleReplacements = require(693) /* ../../conf/replacements.json */;
    //-----------------------------------------------------------------------------
    // Helpers
    //-----------------------------------------------------------------------------
    /**
     * Throws a helpful error when a rule cannot be found.
     * @param {Object} ruleId The rule identifier.
     * @param {string} ruleId.pluginName The ID of the rule to find.
     * @param {string} ruleId.ruleName The ID of the rule to find.
     * @param {Object} config The config to search in.
     * @throws {TypeError} For missing plugin or rule.
     * @returns {void}
     */
    function throwRuleNotFoundError({ pluginName, ruleName }, config) {
        const ruleId = pluginName === "@" ? ruleName : `${pluginName}/${ruleName}`;
        const errorMessageHeader = `Key "rules": Key "${ruleId}"`;
        let errorMessage = `${errorMessageHeader}: Could not find plugin "${pluginName}".`;
        // if the plugin exists then we need to check if the rule exists
        if (config.plugins && config.plugins[pluginName]) {
            const replacementRuleName = ruleReplacements.rules[ruleName];
            if (pluginName === "@" && replacementRuleName) {
                errorMessage = `${errorMessageHeader}: Rule "${ruleName}" was removed and replaced by "${replacementRuleName}".`;
            }
            else {
                errorMessage = `${errorMessageHeader}: Could not find "${ruleName}" in plugin "${pluginName}".`;
                // otherwise, let's see if we can find the rule name elsewhere
                for (const [otherPluginName, otherPlugin] of Object.entries(config.plugins)) {
                    if (otherPlugin.rules && otherPlugin.rules[ruleName]) {
                        errorMessage += ` Did you mean "${otherPluginName}/${ruleName}"?`;
                        break;
                    }
                }
            }
            // falls through to throw error
        }
        throw new TypeError(errorMessage);
    }
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    /**
     * Implements validation functionality for the rules portion of a config.
     */
    class RuleValidator {
        /**
         * Creates a new instance.
         */
        constructor() {
            /**
             * A collection of compiled validators for rules that have already
             * been validated.
             * @type {WeakMap}
             */
            this.validators = new WeakMap();
        }
        /**
         * Validates all of the rule configurations in a config against each
         * rule's schema.
         * @param {Object} config The full config to validate. This object must
         *      contain both the rules section and the plugins section.
         * @returns {void}
         * @throws {Error} If a rule's configuration does not match its schema.
         */
        validate(config) {
            if (!config.rules) {
                return;
            }
            for (const [ruleId, ruleOptions] of Object.entries(config.rules)) {
                // check for edge case
                if (ruleId === "__proto__") {
                    continue;
                }
                /*
                 * If a rule is disabled, we don't do any validation. This allows
                 * users to safely set any value to 0 or "off" without worrying
                 * that it will cause a validation error.
                 *
                 * Note: ruleOptions is always an array at this point because
                 * this validation occurs after FlatConfigArray has merged and
                 * normalized values.
                 */
                if (ruleOptions[0] === 0) {
                    continue;
                }
                const rule = getRuleFromConfig(ruleId, config);
                if (!rule) {
                    throwRuleNotFoundError(parseRuleId(ruleId), config);
                }
                // Precompile and cache validator the first time
                if (!this.validators.has(rule)) {
                    const schema = getRuleOptionsSchema(rule);
                    if (schema) {
                        this.validators.set(rule, ajv.compile(schema));
                    }
                }
                const validateRule = this.validators.get(rule);
                if (validateRule) {
                    validateRule(ruleOptions.slice(1));
                    if (validateRule.errors) {
                        throw new Error(`Key "rules": Key "${ruleId}": ${validateRule.errors.map(error => `\tValue ${JSON.stringify(error.data)} ${error.message}.\n`).join("")}`);
                    }
                }
            }
        }
    }
    exports.RuleValidator = RuleValidator;
},
/* eslint/lib/shared/ajv.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview The instance of Ajv validator.
     * @author Evgeny Poberezkin
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const Ajv = require(233) /* ajv */, metaSchema = require(704) /* ajv/lib/refs/json-schema-draft-04.json */;
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = (additionalOptions = {}) => {
        const ajv = new Ajv({
            meta: false,
            useDefaults: true,
            validateSchema: false,
            missingRefs: "ignore",
            verbose: true,
            schemaId: "auto",
            ...additionalOptions
        });
        ajv.addMetaSchema(metaSchema);
        // eslint-disable-next-line no-underscore-dangle -- Ajv's API
        ajv._opts.defaultMeta = metaSchema.id;
        return ajv;
    };
},
/* ajv/lib/refs/json-schema-draft-04.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "id": "http://json-schema.org/draft-04/schema#",
        "$schema": "http://json-schema.org/draft-04/schema#",
        "description": "Core schema meta-schema",
        "definitions": {
            "schemaArray": {
                "type": "array",
                "minItems": 1,
                "items": { "$ref": "#" }
            },
            "positiveInteger": {
                "type": "integer",
                "minimum": 0
            },
            "positiveIntegerDefault0": {
                "allOf": [{ "$ref": "#/definitions/positiveInteger" }, { "default": 0 }]
            },
            "simpleTypes": {
                "enum": ["array", "boolean", "integer", "null", "number", "object", "string"]
            },
            "stringArray": {
                "type": "array",
                "items": { "type": "string" },
                "minItems": 1,
                "uniqueItems": true
            }
        },
        "type": "object",
        "properties": {
            "id": {
                "type": "string"
            },
            "$schema": {
                "type": "string"
            },
            "title": {
                "type": "string"
            },
            "description": {
                "type": "string"
            },
            "default": {},
            "multipleOf": {
                "type": "number",
                "minimum": 0,
                "exclusiveMinimum": true
            },
            "maximum": {
                "type": "number"
            },
            "exclusiveMaximum": {
                "type": "boolean",
                "default": false
            },
            "minimum": {
                "type": "number"
            },
            "exclusiveMinimum": {
                "type": "boolean",
                "default": false
            },
            "maxLength": { "$ref": "#/definitions/positiveInteger" },
            "minLength": { "$ref": "#/definitions/positiveIntegerDefault0" },
            "pattern": {
                "type": "string",
                "format": "regex"
            },
            "additionalItems": {
                "anyOf": [
                    { "type": "boolean" },
                    { "$ref": "#" }
                ],
                "default": {}
            },
            "items": {
                "anyOf": [
                    { "$ref": "#" },
                    { "$ref": "#/definitions/schemaArray" }
                ],
                "default": {}
            },
            "maxItems": { "$ref": "#/definitions/positiveInteger" },
            "minItems": { "$ref": "#/definitions/positiveIntegerDefault0" },
            "uniqueItems": {
                "type": "boolean",
                "default": false
            },
            "maxProperties": { "$ref": "#/definitions/positiveInteger" },
            "minProperties": { "$ref": "#/definitions/positiveIntegerDefault0" },
            "required": { "$ref": "#/definitions/stringArray" },
            "additionalProperties": {
                "anyOf": [
                    { "type": "boolean" },
                    { "$ref": "#" }
                ],
                "default": {}
            },
            "definitions": {
                "type": "object",
                "additionalProperties": { "$ref": "#" },
                "default": {}
            },
            "properties": {
                "type": "object",
                "additionalProperties": { "$ref": "#" },
                "default": {}
            },
            "patternProperties": {
                "type": "object",
                "additionalProperties": { "$ref": "#" },
                "default": {}
            },
            "dependencies": {
                "type": "object",
                "additionalProperties": {
                    "anyOf": [
                        { "$ref": "#" },
                        { "$ref": "#/definitions/stringArray" }
                    ]
                }
            },
            "enum": {
                "type": "array",
                "minItems": 1,
                "uniqueItems": true
            },
            "type": {
                "anyOf": [
                    { "$ref": "#/definitions/simpleTypes" },
                    {
                        "type": "array",
                        "items": { "$ref": "#/definitions/simpleTypes" },
                        "minItems": 1,
                        "uniqueItems": true
                    }
                ]
            },
            "format": { "type": "string" },
            "allOf": { "$ref": "#/definitions/schemaArray" },
            "anyOf": { "$ref": "#/definitions/schemaArray" },
            "oneOf": { "$ref": "#/definitions/schemaArray" },
            "not": { "$ref": "#" }
        },
        "dependencies": {
            "exclusiveMaximum": ["maximum"],
            "exclusiveMinimum": ["minimum"]
        },
        "default": {}
    };
    module.exports = json;
},
/* eslint/lib/config/default-config.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Default configuration
     * @author Nicholas C. Zakas
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Requirements
    //-----------------------------------------------------------------------------
    const Rules = require(357) /* ../rules */;
    //-----------------------------------------------------------------------------
    // Helpers
    //-----------------------------------------------------------------------------
    exports.defaultConfig = [
        {
            plugins: {
                "@": {
                    parsers: {
                        espree: require(305) /* espree */
                    },
                    /*
                     * Because we try to delay loading rules until absolutely
                     * necessary, a proxy allows us to hook into the lazy-loading
                     * aspect of the rules map while still keeping all of the
                     * relevant configuration inside of the config array.
                     */
                    rules: new Proxy({}, {
                        get(target, property) {
                            return Rules.get(property);
                        },
                        has(target, property) {
                            return Rules.has(property);
                        }
                    })
                }
            },
            languageOptions: {
                sourceType: "module",
                ecmaVersion: "latest",
                parser: "@/espree",
                parserOptions: {}
            }
        },
        // default ignores are listed here
        {
            ignores: [
                "**/node_modules/*",
                ".git/"
            ]
        },
        // intentionally empty config to ensure these files are globbed by default
        {
            files: ["**/*.js", "**/*.mjs"]
        },
        {
            files: ["**/*.cjs"],
            languageOptions: {
                sourceType: "commonjs",
                ecmaVersion: "latest"
            }
        }
    ];
},
/* eslint/conf/globals.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Globals for ecmaVersion/sourceType
     * @author Nicholas C. Zakas
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Globals
    //-----------------------------------------------------------------------------
    const commonjs = {
        exports: true,
        global: false,
        module: false,
        require: false
    };
    const es3 = {
        Array: false,
        Boolean: false,
        constructor: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        propertyIsEnumerable: false,
        RangeError: false,
        ReferenceError: false,
        RegExp: false,
        String: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false
    };
    const es5 = {
        ...es3,
        JSON: false
    };
    const es2015 = {
        ...es5,
        ArrayBuffer: false,
        DataView: false,
        Float32Array: false,
        Float64Array: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        Map: false,
        Promise: false,
        Proxy: false,
        Reflect: false,
        Set: false,
        Symbol: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        WeakMap: false,
        WeakSet: false
    };
    // no new globals in ES2016
    const es2016 = {
        ...es2015
    };
    const es2017 = {
        ...es2016,
        Atomics: false,
        SharedArrayBuffer: false
    };
    // no new globals in ES2018
    const es2018 = {
        ...es2017
    };
    // no new globals in ES2019
    const es2019 = {
        ...es2018
    };
    const es2020 = {
        ...es2019,
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        globalThis: false
    };
    const es2021 = {
        ...es2020,
        AggregateError: false,
        FinalizationRegistry: false,
        WeakRef: false
    };
    const es2022 = {
        ...es2021
    };
    const es2023 = {
        ...es2022
    };
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    module.exports = {
        commonjs,
        es3,
        es5,
        es2015,
        es2016,
        es2017,
        es2018,
        es2019,
        es2020,
        es2021,
        es2022,
        es2023
    };
},
/* eslint/lib/cli-engine/load-rules.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Module for loading rules from files and directories.
     * @author Michael Ficarra
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const fs = require("fs"), path = require("path");
    const rulesDirCache = {};
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    /**
     * Load all rule modules from specified directory.
     * @param {string} relativeRulesDir Path to rules directory, may be relative.
     * @param {string} cwd Current working directory
     * @returns {Object} Loaded rule modules.
     */
    module.exports = function (relativeRulesDir, cwd) {
        const rulesDir = path.resolve(cwd, relativeRulesDir);
        // cache will help performance as IO operation are expensive
        if (rulesDirCache[rulesDir]) {
            return rulesDirCache[rulesDir];
        }
        const rules = Object.create(null);
        fs.readdirSync(rulesDir).forEach(file => {
            if (path.extname(file) !== ".js") {
                return;
            }
            rules[file.slice(0, -3)] = require(path.join(rulesDir, file));
        });
        rulesDirCache[rulesDir] = rules;
        return rules;
    };
},
/* eslint/lib/cli-engine/hash.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Defining the hashing function in one place.
     * @author Michael Ficarra
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const murmur = require(709) /* imurmurhash */;
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    /**
     * hash the given string
     * @param {string} str the string to hash
     * @returns {string} the hash
     */
    function hash(str) {
        return murmur(str).result().toString(36);
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = hash;
},
/* imurmurhash/imurmurhash.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @preserve
     * JS Implementation of incremental MurmurHash3 (r150) (as of May 10, 2013)
     *
     * @author <a href="mailto:jensyt@gmail.com">Jens Taylor</a>
     * @see http://github.com/homebrewing/brauhaus-diff
     * @author <a href="mailto:gary.court@gmail.com">Gary Court</a>
     * @see http://github.com/garycourt/murmurhash-js
     * @author <a href="mailto:aappleby@gmail.com">Austin Appleby</a>
     * @see http://sites.google.com/site/murmurhash/
     */
    (function () {
        var cache;
        // Call this function without `new` to use the cached object (good for
        // single-threaded environments), or with `new` to create a new object.
        //
        // @param {string} key A UTF-16 or ASCII string
        // @param {number} seed An optional positive integer
        // @return {object} A MurmurHash3 object for incremental hashing
        function MurmurHash3(key, seed) {
            var m = this instanceof MurmurHash3 ? this : cache;
            m.reset(seed);
            if (typeof key === 'string' && key.length > 0) {
                m.hash(key);
            }
            if (m !== this) {
                return m;
            }
        }
        ;
        // Incrementally add a string to this hash
        //
        // @param {string} key A UTF-16 or ASCII string
        // @return {object} this
        MurmurHash3.prototype.hash = function (key) {
            var h1, k1, i, top, len;
            len = key.length;
            this.len += len;
            k1 = this.k1;
            i = 0;
            switch (this.rem) {
                case 0: k1 ^= len > i ? (key.charCodeAt(i++) & 0xffff) : 0;
                case 1: k1 ^= len > i ? (key.charCodeAt(i++) & 0xffff) << 8 : 0;
                case 2: k1 ^= len > i ? (key.charCodeAt(i++) & 0xffff) << 16 : 0;
                case 3:
                    k1 ^= len > i ? (key.charCodeAt(i) & 0xff) << 24 : 0;
                    k1 ^= len > i ? (key.charCodeAt(i++) & 0xff00) >> 8 : 0;
            }
            this.rem = (len + this.rem) & 3; // & 3 is same as % 4
            len -= this.rem;
            if (len > 0) {
                h1 = this.h1;
                while (1) {
                    k1 = (k1 * 0x2d51 + (k1 & 0xffff) * 0xcc9e0000) & 0xffffffff;
                    k1 = (k1 << 15) | (k1 >>> 17);
                    k1 = (k1 * 0x3593 + (k1 & 0xffff) * 0x1b870000) & 0xffffffff;
                    h1 ^= k1;
                    h1 = (h1 << 13) | (h1 >>> 19);
                    h1 = (h1 * 5 + 0xe6546b64) & 0xffffffff;
                    if (i >= len) {
                        break;
                    }
                    k1 = ((key.charCodeAt(i++) & 0xffff)) ^
                        ((key.charCodeAt(i++) & 0xffff) << 8) ^
                        ((key.charCodeAt(i++) & 0xffff) << 16);
                    top = key.charCodeAt(i++);
                    k1 ^= ((top & 0xff) << 24) ^
                        ((top & 0xff00) >> 8);
                }
                k1 = 0;
                switch (this.rem) {
                    case 3: k1 ^= (key.charCodeAt(i + 2) & 0xffff) << 16;
                    case 2: k1 ^= (key.charCodeAt(i + 1) & 0xffff) << 8;
                    case 1: k1 ^= (key.charCodeAt(i) & 0xffff);
                }
                this.h1 = h1;
            }
            this.k1 = k1;
            return this;
        };
        // Get the result of this hash
        //
        // @return {number} The 32-bit hash
        MurmurHash3.prototype.result = function () {
            var k1, h1;
            k1 = this.k1;
            h1 = this.h1;
            if (k1 > 0) {
                k1 = (k1 * 0x2d51 + (k1 & 0xffff) * 0xcc9e0000) & 0xffffffff;
                k1 = (k1 << 15) | (k1 >>> 17);
                k1 = (k1 * 0x3593 + (k1 & 0xffff) * 0x1b870000) & 0xffffffff;
                h1 ^= k1;
            }
            h1 ^= this.len;
            h1 ^= h1 >>> 16;
            h1 = (h1 * 0xca6b + (h1 & 0xffff) * 0x85eb0000) & 0xffffffff;
            h1 ^= h1 >>> 13;
            h1 = (h1 * 0xae35 + (h1 & 0xffff) * 0xc2b20000) & 0xffffffff;
            h1 ^= h1 >>> 16;
            return h1 >>> 0;
        };
        // Reset the hash object for reuse
        //
        // @param {number} seed An optional positive integer
        MurmurHash3.prototype.reset = function (seed) {
            this.h1 = typeof seed === 'number' ? seed : 0;
            this.rem = this.k1 = this.len = 0;
            return this;
        };
        // A cached object to use. This can be safely used if you're in a single-
        // threaded environment, otherwise you need to create new hashes to use.
        cache = new MurmurHash3();
        if (typeof (module) != 'undefined') {
            module.exports = MurmurHash3;
        }
        else {
            this.MurmurHash3 = MurmurHash3;
        }
    }());
},
/* eslint/lib/cli-engine/lint-result-cache.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Utility for caching lint results.
     * @author Kevin Partington
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Requirements
    //-----------------------------------------------------------------------------
    const assert = require("assert");
    const fs = require("fs");
    const fileEntryCache = require(711) /* file-entry-cache */;
    const stringify = require(726) /* json-stable-stringify-without-jsonify */;
    const pkg = require(221) /* ../../package.json */;
    const hash = require(708) /* ./hash */;
    const debug = require(72) /* debug */("eslint:lint-result-cache");
    //-----------------------------------------------------------------------------
    // Helpers
    //-----------------------------------------------------------------------------
    const configHashCache = new WeakMap();
    const nodeVersion = process && process.version;
    const validCacheStrategies = ["metadata", "content"];
    const invalidCacheStrategyErrorMessage = `Cache strategy must be one of: ${validCacheStrategies
        .map(strategy => `"${strategy}"`)
        .join(", ")}`;
    /**
     * Tests whether a provided cacheStrategy is valid
     * @param {string} cacheStrategy The cache strategy to use
     * @returns {boolean} true if `cacheStrategy` is one of `validCacheStrategies`; false otherwise
     */
    function isValidCacheStrategy(cacheStrategy) {
        return (validCacheStrategies.includes(cacheStrategy));
    }
    /**
     * Calculates the hash of the config
     * @param {ConfigArray} config The config.
     * @returns {string} The hash of the config
     */
    function hashOfConfigFor(config) {
        if (!configHashCache.has(config)) {
            configHashCache.set(config, hash(`${pkg.version}_${nodeVersion}_${stringify(config)}`));
        }
        return configHashCache.get(config);
    }
    //-----------------------------------------------------------------------------
    // Public Interface
    //-----------------------------------------------------------------------------
    /**
     * Lint result cache. This wraps around the file-entry-cache module,
     * transparently removing properties that are difficult or expensive to
     * serialize and adding them back in on retrieval.
     */
    class LintResultCache {
        /**
         * Creates a new LintResultCache instance.
         * @param {string} cacheFileLocation The cache file location.
         * @param {"metadata" | "content"} cacheStrategy The cache strategy to use.
         */
        constructor(cacheFileLocation, cacheStrategy) {
            assert(cacheFileLocation, "Cache file location is required");
            assert(cacheStrategy, "Cache strategy is required");
            assert(isValidCacheStrategy(cacheStrategy), invalidCacheStrategyErrorMessage);
            debug(`Caching results to ${cacheFileLocation}`);
            const useChecksum = cacheStrategy === "content";
            debug(`Using "${cacheStrategy}" strategy to detect changes`);
            this.fileEntryCache = fileEntryCache.create(cacheFileLocation, void 0, useChecksum);
            this.cacheFileLocation = cacheFileLocation;
        }
        /**
         * Retrieve cached lint results for a given file path, if present in the
         * cache. If the file is present and has not been changed, rebuild any
         * missing result information.
         * @param {string} filePath The file for which to retrieve lint results.
         * @param {ConfigArray} config The config of the file.
         * @returns {Object|null} The rebuilt lint results, or null if the file is
         *   changed or not in the filesystem.
         */
        getCachedLintResults(filePath, config) {
            /*
             * Cached lint results are valid if and only if:
             * 1. The file is present in the filesystem
             * 2. The file has not changed since the time it was previously linted
             * 3. The ESLint configuration has not changed since the time the file
             *    was previously linted
             * If any of these are not true, we will not reuse the lint results.
             */
            const fileDescriptor = this.fileEntryCache.getFileDescriptor(filePath);
            const hashOfConfig = hashOfConfigFor(config);
            const changed = fileDescriptor.changed ||
                fileDescriptor.meta.hashOfConfig !== hashOfConfig;
            if (fileDescriptor.notFound) {
                debug(`File not found on the file system: ${filePath}`);
                return null;
            }
            if (changed) {
                debug(`Cache entry not found or no longer valid: ${filePath}`);
                return null;
            }
            // If source is present but null, need to reread the file from the filesystem.
            if (fileDescriptor.meta.results &&
                fileDescriptor.meta.results.source === null) {
                debug(`Rereading cached result source from filesystem: ${filePath}`);
                fileDescriptor.meta.results.source = fs.readFileSync(filePath, "utf-8");
            }
            return fileDescriptor.meta.results;
        }
        /**
         * Set the cached lint results for a given file path, after removing any
         * information that will be both unnecessary and difficult to serialize.
         * Avoids caching results with an "output" property (meaning fixes were
         * applied), to prevent potentially incorrect results if fixes are not
         * written to disk.
         * @param {string} filePath The file for which to set lint results.
         * @param {ConfigArray} config The config of the file.
         * @param {Object} result The lint result to be set for the file.
         * @returns {void}
         */
        setCachedLintResults(filePath, config, result) {
            if (result && Object.prototype.hasOwnProperty.call(result, "output")) {
                return;
            }
            const fileDescriptor = this.fileEntryCache.getFileDescriptor(filePath);
            if (fileDescriptor && !fileDescriptor.notFound) {
                debug(`Updating cached result: ${filePath}`);
                // Serialize the result, except that we want to remove the file source if present.
                const resultToSerialize = Object.assign({}, result);
                /*
                 * Set result.source to null.
                 * In `getCachedLintResults`, if source is explicitly null, we will
                 * read the file from the filesystem to set the value again.
                 */
                if (Object.prototype.hasOwnProperty.call(resultToSerialize, "source")) {
                    resultToSerialize.source = null;
                }
                fileDescriptor.meta.results = resultToSerialize;
                fileDescriptor.meta.hashOfConfig = hashOfConfigFor(config);
            }
        }
        /**
         * Persists the in-memory cache to disk.
         * @returns {void}
         */
        reconcile() {
            debug(`Persisting cached results: ${this.cacheFileLocation}`);
            this.fileEntryCache.reconcile();
        }
    }
    module.exports = LintResultCache;
},
/* file-entry-cache/cache.js */ function _(require, module, exports, __esModule, __esExport) {
    var path = require('path');
    var crypto = require('crypto');
    module.exports = {
        createFromFile: function (filePath, useChecksum) {
            var fname = path.basename(filePath);
            var dir = path.dirname(filePath);
            return this.create(fname, dir, useChecksum);
        },
        create: function (cacheId, _path, useChecksum) {
            var fs = require('fs');
            var flatCache = require(712) /* flat-cache */;
            var cache = flatCache.load(cacheId, _path);
            var normalizedEntries = {};
            var removeNotFoundFiles = function removeNotFoundFiles() {
                const cachedEntries = cache.keys();
                // remove not found entries
                cachedEntries.forEach(function remover(fPath) {
                    try {
                        fs.statSync(fPath);
                    }
                    catch (err) {
                        if (err.code === 'ENOENT') {
                            cache.removeKey(fPath);
                        }
                    }
                });
            };
            removeNotFoundFiles();
            return {
                /**
                 * the flat cache storage used to persist the metadata of the `files
                 * @type {Object}
                 */
                cache: cache,
                /**
                 * Given a buffer, calculate md5 hash of its content.
                 * @method getHash
                 * @param  {Buffer} buffer   buffer to calculate hash on
                 * @return {String}          content hash digest
                 */
                getHash: function (buffer) {
                    return crypto.createHash('md5').update(buffer).digest('hex');
                },
                /**
                 * Return whether or not a file has changed since last time reconcile was called.
                 * @method hasFileChanged
                 * @param  {String}  file  the filepath to check
                 * @return {Boolean}       wheter or not the file has changed
                 */
                hasFileChanged: function (file) {
                    return this.getFileDescriptor(file).changed;
                },
                /**
                 * given an array of file paths it return and object with three arrays:
                 *  - changedFiles: Files that changed since previous run
                 *  - notChangedFiles: Files that haven't change
                 *  - notFoundFiles: Files that were not found, probably deleted
                 *
                 * @param  {Array} files the files to analyze and compare to the previous seen files
                 * @return {[type]}       [description]
                 */
                analyzeFiles: function (files) {
                    var me = this;
                    files = files || [];
                    var res = {
                        changedFiles: [],
                        notFoundFiles: [],
                        notChangedFiles: [],
                    };
                    me.normalizeEntries(files).forEach(function (entry) {
                        if (entry.changed) {
                            res.changedFiles.push(entry.key);
                            return;
                        }
                        if (entry.notFound) {
                            res.notFoundFiles.push(entry.key);
                            return;
                        }
                        res.notChangedFiles.push(entry.key);
                    });
                    return res;
                },
                getFileDescriptor: function (file) {
                    var fstat;
                    try {
                        fstat = fs.statSync(file);
                    }
                    catch (ex) {
                        this.removeEntry(file);
                        return { key: file, notFound: true, err: ex };
                    }
                    if (useChecksum) {
                        return this._getFileDescriptorUsingChecksum(file);
                    }
                    return this._getFileDescriptorUsingMtimeAndSize(file, fstat);
                },
                _getFileDescriptorUsingMtimeAndSize: function (file, fstat) {
                    var meta = cache.getKey(file);
                    var cacheExists = !!meta;
                    var cSize = fstat.size;
                    var cTime = fstat.mtime.getTime();
                    var isDifferentDate;
                    var isDifferentSize;
                    if (!meta) {
                        meta = { size: cSize, mtime: cTime };
                    }
                    else {
                        isDifferentDate = cTime !== meta.mtime;
                        isDifferentSize = cSize !== meta.size;
                    }
                    var nEntry = (normalizedEntries[file] = {
                        key: file,
                        changed: !cacheExists || isDifferentDate || isDifferentSize,
                        meta: meta,
                    });
                    return nEntry;
                },
                _getFileDescriptorUsingChecksum: function (file) {
                    var meta = cache.getKey(file);
                    var cacheExists = !!meta;
                    var contentBuffer;
                    try {
                        contentBuffer = fs.readFileSync(file);
                    }
                    catch (ex) {
                        contentBuffer = '';
                    }
                    var isDifferent = true;
                    var hash = this.getHash(contentBuffer);
                    if (!meta) {
                        meta = { hash: hash };
                    }
                    else {
                        isDifferent = hash !== meta.hash;
                    }
                    var nEntry = (normalizedEntries[file] = {
                        key: file,
                        changed: !cacheExists || isDifferent,
                        meta: meta,
                    });
                    return nEntry;
                },
                /**
                 * Return the list o the files that changed compared
                 * against the ones stored in the cache
                 *
                 * @method getUpdated
                 * @param files {Array} the array of files to compare against the ones in the cache
                 * @returns {Array}
                 */
                getUpdatedFiles: function (files) {
                    var me = this;
                    files = files || [];
                    return me
                        .normalizeEntries(files)
                        .filter(function (entry) {
                        return entry.changed;
                    })
                        .map(function (entry) {
                        return entry.key;
                    });
                },
                /**
                 * return the list of files
                 * @method normalizeEntries
                 * @param files
                 * @returns {*}
                 */
                normalizeEntries: function (files) {
                    files = files || [];
                    var me = this;
                    var nEntries = files.map(function (file) {
                        return me.getFileDescriptor(file);
                    });
                    //normalizeEntries = nEntries;
                    return nEntries;
                },
                /**
                 * Remove an entry from the file-entry-cache. Useful to force the file to still be considered
                 * modified the next time the process is run
                 *
                 * @method removeEntry
                 * @param entryName
                 */
                removeEntry: function (entryName) {
                    delete normalizedEntries[entryName];
                    cache.removeKey(entryName);
                },
                /**
                 * Delete the cache file from the disk
                 * @method deleteCacheFile
                 */
                deleteCacheFile: function () {
                    cache.removeCacheFile();
                },
                /**
                 * remove the cache from the file and clear the memory cache
                 */
                destroy: function () {
                    normalizedEntries = {};
                    cache.destroy();
                },
                _getMetaForFileUsingCheckSum: function (cacheEntry) {
                    var contentBuffer = fs.readFileSync(cacheEntry.key);
                    var hash = this.getHash(contentBuffer);
                    var meta = Object.assign(cacheEntry.meta, { hash: hash });
                    delete meta.size;
                    delete meta.mtime;
                    return meta;
                },
                _getMetaForFileUsingMtimeAndSize: function (cacheEntry) {
                    var stat = fs.statSync(cacheEntry.key);
                    var meta = Object.assign(cacheEntry.meta, {
                        size: stat.size,
                        mtime: stat.mtime.getTime(),
                    });
                    delete meta.hash;
                    return meta;
                },
                /**
                 * Sync the files and persist them to the cache
                 * @method reconcile
                 */
                reconcile: function (noPrune) {
                    removeNotFoundFiles();
                    noPrune = typeof noPrune === 'undefined' ? true : noPrune;
                    var entries = normalizedEntries;
                    var keys = Object.keys(entries);
                    if (keys.length === 0) {
                        return;
                    }
                    var me = this;
                    keys.forEach(function (entryName) {
                        var cacheEntry = entries[entryName];
                        try {
                            var meta = useChecksum
                                ? me._getMetaForFileUsingCheckSum(cacheEntry)
                                : me._getMetaForFileUsingMtimeAndSize(cacheEntry);
                            cache.setKey(entryName, meta);
                        }
                        catch (err) {
                            // if the file does not exists we don't save it
                            // other errors are just thrown
                            if (err.code !== 'ENOENT') {
                                throw err;
                            }
                        }
                    });
                    cache.save(noPrune);
                },
            };
        },
    };
},
/* flat-cache/src/cache.js */ function _(require, module, exports, __esModule, __esExport) {
    var path = require('path');
    var fs = require('fs');
    var utils = require(713) /* ./utils */;
    var del = require(715) /* ./del */;
    var writeJSON = utils.writeJSON;
    var cache = {
        /**
         * Load a cache identified by the given Id. If the element does not exists, then initialize an empty
         * cache storage. If specified `cacheDir` will be used as the directory to persist the data to. If omitted
         * then the cache module directory `./cache` will be used instead
         *
         * @method load
         * @param docId {String} the id of the cache, would also be used as the name of the file cache
         * @param [cacheDir] {String} directory for the cache entry
         */
        load: function (docId, cacheDir) {
            var me = this;
            me._visited = {};
            me._persisted = {};
            me._pathToFile = cacheDir ? path.resolve(cacheDir, docId) : path.resolve(__dirname, '../.cache/', docId);
            if (fs.existsSync(me._pathToFile)) {
                me._persisted = utils.tryParse(me._pathToFile, {});
            }
        },
        /**
         * Load the cache from the provided file
         * @method loadFile
         * @param  {String} pathToFile the path to the file containing the info for the cache
         */
        loadFile: function (pathToFile) {
            var me = this;
            var dir = path.dirname(pathToFile);
            var fName = path.basename(pathToFile);
            me.load(fName, dir);
        },
        /**
         * Returns the entire persisted object
         * @method all
         * @returns {*}
         */
        all: function () {
            return this._persisted;
        },
        keys: function () {
            return Object.keys(this._persisted);
        },
        /**
         * sets a key to a given value
         * @method setKey
         * @param key {string} the key to set
         * @param value {object} the value of the key. Could be any object that can be serialized with JSON.stringify
         */
        setKey: function (key, value) {
            this._visited[key] = true;
            this._persisted[key] = value;
        },
        /**
         * remove a given key from the cache
         * @method removeKey
         * @param key {String} the key to remove from the object
         */
        removeKey: function (key) {
            delete this._visited[key]; // esfmt-ignore-line
            delete this._persisted[key]; // esfmt-ignore-line
        },
        /**
         * Return the value of the provided key
         * @method getKey
         * @param key {String} the name of the key to retrieve
         * @returns {*} the value from the key
         */
        getKey: function (key) {
            this._visited[key] = true;
            return this._persisted[key];
        },
        /**
         * Remove keys that were not accessed/set since the
         * last time the `prune` method was called.
         * @method _prune
         * @private
         */
        _prune: function () {
            var me = this;
            var obj = {};
            var keys = Object.keys(me._visited);
            // no keys visited for either get or set value
            if (keys.length === 0) {
                return;
            }
            keys.forEach(function (key) {
                obj[key] = me._persisted[key];
            });
            me._visited = {};
            me._persisted = obj;
        },
        /**
         * Save the state of the cache identified by the docId to disk
         * as a JSON structure
         * @param [noPrune=false] {Boolean} whether to remove from cache the non visited files
         * @method save
         */
        save: function (noPrune) {
            var me = this;
            !noPrune && me._prune();
            writeJSON(me._pathToFile, me._persisted);
        },
        /**
         * remove the file where the cache is persisted
         * @method removeCacheFile
         * @return {Boolean} true or false if the file was successfully deleted
         */
        removeCacheFile: function () {
            return del(this._pathToFile);
        },
        /**
         * Destroy the file cache and cache content.
         * @method destroy
         */
        destroy: function () {
            var me = this;
            me._visited = {};
            me._persisted = {};
            me.removeCacheFile();
        },
    };
    module.exports = {
        /**
         * Alias for create. Should be considered depreacted. Will be removed in next releases
         *
         * @method load
         * @param docId {String} the id of the cache, would also be used as the name of the file cache
         * @param [cacheDir] {String} directory for the cache entry
         * @returns {cache} cache instance
         */
        load: function (docId, cacheDir) {
            return this.create(docId, cacheDir);
        },
        /**
         * Load a cache identified by the given Id. If the element does not exists, then initialize an empty
         * cache storage.
         *
         * @method create
         * @param docId {String} the id of the cache, would also be used as the name of the file cache
         * @param [cacheDir] {String} directory for the cache entry
         * @returns {cache} cache instance
         */
        create: function (docId, cacheDir) {
            var obj = Object.create(cache);
            obj.load(docId, cacheDir);
            return obj;
        },
        createFromFile: function (filePath) {
            var obj = Object.create(cache);
            obj.loadFile(filePath);
            return obj;
        },
        /**
         * Clear the cache identified by the given id. Caches stored in a different cache directory can be deleted directly
         *
         * @method clearCache
         * @param docId {String} the id of the cache, would also be used as the name of the file cache
         * @param cacheDir {String} the directory where the cache file was written
         * @returns {Boolean} true if the cache folder was deleted. False otherwise
         */
        clearCacheById: function (docId, cacheDir) {
            var filePath = cacheDir ? path.resolve(cacheDir, docId) : path.resolve(__dirname, '../.cache/', docId);
            return del(filePath);
        },
        /**
         * Remove all cache stored in the cache directory
         * @method clearAll
         * @returns {Boolean} true if the cache folder was deleted. False otherwise
         */
        clearAll: function (cacheDir) {
            var filePath = cacheDir ? path.resolve(cacheDir) : path.resolve(__dirname, '../.cache/');
            return del(filePath);
        },
    };
},
/* flat-cache/src/utils.js */ function _(require, module, exports, __esModule, __esExport) {
    var fs = require('fs');
    var path = require('path');
    var flatted = require(714) /* flatted */;
    module.exports = {
        tryParse: function (filePath, defaultValue) {
            var result;
            try {
                result = this.readJSON(filePath);
            }
            catch (ex) {
                result = defaultValue;
            }
            return result;
        },
        /**
         * Read json file synchronously using flatted
         *
         * @method readJSON
         * @param  {String} filePath Json filepath
         * @returns {*} parse result
         */
        readJSON: function (filePath) {
            return flatted.parse(fs.readFileSync(filePath, {
                encoding: 'utf8',
            }));
        },
        /**
         * Write json file synchronously using circular-json
         *
         * @method writeJSON
         * @param  {String} filePath Json filepath
         * @param  {*} data Object to serialize
         */
        writeJSON: function (filePath, data) {
            fs.mkdirSync(path.dirname(filePath), {
                recursive: true,
            });
            fs.writeFileSync(filePath, flatted.stringify(data));
        },
    };
},
/* flatted/cjs/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    /*! (c) 2020 Andrea Giammarchi */
    const { parse: $parse, stringify: $stringify } = JSON;
    const { keys } = Object;
    const Primitive = String; // it could be Number
    const primitive = 'string'; // it could be 'number'
    const ignore = {};
    const object = 'object';
    const noop = (_, value) => value;
    const primitives = value => (value instanceof Primitive ? Primitive(value) : value);
    const Primitives = (_, value) => (typeof value === primitive ? new Primitive(value) : value);
    const revive = (input, parsed, output, $) => {
        const lazy = [];
        for (let ke = keys(output), { length } = ke, y = 0; y < length; y++) {
            const k = ke[y];
            const value = output[k];
            if (value instanceof Primitive) {
                const tmp = input[value];
                if (typeof tmp === object && !parsed.has(tmp)) {
                    parsed.add(tmp);
                    output[k] = ignore;
                    lazy.push({ k, a: [input, parsed, tmp, $] });
                }
                else
                    output[k] = $.call(output, k, tmp);
            }
            else if (output[k] !== ignore)
                output[k] = $.call(output, k, value);
        }
        for (let { length } = lazy, i = 0; i < length; i++) {
            const { k, a } = lazy[i];
            output[k] = $.call(output, k, revive.apply(null, a));
        }
        return output;
    };
    const set = (known, input, value) => {
        const index = Primitive(input.push(value) - 1);
        known.set(value, index);
        return index;
    };
    const parse = (text, reviver) => {
        const input = $parse(text, Primitives).map(primitives);
        const value = input[0];
        const $ = reviver || noop;
        const tmp = typeof value === object && value ?
            revive(input, new Set, value, $) :
            value;
        return $.call({ '': tmp }, '', tmp);
    };
    exports.parse = parse;
    const stringify = (value, replacer, space) => {
        const $ = replacer && typeof replacer === object ?
            (k, v) => (k === '' || -1 < replacer.indexOf(k) ? v : void 0) :
            (replacer || noop);
        const known = new Map;
        const input = [];
        const output = [];
        let i = +set(known, input, $.call({ '': value }, '', value));
        let firstRun = !i;
        while (i < input.length) {
            firstRun = true;
            output[i] = $stringify(input[i++], replace, space);
        }
        return '[' + output.join(',') + ']';
        function replace(key, value) {
            if (firstRun) {
                firstRun = !firstRun;
                return value;
            }
            const after = $.call(this, key, value);
            switch (typeof after) {
                case object:
                    if (after === null)
                        return after;
                case primitive:
                    return known.get(after) || set(known, input, after);
            }
            return after;
        }
    };
    exports.stringify = stringify;
    const toJSON = any => $parse(stringify(any));
    exports.toJSON = toJSON;
    const fromJSON = any => parse($stringify(any));
    exports.fromJSON = fromJSON;
},
/* flat-cache/src/del.js */ function _(require, module, exports, __esModule, __esExport) {
    var rimraf = require(716) /* rimraf */.sync;
    var fs = require('fs');
    module.exports = function del(file) {
        if (fs.existsSync(file)) {
            //if rimraf doesn't throw then the file has been deleted or didn't exist
            rimraf(file, {
                glob: false,
            });
            return true;
        }
        return false;
    };
},
/* rimraf/rimraf.js */ function _(require, module, exports, __esModule, __esExport) {
    const assert = require("assert");
    const path = require("path");
    const fs = require("fs");
    let glob = undefined;
    try {
        glob = require(717) /* glob */;
    }
    catch (_err) {
        // treat glob as optional.
    }
    const defaultGlobOpts = {
        nosort: true,
        silent: true
    };
    // for EMFILE handling
    let timeout = 0;
    const isWindows = (process.platform === "win32");
    const defaults = options => {
        const methods = [
            'unlink',
            'chmod',
            'stat',
            'lstat',
            'rmdir',
            'readdir'
        ];
        methods.forEach(m => {
            options[m] = options[m] || fs[m];
            m = m + 'Sync';
            options[m] = options[m] || fs[m];
        });
        options.maxBusyTries = options.maxBusyTries || 3;
        options.emfileWait = options.emfileWait || 1000;
        if (options.glob === false) {
            options.disableGlob = true;
        }
        if (options.disableGlob !== true && glob === undefined) {
            throw Error('glob dependency not found, set `options.disableGlob = true` if intentional');
        }
        options.disableGlob = options.disableGlob || false;
        options.glob = options.glob || defaultGlobOpts;
    };
    const rimraf = (p, options, cb) => {
        if (typeof options === 'function') {
            cb = options;
            options = {};
        }
        assert(p, 'rimraf: missing path');
        assert.equal(typeof p, 'string', 'rimraf: path should be a string');
        assert.equal(typeof cb, 'function', 'rimraf: callback function required');
        assert(options, 'rimraf: invalid options argument provided');
        assert.equal(typeof options, 'object', 'rimraf: options should be object');
        defaults(options);
        let busyTries = 0;
        let errState = null;
        let n = 0;
        const next = (er) => {
            errState = errState || er;
            if (--n === 0)
                cb(errState);
        };
        const afterGlob = (er, results) => {
            if (er)
                return cb(er);
            n = results.length;
            if (n === 0)
                return cb();
            results.forEach(p => {
                const CB = (er) => {
                    if (er) {
                        if ((er.code === "EBUSY" || er.code === "ENOTEMPTY" || er.code === "EPERM") &&
                            busyTries < options.maxBusyTries) {
                            busyTries++;
                            // try again, with the same exact callback as this one.
                            return setTimeout(() => rimraf_(p, options, CB), busyTries * 100);
                        }
                        // this one won't happen if graceful-fs is used.
                        if (er.code === "EMFILE" && timeout < options.emfileWait) {
                            return setTimeout(() => rimraf_(p, options, CB), timeout++);
                        }
                        // already gone
                        if (er.code === "ENOENT")
                            er = null;
                    }
                    timeout = 0;
                    next(er);
                };
                rimraf_(p, options, CB);
            });
        };
        if (options.disableGlob || !glob.hasMagic(p))
            return afterGlob(null, [p]);
        options.lstat(p, (er, stat) => {
            if (!er)
                return afterGlob(null, [p]);
            glob(p, options.glob, afterGlob);
        });
    };
    // Two possible strategies.
    // 1. Assume it's a file.  unlink it, then do the dir stuff on EPERM or EISDIR
    // 2. Assume it's a directory.  readdir, then do the file stuff on ENOTDIR
    //
    // Both result in an extra syscall when you guess wrong.  However, there
    // are likely far more normal files in the world than directories.  This
    // is based on the assumption that a the average number of files per
    // directory is >= 1.
    //
    // If anyone ever complains about this, then I guess the strategy could
    // be made configurable somehow.  But until then, YAGNI.
    const rimraf_ = (p, options, cb) => {
        assert(p);
        assert(options);
        assert(typeof cb === 'function');
        // sunos lets the root user unlink directories, which is... weird.
        // so we have to lstat here and make sure it's not a dir.
        options.lstat(p, (er, st) => {
            if (er && er.code === "ENOENT")
                return cb(null);
            // Windows can EPERM on stat.  Life is suffering.
            if (er && er.code === "EPERM" && isWindows)
                fixWinEPERM(p, options, er, cb);
            if (st && st.isDirectory())
                return rmdir(p, options, er, cb);
            options.unlink(p, er => {
                if (er) {
                    if (er.code === "ENOENT")
                        return cb(null);
                    if (er.code === "EPERM")
                        return (isWindows)
                            ? fixWinEPERM(p, options, er, cb)
                            : rmdir(p, options, er, cb);
                    if (er.code === "EISDIR")
                        return rmdir(p, options, er, cb);
                }
                return cb(er);
            });
        });
    };
    const fixWinEPERM = (p, options, er, cb) => {
        assert(p);
        assert(options);
        assert(typeof cb === 'function');
        options.chmod(p, 0o666, er2 => {
            if (er2)
                cb(er2.code === "ENOENT" ? null : er);
            else
                options.stat(p, (er3, stats) => {
                    if (er3)
                        cb(er3.code === "ENOENT" ? null : er);
                    else if (stats.isDirectory())
                        rmdir(p, options, er, cb);
                    else
                        options.unlink(p, cb);
                });
        });
    };
    const fixWinEPERMSync = (p, options, er) => {
        assert(p);
        assert(options);
        try {
            options.chmodSync(p, 0o666);
        }
        catch (er2) {
            if (er2.code === "ENOENT")
                return;
            else
                throw er;
        }
        let stats;
        try {
            stats = options.statSync(p);
        }
        catch (er3) {
            if (er3.code === "ENOENT")
                return;
            else
                throw er;
        }
        if (stats.isDirectory())
            rmdirSync(p, options, er);
        else
            options.unlinkSync(p);
    };
    const rmdir = (p, options, originalEr, cb) => {
        assert(p);
        assert(options);
        assert(typeof cb === 'function');
        // try to rmdir first, and only readdir on ENOTEMPTY or EEXIST (SunOS)
        // if we guessed wrong, and it's not a directory, then
        // raise the original error.
        options.rmdir(p, er => {
            if (er && (er.code === "ENOTEMPTY" || er.code === "EEXIST" || er.code === "EPERM"))
                rmkids(p, options, cb);
            else if (er && er.code === "ENOTDIR")
                cb(originalEr);
            else
                cb(er);
        });
    };
    const rmkids = (p, options, cb) => {
        assert(p);
        assert(options);
        assert(typeof cb === 'function');
        options.readdir(p, (er, files) => {
            if (er)
                return cb(er);
            let n = files.length;
            if (n === 0)
                return options.rmdir(p, cb);
            let errState;
            files.forEach(f => {
                rimraf(path.join(p, f), options, er => {
                    if (errState)
                        return;
                    if (er)
                        return cb(errState = er);
                    if (--n === 0)
                        options.rmdir(p, cb);
                });
            });
        });
    };
    // this looks simpler, and is strictly *faster*, but will
    // tie up the JavaScript thread and fail on excessively
    // deep directory trees.
    const rimrafSync = (p, options) => {
        options = options || {};
        defaults(options);
        assert(p, 'rimraf: missing path');
        assert.equal(typeof p, 'string', 'rimraf: path should be a string');
        assert(options, 'rimraf: missing options');
        assert.equal(typeof options, 'object', 'rimraf: options should be object');
        let results;
        if (options.disableGlob || !glob.hasMagic(p)) {
            results = [p];
        }
        else {
            try {
                options.lstatSync(p);
                results = [p];
            }
            catch (er) {
                results = glob.sync(p, options.glob);
            }
        }
        if (!results.length)
            return;
        for (let i = 0; i < results.length; i++) {
            const p = results[i];
            let st;
            try {
                st = options.lstatSync(p);
            }
            catch (er) {
                if (er.code === "ENOENT")
                    return;
                // Windows can EPERM on stat.  Life is suffering.
                if (er.code === "EPERM" && isWindows)
                    fixWinEPERMSync(p, options, er);
            }
            try {
                // sunos lets the root user unlink directories, which is... weird.
                if (st && st.isDirectory())
                    rmdirSync(p, options, null);
                else
                    options.unlinkSync(p);
            }
            catch (er) {
                if (er.code === "ENOENT")
                    return;
                if (er.code === "EPERM")
                    return isWindows ? fixWinEPERMSync(p, options, er) : rmdirSync(p, options, er);
                if (er.code !== "EISDIR")
                    throw er;
                rmdirSync(p, options, er);
            }
        }
    };
    const rmdirSync = (p, options, originalEr) => {
        assert(p);
        assert(options);
        try {
            options.rmdirSync(p);
        }
        catch (er) {
            if (er.code === "ENOENT")
                return;
            if (er.code === "ENOTDIR")
                throw originalEr;
            if (er.code === "ENOTEMPTY" || er.code === "EEXIST" || er.code === "EPERM")
                rmkidsSync(p, options);
        }
    };
    const rmkidsSync = (p, options) => {
        assert(p);
        assert(options);
        options.readdirSync(p).forEach(f => rimrafSync(path.join(p, f), options));
        // We only end up here once we got ENOTEMPTY at least once, and
        // at this point, we are guaranteed to have removed all the kids.
        // So, we know that it won't be ENOENT or ENOTDIR or anything else.
        // try really hard to delete stuff on windows, because it has a
        // PROFOUNDLY annoying habit of not closing handles promptly when
        // files are deleted, resulting in spurious ENOTEMPTY errors.
        const retries = isWindows ? 100 : 1;
        let i = 0;
        do {
            let threw = true;
            try {
                const ret = options.rmdirSync(p, options);
                threw = false;
                return ret;
            }
            finally {
                if (++i < retries && threw)
                    continue;
            }
        } while (true);
    };
    module.exports = rimraf;
    rimraf.sync = rimrafSync;
},
/* glob/glob.js */ function _(require, module, exports, __esModule, __esExport) {// Approach:
    //
    // 1. Get the minimatch set
    // 2. For each pattern in the set, PROCESS(pattern, false)
    // 3. Store matches per-set, then uniq them
    //
    // PROCESS(pattern, inGlobStar)
    // Get the first [n] items from pattern that are all strings
    // Join these together.  This is PREFIX.
    //   If there is no more remaining, then stat(PREFIX) and
    //   add to matches if it succeeds.  END.
    //
    // If inGlobStar and PREFIX is symlink and points to dir
    //   set ENTRIES = []
    // else readdir(PREFIX) as ENTRIES
    //   If fail, END
    //
    // with ENTRIES
    //   If pattern[n] is GLOBSTAR
    //     // handle the case where the globstar match is empty
    //     // by pruning it out, and testing the resulting pattern
    //     PROCESS(pattern[0..n] + pattern[n+1 .. $], false)
    //     // handle other cases.
    //     for ENTRY in ENTRIES (not dotfiles)
    //       // attach globstar + tail onto the entry
    //       // Mark that this entry is a globstar match
    //       PROCESS(pattern[0..n] + ENTRY + pattern[n .. $], true)
    //
    //   else // not globstar
    //     for ENTRY in ENTRIES (not dotfiles, unless pattern[n] is dot)
    //       Test ENTRY against pattern[n]
    //       If fails, continue
    //       If passes, PROCESS(pattern[0..n] + item + pattern[n+1 .. $])
    //
    // Caveat:
    //   Cache all stats and readdirs results to minimize syscall.  Since all
    //   we ever care about is existence and directory-ness, we can just keep
    //   `true` for files, and [children,...] for directories, or `false` for
    //   things that don't exist.
    module.exports = glob;
    var rp = require(718) /* fs.realpath */;
    var minimatch = require(229) /* minimatch */;
    var Minimatch = minimatch.Minimatch;
    var inherits = require(207) /* inherits */;
    var EE = require('events').EventEmitter;
    var path = require('path');
    var assert = require('assert');
    var isAbsolute = require(720) /* path-is-absolute */;
    var globSync = require(721) /* ./sync.js */;
    var common = require(722) /* ./common.js */;
    var setopts = common.setopts;
    var ownProp = common.ownProp;
    var inflight = require(723) /* inflight */;
    var util = require('util');
    var childrenIgnored = common.childrenIgnored;
    var isIgnored = common.isIgnored;
    var once = require(725) /* once */;
    function glob(pattern, options, cb) {
        if (typeof options === 'function')
            cb = options, options = {};
        if (!options)
            options = {};
        if (options.sync) {
            if (cb)
                throw new TypeError('callback provided to sync glob');
            return globSync(pattern, options);
        }
        return new Glob(pattern, options, cb);
    }
    glob.sync = globSync;
    var GlobSync = glob.GlobSync = globSync.GlobSync;
    // old api surface
    glob.glob = glob;
    function extend(origin, add) {
        if (add === null || typeof add !== 'object') {
            return origin;
        }
        var keys = Object.keys(add);
        var i = keys.length;
        while (i--) {
            origin[keys[i]] = add[keys[i]];
        }
        return origin;
    }
    glob.hasMagic = function (pattern, options_) {
        var options = extend({}, options_);
        options.noprocess = true;
        var g = new Glob(pattern, options);
        var set = g.minimatch.set;
        if (!pattern)
            return false;
        if (set.length > 1)
            return true;
        for (var j = 0; j < set[0].length; j++) {
            if (typeof set[0][j] !== 'string')
                return true;
        }
        return false;
    };
    glob.Glob = Glob;
    inherits(Glob, EE);
    function Glob(pattern, options, cb) {
        if (typeof options === 'function') {
            cb = options;
            options = null;
        }
        if (options && options.sync) {
            if (cb)
                throw new TypeError('callback provided to sync glob');
            return new GlobSync(pattern, options);
        }
        if (!(this instanceof Glob))
            return new Glob(pattern, options, cb);
        setopts(this, pattern, options);
        this._didRealPath = false;
        // process each pattern in the minimatch set
        var n = this.minimatch.set.length;
        // The matches are stored as {<filename>: true,...} so that
        // duplicates are automagically pruned.
        // Later, we do an Object.keys() on these.
        // Keep them as a list so we can fill in when nonull is set.
        this.matches = new Array(n);
        if (typeof cb === 'function') {
            cb = once(cb);
            this.on('error', cb);
            this.on('end', function (matches) {
                cb(null, matches);
            });
        }
        var self = this;
        this._processing = 0;
        this._emitQueue = [];
        this._processQueue = [];
        this.paused = false;
        if (this.noprocess)
            return this;
        if (n === 0)
            return done();
        var sync = true;
        for (var i = 0; i < n; i++) {
            this._process(this.minimatch.set[i], i, false, done);
        }
        sync = false;
        function done() {
            --self._processing;
            if (self._processing <= 0) {
                if (sync) {
                    process.nextTick(function () {
                        self._finish();
                    });
                }
                else {
                    self._finish();
                }
            }
        }
    }
    Glob.prototype._finish = function () {
        assert(this instanceof Glob);
        if (this.aborted)
            return;
        if (this.realpath && !this._didRealpath)
            return this._realpath();
        common.finish(this);
        this.emit('end', this.found);
    };
    Glob.prototype._realpath = function () {
        if (this._didRealpath)
            return;
        this._didRealpath = true;
        var n = this.matches.length;
        if (n === 0)
            return this._finish();
        var self = this;
        for (var i = 0; i < this.matches.length; i++)
            this._realpathSet(i, next);
        function next() {
            if (--n === 0)
                self._finish();
        }
    };
    Glob.prototype._realpathSet = function (index, cb) {
        var matchset = this.matches[index];
        if (!matchset)
            return cb();
        var found = Object.keys(matchset);
        var self = this;
        var n = found.length;
        if (n === 0)
            return cb();
        var set = this.matches[index] = Object.create(null);
        found.forEach(function (p, i) {
            // If there's a problem with the stat, then it means that
            // one or more of the links in the realpath couldn't be
            // resolved.  just return the abs value in that case.
            p = self._makeAbs(p);
            rp.realpath(p, self.realpathCache, function (er, real) {
                if (!er)
                    set[real] = true;
                else if (er.syscall === 'stat')
                    set[p] = true;
                else
                    self.emit('error', er); // srsly wtf right here
                if (--n === 0) {
                    self.matches[index] = set;
                    cb();
                }
            });
        });
    };
    Glob.prototype._mark = function (p) {
        return common.mark(this, p);
    };
    Glob.prototype._makeAbs = function (f) {
        return common.makeAbs(this, f);
    };
    Glob.prototype.abort = function () {
        this.aborted = true;
        this.emit('abort');
    };
    Glob.prototype.pause = function () {
        if (!this.paused) {
            this.paused = true;
            this.emit('pause');
        }
    };
    Glob.prototype.resume = function () {
        if (this.paused) {
            this.emit('resume');
            this.paused = false;
            if (this._emitQueue.length) {
                var eq = this._emitQueue.slice(0);
                this._emitQueue.length = 0;
                for (var i = 0; i < eq.length; i++) {
                    var e = eq[i];
                    this._emitMatch(e[0], e[1]);
                }
            }
            if (this._processQueue.length) {
                var pq = this._processQueue.slice(0);
                this._processQueue.length = 0;
                for (var i = 0; i < pq.length; i++) {
                    var p = pq[i];
                    this._processing--;
                    this._process(p[0], p[1], p[2], p[3]);
                }
            }
        }
    };
    Glob.prototype._process = function (pattern, index, inGlobStar, cb) {
        assert(this instanceof Glob);
        assert(typeof cb === 'function');
        if (this.aborted)
            return;
        this._processing++;
        if (this.paused) {
            this._processQueue.push([pattern, index, inGlobStar, cb]);
            return;
        }
        //console.error('PROCESS %d', this._processing, pattern)
        // Get the first [n] parts of pattern that are all strings.
        var n = 0;
        while (typeof pattern[n] === 'string') {
            n++;
        }
        // now n is the index of the first one that is *not* a string.
        // see if there's anything else
        var prefix;
        switch (n) {
            // if not, then this is rather simple
            case pattern.length:
                this._processSimple(pattern.join('/'), index, cb);
                return;
            case 0:
                // pattern *starts* with some non-trivial item.
                // going to readdir(cwd), but not include the prefix in matches.
                prefix = null;
                break;
            default:
                // pattern has some string bits in the front.
                // whatever it starts with, whether that's 'absolute' like /foo/bar,
                // or 'relative' like '../baz'
                prefix = pattern.slice(0, n).join('/');
                break;
        }
        var remain = pattern.slice(n);
        // get the list of entries.
        var read;
        if (prefix === null)
            read = '.';
        else if (isAbsolute(prefix) ||
            isAbsolute(pattern.map(function (p) {
                return typeof p === 'string' ? p : '[*]';
            }).join('/'))) {
            if (!prefix || !isAbsolute(prefix))
                prefix = '/' + prefix;
            read = prefix;
        }
        else
            read = prefix;
        var abs = this._makeAbs(read);
        //if ignored, skip _processing
        if (childrenIgnored(this, read))
            return cb();
        var isGlobStar = remain[0] === minimatch.GLOBSTAR;
        if (isGlobStar)
            this._processGlobStar(prefix, read, abs, remain, index, inGlobStar, cb);
        else
            this._processReaddir(prefix, read, abs, remain, index, inGlobStar, cb);
    };
    Glob.prototype._processReaddir = function (prefix, read, abs, remain, index, inGlobStar, cb) {
        var self = this;
        this._readdir(abs, inGlobStar, function (er, entries) {
            return self._processReaddir2(prefix, read, abs, remain, index, inGlobStar, entries, cb);
        });
    };
    Glob.prototype._processReaddir2 = function (prefix, read, abs, remain, index, inGlobStar, entries, cb) {
        // if the abs isn't a dir, then nothing can match!
        if (!entries)
            return cb();
        // It will only match dot entries if it starts with a dot, or if
        // dot is set.  Stuff like @(.foo|.bar) isn't allowed.
        var pn = remain[0];
        var negate = !!this.minimatch.negate;
        var rawGlob = pn._glob;
        var dotOk = this.dot || rawGlob.charAt(0) === '.';
        var matchedEntries = [];
        for (var i = 0; i < entries.length; i++) {
            var e = entries[i];
            if (e.charAt(0) !== '.' || dotOk) {
                var m;
                if (negate && !prefix) {
                    m = !e.match(pn);
                }
                else {
                    m = e.match(pn);
                }
                if (m)
                    matchedEntries.push(e);
            }
        }
        //console.error('prd2', prefix, entries, remain[0]._glob, matchedEntries)
        var len = matchedEntries.length;
        // If there are no matched entries, then nothing matches.
        if (len === 0)
            return cb();
        // if this is the last remaining pattern bit, then no need for
        // an additional stat *unless* the user has specified mark or
        // stat explicitly.  We know they exist, since readdir returned
        // them.
        if (remain.length === 1 && !this.mark && !this.stat) {
            if (!this.matches[index])
                this.matches[index] = Object.create(null);
            for (var i = 0; i < len; i++) {
                var e = matchedEntries[i];
                if (prefix) {
                    if (prefix !== '/')
                        e = prefix + '/' + e;
                    else
                        e = prefix + e;
                }
                if (e.charAt(0) === '/' && !this.nomount) {
                    e = path.join(this.root, e);
                }
                this._emitMatch(index, e);
            }
            // This was the last one, and no stats were needed
            return cb();
        }
        // now test all matched entries as stand-ins for that part
        // of the pattern.
        remain.shift();
        for (var i = 0; i < len; i++) {
            var e = matchedEntries[i];
            var newPattern;
            if (prefix) {
                if (prefix !== '/')
                    e = prefix + '/' + e;
                else
                    e = prefix + e;
            }
            this._process([e].concat(remain), index, inGlobStar, cb);
        }
        cb();
    };
    Glob.prototype._emitMatch = function (index, e) {
        if (this.aborted)
            return;
        if (isIgnored(this, e))
            return;
        if (this.paused) {
            this._emitQueue.push([index, e]);
            return;
        }
        var abs = isAbsolute(e) ? e : this._makeAbs(e);
        if (this.mark)
            e = this._mark(e);
        if (this.absolute)
            e = abs;
        if (this.matches[index][e])
            return;
        if (this.nodir) {
            var c = this.cache[abs];
            if (c === 'DIR' || Array.isArray(c))
                return;
        }
        this.matches[index][e] = true;
        var st = this.statCache[abs];
        if (st)
            this.emit('stat', e, st);
        this.emit('match', e);
    };
    Glob.prototype._readdirInGlobStar = function (abs, cb) {
        if (this.aborted)
            return;
        // follow all symlinked directories forever
        // just proceed as if this is a non-globstar situation
        if (this.follow)
            return this._readdir(abs, false, cb);
        var lstatkey = 'lstat\0' + abs;
        var self = this;
        var lstatcb = inflight(lstatkey, lstatcb_);
        if (lstatcb)
            self.fs.lstat(abs, lstatcb);
        function lstatcb_(er, lstat) {
            if (er && er.code === 'ENOENT')
                return cb();
            var isSym = lstat && lstat.isSymbolicLink();
            self.symlinks[abs] = isSym;
            // If it's not a symlink or a dir, then it's definitely a regular file.
            // don't bother doing a readdir in that case.
            if (!isSym && lstat && !lstat.isDirectory()) {
                self.cache[abs] = 'FILE';
                cb();
            }
            else
                self._readdir(abs, false, cb);
        }
    };
    Glob.prototype._readdir = function (abs, inGlobStar, cb) {
        if (this.aborted)
            return;
        cb = inflight('readdir\0' + abs + '\0' + inGlobStar, cb);
        if (!cb)
            return;
        //console.error('RD %j %j', +inGlobStar, abs)
        if (inGlobStar && !ownProp(this.symlinks, abs))
            return this._readdirInGlobStar(abs, cb);
        if (ownProp(this.cache, abs)) {
            var c = this.cache[abs];
            if (!c || c === 'FILE')
                return cb();
            if (Array.isArray(c))
                return cb(null, c);
        }
        var self = this;
        self.fs.readdir(abs, readdirCb(this, abs, cb));
    };
    function readdirCb(self, abs, cb) {
        return function (er, entries) {
            if (er)
                self._readdirError(abs, er, cb);
            else
                self._readdirEntries(abs, entries, cb);
        };
    }
    Glob.prototype._readdirEntries = function (abs, entries, cb) {
        if (this.aborted)
            return;
        // if we haven't asked to stat everything, then just
        // assume that everything in there exists, so we can avoid
        // having to stat it a second time.
        if (!this.mark && !this.stat) {
            for (var i = 0; i < entries.length; i++) {
                var e = entries[i];
                if (abs === '/')
                    e = abs + e;
                else
                    e = abs + '/' + e;
                this.cache[e] = true;
            }
        }
        this.cache[abs] = entries;
        return cb(null, entries);
    };
    Glob.prototype._readdirError = function (f, er, cb) {
        if (this.aborted)
            return;
        // handle errors, and cache the information
        switch (er.code) {
            case 'ENOTSUP': // https://github.com/isaacs/node-glob/issues/205
            case 'ENOTDIR': // totally normal. means it *does* exist.
                var abs = this._makeAbs(f);
                this.cache[abs] = 'FILE';
                if (abs === this.cwdAbs) {
                    var error = new Error(er.code + ' invalid cwd ' + this.cwd);
                    error.path = this.cwd;
                    error.code = er.code;
                    this.emit('error', error);
                    this.abort();
                }
                break;
            case 'ENOENT': // not terribly unusual
            case 'ELOOP':
            case 'ENAMETOOLONG':
            case 'UNKNOWN':
                this.cache[this._makeAbs(f)] = false;
                break;
            default: // some unusual error.  Treat as failure.
                this.cache[this._makeAbs(f)] = false;
                if (this.strict) {
                    this.emit('error', er);
                    // If the error is handled, then we abort
                    // if not, we threw out of here
                    this.abort();
                }
                if (!this.silent)
                    console.error('glob error', er);
                break;
        }
        return cb();
    };
    Glob.prototype._processGlobStar = function (prefix, read, abs, remain, index, inGlobStar, cb) {
        var self = this;
        this._readdir(abs, inGlobStar, function (er, entries) {
            self._processGlobStar2(prefix, read, abs, remain, index, inGlobStar, entries, cb);
        });
    };
    Glob.prototype._processGlobStar2 = function (prefix, read, abs, remain, index, inGlobStar, entries, cb) {
        //console.error('pgs2', prefix, remain[0], entries)
        // no entries means not a dir, so it can never have matches
        // foo.txt/** doesn't match foo.txt
        if (!entries)
            return cb();
        // test without the globstar, and with every child both below
        // and replacing the globstar.
        var remainWithoutGlobStar = remain.slice(1);
        var gspref = prefix ? [prefix] : [];
        var noGlobStar = gspref.concat(remainWithoutGlobStar);
        // the noGlobStar pattern exits the inGlobStar state
        this._process(noGlobStar, index, false, cb);
        var isSym = this.symlinks[abs];
        var len = entries.length;
        // If it's a symlink, and we're in a globstar, then stop
        if (isSym && inGlobStar)
            return cb();
        for (var i = 0; i < len; i++) {
            var e = entries[i];
            if (e.charAt(0) === '.' && !this.dot)
                continue;
            // these two cases enter the inGlobStar state
            var instead = gspref.concat(entries[i], remainWithoutGlobStar);
            this._process(instead, index, true, cb);
            var below = gspref.concat(entries[i], remain);
            this._process(below, index, true, cb);
        }
        cb();
    };
    Glob.prototype._processSimple = function (prefix, index, cb) {
        // XXX review this.  Shouldn't it be doing the mounting etc
        // before doing stat?  kinda weird?
        var self = this;
        this._stat(prefix, function (er, exists) {
            self._processSimple2(prefix, index, er, exists, cb);
        });
    };
    Glob.prototype._processSimple2 = function (prefix, index, er, exists, cb) {
        //console.error('ps2', prefix, exists)
        if (!this.matches[index])
            this.matches[index] = Object.create(null);
        // If it doesn't exist, then just mark the lack of results
        if (!exists)
            return cb();
        if (prefix && isAbsolute(prefix) && !this.nomount) {
            var trail = /[\/\\]$/.test(prefix);
            if (prefix.charAt(0) === '/') {
                prefix = path.join(this.root, prefix);
            }
            else {
                prefix = path.resolve(this.root, prefix);
                if (trail)
                    prefix += '/';
            }
        }
        if (process.platform === 'win32')
            prefix = prefix.replace(/\\/g, '/');
        // Mark this as a match
        this._emitMatch(index, prefix);
        cb();
    };
    // Returns either 'DIR', 'FILE', or false
    Glob.prototype._stat = function (f, cb) {
        var abs = this._makeAbs(f);
        var needDir = f.slice(-1) === '/';
        if (f.length > this.maxLength)
            return cb();
        if (!this.stat && ownProp(this.cache, abs)) {
            var c = this.cache[abs];
            if (Array.isArray(c))
                c = 'DIR';
            // It exists, but maybe not how we need it
            if (!needDir || c === 'DIR')
                return cb(null, c);
            if (needDir && c === 'FILE')
                return cb();
            // otherwise we have to stat, because maybe c=true
            // if we know it exists, but not what it is.
        }
        var exists;
        var stat = this.statCache[abs];
        if (stat !== undefined) {
            if (stat === false)
                return cb(null, stat);
            else {
                var type = stat.isDirectory() ? 'DIR' : 'FILE';
                if (needDir && type === 'FILE')
                    return cb();
                else
                    return cb(null, type, stat);
            }
        }
        var self = this;
        var statcb = inflight('stat\0' + abs, lstatcb_);
        if (statcb)
            self.fs.lstat(abs, statcb);
        function lstatcb_(er, lstat) {
            if (lstat && lstat.isSymbolicLink()) {
                // If it's a symlink, then treat it as the target, unless
                // the target does not exist, then treat it as a file.
                return self.fs.stat(abs, function (er, stat) {
                    if (er)
                        self._stat2(f, abs, null, lstat, cb);
                    else
                        self._stat2(f, abs, er, stat, cb);
                });
            }
            else {
                self._stat2(f, abs, er, lstat, cb);
            }
        }
    };
    Glob.prototype._stat2 = function (f, abs, er, stat, cb) {
        if (er && (er.code === 'ENOENT' || er.code === 'ENOTDIR')) {
            this.statCache[abs] = false;
            return cb();
        }
        var needDir = f.slice(-1) === '/';
        this.statCache[abs] = stat;
        if (abs.slice(-1) === '/' && stat && !stat.isDirectory())
            return cb(null, false, stat);
        var c = true;
        if (stat)
            c = stat.isDirectory() ? 'DIR' : 'FILE';
        this.cache[abs] = this.cache[abs] || c;
        if (needDir && c === 'FILE')
            return cb();
        return cb(null, c, stat);
    };
},
/* fs.realpath/index.js */ function _(require, module, exports, __esModule, __esExport) {
    module.exports = realpath;
    realpath.realpath = realpath;
    realpath.sync = realpathSync;
    realpath.realpathSync = realpathSync;
    realpath.monkeypatch = monkeypatch;
    realpath.unmonkeypatch = unmonkeypatch;
    var fs = require('fs');
    var origRealpath = fs.realpath;
    var origRealpathSync = fs.realpathSync;
    var version = process.version;
    var ok = /^v[0-5]\./.test(version);
    var old = require(719) /* ./old.js */;
    function newError(er) {
        return er && er.syscall === 'realpath' && (er.code === 'ELOOP' ||
            er.code === 'ENOMEM' ||
            er.code === 'ENAMETOOLONG');
    }
    function realpath(p, cache, cb) {
        if (ok) {
            return origRealpath(p, cache, cb);
        }
        if (typeof cache === 'function') {
            cb = cache;
            cache = null;
        }
        origRealpath(p, cache, function (er, result) {
            if (newError(er)) {
                old.realpath(p, cache, cb);
            }
            else {
                cb(er, result);
            }
        });
    }
    function realpathSync(p, cache) {
        if (ok) {
            return origRealpathSync(p, cache);
        }
        try {
            return origRealpathSync(p, cache);
        }
        catch (er) {
            if (newError(er)) {
                return old.realpathSync(p, cache);
            }
            else {
                throw er;
            }
        }
    }
    function monkeypatch() {
        fs.realpath = realpath;
        fs.realpathSync = realpathSync;
    }
    function unmonkeypatch() {
        fs.realpath = origRealpath;
        fs.realpathSync = origRealpathSync;
    }
},
/* fs.realpath/old.js */ function _(require, module, exports, __esModule, __esExport) {// Copyright Joyent, Inc. and other Node contributors.
    //
    // Permission is hereby granted, free of charge, to any person obtaining a
    // copy of this software and associated documentation files (the
    // "Software"), to deal in the Software without restriction, including
    // without limitation the rights to use, copy, modify, merge, publish,
    // distribute, sublicense, and/or sell copies of the Software, and to permit
    // persons to whom the Software is furnished to do so, subject to the
    // following conditions:
    //
    // The above copyright notice and this permission notice shall be included
    // in all copies or substantial portions of the Software.
    //
    // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
    // OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    // MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
    // NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
    // DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
    // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
    // USE OR OTHER DEALINGS IN THE SOFTWARE.
    var pathModule = require('path');
    var isWindows = process.platform === 'win32';
    var fs = require('fs');
    // JavaScript implementation of realpath, ported from node pre-v6
    var DEBUG = process.env.NODE_DEBUG && /fs/.test(process.env.NODE_DEBUG);
    function rethrow() {
        // Only enable in debug mode. A backtrace uses ~1000 bytes of heap space and
        // is fairly slow to generate.
        var callback;
        if (DEBUG) {
            var backtrace = new Error;
            callback = debugCallback;
        }
        else
            callback = missingCallback;
        return callback;
        function debugCallback(err) {
            if (err) {
                backtrace.message = err.message;
                err = backtrace;
                missingCallback(err);
            }
        }
        function missingCallback(err) {
            if (err) {
                if (process.throwDeprecation)
                    throw err; // Forgot a callback but don't know where? Use NODE_DEBUG=fs
                else if (!process.noDeprecation) {
                    var msg = 'fs: missing callback ' + (err.stack || err.message);
                    if (process.traceDeprecation)
                        console.trace(msg);
                    else
                        console.error(msg);
                }
            }
        }
    }
    function maybeCallback(cb) {
        return typeof cb === 'function' ? cb : rethrow();
    }
    var normalize = pathModule.normalize;
    // Regexp that finds the next partion of a (partial) path
    // result is [base_with_slash, base], e.g. ['somedir/', 'somedir']
    if (isWindows) {
        var nextPartRe = /(.*?)(?:[\/\\]+|$)/g;
    }
    else {
        var nextPartRe = /(.*?)(?:[\/]+|$)/g;
    }
    // Regex to find the device root, including trailing slash. E.g. 'c:\\'.
    if (isWindows) {
        var splitRootRe = /^(?:[a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/][^\\\/]+)?[\\\/]*/;
    }
    else {
        var splitRootRe = /^[\/]*/;
    }
    exports.realpathSync = function realpathSync(p, cache) {
        // make p is absolute
        p = pathModule.resolve(p);
        if (cache && Object.prototype.hasOwnProperty.call(cache, p)) {
            return cache[p];
        }
        var original = p, seenLinks = {}, knownHard = {};
        // current character position in p
        var pos;
        // the partial path so far, including a trailing slash if any
        var current;
        // the partial path without a trailing slash (except when pointing at a root)
        var base;
        // the partial path scanned in the previous round, with slash
        var previous;
        start();
        function start() {
            // Skip over roots
            var m = splitRootRe.exec(p);
            pos = m[0].length;
            current = m[0];
            base = m[0];
            previous = '';
            // On windows, check that the root exists. On unix there is no need.
            if (isWindows && !knownHard[base]) {
                fs.lstatSync(base);
                knownHard[base] = true;
            }
        }
        // walk down the path, swapping out linked pathparts for their real
        // values
        // NB: p.length changes.
        while (pos < p.length) {
            // find the next part
            nextPartRe.lastIndex = pos;
            var result = nextPartRe.exec(p);
            previous = current;
            current += result[0];
            base = previous + result[1];
            pos = nextPartRe.lastIndex;
            // continue if not a symlink
            if (knownHard[base] || (cache && cache[base] === base)) {
                continue;
            }
            var resolvedLink;
            if (cache && Object.prototype.hasOwnProperty.call(cache, base)) {
                // some known symbolic link.  no need to stat again.
                resolvedLink = cache[base];
            }
            else {
                var stat = fs.lstatSync(base);
                if (!stat.isSymbolicLink()) {
                    knownHard[base] = true;
                    if (cache)
                        cache[base] = base;
                    continue;
                }
                // read the link if it wasn't read before
                // dev/ino always return 0 on windows, so skip the check.
                var linkTarget = null;
                if (!isWindows) {
                    var id = stat.dev.toString(32) + ':' + stat.ino.toString(32);
                    if (seenLinks.hasOwnProperty(id)) {
                        linkTarget = seenLinks[id];
                    }
                }
                if (linkTarget === null) {
                    fs.statSync(base);
                    linkTarget = fs.readlinkSync(base);
                }
                resolvedLink = pathModule.resolve(previous, linkTarget);
                // track this, if given a cache.
                if (cache)
                    cache[base] = resolvedLink;
                if (!isWindows)
                    seenLinks[id] = linkTarget;
            }
            // resolve the link, then start over
            p = pathModule.resolve(resolvedLink, p.slice(pos));
            start();
        }
        if (cache)
            cache[original] = p;
        return p;
    };
    exports.realpath = function realpath(p, cache, cb) {
        if (typeof cb !== 'function') {
            cb = maybeCallback(cache);
            cache = null;
        }
        // make p is absolute
        p = pathModule.resolve(p);
        if (cache && Object.prototype.hasOwnProperty.call(cache, p)) {
            return process.nextTick(cb.bind(null, null, cache[p]));
        }
        var original = p, seenLinks = {}, knownHard = {};
        // current character position in p
        var pos;
        // the partial path so far, including a trailing slash if any
        var current;
        // the partial path without a trailing slash (except when pointing at a root)
        var base;
        // the partial path scanned in the previous round, with slash
        var previous;
        start();
        function start() {
            // Skip over roots
            var m = splitRootRe.exec(p);
            pos = m[0].length;
            current = m[0];
            base = m[0];
            previous = '';
            // On windows, check that the root exists. On unix there is no need.
            if (isWindows && !knownHard[base]) {
                fs.lstat(base, function (err) {
                    if (err)
                        return cb(err);
                    knownHard[base] = true;
                    LOOP();
                });
            }
            else {
                process.nextTick(LOOP);
            }
        }
        // walk down the path, swapping out linked pathparts for their real
        // values
        function LOOP() {
            // stop if scanned past end of path
            if (pos >= p.length) {
                if (cache)
                    cache[original] = p;
                return cb(null, p);
            }
            // find the next part
            nextPartRe.lastIndex = pos;
            var result = nextPartRe.exec(p);
            previous = current;
            current += result[0];
            base = previous + result[1];
            pos = nextPartRe.lastIndex;
            // continue if not a symlink
            if (knownHard[base] || (cache && cache[base] === base)) {
                return process.nextTick(LOOP);
            }
            if (cache && Object.prototype.hasOwnProperty.call(cache, base)) {
                // known symbolic link.  no need to stat again.
                return gotResolvedLink(cache[base]);
            }
            return fs.lstat(base, gotStat);
        }
        function gotStat(err, stat) {
            if (err)
                return cb(err);
            // if not a symlink, skip to the next path part
            if (!stat.isSymbolicLink()) {
                knownHard[base] = true;
                if (cache)
                    cache[base] = base;
                return process.nextTick(LOOP);
            }
            // stat & read the link if not read before
            // call gotTarget as soon as the link target is known
            // dev/ino always return 0 on windows, so skip the check.
            if (!isWindows) {
                var id = stat.dev.toString(32) + ':' + stat.ino.toString(32);
                if (seenLinks.hasOwnProperty(id)) {
                    return gotTarget(null, seenLinks[id], base);
                }
            }
            fs.stat(base, function (err) {
                if (err)
                    return cb(err);
                fs.readlink(base, function (err, target) {
                    if (!isWindows)
                        seenLinks[id] = target;
                    gotTarget(err, target);
                });
            });
        }
        function gotTarget(err, target, base) {
            if (err)
                return cb(err);
            var resolvedLink = pathModule.resolve(previous, target);
            if (cache)
                cache[base] = resolvedLink;
            gotResolvedLink(resolvedLink);
        }
        function gotResolvedLink(resolvedLink) {
            // resolve the link, then start over
            p = pathModule.resolve(resolvedLink, p.slice(pos));
            start();
        }
    };
},
/* path-is-absolute/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    function posix(path) {
        return path.charAt(0) === '/';
    }
    function win32(path) {
        // https://github.com/nodejs/node/blob/b3fcc245fb25539909ef1d5eaa01dbf92e168633/lib/path.js#L56
        var splitDeviceRe = /^([a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/]+[^\\\/]+)?([\\\/])?([\s\S]*?)$/;
        var result = splitDeviceRe.exec(path);
        var device = result[1] || '';
        var isUnc = Boolean(device && device.charAt(1) !== ':');
        // UNC paths are always absolute
        return Boolean(result[2] || isUnc);
    }
    module.exports = process.platform === 'win32' ? win32 : posix;
    module.exports.posix = posix;
    module.exports.win32 = win32;
},
/* glob/sync.js */ function _(require, module, exports, __esModule, __esExport) {
    module.exports = globSync;
    globSync.GlobSync = GlobSync;
    var rp = require(718) /* fs.realpath */;
    var minimatch = require(229) /* minimatch */;
    var Minimatch = minimatch.Minimatch;
    var Glob = require(717) /* ./glob.js */.Glob;
    var util = require('util');
    var path = require('path');
    var assert = require('assert');
    var isAbsolute = require(720) /* path-is-absolute */;
    var common = require(722) /* ./common.js */;
    var setopts = common.setopts;
    var ownProp = common.ownProp;
    var childrenIgnored = common.childrenIgnored;
    var isIgnored = common.isIgnored;
    function globSync(pattern, options) {
        if (typeof options === 'function' || arguments.length === 3)
            throw new TypeError('callback provided to sync glob\n' +
                'See: https://github.com/isaacs/node-glob/issues/167');
        return new GlobSync(pattern, options).found;
    }
    function GlobSync(pattern, options) {
        if (!pattern)
            throw new Error('must provide pattern');
        if (typeof options === 'function' || arguments.length === 3)
            throw new TypeError('callback provided to sync glob\n' +
                'See: https://github.com/isaacs/node-glob/issues/167');
        if (!(this instanceof GlobSync))
            return new GlobSync(pattern, options);
        setopts(this, pattern, options);
        if (this.noprocess)
            return this;
        var n = this.minimatch.set.length;
        this.matches = new Array(n);
        for (var i = 0; i < n; i++) {
            this._process(this.minimatch.set[i], i, false);
        }
        this._finish();
    }
    GlobSync.prototype._finish = function () {
        assert.ok(this instanceof GlobSync);
        if (this.realpath) {
            var self = this;
            this.matches.forEach(function (matchset, index) {
                var set = self.matches[index] = Object.create(null);
                for (var p in matchset) {
                    try {
                        p = self._makeAbs(p);
                        var real = rp.realpathSync(p, self.realpathCache);
                        set[real] = true;
                    }
                    catch (er) {
                        if (er.syscall === 'stat')
                            set[self._makeAbs(p)] = true;
                        else
                            throw er;
                    }
                }
            });
        }
        common.finish(this);
    };
    GlobSync.prototype._process = function (pattern, index, inGlobStar) {
        assert.ok(this instanceof GlobSync);
        // Get the first [n] parts of pattern that are all strings.
        var n = 0;
        while (typeof pattern[n] === 'string') {
            n++;
        }
        // now n is the index of the first one that is *not* a string.
        // See if there's anything else
        var prefix;
        switch (n) {
            // if not, then this is rather simple
            case pattern.length:
                this._processSimple(pattern.join('/'), index);
                return;
            case 0:
                // pattern *starts* with some non-trivial item.
                // going to readdir(cwd), but not include the prefix in matches.
                prefix = null;
                break;
            default:
                // pattern has some string bits in the front.
                // whatever it starts with, whether that's 'absolute' like /foo/bar,
                // or 'relative' like '../baz'
                prefix = pattern.slice(0, n).join('/');
                break;
        }
        var remain = pattern.slice(n);
        // get the list of entries.
        var read;
        if (prefix === null)
            read = '.';
        else if (isAbsolute(prefix) ||
            isAbsolute(pattern.map(function (p) {
                return typeof p === 'string' ? p : '[*]';
            }).join('/'))) {
            if (!prefix || !isAbsolute(prefix))
                prefix = '/' + prefix;
            read = prefix;
        }
        else
            read = prefix;
        var abs = this._makeAbs(read);
        //if ignored, skip processing
        if (childrenIgnored(this, read))
            return;
        var isGlobStar = remain[0] === minimatch.GLOBSTAR;
        if (isGlobStar)
            this._processGlobStar(prefix, read, abs, remain, index, inGlobStar);
        else
            this._processReaddir(prefix, read, abs, remain, index, inGlobStar);
    };
    GlobSync.prototype._processReaddir = function (prefix, read, abs, remain, index, inGlobStar) {
        var entries = this._readdir(abs, inGlobStar);
        // if the abs isn't a dir, then nothing can match!
        if (!entries)
            return;
        // It will only match dot entries if it starts with a dot, or if
        // dot is set.  Stuff like @(.foo|.bar) isn't allowed.
        var pn = remain[0];
        var negate = !!this.minimatch.negate;
        var rawGlob = pn._glob;
        var dotOk = this.dot || rawGlob.charAt(0) === '.';
        var matchedEntries = [];
        for (var i = 0; i < entries.length; i++) {
            var e = entries[i];
            if (e.charAt(0) !== '.' || dotOk) {
                var m;
                if (negate && !prefix) {
                    m = !e.match(pn);
                }
                else {
                    m = e.match(pn);
                }
                if (m)
                    matchedEntries.push(e);
            }
        }
        var len = matchedEntries.length;
        // If there are no matched entries, then nothing matches.
        if (len === 0)
            return;
        // if this is the last remaining pattern bit, then no need for
        // an additional stat *unless* the user has specified mark or
        // stat explicitly.  We know they exist, since readdir returned
        // them.
        if (remain.length === 1 && !this.mark && !this.stat) {
            if (!this.matches[index])
                this.matches[index] = Object.create(null);
            for (var i = 0; i < len; i++) {
                var e = matchedEntries[i];
                if (prefix) {
                    if (prefix.slice(-1) !== '/')
                        e = prefix + '/' + e;
                    else
                        e = prefix + e;
                }
                if (e.charAt(0) === '/' && !this.nomount) {
                    e = path.join(this.root, e);
                }
                this._emitMatch(index, e);
            }
            // This was the last one, and no stats were needed
            return;
        }
        // now test all matched entries as stand-ins for that part
        // of the pattern.
        remain.shift();
        for (var i = 0; i < len; i++) {
            var e = matchedEntries[i];
            var newPattern;
            if (prefix)
                newPattern = [prefix, e];
            else
                newPattern = [e];
            this._process(newPattern.concat(remain), index, inGlobStar);
        }
    };
    GlobSync.prototype._emitMatch = function (index, e) {
        if (isIgnored(this, e))
            return;
        var abs = this._makeAbs(e);
        if (this.mark)
            e = this._mark(e);
        if (this.absolute) {
            e = abs;
        }
        if (this.matches[index][e])
            return;
        if (this.nodir) {
            var c = this.cache[abs];
            if (c === 'DIR' || Array.isArray(c))
                return;
        }
        this.matches[index][e] = true;
        if (this.stat)
            this._stat(e);
    };
    GlobSync.prototype._readdirInGlobStar = function (abs) {
        // follow all symlinked directories forever
        // just proceed as if this is a non-globstar situation
        if (this.follow)
            return this._readdir(abs, false);
        var entries;
        var lstat;
        var stat;
        try {
            lstat = this.fs.lstatSync(abs);
        }
        catch (er) {
            if (er.code === 'ENOENT') {
                // lstat failed, doesn't exist
                return null;
            }
        }
        var isSym = lstat && lstat.isSymbolicLink();
        this.symlinks[abs] = isSym;
        // If it's not a symlink or a dir, then it's definitely a regular file.
        // don't bother doing a readdir in that case.
        if (!isSym && lstat && !lstat.isDirectory())
            this.cache[abs] = 'FILE';
        else
            entries = this._readdir(abs, false);
        return entries;
    };
    GlobSync.prototype._readdir = function (abs, inGlobStar) {
        var entries;
        if (inGlobStar && !ownProp(this.symlinks, abs))
            return this._readdirInGlobStar(abs);
        if (ownProp(this.cache, abs)) {
            var c = this.cache[abs];
            if (!c || c === 'FILE')
                return null;
            if (Array.isArray(c))
                return c;
        }
        try {
            return this._readdirEntries(abs, this.fs.readdirSync(abs));
        }
        catch (er) {
            this._readdirError(abs, er);
            return null;
        }
    };
    GlobSync.prototype._readdirEntries = function (abs, entries) {
        // if we haven't asked to stat everything, then just
        // assume that everything in there exists, so we can avoid
        // having to stat it a second time.
        if (!this.mark && !this.stat) {
            for (var i = 0; i < entries.length; i++) {
                var e = entries[i];
                if (abs === '/')
                    e = abs + e;
                else
                    e = abs + '/' + e;
                this.cache[e] = true;
            }
        }
        this.cache[abs] = entries;
        // mark and cache dir-ness
        return entries;
    };
    GlobSync.prototype._readdirError = function (f, er) {
        // handle errors, and cache the information
        switch (er.code) {
            case 'ENOTSUP': // https://github.com/isaacs/node-glob/issues/205
            case 'ENOTDIR': // totally normal. means it *does* exist.
                var abs = this._makeAbs(f);
                this.cache[abs] = 'FILE';
                if (abs === this.cwdAbs) {
                    var error = new Error(er.code + ' invalid cwd ' + this.cwd);
                    error.path = this.cwd;
                    error.code = er.code;
                    throw error;
                }
                break;
            case 'ENOENT': // not terribly unusual
            case 'ELOOP':
            case 'ENAMETOOLONG':
            case 'UNKNOWN':
                this.cache[this._makeAbs(f)] = false;
                break;
            default: // some unusual error.  Treat as failure.
                this.cache[this._makeAbs(f)] = false;
                if (this.strict)
                    throw er;
                if (!this.silent)
                    console.error('glob error', er);
                break;
        }
    };
    GlobSync.prototype._processGlobStar = function (prefix, read, abs, remain, index, inGlobStar) {
        var entries = this._readdir(abs, inGlobStar);
        // no entries means not a dir, so it can never have matches
        // foo.txt/** doesn't match foo.txt
        if (!entries)
            return;
        // test without the globstar, and with every child both below
        // and replacing the globstar.
        var remainWithoutGlobStar = remain.slice(1);
        var gspref = prefix ? [prefix] : [];
        var noGlobStar = gspref.concat(remainWithoutGlobStar);
        // the noGlobStar pattern exits the inGlobStar state
        this._process(noGlobStar, index, false);
        var len = entries.length;
        var isSym = this.symlinks[abs];
        // If it's a symlink, and we're in a globstar, then stop
        if (isSym && inGlobStar)
            return;
        for (var i = 0; i < len; i++) {
            var e = entries[i];
            if (e.charAt(0) === '.' && !this.dot)
                continue;
            // these two cases enter the inGlobStar state
            var instead = gspref.concat(entries[i], remainWithoutGlobStar);
            this._process(instead, index, true);
            var below = gspref.concat(entries[i], remain);
            this._process(below, index, true);
        }
    };
    GlobSync.prototype._processSimple = function (prefix, index) {
        // XXX review this.  Shouldn't it be doing the mounting etc
        // before doing stat?  kinda weird?
        var exists = this._stat(prefix);
        if (!this.matches[index])
            this.matches[index] = Object.create(null);
        // If it doesn't exist, then just mark the lack of results
        if (!exists)
            return;
        if (prefix && isAbsolute(prefix) && !this.nomount) {
            var trail = /[\/\\]$/.test(prefix);
            if (prefix.charAt(0) === '/') {
                prefix = path.join(this.root, prefix);
            }
            else {
                prefix = path.resolve(this.root, prefix);
                if (trail)
                    prefix += '/';
            }
        }
        if (process.platform === 'win32')
            prefix = prefix.replace(/\\/g, '/');
        // Mark this as a match
        this._emitMatch(index, prefix);
    };
    // Returns either 'DIR', 'FILE', or false
    GlobSync.prototype._stat = function (f) {
        var abs = this._makeAbs(f);
        var needDir = f.slice(-1) === '/';
        if (f.length > this.maxLength)
            return false;
        if (!this.stat && ownProp(this.cache, abs)) {
            var c = this.cache[abs];
            if (Array.isArray(c))
                c = 'DIR';
            // It exists, but maybe not how we need it
            if (!needDir || c === 'DIR')
                return c;
            if (needDir && c === 'FILE')
                return false;
            // otherwise we have to stat, because maybe c=true
            // if we know it exists, but not what it is.
        }
        var exists;
        var stat = this.statCache[abs];
        if (!stat) {
            var lstat;
            try {
                lstat = this.fs.lstatSync(abs);
            }
            catch (er) {
                if (er && (er.code === 'ENOENT' || er.code === 'ENOTDIR')) {
                    this.statCache[abs] = false;
                    return false;
                }
            }
            if (lstat && lstat.isSymbolicLink()) {
                try {
                    stat = this.fs.statSync(abs);
                }
                catch (er) {
                    stat = lstat;
                }
            }
            else {
                stat = lstat;
            }
        }
        this.statCache[abs] = stat;
        var c = true;
        if (stat)
            c = stat.isDirectory() ? 'DIR' : 'FILE';
        this.cache[abs] = this.cache[abs] || c;
        if (needDir && c === 'FILE')
            return false;
        return c;
    };
    GlobSync.prototype._mark = function (p) {
        return common.mark(this, p);
    };
    GlobSync.prototype._makeAbs = function (f) {
        return common.makeAbs(this, f);
    };
},
/* glob/common.js */ function _(require, module, exports, __esModule, __esExport) {
    exports.setopts = setopts;
    exports.ownProp = ownProp;
    exports.makeAbs = makeAbs;
    exports.finish = finish;
    exports.mark = mark;
    exports.isIgnored = isIgnored;
    exports.childrenIgnored = childrenIgnored;
    function ownProp(obj, field) {
        return Object.prototype.hasOwnProperty.call(obj, field);
    }
    var fs = require("fs");
    var path = require("path");
    var minimatch = require(229) /* minimatch */;
    var isAbsolute = require(720) /* path-is-absolute */;
    var Minimatch = minimatch.Minimatch;
    function alphasort(a, b) {
        return a.localeCompare(b, 'en');
    }
    function setupIgnores(self, options) {
        self.ignore = options.ignore || [];
        if (!Array.isArray(self.ignore))
            self.ignore = [self.ignore];
        if (self.ignore.length) {
            self.ignore = self.ignore.map(ignoreMap);
        }
    }
    // ignore patterns are always in dot:true mode.
    function ignoreMap(pattern) {
        var gmatcher = null;
        if (pattern.slice(-3) === '/**') {
            var gpattern = pattern.replace(/(\/\*\*)+$/, '');
            gmatcher = new Minimatch(gpattern, { dot: true });
        }
        return {
            matcher: new Minimatch(pattern, { dot: true }),
            gmatcher: gmatcher
        };
    }
    function setopts(self, pattern, options) {
        if (!options)
            options = {};
        // base-matching: just use globstar for that.
        if (options.matchBase && -1 === pattern.indexOf("/")) {
            if (options.noglobstar) {
                throw new Error("base matching requires globstar");
            }
            pattern = "**/" + pattern;
        }
        self.silent = !!options.silent;
        self.pattern = pattern;
        self.strict = options.strict !== false;
        self.realpath = !!options.realpath;
        self.realpathCache = options.realpathCache || Object.create(null);
        self.follow = !!options.follow;
        self.dot = !!options.dot;
        self.mark = !!options.mark;
        self.nodir = !!options.nodir;
        if (self.nodir)
            self.mark = true;
        self.sync = !!options.sync;
        self.nounique = !!options.nounique;
        self.nonull = !!options.nonull;
        self.nosort = !!options.nosort;
        self.nocase = !!options.nocase;
        self.stat = !!options.stat;
        self.noprocess = !!options.noprocess;
        self.absolute = !!options.absolute;
        self.fs = options.fs || fs;
        self.maxLength = options.maxLength || Infinity;
        self.cache = options.cache || Object.create(null);
        self.statCache = options.statCache || Object.create(null);
        self.symlinks = options.symlinks || Object.create(null);
        setupIgnores(self, options);
        self.changedCwd = false;
        var cwd = process.cwd();
        if (!ownProp(options, "cwd"))
            self.cwd = cwd;
        else {
            self.cwd = path.resolve(options.cwd);
            self.changedCwd = self.cwd !== cwd;
        }
        self.root = options.root || path.resolve(self.cwd, "/");
        self.root = path.resolve(self.root);
        if (process.platform === "win32")
            self.root = self.root.replace(/\\/g, "/");
        // TODO: is an absolute `cwd` supposed to be resolved against `root`?
        // e.g. { cwd: '/test', root: __dirname } === path.join(__dirname, '/test')
        self.cwdAbs = isAbsolute(self.cwd) ? self.cwd : makeAbs(self, self.cwd);
        if (process.platform === "win32")
            self.cwdAbs = self.cwdAbs.replace(/\\/g, "/");
        self.nomount = !!options.nomount;
        // disable comments and negation in Minimatch.
        // Note that they are not supported in Glob itself anyway.
        options.nonegate = true;
        options.nocomment = true;
        // always treat \ in patterns as escapes, not path separators
        options.allowWindowsEscape = false;
        self.minimatch = new Minimatch(pattern, options);
        self.options = self.minimatch.options;
    }
    function finish(self) {
        var nou = self.nounique;
        var all = nou ? [] : Object.create(null);
        for (var i = 0, l = self.matches.length; i < l; i++) {
            var matches = self.matches[i];
            if (!matches || Object.keys(matches).length === 0) {
                if (self.nonull) {
                    // do like the shell, and spit out the literal glob
                    var literal = self.minimatch.globSet[i];
                    if (nou)
                        all.push(literal);
                    else
                        all[literal] = true;
                }
            }
            else {
                // had matches
                var m = Object.keys(matches);
                if (nou)
                    all.push.apply(all, m);
                else
                    m.forEach(function (m) {
                        all[m] = true;
                    });
            }
        }
        if (!nou)
            all = Object.keys(all);
        if (!self.nosort)
            all = all.sort(alphasort);
        // at *some* point we statted all of these
        if (self.mark) {
            for (var i = 0; i < all.length; i++) {
                all[i] = self._mark(all[i]);
            }
            if (self.nodir) {
                all = all.filter(function (e) {
                    var notDir = !(/\/$/.test(e));
                    var c = self.cache[e] || self.cache[makeAbs(self, e)];
                    if (notDir && c)
                        notDir = c !== 'DIR' && !Array.isArray(c);
                    return notDir;
                });
            }
        }
        if (self.ignore.length)
            all = all.filter(function (m) {
                return !isIgnored(self, m);
            });
        self.found = all;
    }
    function mark(self, p) {
        var abs = makeAbs(self, p);
        var c = self.cache[abs];
        var m = p;
        if (c) {
            var isDir = c === 'DIR' || Array.isArray(c);
            var slash = p.slice(-1) === '/';
            if (isDir && !slash)
                m += '/';
            else if (!isDir && slash)
                m = m.slice(0, -1);
            if (m !== p) {
                var mabs = makeAbs(self, m);
                self.statCache[mabs] = self.statCache[abs];
                self.cache[mabs] = self.cache[abs];
            }
        }
        return m;
    }
    // lotta situps...
    function makeAbs(self, f) {
        var abs = f;
        if (f.charAt(0) === '/') {
            abs = path.join(self.root, f);
        }
        else if (isAbsolute(f) || f === '') {
            abs = f;
        }
        else if (self.changedCwd) {
            abs = path.resolve(self.cwd, f);
        }
        else {
            abs = path.resolve(f);
        }
        if (process.platform === 'win32')
            abs = abs.replace(/\\/g, '/');
        return abs;
    }
    // Return true, if pattern ends with globstar '**', for the accompanying parent directory.
    // Ex:- If node_modules/** is the pattern, add 'node_modules' to ignore list along with it's contents
    function isIgnored(self, path) {
        if (!self.ignore.length)
            return false;
        return self.ignore.some(function (item) {
            return item.matcher.match(path) || !!(item.gmatcher && item.gmatcher.match(path));
        });
    }
    function childrenIgnored(self, path) {
        if (!self.ignore.length)
            return false;
        return self.ignore.some(function (item) {
            return !!(item.gmatcher && item.gmatcher.match(path));
        });
    }
},
/* inflight/inflight.js */ function _(require, module, exports, __esModule, __esExport) {
    var wrappy = require(724) /* wrappy */;
    var reqs = Object.create(null);
    var once = require(725) /* once */;
    module.exports = wrappy(inflight);
    function inflight(key, cb) {
        if (reqs[key]) {
            reqs[key].push(cb);
            return null;
        }
        else {
            reqs[key] = [cb];
            return makeres(key);
        }
    }
    function makeres(key) {
        return once(function RES() {
            var cbs = reqs[key];
            var len = cbs.length;
            var args = slice(arguments);
            // XXX It's somewhat ambiguous whether a new callback added in this
            // pass should be queued for later execution if something in the
            // list of callbacks throws, or if it should just be discarded.
            // However, it's such an edge case that it hardly matters, and either
            // choice is likely as surprising as the other.
            // As it happens, we do go ahead and schedule it for later execution.
            try {
                for (var i = 0; i < len; i++) {
                    cbs[i].apply(null, args);
                }
            }
            finally {
                if (cbs.length > len) {
                    // added more in the interim.
                    // de-zalgo, just in case, but don't call again.
                    cbs.splice(0, len);
                    process.nextTick(function () {
                        RES.apply(null, args);
                    });
                }
                else {
                    delete reqs[key];
                }
            }
        });
    }
    function slice(args) {
        var length = args.length;
        var array = [];
        for (var i = 0; i < length; i++)
            array[i] = args[i];
        return array;
    }
},
/* wrappy/wrappy.js */ function _(require, module, exports, __esModule, __esExport) {
    // Returns a wrapper function that returns a wrapped callback
    // The wrapper function should do some stuff, and return a
    // presumably different callback function.
    // This makes sure that own properties are retained, so that
    // decorations and such are not lost along the way.
    module.exports = wrappy;
    function wrappy(fn, cb) {
        if (fn && cb)
            return wrappy(fn)(cb);
        if (typeof fn !== 'function')
            throw new TypeError('need wrapper function');
        Object.keys(fn).forEach(function (k) {
            wrapper[k] = fn[k];
        });
        return wrapper;
        function wrapper() {
            var args = new Array(arguments.length);
            for (var i = 0; i < args.length; i++) {
                args[i] = arguments[i];
            }
            var ret = fn.apply(this, args);
            var cb = args[args.length - 1];
            if (typeof ret === 'function' && ret !== cb) {
                Object.keys(cb).forEach(function (k) {
                    ret[k] = cb[k];
                });
            }
            return ret;
        }
    }
},
/* once/once.js */ function _(require, module, exports, __esModule, __esExport) {
    var wrappy = require(724) /* wrappy */;
    module.exports = wrappy(once);
    module.exports.strict = wrappy(onceStrict);
    once.proto = once(function () {
        Object.defineProperty(Function.prototype, 'once', {
            value: function () {
                return once(this);
            },
            configurable: true
        });
        Object.defineProperty(Function.prototype, 'onceStrict', {
            value: function () {
                return onceStrict(this);
            },
            configurable: true
        });
    });
    function once(fn) {
        var f = function () {
            if (f.called)
                return f.value;
            f.called = true;
            return f.value = fn.apply(this, arguments);
        };
        f.called = false;
        return f;
    }
    function onceStrict(fn) {
        var f = function () {
            if (f.called)
                throw new Error(f.onceError);
            f.called = true;
            return f.value = fn.apply(this, arguments);
        };
        var name = fn.name || 'Function wrapped with `once`';
        f.onceError = name + " shouldn't be called more than once";
        f.called = false;
        return f;
    }
},
/* json-stable-stringify-without-jsonify/index.js */ function _(require, module, exports, __esModule, __esExport) {
    module.exports = function (obj, opts) {
        if (!opts)
            opts = {};
        if (typeof opts === 'function')
            opts = { cmp: opts };
        var space = opts.space || '';
        if (typeof space === 'number')
            space = Array(space + 1).join(' ');
        var cycles = (typeof opts.cycles === 'boolean') ? opts.cycles : false;
        var replacer = opts.replacer || function (key, value) { return value; };
        var cmp = opts.cmp && (function (f) {
            return function (node) {
                return function (a, b) {
                    var aobj = { key: a, value: node[a] };
                    var bobj = { key: b, value: node[b] };
                    return f(aobj, bobj);
                };
            };
        })(opts.cmp);
        var seen = [];
        return (function stringify(parent, key, node, level) {
            var indent = space ? ('\n' + new Array(level + 1).join(space)) : '';
            var colonSeparator = space ? ': ' : ':';
            if (node && node.toJSON && typeof node.toJSON === 'function') {
                node = node.toJSON();
            }
            node = replacer.call(parent, key, node);
            if (node === undefined) {
                return;
            }
            if (typeof node !== 'object' || node === null) {
                return JSON.stringify(node);
            }
            if (isArray(node)) {
                var out = [];
                for (var i = 0; i < node.length; i++) {
                    var item = stringify(node, i, node[i], level + 1) || JSON.stringify(null);
                    out.push(indent + space + item);
                }
                return '[' + out.join(',') + indent + ']';
            }
            else {
                if (seen.indexOf(node) !== -1) {
                    if (cycles)
                        return JSON.stringify('__cycle__');
                    throw new TypeError('Converting circular structure to JSON');
                }
                else
                    seen.push(node);
                var keys = objectKeys(node).sort(cmp && cmp(node));
                var out = [];
                for (var i = 0; i < keys.length; i++) {
                    var key = keys[i];
                    var value = stringify(node, key, node[key], level + 1);
                    if (!value)
                        continue;
                    var keyValue = JSON.stringify(key)
                        + colonSeparator
                        + value;
                    ;
                    out.push(indent + space + keyValue);
                }
                seen.splice(seen.indexOf(node), 1);
                return '{' + out.join(',') + indent + '}';
            }
        })({ '': obj }, '', obj, 0);
    };
    var isArray = Array.isArray || function (x) {
        return {}.toString.call(x) === '[object Array]';
    };
    var objectKeys = Object.keys || function (obj) {
        var has = Object.prototype.hasOwnProperty || function () { return true; };
        var keys = [];
        for (var key in obj) {
            if (has.call(obj, key))
                keys.push(key);
        }
        return keys;
    };
},
/* eslint/lib/eslint/flat-eslint.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Main class using flat config
     * @author Nicholas C. Zakas
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    // Note: Node.js 12 does not support fs/promises.
    const fs = require("fs").promises;
    const path = require("path");
    const findUp = require(728) /* find-up */;
    const { version } = require(221) /* ../../package.json */;
    const { Linter } = require(289) /* ../linter */;
    const { getRuleFromConfig } = require(694) /* ../config/flat-config-helpers */;
    const { Legacy: { ConfigOps: { getRuleSeverity }, ModuleResolver, naming } } = require(222) /* @eslint/eslintrc */;
    const { findFiles, getCacheFile, isNonEmptyString, isArrayOfNonEmptyString, createIgnoreResult, isErrorMessage, processOptions } = require(734) /* ./eslint-helpers */;
    const { pathToFileURL } = require("url");
    const { FlatConfigArray } = require(695) /* ../config/flat-config-array */;
    const LintResultCache = require(710) /* ../cli-engine/lint-result-cache */;
    /*
     * This is necessary to allow overwriting writeFile for testing purposes.
     * We can just use fs/promises once we drop Node.js 12 support.
     */
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    // For VSCode IntelliSense
    /** @typedef {import("../shared/types").ConfigData} ConfigData */
    /** @typedef {import("../shared/types").DeprecatedRuleInfo} DeprecatedRuleInfo */
    /** @typedef {import("../shared/types").LintMessage} LintMessage */
    /** @typedef {import("../shared/types").ParserOptions} ParserOptions */
    /** @typedef {import("../shared/types").Plugin} Plugin */
    /** @typedef {import("../shared/types").ResultsMeta} ResultsMeta */
    /** @typedef {import("../shared/types").RuleConf} RuleConf */
    /** @typedef {import("../shared/types").Rule} Rule */
    /** @typedef {ReturnType<ConfigArray.extractConfig>} ExtractedConfig */
    /**
     * The options with which to configure the ESLint instance.
     * @typedef {Object} FlatESLintOptions
     * @property {boolean} [allowInlineConfig] Enable or disable inline configuration comments.
     * @property {ConfigData} [baseConfig] Base config object, extended by all configs used with this instance
     * @property {boolean} [cache] Enable result caching.
     * @property {string} [cacheLocation] The cache file to use instead of .eslintcache.
     * @property {"metadata" | "content"} [cacheStrategy] The strategy used to detect changed files.
     * @property {string} [cwd] The value to use for the current working directory.
     * @property {boolean} [errorOnUnmatchedPattern] If `false` then `ESLint#lintFiles()` doesn't throw even if no target files found. Defaults to `true`.
     * @property {boolean|Function} [fix] Execute in autofix mode. If a function, should return a boolean.
     * @property {string[]} [fixTypes] Array of rule types to apply fixes for.
     * @property {boolean} [globInputPaths] Set to false to skip glob resolution of input file paths to lint (default: true). If false, each input file paths is assumed to be a non-glob path to an existing file.
     * @property {boolean} [ignore] False disables all ignore patterns except for the default ones.
     * @property {string[]} [ignorePatterns] Ignore file patterns to use in addition to config ignores.
     * @property {ConfigData} [overrideConfig] Override config object, overrides all configs used with this instance
     * @property {boolean|string} [overrideConfigFile] Searches for default config file when falsy;
     *      doesn't do any config file lookup when `true`; considered to be a config filename
     *      when a string.
     * @property {Record<string,Plugin>} [plugins] An array of plugin implementations.
     * @property {"error" | "warn" | "off"} [reportUnusedDisableDirectives] the severity to report unused eslint-disable directives.
     */
    //------------------------------------------------------------------------------
    // Helpers
    //------------------------------------------------------------------------------
    const FLAT_CONFIG_FILENAME = "eslint.config.js";
    const debug = require(72) /* debug */("eslint:flat-eslint");
    const removedFormatters = new Set(["table", "codeframe"]);
    const privateMembers = new WeakMap();
    const importedConfigFileModificationTime = new Map();
    /**
     * It will calculate the error and warning count for collection of messages per file
     * @param {LintMessage[]} messages Collection of messages
     * @returns {Object} Contains the stats
     * @private
     */
    function calculateStatsPerFile(messages) {
        return messages.reduce((stat, message) => {
            if (message.fatal || message.severity === 2) {
                stat.errorCount++;
                if (message.fatal) {
                    stat.fatalErrorCount++;
                }
                if (message.fix) {
                    stat.fixableErrorCount++;
                }
            }
            else {
                stat.warningCount++;
                if (message.fix) {
                    stat.fixableWarningCount++;
                }
            }
            return stat;
        }, {
            errorCount: 0,
            fatalErrorCount: 0,
            warningCount: 0,
            fixableErrorCount: 0,
            fixableWarningCount: 0
        });
    }
    /**
     * It will calculate the error and warning count for collection of results from all files
     * @param {LintResult[]} results Collection of messages from all the files
     * @returns {Object} Contains the stats
     * @private
     */
    function calculateStatsPerRun(results) {
        return results.reduce((stat, result) => {
            stat.errorCount += result.errorCount;
            stat.fatalErrorCount += result.fatalErrorCount;
            stat.warningCount += result.warningCount;
            stat.fixableErrorCount += result.fixableErrorCount;
            stat.fixableWarningCount += result.fixableWarningCount;
            return stat;
        }, {
            errorCount: 0,
            fatalErrorCount: 0,
            warningCount: 0,
            fixableErrorCount: 0,
            fixableWarningCount: 0
        });
    }
    /**
     * Create rulesMeta object.
     * @param {Map<string,Rule>} rules a map of rules from which to generate the object.
     * @returns {Object} metadata for all enabled rules.
     */
    function createRulesMeta(rules) {
        return Array.from(rules).reduce((retVal, [id, rule]) => {
            retVal[id] = rule.meta;
            return retVal;
        }, {});
    }
    /**
     * Return the absolute path of a file named `"__placeholder__.js"` in a given directory.
     * This is used as a replacement for a missing file path.
     * @param {string} cwd An absolute directory path.
     * @returns {string} The absolute path of a file named `"__placeholder__.js"` in the given directory.
     */
    function getPlaceholderPath(cwd) {
        return path.join(cwd, "__placeholder__.js");
    }
    /** @type {WeakMap<ExtractedConfig, DeprecatedRuleInfo[]>} */
    const usedDeprecatedRulesCache = new WeakMap();
    /**
     * Create used deprecated rule list.
     * @param {CLIEngine} eslint The CLIEngine instance.
     * @param {string} maybeFilePath The absolute path to a lint target file or `"<text>"`.
     * @returns {DeprecatedRuleInfo[]} The used deprecated rule list.
     */
    function getOrFindUsedDeprecatedRules(eslint, maybeFilePath) {
        const { configs, options: { cwd } } = privateMembers.get(eslint);
        const filePath = path.isAbsolute(maybeFilePath)
            ? maybeFilePath
            : getPlaceholderPath(cwd);
        const config = configs.getConfig(filePath);
        // Most files use the same config, so cache it.
        if (config && !usedDeprecatedRulesCache.has(config)) {
            const retv = [];
            if (config.rules) {
                for (const [ruleId, ruleConf] of Object.entries(config.rules)) {
                    if (getRuleSeverity(ruleConf) === 0) {
                        continue;
                    }
                    const rule = getRuleFromConfig(ruleId, config);
                    const meta = rule && rule.meta;
                    if (meta && meta.deprecated) {
                        retv.push({ ruleId, replacedBy: meta.replacedBy || [] });
                    }
                }
            }
            usedDeprecatedRulesCache.set(config, Object.freeze(retv));
        }
        return config ? usedDeprecatedRulesCache.get(config) : Object.freeze([]);
    }
    /**
     * Processes the linting results generated by a CLIEngine linting report to
     * match the ESLint class's API.
     * @param {CLIEngine} eslint The CLIEngine instance.
     * @param {CLIEngineLintReport} report The CLIEngine linting report to process.
     * @returns {LintResult[]} The processed linting results.
     */
    function processLintReport(eslint, { results }) {
        const descriptor = {
            configurable: true,
            enumerable: true,
            get() {
                return getOrFindUsedDeprecatedRules(eslint, this.filePath);
            }
        };
        for (const result of results) {
            Object.defineProperty(result, "usedDeprecatedRules", descriptor);
        }
        return results;
    }
    /**
     * An Array.prototype.sort() compatible compare function to order results by their file path.
     * @param {LintResult} a The first lint result.
     * @param {LintResult} b The second lint result.
     * @returns {number} An integer representing the order in which the two results should occur.
     */
    function compareResultsByFilePath(a, b) {
        if (a.filePath < b.filePath) {
            return -1;
        }
        if (a.filePath > b.filePath) {
            return 1;
        }
        return 0;
    }
    /**
     * Searches from the current working directory up until finding the
     * given flat config filename.
     * @param {string} cwd The current working directory to search from.
     * @returns {Promise<string|null>} The filename if found or `null` if not.
     */
    function findFlatConfigFile(cwd) {
        return findUp(FLAT_CONFIG_FILENAME, { cwd });
    }
    /**
     * Load the config array from the given filename.
     * @param {string} filePath The filename to load from.
     * @returns {Promise<any>} The config loaded from the config file.
     */
    async function loadFlatConfigFile(filePath) {
        debug(`Loading config from ${filePath}`);
        const fileURL = pathToFileURL(filePath);
        debug(`Config file URL is ${fileURL}`);
        const mtime = (await fs.stat(filePath)).mtime.getTime();
        /*
         * Append a query with the config file's modification time (`mtime`) in order
         * to import the current version of the config file. Without the query, `import()` would
         * cache the config file module by the pathname only, and then always return
         * the same version (the one that was actual when the module was imported for the first time).
         *
         * This ensures that the config file module is loaded and executed again
         * if it has been changed since the last time it was imported.
         * If it hasn't been changed, `import()` will just return the cached version.
         *
         * Note that we should not overuse queries (e.g., by appending the current time
         * to always reload the config file module) as that could cause memory leaks
         * because entries are never removed from the import cache.
         */
        fileURL.searchParams.append("mtime", mtime);
        /*
         * With queries, we can bypass the import cache. However, when import-ing a CJS module,
         * Node.js uses the require infrastructure under the hood. That includes the require cache,
         * which caches the config file module by its file path (queries have no effect).
         * Therefore, we also need to clear the require cache before importing the config file module.
         * In order to get the same behavior with ESM and CJS config files, in particular - to reload
         * the config file only if it has been changed, we track file modification times and clear
         * the require cache only if the file has been changed.
         */
        if (importedConfigFileModificationTime.get(filePath) !== mtime) {
            delete require.cache[filePath];
        }
        const config = (await import(fileURL)).default;
        importedConfigFileModificationTime.set(filePath, mtime);
        return config;
    }
    /**
     * Calculates the config array for this run based on inputs.
     * @param {FlatESLint} eslint The instance to create the config array for.
     * @param {import("./eslint").ESLintOptions} options The ESLint instance options.
     * @returns {FlatConfigArray} The config array for `eslint``.
     */
    async function calculateConfigArray(eslint, { cwd, baseConfig, overrideConfig, configFile, ignore: shouldIgnore, ignorePatterns }) {
        // check for cached instance
        const slots = privateMembers.get(eslint);
        if (slots.configs) {
            return slots.configs;
        }
        // determine where to load config file from
        let configFilePath;
        let basePath = cwd;
        if (typeof configFile === "string") {
            debug(`Override config file path is ${configFile}`);
            configFilePath = path.resolve(cwd, configFile);
        }
        else if (configFile !== false) {
            debug("Searching for eslint.config.js");
            configFilePath = await findFlatConfigFile(cwd);
            if (!configFilePath) {
                throw new Error("Could not find config file.");
            }
            basePath = path.resolve(path.dirname(configFilePath));
        }
        const configs = new FlatConfigArray(baseConfig || [], { basePath, shouldIgnore });
        // load config file
        if (configFilePath) {
            const fileConfig = await loadFlatConfigFile(configFilePath);
            if (Array.isArray(fileConfig)) {
                configs.push(...fileConfig);
            }
            else {
                configs.push(fileConfig);
            }
        }
        // add in any configured defaults
        configs.push(...slots.defaultConfigs);
        let allIgnorePatterns = [];
        // append command line ignore patterns
        if (ignorePatterns) {
            if (typeof ignorePatterns === "string") {
                allIgnorePatterns.push(ignorePatterns);
            }
            else {
                allIgnorePatterns.push(...ignorePatterns);
            }
        }
        /*
         * If the config file basePath is different than the cwd, then
         * the ignore patterns won't work correctly. Here, we adjust the
         * ignore pattern to include the correct relative path. Patterns
         * loaded from ignore files are always relative to the cwd, whereas
         * the config file basePath can be an ancestor of the cwd.
         */
        if (basePath !== cwd && allIgnorePatterns.length) {
            const relativeIgnorePath = path.relative(basePath, cwd);
            allIgnorePatterns = allIgnorePatterns.map(pattern => {
                const negated = pattern.startsWith("!");
                const basePattern = negated ? pattern.slice(1) : pattern;
                return (negated ? "!" : "") +
                    path.posix.join(relativeIgnorePath, basePattern);
            });
        }
        if (allIgnorePatterns.length) {
            /*
             * Ignore patterns are added to the end of the config array
             * so they can override default ignores.
             */
            configs.push({
                ignores: allIgnorePatterns
            });
        }
        if (overrideConfig) {
            if (Array.isArray(overrideConfig)) {
                configs.push(...overrideConfig);
            }
            else {
                configs.push(overrideConfig);
            }
        }
        await configs.normalize();
        // cache the config array for this instance
        slots.configs = configs;
        return configs;
    }
    /**
     * Processes an source code using ESLint.
     * @param {Object} config The config object.
     * @param {string} config.text The source code to verify.
     * @param {string} config.cwd The path to the current working directory.
     * @param {string|undefined} config.filePath The path to the file of `text`. If this is undefined, it uses `<text>`.
     * @param {FlatConfigArray} config.configs The config.
     * @param {boolean} config.fix If `true` then it does fix.
     * @param {boolean} config.allowInlineConfig If `true` then it uses directive comments.
     * @param {boolean} config.reportUnusedDisableDirectives If `true` then it reports unused `eslint-disable` comments.
     * @param {Linter} config.linter The linter instance to verify.
     * @returns {LintResult} The result of linting.
     * @private
     */
    function verifyText({ text, cwd, filePath: providedFilePath, configs, fix, allowInlineConfig, reportUnusedDisableDirectives, linter }) {
        const filePath = providedFilePath || "<text>";
        debug(`Lint ${filePath}`);
        /*
         * Verify.
         * `config.extractConfig(filePath)` requires an absolute path, but `linter`
         * doesn't know CWD, so it gives `linter` an absolute path always.
         */
        const filePathToVerify = filePath === "<text>" ? getPlaceholderPath(cwd) : filePath;
        const { fixed, messages, output } = linter.verifyAndFix(text, configs, {
            allowInlineConfig,
            filename: filePathToVerify,
            fix,
            reportUnusedDisableDirectives,
            /**
             * Check if the linter should adopt a given code block or not.
             * @param {string} blockFilename The virtual filename of a code block.
             * @returns {boolean} `true` if the linter should adopt the code block.
             */
            filterCodeBlock(blockFilename) {
                return configs.isExplicitMatch(blockFilename);
            }
        });
        // Tweak and return.
        const result = {
            filePath: filePath === "<text>" ? filePath : path.resolve(filePath),
            messages,
            suppressedMessages: linter.getSuppressedMessages(),
            ...calculateStatsPerFile(messages)
        };
        if (fixed) {
            result.output = output;
        }
        if (result.errorCount + result.warningCount > 0 &&
            typeof result.output === "undefined") {
            result.source = text;
        }
        return result;
    }
    /**
     * Checks whether a message's rule type should be fixed.
     * @param {LintMessage} message The message to check.
     * @param {FlatConfig} config The config for the file that generated the message.
     * @param {string[]} fixTypes An array of fix types to check.
     * @returns {boolean} Whether the message should be fixed.
     */
    function shouldMessageBeFixed(message, config, fixTypes) {
        if (!message.ruleId) {
            return fixTypes.has("directive");
        }
        const rule = message.ruleId && getRuleFromConfig(message.ruleId, config);
        return Boolean(rule && rule.meta && fixTypes.has(rule.meta.type));
    }
    /**
     * Collect used deprecated rules.
     * @param {Array<FlatConfig>} configs The configs to evaluate.
     * @returns {IterableIterator<DeprecatedRuleInfo>} Used deprecated rules.
     */
    function* iterateRuleDeprecationWarnings(configs) {
        const processedRuleIds = new Set();
        for (const config of configs) {
            for (const [ruleId, ruleConfig] of Object.entries(config.rules)) {
                // Skip if it was processed.
                if (processedRuleIds.has(ruleId)) {
                    continue;
                }
                processedRuleIds.add(ruleId);
                // Skip if it's not used.
                if (!getRuleSeverity(ruleConfig)) {
                    continue;
                }
                const rule = getRuleFromConfig(ruleId, config);
                // Skip if it's not deprecated.
                if (!(rule && rule.meta && rule.meta.deprecated)) {
                    continue;
                }
                // This rule was used and deprecated.
                yield {
                    ruleId,
                    replacedBy: rule.meta.replacedBy || []
                };
            }
        }
    }
    /**
     * Creates an error to be thrown when an array of results passed to `getRulesMetaForResults` was not created by the current engine.
     * @returns {TypeError} An error object.
     */
    function createExtraneousResultsError() {
        return new TypeError("Results object was not created from this ESLint instance.");
    }
    //-----------------------------------------------------------------------------
    // Main API
    //-----------------------------------------------------------------------------
    /**
     * Primary Node.js API for ESLint.
     */
    class FlatESLint {
        /**
         * Creates a new instance of the main ESLint API.
         * @param {FlatESLintOptions} options The options for this instance.
         */
        constructor(options = {}) {
            const defaultConfigs = [];
            const processedOptions = processOptions(options);
            const linter = new Linter({
                cwd: processedOptions.cwd,
                configType: "flat"
            });
            const cacheFilePath = getCacheFile(processedOptions.cacheLocation, processedOptions.cwd);
            const lintResultCache = processedOptions.cache
                ? new LintResultCache(cacheFilePath, processedOptions.cacheStrategy)
                : null;
            privateMembers.set(this, {
                options: processedOptions,
                linter,
                cacheFilePath,
                lintResultCache,
                defaultConfigs,
                defaultIgnores: () => false,
                configs: null
            });
            /**
             * If additional plugins are passed in, add that to the default
             * configs for this instance.
             */
            if (options.plugins) {
                const plugins = {};
                for (const [pluginName, plugin] of Object.entries(options.plugins)) {
                    plugins[naming.getShorthandName(pluginName, "eslint-plugin")] = plugin;
                }
                defaultConfigs.push({
                    plugins
                });
            }
        }
        /**
         * The version text.
         * @type {string}
         */
        static get version() {
            return version;
        }
        /**
         * Outputs fixes from the given results to files.
         * @param {LintResult[]} results The lint results.
         * @returns {Promise<void>} Returns a promise that is used to track side effects.
         */
        static async outputFixes(results) {
            if (!Array.isArray(results)) {
                throw new Error("'results' must be an array");
            }
            await Promise.all(results
                .filter(result => {
                if (typeof result !== "object" || result === null) {
                    throw new Error("'results' must include only objects");
                }
                return (typeof result.output === "string" &&
                    path.isAbsolute(result.filePath));
            })
                .map(r => fs.writeFile(r.filePath, r.output)));
        }
        /**
         * Returns results that only contains errors.
         * @param {LintResult[]} results The results to filter.
         * @returns {LintResult[]} The filtered results.
         */
        static getErrorResults(results) {
            const filtered = [];
            results.forEach(result => {
                const filteredMessages = result.messages.filter(isErrorMessage);
                const filteredSuppressedMessages = result.suppressedMessages.filter(isErrorMessage);
                if (filteredMessages.length > 0) {
                    filtered.push({
                        ...result,
                        messages: filteredMessages,
                        suppressedMessages: filteredSuppressedMessages,
                        errorCount: filteredMessages.length,
                        warningCount: 0,
                        fixableErrorCount: result.fixableErrorCount,
                        fixableWarningCount: 0
                    });
                }
            });
            return filtered;
        }
        /**
         * Returns meta objects for each rule represented in the lint results.
         * @param {LintResult[]} results The results to fetch rules meta for.
         * @returns {Object} A mapping of ruleIds to rule meta objects.
         * @throws {TypeError} When the results object wasn't created from this ESLint instance.
         * @throws {TypeError} When a plugin or rule is missing.
         */
        getRulesMetaForResults(results) {
            // short-circuit simple case
            if (results.length === 0) {
                return {};
            }
            const resultRules = new Map();
            const { configs, options: { cwd } } = privateMembers.get(this);
            /*
             * We can only accurately return rules meta information for linting results if the
             * results were created by this instance. Otherwise, the necessary rules data is
             * not available. So if the config array doesn't already exist, just throw an error
             * to let the user know we can't do anything here.
             */
            if (!configs) {
                throw createExtraneousResultsError();
            }
            for (const result of results) {
                /*
                 * Normalize filename for <text>.
                 */
                const filePath = result.filePath === "<text>"
                    ? getPlaceholderPath(cwd) : result.filePath;
                const allMessages = result.messages.concat(result.suppressedMessages);
                for (const { ruleId } of allMessages) {
                    if (!ruleId) {
                        continue;
                    }
                    /*
                     * All of the plugin and rule information is contained within the
                     * calculated config for the given file.
                     */
                    const config = configs.getConfig(filePath);
                    if (!config) {
                        throw createExtraneousResultsError();
                    }
                    const rule = getRuleFromConfig(ruleId, config);
                    // ensure the rule exists
                    if (!rule) {
                        throw new TypeError(`Could not find the rule "${ruleId}".`);
                    }
                    resultRules.set(ruleId, rule);
                }
            }
            return createRulesMeta(resultRules);
        }
        /**
         * Executes the current configuration on an array of file and directory names.
         * @param {string|string[]} patterns An array of file and directory names.
         * @returns {Promise<LintResult[]>} The results of linting the file patterns given.
         */
        async lintFiles(patterns) {
            if (!isNonEmptyString(patterns) && !isArrayOfNonEmptyString(patterns)) {
                throw new Error("'patterns' must be a non-empty string or an array of non-empty strings");
            }
            const { cacheFilePath, lintResultCache, linter, options: eslintOptions } = privateMembers.get(this);
            const configs = await calculateConfigArray(this, eslintOptions);
            const { allowInlineConfig, cache, cwd, fix, fixTypes, reportUnusedDisableDirectives, globInputPaths, errorOnUnmatchedPattern } = eslintOptions;
            const startTime = Date.now();
            const usedConfigs = [];
            const fixTypesSet = fixTypes ? new Set(fixTypes) : null;
            // Delete cache file; should this be done here?
            if (!cache && cacheFilePath) {
                debug(`Deleting cache file at ${cacheFilePath}`);
                try {
                    await fs.unlink(cacheFilePath);
                }
                catch (error) {
                    const errorCode = error && error.code;
                    // Ignore errors when no such file exists or file system is read only (and cache file does not exist)
                    if (errorCode !== "ENOENT" && !(errorCode === "EROFS" && !(await fs.exists(cacheFilePath)))) {
                        throw error;
                    }
                }
            }
            const filePaths = await findFiles({
                patterns: typeof patterns === "string" ? [patterns] : patterns,
                cwd,
                globInputPaths,
                configs,
                errorOnUnmatchedPattern
            });
            debug(`${filePaths.length} files found in: ${Date.now() - startTime}ms`);
            /*
             * Because we need to process multiple files, including reading from disk,
             * it is most efficient to start by reading each file via promises so that
             * they can be done in parallel. Then, we can lint the returned text. This
             * ensures we are waiting the minimum amount of time in between lints.
             */
            const results = await Promise.all(filePaths.map(({ filePath, ignored }) => {
                /*
                 * If a filename was entered that matches an ignore
                 * pattern, then notify the user.
                 */
                if (ignored) {
                    return createIgnoreResult(filePath, cwd);
                }
                const config = configs.getConfig(filePath);
                /*
                 * Sometimes a file found through a glob pattern will
                 * be ignored. In this case, `config` will be undefined
                 * and we just silently ignore the file.
                 */
                if (!config) {
                    return void 0;
                }
                /*
                 * Store used configs for:
                 * - this method uses to collect used deprecated rules.
                 * - `--fix-type` option uses to get the loaded rule's meta data.
                 */
                if (!usedConfigs.includes(config)) {
                    usedConfigs.push(config);
                }
                // Skip if there is cached result.
                if (lintResultCache) {
                    const cachedResult = lintResultCache.getCachedLintResults(filePath, config);
                    if (cachedResult) {
                        const hadMessages = cachedResult.messages &&
                            cachedResult.messages.length > 0;
                        if (hadMessages && fix) {
                            debug(`Reprocessing cached file to allow autofix: ${filePath}`);
                        }
                        else {
                            debug(`Skipping file since it hasn't changed: ${filePath}`);
                            return cachedResult;
                        }
                    }
                }
                // set up fixer for fixTypes if necessary
                let fixer = fix;
                if (fix && fixTypesSet) {
                    // save original value of options.fix in case it's a function
                    const originalFix = (typeof fix === "function")
                        ? fix : () => true;
                    fixer = message => shouldMessageBeFixed(message, config, fixTypesSet) && originalFix(message);
                }
                return fs.readFile(filePath, "utf8")
                    .then(text => {
                    // do the linting
                    const result = verifyText({
                        text,
                        filePath,
                        configs,
                        cwd,
                        fix: fixer,
                        allowInlineConfig,
                        reportUnusedDisableDirectives,
                        linter
                    });
                    /*
                     * Store the lint result in the LintResultCache.
                     * NOTE: The LintResultCache will remove the file source and any
                     * other properties that are difficult to serialize, and will
                     * hydrate those properties back in on future lint runs.
                     */
                    if (lintResultCache) {
                        lintResultCache.setCachedLintResults(filePath, config, result);
                    }
                    return result;
                });
            }));
            // Persist the cache to disk.
            if (lintResultCache) {
                lintResultCache.reconcile();
            }
            let usedDeprecatedRules;
            const finalResults = results.filter(result => !!result);
            return processLintReport(this, {
                results: finalResults,
                ...calculateStatsPerRun(finalResults),
                // Initialize it lazily because CLI and `ESLint` API don't use it.
                get usedDeprecatedRules() {
                    if (!usedDeprecatedRules) {
                        usedDeprecatedRules = Array.from(iterateRuleDeprecationWarnings(usedConfigs));
                    }
                    return usedDeprecatedRules;
                }
            });
        }
        /**
         * Executes the current configuration on text.
         * @param {string} code A string of JavaScript code to lint.
         * @param {Object} [options] The options.
         * @param {string} [options.filePath] The path to the file of the source code.
         * @param {boolean} [options.warnIgnored] When set to true, warn if given filePath is an ignored path.
         * @returns {Promise<LintResult[]>} The results of linting the string of code given.
         */
        async lintText(code, options = {}) {
            // Parameter validation
            if (typeof code !== "string") {
                throw new Error("'code' must be a string");
            }
            if (typeof options !== "object") {
                throw new Error("'options' must be an object, null, or undefined");
            }
            // Options validation
            const { filePath, warnIgnored = false, ...unknownOptions } = options || {};
            const unknownOptionKeys = Object.keys(unknownOptions);
            if (unknownOptionKeys.length > 0) {
                throw new Error(`'options' must not include the unknown option(s): ${unknownOptionKeys.join(", ")}`);
            }
            if (filePath !== void 0 && !isNonEmptyString(filePath)) {
                throw new Error("'options.filePath' must be a non-empty string or undefined");
            }
            if (typeof warnIgnored !== "boolean") {
                throw new Error("'options.warnIgnored' must be a boolean or undefined");
            }
            // Now we can get down to linting
            const { linter, options: eslintOptions } = privateMembers.get(this);
            const configs = await calculateConfigArray(this, eslintOptions);
            const { allowInlineConfig, cwd, fix, reportUnusedDisableDirectives } = eslintOptions;
            const results = [];
            const startTime = Date.now();
            const resolvedFilename = path.resolve(cwd, filePath || "__placeholder__.js");
            let config;
            // Clear the last used config arrays.
            if (resolvedFilename && await this.isPathIgnored(resolvedFilename)) {
                if (warnIgnored) {
                    results.push(createIgnoreResult(resolvedFilename, cwd));
                }
            }
            else {
                // TODO: Needed?
                config = configs.getConfig(resolvedFilename);
                // Do lint.
                results.push(verifyText({
                    text: code,
                    filePath: resolvedFilename.endsWith("__placeholder__.js") ? "<text>" : resolvedFilename,
                    configs,
                    cwd,
                    fix,
                    allowInlineConfig,
                    reportUnusedDisableDirectives,
                    linter
                }));
            }
            debug(`Linting complete in: ${Date.now() - startTime}ms`);
            let usedDeprecatedRules;
            return processLintReport(this, {
                results,
                ...calculateStatsPerRun(results),
                // Initialize it lazily because CLI and `ESLint` API don't use it.
                get usedDeprecatedRules() {
                    if (!usedDeprecatedRules) {
                        usedDeprecatedRules = Array.from(iterateRuleDeprecationWarnings(config));
                    }
                    return usedDeprecatedRules;
                }
            });
        }
        /**
         * Returns the formatter representing the given formatter name.
         * @param {string} [name] The name of the formatter to load.
         * The following values are allowed:
         * - `undefined` ... Load `stylish` builtin formatter.
         * - A builtin formatter name ... Load the builtin formatter.
         * - A third-party formatter name:
         *   - `foo` → `eslint-formatter-foo`
         *   - `@foo` → `@foo/eslint-formatter`
         *   - `@foo/bar` → `@foo/eslint-formatter-bar`
         * - A file path ... Load the file.
         * @returns {Promise<Formatter>} A promise resolving to the formatter object.
         * This promise will be rejected if the given formatter was not found or not
         * a function.
         */
        async loadFormatter(name = "stylish") {
            if (typeof name !== "string") {
                throw new Error("'name' must be a string");
            }
            // replace \ with / for Windows compatibility
            const normalizedFormatName = name.replace(/\\/gu, "/");
            const namespace = naming.getNamespaceFromTerm(normalizedFormatName);
            // grab our options
            const { cwd } = privateMembers.get(this).options;
            let formatterPath;
            // if there's a slash, then it's a file (TODO: this check seems dubious for scoped npm packages)
            if (!namespace && normalizedFormatName.includes("/")) {
                formatterPath = path.resolve(cwd, normalizedFormatName);
            }
            else {
                try {
                    const npmFormat = naming.normalizePackageName(normalizedFormatName, "eslint-formatter");
                    // TODO: This is pretty dirty...would be nice to clean up at some point.
                    formatterPath = ModuleResolver.resolve(npmFormat, getPlaceholderPath(cwd));
                }
                catch {
                    formatterPath = path.resolve(__dirname, "../", "cli-engine", "formatters", `${normalizedFormatName}.js`);
                }
            }
            let formatter;
            try {
                formatter = (await import(pathToFileURL(formatterPath))).default;
            }
            catch (ex) {
                // check for formatters that have been removed
                if (removedFormatters.has(name)) {
                    ex.message = `The ${name} formatter is no longer part of core ESLint. Install it manually with \`npm install -D eslint-formatter-${name}\``;
                }
                else {
                    ex.message = `There was a problem loading formatter: ${formatterPath}\nError: ${ex.message}`;
                }
                throw ex;
            }
            if (typeof formatter !== "function") {
                throw new TypeError(`Formatter must be a function, but got a ${typeof formatter}.`);
            }
            const eslint = this;
            return {
                /**
                 * The main formatter method.
                 * @param {LintResults[]} results The lint results to format.
                 * @param {ResultsMeta} resultsMeta Warning count and max threshold.
                 * @returns {string} The formatted lint results.
                 */
                format(results, resultsMeta) {
                    let rulesMeta = null;
                    results.sort(compareResultsByFilePath);
                    return formatter(results, {
                        ...resultsMeta,
                        cwd,
                        get rulesMeta() {
                            if (!rulesMeta) {
                                rulesMeta = eslint.getRulesMetaForResults(results);
                            }
                            return rulesMeta;
                        }
                    });
                }
            };
        }
        /**
         * Returns a configuration object for the given file based on the CLI options.
         * This is the same logic used by the ESLint CLI executable to determine
         * configuration for each file it processes.
         * @param {string} filePath The path of the file to retrieve a config object for.
         * @returns {Promise<ConfigData|undefined>} A configuration object for the file
         *      or `undefined` if there is no configuration data for the object.
         */
        async calculateConfigForFile(filePath) {
            if (!isNonEmptyString(filePath)) {
                throw new Error("'filePath' must be a non-empty string");
            }
            const options = privateMembers.get(this).options;
            const absolutePath = path.resolve(options.cwd, filePath);
            const configs = await calculateConfigArray(this, options);
            return configs.getConfig(absolutePath);
        }
        /**
         * Checks if a given path is ignored by ESLint.
         * @param {string} filePath The path of the file to check.
         * @returns {Promise<boolean>} Whether or not the given path is ignored.
         */
        async isPathIgnored(filePath) {
            const config = await this.calculateConfigForFile(filePath);
            return config === void 0;
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = {
        FlatESLint,
        findFlatConfigFile
    };
},
/* find-up/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const path = require('path');
    const locatePath = require(729) /* locate-path */;
    const pathExists = require(733) /* path-exists */;
    const stop = Symbol('findUp.stop');
    module.exports = async (name, options = {}) => {
        let directory = path.resolve(options.cwd || '');
        const { root } = path.parse(directory);
        const paths = [].concat(name);
        const runMatcher = async (locateOptions) => {
            if (typeof name !== 'function') {
                return locatePath(paths, locateOptions);
            }
            const foundPath = await name(locateOptions.cwd);
            if (typeof foundPath === 'string') {
                return locatePath([foundPath], locateOptions);
            }
            return foundPath;
        };
        // eslint-disable-next-line no-constant-condition
        while (true) {
            // eslint-disable-next-line no-await-in-loop
            const foundPath = await runMatcher({ ...options, cwd: directory });
            if (foundPath === stop) {
                return;
            }
            if (foundPath) {
                return path.resolve(directory, foundPath);
            }
            if (directory === root) {
                return;
            }
            directory = path.dirname(directory);
        }
    };
    module.exports.sync = (name, options = {}) => {
        let directory = path.resolve(options.cwd || '');
        const { root } = path.parse(directory);
        const paths = [].concat(name);
        const runMatcher = locateOptions => {
            if (typeof name !== 'function') {
                return locatePath.sync(paths, locateOptions);
            }
            const foundPath = name(locateOptions.cwd);
            if (typeof foundPath === 'string') {
                return locatePath.sync([foundPath], locateOptions);
            }
            return foundPath;
        };
        // eslint-disable-next-line no-constant-condition
        while (true) {
            const foundPath = runMatcher({ ...options, cwd: directory });
            if (foundPath === stop) {
                return;
            }
            if (foundPath) {
                return path.resolve(directory, foundPath);
            }
            if (directory === root) {
                return;
            }
            directory = path.dirname(directory);
        }
    };
    module.exports.exists = pathExists;
    module.exports.sync.exists = pathExists.sync;
    module.exports.stop = stop;
},
/* locate-path/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const path = require('path');
    const fs = require('fs');
    const { promisify } = require('util');
    const pLocate = require(730) /* p-locate */;
    const fsStat = promisify(fs.stat);
    const fsLStat = promisify(fs.lstat);
    const typeMappings = {
        directory: 'isDirectory',
        file: 'isFile'
    };
    function checkType({ type }) {
        if (type in typeMappings) {
            return;
        }
        throw new Error(`Invalid type specified: ${type}`);
    }
    const matchType = (type, stat) => type === undefined || stat[typeMappings[type]]();
    module.exports = async (paths, options) => {
        options = {
            cwd: process.cwd(),
            type: 'file',
            allowSymlinks: true,
            ...options
        };
        checkType(options);
        const statFn = options.allowSymlinks ? fsStat : fsLStat;
        return pLocate(paths, async (path_) => {
            try {
                const stat = await statFn(path.resolve(options.cwd, path_));
                return matchType(options.type, stat);
            }
            catch {
                return false;
            }
        }, options);
    };
    module.exports.sync = (paths, options) => {
        options = {
            cwd: process.cwd(),
            allowSymlinks: true,
            type: 'file',
            ...options
        };
        checkType(options);
        const statFn = options.allowSymlinks ? fs.statSync : fs.lstatSync;
        for (const path_ of paths) {
            try {
                const stat = statFn(path.resolve(options.cwd, path_));
                if (matchType(options.type, stat)) {
                    return path_;
                }
            }
            catch { }
        }
    };
},
/* p-locate/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const pLimit = require(731) /* p-limit */;
    class EndError extends Error {
        constructor(value) {
            super();
            this.value = value;
        }
    }
    // The input can also be a promise, so we await it
    const testElement = async (element, tester) => tester(await element);
    // The input can also be a promise, so we `Promise.all()` them both
    const finder = async (element) => {
        const values = await Promise.all(element);
        if (values[1] === true) {
            throw new EndError(values[0]);
        }
        return false;
    };
    const pLocate = async (iterable, tester, options) => {
        options = {
            concurrency: Infinity,
            preserveOrder: true,
            ...options
        };
        const limit = pLimit(options.concurrency);
        // Start all the promises concurrently with optional limit
        const items = [...iterable].map(element => [element, limit(testElement, element, tester)]);
        // Check the promises either serially or concurrently
        const checkLimit = pLimit(options.preserveOrder ? 1 : Infinity);
        try {
            await Promise.all(items.map(element => checkLimit(finder, element)));
        }
        catch (error) {
            if (error instanceof EndError) {
                return error.value;
            }
            throw error;
        }
    };
    module.exports = pLocate;
},
/* p-limit/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const Queue = require(732) /* yocto-queue */;
    const pLimit = concurrency => {
        if (!((Number.isInteger(concurrency) || concurrency === Infinity) && concurrency > 0)) {
            throw new TypeError('Expected `concurrency` to be a number from 1 and up');
        }
        const queue = new Queue();
        let activeCount = 0;
        const next = () => {
            activeCount--;
            if (queue.size > 0) {
                queue.dequeue()();
            }
        };
        const run = async (fn, resolve, ...args) => {
            activeCount++;
            const result = (async () => fn(...args))();
            resolve(result);
            try {
                await result;
            }
            catch { }
            next();
        };
        const enqueue = (fn, resolve, ...args) => {
            queue.enqueue(run.bind(null, fn, resolve, ...args));
            (async () => {
                // This function needs to wait until the next microtask before comparing
                // `activeCount` to `concurrency`, because `activeCount` is updated asynchronously
                // when the run function is dequeued and called. The comparison in the if-statement
                // needs to happen asynchronously as well to get an up-to-date value for `activeCount`.
                await Promise.resolve();
                if (activeCount < concurrency && queue.size > 0) {
                    queue.dequeue()();
                }
            })();
        };
        const generator = (fn, ...args) => new Promise(resolve => {
            enqueue(fn, resolve, ...args);
        });
        Object.defineProperties(generator, {
            activeCount: {
                get: () => activeCount
            },
            pendingCount: {
                get: () => queue.size
            },
            clearQueue: {
                value: () => {
                    queue.clear();
                }
            }
        });
        return generator;
    };
    module.exports = pLimit;
},
/* yocto-queue/index.js */ function _(require, module, exports, __esModule, __esExport) {
    class Node {
        /// value;
        /// next;
        constructor(value) {
            this.value = value;
            // TODO: Remove this when targeting Node.js 12.
            this.next = undefined;
        }
    }
    class Queue {
        // TODO: Use private class fields when targeting Node.js 12.
        // #_head;
        // #_tail;
        // #_size;
        constructor() {
            this.clear();
        }
        enqueue(value) {
            const node = new Node(value);
            if (this._head) {
                this._tail.next = node;
                this._tail = node;
            }
            else {
                this._head = node;
                this._tail = node;
            }
            this._size++;
        }
        dequeue() {
            const current = this._head;
            if (!current) {
                return;
            }
            this._head = this._head.next;
            this._size--;
            return current.value;
        }
        clear() {
            this._head = undefined;
            this._tail = undefined;
            this._size = 0;
        }
        get size() {
            return this._size;
        }
        *[Symbol.iterator]() {
            let current = this._head;
            while (current) {
                yield current.value;
                current = current.next;
            }
        }
    }
    module.exports = Queue;
},
/* path-exists/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const fs = require('fs');
    const { promisify } = require('util');
    const pAccess = promisify(fs.access);
    module.exports = async (path) => {
        try {
            await pAccess(path);
            return true;
        }
        catch (_) {
            return false;
        }
    };
    module.exports.sync = path => {
        try {
            fs.accessSync(path);
            return true;
        }
        catch (_) {
            return false;
        }
    };
},
/* eslint/lib/eslint/eslint-helpers.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview Helper functions for ESLint class
     * @author Nicholas C. Zakas
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Requirements
    //-----------------------------------------------------------------------------
    const path = require("path");
    const fs = require("fs");
    const fsp = fs.promises;
    const isGlob = require(283) /* is-glob */;
    const hash = require(708) /* ../cli-engine/hash */;
    const minimatch = require(229) /* minimatch */;
    const util = require("util");
    const fswalk = require(735) /* @nodelib/fs.walk */;
    const globParent = require(282) /* glob-parent */;
    const isPathInside = require(762) /* is-path-inside */;
    //-----------------------------------------------------------------------------
    // Fixup references
    //-----------------------------------------------------------------------------
    const doFsWalk = util.promisify(fswalk.walk);
    const Minimatch = minimatch.Minimatch;
    const MINIMATCH_OPTIONS = { dot: true };
    //-----------------------------------------------------------------------------
    // Types
    //-----------------------------------------------------------------------------
    /**
     * @typedef {Object} GlobSearch
     * @property {Array<string>} patterns The normalized patterns to use for a search.
     * @property {Array<string>} rawPatterns The patterns as entered by the user
     *      before doing any normalization.
     */
    //-----------------------------------------------------------------------------
    // Errors
    //-----------------------------------------------------------------------------
    /**
     * The error type when no files match a glob.
     */
    class NoFilesFoundError extends Error {
        /**
         * @param {string} pattern The glob pattern which was not found.
         * @param {boolean} globEnabled If `false` then the pattern was a glob pattern, but glob was disabled.
         */
        constructor(pattern, globEnabled) {
            super(`No files matching '${pattern}' were found${!globEnabled ? " (glob was disabled)" : ""}.`);
            this.messageTemplate = "file-not-found";
            this.messageData = { pattern, globDisabled: !globEnabled };
        }
    }
    /**
     * The error type when a search fails to match multiple patterns.
     */
    class UnmatchedSearchPatternsError extends Error {
        /**
         * @param {Object} options The options for the error.
         * @param {string} options.basePath The directory that was searched.
         * @param {Array<string>} options.unmatchedPatterns The glob patterns
         *      which were not found.
         * @param {Array<string>} options.patterns The glob patterns that were
         *      searched.
         * @param {Array<string>} options.rawPatterns The raw glob patterns that
         *      were searched.
         */
        constructor({ basePath, unmatchedPatterns, patterns, rawPatterns }) {
            super(`No files matching '${rawPatterns}' in '${basePath}' were found.`);
            this.basePath = basePath;
            this.unmatchedPatterns = unmatchedPatterns;
            this.patterns = patterns;
            this.rawPatterns = rawPatterns;
        }
    }
    /**
     * The error type when there are files matched by a glob, but all of them have been ignored.
     */
    class AllFilesIgnoredError extends Error {
        /**
         * @param {string} pattern The glob pattern which was not found.
         */
        constructor(pattern) {
            super(`All files matched by '${pattern}' are ignored.`);
            this.messageTemplate = "all-files-ignored";
            this.messageData = { pattern };
        }
    }
    //-----------------------------------------------------------------------------
    // General Helpers
    //-----------------------------------------------------------------------------
    /**
     * Check if a given value is a non-empty string or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if `x` is a non-empty string.
     */
    function isNonEmptyString(x) {
        return typeof x === "string" && x.trim() !== "";
    }
    /**
     * Check if a given value is an array of non-empty strings or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if `x` is an array of non-empty strings.
     */
    function isArrayOfNonEmptyString(x) {
        return Array.isArray(x) && x.every(isNonEmptyString);
    }
    //-----------------------------------------------------------------------------
    // File-related Helpers
    //-----------------------------------------------------------------------------
    /**
     * Normalizes slashes in a file pattern to posix-style.
     * @param {string} pattern The pattern to replace slashes in.
     * @returns {string} The pattern with slashes normalized.
     */
    function normalizeToPosix(pattern) {
        return pattern.replace(/\\/gu, "/");
    }
    /**
     * Check if a string is a glob pattern or not.
     * @param {string} pattern A glob pattern.
     * @returns {boolean} `true` if the string is a glob pattern.
     */
    function isGlobPattern(pattern) {
        return isGlob(path.sep === "\\" ? normalizeToPosix(pattern) : pattern);
    }
    /**
     * Determines if a given glob pattern will return any results.
     * Used primarily to help with useful error messages.
     * @param {Object} options The options for the function.
     * @param {string} options.basePath The directory to search.
     * @param {string} options.pattern A glob pattern to match.
     * @returns {Promise<boolean>} True if there is a glob match, false if not.
     */
    function globMatch({ basePath, pattern }) {
        let found = false;
        const patternToUse = path.isAbsolute(pattern)
            ? normalizeToPosix(path.relative(basePath, pattern))
            : pattern;
        const matcher = new Minimatch(patternToUse, MINIMATCH_OPTIONS);
        const fsWalkSettings = {
            deepFilter(entry) {
                const relativePath = normalizeToPosix(path.relative(basePath, entry.path));
                return !found && matcher.match(relativePath, true);
            },
            entryFilter(entry) {
                if (found || entry.dirent.isDirectory()) {
                    return false;
                }
                const relativePath = normalizeToPosix(path.relative(basePath, entry.path));
                if (matcher.match(relativePath)) {
                    found = true;
                    return true;
                }
                return false;
            }
        };
        return new Promise(resolve => {
            // using a stream so we can exit early because we just need one match
            const globStream = fswalk.walkStream(basePath, fsWalkSettings);
            globStream.on("data", () => {
                globStream.destroy();
                resolve(true);
            });
            // swallow errors as they're not important here
            globStream.on("error", () => { });
            globStream.on("end", () => {
                resolve(false);
            });
            globStream.read();
        });
    }
    /**
     * Searches a directory looking for matching glob patterns. This uses
     * the config array's logic to determine if a directory or file should
     * be ignored, so it is consistent with how ignoring works throughout
     * ESLint.
     * @param {Object} options The options for this function.
     * @param {string} options.basePath The directory to search.
     * @param {Array<string>} options.patterns An array of glob patterns
     *      to match.
     * @param {Array<string>} options.rawPatterns An array of glob patterns
     *      as the user inputted them. Used for errors.
     * @param {FlatConfigArray} options.configs The config array to use for
     *      determining what to ignore.
     * @param {boolean} options.errorOnUnmatchedPattern Determines if an error
     *      should be thrown when a pattern is unmatched.
     * @returns {Promise<Array<string>>} An array of matching file paths
     *      or an empty array if there are no matches.
     * @throws {UnmatchedSearchPatternsError} If there is a pattern that doesn't
     *      match any files.
     */
    async function globSearch({ basePath, patterns, rawPatterns, configs, errorOnUnmatchedPattern }) {
        if (patterns.length === 0) {
            return [];
        }
        /*
         * In this section we are converting the patterns into Minimatch
         * instances for performance reasons. Because we are doing the same
         * matches repeatedly, it's best to compile those patterns once and
         * reuse them multiple times.
         *
         * To do that, we convert any patterns with an absolute path into a
         * relative path and normalize it to Posix-style slashes. We also keep
         * track of the relative patterns to map them back to the original
         * patterns, which we need in order to throw an error if there are any
         * unmatched patterns.
         */
        const relativeToPatterns = new Map();
        const matchers = patterns.map((pattern, i) => {
            const patternToUse = path.isAbsolute(pattern)
                ? normalizeToPosix(path.relative(basePath, pattern))
                : pattern;
            relativeToPatterns.set(patternToUse, patterns[i]);
            return new Minimatch(patternToUse, MINIMATCH_OPTIONS);
        });
        /*
         * We track unmatched patterns because we may want to throw an error when
         * they occur. To start, this set is initialized with all of the patterns.
         * Every time a match occurs, the pattern is removed from the set, making
         * it easy to tell if we have any unmatched patterns left at the end of
         * search.
         */
        const unmatchedPatterns = new Set([...relativeToPatterns.keys()]);
        const filePaths = (await doFsWalk(basePath, {
            deepFilter(entry) {
                const relativePath = normalizeToPosix(path.relative(basePath, entry.path));
                const matchesPattern = matchers.some(matcher => matcher.match(relativePath, true));
                return matchesPattern && !configs.isDirectoryIgnored(entry.path);
            },
            entryFilter(entry) {
                const relativePath = normalizeToPosix(path.relative(basePath, entry.path));
                // entries may be directories or files so filter out directories
                if (entry.dirent.isDirectory()) {
                    return false;
                }
                /*
                 * Optimization: We need to track when patterns are left unmatched
                 * and so we use `unmatchedPatterns` to do that. There is a bit of
                 * complexity here because the same file can be matched by more than
                 * one pattern. So, when we start, we actually need to test every
                 * pattern against every file. Once we know there are no remaining
                 * unmatched patterns, then we can switch to just looking for the
                 * first matching pattern for improved speed.
                 */
                const matchesPattern = unmatchedPatterns.size > 0
                    ? matchers.reduce((previousValue, matcher) => {
                        const pathMatches = matcher.match(relativePath);
                        /*
                         * We updated the unmatched patterns set only if the path
                         * matches and the file isn't ignored. If the file is
                         * ignored, that means there wasn't a match for the
                         * pattern so it should not be removed.
                         *
                         * Performance note: isFileIgnored() aggressively caches
                         * results so there is no performance penalty for calling
                         * it twice with the same argument.
                         */
                        if (pathMatches && !configs.isFileIgnored(entry.path)) {
                            unmatchedPatterns.delete(matcher.pattern);
                        }
                        return pathMatches || previousValue;
                    }, false)
                    : matchers.some(matcher => matcher.match(relativePath));
                return matchesPattern && !configs.isFileIgnored(entry.path);
            }
        })).map(entry => entry.path);
        // now check to see if we have any unmatched patterns
        if (errorOnUnmatchedPattern && unmatchedPatterns.size > 0) {
            throw new UnmatchedSearchPatternsError({
                basePath,
                unmatchedPatterns: [...unmatchedPatterns].map(pattern => relativeToPatterns.get(pattern)),
                patterns,
                rawPatterns
            });
        }
        return filePaths;
    }
    /**
     * Throws an error for unmatched patterns. The error will only contain information about the first one.
     * Checks to see if there are any ignored results for a given search.
     * @param {Object} options The options for this function.
     * @param {string} options.basePath The directory to search.
     * @param {Array<string>} options.patterns An array of glob patterns
     *      that were used in the original search.
     * @param {Array<string>} options.rawPatterns An array of glob patterns
     *      as the user inputted them. Used for errors.
     * @param {Array<string>} options.unmatchedPatterns A non-empty array of glob patterns
     *      that were unmatched in the original search.
     * @returns {void} Always throws an error.
     * @throws {NoFilesFoundError} If the first unmatched pattern
     *      doesn't match any files even when there are no ignores.
     * @throws {AllFilesIgnoredError} If the first unmatched pattern
     *      matches some files when there are no ignores.
     */
    async function throwErrorForUnmatchedPatterns({ basePath, patterns, rawPatterns, unmatchedPatterns }) {
        const pattern = unmatchedPatterns[0];
        const rawPattern = rawPatterns[patterns.indexOf(pattern)];
        const patternHasMatch = await globMatch({
            basePath,
            pattern
        });
        if (patternHasMatch) {
            throw new AllFilesIgnoredError(rawPattern);
        }
        // if we get here there are truly no matches
        throw new NoFilesFoundError(rawPattern, true);
    }
    /**
     * Performs multiple glob searches in parallel.
     * @param {Object} options The options for this function.
     * @param {Map<string,GlobSearch>} options.searches
     *      An array of glob patterns to match.
     * @param {FlatConfigArray} options.configs The config array to use for
     *      determining what to ignore.
     * @param {boolean} options.errorOnUnmatchedPattern Determines if an
     *      unmatched glob pattern should throw an error.
     * @returns {Promise<Array<string>>} An array of matching file paths
     *      or an empty array if there are no matches.
     */
    async function globMultiSearch({ searches, configs, errorOnUnmatchedPattern }) {
        /*
         * For convenience, we normalized the search map into an array of objects.
         * Next, we filter out all searches that have no patterns. This happens
         * primarily for the cwd, which is prepopulated in the searches map as an
         * optimization. However, if it has no patterns, it means all patterns
         * occur outside of the cwd and we can safely filter out that search.
         */
        const normalizedSearches = [...searches].map(([basePath, { patterns, rawPatterns }]) => ({ basePath, patterns, rawPatterns })).filter(({ patterns }) => patterns.length > 0);
        const results = await Promise.allSettled(normalizedSearches.map(({ basePath, patterns, rawPatterns }) => globSearch({
            basePath,
            patterns,
            rawPatterns,
            configs,
            errorOnUnmatchedPattern
        })));
        const filePaths = [];
        for (let i = 0; i < results.length; i++) {
            const result = results[i];
            const currentSearch = normalizedSearches[i];
            if (result.status === "fulfilled") {
                // if the search was successful just add the results
                if (result.value.length > 0) {
                    filePaths.push(...result.value);
                }
                continue;
            }
            // if we make it here then there was an error
            const error = result.reason;
            // unexpected errors should be re-thrown
            if (!error.basePath) {
                throw error;
            }
            if (errorOnUnmatchedPattern) {
                await throwErrorForUnmatchedPatterns({
                    ...currentSearch,
                    unmatchedPatterns: error.unmatchedPatterns
                });
            }
        }
        return [...new Set(filePaths)];
    }
    /**
     * Finds all files matching the options specified.
     * @param {Object} args The arguments objects.
     * @param {Array<string>} args.patterns An array of glob patterns.
     * @param {boolean} args.globInputPaths true to interpret glob patterns,
     *      false to not interpret glob patterns.
     * @param {string} args.cwd The current working directory to find from.
     * @param {FlatConfigArray} args.configs The configs for the current run.
     * @param {boolean} args.errorOnUnmatchedPattern Determines if an unmatched pattern
     *      should throw an error.
     * @returns {Promise<Array<string>>} The fully resolved file paths.
     * @throws {AllFilesIgnoredError} If there are no results due to an ignore pattern.
     * @throws {NoFilesFoundError} If no files matched the given patterns.
     */
    async function findFiles({ patterns, globInputPaths, cwd, configs, errorOnUnmatchedPattern }) {
        const results = [];
        const missingPatterns = [];
        let globbyPatterns = [];
        let rawPatterns = [];
        const searches = new Map([[cwd, { patterns: globbyPatterns, rawPatterns: [] }]]);
        // check to see if we have explicit files and directories
        const filePaths = patterns.map(filePath => path.resolve(cwd, filePath));
        const stats = await Promise.all(filePaths.map(filePath => fsp.stat(filePath).catch(() => { })));
        stats.forEach((stat, index) => {
            const filePath = filePaths[index];
            const pattern = normalizeToPosix(patterns[index]);
            if (stat) {
                // files are added directly to the list
                if (stat.isFile()) {
                    results.push({
                        filePath,
                        ignored: configs.isFileIgnored(filePath)
                    });
                }
                // directories need extensions attached
                if (stat.isDirectory()) {
                    // group everything in cwd together and split out others
                    if (isPathInside(filePath, cwd)) {
                        ({ patterns: globbyPatterns, rawPatterns } = searches.get(cwd));
                    }
                    else {
                        if (!searches.has(filePath)) {
                            searches.set(filePath, { patterns: [], rawPatterns: [] });
                        }
                        ({ patterns: globbyPatterns, rawPatterns } = searches.get(filePath));
                    }
                    globbyPatterns.push(`${normalizeToPosix(filePath)}/**`);
                    rawPatterns.push(pattern);
                }
                return;
            }
            // save patterns for later use based on whether globs are enabled
            if (globInputPaths && isGlobPattern(pattern)) {
                const basePath = path.resolve(cwd, globParent(pattern));
                // group in cwd if possible and split out others
                if (isPathInside(basePath, cwd)) {
                    ({ patterns: globbyPatterns, rawPatterns } = searches.get(cwd));
                }
                else {
                    if (!searches.has(basePath)) {
                        searches.set(basePath, { patterns: [], rawPatterns: [] });
                    }
                    ({ patterns: globbyPatterns, rawPatterns } = searches.get(basePath));
                }
                globbyPatterns.push(filePath);
                rawPatterns.push(pattern);
            }
            else {
                missingPatterns.push(pattern);
            }
        });
        // there were patterns that didn't match anything, tell the user
        if (errorOnUnmatchedPattern && missingPatterns.length) {
            throw new NoFilesFoundError(missingPatterns[0], globInputPaths);
        }
        // now we are safe to do the search
        const globbyResults = await globMultiSearch({
            searches,
            configs,
            errorOnUnmatchedPattern
        });
        return [
            ...results,
            ...globbyResults.map(filePath => ({
                filePath: path.resolve(filePath),
                ignored: false
            }))
        ];
    }
    //-----------------------------------------------------------------------------
    // Results-related Helpers
    //-----------------------------------------------------------------------------
    /**
     * Checks if the given message is an error message.
     * @param {LintMessage} message The message to check.
     * @returns {boolean} Whether or not the message is an error message.
     * @private
     */
    function isErrorMessage(message) {
        return message.severity === 2;
    }
    /**
     * Returns result with warning by ignore settings
     * @param {string} filePath File path of checked code
     * @param {string} baseDir Absolute path of base directory
     * @returns {LintResult} Result with single warning
     * @private
     */
    function createIgnoreResult(filePath, baseDir) {
        let message;
        const isHidden = filePath.split(path.sep)
            .find(segment => /^\./u.test(segment));
        const isInNodeModules = baseDir && path.relative(baseDir, filePath).startsWith("node_modules");
        if (isHidden) {
            message = "File ignored by default.  Use a negated ignore pattern (like \"--ignore-pattern '!<relative/path/to/filename>'\") to override.";
        }
        else if (isInNodeModules) {
            message = "File ignored by default. Use \"--ignore-pattern '!node_modules/*'\" to override.";
        }
        else {
            message = "File ignored because of a matching ignore pattern. Use \"--no-ignore\" to override.";
        }
        return {
            filePath: path.resolve(filePath),
            messages: [
                {
                    fatal: false,
                    severity: 1,
                    message
                }
            ],
            suppressedMessages: [],
            errorCount: 0,
            warningCount: 1,
            fatalErrorCount: 0,
            fixableErrorCount: 0,
            fixableWarningCount: 0
        };
    }
    //-----------------------------------------------------------------------------
    // Options-related Helpers
    //-----------------------------------------------------------------------------
    /**
     * Check if a given value is a valid fix type or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if `x` is valid fix type.
     */
    function isFixType(x) {
        return x === "directive" || x === "problem" || x === "suggestion" || x === "layout";
    }
    /**
     * Check if a given value is an array of fix types or not.
     * @param {any} x The value to check.
     * @returns {boolean} `true` if `x` is an array of fix types.
     */
    function isFixTypeArray(x) {
        return Array.isArray(x) && x.every(isFixType);
    }
    /**
     * The error for invalid options.
     */
    class ESLintInvalidOptionsError extends Error {
        constructor(messages) {
            super(`Invalid Options:\n- ${messages.join("\n- ")}`);
            this.code = "ESLINT_INVALID_OPTIONS";
            Error.captureStackTrace(this, ESLintInvalidOptionsError);
        }
    }
    /**
     * Validates and normalizes options for the wrapped CLIEngine instance.
     * @param {FlatESLintOptions} options The options to process.
     * @throws {ESLintInvalidOptionsError} If of any of a variety of type errors.
     * @returns {FlatESLintOptions} The normalized options.
     */
    function processOptions({ allowInlineConfig = true, // ← we cannot use `overrideConfig.noInlineConfig` instead because `allowInlineConfig` has side-effect that suppress warnings that show inline configs are ignored.
    baseConfig = null, cache = false, cacheLocation = ".eslintcache", cacheStrategy = "metadata", cwd = process.cwd(), errorOnUnmatchedPattern = true, fix = false, fixTypes = null, // ← should be null by default because if it's an array then it suppresses rules that don't have the `meta.type` property.
    globInputPaths = true, ignore = true, ignorePatterns = null, overrideConfig = null, overrideConfigFile = null, plugins = {}, reportUnusedDisableDirectives = null, // ← should be null by default because if it's a string then it overrides the 'reportUnusedDisableDirectives' setting in config files. And we cannot use `overrideConfig.reportUnusedDisableDirectives` instead because we cannot configure the `error` severity with that.
    ...unknownOptions }) {
        const errors = [];
        const unknownOptionKeys = Object.keys(unknownOptions);
        if (unknownOptionKeys.length >= 1) {
            errors.push(`Unknown options: ${unknownOptionKeys.join(", ")}`);
            if (unknownOptionKeys.includes("cacheFile")) {
                errors.push("'cacheFile' has been removed. Please use the 'cacheLocation' option instead.");
            }
            if (unknownOptionKeys.includes("configFile")) {
                errors.push("'configFile' has been removed. Please use the 'overrideConfigFile' option instead.");
            }
            if (unknownOptionKeys.includes("envs")) {
                errors.push("'envs' has been removed.");
            }
            if (unknownOptionKeys.includes("extensions")) {
                errors.push("'extensions' has been removed.");
            }
            if (unknownOptionKeys.includes("resolvePluginsRelativeTo")) {
                errors.push("'resolvePluginsRelativeTo' has been removed.");
            }
            if (unknownOptionKeys.includes("globals")) {
                errors.push("'globals' has been removed. Please use the 'overrideConfig.languageOptions.globals' option instead.");
            }
            if (unknownOptionKeys.includes("ignorePath")) {
                errors.push("'ignorePath' has been removed.");
            }
            if (unknownOptionKeys.includes("ignorePattern")) {
                errors.push("'ignorePattern' has been removed. Please use the 'overrideConfig.ignorePatterns' option instead.");
            }
            if (unknownOptionKeys.includes("parser")) {
                errors.push("'parser' has been removed. Please use the 'overrideConfig.languageOptions.parser' option instead.");
            }
            if (unknownOptionKeys.includes("parserOptions")) {
                errors.push("'parserOptions' has been removed. Please use the 'overrideConfig.languageOptions.parserOptions' option instead.");
            }
            if (unknownOptionKeys.includes("rules")) {
                errors.push("'rules' has been removed. Please use the 'overrideConfig.rules' option instead.");
            }
            if (unknownOptionKeys.includes("rulePaths")) {
                errors.push("'rulePaths' has been removed. Please define your rules using plugins.");
            }
        }
        if (typeof allowInlineConfig !== "boolean") {
            errors.push("'allowInlineConfig' must be a boolean.");
        }
        if (typeof baseConfig !== "object") {
            errors.push("'baseConfig' must be an object or null.");
        }
        if (typeof cache !== "boolean") {
            errors.push("'cache' must be a boolean.");
        }
        if (!isNonEmptyString(cacheLocation)) {
            errors.push("'cacheLocation' must be a non-empty string.");
        }
        if (cacheStrategy !== "metadata" &&
            cacheStrategy !== "content") {
            errors.push("'cacheStrategy' must be any of \"metadata\", \"content\".");
        }
        if (!isNonEmptyString(cwd) || !path.isAbsolute(cwd)) {
            errors.push("'cwd' must be an absolute path.");
        }
        if (typeof errorOnUnmatchedPattern !== "boolean") {
            errors.push("'errorOnUnmatchedPattern' must be a boolean.");
        }
        if (typeof fix !== "boolean" && typeof fix !== "function") {
            errors.push("'fix' must be a boolean or a function.");
        }
        if (fixTypes !== null && !isFixTypeArray(fixTypes)) {
            errors.push("'fixTypes' must be an array of any of \"directive\", \"problem\", \"suggestion\", and \"layout\".");
        }
        if (typeof globInputPaths !== "boolean") {
            errors.push("'globInputPaths' must be a boolean.");
        }
        if (typeof ignore !== "boolean") {
            errors.push("'ignore' must be a boolean.");
        }
        if (typeof overrideConfig !== "object") {
            errors.push("'overrideConfig' must be an object or null.");
        }
        if (!isNonEmptyString(overrideConfigFile) && overrideConfigFile !== null && overrideConfigFile !== true) {
            errors.push("'overrideConfigFile' must be a non-empty string, null, or true.");
        }
        if (typeof plugins !== "object") {
            errors.push("'plugins' must be an object or null.");
        }
        else if (plugins !== null && Object.keys(plugins).includes("")) {
            errors.push("'plugins' must not include an empty string.");
        }
        if (Array.isArray(plugins)) {
            errors.push("'plugins' doesn't add plugins to configuration to load. Please use the 'overrideConfig.plugins' option instead.");
        }
        if (reportUnusedDisableDirectives !== "error" &&
            reportUnusedDisableDirectives !== "warn" &&
            reportUnusedDisableDirectives !== "off" &&
            reportUnusedDisableDirectives !== null) {
            errors.push("'reportUnusedDisableDirectives' must be any of \"error\", \"warn\", \"off\", and null.");
        }
        if (errors.length > 0) {
            throw new ESLintInvalidOptionsError(errors);
        }
        return {
            allowInlineConfig,
            baseConfig,
            cache,
            cacheLocation,
            cacheStrategy,
            // when overrideConfigFile is true that means don't do config file lookup
            configFile: overrideConfigFile === true ? false : overrideConfigFile,
            overrideConfig,
            cwd,
            errorOnUnmatchedPattern,
            fix,
            fixTypes,
            globInputPaths,
            ignore,
            ignorePatterns,
            reportUnusedDisableDirectives
        };
    }
    //-----------------------------------------------------------------------------
    // Cache-related helpers
    //-----------------------------------------------------------------------------
    /**
     * return the cacheFile to be used by eslint, based on whether the provided parameter is
     * a directory or looks like a directory (ends in `path.sep`), in which case the file
     * name will be the `cacheFile/.cache_hashOfCWD`
     *
     * if cacheFile points to a file or looks like a file then in will just use that file
     * @param {string} cacheFile The name of file to be used to store the cache
     * @param {string} cwd Current working directory
     * @returns {string} the resolved path to the cache file
     */
    function getCacheFile(cacheFile, cwd) {
        /*
         * make sure the path separators are normalized for the environment/os
         * keeping the trailing path separator if present
         */
        const normalizedCacheFile = path.normalize(cacheFile);
        const resolvedCacheFile = path.resolve(cwd, normalizedCacheFile);
        const looksLikeADirectory = normalizedCacheFile.slice(-1) === path.sep;
        /**
         * return the name for the cache file in case the provided parameter is a directory
         * @returns {string} the resolved path to the cacheFile
         */
        function getCacheFileForDirectory() {
            return path.join(resolvedCacheFile, `.cache_${hash(cwd)}`);
        }
        let fileStats;
        try {
            fileStats = fs.lstatSync(resolvedCacheFile);
        }
        catch {
            fileStats = null;
        }
        /*
         * in case the file exists we need to verify if the provided path
         * is a directory or a file. If it is a directory we want to create a file
         * inside that directory
         */
        if (fileStats) {
            /*
             * is a directory or is a file, but the original file the user provided
             * looks like a directory but `path.resolve` removed the `last path.sep`
             * so we need to still treat this like a directory
             */
            if (fileStats.isDirectory() || looksLikeADirectory) {
                return getCacheFileForDirectory();
            }
            // is file so just use that file
            return resolvedCacheFile;
        }
        /*
         * here we known the file or directory doesn't exist,
         * so we will try to infer if its a directory if it looks like a directory
         * for the current operating system.
         */
        // if the last character passed is a path separator we assume is a directory
        if (looksLikeADirectory) {
            return getCacheFileForDirectory();
        }
        return resolvedCacheFile;
    }
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    module.exports = {
        isGlobPattern,
        findFiles,
        isNonEmptyString,
        isArrayOfNonEmptyString,
        createIgnoreResult,
        isErrorMessage,
        processOptions,
        getCacheFile
    };
},
/* @nodelib/fs.walk/out/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Settings = exports.walkStream = exports.walkSync = exports.walk = void 0;
    const async_1 = require(736) /* ./providers/async */;
    const stream_1 = require(758) /* ./providers/stream */;
    const sync_1 = require(759) /* ./providers/sync */;
    const settings_1 = require(761) /* ./settings */;
    exports.Settings = settings_1.default;
    function walk(directory, optionsOrSettingsOrCallback, callback) {
        if (typeof optionsOrSettingsOrCallback === 'function') {
            new async_1.default(directory, getSettings()).read(optionsOrSettingsOrCallback);
            return;
        }
        new async_1.default(directory, getSettings(optionsOrSettingsOrCallback)).read(callback);
    }
    exports.walk = walk;
    function walkSync(directory, optionsOrSettings) {
        const settings = getSettings(optionsOrSettings);
        const provider = new sync_1.default(directory, settings);
        return provider.read();
    }
    exports.walkSync = walkSync;
    function walkStream(directory, optionsOrSettings) {
        const settings = getSettings(optionsOrSettings);
        const provider = new stream_1.default(directory, settings);
        return provider.read();
    }
    exports.walkStream = walkStream;
    function getSettings(settingsOrOptions = {}) {
        if (settingsOrOptions instanceof settings_1.default) {
            return settingsOrOptions;
        }
        return new settings_1.default(settingsOrOptions);
    }
},
/* @nodelib/fs.walk/out/providers/async.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const async_1 = require(737) /* ../readers/async */;
    class AsyncProvider {
        constructor(_root, _settings) {
            this._root = _root;
            this._settings = _settings;
            this._reader = new async_1.default(this._root, this._settings);
            this._storage = [];
        }
        read(callback) {
            this._reader.onError((error) => {
                callFailureCallback(callback, error);
            });
            this._reader.onEntry((entry) => {
                this._storage.push(entry);
            });
            this._reader.onEnd(() => {
                callSuccessCallback(callback, this._storage);
            });
            this._reader.read();
        }
    }
    exports.default = AsyncProvider;
    function callFailureCallback(callback, error) {
        callback(error);
    }
    function callSuccessCallback(callback, entries) {
        callback(null, entries);
    }
},
/* @nodelib/fs.walk/out/readers/async.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const events_1 = require("events");
    const fsScandir = require(738) /* @nodelib/fs.scandir */;
    const fastq = require(754) /* fastq */;
    const common = require(756) /* ./common */;
    const reader_1 = require(757) /* ./reader */;
    class AsyncReader extends reader_1.default {
        constructor(_root, _settings) {
            super(_root, _settings);
            this._settings = _settings;
            this._scandir = fsScandir.scandir;
            this._emitter = new events_1.EventEmitter();
            this._queue = fastq(this._worker.bind(this), this._settings.concurrency);
            this._isFatalError = false;
            this._isDestroyed = false;
            this._queue.drain = () => {
                if (!this._isFatalError) {
                    this._emitter.emit('end');
                }
            };
        }
        read() {
            this._isFatalError = false;
            this._isDestroyed = false;
            setImmediate(() => {
                this._pushToQueue(this._root, this._settings.basePath);
            });
            return this._emitter;
        }
        get isDestroyed() {
            return this._isDestroyed;
        }
        destroy() {
            if (this._isDestroyed) {
                throw new Error('The reader is already destroyed');
            }
            this._isDestroyed = true;
            this._queue.killAndDrain();
        }
        onEntry(callback) {
            this._emitter.on('entry', callback);
        }
        onError(callback) {
            this._emitter.once('error', callback);
        }
        onEnd(callback) {
            this._emitter.once('end', callback);
        }
        _pushToQueue(directory, base) {
            const queueItem = { directory, base };
            this._queue.push(queueItem, (error) => {
                if (error !== null) {
                    this._handleError(error);
                }
            });
        }
        _worker(item, done) {
            this._scandir(item.directory, this._settings.fsScandirSettings, (error, entries) => {
                if (error !== null) {
                    done(error, undefined);
                    return;
                }
                for (const entry of entries) {
                    this._handleEntry(entry, item.base);
                }
                done(null, undefined);
            });
        }
        _handleError(error) {
            if (this._isDestroyed || !common.isFatalError(this._settings, error)) {
                return;
            }
            this._isFatalError = true;
            this._isDestroyed = true;
            this._emitter.emit('error', error);
        }
        _handleEntry(entry, base) {
            if (this._isDestroyed || this._isFatalError) {
                return;
            }
            const fullpath = entry.path;
            if (base !== undefined) {
                entry.path = common.joinPathSegments(base, entry.name, this._settings.pathSegmentSeparator);
            }
            if (common.isAppliedFilter(this._settings.entryFilter, entry)) {
                this._emitEntry(entry);
            }
            if (entry.dirent.isDirectory() && common.isAppliedFilter(this._settings.deepFilter, entry)) {
                this._pushToQueue(fullpath, base === undefined ? undefined : entry.path);
            }
        }
        _emitEntry(entry) {
            this._emitter.emit('entry', entry);
        }
    }
    exports.default = AsyncReader;
},
/* @nodelib/fs.scandir/out/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Settings = exports.scandirSync = exports.scandir = void 0;
    const async = require(739) /* ./providers/async */;
    const sync = require(751) /* ./providers/sync */;
    const settings_1 = require(752) /* ./settings */;
    exports.Settings = settings_1.default;
    function scandir(path, optionsOrSettingsOrCallback, callback) {
        if (typeof optionsOrSettingsOrCallback === 'function') {
            async.read(path, getSettings(), optionsOrSettingsOrCallback);
            return;
        }
        async.read(path, getSettings(optionsOrSettingsOrCallback), callback);
    }
    exports.scandir = scandir;
    function scandirSync(path, optionsOrSettings) {
        const settings = getSettings(optionsOrSettings);
        return sync.read(path, settings);
    }
    exports.scandirSync = scandirSync;
    function getSettings(settingsOrOptions = {}) {
        if (settingsOrOptions instanceof settings_1.default) {
            return settingsOrOptions;
        }
        return new settings_1.default(settingsOrOptions);
    }
},
/* @nodelib/fs.scandir/out/providers/async.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.readdir = exports.readdirWithFileTypes = exports.read = void 0;
    const fsStat = require(740) /* @nodelib/fs.stat */;
    const rpl = require(745) /* run-parallel */;
    const constants_1 = require(747) /* ../constants */;
    const utils = require(748) /* ../utils */;
    const common = require(750) /* ./common */;
    function read(directory, settings, callback) {
        if (!settings.stats && constants_1.IS_SUPPORT_READDIR_WITH_FILE_TYPES) {
            readdirWithFileTypes(directory, settings, callback);
            return;
        }
        readdir(directory, settings, callback);
    }
    exports.read = read;
    function readdirWithFileTypes(directory, settings, callback) {
        settings.fs.readdir(directory, { withFileTypes: true }, (readdirError, dirents) => {
            if (readdirError !== null) {
                callFailureCallback(callback, readdirError);
                return;
            }
            const entries = dirents.map((dirent) => ({
                dirent,
                name: dirent.name,
                path: common.joinPathSegments(directory, dirent.name, settings.pathSegmentSeparator)
            }));
            if (!settings.followSymbolicLinks) {
                callSuccessCallback(callback, entries);
                return;
            }
            const tasks = entries.map((entry) => makeRplTaskEntry(entry, settings));
            rpl(tasks, (rplError, rplEntries) => {
                if (rplError !== null) {
                    callFailureCallback(callback, rplError);
                    return;
                }
                callSuccessCallback(callback, rplEntries);
            });
        });
    }
    exports.readdirWithFileTypes = readdirWithFileTypes;
    function makeRplTaskEntry(entry, settings) {
        return (done) => {
            if (!entry.dirent.isSymbolicLink()) {
                done(null, entry);
                return;
            }
            settings.fs.stat(entry.path, (statError, stats) => {
                if (statError !== null) {
                    if (settings.throwErrorOnBrokenSymbolicLink) {
                        done(statError);
                        return;
                    }
                    done(null, entry);
                    return;
                }
                entry.dirent = utils.fs.createDirentFromStats(entry.name, stats);
                done(null, entry);
            });
        };
    }
    function readdir(directory, settings, callback) {
        settings.fs.readdir(directory, (readdirError, names) => {
            if (readdirError !== null) {
                callFailureCallback(callback, readdirError);
                return;
            }
            const tasks = names.map((name) => {
                const path = common.joinPathSegments(directory, name, settings.pathSegmentSeparator);
                return (done) => {
                    fsStat.stat(path, settings.fsStatSettings, (error, stats) => {
                        if (error !== null) {
                            done(error);
                            return;
                        }
                        const entry = {
                            name,
                            path,
                            dirent: utils.fs.createDirentFromStats(name, stats)
                        };
                        if (settings.stats) {
                            entry.stats = stats;
                        }
                        done(null, entry);
                    });
                };
            });
            rpl(tasks, (rplError, entries) => {
                if (rplError !== null) {
                    callFailureCallback(callback, rplError);
                    return;
                }
                callSuccessCallback(callback, entries);
            });
        });
    }
    exports.readdir = readdir;
    function callFailureCallback(callback, error) {
        callback(error);
    }
    function callSuccessCallback(callback, result) {
        callback(null, result);
    }
},
/* @nodelib/fs.stat/out/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.statSync = exports.stat = exports.Settings = void 0;
    const async = require(741) /* ./providers/async */;
    const sync = require(742) /* ./providers/sync */;
    const settings_1 = require(743) /* ./settings */;
    exports.Settings = settings_1.default;
    function stat(path, optionsOrSettingsOrCallback, callback) {
        if (typeof optionsOrSettingsOrCallback === 'function') {
            async.read(path, getSettings(), optionsOrSettingsOrCallback);
            return;
        }
        async.read(path, getSettings(optionsOrSettingsOrCallback), callback);
    }
    exports.stat = stat;
    function statSync(path, optionsOrSettings) {
        const settings = getSettings(optionsOrSettings);
        return sync.read(path, settings);
    }
    exports.statSync = statSync;
    function getSettings(settingsOrOptions = {}) {
        if (settingsOrOptions instanceof settings_1.default) {
            return settingsOrOptions;
        }
        return new settings_1.default(settingsOrOptions);
    }
},
/* @nodelib/fs.stat/out/providers/async.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.read = void 0;
    function read(path, settings, callback) {
        settings.fs.lstat(path, (lstatError, lstat) => {
            if (lstatError !== null) {
                callFailureCallback(callback, lstatError);
                return;
            }
            if (!lstat.isSymbolicLink() || !settings.followSymbolicLink) {
                callSuccessCallback(callback, lstat);
                return;
            }
            settings.fs.stat(path, (statError, stat) => {
                if (statError !== null) {
                    if (settings.throwErrorOnBrokenSymbolicLink) {
                        callFailureCallback(callback, statError);
                        return;
                    }
                    callSuccessCallback(callback, lstat);
                    return;
                }
                if (settings.markSymbolicLink) {
                    stat.isSymbolicLink = () => true;
                }
                callSuccessCallback(callback, stat);
            });
        });
    }
    exports.read = read;
    function callFailureCallback(callback, error) {
        callback(error);
    }
    function callSuccessCallback(callback, result) {
        callback(null, result);
    }
},
/* @nodelib/fs.stat/out/providers/sync.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.read = void 0;
    function read(path, settings) {
        const lstat = settings.fs.lstatSync(path);
        if (!lstat.isSymbolicLink() || !settings.followSymbolicLink) {
            return lstat;
        }
        try {
            const stat = settings.fs.statSync(path);
            if (settings.markSymbolicLink) {
                stat.isSymbolicLink = () => true;
            }
            return stat;
        }
        catch (error) {
            if (!settings.throwErrorOnBrokenSymbolicLink) {
                return lstat;
            }
            throw error;
        }
    }
    exports.read = read;
},
/* @nodelib/fs.stat/out/settings.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const fs = require(744) /* ./adapters/fs */;
    class Settings {
        constructor(_options = {}) {
            this._options = _options;
            this.followSymbolicLink = this._getValue(this._options.followSymbolicLink, true);
            this.fs = fs.createFileSystemAdapter(this._options.fs);
            this.markSymbolicLink = this._getValue(this._options.markSymbolicLink, false);
            this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, true);
        }
        _getValue(option, value) {
            return option !== null && option !== void 0 ? option : value;
        }
    }
    exports.default = Settings;
},
/* @nodelib/fs.stat/out/adapters/fs.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createFileSystemAdapter = exports.FILE_SYSTEM_ADAPTER = void 0;
    const fs = require("fs");
    exports.FILE_SYSTEM_ADAPTER = {
        lstat: fs.lstat,
        stat: fs.stat,
        lstatSync: fs.lstatSync,
        statSync: fs.statSync
    };
    function createFileSystemAdapter(fsMethods) {
        if (fsMethods === undefined) {
            return exports.FILE_SYSTEM_ADAPTER;
        }
        return Object.assign(Object.assign({}, exports.FILE_SYSTEM_ADAPTER), fsMethods);
    }
    exports.createFileSystemAdapter = createFileSystemAdapter;
},
/* run-parallel/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /*! run-parallel. MIT License. Feross Aboukhadijeh <https://feross.org/opensource> */
    module.exports = runParallel;
    const queueMicrotask = require(746) /* queue-microtask */;
    function runParallel(tasks, cb) {
        let results, pending, keys;
        let isSync = true;
        if (Array.isArray(tasks)) {
            results = [];
            pending = tasks.length;
        }
        else {
            keys = Object.keys(tasks);
            results = {};
            pending = keys.length;
        }
        function done(err) {
            function end() {
                if (cb)
                    cb(err, results);
                cb = null;
            }
            if (isSync)
                queueMicrotask(end);
            else
                end();
        }
        function each(i, err, result) {
            results[i] = result;
            if (--pending === 0 || err) {
                done(err);
            }
        }
        if (!pending) {
            // empty
            done(null);
        }
        else if (keys) {
            // object
            keys.forEach(function (key) {
                tasks[key](function (err, result) { each(key, err, result); });
            });
        }
        else {
            // array
            tasks.forEach(function (task, i) {
                task(function (err, result) { each(i, err, result); });
            });
        }
        isSync = false;
    }
},
/* queue-microtask/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /*! queue-microtask. MIT License. Feross Aboukhadijeh <https://feross.org/opensource> */
    let promise;
    module.exports = typeof queueMicrotask === 'function'
        ? queueMicrotask.bind(typeof window !== 'undefined' ? window : global)
        // reuse resolved promise, and allocate it lazily
        : cb => (promise || (promise = Promise.resolve()))
            .then(cb)
            .catch(err => setTimeout(() => { throw err; }, 0));
},
/* @nodelib/fs.scandir/out/constants.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.IS_SUPPORT_READDIR_WITH_FILE_TYPES = void 0;
    const NODE_PROCESS_VERSION_PARTS = process.versions.node.split('.');
    if (NODE_PROCESS_VERSION_PARTS[0] === undefined || NODE_PROCESS_VERSION_PARTS[1] === undefined) {
        throw new Error(`Unexpected behavior. The 'process.versions.node' variable has invalid value: ${process.versions.node}`);
    }
    const MAJOR_VERSION = Number.parseInt(NODE_PROCESS_VERSION_PARTS[0], 10);
    const MINOR_VERSION = Number.parseInt(NODE_PROCESS_VERSION_PARTS[1], 10);
    const SUPPORTED_MAJOR_VERSION = 10;
    const SUPPORTED_MINOR_VERSION = 10;
    const IS_MATCHED_BY_MAJOR = MAJOR_VERSION > SUPPORTED_MAJOR_VERSION;
    const IS_MATCHED_BY_MAJOR_AND_MINOR = MAJOR_VERSION === SUPPORTED_MAJOR_VERSION && MINOR_VERSION >= SUPPORTED_MINOR_VERSION;
    /**
     * IS `true` for Node.js 10.10 and greater.
     */
    exports.IS_SUPPORT_READDIR_WITH_FILE_TYPES = IS_MATCHED_BY_MAJOR || IS_MATCHED_BY_MAJOR_AND_MINOR;
},
/* @nodelib/fs.scandir/out/utils/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.fs = void 0;
    const fs = require(749) /* ./fs */;
    exports.fs = fs;
},
/* @nodelib/fs.scandir/out/utils/fs.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createDirentFromStats = void 0;
    class DirentFromStats {
        constructor(name, stats) {
            this.name = name;
            this.isBlockDevice = stats.isBlockDevice.bind(stats);
            this.isCharacterDevice = stats.isCharacterDevice.bind(stats);
            this.isDirectory = stats.isDirectory.bind(stats);
            this.isFIFO = stats.isFIFO.bind(stats);
            this.isFile = stats.isFile.bind(stats);
            this.isSocket = stats.isSocket.bind(stats);
            this.isSymbolicLink = stats.isSymbolicLink.bind(stats);
        }
    }
    function createDirentFromStats(name, stats) {
        return new DirentFromStats(name, stats);
    }
    exports.createDirentFromStats = createDirentFromStats;
},
/* @nodelib/fs.scandir/out/providers/common.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.joinPathSegments = void 0;
    function joinPathSegments(a, b, separator) {
        /**
         * The correct handling of cases when the first segment is a root (`/`, `C:/`) or UNC path (`//?/C:/`).
         */
        if (a.endsWith(separator)) {
            return a + b;
        }
        return a + separator + b;
    }
    exports.joinPathSegments = joinPathSegments;
},
/* @nodelib/fs.scandir/out/providers/sync.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.readdir = exports.readdirWithFileTypes = exports.read = void 0;
    const fsStat = require(740) /* @nodelib/fs.stat */;
    const constants_1 = require(747) /* ../constants */;
    const utils = require(748) /* ../utils */;
    const common = require(750) /* ./common */;
    function read(directory, settings) {
        if (!settings.stats && constants_1.IS_SUPPORT_READDIR_WITH_FILE_TYPES) {
            return readdirWithFileTypes(directory, settings);
        }
        return readdir(directory, settings);
    }
    exports.read = read;
    function readdirWithFileTypes(directory, settings) {
        const dirents = settings.fs.readdirSync(directory, { withFileTypes: true });
        return dirents.map((dirent) => {
            const entry = {
                dirent,
                name: dirent.name,
                path: common.joinPathSegments(directory, dirent.name, settings.pathSegmentSeparator)
            };
            if (entry.dirent.isSymbolicLink() && settings.followSymbolicLinks) {
                try {
                    const stats = settings.fs.statSync(entry.path);
                    entry.dirent = utils.fs.createDirentFromStats(entry.name, stats);
                }
                catch (error) {
                    if (settings.throwErrorOnBrokenSymbolicLink) {
                        throw error;
                    }
                }
            }
            return entry;
        });
    }
    exports.readdirWithFileTypes = readdirWithFileTypes;
    function readdir(directory, settings) {
        const names = settings.fs.readdirSync(directory);
        return names.map((name) => {
            const entryPath = common.joinPathSegments(directory, name, settings.pathSegmentSeparator);
            const stats = fsStat.statSync(entryPath, settings.fsStatSettings);
            const entry = {
                name,
                path: entryPath,
                dirent: utils.fs.createDirentFromStats(name, stats)
            };
            if (settings.stats) {
                entry.stats = stats;
            }
            return entry;
        });
    }
    exports.readdir = readdir;
},
/* @nodelib/fs.scandir/out/settings.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const path = require("path");
    const fsStat = require(740) /* @nodelib/fs.stat */;
    const fs = require(753) /* ./adapters/fs */;
    class Settings {
        constructor(_options = {}) {
            this._options = _options;
            this.followSymbolicLinks = this._getValue(this._options.followSymbolicLinks, false);
            this.fs = fs.createFileSystemAdapter(this._options.fs);
            this.pathSegmentSeparator = this._getValue(this._options.pathSegmentSeparator, path.sep);
            this.stats = this._getValue(this._options.stats, false);
            this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, true);
            this.fsStatSettings = new fsStat.Settings({
                followSymbolicLink: this.followSymbolicLinks,
                fs: this.fs,
                throwErrorOnBrokenSymbolicLink: this.throwErrorOnBrokenSymbolicLink
            });
        }
        _getValue(option, value) {
            return option !== null && option !== void 0 ? option : value;
        }
    }
    exports.default = Settings;
},
/* @nodelib/fs.scandir/out/adapters/fs.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createFileSystemAdapter = exports.FILE_SYSTEM_ADAPTER = void 0;
    const fs = require("fs");
    exports.FILE_SYSTEM_ADAPTER = {
        lstat: fs.lstat,
        stat: fs.stat,
        lstatSync: fs.lstatSync,
        statSync: fs.statSync,
        readdir: fs.readdir,
        readdirSync: fs.readdirSync
    };
    function createFileSystemAdapter(fsMethods) {
        if (fsMethods === undefined) {
            return exports.FILE_SYSTEM_ADAPTER;
        }
        return Object.assign(Object.assign({}, exports.FILE_SYSTEM_ADAPTER), fsMethods);
    }
    exports.createFileSystemAdapter = createFileSystemAdapter;
},
/* fastq/queue.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    /* eslint-disable no-var */
    var reusify = require(755) /* reusify */;
    function fastqueue(context, worker, concurrency) {
        if (typeof context === 'function') {
            concurrency = worker;
            worker = context;
            context = null;
        }
        if (concurrency < 1) {
            throw new Error('fastqueue concurrency must be greater than 1');
        }
        var cache = reusify(Task);
        var queueHead = null;
        var queueTail = null;
        var _running = 0;
        var errorHandler = null;
        var self = {
            push: push,
            drain: noop,
            saturated: noop,
            pause: pause,
            paused: false,
            concurrency: concurrency,
            running: running,
            resume: resume,
            idle: idle,
            length: length,
            getQueue: getQueue,
            unshift: unshift,
            empty: noop,
            kill: kill,
            killAndDrain: killAndDrain,
            error: error
        };
        return self;
        function running() {
            return _running;
        }
        function pause() {
            self.paused = true;
        }
        function length() {
            var current = queueHead;
            var counter = 0;
            while (current) {
                current = current.next;
                counter++;
            }
            return counter;
        }
        function getQueue() {
            var current = queueHead;
            var tasks = [];
            while (current) {
                tasks.push(current.value);
                current = current.next;
            }
            return tasks;
        }
        function resume() {
            if (!self.paused)
                return;
            self.paused = false;
            for (var i = 0; i < self.concurrency; i++) {
                _running++;
                release();
            }
        }
        function idle() {
            return _running === 0 && self.length() === 0;
        }
        function push(value, done) {
            var current = cache.get();
            current.context = context;
            current.release = release;
            current.value = value;
            current.callback = done || noop;
            current.errorHandler = errorHandler;
            if (_running === self.concurrency || self.paused) {
                if (queueTail) {
                    queueTail.next = current;
                    queueTail = current;
                }
                else {
                    queueHead = current;
                    queueTail = current;
                    self.saturated();
                }
            }
            else {
                _running++;
                worker.call(context, current.value, current.worked);
            }
        }
        function unshift(value, done) {
            var current = cache.get();
            current.context = context;
            current.release = release;
            current.value = value;
            current.callback = done || noop;
            if (_running === self.concurrency || self.paused) {
                if (queueHead) {
                    current.next = queueHead;
                    queueHead = current;
                }
                else {
                    queueHead = current;
                    queueTail = current;
                    self.saturated();
                }
            }
            else {
                _running++;
                worker.call(context, current.value, current.worked);
            }
        }
        function release(holder) {
            if (holder) {
                cache.release(holder);
            }
            var next = queueHead;
            if (next) {
                if (!self.paused) {
                    if (queueTail === queueHead) {
                        queueTail = null;
                    }
                    queueHead = next.next;
                    next.next = null;
                    worker.call(context, next.value, next.worked);
                    if (queueTail === null) {
                        self.empty();
                    }
                }
                else {
                    _running--;
                }
            }
            else if (--_running === 0) {
                self.drain();
            }
        }
        function kill() {
            queueHead = null;
            queueTail = null;
            self.drain = noop;
        }
        function killAndDrain() {
            queueHead = null;
            queueTail = null;
            self.drain();
            self.drain = noop;
        }
        function error(handler) {
            errorHandler = handler;
        }
    }
    function noop() { }
    function Task() {
        this.value = null;
        this.callback = noop;
        this.next = null;
        this.release = noop;
        this.context = null;
        this.errorHandler = null;
        var self = this;
        this.worked = function worked(err, result) {
            var callback = self.callback;
            var errorHandler = self.errorHandler;
            var val = self.value;
            self.value = null;
            self.callback = noop;
            if (self.errorHandler) {
                errorHandler(err, val);
            }
            callback.call(self.context, err, result);
            self.release(self);
        };
    }
    function queueAsPromised(context, worker, concurrency) {
        if (typeof context === 'function') {
            concurrency = worker;
            worker = context;
            context = null;
        }
        function asyncWrapper(arg, cb) {
            worker.call(this, arg)
                .then(function (res) {
                cb(null, res);
            }, cb);
        }
        var queue = fastqueue(context, asyncWrapper, concurrency);
        var pushCb = queue.push;
        var unshiftCb = queue.unshift;
        queue.push = push;
        queue.unshift = unshift;
        queue.drained = drained;
        return queue;
        function push(value) {
            var p = new Promise(function (resolve, reject) {
                pushCb(value, function (err, result) {
                    if (err) {
                        reject(err);
                        return;
                    }
                    resolve(result);
                });
            });
            // Let's fork the promise chain to
            // make the error bubble up to the user but
            // not lead to a unhandledRejection
            p.catch(noop);
            return p;
        }
        function unshift(value) {
            var p = new Promise(function (resolve, reject) {
                unshiftCb(value, function (err, result) {
                    if (err) {
                        reject(err);
                        return;
                    }
                    resolve(result);
                });
            });
            // Let's fork the promise chain to
            // make the error bubble up to the user but
            // not lead to a unhandledRejection
            p.catch(noop);
            return p;
        }
        function drained() {
            if (queue.idle()) {
                return new Promise(function (resolve) {
                    resolve();
                });
            }
            var previousDrain = queue.drain;
            var p = new Promise(function (resolve) {
                queue.drain = function () {
                    previousDrain();
                    resolve();
                };
            });
            return p;
        }
    }
    module.exports = fastqueue;
    module.exports.promise = queueAsPromised;
},
/* reusify/reusify.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    function reusify(Constructor) {
        var head = new Constructor();
        var tail = head;
        function get() {
            var current = head;
            if (current.next) {
                head = current.next;
            }
            else {
                head = new Constructor();
                tail = head;
            }
            current.next = null;
            return current;
        }
        function release(obj) {
            tail.next = obj;
            tail = obj;
        }
        return {
            get: get,
            release: release
        };
    }
    module.exports = reusify;
},
/* @nodelib/fs.walk/out/readers/common.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.joinPathSegments = exports.replacePathSegmentSeparator = exports.isAppliedFilter = exports.isFatalError = void 0;
    function isFatalError(settings, error) {
        if (settings.errorFilter === null) {
            return true;
        }
        return !settings.errorFilter(error);
    }
    exports.isFatalError = isFatalError;
    function isAppliedFilter(filter, value) {
        return filter === null || filter(value);
    }
    exports.isAppliedFilter = isAppliedFilter;
    function replacePathSegmentSeparator(filepath, separator) {
        return filepath.split(/[/\\]/).join(separator);
    }
    exports.replacePathSegmentSeparator = replacePathSegmentSeparator;
    function joinPathSegments(a, b, separator) {
        if (a === '') {
            return b;
        }
        /**
         * The correct handling of cases when the first segment is a root (`/`, `C:/`) or UNC path (`//?/C:/`).
         */
        if (a.endsWith(separator)) {
            return a + b;
        }
        return a + separator + b;
    }
    exports.joinPathSegments = joinPathSegments;
},
/* @nodelib/fs.walk/out/readers/reader.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const common = require(756) /* ./common */;
    class Reader {
        constructor(_root, _settings) {
            this._root = _root;
            this._settings = _settings;
            this._root = common.replacePathSegmentSeparator(_root, _settings.pathSegmentSeparator);
        }
    }
    exports.default = Reader;
},
/* @nodelib/fs.walk/out/providers/stream.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const stream_1 = require("stream");
    const async_1 = require(737) /* ../readers/async */;
    class StreamProvider {
        constructor(_root, _settings) {
            this._root = _root;
            this._settings = _settings;
            this._reader = new async_1.default(this._root, this._settings);
            this._stream = new stream_1.Readable({
                objectMode: true,
                read: () => { },
                destroy: () => {
                    if (!this._reader.isDestroyed) {
                        this._reader.destroy();
                    }
                }
            });
        }
        read() {
            this._reader.onError((error) => {
                this._stream.emit('error', error);
            });
            this._reader.onEntry((entry) => {
                this._stream.push(entry);
            });
            this._reader.onEnd(() => {
                this._stream.push(null);
            });
            this._reader.read();
            return this._stream;
        }
    }
    exports.default = StreamProvider;
},
/* @nodelib/fs.walk/out/providers/sync.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const sync_1 = require(760) /* ../readers/sync */;
    class SyncProvider {
        constructor(_root, _settings) {
            this._root = _root;
            this._settings = _settings;
            this._reader = new sync_1.default(this._root, this._settings);
        }
        read() {
            return this._reader.read();
        }
    }
    exports.default = SyncProvider;
},
/* @nodelib/fs.walk/out/readers/sync.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const fsScandir = require(738) /* @nodelib/fs.scandir */;
    const common = require(756) /* ./common */;
    const reader_1 = require(757) /* ./reader */;
    class SyncReader extends reader_1.default {
        constructor() {
            super(...arguments);
            this._scandir = fsScandir.scandirSync;
            this._storage = [];
            this._queue = new Set();
        }
        read() {
            this._pushToQueue(this._root, this._settings.basePath);
            this._handleQueue();
            return this._storage;
        }
        _pushToQueue(directory, base) {
            this._queue.add({ directory, base });
        }
        _handleQueue() {
            for (const item of this._queue.values()) {
                this._handleDirectory(item.directory, item.base);
            }
        }
        _handleDirectory(directory, base) {
            try {
                const entries = this._scandir(directory, this._settings.fsScandirSettings);
                for (const entry of entries) {
                    this._handleEntry(entry, base);
                }
            }
            catch (error) {
                this._handleError(error);
            }
        }
        _handleError(error) {
            if (!common.isFatalError(this._settings, error)) {
                return;
            }
            throw error;
        }
        _handleEntry(entry, base) {
            const fullpath = entry.path;
            if (base !== undefined) {
                entry.path = common.joinPathSegments(base, entry.name, this._settings.pathSegmentSeparator);
            }
            if (common.isAppliedFilter(this._settings.entryFilter, entry)) {
                this._pushToStorage(entry);
            }
            if (entry.dirent.isDirectory() && common.isAppliedFilter(this._settings.deepFilter, entry)) {
                this._pushToQueue(fullpath, base === undefined ? undefined : entry.path);
            }
        }
        _pushToStorage(entry) {
            this._storage.push(entry);
        }
    }
    exports.default = SyncReader;
},
/* @nodelib/fs.walk/out/settings.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const path = require("path");
    const fsScandir = require(738) /* @nodelib/fs.scandir */;
    class Settings {
        constructor(_options = {}) {
            this._options = _options;
            this.basePath = this._getValue(this._options.basePath, undefined);
            this.concurrency = this._getValue(this._options.concurrency, Number.POSITIVE_INFINITY);
            this.deepFilter = this._getValue(this._options.deepFilter, null);
            this.entryFilter = this._getValue(this._options.entryFilter, null);
            this.errorFilter = this._getValue(this._options.errorFilter, null);
            this.pathSegmentSeparator = this._getValue(this._options.pathSegmentSeparator, path.sep);
            this.fsScandirSettings = new fsScandir.Settings({
                followSymbolicLinks: this._options.followSymbolicLinks,
                fs: this._options.fs,
                pathSegmentSeparator: this._options.pathSegmentSeparator,
                stats: this._options.stats,
                throwErrorOnBrokenSymbolicLink: this._options.throwErrorOnBrokenSymbolicLink
            });
        }
        _getValue(option, value) {
            return option !== null && option !== void 0 ? option : value;
        }
    }
    exports.default = Settings;
},
/* is-path-inside/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const path = require('path');
    module.exports = (childPath, parentPath) => {
        const relation = path.relative(parentPath, childPath);
        return Boolean(relation &&
            relation !== '..' &&
            !relation.startsWith(`..${path.sep}`) &&
            relation !== path.resolve(childPath));
    };
},
/* eslint/lib/rule-tester/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    module.exports = {
        RuleTester: require(764) /* ./rule-tester */
    };
},
/* eslint/lib/rule-tester/rule-tester.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Mocha test wrapper
     * @author Ilya Volodin
     */
    "use strict";
    /* globals describe, it -- Mocha globals */
    /*
     * This is a wrapper around mocha to allow for DRY unittests for eslint
     * Format:
     * RuleTester.run("{ruleName}", {
     *      valid: [
     *          "{code}",
     *          { code: "{code}", options: {options}, globals: {globals}, parser: "{parser}", settings: {settings} }
     *      ],
     *      invalid: [
     *          { code: "{code}", errors: {numErrors} },
     *          { code: "{code}", errors: ["{errorMessage}"] },
     *          { code: "{code}", options: {options}, globals: {globals}, parser: "{parser}", settings: {settings}, errors: [{ message: "{errorMessage}", type: "{errorNodeType}"}] }
     *      ]
     *  });
     *
     * Variables:
     * {code} - String that represents the code to be tested
     * {options} - Arguments that are passed to the configurable rules.
     * {globals} - An object representing a list of variables that are
     *             registered as globals
     * {parser} - String representing the parser to use
     * {settings} - An object representing global settings for all rules
     * {numErrors} - If failing case doesn't need to check error message,
     *               this integer will specify how many errors should be
     *               received
     * {errorMessage} - Message that is returned by the rule on failure
     * {errorNodeType} - AST node type that is returned by they rule as
     *                   a cause of the failure.
     */
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const assert = require("assert"), path = require("path"), util = require("util"), merge = require(308) /* lodash.merge */, equal = require(237) /* fast-deep-equal */, Traverser = require(313) /* ../../lib/shared/traverser */, { getRuleOptionsSchema, validate } = require(765) /* ../shared/config-validator */, { Linter, SourceCodeFixer, interpolate } = require(289) /* ../linter */;
    const ajv = require(703) /* ../shared/ajv */({ strictDefaults: true });
    const espreePath = require.resolve("espree");
    const parserSymbol = Symbol.for("eslint.RuleTester.parser");
    const { SourceCode } = require(314) /* ../source-code */;
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /** @typedef {import("../shared/types").Parser} Parser */
    /* eslint-disable jsdoc/valid-types -- https://github.com/jsdoc-type-pratt-parser/jsdoc-type-pratt-parser/issues/4#issuecomment-778805577 */
    /**
     * A test case that is expected to pass lint.
     * @typedef {Object} ValidTestCase
     * @property {string} [name] Name for the test case.
     * @property {string} code Code for the test case.
     * @property {any[]} [options] Options for the test case.
     * @property {{ [name: string]: any }} [settings] Settings for the test case.
     * @property {string} [filename] The fake filename for the test case. Useful for rules that make assertion about filenames.
     * @property {string} [parser] The absolute path for the parser.
     * @property {{ [name: string]: any }} [parserOptions] Options for the parser.
     * @property {{ [name: string]: "readonly" | "writable" | "off" }} [globals] The additional global variables.
     * @property {{ [name: string]: boolean }} [env] Environments for the test case.
     * @property {boolean} [only] Run only this test case or the subset of test cases with this property.
     */
    /**
     * A test case that is expected to fail lint.
     * @typedef {Object} InvalidTestCase
     * @property {string} [name] Name for the test case.
     * @property {string} code Code for the test case.
     * @property {number | Array<TestCaseError | string | RegExp>} errors Expected errors.
     * @property {string | null} [output] The expected code after autofixes are applied. If set to `null`, the test runner will assert that no autofix is suggested.
     * @property {any[]} [options] Options for the test case.
     * @property {{ [name: string]: any }} [settings] Settings for the test case.
     * @property {string} [filename] The fake filename for the test case. Useful for rules that make assertion about filenames.
     * @property {string} [parser] The absolute path for the parser.
     * @property {{ [name: string]: any }} [parserOptions] Options for the parser.
     * @property {{ [name: string]: "readonly" | "writable" | "off" }} [globals] The additional global variables.
     * @property {{ [name: string]: boolean }} [env] Environments for the test case.
     * @property {boolean} [only] Run only this test case or the subset of test cases with this property.
     */
    /**
     * A description of a reported error used in a rule tester test.
     * @typedef {Object} TestCaseError
     * @property {string | RegExp} [message] Message.
     * @property {string} [messageId] Message ID.
     * @property {string} [type] The type of the reported AST node.
     * @property {{ [name: string]: string }} [data] The data used to fill the message template.
     * @property {number} [line] The 1-based line number of the reported start location.
     * @property {number} [column] The 1-based column number of the reported start location.
     * @property {number} [endLine] The 1-based line number of the reported end location.
     * @property {number} [endColumn] The 1-based column number of the reported end location.
     */
    /* eslint-enable jsdoc/valid-types -- https://github.com/jsdoc-type-pratt-parser/jsdoc-type-pratt-parser/issues/4#issuecomment-778805577 */
    //------------------------------------------------------------------------------
    // Private Members
    //------------------------------------------------------------------------------
    /*
     * testerDefaultConfig must not be modified as it allows to reset the tester to
     * the initial default configuration
     */
    const testerDefaultConfig = { rules: {} };
    let defaultConfig = { rules: {} };
    /*
     * List every parameters possible on a test case that are not related to eslint
     * configuration
     */
    const RuleTesterParameters = [
        "name",
        "code",
        "filename",
        "options",
        "errors",
        "output",
        "only"
    ];
    /*
     * All allowed property names in error objects.
     */
    const errorObjectParameters = new Set([
        "message",
        "messageId",
        "data",
        "type",
        "line",
        "column",
        "endLine",
        "endColumn",
        "suggestions"
    ]);
    const friendlyErrorObjectParameterList = `[${[...errorObjectParameters].map(key => `'${key}'`).join(", ")}]`;
    /*
     * All allowed property names in suggestion objects.
     */
    const suggestionObjectParameters = new Set([
        "desc",
        "messageId",
        "data",
        "output"
    ]);
    const friendlySuggestionObjectParameterList = `[${[...suggestionObjectParameters].map(key => `'${key}'`).join(", ")}]`;
    const hasOwnProperty = Function.call.bind(Object.hasOwnProperty);
    /**
     * Clones a given value deeply.
     * Note: This ignores `parent` property.
     * @param {any} x A value to clone.
     * @returns {any} A cloned value.
     */
    function cloneDeeplyExcludesParent(x) {
        if (typeof x === "object" && x !== null) {
            if (Array.isArray(x)) {
                return x.map(cloneDeeplyExcludesParent);
            }
            const retv = {};
            for (const key in x) {
                if (key !== "parent" && hasOwnProperty(x, key)) {
                    retv[key] = cloneDeeplyExcludesParent(x[key]);
                }
            }
            return retv;
        }
        return x;
    }
    /**
     * Freezes a given value deeply.
     * @param {any} x A value to freeze.
     * @returns {void}
     */
    function freezeDeeply(x) {
        if (typeof x === "object" && x !== null) {
            if (Array.isArray(x)) {
                x.forEach(freezeDeeply);
            }
            else {
                for (const key in x) {
                    if (key !== "parent" && hasOwnProperty(x, key)) {
                        freezeDeeply(x[key]);
                    }
                }
            }
            Object.freeze(x);
        }
    }
    /**
     * Replace control characters by `\u00xx` form.
     * @param {string} text The text to sanitize.
     * @returns {string} The sanitized text.
     */
    function sanitize(text) {
        if (typeof text !== "string") {
            return "";
        }
        return text.replace(/[\u0000-\u0009\u000b-\u001a]/gu, // eslint-disable-line no-control-regex -- Escaping controls
        // eslint-disable-line no-control-regex -- Escaping controls
        c => `\\u${c.codePointAt(0).toString(16).padStart(4, "0")}`);
    }
    /**
     * Define `start`/`end` properties as throwing error.
     * @param {string} objName Object name used for error messages.
     * @param {ASTNode} node The node to define.
     * @returns {void}
     */
    function defineStartEndAsError(objName, node) {
        Object.defineProperties(node, {
            start: {
                get() {
                    throw new Error(`Use ${objName}.range[0] instead of ${objName}.start`);
                },
                configurable: true,
                enumerable: false
            },
            end: {
                get() {
                    throw new Error(`Use ${objName}.range[1] instead of ${objName}.end`);
                },
                configurable: true,
                enumerable: false
            }
        });
    }
    /**
     * Define `start`/`end` properties of all nodes of the given AST as throwing error.
     * @param {ASTNode} ast The root node to errorize `start`/`end` properties.
     * @param {Object} [visitorKeys] Visitor keys to be used for traversing the given ast.
     * @returns {void}
     */
    function defineStartEndAsErrorInTree(ast, visitorKeys) {
        Traverser.traverse(ast, { visitorKeys, enter: defineStartEndAsError.bind(null, "node") });
        ast.tokens.forEach(defineStartEndAsError.bind(null, "token"));
        ast.comments.forEach(defineStartEndAsError.bind(null, "token"));
    }
    /**
     * Wraps the given parser in order to intercept and modify return values from the `parse` and `parseForESLint` methods, for test purposes.
     * In particular, to modify ast nodes, tokens and comments to throw on access to their `start` and `end` properties.
     * @param {Parser} parser Parser object.
     * @returns {Parser} Wrapped parser object.
     */
    function wrapParser(parser) {
        if (typeof parser.parseForESLint === "function") {
            return {
                [parserSymbol]: parser,
                parseForESLint(...args) {
                    const ret = parser.parseForESLint(...args);
                    defineStartEndAsErrorInTree(ret.ast, ret.visitorKeys);
                    return ret;
                }
            };
        }
        return {
            [parserSymbol]: parser,
            parse(...args) {
                const ast = parser.parse(...args);
                defineStartEndAsErrorInTree(ast);
                return ast;
            }
        };
    }
    /**
     * Function to replace `SourceCode.prototype.getComments`.
     * @returns {void}
     * @throws {Error} Deprecation message.
     */
    function getCommentsDeprecation() {
        throw new Error("`SourceCode#getComments()` is deprecated and will be removed in a future major version. Use `getCommentsBefore()`, `getCommentsAfter()`, and `getCommentsInside()` instead.");
    }
    /**
     * Emit a deprecation warning if function-style format is being used.
     * @param {string} ruleName Name of the rule.
     * @returns {void}
     */
    function emitLegacyRuleAPIWarning(ruleName) {
        if (!emitLegacyRuleAPIWarning[`warned-${ruleName}`]) {
            emitLegacyRuleAPIWarning[`warned-${ruleName}`] = true;
            process.emitWarning(`"${ruleName}" rule is using the deprecated function-style format and will stop working in ESLint v9. Please use object-style format: https://eslint.org/docs/latest/extend/custom-rules`, "DeprecationWarning");
        }
    }
    /**
     * Emit a deprecation warning if rule has options but is missing the "meta.schema" property
     * @param {string} ruleName Name of the rule.
     * @returns {void}
     */
    function emitMissingSchemaWarning(ruleName) {
        if (!emitMissingSchemaWarning[`warned-${ruleName}`]) {
            emitMissingSchemaWarning[`warned-${ruleName}`] = true;
            process.emitWarning(`"${ruleName}" rule has options but is missing the "meta.schema" property and will stop working in ESLint v9. Please add a schema: https://eslint.org/docs/latest/extend/custom-rules#options-schemas`, "DeprecationWarning");
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    // default separators for testing
    const DESCRIBE = Symbol("describe");
    const IT = Symbol("it");
    const IT_ONLY = Symbol("itOnly");
    /**
     * This is `it` default handler if `it` don't exist.
     * @this {Mocha}
     * @param {string} text The description of the test case.
     * @param {Function} method The logic of the test case.
     * @throws {Error} Any error upon execution of `method`.
     * @returns {any} Returned value of `method`.
     */
    function itDefaultHandler(text, method) {
        try {
            return method.call(this);
        }
        catch (err) {
            if (err instanceof assert.AssertionError) {
                err.message += ` (${util.inspect(err.actual)} ${err.operator} ${util.inspect(err.expected)})`;
            }
            throw err;
        }
    }
    /**
     * This is `describe` default handler if `describe` don't exist.
     * @this {Mocha}
     * @param {string} text The description of the test case.
     * @param {Function} method The logic of the test case.
     * @returns {any} Returned value of `method`.
     */
    function describeDefaultHandler(text, method) {
        return method.call(this);
    }
    /**
     * Mocha test wrapper.
     */
    class RuleTester {
        /**
         * Creates a new instance of RuleTester.
         * @param {Object} [testerConfig] Optional, extra configuration for the tester
         */
        constructor(testerConfig) {
            /**
             * The configuration to use for this tester. Combination of the tester
             * configuration and the default configuration.
             * @type {Object}
             */
            this.testerConfig = merge({}, defaultConfig, testerConfig, { rules: { "rule-tester/validate-ast": "error" } });
            /**
             * Rule definitions to define before tests.
             * @type {Object}
             */
            this.rules = {};
            this.linter = new Linter();
        }
        /**
         * Set the configuration to use for all future tests
         * @param {Object} config the configuration to use.
         * @throws {TypeError} If non-object config.
         * @returns {void}
         */
        static setDefaultConfig(config) {
            if (typeof config !== "object") {
                throw new TypeError("RuleTester.setDefaultConfig: config must be an object");
            }
            defaultConfig = config;
            // Make sure the rules object exists since it is assumed to exist later
            defaultConfig.rules = defaultConfig.rules || {};
        }
        /**
         * Get the current configuration used for all tests
         * @returns {Object} the current configuration
         */
        static getDefaultConfig() {
            return defaultConfig;
        }
        /**
         * Reset the configuration to the initial configuration of the tester removing
         * any changes made until now.
         * @returns {void}
         */
        static resetDefaultConfig() {
            defaultConfig = merge({}, testerDefaultConfig);
        }
        /*
         * If people use `mocha test.js --watch` command, `describe` and `it` function
         * instances are different for each execution. So `describe` and `it` should get fresh instance
         * always.
         */
        static get describe() {
            return (this[DESCRIBE] ||
                (typeof describe === "function" ? describe : describeDefaultHandler));
        }
        static set describe(value) {
            this[DESCRIBE] = value;
        }
        static get it() {
            return (this[IT] ||
                (typeof it === "function" ? it : itDefaultHandler));
        }
        static set it(value) {
            this[IT] = value;
        }
        /**
         * Adds the `only` property to a test to run it in isolation.
         * @param {string | ValidTestCase | InvalidTestCase} item A single test to run by itself.
         * @returns {ValidTestCase | InvalidTestCase} The test with `only` set.
         */
        static only(item) {
            if (typeof item === "string") {
                return { code: item, only: true };
            }
            return { ...item, only: true };
        }
        static get itOnly() {
            if (typeof this[IT_ONLY] === "function") {
                return this[IT_ONLY];
            }
            if (typeof this[IT] === "function" && typeof this[IT].only === "function") {
                return Function.bind.call(this[IT].only, this[IT]);
            }
            if (typeof it === "function" && typeof it.only === "function") {
                return Function.bind.call(it.only, it);
            }
            if (typeof this[DESCRIBE] === "function" || typeof this[IT] === "function") {
                throw new Error("Set `RuleTester.itOnly` to use `only` with a custom test framework.\n" +
                    "See https://eslint.org/docs/latest/integrate/nodejs-api#customizing-ruletester for more.");
            }
            if (typeof it === "function") {
                throw new Error("The current test framework does not support exclusive tests with `only`.");
            }
            throw new Error("To use `only`, use RuleTester with a test framework that provides `it.only()` like Mocha.");
        }
        static set itOnly(value) {
            this[IT_ONLY] = value;
        }
        /**
         * Define a rule for one particular run of tests.
         * @param {string} name The name of the rule to define.
         * @param {Function} rule The rule definition.
         * @returns {void}
         */
        defineRule(name, rule) {
            this.rules[name] = rule;
        }
        /**
         * Adds a new rule test to execute.
         * @param {string} ruleName The name of the rule to run.
         * @param {Function} rule The rule to test.
         * @param {{
         *   valid: (ValidTestCase | string)[],
         *   invalid: InvalidTestCase[]
         * }} test The collection of tests to run.
         * @throws {TypeError|Error} If non-object `test`, or if a required
         * scenario of the given type is missing.
         * @returns {void}
         */
        run(ruleName, rule, test) {
            const testerConfig = this.testerConfig, requiredScenarios = ["valid", "invalid"], scenarioErrors = [], linter = this.linter;
            if (!test || typeof test !== "object") {
                throw new TypeError(`Test Scenarios for rule ${ruleName} : Could not find test scenario object`);
            }
            requiredScenarios.forEach(scenarioType => {
                if (!test[scenarioType]) {
                    scenarioErrors.push(`Could not find any ${scenarioType} test scenarios`);
                }
            });
            if (scenarioErrors.length > 0) {
                throw new Error([
                    `Test Scenarios for rule ${ruleName} is invalid:`
                ].concat(scenarioErrors).join("\n"));
            }
            if (typeof rule === "function") {
                emitLegacyRuleAPIWarning(ruleName);
            }
            linter.defineRule(ruleName, Object.assign({}, rule, {
                // Create a wrapper rule that freezes the `context` properties.
                create(context) {
                    freezeDeeply(context.options);
                    freezeDeeply(context.settings);
                    freezeDeeply(context.parserOptions);
                    return (typeof rule === "function" ? rule : rule.create)(context);
                }
            }));
            linter.defineRules(this.rules);
            /**
             * Run the rule for the given item
             * @param {string|Object} item Item to run the rule against
             * @throws {Error} If an invalid schema.
             * @returns {Object} Eslint run result
             * @private
             */
            function runRuleForItem(item) {
                let config = merge({}, testerConfig), code, filename, output, beforeAST, afterAST;
                if (typeof item === "string") {
                    code = item;
                }
                else {
                    code = item.code;
                    /*
                     * Assumes everything on the item is a config except for the
                     * parameters used by this tester
                     */
                    const itemConfig = { ...item };
                    for (const parameter of RuleTesterParameters) {
                        delete itemConfig[parameter];
                    }
                    /*
                     * Create the config object from the tester config and this item
                     * specific configurations.
                     */
                    config = merge(config, itemConfig);
                }
                if (item.filename) {
                    filename = item.filename;
                }
                if (hasOwnProperty(item, "options")) {
                    assert(Array.isArray(item.options), "options must be an array");
                    if (item.options.length > 0 &&
                        typeof rule === "object" &&
                        (!rule.meta || (rule.meta && (typeof rule.meta.schema === "undefined" || rule.meta.schema === null)))) {
                        emitMissingSchemaWarning(ruleName);
                    }
                    config.rules[ruleName] = [1].concat(item.options);
                }
                else {
                    config.rules[ruleName] = 1;
                }
                const schema = getRuleOptionsSchema(rule);
                /*
                 * Setup AST getters.
                 * The goal is to check whether or not AST was modified when
                 * running the rule under test.
                 */
                linter.defineRule("rule-tester/validate-ast", {
                    create() {
                        return {
                            Program(node) {
                                beforeAST = cloneDeeplyExcludesParent(node);
                            },
                            "Program:exit"(node) {
                                afterAST = node;
                            }
                        };
                    }
                });
                if (typeof config.parser === "string") {
                    assert(path.isAbsolute(config.parser), "Parsers provided as strings to RuleTester must be absolute paths");
                }
                else {
                    config.parser = espreePath;
                }
                linter.defineParser(config.parser, wrapParser(require(config.parser)));
                if (schema) {
                    ajv.validateSchema(schema);
                    if (ajv.errors) {
                        const errors = ajv.errors.map(error => {
                            const field = error.dataPath[0] === "." ? error.dataPath.slice(1) : error.dataPath;
                            return `\t${field}: ${error.message}`;
                        }).join("\n");
                        throw new Error([`Schema for rule ${ruleName} is invalid:`, errors]);
                    }
                    /*
                     * `ajv.validateSchema` checks for errors in the structure of the schema (by comparing the schema against a "meta-schema"),
                     * and it reports those errors individually. However, there are other types of schema errors that only occur when compiling
                     * the schema (e.g. using invalid defaults in a schema), and only one of these errors can be reported at a time. As a result,
                     * the schema is compiled here separately from checking for `validateSchema` errors.
                     */
                    try {
                        ajv.compile(schema);
                    }
                    catch (err) {
                        throw new Error(`Schema for rule ${ruleName} is invalid: ${err.message}`);
                    }
                }
                validate(config, "rule-tester", id => (id === ruleName ? rule : null));
                // Verify the code.
                const { getComments } = SourceCode.prototype;
                let messages;
                try {
                    SourceCode.prototype.getComments = getCommentsDeprecation;
                    messages = linter.verify(code, config, filename);
                }
                finally {
                    SourceCode.prototype.getComments = getComments;
                }
                const fatalErrorMessage = messages.find(m => m.fatal);
                assert(!fatalErrorMessage, `A fatal parsing error occurred: ${fatalErrorMessage && fatalErrorMessage.message}`);
                // Verify if autofix makes a syntax error or not.
                if (messages.some(m => m.fix)) {
                    output = SourceCodeFixer.applyFixes(code, messages).output;
                    const errorMessageInFix = linter.verify(output, config, filename).find(m => m.fatal);
                    assert(!errorMessageInFix, [
                        "A fatal parsing error occurred in autofix.",
                        `Error: ${errorMessageInFix && errorMessageInFix.message}`,
                        "Autofix output:",
                        output
                    ].join("\n"));
                }
                else {
                    output = code;
                }
                return {
                    messages,
                    output,
                    beforeAST,
                    afterAST: cloneDeeplyExcludesParent(afterAST)
                };
            }
            /**
             * Check if the AST was changed
             * @param {ASTNode} beforeAST AST node before running
             * @param {ASTNode} afterAST AST node after running
             * @returns {void}
             * @private
             */
            function assertASTDidntChange(beforeAST, afterAST) {
                if (!equal(beforeAST, afterAST)) {
                    assert.fail("Rule should not modify AST.");
                }
            }
            /**
             * Check if the template is valid or not
             * all valid cases go through this
             * @param {string|Object} item Item to run the rule against
             * @returns {void}
             * @private
             */
            function testValidTemplate(item) {
                const code = typeof item === "object" ? item.code : item;
                assert.ok(typeof code === "string", "Test case must specify a string value for 'code'");
                if (item.name) {
                    assert.ok(typeof item.name === "string", "Optional test case property 'name' must be a string");
                }
                const result = runRuleForItem(item);
                const messages = result.messages;
                assert.strictEqual(messages.length, 0, util.format("Should have no errors but had %d: %s", messages.length, util.inspect(messages)));
                assertASTDidntChange(result.beforeAST, result.afterAST);
            }
            /**
             * Asserts that the message matches its expected value. If the expected
             * value is a regular expression, it is checked against the actual
             * value.
             * @param {string} actual Actual value
             * @param {string|RegExp} expected Expected value
             * @returns {void}
             * @private
             */
            function assertMessageMatches(actual, expected) {
                if (expected instanceof RegExp) {
                    // assert.js doesn't have a built-in RegExp match function
                    assert.ok(expected.test(actual), `Expected '${actual}' to match ${expected}`);
                }
                else {
                    assert.strictEqual(actual, expected);
                }
            }
            /**
             * Check if the template is invalid or not
             * all invalid cases go through this.
             * @param {string|Object} item Item to run the rule against
             * @returns {void}
             * @private
             */
            function testInvalidTemplate(item) {
                assert.ok(typeof item.code === "string", "Test case must specify a string value for 'code'");
                if (item.name) {
                    assert.ok(typeof item.name === "string", "Optional test case property 'name' must be a string");
                }
                assert.ok(item.errors || item.errors === 0, `Did not specify errors for an invalid test of ${ruleName}`);
                if (Array.isArray(item.errors) && item.errors.length === 0) {
                    assert.fail("Invalid cases must have at least one error");
                }
                const ruleHasMetaMessages = hasOwnProperty(rule, "meta") && hasOwnProperty(rule.meta, "messages");
                const friendlyIDList = ruleHasMetaMessages ? `[${Object.keys(rule.meta.messages).map(key => `'${key}'`).join(", ")}]` : null;
                const result = runRuleForItem(item);
                const messages = result.messages;
                if (typeof item.errors === "number") {
                    if (item.errors === 0) {
                        assert.fail("Invalid cases must have 'error' value greater than 0");
                    }
                    assert.strictEqual(messages.length, item.errors, util.format("Should have %d error%s but had %d: %s", item.errors, item.errors === 1 ? "" : "s", messages.length, util.inspect(messages)));
                }
                else {
                    assert.strictEqual(messages.length, item.errors.length, util.format("Should have %d error%s but had %d: %s", item.errors.length, item.errors.length === 1 ? "" : "s", messages.length, util.inspect(messages)));
                    const hasMessageOfThisRule = messages.some(m => m.ruleId === ruleName);
                    for (let i = 0, l = item.errors.length; i < l; i++) {
                        const error = item.errors[i];
                        const message = messages[i];
                        assert(hasMessageOfThisRule, "Error rule name should be the same as the name of the rule being tested");
                        if (typeof error === "string" || error instanceof RegExp) {
                            // Just an error message.
                            assertMessageMatches(message.message, error);
                        }
                        else if (typeof error === "object" && error !== null) {
                            /*
                             * Error object.
                             * This may have a message, messageId, data, node type, line, and/or
                             * column.
                             */
                            Object.keys(error).forEach(propertyName => {
                                assert.ok(errorObjectParameters.has(propertyName), `Invalid error property name '${propertyName}'. Expected one of ${friendlyErrorObjectParameterList}.`);
                            });
                            if (hasOwnProperty(error, "message")) {
                                assert.ok(!hasOwnProperty(error, "messageId"), "Error should not specify both 'message' and a 'messageId'.");
                                assert.ok(!hasOwnProperty(error, "data"), "Error should not specify both 'data' and 'message'.");
                                assertMessageMatches(message.message, error.message);
                            }
                            else if (hasOwnProperty(error, "messageId")) {
                                assert.ok(ruleHasMetaMessages, "Error can not use 'messageId' if rule under test doesn't define 'meta.messages'.");
                                if (!hasOwnProperty(rule.meta.messages, error.messageId)) {
                                    assert(false, `Invalid messageId '${error.messageId}'. Expected one of ${friendlyIDList}.`);
                                }
                                assert.strictEqual(message.messageId, error.messageId, `messageId '${message.messageId}' does not match expected messageId '${error.messageId}'.`);
                                if (hasOwnProperty(error, "data")) {
                                    /*
                                     *  if data was provided, then directly compare the returned message to a synthetic
                                     *  interpolated message using the same message ID and data provided in the test.
                                     *  See https://github.com/eslint/eslint/issues/9890 for context.
                                     */
                                    const unformattedOriginalMessage = rule.meta.messages[error.messageId];
                                    const rehydratedMessage = interpolate(unformattedOriginalMessage, error.data);
                                    assert.strictEqual(message.message, rehydratedMessage, `Hydrated message "${rehydratedMessage}" does not match "${message.message}"`);
                                }
                            }
                            assert.ok(hasOwnProperty(error, "data") ? hasOwnProperty(error, "messageId") : true, "Error must specify 'messageId' if 'data' is used.");
                            if (error.type) {
                                assert.strictEqual(message.nodeType, error.type, `Error type should be ${error.type}, found ${message.nodeType}`);
                            }
                            if (hasOwnProperty(error, "line")) {
                                assert.strictEqual(message.line, error.line, `Error line should be ${error.line}`);
                            }
                            if (hasOwnProperty(error, "column")) {
                                assert.strictEqual(message.column, error.column, `Error column should be ${error.column}`);
                            }
                            if (hasOwnProperty(error, "endLine")) {
                                assert.strictEqual(message.endLine, error.endLine, `Error endLine should be ${error.endLine}`);
                            }
                            if (hasOwnProperty(error, "endColumn")) {
                                assert.strictEqual(message.endColumn, error.endColumn, `Error endColumn should be ${error.endColumn}`);
                            }
                            if (hasOwnProperty(error, "suggestions")) {
                                // Support asserting there are no suggestions
                                if (!error.suggestions || (Array.isArray(error.suggestions) && error.suggestions.length === 0)) {
                                    if (Array.isArray(message.suggestions) && message.suggestions.length > 0) {
                                        assert.fail(`Error should have no suggestions on error with message: "${message.message}"`);
                                    }
                                }
                                else {
                                    assert.strictEqual(Array.isArray(message.suggestions), true, `Error should have an array of suggestions. Instead received "${message.suggestions}" on error with message: "${message.message}"`);
                                    assert.strictEqual(message.suggestions.length, error.suggestions.length, `Error should have ${error.suggestions.length} suggestions. Instead found ${message.suggestions.length} suggestions`);
                                    error.suggestions.forEach((expectedSuggestion, index) => {
                                        assert.ok(typeof expectedSuggestion === "object" && expectedSuggestion !== null, "Test suggestion in 'suggestions' array must be an object.");
                                        Object.keys(expectedSuggestion).forEach(propertyName => {
                                            assert.ok(suggestionObjectParameters.has(propertyName), `Invalid suggestion property name '${propertyName}'. Expected one of ${friendlySuggestionObjectParameterList}.`);
                                        });
                                        const actualSuggestion = message.suggestions[index];
                                        const suggestionPrefix = `Error Suggestion at index ${index} :`;
                                        if (hasOwnProperty(expectedSuggestion, "desc")) {
                                            assert.ok(!hasOwnProperty(expectedSuggestion, "data"), `${suggestionPrefix} Test should not specify both 'desc' and 'data'.`);
                                            assert.strictEqual(actualSuggestion.desc, expectedSuggestion.desc, `${suggestionPrefix} desc should be "${expectedSuggestion.desc}" but got "${actualSuggestion.desc}" instead.`);
                                        }
                                        if (hasOwnProperty(expectedSuggestion, "messageId")) {
                                            assert.ok(ruleHasMetaMessages, `${suggestionPrefix} Test can not use 'messageId' if rule under test doesn't define 'meta.messages'.`);
                                            assert.ok(hasOwnProperty(rule.meta.messages, expectedSuggestion.messageId), `${suggestionPrefix} Test has invalid messageId '${expectedSuggestion.messageId}', the rule under test allows only one of ${friendlyIDList}.`);
                                            assert.strictEqual(actualSuggestion.messageId, expectedSuggestion.messageId, `${suggestionPrefix} messageId should be '${expectedSuggestion.messageId}' but got '${actualSuggestion.messageId}' instead.`);
                                            if (hasOwnProperty(expectedSuggestion, "data")) {
                                                const unformattedMetaMessage = rule.meta.messages[expectedSuggestion.messageId];
                                                const rehydratedDesc = interpolate(unformattedMetaMessage, expectedSuggestion.data);
                                                assert.strictEqual(actualSuggestion.desc, rehydratedDesc, `${suggestionPrefix} Hydrated test desc "${rehydratedDesc}" does not match received desc "${actualSuggestion.desc}".`);
                                            }
                                        }
                                        else {
                                            assert.ok(!hasOwnProperty(expectedSuggestion, "data"), `${suggestionPrefix} Test must specify 'messageId' if 'data' is used.`);
                                        }
                                        if (hasOwnProperty(expectedSuggestion, "output")) {
                                            const codeWithAppliedSuggestion = SourceCodeFixer.applyFixes(item.code, [actualSuggestion]).output;
                                            assert.strictEqual(codeWithAppliedSuggestion, expectedSuggestion.output, `Expected the applied suggestion fix to match the test suggestion output for suggestion at index: ${index} on error with message: "${message.message}"`);
                                        }
                                    });
                                }
                            }
                        }
                        else {
                            // Message was an unexpected type
                            assert.fail(`Error should be a string, object, or RegExp, but found (${util.inspect(message)})`);
                        }
                    }
                }
                if (hasOwnProperty(item, "output")) {
                    if (item.output === null) {
                        assert.strictEqual(result.output, item.code, "Expected no autofixes to be suggested");
                    }
                    else {
                        assert.strictEqual(result.output, item.output, "Output is incorrect.");
                    }
                }
                else {
                    assert.strictEqual(result.output, item.code, "The rule fixed the code. Please add 'output' property.");
                }
                assertASTDidntChange(result.beforeAST, result.afterAST);
            }
            /*
             * This creates a mocha test suite and pipes all supplied info through
             * one of the templates above.
             */
            this.constructor.describe(ruleName, () => {
                this.constructor.describe("valid", () => {
                    test.valid.forEach(valid => {
                        this.constructor[valid.only ? "itOnly" : "it"](sanitize(typeof valid === "object" ? valid.name || valid.code : valid), () => {
                            testValidTemplate(valid);
                        });
                    });
                });
                this.constructor.describe("invalid", () => {
                    test.invalid.forEach(invalid => {
                        this.constructor[invalid.only ? "itOnly" : "it"](sanitize(invalid.name || invalid.code), () => {
                            testInvalidTemplate(invalid);
                        });
                    });
                });
            });
        }
    }
    RuleTester[DESCRIBE] = RuleTester[IT] = RuleTester[IT_ONLY] = null;
    module.exports = RuleTester;
},
/* eslint/lib/shared/config-validator.js */ function _(require, module, exports, __esModule, __esExport) {/*
     * STOP!!! DO NOT MODIFY.
     *
     * This file is part of the ongoing work to move the eslintrc-style config
     * system into the @eslint/eslintrc package. This file needs to remain
     * unchanged in order for this work to proceed.
     *
     * If you think you need to change this file, please contact @nzakas first.
     *
     * Thanks in advance for your cooperation.
     */
    /**
     * @fileoverview Validates configs.
     * @author Brandon Mills
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const util = require("util"), configSchema = require(766) /* ../../conf/config-schema */, BuiltInRules = require(357) /* ../rules */, { Legacy: { ConfigOps, environments: BuiltInEnvironments } } = require(222) /* @eslint/eslintrc */, { emitDeprecationWarning } = require(767) /* ./deprecation-warnings */;
    const ajv = require(703) /* ./ajv */();
    const ruleValidators = new WeakMap();
    const noop = Function.prototype;
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    let validateSchema;
    const severityMap = {
        error: 2,
        warn: 1,
        off: 0
    };
    /**
     * Gets a complete options schema for a rule.
     * @param {{create: Function, schema: (Array|null)}} rule A new-style rule object
     * @returns {Object} JSON Schema for the rule's options.
     */
    function getRuleOptionsSchema(rule) {
        if (!rule) {
            return null;
        }
        const schema = rule.schema || rule.meta && rule.meta.schema;
        // Given a tuple of schemas, insert warning level at the beginning
        if (Array.isArray(schema)) {
            if (schema.length) {
                return {
                    type: "array",
                    items: schema,
                    minItems: 0,
                    maxItems: schema.length
                };
            }
            return {
                type: "array",
                minItems: 0,
                maxItems: 0
            };
        }
        // Given a full schema, leave it alone
        return schema || null;
    }
    /**
     * Validates a rule's severity and returns the severity value. Throws an error if the severity is invalid.
     * @param {options} options The given options for the rule.
     * @throws {Error} Wrong severity value.
     * @returns {number|string} The rule's severity value
     */
    function validateRuleSeverity(options) {
        const severity = Array.isArray(options) ? options[0] : options;
        const normSeverity = typeof severity === "string" ? severityMap[severity.toLowerCase()] : severity;
        if (normSeverity === 0 || normSeverity === 1 || normSeverity === 2) {
            return normSeverity;
        }
        throw new Error(`\tSeverity should be one of the following: 0 = off, 1 = warn, 2 = error (you passed '${util.inspect(severity).replace(/'/gu, "\"").replace(/\n/gu, "")}').\n`);
    }
    /**
     * Validates the non-severity options passed to a rule, based on its schema.
     * @param {{create: Function}} rule The rule to validate
     * @param {Array} localOptions The options for the rule, excluding severity
     * @throws {Error} Any rule validation errors.
     * @returns {void}
     */
    function validateRuleSchema(rule, localOptions) {
        if (!ruleValidators.has(rule)) {
            const schema = getRuleOptionsSchema(rule);
            if (schema) {
                ruleValidators.set(rule, ajv.compile(schema));
            }
        }
        const validateRule = ruleValidators.get(rule);
        if (validateRule) {
            validateRule(localOptions);
            if (validateRule.errors) {
                throw new Error(validateRule.errors.map(error => `\tValue ${JSON.stringify(error.data)} ${error.message}.\n`).join(""));
            }
        }
    }
    /**
     * Validates a rule's options against its schema.
     * @param {{create: Function}|null} rule The rule that the config is being validated for
     * @param {string} ruleId The rule's unique name.
     * @param {Array|number} options The given options for the rule.
     * @param {string|null} source The name of the configuration source to report in any errors. If null or undefined,
     * no source is prepended to the message.
     * @throws {Error} Upon any bad rule configuration.
     * @returns {void}
     */
    function validateRuleOptions(rule, ruleId, options, source = null) {
        try {
            const severity = validateRuleSeverity(options);
            if (severity !== 0) {
                validateRuleSchema(rule, Array.isArray(options) ? options.slice(1) : []);
            }
        }
        catch (err) {
            const enhancedMessage = `Configuration for rule "${ruleId}" is invalid:\n${err.message}`;
            if (typeof source === "string") {
                throw new Error(`${source}:\n\t${enhancedMessage}`);
            }
            else {
                throw new Error(enhancedMessage);
            }
        }
    }
    /**
     * Validates an environment object
     * @param {Object} environment The environment config object to validate.
     * @param {string} source The name of the configuration source to report in any errors.
     * @param {(envId:string) => Object} [getAdditionalEnv] A map from strings to loaded environments.
     * @returns {void}
     */
    function validateEnvironment(environment, source, getAdditionalEnv = noop) {
        // not having an environment is ok
        if (!environment) {
            return;
        }
        Object.keys(environment).forEach(id => {
            const env = getAdditionalEnv(id) || BuiltInEnvironments.get(id) || null;
            if (!env) {
                const message = `${source}:\n\tEnvironment key "${id}" is unknown\n`;
                throw new Error(message);
            }
        });
    }
    /**
     * Validates a rules config object
     * @param {Object} rulesConfig The rules config object to validate.
     * @param {string} source The name of the configuration source to report in any errors.
     * @param {(ruleId:string) => Object} getAdditionalRule A map from strings to loaded rules
     * @returns {void}
     */
    function validateRules(rulesConfig, source, getAdditionalRule = noop) {
        if (!rulesConfig) {
            return;
        }
        Object.keys(rulesConfig).forEach(id => {
            const rule = getAdditionalRule(id) || BuiltInRules.get(id) || null;
            validateRuleOptions(rule, id, rulesConfig[id], source);
        });
    }
    /**
     * Validates a `globals` section of a config file
     * @param {Object} globalsConfig The `globals` section
     * @param {string|null} source The name of the configuration source to report in the event of an error.
     * @returns {void}
     */
    function validateGlobals(globalsConfig, source = null) {
        if (!globalsConfig) {
            return;
        }
        Object.entries(globalsConfig)
            .forEach(([configuredGlobal, configuredValue]) => {
            try {
                ConfigOps.normalizeConfigGlobal(configuredValue);
            }
            catch (err) {
                throw new Error(`ESLint configuration of global '${configuredGlobal}' in ${source} is invalid:\n${err.message}`);
            }
        });
    }
    /**
     * Validate `processor` configuration.
     * @param {string|undefined} processorName The processor name.
     * @param {string} source The name of config file.
     * @param {(id:string) => Processor} getProcessor The getter of defined processors.
     * @throws {Error} For invalid processor configuration.
     * @returns {void}
     */
    function validateProcessor(processorName, source, getProcessor) {
        if (processorName && !getProcessor(processorName)) {
            throw new Error(`ESLint configuration of processor in '${source}' is invalid: '${processorName}' was not found.`);
        }
    }
    /**
     * Formats an array of schema validation errors.
     * @param {Array} errors An array of error messages to format.
     * @returns {string} Formatted error message
     */
    function formatErrors(errors) {
        return errors.map(error => {
            if (error.keyword === "additionalProperties") {
                const formattedPropertyPath = error.dataPath.length ? `${error.dataPath.slice(1)}.${error.params.additionalProperty}` : error.params.additionalProperty;
                return `Unexpected top-level property "${formattedPropertyPath}"`;
            }
            if (error.keyword === "type") {
                const formattedField = error.dataPath.slice(1);
                const formattedExpectedType = Array.isArray(error.schema) ? error.schema.join("/") : error.schema;
                const formattedValue = JSON.stringify(error.data);
                return `Property "${formattedField}" is the wrong type (expected ${formattedExpectedType} but got \`${formattedValue}\`)`;
            }
            const field = error.dataPath[0] === "." ? error.dataPath.slice(1) : error.dataPath;
            return `"${field}" ${error.message}. Value: ${JSON.stringify(error.data)}`;
        }).map(message => `\t- ${message}.\n`).join("");
    }
    /**
     * Validates the top level properties of the config object.
     * @param {Object} config The config object to validate.
     * @param {string} source The name of the configuration source to report in any errors.
     * @throws {Error} For any config invalid per the schema.
     * @returns {void}
     */
    function validateConfigSchema(config, source = null) {
        validateSchema = validateSchema || ajv.compile(configSchema);
        if (!validateSchema(config)) {
            throw new Error(`ESLint configuration in ${source} is invalid:\n${formatErrors(validateSchema.errors)}`);
        }
        if (Object.hasOwnProperty.call(config, "ecmaFeatures")) {
            emitDeprecationWarning(source, "ESLINT_LEGACY_ECMAFEATURES");
        }
    }
    /**
     * Validates an entire config object.
     * @param {Object} config The config object to validate.
     * @param {string} source The name of the configuration source to report in any errors.
     * @param {(ruleId:string) => Object} [getAdditionalRule] A map from strings to loaded rules.
     * @param {(envId:string) => Object} [getAdditionalEnv] A map from strings to loaded envs.
     * @returns {void}
     */
    function validate(config, source, getAdditionalRule, getAdditionalEnv) {
        validateConfigSchema(config, source);
        validateRules(config.rules, source, getAdditionalRule);
        validateEnvironment(config.env, source, getAdditionalEnv);
        validateGlobals(config.globals, source);
        for (const override of config.overrides || []) {
            validateRules(override.rules, source, getAdditionalRule);
            validateEnvironment(override.env, source, getAdditionalEnv);
            validateGlobals(config.globals, source);
        }
    }
    const validated = new WeakSet();
    /**
     * Validate config array object.
     * @param {ConfigArray} configArray The config array to validate.
     * @returns {void}
     */
    function validateConfigArray(configArray) {
        const getPluginEnv = Map.prototype.get.bind(configArray.pluginEnvironments);
        const getPluginProcessor = Map.prototype.get.bind(configArray.pluginProcessors);
        const getPluginRule = Map.prototype.get.bind(configArray.pluginRules);
        // Validate.
        for (const element of configArray) {
            if (validated.has(element)) {
                continue;
            }
            validated.add(element);
            validateEnvironment(element.env, element.name, getPluginEnv);
            validateGlobals(element.globals, element.name);
            validateProcessor(element.processor, element.name, getPluginProcessor);
            validateRules(element.rules, element.name, getPluginRule);
        }
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = {
        getRuleOptionsSchema,
        validate,
        validateConfigArray,
        validateConfigSchema,
        validateRuleOptions
    };
},
/* eslint/conf/config-schema.js */ function _(require, module, exports, __esModule, __esExport) {/*
     * STOP!!! DO NOT MODIFY.
     *
     * This file is part of the ongoing work to move the eslintrc-style config
     * system into the @eslint/eslintrc package. This file needs to remain
     * unchanged in order for this work to proceed.
     *
     * If you think you need to change this file, please contact @nzakas first.
     *
     * Thanks in advance for your cooperation.
     */
    /**
     * @fileoverview Defines a schema for configs.
     * @author Sylvan Mably
     */
    "use strict";
    const baseConfigProperties = {
        $schema: { type: "string" },
        env: { type: "object" },
        extends: { $ref: "#/definitions/stringOrStrings" },
        globals: { type: "object" },
        overrides: {
            type: "array",
            items: { $ref: "#/definitions/overrideConfig" },
            additionalItems: false
        },
        parser: { type: ["string", "null"] },
        parserOptions: { type: "object" },
        plugins: { type: "array" },
        processor: { type: "string" },
        rules: { type: "object" },
        settings: { type: "object" },
        noInlineConfig: { type: "boolean" },
        reportUnusedDisableDirectives: { type: "boolean" },
        ecmaFeatures: { type: "object" } // deprecated; logs a warning when used
    };
    const configSchema = {
        definitions: {
            stringOrStrings: {
                oneOf: [
                    { type: "string" },
                    {
                        type: "array",
                        items: { type: "string" },
                        additionalItems: false
                    }
                ]
            },
            stringOrStringsRequired: {
                oneOf: [
                    { type: "string" },
                    {
                        type: "array",
                        items: { type: "string" },
                        additionalItems: false,
                        minItems: 1
                    }
                ]
            },
            // Config at top-level.
            objectConfig: {
                type: "object",
                properties: {
                    root: { type: "boolean" },
                    ignorePatterns: { $ref: "#/definitions/stringOrStrings" },
                    ...baseConfigProperties
                },
                additionalProperties: false
            },
            // Config in `overrides`.
            overrideConfig: {
                type: "object",
                properties: {
                    excludedFiles: { $ref: "#/definitions/stringOrStrings" },
                    files: { $ref: "#/definitions/stringOrStringsRequired" },
                    ...baseConfigProperties
                },
                required: ["files"],
                additionalProperties: false
            }
        },
        $ref: "#/definitions/objectConfig"
    };
    module.exports = configSchema;
},
/* eslint/lib/shared/deprecation-warnings.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Provide the function that emits deprecation warnings.
     * @author Toru Nagashima <http://github.com/mysticatea>
     */
    "use strict";
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const path = require("path");
    //------------------------------------------------------------------------------
    // Private
    //------------------------------------------------------------------------------
    // Definitions for deprecation warnings.
    const deprecationWarningMessages = {
        ESLINT_LEGACY_ECMAFEATURES: "The 'ecmaFeatures' config file property is deprecated and has no effect."
    };
    const sourceFileErrorCache = new Set();
    /**
     * Emits a deprecation warning containing a given filepath. A new deprecation warning is emitted
     * for each unique file path, but repeated invocations with the same file path have no effect.
     * No warnings are emitted if the `--no-deprecation` or `--no-warnings` Node runtime flags are active.
     * @param {string} source The name of the configuration source to report the warning for.
     * @param {string} errorCode The warning message to show.
     * @returns {void}
     */
    function emitDeprecationWarning(source, errorCode) {
        const cacheKey = JSON.stringify({ source, errorCode });
        if (sourceFileErrorCache.has(cacheKey)) {
            return;
        }
        sourceFileErrorCache.add(cacheKey);
        const rel = path.relative(process.cwd(), source);
        const message = deprecationWarningMessages[errorCode];
        process.emitWarning(`${message} (found in "${rel}")`, "DeprecationWarning", errorCode);
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    module.exports = {
        emitDeprecationWarning
    };
},
/* @typescript-eslint/eslint-plugin/dist/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    const all_1 = __importDefault(require(769) /* ./configs/all */);
    const base_1 = __importDefault(require(770) /* ./configs/base */);
    const eslint_recommended_1 = __importDefault(require(771) /* ./configs/eslint-recommended */);
    const recommended_1 = __importDefault(require(772) /* ./configs/recommended */);
    const recommended_requiring_type_checking_1 = __importDefault(require(773) /* ./configs/recommended-requiring-type-checking */);
    const strict_1 = __importDefault(require(774) /* ./configs/strict */);
    const rules_1 = __importDefault(require(775) /* ./rules */);
    module.exports = {
        rules: rules_1.default,
        configs: {
            all: all_1.default,
            base: base_1.default,
            recommended: recommended_1.default,
            'eslint-recommended': eslint_recommended_1.default,
            'recommended-requiring-type-checking': recommended_requiring_type_checking_1.default,
            strict: strict_1.default,
        },
    };
    
},
/* @typescript-eslint/eslint-plugin/dist/configs/all.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // YOU CAN REGENERATE IT USING yarn generate:configs
    module.exports = {
        extends: ['./configs/base', './configs/eslint-recommended'],
        rules: {
            '@typescript-eslint/adjacent-overload-signatures': 'error',
            '@typescript-eslint/array-type': 'error',
            '@typescript-eslint/await-thenable': 'error',
            '@typescript-eslint/ban-ts-comment': 'error',
            '@typescript-eslint/ban-tslint-comment': 'error',
            '@typescript-eslint/ban-types': 'error',
            'block-spacing': 'off',
            '@typescript-eslint/block-spacing': 'error',
            'brace-style': 'off',
            '@typescript-eslint/brace-style': 'error',
            '@typescript-eslint/class-literal-property-style': 'error',
            'comma-dangle': 'off',
            '@typescript-eslint/comma-dangle': 'error',
            'comma-spacing': 'off',
            '@typescript-eslint/comma-spacing': 'error',
            '@typescript-eslint/consistent-generic-constructors': 'error',
            '@typescript-eslint/consistent-indexed-object-style': 'error',
            '@typescript-eslint/consistent-type-assertions': 'error',
            '@typescript-eslint/consistent-type-definitions': 'error',
            '@typescript-eslint/consistent-type-exports': 'error',
            '@typescript-eslint/consistent-type-imports': 'error',
            'default-param-last': 'off',
            '@typescript-eslint/default-param-last': 'error',
            'dot-notation': 'off',
            '@typescript-eslint/dot-notation': 'error',
            '@typescript-eslint/explicit-function-return-type': 'error',
            '@typescript-eslint/explicit-member-accessibility': 'error',
            '@typescript-eslint/explicit-module-boundary-types': 'error',
            'func-call-spacing': 'off',
            '@typescript-eslint/func-call-spacing': 'error',
            indent: 'off',
            '@typescript-eslint/indent': 'error',
            'init-declarations': 'off',
            '@typescript-eslint/init-declarations': 'error',
            'key-spacing': 'off',
            '@typescript-eslint/key-spacing': 'error',
            'keyword-spacing': 'off',
            '@typescript-eslint/keyword-spacing': 'error',
            'lines-around-comment': 'off',
            '@typescript-eslint/lines-around-comment': 'error',
            'lines-between-class-members': 'off',
            '@typescript-eslint/lines-between-class-members': 'error',
            '@typescript-eslint/member-delimiter-style': 'error',
            '@typescript-eslint/member-ordering': 'error',
            '@typescript-eslint/method-signature-style': 'error',
            '@typescript-eslint/naming-convention': 'error',
            'no-array-constructor': 'off',
            '@typescript-eslint/no-array-constructor': 'error',
            '@typescript-eslint/no-base-to-string': 'error',
            '@typescript-eslint/no-confusing-non-null-assertion': 'error',
            '@typescript-eslint/no-confusing-void-expression': 'error',
            'no-dupe-class-members': 'off',
            '@typescript-eslint/no-dupe-class-members': 'error',
            '@typescript-eslint/no-duplicate-enum-values': 'error',
            '@typescript-eslint/no-dynamic-delete': 'error',
            'no-empty-function': 'off',
            '@typescript-eslint/no-empty-function': 'error',
            '@typescript-eslint/no-empty-interface': 'error',
            '@typescript-eslint/no-explicit-any': 'error',
            '@typescript-eslint/no-extra-non-null-assertion': 'error',
            'no-extra-parens': 'off',
            '@typescript-eslint/no-extra-parens': 'error',
            'no-extra-semi': 'off',
            '@typescript-eslint/no-extra-semi': 'error',
            '@typescript-eslint/no-extraneous-class': 'error',
            '@typescript-eslint/no-floating-promises': 'error',
            '@typescript-eslint/no-for-in-array': 'error',
            'no-implied-eval': 'off',
            '@typescript-eslint/no-implied-eval': 'error',
            '@typescript-eslint/no-import-type-side-effects': 'error',
            '@typescript-eslint/no-inferrable-types': 'error',
            'no-invalid-this': 'off',
            '@typescript-eslint/no-invalid-this': 'error',
            '@typescript-eslint/no-invalid-void-type': 'error',
            'no-loop-func': 'off',
            '@typescript-eslint/no-loop-func': 'error',
            'no-loss-of-precision': 'off',
            '@typescript-eslint/no-loss-of-precision': 'error',
            'no-magic-numbers': 'off',
            '@typescript-eslint/no-magic-numbers': 'error',
            '@typescript-eslint/no-meaningless-void-operator': 'error',
            '@typescript-eslint/no-misused-new': 'error',
            '@typescript-eslint/no-misused-promises': 'error',
            '@typescript-eslint/no-mixed-enums': 'error',
            '@typescript-eslint/no-namespace': 'error',
            '@typescript-eslint/no-non-null-asserted-nullish-coalescing': 'error',
            '@typescript-eslint/no-non-null-asserted-optional-chain': 'error',
            '@typescript-eslint/no-non-null-assertion': 'error',
            'no-redeclare': 'off',
            '@typescript-eslint/no-redeclare': 'error',
            '@typescript-eslint/no-redundant-type-constituents': 'error',
            '@typescript-eslint/no-require-imports': 'error',
            'no-restricted-imports': 'off',
            '@typescript-eslint/no-restricted-imports': 'error',
            'no-shadow': 'off',
            '@typescript-eslint/no-shadow': 'error',
            '@typescript-eslint/no-this-alias': 'error',
            'no-throw-literal': 'off',
            '@typescript-eslint/no-throw-literal': 'error',
            '@typescript-eslint/no-type-alias': 'error',
            '@typescript-eslint/no-unnecessary-boolean-literal-compare': 'error',
            '@typescript-eslint/no-unnecessary-condition': 'error',
            '@typescript-eslint/no-unnecessary-qualifier': 'error',
            '@typescript-eslint/no-unnecessary-type-arguments': 'error',
            '@typescript-eslint/no-unnecessary-type-assertion': 'error',
            '@typescript-eslint/no-unnecessary-type-constraint': 'error',
            '@typescript-eslint/no-unsafe-argument': 'error',
            '@typescript-eslint/no-unsafe-assignment': 'error',
            '@typescript-eslint/no-unsafe-call': 'error',
            '@typescript-eslint/no-unsafe-declaration-merging': 'error',
            '@typescript-eslint/no-unsafe-member-access': 'error',
            '@typescript-eslint/no-unsafe-return': 'error',
            'no-unused-expressions': 'off',
            '@typescript-eslint/no-unused-expressions': 'error',
            'no-unused-vars': 'off',
            '@typescript-eslint/no-unused-vars': 'error',
            'no-use-before-define': 'off',
            '@typescript-eslint/no-use-before-define': 'error',
            'no-useless-constructor': 'off',
            '@typescript-eslint/no-useless-constructor': 'error',
            '@typescript-eslint/no-useless-empty-export': 'error',
            '@typescript-eslint/no-var-requires': 'error',
            '@typescript-eslint/non-nullable-type-assertion-style': 'error',
            'object-curly-spacing': 'off',
            '@typescript-eslint/object-curly-spacing': 'error',
            'padding-line-between-statements': 'off',
            '@typescript-eslint/padding-line-between-statements': 'error',
            '@typescript-eslint/parameter-properties': 'error',
            '@typescript-eslint/prefer-as-const': 'error',
            '@typescript-eslint/prefer-enum-initializers': 'error',
            '@typescript-eslint/prefer-for-of': 'error',
            '@typescript-eslint/prefer-function-type': 'error',
            '@typescript-eslint/prefer-includes': 'error',
            '@typescript-eslint/prefer-literal-enum-member': 'error',
            '@typescript-eslint/prefer-namespace-keyword': 'error',
            '@typescript-eslint/prefer-nullish-coalescing': 'error',
            '@typescript-eslint/prefer-optional-chain': 'error',
            '@typescript-eslint/prefer-readonly': 'error',
            '@typescript-eslint/prefer-readonly-parameter-types': 'error',
            '@typescript-eslint/prefer-reduce-type-parameter': 'error',
            '@typescript-eslint/prefer-regexp-exec': 'error',
            '@typescript-eslint/prefer-return-this-type': 'error',
            '@typescript-eslint/prefer-string-starts-ends-with': 'error',
            '@typescript-eslint/prefer-ts-expect-error': 'error',
            '@typescript-eslint/promise-function-async': 'error',
            quotes: 'off',
            '@typescript-eslint/quotes': 'error',
            '@typescript-eslint/require-array-sort-compare': 'error',
            'require-await': 'off',
            '@typescript-eslint/require-await': 'error',
            '@typescript-eslint/restrict-plus-operands': 'error',
            '@typescript-eslint/restrict-template-expressions': 'error',
            'no-return-await': 'off',
            '@typescript-eslint/return-await': 'error',
            semi: 'off',
            '@typescript-eslint/semi': 'error',
            '@typescript-eslint/sort-type-constituents': 'error',
            'space-before-blocks': 'off',
            '@typescript-eslint/space-before-blocks': 'error',
            'space-before-function-paren': 'off',
            '@typescript-eslint/space-before-function-paren': 'error',
            'space-infix-ops': 'off',
            '@typescript-eslint/space-infix-ops': 'error',
            '@typescript-eslint/strict-boolean-expressions': 'error',
            '@typescript-eslint/switch-exhaustiveness-check': 'error',
            '@typescript-eslint/triple-slash-reference': 'error',
            '@typescript-eslint/type-annotation-spacing': 'error',
            '@typescript-eslint/typedef': 'error',
            '@typescript-eslint/unbound-method': 'error',
            '@typescript-eslint/unified-signatures': 'error',
        },
    };
    
},
/* @typescript-eslint/eslint-plugin/dist/configs/base.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // YOU CAN REGENERATE IT USING yarn generate:configs
    module.exports = {
        parser: '@typescript-eslint/parser',
        parserOptions: { sourceType: 'module' },
        plugins: ['@typescript-eslint'],
    };
    
},
/* @typescript-eslint/eslint-plugin/dist/configs/eslint-recommended.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    module.exports = {
        overrides: [
            {
                files: ['*.ts', '*.tsx', '*.mts', '*.cts'],
                rules: {
                    'constructor-super': 'off',
                    'getter-return': 'off',
                    'no-const-assign': 'off',
                    'no-dupe-args': 'off',
                    'no-dupe-class-members': 'off',
                    'no-dupe-keys': 'off',
                    'no-func-assign': 'off',
                    'no-import-assign': 'off',
                    'no-new-symbol': 'off',
                    'no-obj-calls': 'off',
                    'no-redeclare': 'off',
                    'no-setter-return': 'off',
                    'no-this-before-super': 'off',
                    'no-undef': 'off',
                    'no-unreachable': 'off',
                    'no-unsafe-negation': 'off',
                    'no-var': 'error',
                    'prefer-const': 'error',
                    'prefer-rest-params': 'error',
                    'prefer-spread': 'error',
                    'valid-typeof': 'off', // ts(2367)
                },
            },
        ],
    };
    
},
/* @typescript-eslint/eslint-plugin/dist/configs/recommended.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // YOU CAN REGENERATE IT USING yarn generate:configs
    module.exports = {
        extends: ['./configs/base', './configs/eslint-recommended'],
        rules: {
            '@typescript-eslint/adjacent-overload-signatures': 'error',
            '@typescript-eslint/ban-ts-comment': 'error',
            '@typescript-eslint/ban-types': 'error',
            'no-array-constructor': 'off',
            '@typescript-eslint/no-array-constructor': 'error',
            'no-empty-function': 'off',
            '@typescript-eslint/no-empty-function': 'error',
            '@typescript-eslint/no-empty-interface': 'error',
            '@typescript-eslint/no-explicit-any': 'warn',
            '@typescript-eslint/no-extra-non-null-assertion': 'error',
            'no-extra-semi': 'off',
            '@typescript-eslint/no-extra-semi': 'error',
            '@typescript-eslint/no-inferrable-types': 'error',
            'no-loss-of-precision': 'off',
            '@typescript-eslint/no-loss-of-precision': 'error',
            '@typescript-eslint/no-misused-new': 'error',
            '@typescript-eslint/no-namespace': 'error',
            '@typescript-eslint/no-non-null-asserted-optional-chain': 'error',
            '@typescript-eslint/no-non-null-assertion': 'warn',
            '@typescript-eslint/no-this-alias': 'error',
            '@typescript-eslint/no-unnecessary-type-constraint': 'error',
            'no-unused-vars': 'off',
            '@typescript-eslint/no-unused-vars': 'warn',
            '@typescript-eslint/no-var-requires': 'error',
            '@typescript-eslint/prefer-as-const': 'error',
            '@typescript-eslint/prefer-namespace-keyword': 'error',
            '@typescript-eslint/triple-slash-reference': 'error',
        },
    };
    
},
/* @typescript-eslint/eslint-plugin/dist/configs/recommended-requiring-type-checking.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // YOU CAN REGENERATE IT USING yarn generate:configs
    module.exports = {
        extends: ['./configs/base', './configs/eslint-recommended'],
        rules: {
            '@typescript-eslint/await-thenable': 'error',
            '@typescript-eslint/no-floating-promises': 'error',
            '@typescript-eslint/no-for-in-array': 'error',
            'no-implied-eval': 'off',
            '@typescript-eslint/no-implied-eval': 'error',
            '@typescript-eslint/no-misused-promises': 'error',
            '@typescript-eslint/no-unnecessary-type-assertion': 'error',
            '@typescript-eslint/no-unsafe-argument': 'error',
            '@typescript-eslint/no-unsafe-assignment': 'error',
            '@typescript-eslint/no-unsafe-call': 'error',
            '@typescript-eslint/no-unsafe-member-access': 'error',
            '@typescript-eslint/no-unsafe-return': 'error',
            'require-await': 'off',
            '@typescript-eslint/require-await': 'error',
            '@typescript-eslint/restrict-plus-operands': 'error',
            '@typescript-eslint/restrict-template-expressions': 'error',
            '@typescript-eslint/unbound-method': 'error',
        },
    };
    
},
/* @typescript-eslint/eslint-plugin/dist/configs/strict.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // YOU CAN REGENERATE IT USING yarn generate:configs
    module.exports = {
        extends: ['./configs/base', './configs/eslint-recommended'],
        rules: {
            '@typescript-eslint/array-type': 'warn',
            '@typescript-eslint/ban-tslint-comment': 'warn',
            '@typescript-eslint/class-literal-property-style': 'warn',
            '@typescript-eslint/consistent-generic-constructors': 'warn',
            '@typescript-eslint/consistent-indexed-object-style': 'warn',
            '@typescript-eslint/consistent-type-assertions': 'warn',
            '@typescript-eslint/consistent-type-definitions': 'warn',
            'dot-notation': 'off',
            '@typescript-eslint/dot-notation': 'warn',
            '@typescript-eslint/no-base-to-string': 'warn',
            '@typescript-eslint/no-confusing-non-null-assertion': 'warn',
            '@typescript-eslint/no-duplicate-enum-values': 'warn',
            '@typescript-eslint/no-dynamic-delete': 'warn',
            '@typescript-eslint/no-extraneous-class': 'warn',
            '@typescript-eslint/no-invalid-void-type': 'warn',
            '@typescript-eslint/no-meaningless-void-operator': 'warn',
            '@typescript-eslint/no-mixed-enums': 'warn',
            '@typescript-eslint/no-non-null-asserted-nullish-coalescing': 'warn',
            'no-throw-literal': 'off',
            '@typescript-eslint/no-throw-literal': 'warn',
            '@typescript-eslint/no-unnecessary-boolean-literal-compare': 'warn',
            '@typescript-eslint/no-unnecessary-condition': 'warn',
            '@typescript-eslint/no-unnecessary-type-arguments': 'warn',
            '@typescript-eslint/no-unsafe-declaration-merging': 'warn',
            'no-useless-constructor': 'off',
            '@typescript-eslint/no-useless-constructor': 'warn',
            '@typescript-eslint/non-nullable-type-assertion-style': 'warn',
            '@typescript-eslint/prefer-for-of': 'warn',
            '@typescript-eslint/prefer-function-type': 'warn',
            '@typescript-eslint/prefer-includes': 'warn',
            '@typescript-eslint/prefer-literal-enum-member': 'warn',
            '@typescript-eslint/prefer-nullish-coalescing': 'warn',
            '@typescript-eslint/prefer-optional-chain': 'warn',
            '@typescript-eslint/prefer-reduce-type-parameter': 'warn',
            '@typescript-eslint/prefer-return-this-type': 'warn',
            '@typescript-eslint/prefer-string-starts-ends-with': 'warn',
            '@typescript-eslint/prefer-ts-expect-error': 'warn',
            '@typescript-eslint/unified-signatures': 'warn',
        },
    };
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const adjacent_overload_signatures_1 = __importDefault(require(776) /* ./adjacent-overload-signatures */);
    const array_type_1 = __importDefault(require(1149) /* ./array-type */);
    const await_thenable_1 = __importDefault(require(1150) /* ./await-thenable */);
    const ban_ts_comment_1 = __importDefault(require(1151) /* ./ban-ts-comment */);
    const ban_tslint_comment_1 = __importDefault(require(1152) /* ./ban-tslint-comment */);
    const ban_types_1 = __importDefault(require(1153) /* ./ban-types */);
    const block_spacing_1 = __importDefault(require(1154) /* ./block-spacing */);
    const brace_style_1 = __importDefault(require(1158) /* ./brace-style */);
    const class_literal_property_style_1 = __importDefault(require(1159) /* ./class-literal-property-style */);
    const comma_dangle_1 = __importDefault(require(1160) /* ./comma-dangle */);
    const comma_spacing_1 = __importDefault(require(1161) /* ./comma-spacing */);
    const consistent_generic_constructors_1 = __importDefault(require(1162) /* ./consistent-generic-constructors */);
    const consistent_indexed_object_style_1 = __importDefault(require(1163) /* ./consistent-indexed-object-style */);
    const consistent_type_assertions_1 = __importDefault(require(1164) /* ./consistent-type-assertions */);
    const consistent_type_definitions_1 = __importDefault(require(1165) /* ./consistent-type-definitions */);
    const consistent_type_exports_1 = __importDefault(require(1166) /* ./consistent-type-exports */);
    const consistent_type_imports_1 = __importDefault(require(1167) /* ./consistent-type-imports */);
    const default_param_last_1 = __importDefault(require(1168) /* ./default-param-last */);
    const dot_notation_1 = __importDefault(require(1169) /* ./dot-notation */);
    const explicit_function_return_type_1 = __importDefault(require(1170) /* ./explicit-function-return-type */);
    const explicit_member_accessibility_1 = __importDefault(require(1172) /* ./explicit-member-accessibility */);
    const explicit_module_boundary_types_1 = __importDefault(require(1173) /* ./explicit-module-boundary-types */);
    const func_call_spacing_1 = __importDefault(require(1174) /* ./func-call-spacing */);
    const indent_1 = __importDefault(require(1175) /* ./indent */);
    const init_declarations_1 = __importDefault(require(1176) /* ./init-declarations */);
    const key_spacing_1 = __importDefault(require(1177) /* ./key-spacing */);
    const keyword_spacing_1 = __importDefault(require(1178) /* ./keyword-spacing */);
    const lines_around_comment_1 = __importDefault(require(1179) /* ./lines-around-comment */);
    const lines_between_class_members_1 = __importDefault(require(1180) /* ./lines-between-class-members */);
    const member_delimiter_style_1 = __importDefault(require(1181) /* ./member-delimiter-style */);
    const member_ordering_1 = __importDefault(require(1182) /* ./member-ordering */);
    const method_signature_style_1 = __importDefault(require(1184) /* ./method-signature-style */);
    const naming_convention_1 = __importDefault(require(1185) /* ./naming-convention */);
    const no_array_constructor_1 = __importDefault(require(1193) /* ./no-array-constructor */);
    const no_base_to_string_1 = __importDefault(require(1194) /* ./no-base-to-string */);
    const no_confusing_non_null_assertion_1 = __importDefault(require(1195) /* ./no-confusing-non-null-assertion */);
    const no_confusing_void_expression_1 = __importDefault(require(1196) /* ./no-confusing-void-expression */);
    const no_dupe_class_members_1 = __importDefault(require(1197) /* ./no-dupe-class-members */);
    const no_duplicate_enum_values_1 = __importDefault(require(1198) /* ./no-duplicate-enum-values */);
    const no_duplicate_imports_1 = __importDefault(require(1199) /* ./no-duplicate-imports */);
    const no_dynamic_delete_1 = __importDefault(require(1200) /* ./no-dynamic-delete */);
    const no_empty_function_1 = __importDefault(require(1201) /* ./no-empty-function */);
    const no_empty_interface_1 = __importDefault(require(1202) /* ./no-empty-interface */);
    const no_explicit_any_1 = __importDefault(require(1203) /* ./no-explicit-any */);
    const no_extra_non_null_assertion_1 = __importDefault(require(1204) /* ./no-extra-non-null-assertion */);
    const no_extra_parens_1 = __importDefault(require(1205) /* ./no-extra-parens */);
    const no_extra_semi_1 = __importDefault(require(1206) /* ./no-extra-semi */);
    const no_extraneous_class_1 = __importDefault(require(1207) /* ./no-extraneous-class */);
    const no_floating_promises_1 = __importDefault(require(1208) /* ./no-floating-promises */);
    const no_for_in_array_1 = __importDefault(require(1209) /* ./no-for-in-array */);
    const no_implicit_any_catch_1 = __importDefault(require(1210) /* ./no-implicit-any-catch */);
    const no_implied_eval_1 = __importDefault(require(1211) /* ./no-implied-eval */);
    const no_import_type_side_effects_1 = __importDefault(require(1212) /* ./no-import-type-side-effects */);
    const no_inferrable_types_1 = __importDefault(require(1213) /* ./no-inferrable-types */);
    const no_invalid_this_1 = __importDefault(require(1214) /* ./no-invalid-this */);
    const no_invalid_void_type_1 = __importDefault(require(1215) /* ./no-invalid-void-type */);
    const no_loop_func_1 = __importDefault(require(1216) /* ./no-loop-func */);
    const no_loss_of_precision_1 = __importDefault(require(1217) /* ./no-loss-of-precision */);
    const no_magic_numbers_1 = __importDefault(require(1218) /* ./no-magic-numbers */);
    const no_meaningless_void_operator_1 = __importDefault(require(1219) /* ./no-meaningless-void-operator */);
    const no_misused_new_1 = __importDefault(require(1220) /* ./no-misused-new */);
    const no_misused_promises_1 = __importDefault(require(1221) /* ./no-misused-promises */);
    const no_mixed_enums_1 = __importDefault(require(1222) /* ./no-mixed-enums */);
    const no_namespace_1 = __importDefault(require(1223) /* ./no-namespace */);
    const no_non_null_asserted_nullish_coalescing_1 = __importDefault(require(1224) /* ./no-non-null-asserted-nullish-coalescing */);
    const no_non_null_asserted_optional_chain_1 = __importDefault(require(1225) /* ./no-non-null-asserted-optional-chain */);
    const no_non_null_assertion_1 = __importDefault(require(1226) /* ./no-non-null-assertion */);
    const no_parameter_properties_1 = __importDefault(require(1227) /* ./no-parameter-properties */);
    const no_redeclare_1 = __importDefault(require(1228) /* ./no-redeclare */);
    const no_redundant_type_constituents_1 = __importDefault(require(1229) /* ./no-redundant-type-constituents */);
    const no_require_imports_1 = __importDefault(require(1230) /* ./no-require-imports */);
    const no_restricted_imports_1 = __importDefault(require(1231) /* ./no-restricted-imports */);
    const no_shadow_1 = __importDefault(require(1232) /* ./no-shadow */);
    const no_this_alias_1 = __importDefault(require(1233) /* ./no-this-alias */);
    const no_throw_literal_1 = __importDefault(require(1234) /* ./no-throw-literal */);
    const no_type_alias_1 = __importDefault(require(1235) /* ./no-type-alias */);
    const no_unnecessary_boolean_literal_compare_1 = __importDefault(require(1236) /* ./no-unnecessary-boolean-literal-compare */);
    const no_unnecessary_condition_1 = __importDefault(require(1237) /* ./no-unnecessary-condition */);
    const no_unnecessary_qualifier_1 = __importDefault(require(1238) /* ./no-unnecessary-qualifier */);
    const no_unnecessary_type_arguments_1 = __importDefault(require(1239) /* ./no-unnecessary-type-arguments */);
    const no_unnecessary_type_assertion_1 = __importDefault(require(1240) /* ./no-unnecessary-type-assertion */);
    const no_unnecessary_type_constraint_1 = __importDefault(require(1241) /* ./no-unnecessary-type-constraint */);
    const no_unsafe_argument_1 = __importDefault(require(1242) /* ./no-unsafe-argument */);
    const no_unsafe_assignment_1 = __importDefault(require(1243) /* ./no-unsafe-assignment */);
    const no_unsafe_call_1 = __importDefault(require(1244) /* ./no-unsafe-call */);
    const no_unsafe_declaration_merging_1 = __importDefault(require(1245) /* ./no-unsafe-declaration-merging */);
    const no_unsafe_member_access_1 = __importDefault(require(1246) /* ./no-unsafe-member-access */);
    const no_unsafe_return_1 = __importDefault(require(1247) /* ./no-unsafe-return */);
    const no_unused_expressions_1 = __importDefault(require(1248) /* ./no-unused-expressions */);
    const no_unused_vars_1 = __importDefault(require(1249) /* ./no-unused-vars */);
    const no_use_before_define_1 = __importDefault(require(1250) /* ./no-use-before-define */);
    const no_useless_constructor_1 = __importDefault(require(1251) /* ./no-useless-constructor */);
    const no_useless_empty_export_1 = __importDefault(require(1252) /* ./no-useless-empty-export */);
    const no_var_requires_1 = __importDefault(require(1253) /* ./no-var-requires */);
    const non_nullable_type_assertion_style_1 = __importDefault(require(1254) /* ./non-nullable-type-assertion-style */);
    const object_curly_spacing_1 = __importDefault(require(1255) /* ./object-curly-spacing */);
    const padding_line_between_statements_1 = __importDefault(require(1256) /* ./padding-line-between-statements */);
    const parameter_properties_1 = __importDefault(require(1257) /* ./parameter-properties */);
    const prefer_as_const_1 = __importDefault(require(1258) /* ./prefer-as-const */);
    const prefer_enum_initializers_1 = __importDefault(require(1259) /* ./prefer-enum-initializers */);
    const prefer_for_of_1 = __importDefault(require(1260) /* ./prefer-for-of */);
    const prefer_function_type_1 = __importDefault(require(1261) /* ./prefer-function-type */);
    const prefer_includes_1 = __importDefault(require(1262) /* ./prefer-includes */);
    const prefer_literal_enum_member_1 = __importDefault(require(1263) /* ./prefer-literal-enum-member */);
    const prefer_namespace_keyword_1 = __importDefault(require(1264) /* ./prefer-namespace-keyword */);
    const prefer_nullish_coalescing_1 = __importDefault(require(1265) /* ./prefer-nullish-coalescing */);
    const prefer_optional_chain_1 = __importDefault(require(1266) /* ./prefer-optional-chain */);
    const prefer_readonly_1 = __importDefault(require(1267) /* ./prefer-readonly */);
    const prefer_readonly_parameter_types_1 = __importDefault(require(1268) /* ./prefer-readonly-parameter-types */);
    const prefer_reduce_type_parameter_1 = __importDefault(require(1269) /* ./prefer-reduce-type-parameter */);
    const prefer_regexp_exec_1 = __importDefault(require(1270) /* ./prefer-regexp-exec */);
    const prefer_return_this_type_1 = __importDefault(require(1271) /* ./prefer-return-this-type */);
    const prefer_string_starts_ends_with_1 = __importDefault(require(1272) /* ./prefer-string-starts-ends-with */);
    const prefer_ts_expect_error_1 = __importDefault(require(1273) /* ./prefer-ts-expect-error */);
    const promise_function_async_1 = __importDefault(require(1274) /* ./promise-function-async */);
    const quotes_1 = __importDefault(require(1275) /* ./quotes */);
    const require_array_sort_compare_1 = __importDefault(require(1276) /* ./require-array-sort-compare */);
    const require_await_1 = __importDefault(require(1277) /* ./require-await */);
    const restrict_plus_operands_1 = __importDefault(require(1278) /* ./restrict-plus-operands */);
    const restrict_template_expressions_1 = __importDefault(require(1279) /* ./restrict-template-expressions */);
    const return_await_1 = __importDefault(require(1280) /* ./return-await */);
    const semi_1 = __importDefault(require(1281) /* ./semi */);
    const sort_type_constituents_1 = __importDefault(require(1282) /* ./sort-type-constituents */);
    const sort_type_union_intersection_members_1 = __importDefault(require(1283) /* ./sort-type-union-intersection-members */);
    const space_before_blocks_1 = __importDefault(require(1284) /* ./space-before-blocks */);
    const space_before_function_paren_1 = __importDefault(require(1285) /* ./space-before-function-paren */);
    const space_infix_ops_1 = __importDefault(require(1286) /* ./space-infix-ops */);
    const strict_boolean_expressions_1 = __importDefault(require(1287) /* ./strict-boolean-expressions */);
    const switch_exhaustiveness_check_1 = __importDefault(require(1288) /* ./switch-exhaustiveness-check */);
    const triple_slash_reference_1 = __importDefault(require(1289) /* ./triple-slash-reference */);
    const type_annotation_spacing_1 = __importDefault(require(1290) /* ./type-annotation-spacing */);
    const typedef_1 = __importDefault(require(1291) /* ./typedef */);
    const unbound_method_1 = __importDefault(require(1292) /* ./unbound-method */);
    const unified_signatures_1 = __importDefault(require(1293) /* ./unified-signatures */);
    exports.default = {
        'adjacent-overload-signatures': adjacent_overload_signatures_1.default,
        'array-type': array_type_1.default,
        'await-thenable': await_thenable_1.default,
        'ban-ts-comment': ban_ts_comment_1.default,
        'ban-tslint-comment': ban_tslint_comment_1.default,
        'ban-types': ban_types_1.default,
        'block-spacing': block_spacing_1.default,
        'brace-style': brace_style_1.default,
        'class-literal-property-style': class_literal_property_style_1.default,
        'comma-dangle': comma_dangle_1.default,
        'comma-spacing': comma_spacing_1.default,
        'consistent-generic-constructors': consistent_generic_constructors_1.default,
        'consistent-indexed-object-style': consistent_indexed_object_style_1.default,
        'consistent-type-assertions': consistent_type_assertions_1.default,
        'consistent-type-definitions': consistent_type_definitions_1.default,
        'consistent-type-exports': consistent_type_exports_1.default,
        'consistent-type-imports': consistent_type_imports_1.default,
        'default-param-last': default_param_last_1.default,
        'dot-notation': dot_notation_1.default,
        'explicit-function-return-type': explicit_function_return_type_1.default,
        'explicit-member-accessibility': explicit_member_accessibility_1.default,
        'explicit-module-boundary-types': explicit_module_boundary_types_1.default,
        'func-call-spacing': func_call_spacing_1.default,
        indent: indent_1.default,
        'init-declarations': init_declarations_1.default,
        'key-spacing': key_spacing_1.default,
        'keyword-spacing': keyword_spacing_1.default,
        'lines-around-comment': lines_around_comment_1.default,
        'lines-between-class-members': lines_between_class_members_1.default,
        'member-delimiter-style': member_delimiter_style_1.default,
        'member-ordering': member_ordering_1.default,
        'method-signature-style': method_signature_style_1.default,
        'naming-convention': naming_convention_1.default,
        'no-array-constructor': no_array_constructor_1.default,
        'no-base-to-string': no_base_to_string_1.default,
        'no-confusing-non-null-assertion': no_confusing_non_null_assertion_1.default,
        'no-confusing-void-expression': no_confusing_void_expression_1.default,
        'no-dupe-class-members': no_dupe_class_members_1.default,
        'no-duplicate-enum-values': no_duplicate_enum_values_1.default,
        'no-duplicate-imports': no_duplicate_imports_1.default,
        'no-dynamic-delete': no_dynamic_delete_1.default,
        'no-empty-function': no_empty_function_1.default,
        'no-empty-interface': no_empty_interface_1.default,
        'no-explicit-any': no_explicit_any_1.default,
        'no-extra-non-null-assertion': no_extra_non_null_assertion_1.default,
        'no-extra-parens': no_extra_parens_1.default,
        'no-extra-semi': no_extra_semi_1.default,
        'no-extraneous-class': no_extraneous_class_1.default,
        'no-floating-promises': no_floating_promises_1.default,
        'no-for-in-array': no_for_in_array_1.default,
        'no-implicit-any-catch': no_implicit_any_catch_1.default,
        'no-implied-eval': no_implied_eval_1.default,
        'no-import-type-side-effects': no_import_type_side_effects_1.default,
        'no-inferrable-types': no_inferrable_types_1.default,
        'no-invalid-this': no_invalid_this_1.default,
        'no-invalid-void-type': no_invalid_void_type_1.default,
        'no-loop-func': no_loop_func_1.default,
        'no-loss-of-precision': no_loss_of_precision_1.default,
        'no-magic-numbers': no_magic_numbers_1.default,
        'no-meaningless-void-operator': no_meaningless_void_operator_1.default,
        'no-misused-new': no_misused_new_1.default,
        'no-misused-promises': no_misused_promises_1.default,
        'no-mixed-enums': no_mixed_enums_1.default,
        'no-namespace': no_namespace_1.default,
        'no-non-null-asserted-nullish-coalescing': no_non_null_asserted_nullish_coalescing_1.default,
        'no-non-null-asserted-optional-chain': no_non_null_asserted_optional_chain_1.default,
        'no-non-null-assertion': no_non_null_assertion_1.default,
        'no-parameter-properties': no_parameter_properties_1.default,
        'no-redeclare': no_redeclare_1.default,
        'no-redundant-type-constituents': no_redundant_type_constituents_1.default,
        'no-require-imports': no_require_imports_1.default,
        'no-restricted-imports': no_restricted_imports_1.default,
        'no-shadow': no_shadow_1.default,
        'no-this-alias': no_this_alias_1.default,
        'no-throw-literal': no_throw_literal_1.default,
        'no-type-alias': no_type_alias_1.default,
        'no-unnecessary-boolean-literal-compare': no_unnecessary_boolean_literal_compare_1.default,
        'no-unnecessary-condition': no_unnecessary_condition_1.default,
        'no-unnecessary-qualifier': no_unnecessary_qualifier_1.default,
        'no-unnecessary-type-arguments': no_unnecessary_type_arguments_1.default,
        'no-unnecessary-type-assertion': no_unnecessary_type_assertion_1.default,
        'no-unnecessary-type-constraint': no_unnecessary_type_constraint_1.default,
        'no-unsafe-argument': no_unsafe_argument_1.default,
        'no-unsafe-assignment': no_unsafe_assignment_1.default,
        'no-unsafe-call': no_unsafe_call_1.default,
        'no-unsafe-declaration-merging': no_unsafe_declaration_merging_1.default,
        'no-unsafe-member-access': no_unsafe_member_access_1.default,
        'no-unsafe-return': no_unsafe_return_1.default,
        'no-unused-expressions': no_unused_expressions_1.default,
        'no-unused-vars': no_unused_vars_1.default,
        'no-use-before-define': no_use_before_define_1.default,
        'no-useless-constructor': no_useless_constructor_1.default,
        'no-useless-empty-export': no_useless_empty_export_1.default,
        'no-var-requires': no_var_requires_1.default,
        'non-nullable-type-assertion-style': non_nullable_type_assertion_style_1.default,
        'object-curly-spacing': object_curly_spacing_1.default,
        'padding-line-between-statements': padding_line_between_statements_1.default,
        'parameter-properties': parameter_properties_1.default,
        'prefer-as-const': prefer_as_const_1.default,
        'prefer-enum-initializers': prefer_enum_initializers_1.default,
        'prefer-for-of': prefer_for_of_1.default,
        'prefer-function-type': prefer_function_type_1.default,
        'prefer-includes': prefer_includes_1.default,
        'prefer-literal-enum-member': prefer_literal_enum_member_1.default,
        'prefer-namespace-keyword': prefer_namespace_keyword_1.default,
        'prefer-nullish-coalescing': prefer_nullish_coalescing_1.default,
        'prefer-optional-chain': prefer_optional_chain_1.default,
        'prefer-readonly': prefer_readonly_1.default,
        'prefer-readonly-parameter-types': prefer_readonly_parameter_types_1.default,
        'prefer-reduce-type-parameter': prefer_reduce_type_parameter_1.default,
        'prefer-regexp-exec': prefer_regexp_exec_1.default,
        'prefer-return-this-type': prefer_return_this_type_1.default,
        'prefer-string-starts-ends-with': prefer_string_starts_ends_with_1.default,
        'prefer-ts-expect-error': prefer_ts_expect_error_1.default,
        'promise-function-async': promise_function_async_1.default,
        quotes: quotes_1.default,
        'require-array-sort-compare': require_array_sort_compare_1.default,
        'require-await': require_await_1.default,
        'restrict-plus-operands': restrict_plus_operands_1.default,
        'restrict-template-expressions': restrict_template_expressions_1.default,
        'return-await': return_await_1.default,
        semi: semi_1.default,
        'sort-type-constituents': sort_type_constituents_1.default,
        'sort-type-union-intersection-members': sort_type_union_intersection_members_1.default,
        'space-before-blocks': space_before_blocks_1.default,
        'space-before-function-paren': space_before_function_paren_1.default,
        'space-infix-ops': space_infix_ops_1.default,
        'strict-boolean-expressions': strict_boolean_expressions_1.default,
        'switch-exhaustiveness-check': switch_exhaustiveness_check_1.default,
        'triple-slash-reference': triple_slash_reference_1.default,
        'type-annotation-spacing': type_annotation_spacing_1.default,
        typedef: typedef_1.default,
        'unbound-method': unbound_method_1.default,
        'unified-signatures': unified_signatures_1.default,
    };
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/adjacent-overload-signatures.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'adjacent-overload-signatures',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require that function overload signatures be consecutive',
                recommended: 'error',
            },
            schema: [],
            messages: {
                adjacentSignature: 'All {{name}} signatures should be adjacent.',
            },
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Gets the name and attribute of the member being processed.
             * @param member the member being processed.
             * @returns the name and attribute of the member or null if it's a member not relevant to the rule.
             */
            function getMemberMethod(member) {
                var _a, _b;
                if (!member) {
                    return null;
                }
                const isStatic = 'static' in member && !!member.static;
                switch (member.type) {
                    case utils_1.AST_NODE_TYPES.ExportDefaultDeclaration:
                    case utils_1.AST_NODE_TYPES.ExportNamedDeclaration: {
                        // export statements (e.g. export { a };)
                        // have no declarations, so ignore them
                        if (!member.declaration) {
                            return null;
                        }
                        return getMemberMethod(member.declaration);
                    }
                    case utils_1.AST_NODE_TYPES.TSDeclareFunction:
                    case utils_1.AST_NODE_TYPES.FunctionDeclaration: {
                        const name = (_b = (_a = member.id) === null || _a === void 0 ? void 0 : _a.name) !== null && _b !== void 0 ? _b : null;
                        if (name == null) {
                            return null;
                        }
                        return {
                            name,
                            static: isStatic,
                            callSignature: false,
                            type: util.MemberNameType.Normal,
                        };
                    }
                    case utils_1.AST_NODE_TYPES.TSMethodSignature:
                        return Object.assign(Object.assign({}, util.getNameFromMember(member, sourceCode)), { static: isStatic, callSignature: false });
                    case utils_1.AST_NODE_TYPES.TSCallSignatureDeclaration:
                        return {
                            name: 'call',
                            static: isStatic,
                            callSignature: true,
                            type: util.MemberNameType.Normal,
                        };
                    case utils_1.AST_NODE_TYPES.TSConstructSignatureDeclaration:
                        return {
                            name: 'new',
                            static: isStatic,
                            callSignature: false,
                            type: util.MemberNameType.Normal,
                        };
                    case utils_1.AST_NODE_TYPES.MethodDefinition:
                        return Object.assign(Object.assign({}, util.getNameFromMember(member, sourceCode)), { static: isStatic, callSignature: false });
                }
                return null;
            }
            function isSameMethod(method1, method2) {
                return (!!method2 &&
                    method1.name === method2.name &&
                    method1.static === method2.static &&
                    method1.callSignature === method2.callSignature &&
                    method1.type === method2.type);
            }
            function getMembers(node) {
                switch (node.type) {
                    case utils_1.AST_NODE_TYPES.ClassBody:
                    case utils_1.AST_NODE_TYPES.Program:
                    case utils_1.AST_NODE_TYPES.TSModuleBlock:
                    case utils_1.AST_NODE_TYPES.TSInterfaceBody:
                    case utils_1.AST_NODE_TYPES.BlockStatement:
                        return node.body;
                    case utils_1.AST_NODE_TYPES.TSTypeLiteral:
                        return node.members;
                }
            }
            /**
             * Check the body for overload methods.
             * @param {ASTNode} node the body to be inspected.
             */
            function checkBodyForOverloadMethods(node) {
                const members = getMembers(node);
                if (members) {
                    let lastMethod = null;
                    const seenMethods = [];
                    members.forEach(member => {
                        const method = getMemberMethod(member);
                        if (method == null) {
                            lastMethod = null;
                            return;
                        }
                        const index = seenMethods.findIndex(seenMethod => isSameMethod(method, seenMethod));
                        if (index > -1 && !isSameMethod(method, lastMethod)) {
                            context.report({
                                node: member,
                                messageId: 'adjacentSignature',
                                data: {
                                    name: `${method.static ? 'static ' : ''}${method.name}`,
                                },
                            });
                        }
                        else if (index === -1) {
                            seenMethods.push(method);
                        }
                        lastMethod = method;
                    });
                }
            }
            return {
                ClassBody: checkBodyForOverloadMethods,
                Program: checkBodyForOverloadMethods,
                TSModuleBlock: checkBodyForOverloadMethods,
                TSTypeLiteral: checkBodyForOverloadMethods,
                TSInterfaceBody: checkBodyForOverloadMethods,
                BlockStatement: checkBodyForOverloadMethods,
            };
        },
    });
    
},
/* @typescript-eslint/utils/dist/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TSESLintScope = exports.TSESLint = exports.JSONSchema = exports.ESLintUtils = exports.ASTUtils = void 0;
    const ASTUtils = __importStar(require(778) /* ./ast-utils */);
    exports.ASTUtils = ASTUtils;
    const ESLintUtils = __importStar(require(794) /* ./eslint-utils */);
    exports.ESLintUtils = ESLintUtils;
    const JSONSchema = __importStar(require(852) /* ./json-schema */);
    exports.JSONSchema = JSONSchema;
    const TSESLint = __importStar(require(853) /* ./ts-eslint */);
    exports.TSESLint = TSESLint;
    const TSESLintScope = __importStar(require(1008) /* ./ts-eslint-scope */);
    exports.TSESLintScope = TSESLintScope;
    __exportStar(require(788) /* ./ts-estree */, exports);
    
},
/* @typescript-eslint/utils/dist/ast-utils/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    __exportStar(require(779) /* ./eslint-utils */, exports);
    __exportStar(require(785) /* ./helpers */, exports);
    __exportStar(require(786) /* ./misc */, exports);
    __exportStar(require(787) /* ./predicates */, exports);
    
},
/* @typescript-eslint/utils/dist/ast-utils/eslint-utils/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    __exportStar(require(780) /* ./astUtilities */, exports);
    __exportStar(require(781) /* ./PatternMatcher */, exports);
    __exportStar(require(782) /* ./predicates */, exports);
    __exportStar(require(783) /* ./ReferenceTracker */, exports);
    __exportStar(require(784) /* ./scopeAnalysis */, exports);
    
},
/* @typescript-eslint/utils/dist/ast-utils/eslint-utils/astUtilities.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isParenthesized = exports.hasSideEffect = exports.getStringIfConstant = exports.getStaticValue = exports.getPropertyName = exports.getFunctionNameWithKind = exports.getFunctionHeadLocation = void 0;
    const eslintUtils = __importStar(require(316) /* @eslint-community/eslint-utils */);
    /**
     * Get the proper location of a given function node to report.
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/ast-utils.html#getfunctionheadlocation}
     */
    const getFunctionHeadLocation = eslintUtils.getFunctionHeadLocation;
    exports.getFunctionHeadLocation = getFunctionHeadLocation;
    /**
     * Get the name and kind of a given function node.
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/ast-utils.html#getfunctionnamewithkind}
     */
    const getFunctionNameWithKind = eslintUtils.getFunctionNameWithKind;
    exports.getFunctionNameWithKind = getFunctionNameWithKind;
    /**
     * Get the property name of a given property node.
     * If the node is a computed property, this tries to compute the property name by the getStringIfConstant function.
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/ast-utils.html#getpropertyname}
     * @returns The property name of the node. If the property name is not constant then it returns `null`.
     */
    const getPropertyName = eslintUtils.getPropertyName;
    exports.getPropertyName = getPropertyName;
    /**
     * Get the value of a given node if it can decide the value statically.
     * If the 2nd parameter `initialScope` was given, this function tries to resolve identifier references which are in the
     * given node as much as possible. In the resolving way, it does on the assumption that built-in global objects have
     * not been modified.
     * For example, it considers `Symbol.iterator`, ` String.raw``hello`` `, and `Object.freeze({a: 1}).a` as static.
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/ast-utils.html#getstaticvalue}
     * @returns The `{ value: any }` shaped object. The `value` property is the static value. If it couldn't compute the
     * static value of the node, it returns `null`.
     */
    const getStaticValue = eslintUtils.getStaticValue;
    exports.getStaticValue = getStaticValue;
    /**
     * Get the string value of a given node.
     * This function is a tiny wrapper of the getStaticValue function.
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/ast-utils.html#getstringifconstant}
     */
    const getStringIfConstant = eslintUtils.getStringIfConstant;
    exports.getStringIfConstant = getStringIfConstant;
    /**
     * Check whether a given node has any side effect or not.
     * The side effect means that it may modify a certain variable or object member. This function considers the node which
     * contains the following types as the node which has side effects:
     * - `AssignmentExpression`
     * - `AwaitExpression`
     * - `CallExpression`
     * - `ImportExpression`
     * - `NewExpression`
     * - `UnaryExpression([operator = "delete"])`
     * - `UpdateExpression`
     * - `YieldExpression`
     * - When `options.considerGetters` is `true`:
     *   - `MemberExpression`
     * - When `options.considerImplicitTypeConversion` is `true`:
     *   - `BinaryExpression([operator = "==" | "!=" | "<" | "<=" | ">" | ">=" | "<<" | ">>" | ">>>" | "+" | "-" | "*" | "/" | "%" | "|" | "^" | "&" | "in"])`
     *   - `MemberExpression([computed = true])`
     *   - `MethodDefinition([computed = true])`
     *   - `Property([computed = true])`
     *   - `UnaryExpression([operator = "-" | "+" | "!" | "~"])`
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/ast-utils.html#hassideeffect}
     */
    const hasSideEffect = eslintUtils.hasSideEffect;
    exports.hasSideEffect = hasSideEffect;
    const isParenthesized = eslintUtils.isParenthesized;
    exports.isParenthesized = isParenthesized;
    
},
/* @typescript-eslint/utils/dist/ast-utils/eslint-utils/PatternMatcher.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.PatternMatcher = void 0;
    const eslintUtils = __importStar(require(316) /* @eslint-community/eslint-utils */);
    /**
     * The class to find a pattern in strings as handling escape sequences.
     * It ignores the found pattern if it's escaped with `\`.
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/ast-utils.html#patternmatcher-class}
     */
    const PatternMatcher = eslintUtils.PatternMatcher;
    exports.PatternMatcher = PatternMatcher;
    
},
/* @typescript-eslint/utils/dist/ast-utils/eslint-utils/predicates.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isSemicolonToken = exports.isOpeningParenToken = exports.isOpeningBracketToken = exports.isOpeningBraceToken = exports.isNotSemicolonToken = exports.isNotOpeningParenToken = exports.isNotOpeningBracketToken = exports.isNotOpeningBraceToken = exports.isNotCommentToken = exports.isNotCommaToken = exports.isNotColonToken = exports.isNotClosingParenToken = exports.isNotClosingBracketToken = exports.isNotClosingBraceToken = exports.isNotArrowToken = exports.isCommentToken = exports.isCommaToken = exports.isColonToken = exports.isClosingParenToken = exports.isClosingBracketToken = exports.isClosingBraceToken = exports.isArrowToken = void 0;
    const eslintUtils = __importStar(require(316) /* @eslint-community/eslint-utils */);
    const isArrowToken = eslintUtils.isArrowToken;
    exports.isArrowToken = isArrowToken;
    const isNotArrowToken = eslintUtils.isNotArrowToken;
    exports.isNotArrowToken = isNotArrowToken;
    const isClosingBraceToken = eslintUtils.isClosingBraceToken;
    exports.isClosingBraceToken = isClosingBraceToken;
    const isNotClosingBraceToken = eslintUtils.isNotClosingBraceToken;
    exports.isNotClosingBraceToken = isNotClosingBraceToken;
    const isClosingBracketToken = eslintUtils.isClosingBracketToken;
    exports.isClosingBracketToken = isClosingBracketToken;
    const isNotClosingBracketToken = eslintUtils.isNotClosingBracketToken;
    exports.isNotClosingBracketToken = isNotClosingBracketToken;
    const isClosingParenToken = eslintUtils.isClosingParenToken;
    exports.isClosingParenToken = isClosingParenToken;
    const isNotClosingParenToken = eslintUtils.isNotClosingParenToken;
    exports.isNotClosingParenToken = isNotClosingParenToken;
    const isColonToken = eslintUtils.isColonToken;
    exports.isColonToken = isColonToken;
    const isNotColonToken = eslintUtils.isNotColonToken;
    exports.isNotColonToken = isNotColonToken;
    const isCommaToken = eslintUtils.isCommaToken;
    exports.isCommaToken = isCommaToken;
    const isNotCommaToken = eslintUtils.isNotCommaToken;
    exports.isNotCommaToken = isNotCommaToken;
    const isCommentToken = eslintUtils.isCommentToken;
    exports.isCommentToken = isCommentToken;
    const isNotCommentToken = eslintUtils.isNotCommentToken;
    exports.isNotCommentToken = isNotCommentToken;
    const isOpeningBraceToken = eslintUtils.isOpeningBraceToken;
    exports.isOpeningBraceToken = isOpeningBraceToken;
    const isNotOpeningBraceToken = eslintUtils.isNotOpeningBraceToken;
    exports.isNotOpeningBraceToken = isNotOpeningBraceToken;
    const isOpeningBracketToken = eslintUtils.isOpeningBracketToken;
    exports.isOpeningBracketToken = isOpeningBracketToken;
    const isNotOpeningBracketToken = eslintUtils.isNotOpeningBracketToken;
    exports.isNotOpeningBracketToken = isNotOpeningBracketToken;
    const isOpeningParenToken = eslintUtils.isOpeningParenToken;
    exports.isOpeningParenToken = isOpeningParenToken;
    const isNotOpeningParenToken = eslintUtils.isNotOpeningParenToken;
    exports.isNotOpeningParenToken = isNotOpeningParenToken;
    const isSemicolonToken = eslintUtils.isSemicolonToken;
    exports.isSemicolonToken = isSemicolonToken;
    const isNotSemicolonToken = eslintUtils.isNotSemicolonToken;
    exports.isNotSemicolonToken = isNotSemicolonToken;
    
},
/* @typescript-eslint/utils/dist/ast-utils/eslint-utils/ReferenceTracker.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ReferenceTracker = void 0;
    /* eslint-disable @typescript-eslint/no-namespace */
    const eslintUtils = __importStar(require(316) /* @eslint-community/eslint-utils */);
    const ReferenceTrackerREAD = eslintUtils.ReferenceTracker.READ;
    const ReferenceTrackerCALL = eslintUtils.ReferenceTracker.CALL;
    const ReferenceTrackerCONSTRUCT = eslintUtils.ReferenceTracker.CONSTRUCT;
    const ReferenceTrackerESM = eslintUtils.ReferenceTracker.ESM;
    /**
     * The tracker for references. This provides reference tracking for global variables, CommonJS modules, and ES modules.
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/scope-utils.html#referencetracker-class}
     */
    const ReferenceTracker = eslintUtils.ReferenceTracker;
    exports.ReferenceTracker = ReferenceTracker;
    
},
/* @typescript-eslint/utils/dist/ast-utils/eslint-utils/scopeAnalysis.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getInnermostScope = exports.findVariable = void 0;
    const eslintUtils = __importStar(require(316) /* @eslint-community/eslint-utils */);
    /**
     * Get the variable of a given name.
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/scope-utils.html#findvariable}
     */
    const findVariable = eslintUtils.findVariable;
    exports.findVariable = findVariable;
    /**
     * Get the innermost scope which contains a given node.
     *
     * @see {@link https://eslint-community.github.io/eslint-utils/api/scope-utils.html#getinnermostscope}
     * @returns The innermost scope which contains the given node.
     * If such scope doesn't exist then it returns the 1st argument `initialScope`.
     */
    const getInnermostScope = eslintUtils.getInnermostScope;
    exports.getInnermostScope = getInnermostScope;
    
},
/* @typescript-eslint/utils/dist/ast-utils/helpers.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isNotTokenOfTypeWithConditions = exports.isTokenOfTypeWithConditions = exports.isNodeOfTypeWithConditions = exports.isNodeOfTypes = exports.isNodeOfType = void 0;
    const isNodeOfType = (nodeType) => (node) => (node === null || node === void 0 ? void 0 : node.type) === nodeType;
    exports.isNodeOfType = isNodeOfType;
    const isNodeOfTypes = (nodeTypes) => (node) => !!node && nodeTypes.includes(node.type);
    exports.isNodeOfTypes = isNodeOfTypes;
    const isNodeOfTypeWithConditions = (nodeType, conditions) => {
        const entries = Object.entries(conditions);
        return (node) => (node === null || node === void 0 ? void 0 : node.type) === nodeType &&
            entries.every(([key, value]) => node[key] === value);
    };
    exports.isNodeOfTypeWithConditions = isNodeOfTypeWithConditions;
    const isTokenOfTypeWithConditions = (tokenType, conditions) => {
        const entries = Object.entries(conditions);
        return (token) => (token === null || token === void 0 ? void 0 : token.type) === tokenType &&
            entries.every(([key, value]) => token[key] === value);
    };
    exports.isTokenOfTypeWithConditions = isTokenOfTypeWithConditions;
    const isNotTokenOfTypeWithConditions = (tokenType, conditions) => (token) => !(0, exports.isTokenOfTypeWithConditions)(tokenType, conditions)(token);
    exports.isNotTokenOfTypeWithConditions = isNotTokenOfTypeWithConditions;
    
},
/* @typescript-eslint/utils/dist/ast-utils/misc.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.LINEBREAK_MATCHER = exports.isTokenOnSameLine = void 0;
    const LINEBREAK_MATCHER = /\r\n|[\r\n\u2028\u2029]/;
    exports.LINEBREAK_MATCHER = LINEBREAK_MATCHER;
    /**
     * Determines whether two adjacent tokens are on the same line
     */
    function isTokenOnSameLine(left, right) {
        return left.loc.end.line === right.loc.start.line;
    }
    exports.isTokenOnSameLine = isTokenOnSameLine;
    
},
/* @typescript-eslint/utils/dist/ast-utils/predicates.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isVariableDeclarator = exports.isTypeKeyword = exports.isTypeAssertion = exports.isTSFunctionType = exports.isTSConstructorType = exports.isSetter = exports.isOptionalCallExpression = exports.isOptionalChainPunctuator = exports.isNotOptionalChainPunctuator = exports.isNotNonNullAssertionPunctuator = exports.isNonNullAssertionPunctuator = exports.isLogicalOrOperator = exports.isLoop = exports.isImportKeyword = exports.isIdentifier = exports.isFunctionType = exports.isFunctionOrFunctionType = exports.isFunction = exports.isClassOrTypeElement = exports.isConstructor = exports.isAwaitKeyword = exports.isAwaitExpression = void 0;
    const ts_estree_1 = require(788) /* ../ts-estree */;
    const helpers_1 = require(785) /* ./helpers */;
    const isOptionalChainPunctuator = (0, helpers_1.isTokenOfTypeWithConditions)(ts_estree_1.AST_TOKEN_TYPES.Punctuator, { value: '?.' });
    exports.isOptionalChainPunctuator = isOptionalChainPunctuator;
    const isNotOptionalChainPunctuator = (0, helpers_1.isNotTokenOfTypeWithConditions)(ts_estree_1.AST_TOKEN_TYPES.Punctuator, { value: '?.' });
    exports.isNotOptionalChainPunctuator = isNotOptionalChainPunctuator;
    const isNonNullAssertionPunctuator = (0, helpers_1.isTokenOfTypeWithConditions)(ts_estree_1.AST_TOKEN_TYPES.Punctuator, { value: '!' });
    exports.isNonNullAssertionPunctuator = isNonNullAssertionPunctuator;
    const isNotNonNullAssertionPunctuator = (0, helpers_1.isNotTokenOfTypeWithConditions)(ts_estree_1.AST_TOKEN_TYPES.Punctuator, { value: '!' });
    exports.isNotNonNullAssertionPunctuator = isNotNonNullAssertionPunctuator;
    /**
     * Returns true if and only if the node represents: foo?.() or foo.bar?.()
     */
    const isOptionalCallExpression = (0, helpers_1.isNodeOfTypeWithConditions)(ts_estree_1.AST_NODE_TYPES.CallExpression, 
    // this flag means the call expression itself is option
    // i.e. it is foo.bar?.() and not foo?.bar()
    { optional: true });
    exports.isOptionalCallExpression = isOptionalCallExpression;
    /**
     * Returns true if and only if the node represents logical OR
     */
    const isLogicalOrOperator = (0, helpers_1.isNodeOfTypeWithConditions)(ts_estree_1.AST_NODE_TYPES.LogicalExpression, { operator: '||' });
    exports.isLogicalOrOperator = isLogicalOrOperator;
    /**
     * Checks if a node is a type assertion:
     * ```
     * x as foo
     * <foo>x
     * ```
     */
    const isTypeAssertion = (0, helpers_1.isNodeOfTypes)([
        ts_estree_1.AST_NODE_TYPES.TSAsExpression,
        ts_estree_1.AST_NODE_TYPES.TSTypeAssertion,
    ]);
    exports.isTypeAssertion = isTypeAssertion;
    const isVariableDeclarator = (0, helpers_1.isNodeOfType)(ts_estree_1.AST_NODE_TYPES.VariableDeclarator);
    exports.isVariableDeclarator = isVariableDeclarator;
    const functionTypes = [
        ts_estree_1.AST_NODE_TYPES.ArrowFunctionExpression,
        ts_estree_1.AST_NODE_TYPES.FunctionDeclaration,
        ts_estree_1.AST_NODE_TYPES.FunctionExpression,
    ];
    const isFunction = (0, helpers_1.isNodeOfTypes)(functionTypes);
    exports.isFunction = isFunction;
    const functionTypeTypes = [
        ts_estree_1.AST_NODE_TYPES.TSCallSignatureDeclaration,
        ts_estree_1.AST_NODE_TYPES.TSConstructorType,
        ts_estree_1.AST_NODE_TYPES.TSConstructSignatureDeclaration,
        ts_estree_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression,
        ts_estree_1.AST_NODE_TYPES.TSFunctionType,
        ts_estree_1.AST_NODE_TYPES.TSMethodSignature,
    ];
    const isFunctionType = (0, helpers_1.isNodeOfTypes)(functionTypeTypes);
    exports.isFunctionType = isFunctionType;
    const isFunctionOrFunctionType = (0, helpers_1.isNodeOfTypes)([
        ...functionTypes,
        ...functionTypeTypes,
    ]);
    exports.isFunctionOrFunctionType = isFunctionOrFunctionType;
    const isTSFunctionType = (0, helpers_1.isNodeOfType)(ts_estree_1.AST_NODE_TYPES.TSFunctionType);
    exports.isTSFunctionType = isTSFunctionType;
    const isTSConstructorType = (0, helpers_1.isNodeOfType)(ts_estree_1.AST_NODE_TYPES.TSConstructorType);
    exports.isTSConstructorType = isTSConstructorType;
    const isClassOrTypeElement = (0, helpers_1.isNodeOfTypes)([
        // ClassElement
        ts_estree_1.AST_NODE_TYPES.PropertyDefinition,
        ts_estree_1.AST_NODE_TYPES.FunctionExpression,
        ts_estree_1.AST_NODE_TYPES.MethodDefinition,
        ts_estree_1.AST_NODE_TYPES.TSAbstractPropertyDefinition,
        ts_estree_1.AST_NODE_TYPES.TSAbstractMethodDefinition,
        ts_estree_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression,
        ts_estree_1.AST_NODE_TYPES.TSIndexSignature,
        // TypeElement
        ts_estree_1.AST_NODE_TYPES.TSCallSignatureDeclaration,
        ts_estree_1.AST_NODE_TYPES.TSConstructSignatureDeclaration,
        // AST_NODE_TYPES.TSIndexSignature,
        ts_estree_1.AST_NODE_TYPES.TSMethodSignature,
        ts_estree_1.AST_NODE_TYPES.TSPropertySignature,
    ]);
    exports.isClassOrTypeElement = isClassOrTypeElement;
    /**
     * Checks if a node is a constructor method.
     */
    const isConstructor = (0, helpers_1.isNodeOfTypeWithConditions)(ts_estree_1.AST_NODE_TYPES.MethodDefinition, { kind: 'constructor' });
    exports.isConstructor = isConstructor;
    /**
     * Checks if a node is a setter method.
     */
    function isSetter(node) {
        return (!!node &&
            (node.type === ts_estree_1.AST_NODE_TYPES.MethodDefinition ||
                node.type === ts_estree_1.AST_NODE_TYPES.Property) &&
            node.kind === 'set');
    }
    exports.isSetter = isSetter;
    const isIdentifier = (0, helpers_1.isNodeOfType)(ts_estree_1.AST_NODE_TYPES.Identifier);
    exports.isIdentifier = isIdentifier;
    /**
     * Checks if a node represents an `await …` expression.
     */
    const isAwaitExpression = (0, helpers_1.isNodeOfType)(ts_estree_1.AST_NODE_TYPES.AwaitExpression);
    exports.isAwaitExpression = isAwaitExpression;
    /**
     * Checks if a possible token is the `await` keyword.
     */
    const isAwaitKeyword = (0, helpers_1.isTokenOfTypeWithConditions)(ts_estree_1.AST_TOKEN_TYPES.Identifier, {
        value: 'await',
    });
    exports.isAwaitKeyword = isAwaitKeyword;
    /**
     * Checks if a possible token is the `type` keyword.
     */
    const isTypeKeyword = (0, helpers_1.isTokenOfTypeWithConditions)(ts_estree_1.AST_TOKEN_TYPES.Identifier, {
        value: 'type',
    });
    exports.isTypeKeyword = isTypeKeyword;
    /**
     * Checks if a possible token is the `import` keyword.
     */
    const isImportKeyword = (0, helpers_1.isTokenOfTypeWithConditions)(ts_estree_1.AST_TOKEN_TYPES.Keyword, {
        value: 'import',
    });
    exports.isImportKeyword = isImportKeyword;
    const isLoop = (0, helpers_1.isNodeOfTypes)([
        ts_estree_1.AST_NODE_TYPES.DoWhileStatement,
        ts_estree_1.AST_NODE_TYPES.ForStatement,
        ts_estree_1.AST_NODE_TYPES.ForInStatement,
        ts_estree_1.AST_NODE_TYPES.ForOfStatement,
        ts_estree_1.AST_NODE_TYPES.WhileStatement,
    ]);
    exports.isLoop = isLoop;
    
},
/* @typescript-eslint/utils/dist/ts-estree.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // for convenience's sake - export the types directly from here so consumers
    // don't need to reference/install both packages in their code
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TSESTree = exports.AST_TOKEN_TYPES = exports.AST_NODE_TYPES = void 0;
    var types_1 = require(789) /* @typescript-eslint/types */;
    Object.defineProperty(exports, "AST_NODE_TYPES", { enumerable: true, get: function () { return types_1.AST_NODE_TYPES; } });
    Object.defineProperty(exports, "AST_TOKEN_TYPES", { enumerable: true, get: function () { return types_1.AST_TOKEN_TYPES; } });
    Object.defineProperty(exports, "TSESTree", { enumerable: true, get: function () { return types_1.TSESTree; } });
    
},
/* @typescript-eslint/types/dist/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AST_TOKEN_TYPES = exports.AST_NODE_TYPES = void 0;
    var ast_spec_1 = require(790) /* ./generated/ast-spec */;
    Object.defineProperty(exports, "AST_NODE_TYPES", { enumerable: true, get: function () { return ast_spec_1.AST_NODE_TYPES; } });
    Object.defineProperty(exports, "AST_TOKEN_TYPES", { enumerable: true, get: function () { return ast_spec_1.AST_TOKEN_TYPES; } });
    __exportStar(require(791) /* ./lib */, exports);
    __exportStar(require(792) /* ./parser-options */, exports);
    __exportStar(require(793) /* ./ts-estree */, exports);
    
},
/* @typescript-eslint/types/dist/generated/ast-spec.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /**********************************************
     *      DO NOT MODIFY THIS FILE MANUALLY      *
     *                                            *
     *  THIS FILE HAS BEEN COPIED FROM ast-spec.  *
     * ANY CHANGES WILL BE LOST ON THE NEXT BUILD *
     *                                            *
     *   MAKE CHANGES TO ast-spec AND THEN RUN    *
     *                 yarn build                 *
     **********************************************/
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AST_TOKEN_TYPES = exports.AST_NODE_TYPES = void 0;
    var AST_NODE_TYPES;
    (function (AST_NODE_TYPES) {
        AST_NODE_TYPES["AccessorProperty"] = "AccessorProperty";
        AST_NODE_TYPES["ArrayExpression"] = "ArrayExpression";
        AST_NODE_TYPES["ArrayPattern"] = "ArrayPattern";
        AST_NODE_TYPES["ArrowFunctionExpression"] = "ArrowFunctionExpression";
        AST_NODE_TYPES["AssignmentExpression"] = "AssignmentExpression";
        AST_NODE_TYPES["AssignmentPattern"] = "AssignmentPattern";
        AST_NODE_TYPES["AwaitExpression"] = "AwaitExpression";
        AST_NODE_TYPES["BinaryExpression"] = "BinaryExpression";
        AST_NODE_TYPES["BlockStatement"] = "BlockStatement";
        AST_NODE_TYPES["BreakStatement"] = "BreakStatement";
        AST_NODE_TYPES["CallExpression"] = "CallExpression";
        AST_NODE_TYPES["CatchClause"] = "CatchClause";
        AST_NODE_TYPES["ChainExpression"] = "ChainExpression";
        AST_NODE_TYPES["ClassBody"] = "ClassBody";
        AST_NODE_TYPES["ClassDeclaration"] = "ClassDeclaration";
        AST_NODE_TYPES["ClassExpression"] = "ClassExpression";
        AST_NODE_TYPES["ConditionalExpression"] = "ConditionalExpression";
        AST_NODE_TYPES["ContinueStatement"] = "ContinueStatement";
        AST_NODE_TYPES["DebuggerStatement"] = "DebuggerStatement";
        AST_NODE_TYPES["Decorator"] = "Decorator";
        AST_NODE_TYPES["DoWhileStatement"] = "DoWhileStatement";
        AST_NODE_TYPES["EmptyStatement"] = "EmptyStatement";
        AST_NODE_TYPES["ExportAllDeclaration"] = "ExportAllDeclaration";
        AST_NODE_TYPES["ExportDefaultDeclaration"] = "ExportDefaultDeclaration";
        AST_NODE_TYPES["ExportNamedDeclaration"] = "ExportNamedDeclaration";
        AST_NODE_TYPES["ExportSpecifier"] = "ExportSpecifier";
        AST_NODE_TYPES["ExpressionStatement"] = "ExpressionStatement";
        AST_NODE_TYPES["ForInStatement"] = "ForInStatement";
        AST_NODE_TYPES["ForOfStatement"] = "ForOfStatement";
        AST_NODE_TYPES["ForStatement"] = "ForStatement";
        AST_NODE_TYPES["FunctionDeclaration"] = "FunctionDeclaration";
        AST_NODE_TYPES["FunctionExpression"] = "FunctionExpression";
        AST_NODE_TYPES["Identifier"] = "Identifier";
        AST_NODE_TYPES["IfStatement"] = "IfStatement";
        AST_NODE_TYPES["ImportAttribute"] = "ImportAttribute";
        AST_NODE_TYPES["ImportDeclaration"] = "ImportDeclaration";
        AST_NODE_TYPES["ImportDefaultSpecifier"] = "ImportDefaultSpecifier";
        AST_NODE_TYPES["ImportExpression"] = "ImportExpression";
        AST_NODE_TYPES["ImportNamespaceSpecifier"] = "ImportNamespaceSpecifier";
        AST_NODE_TYPES["ImportSpecifier"] = "ImportSpecifier";
        AST_NODE_TYPES["JSXAttribute"] = "JSXAttribute";
        AST_NODE_TYPES["JSXClosingElement"] = "JSXClosingElement";
        AST_NODE_TYPES["JSXClosingFragment"] = "JSXClosingFragment";
        AST_NODE_TYPES["JSXElement"] = "JSXElement";
        AST_NODE_TYPES["JSXEmptyExpression"] = "JSXEmptyExpression";
        AST_NODE_TYPES["JSXExpressionContainer"] = "JSXExpressionContainer";
        AST_NODE_TYPES["JSXFragment"] = "JSXFragment";
        AST_NODE_TYPES["JSXIdentifier"] = "JSXIdentifier";
        AST_NODE_TYPES["JSXMemberExpression"] = "JSXMemberExpression";
        AST_NODE_TYPES["JSXNamespacedName"] = "JSXNamespacedName";
        AST_NODE_TYPES["JSXOpeningElement"] = "JSXOpeningElement";
        AST_NODE_TYPES["JSXOpeningFragment"] = "JSXOpeningFragment";
        AST_NODE_TYPES["JSXSpreadAttribute"] = "JSXSpreadAttribute";
        AST_NODE_TYPES["JSXSpreadChild"] = "JSXSpreadChild";
        AST_NODE_TYPES["JSXText"] = "JSXText";
        AST_NODE_TYPES["LabeledStatement"] = "LabeledStatement";
        AST_NODE_TYPES["Literal"] = "Literal";
        AST_NODE_TYPES["LogicalExpression"] = "LogicalExpression";
        AST_NODE_TYPES["MemberExpression"] = "MemberExpression";
        AST_NODE_TYPES["MetaProperty"] = "MetaProperty";
        AST_NODE_TYPES["MethodDefinition"] = "MethodDefinition";
        AST_NODE_TYPES["NewExpression"] = "NewExpression";
        AST_NODE_TYPES["ObjectExpression"] = "ObjectExpression";
        AST_NODE_TYPES["ObjectPattern"] = "ObjectPattern";
        AST_NODE_TYPES["PrivateIdentifier"] = "PrivateIdentifier";
        AST_NODE_TYPES["Program"] = "Program";
        AST_NODE_TYPES["Property"] = "Property";
        AST_NODE_TYPES["PropertyDefinition"] = "PropertyDefinition";
        AST_NODE_TYPES["RestElement"] = "RestElement";
        AST_NODE_TYPES["ReturnStatement"] = "ReturnStatement";
        AST_NODE_TYPES["SequenceExpression"] = "SequenceExpression";
        AST_NODE_TYPES["SpreadElement"] = "SpreadElement";
        AST_NODE_TYPES["StaticBlock"] = "StaticBlock";
        AST_NODE_TYPES["Super"] = "Super";
        AST_NODE_TYPES["SwitchCase"] = "SwitchCase";
        AST_NODE_TYPES["SwitchStatement"] = "SwitchStatement";
        AST_NODE_TYPES["TaggedTemplateExpression"] = "TaggedTemplateExpression";
        AST_NODE_TYPES["TemplateElement"] = "TemplateElement";
        AST_NODE_TYPES["TemplateLiteral"] = "TemplateLiteral";
        AST_NODE_TYPES["ThisExpression"] = "ThisExpression";
        AST_NODE_TYPES["ThrowStatement"] = "ThrowStatement";
        AST_NODE_TYPES["TryStatement"] = "TryStatement";
        AST_NODE_TYPES["UnaryExpression"] = "UnaryExpression";
        AST_NODE_TYPES["UpdateExpression"] = "UpdateExpression";
        AST_NODE_TYPES["VariableDeclaration"] = "VariableDeclaration";
        AST_NODE_TYPES["VariableDeclarator"] = "VariableDeclarator";
        AST_NODE_TYPES["WhileStatement"] = "WhileStatement";
        AST_NODE_TYPES["WithStatement"] = "WithStatement";
        AST_NODE_TYPES["YieldExpression"] = "YieldExpression";
        /**
         * TS-prefixed nodes
         */
        AST_NODE_TYPES["TSAbstractAccessorProperty"] = "TSAbstractAccessorProperty";
        AST_NODE_TYPES["TSAbstractKeyword"] = "TSAbstractKeyword";
        AST_NODE_TYPES["TSAbstractMethodDefinition"] = "TSAbstractMethodDefinition";
        AST_NODE_TYPES["TSAbstractPropertyDefinition"] = "TSAbstractPropertyDefinition";
        AST_NODE_TYPES["TSAnyKeyword"] = "TSAnyKeyword";
        AST_NODE_TYPES["TSArrayType"] = "TSArrayType";
        AST_NODE_TYPES["TSAsExpression"] = "TSAsExpression";
        AST_NODE_TYPES["TSAsyncKeyword"] = "TSAsyncKeyword";
        AST_NODE_TYPES["TSBigIntKeyword"] = "TSBigIntKeyword";
        AST_NODE_TYPES["TSBooleanKeyword"] = "TSBooleanKeyword";
        AST_NODE_TYPES["TSCallSignatureDeclaration"] = "TSCallSignatureDeclaration";
        AST_NODE_TYPES["TSClassImplements"] = "TSClassImplements";
        AST_NODE_TYPES["TSConditionalType"] = "TSConditionalType";
        AST_NODE_TYPES["TSConstructorType"] = "TSConstructorType";
        AST_NODE_TYPES["TSConstructSignatureDeclaration"] = "TSConstructSignatureDeclaration";
        AST_NODE_TYPES["TSDeclareFunction"] = "TSDeclareFunction";
        AST_NODE_TYPES["TSDeclareKeyword"] = "TSDeclareKeyword";
        AST_NODE_TYPES["TSEmptyBodyFunctionExpression"] = "TSEmptyBodyFunctionExpression";
        AST_NODE_TYPES["TSEnumDeclaration"] = "TSEnumDeclaration";
        AST_NODE_TYPES["TSEnumMember"] = "TSEnumMember";
        AST_NODE_TYPES["TSExportAssignment"] = "TSExportAssignment";
        AST_NODE_TYPES["TSExportKeyword"] = "TSExportKeyword";
        AST_NODE_TYPES["TSExternalModuleReference"] = "TSExternalModuleReference";
        AST_NODE_TYPES["TSFunctionType"] = "TSFunctionType";
        AST_NODE_TYPES["TSInstantiationExpression"] = "TSInstantiationExpression";
        AST_NODE_TYPES["TSImportEqualsDeclaration"] = "TSImportEqualsDeclaration";
        AST_NODE_TYPES["TSImportType"] = "TSImportType";
        AST_NODE_TYPES["TSIndexedAccessType"] = "TSIndexedAccessType";
        AST_NODE_TYPES["TSIndexSignature"] = "TSIndexSignature";
        AST_NODE_TYPES["TSInferType"] = "TSInferType";
        AST_NODE_TYPES["TSInterfaceBody"] = "TSInterfaceBody";
        AST_NODE_TYPES["TSInterfaceDeclaration"] = "TSInterfaceDeclaration";
        AST_NODE_TYPES["TSInterfaceHeritage"] = "TSInterfaceHeritage";
        AST_NODE_TYPES["TSIntersectionType"] = "TSIntersectionType";
        AST_NODE_TYPES["TSIntrinsicKeyword"] = "TSIntrinsicKeyword";
        AST_NODE_TYPES["TSLiteralType"] = "TSLiteralType";
        AST_NODE_TYPES["TSMappedType"] = "TSMappedType";
        AST_NODE_TYPES["TSMethodSignature"] = "TSMethodSignature";
        AST_NODE_TYPES["TSModuleBlock"] = "TSModuleBlock";
        AST_NODE_TYPES["TSModuleDeclaration"] = "TSModuleDeclaration";
        AST_NODE_TYPES["TSNamedTupleMember"] = "TSNamedTupleMember";
        AST_NODE_TYPES["TSNamespaceExportDeclaration"] = "TSNamespaceExportDeclaration";
        AST_NODE_TYPES["TSNeverKeyword"] = "TSNeverKeyword";
        AST_NODE_TYPES["TSNonNullExpression"] = "TSNonNullExpression";
        AST_NODE_TYPES["TSNullKeyword"] = "TSNullKeyword";
        AST_NODE_TYPES["TSNumberKeyword"] = "TSNumberKeyword";
        AST_NODE_TYPES["TSObjectKeyword"] = "TSObjectKeyword";
        AST_NODE_TYPES["TSOptionalType"] = "TSOptionalType";
        AST_NODE_TYPES["TSParameterProperty"] = "TSParameterProperty";
        AST_NODE_TYPES["TSPrivateKeyword"] = "TSPrivateKeyword";
        AST_NODE_TYPES["TSPropertySignature"] = "TSPropertySignature";
        AST_NODE_TYPES["TSProtectedKeyword"] = "TSProtectedKeyword";
        AST_NODE_TYPES["TSPublicKeyword"] = "TSPublicKeyword";
        AST_NODE_TYPES["TSQualifiedName"] = "TSQualifiedName";
        AST_NODE_TYPES["TSReadonlyKeyword"] = "TSReadonlyKeyword";
        AST_NODE_TYPES["TSRestType"] = "TSRestType";
        AST_NODE_TYPES["TSSatisfiesExpression"] = "TSSatisfiesExpression";
        AST_NODE_TYPES["TSStaticKeyword"] = "TSStaticKeyword";
        AST_NODE_TYPES["TSStringKeyword"] = "TSStringKeyword";
        AST_NODE_TYPES["TSSymbolKeyword"] = "TSSymbolKeyword";
        AST_NODE_TYPES["TSTemplateLiteralType"] = "TSTemplateLiteralType";
        AST_NODE_TYPES["TSThisType"] = "TSThisType";
        AST_NODE_TYPES["TSTupleType"] = "TSTupleType";
        AST_NODE_TYPES["TSTypeAliasDeclaration"] = "TSTypeAliasDeclaration";
        AST_NODE_TYPES["TSTypeAnnotation"] = "TSTypeAnnotation";
        AST_NODE_TYPES["TSTypeAssertion"] = "TSTypeAssertion";
        AST_NODE_TYPES["TSTypeLiteral"] = "TSTypeLiteral";
        AST_NODE_TYPES["TSTypeOperator"] = "TSTypeOperator";
        AST_NODE_TYPES["TSTypeParameter"] = "TSTypeParameter";
        AST_NODE_TYPES["TSTypeParameterDeclaration"] = "TSTypeParameterDeclaration";
        AST_NODE_TYPES["TSTypeParameterInstantiation"] = "TSTypeParameterInstantiation";
        AST_NODE_TYPES["TSTypePredicate"] = "TSTypePredicate";
        AST_NODE_TYPES["TSTypeQuery"] = "TSTypeQuery";
        AST_NODE_TYPES["TSTypeReference"] = "TSTypeReference";
        AST_NODE_TYPES["TSUndefinedKeyword"] = "TSUndefinedKeyword";
        AST_NODE_TYPES["TSUnionType"] = "TSUnionType";
        AST_NODE_TYPES["TSUnknownKeyword"] = "TSUnknownKeyword";
        AST_NODE_TYPES["TSVoidKeyword"] = "TSVoidKeyword";
    })(AST_NODE_TYPES = exports.AST_NODE_TYPES || (exports.AST_NODE_TYPES = {}));
    var AST_TOKEN_TYPES;
    (function (AST_TOKEN_TYPES) {
        AST_TOKEN_TYPES["Boolean"] = "Boolean";
        AST_TOKEN_TYPES["Identifier"] = "Identifier";
        AST_TOKEN_TYPES["JSXIdentifier"] = "JSXIdentifier";
        AST_TOKEN_TYPES["JSXText"] = "JSXText";
        AST_TOKEN_TYPES["Keyword"] = "Keyword";
        AST_TOKEN_TYPES["Null"] = "Null";
        AST_TOKEN_TYPES["Numeric"] = "Numeric";
        AST_TOKEN_TYPES["Punctuator"] = "Punctuator";
        AST_TOKEN_TYPES["RegularExpression"] = "RegularExpression";
        AST_TOKEN_TYPES["String"] = "String";
        AST_TOKEN_TYPES["Template"] = "Template";
        AST_TOKEN_TYPES["Block"] = "Block";
        AST_TOKEN_TYPES["Line"] = "Line";
    })(AST_TOKEN_TYPES = exports.AST_TOKEN_TYPES || (exports.AST_TOKEN_TYPES = {}));
    
},
/* @typescript-eslint/types/dist/lib.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/types/dist/parser-options.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/types/dist/ts-estree.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TSESTree = void 0;
    exports.TSESTree = __importStar(require(790) /* ./generated/ast-spec */);
    
},
/* @typescript-eslint/utils/dist/eslint-utils/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    __exportStar(require(795) /* ./applyDefault */, exports);
    __exportStar(require(797) /* ./batchedSingleLineTests */, exports);
    __exportStar(require(798) /* ./getParserServices */, exports);
    __exportStar(require(799) /* ./InferTypesFromRule */, exports);
    __exportStar(require(800) /* ./RuleCreator */, exports);
    __exportStar(require(801) /* ./rule-tester/RuleTester */, exports);
    __exportStar(require(796) /* ./deepMerge */, exports);
    __exportStar(require(851) /* ./nullThrows */, exports);
    
},
/* @typescript-eslint/utils/dist/eslint-utils/applyDefault.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.applyDefault = void 0;
    const deepMerge_1 = require(796) /* ./deepMerge */;
    /**
     * Pure function - doesn't mutate either parameter!
     * Uses the default options and overrides with the options provided by the user
     * @param defaultOptions the defaults
     * @param userOptions the user opts
     * @returns the options with defaults
     */
    function applyDefault(defaultOptions, userOptions) {
        // clone defaults
        const options = JSON.parse(JSON.stringify(defaultOptions));
        if (userOptions == null) {
            return options;
        }
        // For avoiding the type error
        //   `This expression is not callable. Type 'unknown' has no call signatures.ts(2349)`
        options.forEach((opt, i) => {
            if (userOptions[i] !== undefined) {
                const userOpt = userOptions[i];
                if ((0, deepMerge_1.isObjectNotArray)(userOpt) && (0, deepMerge_1.isObjectNotArray)(opt)) {
                    options[i] = (0, deepMerge_1.deepMerge)(opt, userOpt);
                }
                else {
                    options[i] = userOpt;
                }
            }
        });
        return options;
    }
    exports.applyDefault = applyDefault;
    
},
/* @typescript-eslint/utils/dist/eslint-utils/deepMerge.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isObjectNotArray = exports.deepMerge = void 0;
    /**
     * Check if the variable contains an object strictly rejecting arrays
     * @param obj an object
     * @returns `true` if obj is an object
     */
    function isObjectNotArray(obj) {
        return typeof obj === 'object' && !Array.isArray(obj);
    }
    exports.isObjectNotArray = isObjectNotArray;
    /**
     * Pure function - doesn't mutate either parameter!
     * Merges two objects together deeply, overwriting the properties in first with the properties in second
     * @param first The first object
     * @param second The second object
     * @returns a new object
     */
    function deepMerge(first = {}, second = {}) {
        // get the unique set of keys across both objects
        const keys = new Set(Object.keys(first).concat(Object.keys(second)));
        return Array.from(keys).reduce((acc, key) => {
            const firstHasKey = key in first;
            const secondHasKey = key in second;
            const firstValue = first[key];
            const secondValue = second[key];
            if (firstHasKey && secondHasKey) {
                if (isObjectNotArray(firstValue) && isObjectNotArray(secondValue)) {
                    // object type
                    acc[key] = deepMerge(firstValue, secondValue);
                }
                else {
                    // value type
                    acc[key] = secondValue;
                }
            }
            else if (firstHasKey) {
                acc[key] = firstValue;
            }
            else {
                acc[key] = secondValue;
            }
            return acc;
        }, {});
    }
    exports.deepMerge = deepMerge;
    
},
/* @typescript-eslint/utils/dist/eslint-utils/batchedSingleLineTests.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.batchedSingleLineTests = void 0;
    function batchedSingleLineTests(options) {
        // -- eslint counts lines from 1
        const lineOffset = options.code.startsWith('\n') ? 2 : 1;
        const output = 'output' in options && options.output
            ? options.output.trim().split('\n')
            : null;
        return options.code
            .trim()
            .split('\n')
            .map((code, i) => {
            const lineNum = i + lineOffset;
            const errors = 'errors' in options
                ? options.errors.filter(e => e.line === lineNum)
                : [];
            const returnVal = Object.assign(Object.assign({}, options), { code, errors: errors.map(e => (Object.assign(Object.assign({}, e), { line: 1 }))) });
            if (output === null || output === void 0 ? void 0 : output[i]) {
                return Object.assign(Object.assign({}, returnVal), { output: output[i] });
            }
            return returnVal;
        });
    }
    exports.batchedSingleLineTests = batchedSingleLineTests;
    
},
/* @typescript-eslint/utils/dist/eslint-utils/getParserServices.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getParserServices = void 0;
    const ERROR_MESSAGE = 'You have used a rule which requires parserServices to be generated. You must therefore provide a value for the "parserOptions.project" property for @typescript-eslint/parser.';
    /**
     * Try to retrieve typescript parser service from context
     */
    function getParserServices(context, allowWithoutFullTypeInformation = false) {
        var _a, _b;
        // backwards compatibility check
        // old versions of the parser would not return any parserServices unless parserOptions.project was set
        if (!((_a = context.parserServices) === null || _a === void 0 ? void 0 : _a.program) ||
            !context.parserServices.esTreeNodeToTSNodeMap ||
            !context.parserServices.tsNodeToESTreeNodeMap) {
            throw new Error(ERROR_MESSAGE);
        }
        const hasFullTypeInformation = (_b = context.parserServices.hasFullTypeInformation) !== null && _b !== void 0 ? _b :
            /* backwards compatible */ true;
        // if a rule requires full type information, then hard fail if it doesn't exist
        // this forces the user to supply parserOptions.project
        if (!hasFullTypeInformation && !allowWithoutFullTypeInformation) {
            throw new Error(ERROR_MESSAGE);
        }
        return context.parserServices;
    }
    exports.getParserServices = getParserServices;
    
},
/* @typescript-eslint/utils/dist/eslint-utils/InferTypesFromRule.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/utils/dist/eslint-utils/RuleCreator.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __rest = (this && this.__rest) || function (s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.RuleCreator = void 0;
    const applyDefault_1 = require(795) /* ./applyDefault */;
    /**
     * Creates reusable function to create rules with default options and docs URLs.
     *
     * @param urlCreator Creates a documentation URL for a given rule name.
     * @returns Function to create a rule with the docs URL format.
     */
    function RuleCreator(urlCreator) {
        // This function will get much easier to call when this is merged https://github.com/Microsoft/TypeScript/pull/26349
        // TODO - when the above PR lands; add type checking for the context.report `data` property
        return function createNamedRule(_a) {
            var { name, meta } = _a, rule = __rest(_a, ["name", "meta"]);
            return createRule(Object.assign({ meta: Object.assign(Object.assign({}, meta), { docs: Object.assign(Object.assign({}, meta.docs), { url: urlCreator(name) }) }) }, rule));
        };
    }
    exports.RuleCreator = RuleCreator;
    /**
     * Creates a well-typed TSESLint custom ESLint rule without a docs URL.
     *
     * @returns Well-typed TSESLint custom ESLint rule.
     * @remarks It is generally better to provide a docs URL function to RuleCreator.
     */
    function createRule({ create, defaultOptions, meta, }) {
        return {
            create(context) {
                const optionsWithDefault = (0, applyDefault_1.applyDefault)(defaultOptions, context.options);
                return create(context, optionsWithDefault);
            },
            defaultOptions,
            meta,
        };
    }
    RuleCreator.withoutDocs = createRule;
    
},
/* @typescript-eslint/utils/dist/eslint-utils/rule-tester/RuleTester.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __rest = (this && this.__rest) || function (s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    var _a, _RuleTester_baseOptions, _RuleTester_afterAll;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.RuleTester = exports.noFormat = void 0;
    const assert_1 = __importDefault(require("assert"));
    const package_json_1 = require(221) /* eslint/package.json */;
    const path = __importStar(require("path"));
    const semver = __importStar(require(802) /* semver */);
    const BaseRuleTester = __importStar(require(849) /* ../../ts-eslint/RuleTester */);
    const deepMerge_1 = require(796) /* ../deepMerge */;
    const dependencyConstraints_1 = require(850) /* ./dependencyConstraints */;
    const TS_ESLINT_PARSER = '@typescript-eslint/parser';
    const ERROR_MESSAGE = `Do not set the parser at the test level unless you want to use a parser other than ${TS_ESLINT_PARSER}`;
    function isDescribeWithSkip(value) {
        return (typeof value === 'object' &&
            value != null &&
            'skip' in value &&
            typeof value.skip === 'function');
    }
    class RuleTester extends BaseRuleTester.RuleTester {
        /**
         * If you supply a value to this property, the rule tester will call this instead of using the version defined on
         * the global namespace.
         */
        static get afterAll() {
            var _b;
            return ((_b = __classPrivateFieldGet(this, _a, "f", _RuleTester_afterAll)) !== null && _b !== void 0 ? _b : (typeof afterAll === 'function' ? afterAll : () => { }));
        }
        static set afterAll(value) {
            __classPrivateFieldSet(this, _a, value, "f", _RuleTester_afterAll);
        }
        get staticThis() {
            // the cast here is due to https://github.com/microsoft/TypeScript/issues/3841
            return this.constructor;
        }
        constructor(baseOptions) {
            var _b, _c;
            // eslint will hard-error if you include non-standard top-level properties
            const { dependencyConstraints: _ } = baseOptions, baseOptionsSafeForESLint = __rest(baseOptions, ["dependencyConstraints"]);
            super(Object.assign(Object.assign({}, baseOptionsSafeForESLint), { parserOptions: Object.assign(Object.assign({}, baseOptions.parserOptions), { warnOnUnsupportedTypeScriptVersion: (_c = (_b = baseOptions.parserOptions) === null || _b === void 0 ? void 0 : _b.warnOnUnsupportedTypeScriptVersion) !== null && _c !== void 0 ? _c : false }),
                // as of eslint 6 you have to provide an absolute path to the parser
                // but that's not as clean to type, this saves us trying to manually enforce
                // that contributors require.resolve everything
                parser: require.resolve(baseOptions.parser) }));
            _RuleTester_baseOptions.set(this, void 0);
            __classPrivateFieldSet(this, _RuleTester_baseOptions, baseOptions, "f");
            // make sure that the parser doesn't hold onto file handles between tests
            // on linux (i.e. our CI env), there can be very a limited number of watch handles available
            this.staticThis.afterAll(() => {
                try {
                    // instead of creating a hard dependency, just use a soft require
                    // a bit weird, but if they're using this tooling, it'll be installed
                    const parser = require(TS_ESLINT_PARSER);
                    parser.clearCaches();
                }
                catch (_b) {
                    // ignored on purpose
                }
            });
        }
        getFilename(testOptions) {
            var _b;
            const resolvedOptions = (0, deepMerge_1.deepMerge)(__classPrivateFieldGet(this, _RuleTester_baseOptions, "f").parserOptions, testOptions);
            const filename = `file.ts${((_b = resolvedOptions.ecmaFeatures) === null || _b === void 0 ? void 0 : _b.jsx) ? 'x' : ''}`;
            if (resolvedOptions.project) {
                return path.join(resolvedOptions.tsconfigRootDir != null
                    ? resolvedOptions.tsconfigRootDir
                    : process.cwd(), filename);
            }
            return filename;
        }
        // as of eslint 6 you have to provide an absolute path to the parser
        // If you don't do that at the test level, the test will fail somewhat cryptically...
        // This is a lot more explicit
        run(name, rule, testsReadonly) {
            if (__classPrivateFieldGet(this, _RuleTester_baseOptions, "f").dependencyConstraints &&
                !(0, dependencyConstraints_1.satisfiesAllDependencyConstraints)(__classPrivateFieldGet(this, _RuleTester_baseOptions, "f").dependencyConstraints)) {
                if (isDescribeWithSkip(this.staticThis.describe)) {
                    // for frameworks like mocha or jest that have a "skip" version of their function
                    // we can provide a nice skipped test!
                    this.staticThis.describe.skip(name, () => {
                        this.staticThis.it('All tests skipped due to unsatisfied constructor dependency constraints', () => { });
                    });
                }
                else {
                    // otherwise just declare an empty test
                    this.staticThis.describe(name, () => {
                        this.staticThis.it('All tests skipped due to unsatisfied constructor dependency constraints', () => {
                            // some frameworks error if there are no assertions
                            assert_1.default.equal(true, true);
                        });
                    });
                }
                // don't run any tests because we don't match the base constraint
                return;
            }
            const tests = {
                // standardize the valid tests as objects
                valid: testsReadonly.valid.map(test => {
                    if (typeof test === 'string') {
                        return {
                            code: test,
                        };
                    }
                    return test;
                }),
                invalid: testsReadonly.invalid,
            };
            // convenience iterator to make it easy to loop all tests without a concat
            const allTestsIterator = {
                *[Symbol.iterator]() {
                    for (const test of tests.valid) {
                        yield test;
                    }
                    for (const test of tests.invalid) {
                        yield test;
                    }
                },
            };
            /*
            Automatically add a filename to the tests to enable type-aware tests to "just work".
            This saves users having to verbosely and manually add the filename to every
            single test case.
            Hugely helps with the string-based valid test cases as it means they don't
            need to be made objects!
            Also removes dependencyConstraints, which we support but ESLint core doesn't.
            */
            const normalizeTest = (_b) => {
                var { dependencyConstraints: _ } = _b, test = __rest(_b, ["dependencyConstraints"]);
                if (test.parser === TS_ESLINT_PARSER) {
                    throw new Error(ERROR_MESSAGE);
                }
                if (!test.filename) {
                    return Object.assign(Object.assign({}, test), { filename: this.getFilename(test.parserOptions) });
                }
                return test;
            };
            tests.valid = tests.valid.map(normalizeTest);
            tests.invalid = tests.invalid.map(normalizeTest);
            const hasOnly = (() => {
                for (const test of allTestsIterator) {
                    if (test.only) {
                        return true;
                    }
                }
                return false;
            })();
            // if there is an `only: true` - don't apply constraints - assume that
            // we are in "local development" mode rather than "CI validation" mode
            if (!hasOnly) {
                /*
                Automatically skip tests that don't satisfy the dependency constraints.
                */
                const hasConstraints = (() => {
                    for (const test of allTestsIterator) {
                        if (test.dependencyConstraints &&
                            Object.keys(test.dependencyConstraints).length > 0) {
                            return true;
                        }
                    }
                    return false;
                })();
                if (hasConstraints) {
                    // The `only: boolean` test property was only added in ESLint v7.29.0.
                    if (semver.satisfies(package_json_1.version, '>=7.29.0')) {
                        /*
                        Mark all satisfactory tests as `only: true`, and all other tests as
                        `only: false`.
                        When multiple tests are marked as "only", test frameworks like jest and mocha
                        will run all of those tests and will just skip the other tests.
              
                        We do this instead of just omitting the tests entirely because it gives the
                        test framework the opportunity to log the test as skipped rather than the test
                        just disappearing.
                        */
                        const maybeMarkAsOnly = (test) => {
                            return Object.assign(Object.assign({}, test), { only: (0, dependencyConstraints_1.satisfiesAllDependencyConstraints)(test.dependencyConstraints) });
                        };
                        tests.valid = tests.valid.map(maybeMarkAsOnly);
                        tests.invalid = tests.invalid.map(maybeMarkAsOnly);
                    }
                    else {
                        // On older versions we just fallback to raw array filtering like SAVAGES
                        tests.valid = tests.valid.filter(test => (0, dependencyConstraints_1.satisfiesAllDependencyConstraints)(test.dependencyConstraints));
                        tests.invalid = tests.invalid.filter(test => (0, dependencyConstraints_1.satisfiesAllDependencyConstraints)(test.dependencyConstraints));
                    }
                }
            }
            super.run(name, rule, tests);
        }
    }
    exports.RuleTester = RuleTester;
    _a = RuleTester, _RuleTester_baseOptions = new WeakMap();
    _RuleTester_afterAll = { value: void 0 };
    /**
     * Simple no-op tag to mark code samples as "should not format with prettier"
     *   for the internal/plugin-test-formatting lint rule
     */
    function noFormat(raw, ...keys) {
        return String.raw({ raw }, ...keys);
    }
    exports.noFormat = noFormat;
    
},
/* semver/index.js */ function _(require, module, exports, __esModule, __esExport) {
    // just pre-load all the stuff that index.js lazily exports
    const internalRe = require(803) /* ./internal/re */;
    const constants = require(804) /* ./internal/constants */;
    const SemVer = require(806) /* ./classes/semver */;
    const identifiers = require(808) /* ./internal/identifiers */;
    const parse = require(809) /* ./functions/parse */;
    const valid = require(810) /* ./functions/valid */;
    const clean = require(811) /* ./functions/clean */;
    const inc = require(812) /* ./functions/inc */;
    const diff = require(813) /* ./functions/diff */;
    const major = require(816) /* ./functions/major */;
    const minor = require(817) /* ./functions/minor */;
    const patch = require(818) /* ./functions/patch */;
    const prerelease = require(819) /* ./functions/prerelease */;
    const compare = require(815) /* ./functions/compare */;
    const rcompare = require(820) /* ./functions/rcompare */;
    const compareLoose = require(821) /* ./functions/compare-loose */;
    const compareBuild = require(822) /* ./functions/compare-build */;
    const sort = require(823) /* ./functions/sort */;
    const rsort = require(824) /* ./functions/rsort */;
    const gt = require(825) /* ./functions/gt */;
    const lt = require(826) /* ./functions/lt */;
    const eq = require(814) /* ./functions/eq */;
    const neq = require(827) /* ./functions/neq */;
    const gte = require(828) /* ./functions/gte */;
    const lte = require(829) /* ./functions/lte */;
    const cmp = require(830) /* ./functions/cmp */;
    const coerce = require(831) /* ./functions/coerce */;
    const Comparator = require(832) /* ./classes/comparator */;
    const Range = require(833) /* ./classes/range */;
    const satisfies = require(837) /* ./functions/satisfies */;
    const toComparators = require(838) /* ./ranges/to-comparators */;
    const maxSatisfying = require(839) /* ./ranges/max-satisfying */;
    const minSatisfying = require(840) /* ./ranges/min-satisfying */;
    const minVersion = require(841) /* ./ranges/min-version */;
    const validRange = require(842) /* ./ranges/valid */;
    const outside = require(843) /* ./ranges/outside */;
    const gtr = require(844) /* ./ranges/gtr */;
    const ltr = require(845) /* ./ranges/ltr */;
    const intersects = require(846) /* ./ranges/intersects */;
    const simplifyRange = require(847) /* ./ranges/simplify */;
    const subset = require(848) /* ./ranges/subset */;
    module.exports = {
        parse,
        valid,
        clean,
        inc,
        diff,
        major,
        minor,
        patch,
        prerelease,
        compare,
        rcompare,
        compareLoose,
        compareBuild,
        sort,
        rsort,
        gt,
        lt,
        eq,
        neq,
        gte,
        lte,
        cmp,
        coerce,
        Comparator,
        Range,
        satisfies,
        toComparators,
        maxSatisfying,
        minSatisfying,
        minVersion,
        validRange,
        outside,
        gtr,
        ltr,
        intersects,
        simplifyRange,
        subset,
        SemVer,
        re: internalRe.re,
        src: internalRe.src,
        tokens: internalRe.t,
        SEMVER_SPEC_VERSION: constants.SEMVER_SPEC_VERSION,
        compareIdentifiers: identifiers.compareIdentifiers,
        rcompareIdentifiers: identifiers.rcompareIdentifiers,
    };
},
/* semver/internal/re.js */ function _(require, module, exports, __esModule, __esExport) {
    const { MAX_SAFE_COMPONENT_LENGTH } = require(804) /* ./constants */;
    const debug = require(805) /* ./debug */;
    exports = module.exports = {};
    // The actual regexps go on exports.re
    const re = exports.re = [];
    const src = exports.src = [];
    const t = exports.t = {};
    let R = 0;
    const createToken = (name, value, isGlobal) => {
        const index = R++;
        debug(name, index, value);
        t[name] = index;
        src[index] = value;
        re[index] = new RegExp(value, isGlobal ? 'g' : undefined);
    };
    // The following Regular Expressions can be used for tokenizing,
    // validating, and parsing SemVer version strings.
    // ## Numeric Identifier
    // A single `0`, or a non-zero digit followed by zero or more digits.
    createToken('NUMERICIDENTIFIER', '0|[1-9]\\d*');
    createToken('NUMERICIDENTIFIERLOOSE', '[0-9]+');
    // ## Non-numeric Identifier
    // Zero or more digits, followed by a letter or hyphen, and then zero or
    // more letters, digits, or hyphens.
    createToken('NONNUMERICIDENTIFIER', '\\d*[a-zA-Z-][a-zA-Z0-9-]*');
    // ## Main Version
    // Three dot-separated numeric identifiers.
    createToken('MAINVERSION', `(${src[t.NUMERICIDENTIFIER]})\\.` +
        `(${src[t.NUMERICIDENTIFIER]})\\.` +
        `(${src[t.NUMERICIDENTIFIER]})`);
    createToken('MAINVERSIONLOOSE', `(${src[t.NUMERICIDENTIFIERLOOSE]})\\.` +
        `(${src[t.NUMERICIDENTIFIERLOOSE]})\\.` +
        `(${src[t.NUMERICIDENTIFIERLOOSE]})`);
    // ## Pre-release Version Identifier
    // A numeric identifier, or a non-numeric identifier.
    createToken('PRERELEASEIDENTIFIER', `(?:${src[t.NUMERICIDENTIFIER]}|${src[t.NONNUMERICIDENTIFIER]})`);
    createToken('PRERELEASEIDENTIFIERLOOSE', `(?:${src[t.NUMERICIDENTIFIERLOOSE]}|${src[t.NONNUMERICIDENTIFIER]})`);
    // ## Pre-release Version
    // Hyphen, followed by one or more dot-separated pre-release version
    // identifiers.
    createToken('PRERELEASE', `(?:-(${src[t.PRERELEASEIDENTIFIER]}(?:\\.${src[t.PRERELEASEIDENTIFIER]})*))`);
    createToken('PRERELEASELOOSE', `(?:-?(${src[t.PRERELEASEIDENTIFIERLOOSE]}(?:\\.${src[t.PRERELEASEIDENTIFIERLOOSE]})*))`);
    // ## Build Metadata Identifier
    // Any combination of digits, letters, or hyphens.
    createToken('BUILDIDENTIFIER', '[0-9A-Za-z-]+');
    // ## Build Metadata
    // Plus sign, followed by one or more period-separated build metadata
    // identifiers.
    createToken('BUILD', `(?:\\+(${src[t.BUILDIDENTIFIER]}(?:\\.${src[t.BUILDIDENTIFIER]})*))`);
    // ## Full Version String
    // A main version, followed optionally by a pre-release version and
    // build metadata.
    // Note that the only major, minor, patch, and pre-release sections of
    // the version string are capturing groups.  The build metadata is not a
    // capturing group, because it should not ever be used in version
    // comparison.
    createToken('FULLPLAIN', `v?${src[t.MAINVERSION]}${src[t.PRERELEASE]}?${src[t.BUILD]}?`);
    createToken('FULL', `^${src[t.FULLPLAIN]}$`);
    // like full, but allows v1.2.3 and =1.2.3, which people do sometimes.
    // also, 1.0.0alpha1 (prerelease without the hyphen) which is pretty
    // common in the npm registry.
    createToken('LOOSEPLAIN', `[v=\\s]*${src[t.MAINVERSIONLOOSE]}${src[t.PRERELEASELOOSE]}?${src[t.BUILD]}?`);
    createToken('LOOSE', `^${src[t.LOOSEPLAIN]}$`);
    createToken('GTLT', '((?:<|>)?=?)');
    // Something like "2.*" or "1.2.x".
    // Note that "x.x" is a valid xRange identifer, meaning "any version"
    // Only the first item is strictly required.
    createToken('XRANGEIDENTIFIERLOOSE', `${src[t.NUMERICIDENTIFIERLOOSE]}|x|X|\\*`);
    createToken('XRANGEIDENTIFIER', `${src[t.NUMERICIDENTIFIER]}|x|X|\\*`);
    createToken('XRANGEPLAIN', `[v=\\s]*(${src[t.XRANGEIDENTIFIER]})` +
        `(?:\\.(${src[t.XRANGEIDENTIFIER]})` +
        `(?:\\.(${src[t.XRANGEIDENTIFIER]})` +
        `(?:${src[t.PRERELEASE]})?${src[t.BUILD]}?` +
        `)?)?`);
    createToken('XRANGEPLAINLOOSE', `[v=\\s]*(${src[t.XRANGEIDENTIFIERLOOSE]})` +
        `(?:\\.(${src[t.XRANGEIDENTIFIERLOOSE]})` +
        `(?:\\.(${src[t.XRANGEIDENTIFIERLOOSE]})` +
        `(?:${src[t.PRERELEASELOOSE]})?${src[t.BUILD]}?` +
        `)?)?`);
    createToken('XRANGE', `^${src[t.GTLT]}\\s*${src[t.XRANGEPLAIN]}$`);
    createToken('XRANGELOOSE', `^${src[t.GTLT]}\\s*${src[t.XRANGEPLAINLOOSE]}$`);
    // Coercion.
    // Extract anything that could conceivably be a part of a valid semver
    createToken('COERCE', `${'(^|[^\\d])' +
        '(\\d{1,'}${MAX_SAFE_COMPONENT_LENGTH}})` +
        `(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?` +
        `(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?` +
        `(?:$|[^\\d])`);
    createToken('COERCERTL', src[t.COERCE], true);
    // Tilde ranges.
    // Meaning is "reasonably at or greater than"
    createToken('LONETILDE', '(?:~>?)');
    createToken('TILDETRIM', `(\\s*)${src[t.LONETILDE]}\\s+`, true);
    exports.tildeTrimReplace = '$1~';
    createToken('TILDE', `^${src[t.LONETILDE]}${src[t.XRANGEPLAIN]}$`);
    createToken('TILDELOOSE', `^${src[t.LONETILDE]}${src[t.XRANGEPLAINLOOSE]}$`);
    // Caret ranges.
    // Meaning is "at least and backwards compatible with"
    createToken('LONECARET', '(?:\\^)');
    createToken('CARETTRIM', `(\\s*)${src[t.LONECARET]}\\s+`, true);
    exports.caretTrimReplace = '$1^';
    createToken('CARET', `^${src[t.LONECARET]}${src[t.XRANGEPLAIN]}$`);
    createToken('CARETLOOSE', `^${src[t.LONECARET]}${src[t.XRANGEPLAINLOOSE]}$`);
    // A simple gt/lt/eq thing, or just "" to indicate "any version"
    createToken('COMPARATORLOOSE', `^${src[t.GTLT]}\\s*(${src[t.LOOSEPLAIN]})$|^$`);
    createToken('COMPARATOR', `^${src[t.GTLT]}\\s*(${src[t.FULLPLAIN]})$|^$`);
    // An expression to strip any whitespace between the gtlt and the thing
    // it modifies, so that `> 1.2.3` ==> `>1.2.3`
    createToken('COMPARATORTRIM', `(\\s*)${src[t.GTLT]}\\s*(${src[t.LOOSEPLAIN]}|${src[t.XRANGEPLAIN]})`, true);
    exports.comparatorTrimReplace = '$1$2$3';
    // Something like `1.2.3 - 1.2.4`
    // Note that these all use the loose form, because they'll be
    // checked against either the strict or loose comparator form
    // later.
    createToken('HYPHENRANGE', `^\\s*(${src[t.XRANGEPLAIN]})` +
        `\\s+-\\s+` +
        `(${src[t.XRANGEPLAIN]})` +
        `\\s*$`);
    createToken('HYPHENRANGELOOSE', `^\\s*(${src[t.XRANGEPLAINLOOSE]})` +
        `\\s+-\\s+` +
        `(${src[t.XRANGEPLAINLOOSE]})` +
        `\\s*$`);
    // Star ranges basically just allow anything at all.
    createToken('STAR', '(<|>)?=?\\s*\\*');
    // >=0.0.0 is like a star
    createToken('GTE0', '^\\s*>=\\s*0\\.0\\.0\\s*$');
    createToken('GTE0PRE', '^\\s*>=\\s*0\\.0\\.0-0\\s*$');
},
/* semver/internal/constants.js */ function _(require, module, exports, __esModule, __esExport) {
    // Note: this is the semver.org version of the spec that it implements
    // Not necessarily the package version of this code.
    const SEMVER_SPEC_VERSION = '2.0.0';
    const MAX_LENGTH = 256;
    const MAX_SAFE_INTEGER = Number.MAX_SAFE_INTEGER ||
        /* istanbul ignore next */ 9007199254740991;
    // Max safe segment length for coercion.
    const MAX_SAFE_COMPONENT_LENGTH = 16;
    module.exports = {
        SEMVER_SPEC_VERSION,
        MAX_LENGTH,
        MAX_SAFE_INTEGER,
        MAX_SAFE_COMPONENT_LENGTH,
    };
},
/* semver/internal/debug.js */ function _(require, module, exports, __esModule, __esExport) {
    const debug = (typeof process === 'object' &&
        process.env &&
        process.env.NODE_DEBUG &&
        /\bsemver\b/i.test(process.env.NODE_DEBUG)) ? (...args) => console.error('SEMVER', ...args)
        : () => { };
    module.exports = debug;
},
/* semver/classes/semver.js */ function _(require, module, exports, __esModule, __esExport) {
    const debug = require(805) /* ../internal/debug */;
    const { MAX_LENGTH, MAX_SAFE_INTEGER } = require(804) /* ../internal/constants */;
    const { re, t } = require(803) /* ../internal/re */;
    const parseOptions = require(807) /* ../internal/parse-options */;
    const { compareIdentifiers } = require(808) /* ../internal/identifiers */;
    class SemVer {
        constructor(version, options) {
            options = parseOptions(options);
            if (version instanceof SemVer) {
                if (version.loose === !!options.loose &&
                    version.includePrerelease === !!options.includePrerelease) {
                    return version;
                }
                else {
                    version = version.version;
                }
            }
            else if (typeof version !== 'string') {
                throw new TypeError(`Invalid Version: ${version}`);
            }
            if (version.length > MAX_LENGTH) {
                throw new TypeError(`version is longer than ${MAX_LENGTH} characters`);
            }
            debug('SemVer', version, options);
            this.options = options;
            this.loose = !!options.loose;
            // this isn't actually relevant for versions, but keep it so that we
            // don't run into trouble passing this.options around.
            this.includePrerelease = !!options.includePrerelease;
            const m = version.trim().match(options.loose ? re[t.LOOSE] : re[t.FULL]);
            if (!m) {
                throw new TypeError(`Invalid Version: ${version}`);
            }
            this.raw = version;
            // these are actually numbers
            this.major = +m[1];
            this.minor = +m[2];
            this.patch = +m[3];
            if (this.major > MAX_SAFE_INTEGER || this.major < 0) {
                throw new TypeError('Invalid major version');
            }
            if (this.minor > MAX_SAFE_INTEGER || this.minor < 0) {
                throw new TypeError('Invalid minor version');
            }
            if (this.patch > MAX_SAFE_INTEGER || this.patch < 0) {
                throw new TypeError('Invalid patch version');
            }
            // numberify any prerelease numeric ids
            if (!m[4]) {
                this.prerelease = [];
            }
            else {
                this.prerelease = m[4].split('.').map((id) => {
                    if (/^[0-9]+$/.test(id)) {
                        const num = +id;
                        if (num >= 0 && num < MAX_SAFE_INTEGER) {
                            return num;
                        }
                    }
                    return id;
                });
            }
            this.build = m[5] ? m[5].split('.') : [];
            this.format();
        }
        format() {
            this.version = `${this.major}.${this.minor}.${this.patch}`;
            if (this.prerelease.length) {
                this.version += `-${this.prerelease.join('.')}`;
            }
            return this.version;
        }
        toString() {
            return this.version;
        }
        compare(other) {
            debug('SemVer.compare', this.version, this.options, other);
            if (!(other instanceof SemVer)) {
                if (typeof other === 'string' && other === this.version) {
                    return 0;
                }
                other = new SemVer(other, this.options);
            }
            if (other.version === this.version) {
                return 0;
            }
            return this.compareMain(other) || this.comparePre(other);
        }
        compareMain(other) {
            if (!(other instanceof SemVer)) {
                other = new SemVer(other, this.options);
            }
            return (compareIdentifiers(this.major, other.major) ||
                compareIdentifiers(this.minor, other.minor) ||
                compareIdentifiers(this.patch, other.patch));
        }
        comparePre(other) {
            if (!(other instanceof SemVer)) {
                other = new SemVer(other, this.options);
            }
            // NOT having a prerelease is > having one
            if (this.prerelease.length && !other.prerelease.length) {
                return -1;
            }
            else if (!this.prerelease.length && other.prerelease.length) {
                return 1;
            }
            else if (!this.prerelease.length && !other.prerelease.length) {
                return 0;
            }
            let i = 0;
            do {
                const a = this.prerelease[i];
                const b = other.prerelease[i];
                debug('prerelease compare', i, a, b);
                if (a === undefined && b === undefined) {
                    return 0;
                }
                else if (b === undefined) {
                    return 1;
                }
                else if (a === undefined) {
                    return -1;
                }
                else if (a === b) {
                    continue;
                }
                else {
                    return compareIdentifiers(a, b);
                }
            } while (++i);
        }
        compareBuild(other) {
            if (!(other instanceof SemVer)) {
                other = new SemVer(other, this.options);
            }
            let i = 0;
            do {
                const a = this.build[i];
                const b = other.build[i];
                debug('prerelease compare', i, a, b);
                if (a === undefined && b === undefined) {
                    return 0;
                }
                else if (b === undefined) {
                    return 1;
                }
                else if (a === undefined) {
                    return -1;
                }
                else if (a === b) {
                    continue;
                }
                else {
                    return compareIdentifiers(a, b);
                }
            } while (++i);
        }
        // preminor will bump the version up to the next minor release, and immediately
        // down to pre-release. premajor and prepatch work the same way.
        inc(release, identifier) {
            switch (release) {
                case 'premajor':
                    this.prerelease.length = 0;
                    this.patch = 0;
                    this.minor = 0;
                    this.major++;
                    this.inc('pre', identifier);
                    break;
                case 'preminor':
                    this.prerelease.length = 0;
                    this.patch = 0;
                    this.minor++;
                    this.inc('pre', identifier);
                    break;
                case 'prepatch':
                    // If this is already a prerelease, it will bump to the next version
                    // drop any prereleases that might already exist, since they are not
                    // relevant at this point.
                    this.prerelease.length = 0;
                    this.inc('patch', identifier);
                    this.inc('pre', identifier);
                    break;
                // If the input is a non-prerelease version, this acts the same as
                // prepatch.
                case 'prerelease':
                    if (this.prerelease.length === 0) {
                        this.inc('patch', identifier);
                    }
                    this.inc('pre', identifier);
                    break;
                case 'major':
                    // If this is a pre-major version, bump up to the same major version.
                    // Otherwise increment major.
                    // 1.0.0-5 bumps to 1.0.0
                    // 1.1.0 bumps to 2.0.0
                    if (this.minor !== 0 ||
                        this.patch !== 0 ||
                        this.prerelease.length === 0) {
                        this.major++;
                    }
                    this.minor = 0;
                    this.patch = 0;
                    this.prerelease = [];
                    break;
                case 'minor':
                    // If this is a pre-minor version, bump up to the same minor version.
                    // Otherwise increment minor.
                    // 1.2.0-5 bumps to 1.2.0
                    // 1.2.1 bumps to 1.3.0
                    if (this.patch !== 0 || this.prerelease.length === 0) {
                        this.minor++;
                    }
                    this.patch = 0;
                    this.prerelease = [];
                    break;
                case 'patch':
                    // If this is not a pre-release version, it will increment the patch.
                    // If it is a pre-release it will bump up to the same patch version.
                    // 1.2.0-5 patches to 1.2.0
                    // 1.2.0 patches to 1.2.1
                    if (this.prerelease.length === 0) {
                        this.patch++;
                    }
                    this.prerelease = [];
                    break;
                // This probably shouldn't be used publicly.
                // 1.0.0 'pre' would become 1.0.0-0 which is the wrong direction.
                case 'pre':
                    if (this.prerelease.length === 0) {
                        this.prerelease = [0];
                    }
                    else {
                        let i = this.prerelease.length;
                        while (--i >= 0) {
                            if (typeof this.prerelease[i] === 'number') {
                                this.prerelease[i]++;
                                i = -2;
                            }
                        }
                        if (i === -1) {
                            // didn't increment anything
                            this.prerelease.push(0);
                        }
                    }
                    if (identifier) {
                        // 1.2.0-beta.1 bumps to 1.2.0-beta.2,
                        // 1.2.0-beta.fooblz or 1.2.0-beta bumps to 1.2.0-beta.0
                        if (compareIdentifiers(this.prerelease[0], identifier) === 0) {
                            if (isNaN(this.prerelease[1])) {
                                this.prerelease = [identifier, 0];
                            }
                        }
                        else {
                            this.prerelease = [identifier, 0];
                        }
                    }
                    break;
                default:
                    throw new Error(`invalid increment argument: ${release}`);
            }
            this.format();
            this.raw = this.version;
            return this;
        }
    }
    module.exports = SemVer;
},
/* semver/internal/parse-options.js */ function _(require, module, exports, __esModule, __esExport) {
    // parse out just the options we care about so we always get a consistent
    // obj with keys in a consistent order.
    const opts = ['includePrerelease', 'loose', 'rtl'];
    const parseOptions = options => !options ? {}
        : typeof options !== 'object' ? { loose: true }
            : opts.filter(k => options[k]).reduce((o, k) => {
                o[k] = true;
                return o;
            }, {});
    module.exports = parseOptions;
},
/* semver/internal/identifiers.js */ function _(require, module, exports, __esModule, __esExport) {
    const numeric = /^[0-9]+$/;
    const compareIdentifiers = (a, b) => {
        const anum = numeric.test(a);
        const bnum = numeric.test(b);
        if (anum && bnum) {
            a = +a;
            b = +b;
        }
        return a === b ? 0
            : (anum && !bnum) ? -1
                : (bnum && !anum) ? 1
                    : a < b ? -1
                        : 1;
    };
    const rcompareIdentifiers = (a, b) => compareIdentifiers(b, a);
    module.exports = {
        compareIdentifiers,
        rcompareIdentifiers,
    };
},
/* semver/functions/parse.js */ function _(require, module, exports, __esModule, __esExport) {
    const { MAX_LENGTH } = require(804) /* ../internal/constants */;
    const { re, t } = require(803) /* ../internal/re */;
    const SemVer = require(806) /* ../classes/semver */;
    const parseOptions = require(807) /* ../internal/parse-options */;
    const parse = (version, options) => {
        options = parseOptions(options);
        if (version instanceof SemVer) {
            return version;
        }
        if (typeof version !== 'string') {
            return null;
        }
        if (version.length > MAX_LENGTH) {
            return null;
        }
        const r = options.loose ? re[t.LOOSE] : re[t.FULL];
        if (!r.test(version)) {
            return null;
        }
        try {
            return new SemVer(version, options);
        }
        catch (er) {
            return null;
        }
    };
    module.exports = parse;
},
/* semver/functions/valid.js */ function _(require, module, exports, __esModule, __esExport) {
    const parse = require(809) /* ./parse */;
    const valid = (version, options) => {
        const v = parse(version, options);
        return v ? v.version : null;
    };
    module.exports = valid;
},
/* semver/functions/clean.js */ function _(require, module, exports, __esModule, __esExport) {
    const parse = require(809) /* ./parse */;
    const clean = (version, options) => {
        const s = parse(version.trim().replace(/^[=v]+/, ''), options);
        return s ? s.version : null;
    };
    module.exports = clean;
},
/* semver/functions/inc.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const inc = (version, release, options, identifier) => {
        if (typeof (options) === 'string') {
            identifier = options;
            options = undefined;
        }
        try {
            return new SemVer(version instanceof SemVer ? version.version : version, options).inc(release, identifier).version;
        }
        catch (er) {
            return null;
        }
    };
    module.exports = inc;
},
/* semver/functions/diff.js */ function _(require, module, exports, __esModule, __esExport) {
    const parse = require(809) /* ./parse */;
    const eq = require(814) /* ./eq */;
    const diff = (version1, version2) => {
        if (eq(version1, version2)) {
            return null;
        }
        else {
            const v1 = parse(version1);
            const v2 = parse(version2);
            const hasPre = v1.prerelease.length || v2.prerelease.length;
            const prefix = hasPre ? 'pre' : '';
            const defaultResult = hasPre ? 'prerelease' : '';
            for (const key in v1) {
                if (key === 'major' || key === 'minor' || key === 'patch') {
                    if (v1[key] !== v2[key]) {
                        return prefix + key;
                    }
                }
            }
            return defaultResult; // may be undefined
        }
    };
    module.exports = diff;
},
/* semver/functions/eq.js */ function _(require, module, exports, __esModule, __esExport) {
    const compare = require(815) /* ./compare */;
    const eq = (a, b, loose) => compare(a, b, loose) === 0;
    module.exports = eq;
},
/* semver/functions/compare.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const compare = (a, b, loose) => new SemVer(a, loose).compare(new SemVer(b, loose));
    module.exports = compare;
},
/* semver/functions/major.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const major = (a, loose) => new SemVer(a, loose).major;
    module.exports = major;
},
/* semver/functions/minor.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const minor = (a, loose) => new SemVer(a, loose).minor;
    module.exports = minor;
},
/* semver/functions/patch.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const patch = (a, loose) => new SemVer(a, loose).patch;
    module.exports = patch;
},
/* semver/functions/prerelease.js */ function _(require, module, exports, __esModule, __esExport) {
    const parse = require(809) /* ./parse */;
    const prerelease = (version, options) => {
        const parsed = parse(version, options);
        return (parsed && parsed.prerelease.length) ? parsed.prerelease : null;
    };
    module.exports = prerelease;
},
/* semver/functions/rcompare.js */ function _(require, module, exports, __esModule, __esExport) {
    const compare = require(815) /* ./compare */;
    const rcompare = (a, b, loose) => compare(b, a, loose);
    module.exports = rcompare;
},
/* semver/functions/compare-loose.js */ function _(require, module, exports, __esModule, __esExport) {
    const compare = require(815) /* ./compare */;
    const compareLoose = (a, b) => compare(a, b, true);
    module.exports = compareLoose;
},
/* semver/functions/compare-build.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const compareBuild = (a, b, loose) => {
        const versionA = new SemVer(a, loose);
        const versionB = new SemVer(b, loose);
        return versionA.compare(versionB) || versionA.compareBuild(versionB);
    };
    module.exports = compareBuild;
},
/* semver/functions/sort.js */ function _(require, module, exports, __esModule, __esExport) {
    const compareBuild = require(822) /* ./compare-build */;
    const sort = (list, loose) => list.sort((a, b) => compareBuild(a, b, loose));
    module.exports = sort;
},
/* semver/functions/rsort.js */ function _(require, module, exports, __esModule, __esExport) {
    const compareBuild = require(822) /* ./compare-build */;
    const rsort = (list, loose) => list.sort((a, b) => compareBuild(b, a, loose));
    module.exports = rsort;
},
/* semver/functions/gt.js */ function _(require, module, exports, __esModule, __esExport) {
    const compare = require(815) /* ./compare */;
    const gt = (a, b, loose) => compare(a, b, loose) > 0;
    module.exports = gt;
},
/* semver/functions/lt.js */ function _(require, module, exports, __esModule, __esExport) {
    const compare = require(815) /* ./compare */;
    const lt = (a, b, loose) => compare(a, b, loose) < 0;
    module.exports = lt;
},
/* semver/functions/neq.js */ function _(require, module, exports, __esModule, __esExport) {
    const compare = require(815) /* ./compare */;
    const neq = (a, b, loose) => compare(a, b, loose) !== 0;
    module.exports = neq;
},
/* semver/functions/gte.js */ function _(require, module, exports, __esModule, __esExport) {
    const compare = require(815) /* ./compare */;
    const gte = (a, b, loose) => compare(a, b, loose) >= 0;
    module.exports = gte;
},
/* semver/functions/lte.js */ function _(require, module, exports, __esModule, __esExport) {
    const compare = require(815) /* ./compare */;
    const lte = (a, b, loose) => compare(a, b, loose) <= 0;
    module.exports = lte;
},
/* semver/functions/cmp.js */ function _(require, module, exports, __esModule, __esExport) {
    const eq = require(814) /* ./eq */;
    const neq = require(827) /* ./neq */;
    const gt = require(825) /* ./gt */;
    const gte = require(828) /* ./gte */;
    const lt = require(826) /* ./lt */;
    const lte = require(829) /* ./lte */;
    const cmp = (a, op, b, loose) => {
        switch (op) {
            case '===':
                if (typeof a === 'object') {
                    a = a.version;
                }
                if (typeof b === 'object') {
                    b = b.version;
                }
                return a === b;
            case '!==':
                if (typeof a === 'object') {
                    a = a.version;
                }
                if (typeof b === 'object') {
                    b = b.version;
                }
                return a !== b;
            case '':
            case '=':
            case '==':
                return eq(a, b, loose);
            case '!=':
                return neq(a, b, loose);
            case '>':
                return gt(a, b, loose);
            case '>=':
                return gte(a, b, loose);
            case '<':
                return lt(a, b, loose);
            case '<=':
                return lte(a, b, loose);
            default:
                throw new TypeError(`Invalid operator: ${op}`);
        }
    };
    module.exports = cmp;
},
/* semver/functions/coerce.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const parse = require(809) /* ./parse */;
    const { re, t } = require(803) /* ../internal/re */;
    const coerce = (version, options) => {
        if (version instanceof SemVer) {
            return version;
        }
        if (typeof version === 'number') {
            version = String(version);
        }
        if (typeof version !== 'string') {
            return null;
        }
        options = options || {};
        let match = null;
        if (!options.rtl) {
            match = version.match(re[t.COERCE]);
        }
        else {
            // Find the right-most coercible string that does not share
            // a terminus with a more left-ward coercible string.
            // Eg, '1.2.3.4' wants to coerce '2.3.4', not '3.4' or '4'
            //
            // Walk through the string checking with a /g regexp
            // Manually set the index so as to pick up overlapping matches.
            // Stop when we get a match that ends at the string end, since no
            // coercible string can be more right-ward without the same terminus.
            let next;
            while ((next = re[t.COERCERTL].exec(version)) &&
                (!match || match.index + match[0].length !== version.length)) {
                if (!match ||
                    next.index + next[0].length !== match.index + match[0].length) {
                    match = next;
                }
                re[t.COERCERTL].lastIndex = next.index + next[1].length + next[2].length;
            }
            // leave it in a clean state
            re[t.COERCERTL].lastIndex = -1;
        }
        if (match === null) {
            return null;
        }
        return parse(`${match[2]}.${match[3] || '0'}.${match[4] || '0'}`, options);
    };
    module.exports = coerce;
},
/* semver/classes/comparator.js */ function _(require, module, exports, __esModule, __esExport) {
    const ANY = Symbol('SemVer ANY');
    // hoisted class for cyclic dependency
    class Comparator {
        static get ANY() {
            return ANY;
        }
        constructor(comp, options) {
            options = parseOptions(options);
            if (comp instanceof Comparator) {
                if (comp.loose === !!options.loose) {
                    return comp;
                }
                else {
                    comp = comp.value;
                }
            }
            debug('comparator', comp, options);
            this.options = options;
            this.loose = !!options.loose;
            this.parse(comp);
            if (this.semver === ANY) {
                this.value = '';
            }
            else {
                this.value = this.operator + this.semver.version;
            }
            debug('comp', this);
        }
        parse(comp) {
            const r = this.options.loose ? re[t.COMPARATORLOOSE] : re[t.COMPARATOR];
            const m = comp.match(r);
            if (!m) {
                throw new TypeError(`Invalid comparator: ${comp}`);
            }
            this.operator = m[1] !== undefined ? m[1] : '';
            if (this.operator === '=') {
                this.operator = '';
            }
            // if it literally is just '>' or '' then allow anything.
            if (!m[2]) {
                this.semver = ANY;
            }
            else {
                this.semver = new SemVer(m[2], this.options.loose);
            }
        }
        toString() {
            return this.value;
        }
        test(version) {
            debug('Comparator.test', version, this.options.loose);
            if (this.semver === ANY || version === ANY) {
                return true;
            }
            if (typeof version === 'string') {
                try {
                    version = new SemVer(version, this.options);
                }
                catch (er) {
                    return false;
                }
            }
            return cmp(version, this.operator, this.semver, this.options);
        }
        intersects(comp, options) {
            if (!(comp instanceof Comparator)) {
                throw new TypeError('a Comparator is required');
            }
            if (!options || typeof options !== 'object') {
                options = {
                    loose: !!options,
                    includePrerelease: false,
                };
            }
            if (this.operator === '') {
                if (this.value === '') {
                    return true;
                }
                return new Range(comp.value, options).test(this.value);
            }
            else if (comp.operator === '') {
                if (comp.value === '') {
                    return true;
                }
                return new Range(this.value, options).test(comp.semver);
            }
            const sameDirectionIncreasing = (this.operator === '>=' || this.operator === '>') &&
                (comp.operator === '>=' || comp.operator === '>');
            const sameDirectionDecreasing = (this.operator === '<=' || this.operator === '<') &&
                (comp.operator === '<=' || comp.operator === '<');
            const sameSemVer = this.semver.version === comp.semver.version;
            const differentDirectionsInclusive = (this.operator === '>=' || this.operator === '<=') &&
                (comp.operator === '>=' || comp.operator === '<=');
            const oppositeDirectionsLessThan = cmp(this.semver, '<', comp.semver, options) &&
                (this.operator === '>=' || this.operator === '>') &&
                (comp.operator === '<=' || comp.operator === '<');
            const oppositeDirectionsGreaterThan = cmp(this.semver, '>', comp.semver, options) &&
                (this.operator === '<=' || this.operator === '<') &&
                (comp.operator === '>=' || comp.operator === '>');
            return (sameDirectionIncreasing ||
                sameDirectionDecreasing ||
                (sameSemVer && differentDirectionsInclusive) ||
                oppositeDirectionsLessThan ||
                oppositeDirectionsGreaterThan);
        }
    }
    module.exports = Comparator;
    const parseOptions = require(807) /* ../internal/parse-options */;
    const { re, t } = require(803) /* ../internal/re */;
    const cmp = require(830) /* ../functions/cmp */;
    const debug = require(805) /* ../internal/debug */;
    const SemVer = require(806) /* ./semver */;
    const Range = require(833) /* ./range */;
},
/* semver/classes/range.js */ function _(require, module, exports, __esModule, __esExport) {
    // hoisted class for cyclic dependency
    class Range {
        constructor(range, options) {
            options = parseOptions(options);
            if (range instanceof Range) {
                if (range.loose === !!options.loose &&
                    range.includePrerelease === !!options.includePrerelease) {
                    return range;
                }
                else {
                    return new Range(range.raw, options);
                }
            }
            if (range instanceof Comparator) {
                // just put it in the set and return
                this.raw = range.value;
                this.set = [[range]];
                this.format();
                return this;
            }
            this.options = options;
            this.loose = !!options.loose;
            this.includePrerelease = !!options.includePrerelease;
            // First, split based on boolean or ||
            this.raw = range;
            this.set = range
                .split('||')
                // map the range to a 2d array of comparators
                .map(r => this.parseRange(r.trim()))
                // throw out any comparator lists that are empty
                // this generally means that it was not a valid range, which is allowed
                // in loose mode, but will still throw if the WHOLE range is invalid.
                .filter(c => c.length);
            if (!this.set.length) {
                throw new TypeError(`Invalid SemVer Range: ${range}`);
            }
            // if we have any that are not the null set, throw out null sets.
            if (this.set.length > 1) {
                // keep the first one, in case they're all null sets
                const first = this.set[0];
                this.set = this.set.filter(c => !isNullSet(c[0]));
                if (this.set.length === 0) {
                    this.set = [first];
                }
                else if (this.set.length > 1) {
                    // if we have any that are *, then the range is just *
                    for (const c of this.set) {
                        if (c.length === 1 && isAny(c[0])) {
                            this.set = [c];
                            break;
                        }
                    }
                }
            }
            this.format();
        }
        format() {
            this.range = this.set
                .map((comps) => {
                return comps.join(' ').trim();
            })
                .join('||')
                .trim();
            return this.range;
        }
        toString() {
            return this.range;
        }
        parseRange(range) {
            range = range.trim();
            // memoize range parsing for performance.
            // this is a very hot path, and fully deterministic.
            const memoOpts = Object.keys(this.options).join(',');
            const memoKey = `parseRange:${memoOpts}:${range}`;
            const cached = cache.get(memoKey);
            if (cached) {
                return cached;
            }
            const loose = this.options.loose;
            // `1.2.3 - 1.2.4` => `>=1.2.3 <=1.2.4`
            const hr = loose ? re[t.HYPHENRANGELOOSE] : re[t.HYPHENRANGE];
            range = range.replace(hr, hyphenReplace(this.options.includePrerelease));
            debug('hyphen replace', range);
            // `> 1.2.3 < 1.2.5` => `>1.2.3 <1.2.5`
            range = range.replace(re[t.COMPARATORTRIM], comparatorTrimReplace);
            debug('comparator trim', range);
            // `~ 1.2.3` => `~1.2.3`
            range = range.replace(re[t.TILDETRIM], tildeTrimReplace);
            // `^ 1.2.3` => `^1.2.3`
            range = range.replace(re[t.CARETTRIM], caretTrimReplace);
            // normalize spaces
            range = range.split(/\s+/).join(' ');
            // At this point, the range is completely trimmed and
            // ready to be split into comparators.
            let rangeList = range
                .split(' ')
                .map(comp => parseComparator(comp, this.options))
                .join(' ')
                .split(/\s+/)
                // >=0.0.0 is equivalent to *
                .map(comp => replaceGTE0(comp, this.options));
            if (loose) {
                // in loose mode, throw out any that are not valid comparators
                rangeList = rangeList.filter(comp => {
                    debug('loose invalid filter', comp, this.options);
                    return !!comp.match(re[t.COMPARATORLOOSE]);
                });
            }
            debug('range list', rangeList);
            // if any comparators are the null set, then replace with JUST null set
            // if more than one comparator, remove any * comparators
            // also, don't include the same comparator more than once
            const rangeMap = new Map();
            const comparators = rangeList.map(comp => new Comparator(comp, this.options));
            for (const comp of comparators) {
                if (isNullSet(comp)) {
                    return [comp];
                }
                rangeMap.set(comp.value, comp);
            }
            if (rangeMap.size > 1 && rangeMap.has('')) {
                rangeMap.delete('');
            }
            const result = [...rangeMap.values()];
            cache.set(memoKey, result);
            return result;
        }
        intersects(range, options) {
            if (!(range instanceof Range)) {
                throw new TypeError('a Range is required');
            }
            return this.set.some((thisComparators) => {
                return (isSatisfiable(thisComparators, options) &&
                    range.set.some((rangeComparators) => {
                        return (isSatisfiable(rangeComparators, options) &&
                            thisComparators.every((thisComparator) => {
                                return rangeComparators.every((rangeComparator) => {
                                    return thisComparator.intersects(rangeComparator, options);
                                });
                            }));
                    }));
            });
        }
        // if ANY of the sets match ALL of its comparators, then pass
        test(version) {
            if (!version) {
                return false;
            }
            if (typeof version === 'string') {
                try {
                    version = new SemVer(version, this.options);
                }
                catch (er) {
                    return false;
                }
            }
            for (let i = 0; i < this.set.length; i++) {
                if (testSet(this.set[i], version, this.options)) {
                    return true;
                }
            }
            return false;
        }
    }
    module.exports = Range;
    const LRU = require(834) /* lru-cache */;
    const cache = new LRU({ max: 1000 });
    const parseOptions = require(807) /* ../internal/parse-options */;
    const Comparator = require(832) /* ./comparator */;
    const debug = require(805) /* ../internal/debug */;
    const SemVer = require(806) /* ./semver */;
    const { re, t, comparatorTrimReplace, tildeTrimReplace, caretTrimReplace, } = require(803) /* ../internal/re */;
    const isNullSet = c => c.value === '<0.0.0-0';
    const isAny = c => c.value === '';
    // take a set of comparators and determine whether there
    // exists a version which can satisfy it
    const isSatisfiable = (comparators, options) => {
        let result = true;
        const remainingComparators = comparators.slice();
        let testComparator = remainingComparators.pop();
        while (result && remainingComparators.length) {
            result = remainingComparators.every((otherComparator) => {
                return testComparator.intersects(otherComparator, options);
            });
            testComparator = remainingComparators.pop();
        }
        return result;
    };
    // comprised of xranges, tildes, stars, and gtlt's at this point.
    // already replaced the hyphen ranges
    // turn into a set of JUST comparators.
    const parseComparator = (comp, options) => {
        debug('comp', comp, options);
        comp = replaceCarets(comp, options);
        debug('caret', comp);
        comp = replaceTildes(comp, options);
        debug('tildes', comp);
        comp = replaceXRanges(comp, options);
        debug('xrange', comp);
        comp = replaceStars(comp, options);
        debug('stars', comp);
        return comp;
    };
    const isX = id => !id || id.toLowerCase() === 'x' || id === '*';
    // ~, ~> --> * (any, kinda silly)
    // ~2, ~2.x, ~2.x.x, ~>2, ~>2.x ~>2.x.x --> >=2.0.0 <3.0.0-0
    // ~2.0, ~2.0.x, ~>2.0, ~>2.0.x --> >=2.0.0 <2.1.0-0
    // ~1.2, ~1.2.x, ~>1.2, ~>1.2.x --> >=1.2.0 <1.3.0-0
    // ~1.2.3, ~>1.2.3 --> >=1.2.3 <1.3.0-0
    // ~1.2.0, ~>1.2.0 --> >=1.2.0 <1.3.0-0
    // ~0.0.1 --> >=0.0.1 <0.1.0-0
    const replaceTildes = (comp, options) => comp.trim().split(/\s+/).map((c) => {
        return replaceTilde(c, options);
    }).join(' ');
    const replaceTilde = (comp, options) => {
        const r = options.loose ? re[t.TILDELOOSE] : re[t.TILDE];
        return comp.replace(r, (_, M, m, p, pr) => {
            debug('tilde', comp, _, M, m, p, pr);
            let ret;
            if (isX(M)) {
                ret = '';
            }
            else if (isX(m)) {
                ret = `>=${M}.0.0 <${+M + 1}.0.0-0`;
            }
            else if (isX(p)) {
                // ~1.2 == >=1.2.0 <1.3.0-0
                ret = `>=${M}.${m}.0 <${M}.${+m + 1}.0-0`;
            }
            else if (pr) {
                debug('replaceTilde pr', pr);
                ret = `>=${M}.${m}.${p}-${pr} <${M}.${+m + 1}.0-0`;
            }
            else {
                // ~1.2.3 == >=1.2.3 <1.3.0-0
                ret = `>=${M}.${m}.${p} <${M}.${+m + 1}.0-0`;
            }
            debug('tilde return', ret);
            return ret;
        });
    };
    // ^ --> * (any, kinda silly)
    // ^2, ^2.x, ^2.x.x --> >=2.0.0 <3.0.0-0
    // ^2.0, ^2.0.x --> >=2.0.0 <3.0.0-0
    // ^1.2, ^1.2.x --> >=1.2.0 <2.0.0-0
    // ^1.2.3 --> >=1.2.3 <2.0.0-0
    // ^1.2.0 --> >=1.2.0 <2.0.0-0
    // ^0.0.1 --> >=0.0.1 <0.0.2-0
    // ^0.1.0 --> >=0.1.0 <0.2.0-0
    const replaceCarets = (comp, options) => comp.trim().split(/\s+/).map((c) => {
        return replaceCaret(c, options);
    }).join(' ');
    const replaceCaret = (comp, options) => {
        debug('caret', comp, options);
        const r = options.loose ? re[t.CARETLOOSE] : re[t.CARET];
        const z = options.includePrerelease ? '-0' : '';
        return comp.replace(r, (_, M, m, p, pr) => {
            debug('caret', comp, _, M, m, p, pr);
            let ret;
            if (isX(M)) {
                ret = '';
            }
            else if (isX(m)) {
                ret = `>=${M}.0.0${z} <${+M + 1}.0.0-0`;
            }
            else if (isX(p)) {
                if (M === '0') {
                    ret = `>=${M}.${m}.0${z} <${M}.${+m + 1}.0-0`;
                }
                else {
                    ret = `>=${M}.${m}.0${z} <${+M + 1}.0.0-0`;
                }
            }
            else if (pr) {
                debug('replaceCaret pr', pr);
                if (M === '0') {
                    if (m === '0') {
                        ret = `>=${M}.${m}.${p}-${pr} <${M}.${m}.${+p + 1}-0`;
                    }
                    else {
                        ret = `>=${M}.${m}.${p}-${pr} <${M}.${+m + 1}.0-0`;
                    }
                }
                else {
                    ret = `>=${M}.${m}.${p}-${pr} <${+M + 1}.0.0-0`;
                }
            }
            else {
                debug('no pr');
                if (M === '0') {
                    if (m === '0') {
                        ret = `>=${M}.${m}.${p}${z} <${M}.${m}.${+p + 1}-0`;
                    }
                    else {
                        ret = `>=${M}.${m}.${p}${z} <${M}.${+m + 1}.0-0`;
                    }
                }
                else {
                    ret = `>=${M}.${m}.${p} <${+M + 1}.0.0-0`;
                }
            }
            debug('caret return', ret);
            return ret;
        });
    };
    const replaceXRanges = (comp, options) => {
        debug('replaceXRanges', comp, options);
        return comp.split(/\s+/).map((c) => {
            return replaceXRange(c, options);
        }).join(' ');
    };
    const replaceXRange = (comp, options) => {
        comp = comp.trim();
        const r = options.loose ? re[t.XRANGELOOSE] : re[t.XRANGE];
        return comp.replace(r, (ret, gtlt, M, m, p, pr) => {
            debug('xRange', comp, ret, gtlt, M, m, p, pr);
            const xM = isX(M);
            const xm = xM || isX(m);
            const xp = xm || isX(p);
            const anyX = xp;
            if (gtlt === '=' && anyX) {
                gtlt = '';
            }
            // if we're including prereleases in the match, then we need
            // to fix this to -0, the lowest possible prerelease value
            pr = options.includePrerelease ? '-0' : '';
            if (xM) {
                if (gtlt === '>' || gtlt === '<') {
                    // nothing is allowed
                    ret = '<0.0.0-0';
                }
                else {
                    // nothing is forbidden
                    ret = '*';
                }
            }
            else if (gtlt && anyX) {
                // we know patch is an x, because we have any x at all.
                // replace X with 0
                if (xm) {
                    m = 0;
                }
                p = 0;
                if (gtlt === '>') {
                    // >1 => >=2.0.0
                    // >1.2 => >=1.3.0
                    gtlt = '>=';
                    if (xm) {
                        M = +M + 1;
                        m = 0;
                        p = 0;
                    }
                    else {
                        m = +m + 1;
                        p = 0;
                    }
                }
                else if (gtlt === '<=') {
                    // <=0.7.x is actually <0.8.0, since any 0.7.x should
                    // pass.  Similarly, <=7.x is actually <8.0.0, etc.
                    gtlt = '<';
                    if (xm) {
                        M = +M + 1;
                    }
                    else {
                        m = +m + 1;
                    }
                }
                if (gtlt === '<') {
                    pr = '-0';
                }
                ret = `${gtlt + M}.${m}.${p}${pr}`;
            }
            else if (xm) {
                ret = `>=${M}.0.0${pr} <${+M + 1}.0.0-0`;
            }
            else if (xp) {
                ret = `>=${M}.${m}.0${pr} <${M}.${+m + 1}.0-0`;
            }
            debug('xRange return', ret);
            return ret;
        });
    };
    // Because * is AND-ed with everything else in the comparator,
    // and '' means "any version", just remove the *s entirely.
    const replaceStars = (comp, options) => {
        debug('replaceStars', comp, options);
        // Looseness is ignored here.  star is always as loose as it gets!
        return comp.trim().replace(re[t.STAR], '');
    };
    const replaceGTE0 = (comp, options) => {
        debug('replaceGTE0', comp, options);
        return comp.trim()
            .replace(re[options.includePrerelease ? t.GTE0PRE : t.GTE0], '');
    };
    // This function is passed to string.replace(re[t.HYPHENRANGE])
    // M, m, patch, prerelease, build
    // 1.2 - 3.4.5 => >=1.2.0 <=3.4.5
    // 1.2.3 - 3.4 => >=1.2.0 <3.5.0-0 Any 3.4.x will do
    // 1.2 - 3.4 => >=1.2.0 <3.5.0-0
    const hyphenReplace = incPr => ($0, from, fM, fm, fp, fpr, fb, to, tM, tm, tp, tpr, tb) => {
        if (isX(fM)) {
            from = '';
        }
        else if (isX(fm)) {
            from = `>=${fM}.0.0${incPr ? '-0' : ''}`;
        }
        else if (isX(fp)) {
            from = `>=${fM}.${fm}.0${incPr ? '-0' : ''}`;
        }
        else if (fpr) {
            from = `>=${from}`;
        }
        else {
            from = `>=${from}${incPr ? '-0' : ''}`;
        }
        if (isX(tM)) {
            to = '';
        }
        else if (isX(tm)) {
            to = `<${+tM + 1}.0.0-0`;
        }
        else if (isX(tp)) {
            to = `<${tM}.${+tm + 1}.0-0`;
        }
        else if (tpr) {
            to = `<=${tM}.${tm}.${tp}-${tpr}`;
        }
        else if (incPr) {
            to = `<${tM}.${tm}.${+tp + 1}-0`;
        }
        else {
            to = `<=${to}`;
        }
        return (`${from} ${to}`).trim();
    };
    const testSet = (set, version, options) => {
        for (let i = 0; i < set.length; i++) {
            if (!set[i].test(version)) {
                return false;
            }
        }
        if (version.prerelease.length && !options.includePrerelease) {
            // Find the set of versions that are allowed to have prereleases
            // For example, ^1.2.3-pr.1 desugars to >=1.2.3-pr.1 <2.0.0
            // That should allow `1.2.3-pr.2` to pass.
            // However, `1.2.4-alpha.notready` should NOT be allowed,
            // even though it's within the range set by the comparators.
            for (let i = 0; i < set.length; i++) {
                debug(set[i].semver);
                if (set[i].semver === Comparator.ANY) {
                    continue;
                }
                if (set[i].semver.prerelease.length > 0) {
                    const allowed = set[i].semver;
                    if (allowed.major === version.major &&
                        allowed.minor === version.minor &&
                        allowed.patch === version.patch) {
                        return true;
                    }
                }
            }
            // Version has a -pre, but it's not one of the ones we like.
            return false;
        }
        return true;
    };
},
/* lru-cache/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    // A linked list to keep track of recently-used-ness
    const Yallist = require(835) /* yallist */;
    const MAX = Symbol('max');
    const LENGTH = Symbol('length');
    const LENGTH_CALCULATOR = Symbol('lengthCalculator');
    const ALLOW_STALE = Symbol('allowStale');
    const MAX_AGE = Symbol('maxAge');
    const DISPOSE = Symbol('dispose');
    const NO_DISPOSE_ON_SET = Symbol('noDisposeOnSet');
    const LRU_LIST = Symbol('lruList');
    const CACHE = Symbol('cache');
    const UPDATE_AGE_ON_GET = Symbol('updateAgeOnGet');
    const naiveLength = () => 1;
    // lruList is a yallist where the head is the youngest
    // item, and the tail is the oldest.  the list contains the Hit
    // objects as the entries.
    // Each Hit object has a reference to its Yallist.Node.  This
    // never changes.
    //
    // cache is a Map (or PseudoMap) that matches the keys to
    // the Yallist.Node object.
    class LRUCache {
        constructor(options) {
            if (typeof options === 'number')
                options = { max: options };
            if (!options)
                options = {};
            if (options.max && (typeof options.max !== 'number' || options.max < 0))
                throw new TypeError('max must be a non-negative number');
            // Kind of weird to have a default max of Infinity, but oh well.
            const max = this[MAX] = options.max || Infinity;
            const lc = options.length || naiveLength;
            this[LENGTH_CALCULATOR] = (typeof lc !== 'function') ? naiveLength : lc;
            this[ALLOW_STALE] = options.stale || false;
            if (options.maxAge && typeof options.maxAge !== 'number')
                throw new TypeError('maxAge must be a number');
            this[MAX_AGE] = options.maxAge || 0;
            this[DISPOSE] = options.dispose;
            this[NO_DISPOSE_ON_SET] = options.noDisposeOnSet || false;
            this[UPDATE_AGE_ON_GET] = options.updateAgeOnGet || false;
            this.reset();
        }
        // resize the cache when the max changes.
        set max(mL) {
            if (typeof mL !== 'number' || mL < 0)
                throw new TypeError('max must be a non-negative number');
            this[MAX] = mL || Infinity;
            trim(this);
        }
        get max() {
            return this[MAX];
        }
        set allowStale(allowStale) {
            this[ALLOW_STALE] = !!allowStale;
        }
        get allowStale() {
            return this[ALLOW_STALE];
        }
        set maxAge(mA) {
            if (typeof mA !== 'number')
                throw new TypeError('maxAge must be a non-negative number');
            this[MAX_AGE] = mA;
            trim(this);
        }
        get maxAge() {
            return this[MAX_AGE];
        }
        // resize the cache when the lengthCalculator changes.
        set lengthCalculator(lC) {
            if (typeof lC !== 'function')
                lC = naiveLength;
            if (lC !== this[LENGTH_CALCULATOR]) {
                this[LENGTH_CALCULATOR] = lC;
                this[LENGTH] = 0;
                this[LRU_LIST].forEach(hit => {
                    hit.length = this[LENGTH_CALCULATOR](hit.value, hit.key);
                    this[LENGTH] += hit.length;
                });
            }
            trim(this);
        }
        get lengthCalculator() { return this[LENGTH_CALCULATOR]; }
        get length() { return this[LENGTH]; }
        get itemCount() { return this[LRU_LIST].length; }
        rforEach(fn, thisp) {
            thisp = thisp || this;
            for (let walker = this[LRU_LIST].tail; walker !== null;) {
                const prev = walker.prev;
                forEachStep(this, fn, walker, thisp);
                walker = prev;
            }
        }
        forEach(fn, thisp) {
            thisp = thisp || this;
            for (let walker = this[LRU_LIST].head; walker !== null;) {
                const next = walker.next;
                forEachStep(this, fn, walker, thisp);
                walker = next;
            }
        }
        keys() {
            return this[LRU_LIST].toArray().map(k => k.key);
        }
        values() {
            return this[LRU_LIST].toArray().map(k => k.value);
        }
        reset() {
            if (this[DISPOSE] &&
                this[LRU_LIST] &&
                this[LRU_LIST].length) {
                this[LRU_LIST].forEach(hit => this[DISPOSE](hit.key, hit.value));
            }
            this[CACHE] = new Map(); // hash of items by key
            this[LRU_LIST] = new Yallist(); // list of items in order of use recency
            this[LENGTH] = 0; // length of items in the list
        }
        dump() {
            return this[LRU_LIST].map(hit => isStale(this, hit) ? false : {
                k: hit.key,
                v: hit.value,
                e: hit.now + (hit.maxAge || 0)
            }).toArray().filter(h => h);
        }
        dumpLru() {
            return this[LRU_LIST];
        }
        set(key, value, maxAge) {
            maxAge = maxAge || this[MAX_AGE];
            if (maxAge && typeof maxAge !== 'number')
                throw new TypeError('maxAge must be a number');
            const now = maxAge ? Date.now() : 0;
            const len = this[LENGTH_CALCULATOR](value, key);
            if (this[CACHE].has(key)) {
                if (len > this[MAX]) {
                    del(this, this[CACHE].get(key));
                    return false;
                }
                const node = this[CACHE].get(key);
                const item = node.value;
                // dispose of the old one before overwriting
                // split out into 2 ifs for better coverage tracking
                if (this[DISPOSE]) {
                    if (!this[NO_DISPOSE_ON_SET])
                        this[DISPOSE](key, item.value);
                }
                item.now = now;
                item.maxAge = maxAge;
                item.value = value;
                this[LENGTH] += len - item.length;
                item.length = len;
                this.get(key);
                trim(this);
                return true;
            }
            const hit = new Entry(key, value, len, now, maxAge);
            // oversized objects fall out of cache automatically.
            if (hit.length > this[MAX]) {
                if (this[DISPOSE])
                    this[DISPOSE](key, value);
                return false;
            }
            this[LENGTH] += hit.length;
            this[LRU_LIST].unshift(hit);
            this[CACHE].set(key, this[LRU_LIST].head);
            trim(this);
            return true;
        }
        has(key) {
            if (!this[CACHE].has(key))
                return false;
            const hit = this[CACHE].get(key).value;
            return !isStale(this, hit);
        }
        get(key) {
            return get(this, key, true);
        }
        peek(key) {
            return get(this, key, false);
        }
        pop() {
            const node = this[LRU_LIST].tail;
            if (!node)
                return null;
            del(this, node);
            return node.value;
        }
        del(key) {
            del(this, this[CACHE].get(key));
        }
        load(arr) {
            // reset the cache
            this.reset();
            const now = Date.now();
            // A previous serialized cache has the most recent items first
            for (let l = arr.length - 1; l >= 0; l--) {
                const hit = arr[l];
                const expiresAt = hit.e || 0;
                if (expiresAt === 0)
                    // the item was created without expiration in a non aged cache
                    this.set(hit.k, hit.v);
                else {
                    const maxAge = expiresAt - now;
                    // dont add already expired items
                    if (maxAge > 0) {
                        this.set(hit.k, hit.v, maxAge);
                    }
                }
            }
        }
        prune() {
            this[CACHE].forEach((value, key) => get(this, key, false));
        }
    }
    const get = (self, key, doUse) => {
        const node = self[CACHE].get(key);
        if (node) {
            const hit = node.value;
            if (isStale(self, hit)) {
                del(self, node);
                if (!self[ALLOW_STALE])
                    return undefined;
            }
            else {
                if (doUse) {
                    if (self[UPDATE_AGE_ON_GET])
                        node.value.now = Date.now();
                    self[LRU_LIST].unshiftNode(node);
                }
            }
            return hit.value;
        }
    };
    const isStale = (self, hit) => {
        if (!hit || (!hit.maxAge && !self[MAX_AGE]))
            return false;
        const diff = Date.now() - hit.now;
        return hit.maxAge ? diff > hit.maxAge
            : self[MAX_AGE] && (diff > self[MAX_AGE]);
    };
    const trim = self => {
        if (self[LENGTH] > self[MAX]) {
            for (let walker = self[LRU_LIST].tail; self[LENGTH] > self[MAX] && walker !== null;) {
                // We know that we're about to delete this one, and also
                // what the next least recently used key will be, so just
                // go ahead and set it now.
                const prev = walker.prev;
                del(self, walker);
                walker = prev;
            }
        }
    };
    const del = (self, node) => {
        if (node) {
            const hit = node.value;
            if (self[DISPOSE])
                self[DISPOSE](hit.key, hit.value);
            self[LENGTH] -= hit.length;
            self[CACHE].delete(hit.key);
            self[LRU_LIST].removeNode(node);
        }
    };
    class Entry {
        constructor(key, value, length, now, maxAge) {
            this.key = key;
            this.value = value;
            this.length = length;
            this.now = now;
            this.maxAge = maxAge || 0;
        }
    }
    const forEachStep = (self, fn, node, thisp) => {
        let hit = node.value;
        if (isStale(self, hit)) {
            del(self, node);
            if (!self[ALLOW_STALE])
                hit = undefined;
        }
        if (hit)
            fn.call(thisp, hit.value, hit.key, self);
    };
    module.exports = LRUCache;
},
/* yallist/yallist.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = Yallist;
    Yallist.Node = Node;
    Yallist.create = Yallist;
    function Yallist(list) {
        var self = this;
        if (!(self instanceof Yallist)) {
            self = new Yallist();
        }
        self.tail = null;
        self.head = null;
        self.length = 0;
        if (list && typeof list.forEach === 'function') {
            list.forEach(function (item) {
                self.push(item);
            });
        }
        else if (arguments.length > 0) {
            for (var i = 0, l = arguments.length; i < l; i++) {
                self.push(arguments[i]);
            }
        }
        return self;
    }
    Yallist.prototype.removeNode = function (node) {
        if (node.list !== this) {
            throw new Error('removing node which does not belong to this list');
        }
        var next = node.next;
        var prev = node.prev;
        if (next) {
            next.prev = prev;
        }
        if (prev) {
            prev.next = next;
        }
        if (node === this.head) {
            this.head = next;
        }
        if (node === this.tail) {
            this.tail = prev;
        }
        node.list.length--;
        node.next = null;
        node.prev = null;
        node.list = null;
        return next;
    };
    Yallist.prototype.unshiftNode = function (node) {
        if (node === this.head) {
            return;
        }
        if (node.list) {
            node.list.removeNode(node);
        }
        var head = this.head;
        node.list = this;
        node.next = head;
        if (head) {
            head.prev = node;
        }
        this.head = node;
        if (!this.tail) {
            this.tail = node;
        }
        this.length++;
    };
    Yallist.prototype.pushNode = function (node) {
        if (node === this.tail) {
            return;
        }
        if (node.list) {
            node.list.removeNode(node);
        }
        var tail = this.tail;
        node.list = this;
        node.prev = tail;
        if (tail) {
            tail.next = node;
        }
        this.tail = node;
        if (!this.head) {
            this.head = node;
        }
        this.length++;
    };
    Yallist.prototype.push = function () {
        for (var i = 0, l = arguments.length; i < l; i++) {
            push(this, arguments[i]);
        }
        return this.length;
    };
    Yallist.prototype.unshift = function () {
        for (var i = 0, l = arguments.length; i < l; i++) {
            unshift(this, arguments[i]);
        }
        return this.length;
    };
    Yallist.prototype.pop = function () {
        if (!this.tail) {
            return undefined;
        }
        var res = this.tail.value;
        this.tail = this.tail.prev;
        if (this.tail) {
            this.tail.next = null;
        }
        else {
            this.head = null;
        }
        this.length--;
        return res;
    };
    Yallist.prototype.shift = function () {
        if (!this.head) {
            return undefined;
        }
        var res = this.head.value;
        this.head = this.head.next;
        if (this.head) {
            this.head.prev = null;
        }
        else {
            this.tail = null;
        }
        this.length--;
        return res;
    };
    Yallist.prototype.forEach = function (fn, thisp) {
        thisp = thisp || this;
        for (var walker = this.head, i = 0; walker !== null; i++) {
            fn.call(thisp, walker.value, i, this);
            walker = walker.next;
        }
    };
    Yallist.prototype.forEachReverse = function (fn, thisp) {
        thisp = thisp || this;
        for (var walker = this.tail, i = this.length - 1; walker !== null; i--) {
            fn.call(thisp, walker.value, i, this);
            walker = walker.prev;
        }
    };
    Yallist.prototype.get = function (n) {
        for (var i = 0, walker = this.head; walker !== null && i < n; i++) {
            // abort out of the list early if we hit a cycle
            walker = walker.next;
        }
        if (i === n && walker !== null) {
            return walker.value;
        }
    };
    Yallist.prototype.getReverse = function (n) {
        for (var i = 0, walker = this.tail; walker !== null && i < n; i++) {
            // abort out of the list early if we hit a cycle
            walker = walker.prev;
        }
        if (i === n && walker !== null) {
            return walker.value;
        }
    };
    Yallist.prototype.map = function (fn, thisp) {
        thisp = thisp || this;
        var res = new Yallist();
        for (var walker = this.head; walker !== null;) {
            res.push(fn.call(thisp, walker.value, this));
            walker = walker.next;
        }
        return res;
    };
    Yallist.prototype.mapReverse = function (fn, thisp) {
        thisp = thisp || this;
        var res = new Yallist();
        for (var walker = this.tail; walker !== null;) {
            res.push(fn.call(thisp, walker.value, this));
            walker = walker.prev;
        }
        return res;
    };
    Yallist.prototype.reduce = function (fn, initial) {
        var acc;
        var walker = this.head;
        if (arguments.length > 1) {
            acc = initial;
        }
        else if (this.head) {
            walker = this.head.next;
            acc = this.head.value;
        }
        else {
            throw new TypeError('Reduce of empty list with no initial value');
        }
        for (var i = 0; walker !== null; i++) {
            acc = fn(acc, walker.value, i);
            walker = walker.next;
        }
        return acc;
    };
    Yallist.prototype.reduceReverse = function (fn, initial) {
        var acc;
        var walker = this.tail;
        if (arguments.length > 1) {
            acc = initial;
        }
        else if (this.tail) {
            walker = this.tail.prev;
            acc = this.tail.value;
        }
        else {
            throw new TypeError('Reduce of empty list with no initial value');
        }
        for (var i = this.length - 1; walker !== null; i--) {
            acc = fn(acc, walker.value, i);
            walker = walker.prev;
        }
        return acc;
    };
    Yallist.prototype.toArray = function () {
        var arr = new Array(this.length);
        for (var i = 0, walker = this.head; walker !== null; i++) {
            arr[i] = walker.value;
            walker = walker.next;
        }
        return arr;
    };
    Yallist.prototype.toArrayReverse = function () {
        var arr = new Array(this.length);
        for (var i = 0, walker = this.tail; walker !== null; i++) {
            arr[i] = walker.value;
            walker = walker.prev;
        }
        return arr;
    };
    Yallist.prototype.slice = function (from, to) {
        to = to || this.length;
        if (to < 0) {
            to += this.length;
        }
        from = from || 0;
        if (from < 0) {
            from += this.length;
        }
        var ret = new Yallist();
        if (to < from || to < 0) {
            return ret;
        }
        if (from < 0) {
            from = 0;
        }
        if (to > this.length) {
            to = this.length;
        }
        for (var i = 0, walker = this.head; walker !== null && i < from; i++) {
            walker = walker.next;
        }
        for (; walker !== null && i < to; i++, walker = walker.next) {
            ret.push(walker.value);
        }
        return ret;
    };
    Yallist.prototype.sliceReverse = function (from, to) {
        to = to || this.length;
        if (to < 0) {
            to += this.length;
        }
        from = from || 0;
        if (from < 0) {
            from += this.length;
        }
        var ret = new Yallist();
        if (to < from || to < 0) {
            return ret;
        }
        if (from < 0) {
            from = 0;
        }
        if (to > this.length) {
            to = this.length;
        }
        for (var i = this.length, walker = this.tail; walker !== null && i > to; i--) {
            walker = walker.prev;
        }
        for (; walker !== null && i > from; i--, walker = walker.prev) {
            ret.push(walker.value);
        }
        return ret;
    };
    Yallist.prototype.splice = function (start, deleteCount, ...nodes) {
        if (start > this.length) {
            start = this.length - 1;
        }
        if (start < 0) {
            start = this.length + start;
        }
        for (var i = 0, walker = this.head; walker !== null && i < start; i++) {
            walker = walker.next;
        }
        var ret = [];
        for (var i = 0; walker && i < deleteCount; i++) {
            ret.push(walker.value);
            walker = this.removeNode(walker);
        }
        if (walker === null) {
            walker = this.tail;
        }
        if (walker !== this.head && walker !== this.tail) {
            walker = walker.prev;
        }
        for (var i = 0; i < nodes.length; i++) {
            walker = insert(this, walker, nodes[i]);
        }
        return ret;
    };
    Yallist.prototype.reverse = function () {
        var head = this.head;
        var tail = this.tail;
        for (var walker = head; walker !== null; walker = walker.prev) {
            var p = walker.prev;
            walker.prev = walker.next;
            walker.next = p;
        }
        this.head = tail;
        this.tail = head;
        return this;
    };
    function insert(self, node, value) {
        var inserted = node === self.head ?
            new Node(value, null, node, self) :
            new Node(value, node, node.next, self);
        if (inserted.next === null) {
            self.tail = inserted;
        }
        if (inserted.prev === null) {
            self.head = inserted;
        }
        self.length++;
        return inserted;
    }
    function push(self, item) {
        self.tail = new Node(item, self.tail, null, self);
        if (!self.head) {
            self.head = self.tail;
        }
        self.length++;
    }
    function unshift(self, item) {
        self.head = new Node(item, null, self.head, self);
        if (!self.tail) {
            self.tail = self.head;
        }
        self.length++;
    }
    function Node(value, prev, next, list) {
        if (!(this instanceof Node)) {
            return new Node(value, prev, next, list);
        }
        this.list = list;
        this.value = value;
        if (prev) {
            prev.next = this;
            this.prev = prev;
        }
        else {
            this.prev = null;
        }
        if (next) {
            next.prev = this;
            this.next = next;
        }
        else {
            this.next = null;
        }
    }
    try {
        // add if support for Symbol.iterator is present
        require(836) /* ./iterator.js */(Yallist);
    }
    catch (er) { }
},
/* yallist/iterator.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = function (Yallist) {
        Yallist.prototype[Symbol.iterator] = function* () {
            for (let walker = this.head; walker; walker = walker.next) {
                yield walker.value;
            }
        };
    };
},
/* semver/functions/satisfies.js */ function _(require, module, exports, __esModule, __esExport) {
    const Range = require(833) /* ../classes/range */;
    const satisfies = (version, range, options) => {
        try {
            range = new Range(range, options);
        }
        catch (er) {
            return false;
        }
        return range.test(version);
    };
    module.exports = satisfies;
},
/* semver/ranges/to-comparators.js */ function _(require, module, exports, __esModule, __esExport) {
    const Range = require(833) /* ../classes/range */;
    // Mostly just for testing and legacy API reasons
    const toComparators = (range, options) => new Range(range, options).set
        .map(comp => comp.map(c => c.value).join(' ').trim().split(' '));
    module.exports = toComparators;
},
/* semver/ranges/max-satisfying.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const Range = require(833) /* ../classes/range */;
    const maxSatisfying = (versions, range, options) => {
        let max = null;
        let maxSV = null;
        let rangeObj = null;
        try {
            rangeObj = new Range(range, options);
        }
        catch (er) {
            return null;
        }
        versions.forEach((v) => {
            if (rangeObj.test(v)) {
                // satisfies(v, range, options)
                if (!max || maxSV.compare(v) === -1) {
                    // compare(max, v, true)
                    max = v;
                    maxSV = new SemVer(max, options);
                }
            }
        });
        return max;
    };
    module.exports = maxSatisfying;
},
/* semver/ranges/min-satisfying.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const Range = require(833) /* ../classes/range */;
    const minSatisfying = (versions, range, options) => {
        let min = null;
        let minSV = null;
        let rangeObj = null;
        try {
            rangeObj = new Range(range, options);
        }
        catch (er) {
            return null;
        }
        versions.forEach((v) => {
            if (rangeObj.test(v)) {
                // satisfies(v, range, options)
                if (!min || minSV.compare(v) === 1) {
                    // compare(min, v, true)
                    min = v;
                    minSV = new SemVer(min, options);
                }
            }
        });
        return min;
    };
    module.exports = minSatisfying;
},
/* semver/ranges/min-version.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const Range = require(833) /* ../classes/range */;
    const gt = require(825) /* ../functions/gt */;
    const minVersion = (range, loose) => {
        range = new Range(range, loose);
        let minver = new SemVer('0.0.0');
        if (range.test(minver)) {
            return minver;
        }
        minver = new SemVer('0.0.0-0');
        if (range.test(minver)) {
            return minver;
        }
        minver = null;
        for (let i = 0; i < range.set.length; ++i) {
            const comparators = range.set[i];
            let setMin = null;
            comparators.forEach((comparator) => {
                // Clone to avoid manipulating the comparator's semver object.
                const compver = new SemVer(comparator.semver.version);
                switch (comparator.operator) {
                    case '>':
                        if (compver.prerelease.length === 0) {
                            compver.patch++;
                        }
                        else {
                            compver.prerelease.push(0);
                        }
                        compver.raw = compver.format();
                    /* fallthrough */
                    case '':
                    case '>=':
                        if (!setMin || gt(compver, setMin)) {
                            setMin = compver;
                        }
                        break;
                    case '<':
                    case '<=':
                        /* Ignore maximum versions */
                        break;
                    /* istanbul ignore next */
                    default:
                        throw new Error(`Unexpected operation: ${comparator.operator}`);
                }
            });
            if (setMin && (!minver || gt(minver, setMin))) {
                minver = setMin;
            }
        }
        if (minver && range.test(minver)) {
            return minver;
        }
        return null;
    };
    module.exports = minVersion;
},
/* semver/ranges/valid.js */ function _(require, module, exports, __esModule, __esExport) {
    const Range = require(833) /* ../classes/range */;
    const validRange = (range, options) => {
        try {
            // Return '*' instead of '' so that truthiness works.
            // This will throw if it's invalid anyway
            return new Range(range, options).range || '*';
        }
        catch (er) {
            return null;
        }
    };
    module.exports = validRange;
},
/* semver/ranges/outside.js */ function _(require, module, exports, __esModule, __esExport) {
    const SemVer = require(806) /* ../classes/semver */;
    const Comparator = require(832) /* ../classes/comparator */;
    const { ANY } = Comparator;
    const Range = require(833) /* ../classes/range */;
    const satisfies = require(837) /* ../functions/satisfies */;
    const gt = require(825) /* ../functions/gt */;
    const lt = require(826) /* ../functions/lt */;
    const lte = require(829) /* ../functions/lte */;
    const gte = require(828) /* ../functions/gte */;
    const outside = (version, range, hilo, options) => {
        version = new SemVer(version, options);
        range = new Range(range, options);
        let gtfn, ltefn, ltfn, comp, ecomp;
        switch (hilo) {
            case '>':
                gtfn = gt;
                ltefn = lte;
                ltfn = lt;
                comp = '>';
                ecomp = '>=';
                break;
            case '<':
                gtfn = lt;
                ltefn = gte;
                ltfn = gt;
                comp = '<';
                ecomp = '<=';
                break;
            default:
                throw new TypeError('Must provide a hilo val of "<" or ">"');
        }
        // If it satisfies the range it is not outside
        if (satisfies(version, range, options)) {
            return false;
        }
        // From now on, variable terms are as if we're in "gtr" mode.
        // but note that everything is flipped for the "ltr" function.
        for (let i = 0; i < range.set.length; ++i) {
            const comparators = range.set[i];
            let high = null;
            let low = null;
            comparators.forEach((comparator) => {
                if (comparator.semver === ANY) {
                    comparator = new Comparator('>=0.0.0');
                }
                high = high || comparator;
                low = low || comparator;
                if (gtfn(comparator.semver, high.semver, options)) {
                    high = comparator;
                }
                else if (ltfn(comparator.semver, low.semver, options)) {
                    low = comparator;
                }
            });
            // If the edge version comparator has a operator then our version
            // isn't outside it
            if (high.operator === comp || high.operator === ecomp) {
                return false;
            }
            // If the lowest version comparator has an operator and our version
            // is less than it then it isn't higher than the range
            if ((!low.operator || low.operator === comp) &&
                ltefn(version, low.semver)) {
                return false;
            }
            else if (low.operator === ecomp && ltfn(version, low.semver)) {
                return false;
            }
        }
        return true;
    };
    module.exports = outside;
},
/* semver/ranges/gtr.js */ function _(require, module, exports, __esModule, __esExport) {
    // Determine if version is greater than all the versions possible in the range.
    const outside = require(843) /* ./outside */;
    const gtr = (version, range, options) => outside(version, range, '>', options);
    module.exports = gtr;
},
/* semver/ranges/ltr.js */ function _(require, module, exports, __esModule, __esExport) {
    const outside = require(843) /* ./outside */;
    // Determine if version is less than all the versions possible in the range
    const ltr = (version, range, options) => outside(version, range, '<', options);
    module.exports = ltr;
},
/* semver/ranges/intersects.js */ function _(require, module, exports, __esModule, __esExport) {
    const Range = require(833) /* ../classes/range */;
    const intersects = (r1, r2, options) => {
        r1 = new Range(r1, options);
        r2 = new Range(r2, options);
        return r1.intersects(r2);
    };
    module.exports = intersects;
},
/* semver/ranges/simplify.js */ function _(require, module, exports, __esModule, __esExport) {
    // given a set of versions and a range, create a "simplified" range
    // that includes the same versions that the original range does
    // If the original range is shorter than the simplified one, return that.
    const satisfies = require(837) /* ../functions/satisfies.js */;
    const compare = require(815) /* ../functions/compare.js */;
    module.exports = (versions, range, options) => {
        const set = [];
        let first = null;
        let prev = null;
        const v = versions.sort((a, b) => compare(a, b, options));
        for (const version of v) {
            const included = satisfies(version, range, options);
            if (included) {
                prev = version;
                if (!first) {
                    first = version;
                }
            }
            else {
                if (prev) {
                    set.push([first, prev]);
                }
                prev = null;
                first = null;
            }
        }
        if (first) {
            set.push([first, null]);
        }
        const ranges = [];
        for (const [min, max] of set) {
            if (min === max) {
                ranges.push(min);
            }
            else if (!max && min === v[0]) {
                ranges.push('*');
            }
            else if (!max) {
                ranges.push(`>=${min}`);
            }
            else if (min === v[0]) {
                ranges.push(`<=${max}`);
            }
            else {
                ranges.push(`${min} - ${max}`);
            }
        }
        const simplified = ranges.join(' || ');
        const original = typeof range.raw === 'string' ? range.raw : String(range);
        return simplified.length < original.length ? simplified : range;
    };
},
/* semver/ranges/subset.js */ function _(require, module, exports, __esModule, __esExport) {
    const Range = require(833) /* ../classes/range.js */;
    const Comparator = require(832) /* ../classes/comparator.js */;
    const { ANY } = Comparator;
    const satisfies = require(837) /* ../functions/satisfies.js */;
    const compare = require(815) /* ../functions/compare.js */;
    // Complex range `r1 || r2 || ...` is a subset of `R1 || R2 || ...` iff:
    // - Every simple range `r1, r2, ...` is a null set, OR
    // - Every simple range `r1, r2, ...` which is not a null set is a subset of
    //   some `R1, R2, ...`
    //
    // Simple range `c1 c2 ...` is a subset of simple range `C1 C2 ...` iff:
    // - If c is only the ANY comparator
    //   - If C is only the ANY comparator, return true
    //   - Else if in prerelease mode, return false
    //   - else replace c with `[>=0.0.0]`
    // - If C is only the ANY comparator
    //   - if in prerelease mode, return true
    //   - else replace C with `[>=0.0.0]`
    // - Let EQ be the set of = comparators in c
    // - If EQ is more than one, return true (null set)
    // - Let GT be the highest > or >= comparator in c
    // - Let LT be the lowest < or <= comparator in c
    // - If GT and LT, and GT.semver > LT.semver, return true (null set)
    // - If any C is a = range, and GT or LT are set, return false
    // - If EQ
    //   - If GT, and EQ does not satisfy GT, return true (null set)
    //   - If LT, and EQ does not satisfy LT, return true (null set)
    //   - If EQ satisfies every C, return true
    //   - Else return false
    // - If GT
    //   - If GT.semver is lower than any > or >= comp in C, return false
    //   - If GT is >=, and GT.semver does not satisfy every C, return false
    //   - If GT.semver has a prerelease, and not in prerelease mode
    //     - If no C has a prerelease and the GT.semver tuple, return false
    // - If LT
    //   - If LT.semver is greater than any < or <= comp in C, return false
    //   - If LT is <=, and LT.semver does not satisfy every C, return false
    //   - If GT.semver has a prerelease, and not in prerelease mode
    //     - If no C has a prerelease and the LT.semver tuple, return false
    // - Else return true
    const subset = (sub, dom, options = {}) => {
        if (sub === dom) {
            return true;
        }
        sub = new Range(sub, options);
        dom = new Range(dom, options);
        let sawNonNull = false;
        OUTER: for (const simpleSub of sub.set) {
            for (const simpleDom of dom.set) {
                const isSub = simpleSubset(simpleSub, simpleDom, options);
                sawNonNull = sawNonNull || isSub !== null;
                if (isSub) {
                    continue OUTER;
                }
            }
            // the null set is a subset of everything, but null simple ranges in
            // a complex range should be ignored.  so if we saw a non-null range,
            // then we know this isn't a subset, but if EVERY simple range was null,
            // then it is a subset.
            if (sawNonNull) {
                return false;
            }
        }
        return true;
    };
    const simpleSubset = (sub, dom, options) => {
        if (sub === dom) {
            return true;
        }
        if (sub.length === 1 && sub[0].semver === ANY) {
            if (dom.length === 1 && dom[0].semver === ANY) {
                return true;
            }
            else if (options.includePrerelease) {
                sub = [new Comparator('>=0.0.0-0')];
            }
            else {
                sub = [new Comparator('>=0.0.0')];
            }
        }
        if (dom.length === 1 && dom[0].semver === ANY) {
            if (options.includePrerelease) {
                return true;
            }
            else {
                dom = [new Comparator('>=0.0.0')];
            }
        }
        const eqSet = new Set();
        let gt, lt;
        for (const c of sub) {
            if (c.operator === '>' || c.operator === '>=') {
                gt = higherGT(gt, c, options);
            }
            else if (c.operator === '<' || c.operator === '<=') {
                lt = lowerLT(lt, c, options);
            }
            else {
                eqSet.add(c.semver);
            }
        }
        if (eqSet.size > 1) {
            return null;
        }
        let gtltComp;
        if (gt && lt) {
            gtltComp = compare(gt.semver, lt.semver, options);
            if (gtltComp > 0) {
                return null;
            }
            else if (gtltComp === 0 && (gt.operator !== '>=' || lt.operator !== '<=')) {
                return null;
            }
        }
        // will iterate one or zero times
        for (const eq of eqSet) {
            if (gt && !satisfies(eq, String(gt), options)) {
                return null;
            }
            if (lt && !satisfies(eq, String(lt), options)) {
                return null;
            }
            for (const c of dom) {
                if (!satisfies(eq, String(c), options)) {
                    return false;
                }
            }
            return true;
        }
        let higher, lower;
        let hasDomLT, hasDomGT;
        // if the subset has a prerelease, we need a comparator in the superset
        // with the same tuple and a prerelease, or it's not a subset
        let needDomLTPre = lt &&
            !options.includePrerelease &&
            lt.semver.prerelease.length ? lt.semver : false;
        let needDomGTPre = gt &&
            !options.includePrerelease &&
            gt.semver.prerelease.length ? gt.semver : false;
        // exception: <1.2.3-0 is the same as <1.2.3
        if (needDomLTPre && needDomLTPre.prerelease.length === 1 &&
            lt.operator === '<' && needDomLTPre.prerelease[0] === 0) {
            needDomLTPre = false;
        }
        for (const c of dom) {
            hasDomGT = hasDomGT || c.operator === '>' || c.operator === '>=';
            hasDomLT = hasDomLT || c.operator === '<' || c.operator === '<=';
            if (gt) {
                if (needDomGTPre) {
                    if (c.semver.prerelease && c.semver.prerelease.length &&
                        c.semver.major === needDomGTPre.major &&
                        c.semver.minor === needDomGTPre.minor &&
                        c.semver.patch === needDomGTPre.patch) {
                        needDomGTPre = false;
                    }
                }
                if (c.operator === '>' || c.operator === '>=') {
                    higher = higherGT(gt, c, options);
                    if (higher === c && higher !== gt) {
                        return false;
                    }
                }
                else if (gt.operator === '>=' && !satisfies(gt.semver, String(c), options)) {
                    return false;
                }
            }
            if (lt) {
                if (needDomLTPre) {
                    if (c.semver.prerelease && c.semver.prerelease.length &&
                        c.semver.major === needDomLTPre.major &&
                        c.semver.minor === needDomLTPre.minor &&
                        c.semver.patch === needDomLTPre.patch) {
                        needDomLTPre = false;
                    }
                }
                if (c.operator === '<' || c.operator === '<=') {
                    lower = lowerLT(lt, c, options);
                    if (lower === c && lower !== lt) {
                        return false;
                    }
                }
                else if (lt.operator === '<=' && !satisfies(lt.semver, String(c), options)) {
                    return false;
                }
            }
            if (!c.operator && (lt || gt) && gtltComp !== 0) {
                return false;
            }
        }
        // if there was a < or >, and nothing in the dom, then must be false
        // UNLESS it was limited by another range in the other direction.
        // Eg, >1.0.0 <1.0.1 is still a subset of <2.0.0
        if (gt && hasDomLT && !lt && gtltComp !== 0) {
            return false;
        }
        if (lt && hasDomGT && !gt && gtltComp !== 0) {
            return false;
        }
        // we needed a prerelease range in a specific tuple, but didn't get one
        // then this isn't a subset.  eg >=1.2.3-pre is not a subset of >=1.0.0,
        // because it includes prereleases in the 1.2.3 tuple
        if (needDomGTPre || needDomLTPre) {
            return false;
        }
        return true;
    };
    // >=1.2.3 is lower than >1.2.3
    const higherGT = (a, b, options) => {
        if (!a) {
            return b;
        }
        const comp = compare(a.semver, b.semver, options);
        return comp > 0 ? a
            : comp < 0 ? b
                : b.operator === '>' && a.operator === '>=' ? b
                    : a;
    };
    // <=1.2.3 is higher than <1.2.3
    const lowerLT = (a, b, options) => {
        if (!a) {
            return b;
        }
        const comp = compare(a.semver, b.semver, options);
        return comp < 0 ? a
            : comp > 0 ? b
                : b.operator === '<' && a.operator === '<=' ? b
                    : a;
    };
    module.exports = subset;
},
/* @typescript-eslint/utils/dist/ts-eslint/RuleTester.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.RuleTester = void 0;
    const eslint_1 = require(216) /* eslint */;
    class RuleTester extends eslint_1.RuleTester {
    }
    exports.RuleTester = RuleTester;
    
},
/* @typescript-eslint/utils/dist/eslint-utils/rule-tester/dependencyConstraints.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.satisfiesAllDependencyConstraints = void 0;
    const semver = __importStar(require(802) /* semver */);
    const BASE_SATISFIES_OPTIONS = {
        includePrerelease: true,
    };
    function satisfiesDependencyConstraint(packageName, constraintIn) {
        const constraint = typeof constraintIn === 'string'
            ? {
                range: `>=${constraintIn}`,
            }
            : constraintIn;
        return semver.satisfies(require(`${packageName}/package.json`).version, constraint.range, typeof constraint.options === 'object'
            ? Object.assign(Object.assign({}, BASE_SATISFIES_OPTIONS), constraint.options) : constraint.options);
    }
    function satisfiesAllDependencyConstraints(dependencyConstraints) {
        if (dependencyConstraints == null) {
            return true;
        }
        for (const [packageName, constraint] of Object.entries(dependencyConstraints)) {
            if (!satisfiesDependencyConstraint(packageName, constraint)) {
                return false;
            }
        }
        return true;
    }
    exports.satisfiesAllDependencyConstraints = satisfiesAllDependencyConstraints;
    
},
/* @typescript-eslint/utils/dist/eslint-utils/nullThrows.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.NullThrowsReasons = exports.nullThrows = void 0;
    /**
     * A set of common reasons for calling nullThrows
     */
    const NullThrowsReasons = {
        MissingParent: 'Expected node to have a parent.',
        MissingToken: (token, thing) => `Expected to find a ${token} for the ${thing}.`,
    };
    exports.NullThrowsReasons = NullThrowsReasons;
    /**
     * Assert that a value must not be null or undefined.
     * This is a nice explicit alternative to the non-null assertion operator.
     */
    function nullThrows(value, message) {
        // this function is primarily used to keep types happy in a safe way
        // i.e. is used when we expect that a value is never nullish
        // this means that it's pretty much impossible to test the below if...
        // so ignore it in coverage metrics.
        /* istanbul ignore if */
        if (value == null) {
            throw new Error(`Non-null Assertion Failed: ${message}`);
        }
        return value;
    }
    exports.nullThrows = nullThrows;
    
},
/* @typescript-eslint/utils/dist/json-schema.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Note - @types/json-schema@7.0.4 added some function declarations to the type package
    // If we do export *, then it will also export these function declarations.
    // This will cause typescript to not scrub the require from the build, breaking anyone who doesn't have it as a dependency
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/utils/dist/ts-eslint/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    __exportStar(require(854) /* ./AST */, exports);
    __exportStar(require(855) /* ./CLIEngine */, exports);
    __exportStar(require(856) /* ./ESLint */, exports);
    __exportStar(require(857) /* ./Linter */, exports);
    __exportStar(require(858) /* ./ParserOptions */, exports);
    __exportStar(require(859) /* ./Rule */, exports);
    __exportStar(require(849) /* ./RuleTester */, exports);
    __exportStar(require(860) /* ./Scope */, exports);
    __exportStar(require(1007) /* ./SourceCode */, exports);
    
},
/* @typescript-eslint/utils/dist/ts-eslint/AST.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /* eslint-disable @typescript-eslint/no-namespace */
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/utils/dist/ts-eslint/CLIEngine.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /* eslint-disable @typescript-eslint/no-namespace */
    /* eslint-disable deprecation/deprecation -- "uses" deprecated API to define the deprecated API */
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.CLIEngine = void 0;
    const eslint_1 = require(216) /* eslint */;
    /**
     * The underlying utility that runs the ESLint command line interface. This object will read the filesystem for
     * configuration and file information but will not output any results. Instead, it allows you direct access to the
     * important information so you can deal with the output yourself.
     * @deprecated use the ESLint class instead
     */
    const CLIEngine = eslint_1.CLIEngine
        ? class CLIEngine extends eslint_1.CLIEngine {
        }
        : undefined;
    exports.CLIEngine = CLIEngine;
    
},
/* @typescript-eslint/utils/dist/ts-eslint/ESLint.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /* eslint-disable @typescript-eslint/no-namespace */
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ESLint = void 0;
    const eslint_1 = require(216) /* eslint */;
    // We want to export this class always so it's easy for end users to consume.
    // However on ESLint v6, this class will not exist, so we provide a fallback to make it clear
    // The only users of this should be users scripting ESLint locally, so _they_ should have the correct version installed.
    const _ESLint = (eslint_1.ESLint !== null && eslint_1.ESLint !== void 0 ? eslint_1.ESLint : function () {
        throw new Error('Attempted to construct an ESLint instance on less than ESLint v7.0.0');
    });
    /**
     * The ESLint class is the primary class to use in Node.js applications.
     * This class depends on the Node.js fs module and the file system, so you cannot use it in browsers.
     *
     * If you want to lint code on browsers, use the Linter class instead.
     *
     * @since 7.0.0
     */
    class ESLint extends _ESLint {
    }
    exports.ESLint = ESLint;
    
},
/* @typescript-eslint/utils/dist/ts-eslint/Linter.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /* eslint-disable @typescript-eslint/no-namespace */
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Linter = void 0;
    const eslint_1 = require(216) /* eslint */;
    /**
     * The Linter object does the actual evaluation of the JavaScript code. It doesn't do any filesystem operations, it
     * simply parses and reports on the code. In particular, the Linter object does not process configuration objects
     * or files.
     */
    class Linter extends eslint_1.Linter {
    }
    exports.Linter = Linter;
    
},
/* @typescript-eslint/utils/dist/ts-eslint/ParserOptions.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/utils/dist/ts-eslint/Rule.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/utils/dist/ts-eslint/Scope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /* eslint-disable @typescript-eslint/no-namespace */
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Scope = void 0;
    const scopeManager = __importStar(require(861) /* @typescript-eslint/scope-manager */);
    var Scope;
    (function (Scope) {
        Scope.ScopeType = scopeManager.ScopeType;
        Scope.DefinitionType = scopeManager.DefinitionType;
    })(Scope || (Scope = {}));
    exports.Scope = Scope;
    
},
/* @typescript-eslint/scope-manager/dist/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ScopeManager = exports.PatternVisitor = exports.Visitor = exports.Reference = exports.analyze = void 0;
    var analyze_1 = require(862) /* ./analyze */;
    Object.defineProperty(exports, "analyze", { enumerable: true, get: function () { return analyze_1.analyze; } });
    __exportStar(require(955) /* ./definition */, exports);
    var Reference_1 = require(976) /* ./referencer/Reference */;
    Object.defineProperty(exports, "Reference", { enumerable: true, get: function () { return Reference_1.Reference; } });
    var Visitor_1 = require(1000) /* ./referencer/Visitor */;
    Object.defineProperty(exports, "Visitor", { enumerable: true, get: function () { return Visitor_1.Visitor; } });
    var PatternVisitor_1 = require(1001) /* ./referencer/PatternVisitor */;
    Object.defineProperty(exports, "PatternVisitor", { enumerable: true, get: function () { return PatternVisitor_1.PatternVisitor; } });
    __exportStar(require(973) /* ./scope */, exports);
    var ScopeManager_1 = require(1005) /* ./ScopeManager */;
    Object.defineProperty(exports, "ScopeManager", { enumerable: true, get: function () { return ScopeManager_1.ScopeManager; } });
    __exportStar(require(977) /* ./variable */, exports);
    
},
/* @typescript-eslint/scope-manager/dist/analyze.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.analyze = void 0;
    const visitor_keys_1 = require(863) /* @typescript-eslint/visitor-keys */;
    const lib_1 = require(866) /* ./lib */;
    const referencer_1 = require(952) /* ./referencer */;
    const ScopeManager_1 = require(1005) /* ./ScopeManager */;
    const DEFAULT_OPTIONS = {
        childVisitorKeys: visitor_keys_1.visitorKeys,
        ecmaVersion: 2018,
        globalReturn: false,
        impliedStrict: false,
        jsxPragma: 'React',
        jsxFragmentName: null,
        lib: ['es2018'],
        sourceType: 'script',
        emitDecoratorMetadata: false,
    };
    /**
     * Convert ecmaVersion to lib.
     * `'latest'` is converted to 1e8 at parser.
     */
    function mapEcmaVersion(version) {
        if (version == null || version === 3 || version === 5) {
            return 'es5';
        }
        const year = version > 2000 ? version : 2015 + (version - 6);
        const lib = `es${year}`;
        return lib in lib_1.lib ? lib : year > 2020 ? 'esnext' : 'es5';
    }
    /**
     * Takes an AST and returns the analyzed scopes.
     */
    function analyze(tree, providedOptions) {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        const ecmaVersion = (_a = providedOptions === null || providedOptions === void 0 ? void 0 : providedOptions.ecmaVersion) !== null && _a !== void 0 ? _a : DEFAULT_OPTIONS.ecmaVersion;
        const options = {
            childVisitorKeys: (_b = providedOptions === null || providedOptions === void 0 ? void 0 : providedOptions.childVisitorKeys) !== null && _b !== void 0 ? _b : DEFAULT_OPTIONS.childVisitorKeys,
            ecmaVersion,
            globalReturn: (_c = providedOptions === null || providedOptions === void 0 ? void 0 : providedOptions.globalReturn) !== null && _c !== void 0 ? _c : DEFAULT_OPTIONS.globalReturn,
            impliedStrict: (_d = providedOptions === null || providedOptions === void 0 ? void 0 : providedOptions.impliedStrict) !== null && _d !== void 0 ? _d : DEFAULT_OPTIONS.impliedStrict,
            jsxPragma: (providedOptions === null || providedOptions === void 0 ? void 0 : providedOptions.jsxPragma) === undefined
                ? DEFAULT_OPTIONS.jsxPragma
                : providedOptions.jsxPragma,
            jsxFragmentName: (_e = providedOptions === null || providedOptions === void 0 ? void 0 : providedOptions.jsxFragmentName) !== null && _e !== void 0 ? _e : DEFAULT_OPTIONS.jsxFragmentName,
            sourceType: (_f = providedOptions === null || providedOptions === void 0 ? void 0 : providedOptions.sourceType) !== null && _f !== void 0 ? _f : DEFAULT_OPTIONS.sourceType,
            lib: (_g = providedOptions === null || providedOptions === void 0 ? void 0 : providedOptions.lib) !== null && _g !== void 0 ? _g : [mapEcmaVersion(ecmaVersion)],
            emitDecoratorMetadata: (_h = providedOptions === null || providedOptions === void 0 ? void 0 : providedOptions.emitDecoratorMetadata) !== null && _h !== void 0 ? _h : DEFAULT_OPTIONS.emitDecoratorMetadata,
        };
        // ensure the option is lower cased
        options.lib = options.lib.map(l => l.toLowerCase());
        const scopeManager = new ScopeManager_1.ScopeManager(options);
        const referencer = new referencer_1.Referencer(options, scopeManager);
        referencer.visit(tree);
        return scopeManager;
    }
    exports.analyze = analyze;
    
},
/* @typescript-eslint/visitor-keys/dist/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.visitorKeys = exports.getKeys = void 0;
    var get_keys_1 = require(864) /* ./get-keys */;
    Object.defineProperty(exports, "getKeys", { enumerable: true, get: function () { return get_keys_1.getKeys; } });
    var visitor_keys_1 = require(865) /* ./visitor-keys */;
    Object.defineProperty(exports, "visitorKeys", { enumerable: true, get: function () { return visitor_keys_1.visitorKeys; } });
    
},
/* @typescript-eslint/visitor-keys/dist/get-keys.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getKeys = void 0;
    const eslint_visitor_keys_1 = require(304) /* eslint-visitor-keys */;
    const getKeys = eslint_visitor_keys_1.getKeys;
    exports.getKeys = getKeys;
    
},
/* @typescript-eslint/visitor-keys/dist/visitor-keys.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.visitorKeys = void 0;
    const eslintVisitorKeys = __importStar(require(304) /* eslint-visitor-keys */);
    /**
     * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! IMPORTANT NOTE !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     *
     * The key arrays should be sorted in the order in which you would want to visit
     * the child keys - don't just sort them alphabetically.
     */
    // eslint-disable-next-line @typescript-eslint/explicit-function-return-type -- TODO - add ignore IIFE option
    const SharedVisitorKeys = (() => {
        const FunctionType = ['typeParameters', 'params', 'returnType'];
        const AnonymousFunction = [...FunctionType, 'body'];
        const AbstractPropertyDefinition = [
            'decorators',
            'key',
            'typeAnnotation',
        ];
        return {
            AnonymousFunction,
            Function: ['id', ...AnonymousFunction],
            FunctionType,
            ClassDeclaration: [
                'decorators',
                'id',
                'typeParameters',
                'superClass',
                'superTypeParameters',
                'implements',
                'body',
            ],
            AbstractPropertyDefinition: ['decorators', 'key', 'typeAnnotation'],
            PropertyDefinition: [...AbstractPropertyDefinition, 'value'],
            TypeAssertion: ['expression', 'typeAnnotation'],
        };
    })();
    const additionalKeys = {
        AccessorProperty: SharedVisitorKeys.PropertyDefinition,
        ArrayPattern: ['decorators', 'elements', 'typeAnnotation'],
        ArrowFunctionExpression: SharedVisitorKeys.AnonymousFunction,
        AssignmentPattern: ['decorators', 'left', 'right', 'typeAnnotation'],
        CallExpression: ['callee', 'typeParameters', 'arguments'],
        ClassDeclaration: SharedVisitorKeys.ClassDeclaration,
        ClassExpression: SharedVisitorKeys.ClassDeclaration,
        Decorator: ['expression'],
        ExportAllDeclaration: ['exported', 'source', 'assertions'],
        ExportNamedDeclaration: ['declaration', 'specifiers', 'source', 'assertions'],
        FunctionDeclaration: SharedVisitorKeys.Function,
        FunctionExpression: SharedVisitorKeys.Function,
        Identifier: ['decorators', 'typeAnnotation'],
        ImportAttribute: ['key', 'value'],
        ImportDeclaration: ['specifiers', 'source', 'assertions'],
        ImportExpression: ['source', 'attributes'],
        JSXClosingFragment: [],
        JSXOpeningElement: ['name', 'typeParameters', 'attributes'],
        JSXOpeningFragment: [],
        JSXSpreadChild: ['expression'],
        MethodDefinition: ['decorators', 'key', 'value', 'typeParameters'],
        NewExpression: ['callee', 'typeParameters', 'arguments'],
        ObjectPattern: ['decorators', 'properties', 'typeAnnotation'],
        PropertyDefinition: SharedVisitorKeys.PropertyDefinition,
        RestElement: ['decorators', 'argument', 'typeAnnotation'],
        StaticBlock: ['body'],
        TaggedTemplateExpression: ['tag', 'typeParameters', 'quasi'],
        TSAbstractAccessorProperty: SharedVisitorKeys.AbstractPropertyDefinition,
        TSAbstractKeyword: [],
        TSAbstractMethodDefinition: ['key', 'value'],
        TSAbstractPropertyDefinition: SharedVisitorKeys.AbstractPropertyDefinition,
        TSAnyKeyword: [],
        TSArrayType: ['elementType'],
        TSAsExpression: SharedVisitorKeys.TypeAssertion,
        TSAsyncKeyword: [],
        TSBigIntKeyword: [],
        TSBooleanKeyword: [],
        TSCallSignatureDeclaration: SharedVisitorKeys.FunctionType,
        TSClassImplements: ['expression', 'typeParameters'],
        TSConditionalType: ['checkType', 'extendsType', 'trueType', 'falseType'],
        TSConstructorType: SharedVisitorKeys.FunctionType,
        TSConstructSignatureDeclaration: SharedVisitorKeys.FunctionType,
        TSDeclareFunction: SharedVisitorKeys.Function,
        TSDeclareKeyword: [],
        TSEmptyBodyFunctionExpression: ['id', ...SharedVisitorKeys.FunctionType],
        TSEnumDeclaration: ['id', 'members'],
        TSEnumMember: ['id', 'initializer'],
        TSExportAssignment: ['expression'],
        TSExportKeyword: [],
        TSExternalModuleReference: ['expression'],
        TSFunctionType: SharedVisitorKeys.FunctionType,
        TSImportEqualsDeclaration: ['id', 'moduleReference'],
        TSImportType: ['parameter', 'qualifier', 'typeParameters'],
        TSIndexedAccessType: ['indexType', 'objectType'],
        TSIndexSignature: ['parameters', 'typeAnnotation'],
        TSInferType: ['typeParameter'],
        TSInstantiationExpression: ['expression', 'typeParameters'],
        TSInterfaceBody: ['body'],
        TSInterfaceDeclaration: ['id', 'typeParameters', 'extends', 'body'],
        TSInterfaceHeritage: ['expression', 'typeParameters'],
        TSIntersectionType: ['types'],
        TSIntrinsicKeyword: [],
        TSLiteralType: ['literal'],
        TSMappedType: ['nameType', 'typeParameter', 'typeAnnotation'],
        TSMethodSignature: ['typeParameters', 'key', 'params', 'returnType'],
        TSModuleBlock: ['body'],
        TSModuleDeclaration: ['id', 'body'],
        TSNamedTupleMember: ['label', 'elementType'],
        TSNamespaceExportDeclaration: ['id'],
        TSNeverKeyword: [],
        TSNonNullExpression: ['expression'],
        TSNullKeyword: [],
        TSNumberKeyword: [],
        TSObjectKeyword: [],
        TSOptionalType: ['typeAnnotation'],
        TSParameterProperty: ['decorators', 'parameter'],
        TSPrivateKeyword: [],
        TSPropertySignature: ['typeAnnotation', 'key', 'initializer'],
        TSProtectedKeyword: [],
        TSPublicKeyword: [],
        TSQualifiedName: ['left', 'right'],
        TSReadonlyKeyword: [],
        TSRestType: ['typeAnnotation'],
        TSSatisfiesExpression: [
            // this is intentionally different to SharedVisitorKeys.TypeAssertion because
            // the type annotation comes first in the source code
            'typeAnnotation',
            'expression',
        ],
        TSStaticKeyword: [],
        TSStringKeyword: [],
        TSSymbolKeyword: [],
        TSTemplateLiteralType: ['quasis', 'types'],
        TSThisType: [],
        TSTupleType: ['elementTypes'],
        TSTypeAliasDeclaration: ['id', 'typeParameters', 'typeAnnotation'],
        TSTypeAnnotation: ['typeAnnotation'],
        TSTypeAssertion: SharedVisitorKeys.TypeAssertion,
        TSTypeLiteral: ['members'],
        TSTypeOperator: ['typeAnnotation'],
        TSTypeParameter: ['name', 'constraint', 'default'],
        TSTypeParameterDeclaration: ['params'],
        TSTypeParameterInstantiation: ['params'],
        TSTypePredicate: ['typeAnnotation', 'parameterName'],
        TSTypeQuery: ['exprName', 'typeParameters'],
        TSTypeReference: ['typeName', 'typeParameters'],
        TSUndefinedKeyword: [],
        TSUnionType: ['types'],
        TSUnknownKeyword: [],
        TSVoidKeyword: [],
    };
    const visitorKeys = eslintVisitorKeys.unionWith(additionalKeys);
    exports.visitorKeys = visitorKeys;
    
},
/* @typescript-eslint/scope-manager/dist/lib/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.lib = void 0;
    const decorators_1 = require(867) /* ./decorators */;
    const decorators_legacy_1 = require(869) /* ./decorators.legacy */;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const es5_1 = require(872) /* ./es5 */;
    const es6_1 = require(873) /* ./es6 */;
    const es7_1 = require(883) /* ./es7 */;
    const es2015_1 = require(884) /* ./es2015 */;
    const es2015_collection_1 = require(874) /* ./es2015.collection */;
    const es2015_core_1 = require(875) /* ./es2015.core */;
    const es2015_generator_1 = require(876) /* ./es2015.generator */;
    const es2015_iterable_1 = require(877) /* ./es2015.iterable */;
    const es2015_promise_1 = require(879) /* ./es2015.promise */;
    const es2015_proxy_1 = require(880) /* ./es2015.proxy */;
    const es2015_reflect_1 = require(881) /* ./es2015.reflect */;
    const es2015_symbol_1 = require(878) /* ./es2015.symbol */;
    const es2015_symbol_wellknown_1 = require(882) /* ./es2015.symbol.wellknown */;
    const es2016_1 = require(886) /* ./es2016 */;
    const es2016_array_include_1 = require(885) /* ./es2016.array.include */;
    const es2016_full_1 = require(887) /* ./es2016.full */;
    const es2017_1 = require(890) /* ./es2017 */;
    const es2017_full_1 = require(896) /* ./es2017.full */;
    const es2017_intl_1 = require(891) /* ./es2017.intl */;
    const es2017_object_1 = require(892) /* ./es2017.object */;
    const es2017_sharedmemory_1 = require(893) /* ./es2017.sharedmemory */;
    const es2017_string_1 = require(894) /* ./es2017.string */;
    const es2017_typedarrays_1 = require(895) /* ./es2017.typedarrays */;
    const es2018_1 = require(897) /* ./es2018 */;
    const es2018_asyncgenerator_1 = require(898) /* ./es2018.asyncgenerator */;
    const es2018_asynciterable_1 = require(899) /* ./es2018.asynciterable */;
    const es2018_full_1 = require(903) /* ./es2018.full */;
    const es2018_intl_1 = require(900) /* ./es2018.intl */;
    const es2018_promise_1 = require(901) /* ./es2018.promise */;
    const es2018_regexp_1 = require(902) /* ./es2018.regexp */;
    const es2019_1 = require(904) /* ./es2019 */;
    const es2019_array_1 = require(905) /* ./es2019.array */;
    const es2019_full_1 = require(910) /* ./es2019.full */;
    const es2019_intl_1 = require(906) /* ./es2019.intl */;
    const es2019_object_1 = require(907) /* ./es2019.object */;
    const es2019_string_1 = require(908) /* ./es2019.string */;
    const es2019_symbol_1 = require(909) /* ./es2019.symbol */;
    const es2020_1 = require(911) /* ./es2020 */;
    const es2020_bigint_1 = require(912) /* ./es2020.bigint */;
    const es2020_date_1 = require(914) /* ./es2020.date */;
    const es2020_full_1 = require(920) /* ./es2020.full */;
    const es2020_intl_1 = require(913) /* ./es2020.intl */;
    const es2020_number_1 = require(915) /* ./es2020.number */;
    const es2020_promise_1 = require(916) /* ./es2020.promise */;
    const es2020_sharedmemory_1 = require(917) /* ./es2020.sharedmemory */;
    const es2020_string_1 = require(918) /* ./es2020.string */;
    const es2020_symbol_wellknown_1 = require(919) /* ./es2020.symbol.wellknown */;
    const es2021_1 = require(921) /* ./es2021 */;
    const es2021_full_1 = require(926) /* ./es2021.full */;
    const es2021_intl_1 = require(922) /* ./es2021.intl */;
    const es2021_promise_1 = require(923) /* ./es2021.promise */;
    const es2021_string_1 = require(924) /* ./es2021.string */;
    const es2021_weakref_1 = require(925) /* ./es2021.weakref */;
    const es2022_1 = require(927) /* ./es2022 */;
    const es2022_array_1 = require(928) /* ./es2022.array */;
    const es2022_error_1 = require(929) /* ./es2022.error */;
    const es2022_full_1 = require(935) /* ./es2022.full */;
    const es2022_intl_1 = require(930) /* ./es2022.intl */;
    const es2022_object_1 = require(931) /* ./es2022.object */;
    const es2022_regexp_1 = require(932) /* ./es2022.regexp */;
    const es2022_sharedmemory_1 = require(933) /* ./es2022.sharedmemory */;
    const es2022_string_1 = require(934) /* ./es2022.string */;
    const es2023_1 = require(936) /* ./es2023 */;
    const es2023_array_1 = require(937) /* ./es2023.array */;
    const es2023_full_1 = require(938) /* ./es2023.full */;
    const esnext_1 = require(939) /* ./esnext */;
    const esnext_array_1 = require(941) /* ./esnext.array */;
    const esnext_asynciterable_1 = require(942) /* ./esnext.asynciterable */;
    const esnext_bigint_1 = require(943) /* ./esnext.bigint */;
    const esnext_full_1 = require(944) /* ./esnext.full */;
    const esnext_intl_1 = require(940) /* ./esnext.intl */;
    const esnext_promise_1 = require(945) /* ./esnext.promise */;
    const esnext_string_1 = require(946) /* ./esnext.string */;
    const esnext_symbol_1 = require(947) /* ./esnext.symbol */;
    const esnext_weakref_1 = require(948) /* ./esnext.weakref */;
    const lib_1 = require(949) /* ./lib */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_1 = require(950) /* ./webworker */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    const webworker_iterable_1 = require(951) /* ./webworker.iterable */;
    const lib = {
        es5: es5_1.es5,
        es6: es6_1.es6,
        es2015: es2015_1.es2015,
        es7: es7_1.es7,
        es2016: es2016_1.es2016,
        es2017: es2017_1.es2017,
        es2018: es2018_1.es2018,
        es2019: es2019_1.es2019,
        es2020: es2020_1.es2020,
        es2021: es2021_1.es2021,
        es2022: es2022_1.es2022,
        es2023: es2023_1.es2023,
        esnext: esnext_1.esnext,
        dom: dom_1.dom,
        'dom.iterable': dom_iterable_1.dom_iterable,
        webworker: webworker_1.webworker,
        'webworker.importscripts': webworker_importscripts_1.webworker_importscripts,
        'webworker.iterable': webworker_iterable_1.webworker_iterable,
        scripthost: scripthost_1.scripthost,
        'es2015.core': es2015_core_1.es2015_core,
        'es2015.collection': es2015_collection_1.es2015_collection,
        'es2015.generator': es2015_generator_1.es2015_generator,
        'es2015.iterable': es2015_iterable_1.es2015_iterable,
        'es2015.promise': es2015_promise_1.es2015_promise,
        'es2015.proxy': es2015_proxy_1.es2015_proxy,
        'es2015.reflect': es2015_reflect_1.es2015_reflect,
        'es2015.symbol': es2015_symbol_1.es2015_symbol,
        'es2015.symbol.wellknown': es2015_symbol_wellknown_1.es2015_symbol_wellknown,
        'es2016.array.include': es2016_array_include_1.es2016_array_include,
        'es2017.object': es2017_object_1.es2017_object,
        'es2017.sharedmemory': es2017_sharedmemory_1.es2017_sharedmemory,
        'es2017.string': es2017_string_1.es2017_string,
        'es2017.intl': es2017_intl_1.es2017_intl,
        'es2017.typedarrays': es2017_typedarrays_1.es2017_typedarrays,
        'es2018.asyncgenerator': es2018_asyncgenerator_1.es2018_asyncgenerator,
        'es2018.asynciterable': es2018_asynciterable_1.es2018_asynciterable,
        'es2018.intl': es2018_intl_1.es2018_intl,
        'es2018.promise': es2018_promise_1.es2018_promise,
        'es2018.regexp': es2018_regexp_1.es2018_regexp,
        'es2019.array': es2019_array_1.es2019_array,
        'es2019.object': es2019_object_1.es2019_object,
        'es2019.string': es2019_string_1.es2019_string,
        'es2019.symbol': es2019_symbol_1.es2019_symbol,
        'es2019.intl': es2019_intl_1.es2019_intl,
        'es2020.bigint': es2020_bigint_1.es2020_bigint,
        'es2020.date': es2020_date_1.es2020_date,
        'es2020.promise': es2020_promise_1.es2020_promise,
        'es2020.sharedmemory': es2020_sharedmemory_1.es2020_sharedmemory,
        'es2020.string': es2020_string_1.es2020_string,
        'es2020.symbol.wellknown': es2020_symbol_wellknown_1.es2020_symbol_wellknown,
        'es2020.intl': es2020_intl_1.es2020_intl,
        'es2020.number': es2020_number_1.es2020_number,
        'es2021.promise': es2021_promise_1.es2021_promise,
        'es2021.string': es2021_string_1.es2021_string,
        'es2021.weakref': es2021_weakref_1.es2021_weakref,
        'es2021.intl': es2021_intl_1.es2021_intl,
        'es2022.array': es2022_array_1.es2022_array,
        'es2022.error': es2022_error_1.es2022_error,
        'es2022.intl': es2022_intl_1.es2022_intl,
        'es2022.object': es2022_object_1.es2022_object,
        'es2022.sharedmemory': es2022_sharedmemory_1.es2022_sharedmemory,
        'es2022.string': es2022_string_1.es2022_string,
        'es2022.regexp': es2022_regexp_1.es2022_regexp,
        'es2023.array': es2023_array_1.es2023_array,
        'esnext.array': esnext_array_1.esnext_array,
        'esnext.symbol': esnext_symbol_1.esnext_symbol,
        'esnext.asynciterable': esnext_asynciterable_1.esnext_asynciterable,
        'esnext.intl': esnext_intl_1.esnext_intl,
        'esnext.bigint': esnext_bigint_1.esnext_bigint,
        'esnext.string': esnext_string_1.esnext_string,
        'esnext.promise': esnext_promise_1.esnext_promise,
        'esnext.weakref': esnext_weakref_1.esnext_weakref,
        decorators: decorators_1.decorators,
        'decorators.legacy': decorators_legacy_1.decorators_legacy,
        'es2016.full': es2016_full_1.es2016_full,
        'es2017.full': es2017_full_1.es2017_full,
        'es2018.full': es2018_full_1.es2018_full,
        'es2019.full': es2019_full_1.es2019_full,
        'es2020.full': es2020_full_1.es2020_full,
        'es2021.full': es2021_full_1.es2021_full,
        'es2022.full': es2022_full_1.es2022_full,
        'es2023.full': es2023_full_1.es2023_full,
        'esnext.full': esnext_full_1.esnext_full,
        lib: lib_1.lib,
    };
    exports.lib = lib;
    
},
/* @typescript-eslint/scope-manager/dist/lib/decorators.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.decorators = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.decorators = {
        ClassMemberDecoratorContext: base_config_1.TYPE,
        DecoratorContext: base_config_1.TYPE,
        ClassDecoratorContext: base_config_1.TYPE,
        ClassMethodDecoratorContext: base_config_1.TYPE,
        ClassGetterDecoratorContext: base_config_1.TYPE,
        ClassSetterDecoratorContext: base_config_1.TYPE,
        ClassAccessorDecoratorContext: base_config_1.TYPE,
        ClassAccessorDecoratorTarget: base_config_1.TYPE,
        ClassAccessorDecoratorResult: base_config_1.TYPE,
        ClassFieldDecoratorContext: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/base-config.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TYPE_VALUE = exports.VALUE = exports.TYPE = void 0;
    exports.TYPE = Object.freeze({
        eslintImplicitGlobalSetting: 'readonly',
        isTypeVariable: true,
        isValueVariable: false,
    });
    exports.VALUE = Object.freeze({
        eslintImplicitGlobalSetting: 'readonly',
        isTypeVariable: false,
        isValueVariable: true,
    });
    exports.TYPE_VALUE = Object.freeze({
        eslintImplicitGlobalSetting: 'readonly',
        isTypeVariable: true,
        isValueVariable: true,
    });
    
},
/* @typescript-eslint/scope-manager/dist/lib/decorators.legacy.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.decorators_legacy = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.decorators_legacy = {
        ClassDecorator: base_config_1.TYPE,
        PropertyDecorator: base_config_1.TYPE,
        MethodDecorator: base_config_1.TYPE,
        ParameterDecorator: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/dom.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.dom = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.dom = {
        AddEventListenerOptions: base_config_1.TYPE,
        AesCbcParams: base_config_1.TYPE,
        AesCtrParams: base_config_1.TYPE,
        AesDerivedKeyParams: base_config_1.TYPE,
        AesGcmParams: base_config_1.TYPE,
        AesKeyAlgorithm: base_config_1.TYPE,
        AesKeyGenParams: base_config_1.TYPE,
        Algorithm: base_config_1.TYPE,
        AnalyserOptions: base_config_1.TYPE,
        AnimationEventInit: base_config_1.TYPE,
        AnimationPlaybackEventInit: base_config_1.TYPE,
        AssignedNodesOptions: base_config_1.TYPE,
        AudioBufferOptions: base_config_1.TYPE,
        AudioBufferSourceOptions: base_config_1.TYPE,
        AudioConfiguration: base_config_1.TYPE,
        AudioContextOptions: base_config_1.TYPE,
        AudioNodeOptions: base_config_1.TYPE,
        AudioProcessingEventInit: base_config_1.TYPE,
        AudioTimestamp: base_config_1.TYPE,
        AudioWorkletNodeOptions: base_config_1.TYPE,
        AuthenticationExtensionsClientInputs: base_config_1.TYPE,
        AuthenticationExtensionsClientOutputs: base_config_1.TYPE,
        AuthenticatorSelectionCriteria: base_config_1.TYPE,
        BiquadFilterOptions: base_config_1.TYPE,
        BlobEventInit: base_config_1.TYPE,
        BlobPropertyBag: base_config_1.TYPE,
        CSSStyleSheetInit: base_config_1.TYPE,
        CacheQueryOptions: base_config_1.TYPE,
        CanvasRenderingContext2DSettings: base_config_1.TYPE,
        ChannelMergerOptions: base_config_1.TYPE,
        ChannelSplitterOptions: base_config_1.TYPE,
        CheckVisibilityOptions: base_config_1.TYPE,
        ClientQueryOptions: base_config_1.TYPE,
        ClipboardEventInit: base_config_1.TYPE,
        ClipboardItemOptions: base_config_1.TYPE,
        CloseEventInit: base_config_1.TYPE,
        CompositionEventInit: base_config_1.TYPE,
        ComputedEffectTiming: base_config_1.TYPE,
        ComputedKeyframe: base_config_1.TYPE,
        ConstantSourceOptions: base_config_1.TYPE,
        ConstrainBooleanParameters: base_config_1.TYPE,
        ConstrainDOMStringParameters: base_config_1.TYPE,
        ConstrainDoubleRange: base_config_1.TYPE,
        ConstrainULongRange: base_config_1.TYPE,
        ConvolverOptions: base_config_1.TYPE,
        CredentialCreationOptions: base_config_1.TYPE,
        CredentialPropertiesOutput: base_config_1.TYPE,
        CredentialRequestOptions: base_config_1.TYPE,
        CryptoKeyPair: base_config_1.TYPE,
        CustomEventInit: base_config_1.TYPE,
        DOMMatrix2DInit: base_config_1.TYPE,
        DOMMatrixInit: base_config_1.TYPE,
        DOMPointInit: base_config_1.TYPE,
        DOMQuadInit: base_config_1.TYPE,
        DOMRectInit: base_config_1.TYPE,
        DelayOptions: base_config_1.TYPE,
        DeviceMotionEventAccelerationInit: base_config_1.TYPE,
        DeviceMotionEventInit: base_config_1.TYPE,
        DeviceMotionEventRotationRateInit: base_config_1.TYPE,
        DeviceOrientationEventInit: base_config_1.TYPE,
        DisplayMediaStreamOptions: base_config_1.TYPE,
        DocumentTimelineOptions: base_config_1.TYPE,
        DoubleRange: base_config_1.TYPE,
        DragEventInit: base_config_1.TYPE,
        DynamicsCompressorOptions: base_config_1.TYPE,
        EcKeyAlgorithm: base_config_1.TYPE,
        EcKeyGenParams: base_config_1.TYPE,
        EcKeyImportParams: base_config_1.TYPE,
        EcdhKeyDeriveParams: base_config_1.TYPE,
        EcdsaParams: base_config_1.TYPE,
        EffectTiming: base_config_1.TYPE,
        ElementCreationOptions: base_config_1.TYPE,
        ElementDefinitionOptions: base_config_1.TYPE,
        ErrorEventInit: base_config_1.TYPE,
        EventInit: base_config_1.TYPE,
        EventListenerOptions: base_config_1.TYPE,
        EventModifierInit: base_config_1.TYPE,
        EventSourceInit: base_config_1.TYPE,
        FilePropertyBag: base_config_1.TYPE,
        FileSystemFlags: base_config_1.TYPE,
        FileSystemGetDirectoryOptions: base_config_1.TYPE,
        FileSystemGetFileOptions: base_config_1.TYPE,
        FileSystemRemoveOptions: base_config_1.TYPE,
        FocusEventInit: base_config_1.TYPE,
        FocusOptions: base_config_1.TYPE,
        FontFaceDescriptors: base_config_1.TYPE,
        FontFaceSetLoadEventInit: base_config_1.TYPE,
        FormDataEventInit: base_config_1.TYPE,
        FullscreenOptions: base_config_1.TYPE,
        GainOptions: base_config_1.TYPE,
        GamepadEventInit: base_config_1.TYPE,
        GetAnimationsOptions: base_config_1.TYPE,
        GetNotificationOptions: base_config_1.TYPE,
        GetRootNodeOptions: base_config_1.TYPE,
        HashChangeEventInit: base_config_1.TYPE,
        HkdfParams: base_config_1.TYPE,
        HmacImportParams: base_config_1.TYPE,
        HmacKeyAlgorithm: base_config_1.TYPE,
        HmacKeyGenParams: base_config_1.TYPE,
        IDBDatabaseInfo: base_config_1.TYPE,
        IDBIndexParameters: base_config_1.TYPE,
        IDBObjectStoreParameters: base_config_1.TYPE,
        IDBTransactionOptions: base_config_1.TYPE,
        IDBVersionChangeEventInit: base_config_1.TYPE,
        IIRFilterOptions: base_config_1.TYPE,
        IdleRequestOptions: base_config_1.TYPE,
        ImageBitmapOptions: base_config_1.TYPE,
        ImageBitmapRenderingContextSettings: base_config_1.TYPE,
        ImageDataSettings: base_config_1.TYPE,
        ImageEncodeOptions: base_config_1.TYPE,
        ImportMeta: base_config_1.TYPE,
        InputEventInit: base_config_1.TYPE,
        IntersectionObserverEntryInit: base_config_1.TYPE,
        IntersectionObserverInit: base_config_1.TYPE,
        JsonWebKey: base_config_1.TYPE,
        KeyAlgorithm: base_config_1.TYPE,
        KeyboardEventInit: base_config_1.TYPE,
        Keyframe: base_config_1.TYPE,
        KeyframeAnimationOptions: base_config_1.TYPE,
        KeyframeEffectOptions: base_config_1.TYPE,
        LockInfo: base_config_1.TYPE,
        LockManagerSnapshot: base_config_1.TYPE,
        LockOptions: base_config_1.TYPE,
        MIDIConnectionEventInit: base_config_1.TYPE,
        MIDIMessageEventInit: base_config_1.TYPE,
        MIDIOptions: base_config_1.TYPE,
        MediaCapabilitiesDecodingInfo: base_config_1.TYPE,
        MediaCapabilitiesEncodingInfo: base_config_1.TYPE,
        MediaCapabilitiesInfo: base_config_1.TYPE,
        MediaConfiguration: base_config_1.TYPE,
        MediaDecodingConfiguration: base_config_1.TYPE,
        MediaElementAudioSourceOptions: base_config_1.TYPE,
        MediaEncodingConfiguration: base_config_1.TYPE,
        MediaEncryptedEventInit: base_config_1.TYPE,
        MediaImage: base_config_1.TYPE,
        MediaKeyMessageEventInit: base_config_1.TYPE,
        MediaKeySystemConfiguration: base_config_1.TYPE,
        MediaKeySystemMediaCapability: base_config_1.TYPE,
        MediaMetadataInit: base_config_1.TYPE,
        MediaPositionState: base_config_1.TYPE,
        MediaQueryListEventInit: base_config_1.TYPE,
        MediaRecorderOptions: base_config_1.TYPE,
        MediaSessionActionDetails: base_config_1.TYPE,
        MediaStreamAudioSourceOptions: base_config_1.TYPE,
        MediaStreamConstraints: base_config_1.TYPE,
        MediaStreamTrackEventInit: base_config_1.TYPE,
        MediaTrackCapabilities: base_config_1.TYPE,
        MediaTrackConstraintSet: base_config_1.TYPE,
        MediaTrackConstraints: base_config_1.TYPE,
        MediaTrackSettings: base_config_1.TYPE,
        MediaTrackSupportedConstraints: base_config_1.TYPE,
        MessageEventInit: base_config_1.TYPE,
        MouseEventInit: base_config_1.TYPE,
        MultiCacheQueryOptions: base_config_1.TYPE,
        MutationObserverInit: base_config_1.TYPE,
        NavigationPreloadState: base_config_1.TYPE,
        NotificationAction: base_config_1.TYPE,
        NotificationOptions: base_config_1.TYPE,
        OfflineAudioCompletionEventInit: base_config_1.TYPE,
        OfflineAudioContextOptions: base_config_1.TYPE,
        OptionalEffectTiming: base_config_1.TYPE,
        OscillatorOptions: base_config_1.TYPE,
        PageTransitionEventInit: base_config_1.TYPE,
        PannerOptions: base_config_1.TYPE,
        PaymentCurrencyAmount: base_config_1.TYPE,
        PaymentDetailsBase: base_config_1.TYPE,
        PaymentDetailsInit: base_config_1.TYPE,
        PaymentDetailsModifier: base_config_1.TYPE,
        PaymentDetailsUpdate: base_config_1.TYPE,
        PaymentItem: base_config_1.TYPE,
        PaymentMethodChangeEventInit: base_config_1.TYPE,
        PaymentMethodData: base_config_1.TYPE,
        PaymentRequestUpdateEventInit: base_config_1.TYPE,
        PaymentValidationErrors: base_config_1.TYPE,
        Pbkdf2Params: base_config_1.TYPE,
        PerformanceMarkOptions: base_config_1.TYPE,
        PerformanceMeasureOptions: base_config_1.TYPE,
        PerformanceObserverInit: base_config_1.TYPE,
        PeriodicWaveConstraints: base_config_1.TYPE,
        PeriodicWaveOptions: base_config_1.TYPE,
        PermissionDescriptor: base_config_1.TYPE,
        PictureInPictureEventInit: base_config_1.TYPE,
        PointerEventInit: base_config_1.TYPE,
        PopStateEventInit: base_config_1.TYPE,
        PositionOptions: base_config_1.TYPE,
        ProgressEventInit: base_config_1.TYPE,
        PromiseRejectionEventInit: base_config_1.TYPE,
        PropertyIndexedKeyframes: base_config_1.TYPE,
        PublicKeyCredentialCreationOptions: base_config_1.TYPE,
        PublicKeyCredentialDescriptor: base_config_1.TYPE,
        PublicKeyCredentialEntity: base_config_1.TYPE,
        PublicKeyCredentialParameters: base_config_1.TYPE,
        PublicKeyCredentialRequestOptions: base_config_1.TYPE,
        PublicKeyCredentialRpEntity: base_config_1.TYPE,
        PublicKeyCredentialUserEntity: base_config_1.TYPE,
        PushSubscriptionJSON: base_config_1.TYPE,
        PushSubscriptionOptionsInit: base_config_1.TYPE,
        QueuingStrategy: base_config_1.TYPE,
        QueuingStrategyInit: base_config_1.TYPE,
        RTCAnswerOptions: base_config_1.TYPE,
        RTCCertificateExpiration: base_config_1.TYPE,
        RTCConfiguration: base_config_1.TYPE,
        RTCDTMFToneChangeEventInit: base_config_1.TYPE,
        RTCDataChannelEventInit: base_config_1.TYPE,
        RTCDataChannelInit: base_config_1.TYPE,
        RTCDtlsFingerprint: base_config_1.TYPE,
        RTCEncodedAudioFrameMetadata: base_config_1.TYPE,
        RTCEncodedVideoFrameMetadata: base_config_1.TYPE,
        RTCErrorEventInit: base_config_1.TYPE,
        RTCErrorInit: base_config_1.TYPE,
        RTCIceCandidateInit: base_config_1.TYPE,
        RTCIceCandidatePairStats: base_config_1.TYPE,
        RTCIceServer: base_config_1.TYPE,
        RTCInboundRtpStreamStats: base_config_1.TYPE,
        RTCLocalSessionDescriptionInit: base_config_1.TYPE,
        RTCOfferAnswerOptions: base_config_1.TYPE,
        RTCOfferOptions: base_config_1.TYPE,
        RTCOutboundRtpStreamStats: base_config_1.TYPE,
        RTCPeerConnectionIceErrorEventInit: base_config_1.TYPE,
        RTCPeerConnectionIceEventInit: base_config_1.TYPE,
        RTCReceivedRtpStreamStats: base_config_1.TYPE,
        RTCRtcpParameters: base_config_1.TYPE,
        RTCRtpCapabilities: base_config_1.TYPE,
        RTCRtpCodecCapability: base_config_1.TYPE,
        RTCRtpCodecParameters: base_config_1.TYPE,
        RTCRtpCodingParameters: base_config_1.TYPE,
        RTCRtpContributingSource: base_config_1.TYPE,
        RTCRtpEncodingParameters: base_config_1.TYPE,
        RTCRtpHeaderExtensionCapability: base_config_1.TYPE,
        RTCRtpHeaderExtensionParameters: base_config_1.TYPE,
        RTCRtpParameters: base_config_1.TYPE,
        RTCRtpReceiveParameters: base_config_1.TYPE,
        RTCRtpSendParameters: base_config_1.TYPE,
        RTCRtpStreamStats: base_config_1.TYPE,
        RTCRtpSynchronizationSource: base_config_1.TYPE,
        RTCRtpTransceiverInit: base_config_1.TYPE,
        RTCSentRtpStreamStats: base_config_1.TYPE,
        RTCSessionDescriptionInit: base_config_1.TYPE,
        RTCStats: base_config_1.TYPE,
        RTCTrackEventInit: base_config_1.TYPE,
        RTCTransportStats: base_config_1.TYPE,
        ReadableStreamGetReaderOptions: base_config_1.TYPE,
        ReadableStreamReadDoneResult: base_config_1.TYPE,
        ReadableStreamReadValueResult: base_config_1.TYPE,
        ReadableWritablePair: base_config_1.TYPE,
        RegistrationOptions: base_config_1.TYPE,
        RequestInit: base_config_1.TYPE,
        ResizeObserverOptions: base_config_1.TYPE,
        ResponseInit: base_config_1.TYPE,
        RsaHashedImportParams: base_config_1.TYPE,
        RsaHashedKeyAlgorithm: base_config_1.TYPE,
        RsaHashedKeyGenParams: base_config_1.TYPE,
        RsaKeyAlgorithm: base_config_1.TYPE,
        RsaKeyGenParams: base_config_1.TYPE,
        RsaOaepParams: base_config_1.TYPE,
        RsaOtherPrimesInfo: base_config_1.TYPE,
        RsaPssParams: base_config_1.TYPE,
        SVGBoundingBoxOptions: base_config_1.TYPE,
        ScrollIntoViewOptions: base_config_1.TYPE,
        ScrollOptions: base_config_1.TYPE,
        ScrollToOptions: base_config_1.TYPE,
        SecurityPolicyViolationEventInit: base_config_1.TYPE,
        ShadowRootInit: base_config_1.TYPE,
        ShareData: base_config_1.TYPE,
        SpeechSynthesisErrorEventInit: base_config_1.TYPE,
        SpeechSynthesisEventInit: base_config_1.TYPE,
        StaticRangeInit: base_config_1.TYPE,
        StereoPannerOptions: base_config_1.TYPE,
        StorageEstimate: base_config_1.TYPE,
        StorageEventInit: base_config_1.TYPE,
        StreamPipeOptions: base_config_1.TYPE,
        StructuredSerializeOptions: base_config_1.TYPE,
        SubmitEventInit: base_config_1.TYPE,
        TextDecodeOptions: base_config_1.TYPE,
        TextDecoderOptions: base_config_1.TYPE,
        TextEncoderEncodeIntoResult: base_config_1.TYPE,
        TouchEventInit: base_config_1.TYPE,
        TouchInit: base_config_1.TYPE,
        TrackEventInit: base_config_1.TYPE,
        Transformer: base_config_1.TYPE,
        TransitionEventInit: base_config_1.TYPE,
        UIEventInit: base_config_1.TYPE,
        ULongRange: base_config_1.TYPE,
        UnderlyingByteSource: base_config_1.TYPE,
        UnderlyingDefaultSource: base_config_1.TYPE,
        UnderlyingSink: base_config_1.TYPE,
        UnderlyingSource: base_config_1.TYPE,
        ValidityStateFlags: base_config_1.TYPE,
        VideoColorSpaceInit: base_config_1.TYPE,
        VideoConfiguration: base_config_1.TYPE,
        VideoFrameCallbackMetadata: base_config_1.TYPE,
        WaveShaperOptions: base_config_1.TYPE,
        WebGLContextAttributes: base_config_1.TYPE,
        WebGLContextEventInit: base_config_1.TYPE,
        WheelEventInit: base_config_1.TYPE,
        WindowPostMessageOptions: base_config_1.TYPE,
        WorkerOptions: base_config_1.TYPE,
        WorkletOptions: base_config_1.TYPE,
        NodeFilter: base_config_1.TYPE_VALUE,
        XPathNSResolver: base_config_1.TYPE,
        ANGLE_instanced_arrays: base_config_1.TYPE,
        ARIAMixin: base_config_1.TYPE,
        AbortController: base_config_1.TYPE_VALUE,
        AbortSignalEventMap: base_config_1.TYPE,
        AbortSignal: base_config_1.TYPE_VALUE,
        AbstractRange: base_config_1.TYPE_VALUE,
        AbstractWorkerEventMap: base_config_1.TYPE,
        AbstractWorker: base_config_1.TYPE,
        AnalyserNode: base_config_1.TYPE_VALUE,
        Animatable: base_config_1.TYPE,
        AnimationEventMap: base_config_1.TYPE,
        Animation: base_config_1.TYPE_VALUE,
        AnimationEffect: base_config_1.TYPE_VALUE,
        AnimationEvent: base_config_1.TYPE_VALUE,
        AnimationFrameProvider: base_config_1.TYPE,
        AnimationPlaybackEvent: base_config_1.TYPE_VALUE,
        AnimationTimeline: base_config_1.TYPE_VALUE,
        Attr: base_config_1.TYPE_VALUE,
        AudioBuffer: base_config_1.TYPE_VALUE,
        AudioBufferSourceNode: base_config_1.TYPE_VALUE,
        AudioContext: base_config_1.TYPE_VALUE,
        AudioDestinationNode: base_config_1.TYPE_VALUE,
        AudioListener: base_config_1.TYPE_VALUE,
        AudioNode: base_config_1.TYPE_VALUE,
        AudioParam: base_config_1.TYPE_VALUE,
        AudioParamMap: base_config_1.TYPE_VALUE,
        AudioProcessingEvent: base_config_1.TYPE_VALUE,
        AudioScheduledSourceNodeEventMap: base_config_1.TYPE,
        AudioScheduledSourceNode: base_config_1.TYPE_VALUE,
        AudioWorklet: base_config_1.TYPE_VALUE,
        AudioWorkletNodeEventMap: base_config_1.TYPE,
        AudioWorkletNode: base_config_1.TYPE_VALUE,
        AuthenticatorAssertionResponse: base_config_1.TYPE_VALUE,
        AuthenticatorAttestationResponse: base_config_1.TYPE_VALUE,
        AuthenticatorResponse: base_config_1.TYPE_VALUE,
        BarProp: base_config_1.TYPE_VALUE,
        BaseAudioContextEventMap: base_config_1.TYPE,
        BaseAudioContext: base_config_1.TYPE_VALUE,
        BeforeUnloadEvent: base_config_1.TYPE_VALUE,
        BiquadFilterNode: base_config_1.TYPE_VALUE,
        Blob: base_config_1.TYPE_VALUE,
        BlobEvent: base_config_1.TYPE_VALUE,
        Body: base_config_1.TYPE,
        BroadcastChannelEventMap: base_config_1.TYPE,
        BroadcastChannel: base_config_1.TYPE_VALUE,
        ByteLengthQueuingStrategy: base_config_1.TYPE_VALUE,
        CDATASection: base_config_1.TYPE_VALUE,
        CSSAnimation: base_config_1.TYPE_VALUE,
        CSSConditionRule: base_config_1.TYPE_VALUE,
        CSSContainerRule: base_config_1.TYPE_VALUE,
        CSSCounterStyleRule: base_config_1.TYPE_VALUE,
        CSSFontFaceRule: base_config_1.TYPE_VALUE,
        CSSFontFeatureValuesRule: base_config_1.TYPE_VALUE,
        CSSFontPaletteValuesRule: base_config_1.TYPE_VALUE,
        CSSGroupingRule: base_config_1.TYPE_VALUE,
        CSSImportRule: base_config_1.TYPE_VALUE,
        CSSKeyframeRule: base_config_1.TYPE_VALUE,
        CSSKeyframesRule: base_config_1.TYPE_VALUE,
        CSSLayerBlockRule: base_config_1.TYPE_VALUE,
        CSSLayerStatementRule: base_config_1.TYPE_VALUE,
        CSSMediaRule: base_config_1.TYPE_VALUE,
        CSSNamespaceRule: base_config_1.TYPE_VALUE,
        CSSPageRule: base_config_1.TYPE_VALUE,
        CSSRule: base_config_1.TYPE_VALUE,
        CSSRuleList: base_config_1.TYPE_VALUE,
        CSSStyleDeclaration: base_config_1.TYPE_VALUE,
        CSSStyleRule: base_config_1.TYPE_VALUE,
        CSSStyleSheet: base_config_1.TYPE_VALUE,
        CSSSupportsRule: base_config_1.TYPE_VALUE,
        CSSTransition: base_config_1.TYPE_VALUE,
        Cache: base_config_1.TYPE_VALUE,
        CacheStorage: base_config_1.TYPE_VALUE,
        CanvasCaptureMediaStreamTrack: base_config_1.TYPE_VALUE,
        CanvasCompositing: base_config_1.TYPE,
        CanvasDrawImage: base_config_1.TYPE,
        CanvasDrawPath: base_config_1.TYPE,
        CanvasFillStrokeStyles: base_config_1.TYPE,
        CanvasFilters: base_config_1.TYPE,
        CanvasGradient: base_config_1.TYPE_VALUE,
        CanvasImageData: base_config_1.TYPE,
        CanvasImageSmoothing: base_config_1.TYPE,
        CanvasPath: base_config_1.TYPE,
        CanvasPathDrawingStyles: base_config_1.TYPE,
        CanvasPattern: base_config_1.TYPE_VALUE,
        CanvasRect: base_config_1.TYPE,
        CanvasRenderingContext2D: base_config_1.TYPE_VALUE,
        CanvasShadowStyles: base_config_1.TYPE,
        CanvasState: base_config_1.TYPE,
        CanvasText: base_config_1.TYPE,
        CanvasTextDrawingStyles: base_config_1.TYPE,
        CanvasTransform: base_config_1.TYPE,
        CanvasUserInterface: base_config_1.TYPE,
        ChannelMergerNode: base_config_1.TYPE_VALUE,
        ChannelSplitterNode: base_config_1.TYPE_VALUE,
        CharacterData: base_config_1.TYPE_VALUE,
        ChildNode: base_config_1.TYPE,
        ClientRect: base_config_1.TYPE,
        Clipboard: base_config_1.TYPE_VALUE,
        ClipboardEvent: base_config_1.TYPE_VALUE,
        ClipboardItem: base_config_1.TYPE_VALUE,
        CloseEvent: base_config_1.TYPE_VALUE,
        Comment: base_config_1.TYPE_VALUE,
        CompositionEvent: base_config_1.TYPE_VALUE,
        ConstantSourceNode: base_config_1.TYPE_VALUE,
        ConvolverNode: base_config_1.TYPE_VALUE,
        CountQueuingStrategy: base_config_1.TYPE_VALUE,
        Credential: base_config_1.TYPE_VALUE,
        CredentialsContainer: base_config_1.TYPE_VALUE,
        Crypto: base_config_1.TYPE_VALUE,
        CryptoKey: base_config_1.TYPE_VALUE,
        CustomElementRegistry: base_config_1.TYPE_VALUE,
        CustomEvent: base_config_1.TYPE_VALUE,
        DOMException: base_config_1.TYPE_VALUE,
        DOMImplementation: base_config_1.TYPE_VALUE,
        DOMMatrix: base_config_1.TYPE_VALUE,
        SVGMatrix: base_config_1.TYPE_VALUE,
        WebKitCSSMatrix: base_config_1.TYPE_VALUE,
        DOMMatrixReadOnly: base_config_1.TYPE_VALUE,
        DOMParser: base_config_1.TYPE_VALUE,
        DOMPoint: base_config_1.TYPE_VALUE,
        SVGPoint: base_config_1.TYPE_VALUE,
        DOMPointReadOnly: base_config_1.TYPE_VALUE,
        DOMQuad: base_config_1.TYPE_VALUE,
        DOMRect: base_config_1.TYPE_VALUE,
        SVGRect: base_config_1.TYPE_VALUE,
        DOMRectList: base_config_1.TYPE_VALUE,
        DOMRectReadOnly: base_config_1.TYPE_VALUE,
        DOMStringList: base_config_1.TYPE_VALUE,
        DOMStringMap: base_config_1.TYPE_VALUE,
        DOMTokenList: base_config_1.TYPE_VALUE,
        DataTransfer: base_config_1.TYPE_VALUE,
        DataTransferItem: base_config_1.TYPE_VALUE,
        DataTransferItemList: base_config_1.TYPE_VALUE,
        DelayNode: base_config_1.TYPE_VALUE,
        DeviceMotionEvent: base_config_1.TYPE_VALUE,
        DeviceMotionEventAcceleration: base_config_1.TYPE,
        DeviceMotionEventRotationRate: base_config_1.TYPE,
        DeviceOrientationEvent: base_config_1.TYPE_VALUE,
        DocumentEventMap: base_config_1.TYPE,
        Document: base_config_1.TYPE_VALUE,
        DocumentFragment: base_config_1.TYPE_VALUE,
        DocumentOrShadowRoot: base_config_1.TYPE,
        DocumentTimeline: base_config_1.TYPE_VALUE,
        DocumentType: base_config_1.TYPE_VALUE,
        DragEvent: base_config_1.TYPE_VALUE,
        DynamicsCompressorNode: base_config_1.TYPE_VALUE,
        EXT_blend_minmax: base_config_1.TYPE,
        EXT_color_buffer_float: base_config_1.TYPE,
        EXT_color_buffer_half_float: base_config_1.TYPE,
        EXT_float_blend: base_config_1.TYPE,
        EXT_frag_depth: base_config_1.TYPE,
        EXT_sRGB: base_config_1.TYPE,
        EXT_shader_texture_lod: base_config_1.TYPE,
        EXT_texture_compression_bptc: base_config_1.TYPE,
        EXT_texture_compression_rgtc: base_config_1.TYPE,
        EXT_texture_filter_anisotropic: base_config_1.TYPE,
        EXT_texture_norm16: base_config_1.TYPE,
        ElementEventMap: base_config_1.TYPE,
        Element: base_config_1.TYPE_VALUE,
        ElementCSSInlineStyle: base_config_1.TYPE,
        ElementContentEditable: base_config_1.TYPE,
        ElementInternals: base_config_1.TYPE_VALUE,
        ErrorEvent: base_config_1.TYPE_VALUE,
        Event: base_config_1.TYPE_VALUE,
        EventCounts: base_config_1.TYPE_VALUE,
        EventListener: base_config_1.TYPE,
        EventListenerObject: base_config_1.TYPE,
        EventSourceEventMap: base_config_1.TYPE,
        EventSource: base_config_1.TYPE_VALUE,
        EventTarget: base_config_1.TYPE_VALUE,
        External: base_config_1.TYPE_VALUE,
        File: base_config_1.TYPE_VALUE,
        FileList: base_config_1.TYPE_VALUE,
        FileReaderEventMap: base_config_1.TYPE,
        FileReader: base_config_1.TYPE_VALUE,
        FileSystem: base_config_1.TYPE_VALUE,
        FileSystemDirectoryEntry: base_config_1.TYPE_VALUE,
        FileSystemDirectoryHandle: base_config_1.TYPE_VALUE,
        FileSystemDirectoryReader: base_config_1.TYPE_VALUE,
        FileSystemEntry: base_config_1.TYPE_VALUE,
        FileSystemFileEntry: base_config_1.TYPE_VALUE,
        FileSystemFileHandle: base_config_1.TYPE_VALUE,
        FileSystemHandle: base_config_1.TYPE_VALUE,
        FocusEvent: base_config_1.TYPE_VALUE,
        FontFace: base_config_1.TYPE_VALUE,
        FontFaceSetEventMap: base_config_1.TYPE,
        FontFaceSet: base_config_1.TYPE_VALUE,
        FontFaceSetLoadEvent: base_config_1.TYPE_VALUE,
        FontFaceSource: base_config_1.TYPE,
        FormData: base_config_1.TYPE_VALUE,
        FormDataEvent: base_config_1.TYPE_VALUE,
        GainNode: base_config_1.TYPE_VALUE,
        Gamepad: base_config_1.TYPE_VALUE,
        GamepadButton: base_config_1.TYPE_VALUE,
        GamepadEvent: base_config_1.TYPE_VALUE,
        GamepadHapticActuator: base_config_1.TYPE_VALUE,
        GenericTransformStream: base_config_1.TYPE,
        Geolocation: base_config_1.TYPE_VALUE,
        GeolocationCoordinates: base_config_1.TYPE_VALUE,
        GeolocationPosition: base_config_1.TYPE_VALUE,
        GeolocationPositionError: base_config_1.TYPE_VALUE,
        GlobalEventHandlersEventMap: base_config_1.TYPE,
        GlobalEventHandlers: base_config_1.TYPE,
        HTMLAllCollection: base_config_1.TYPE_VALUE,
        HTMLAnchorElement: base_config_1.TYPE_VALUE,
        HTMLAreaElement: base_config_1.TYPE_VALUE,
        HTMLAudioElement: base_config_1.TYPE_VALUE,
        HTMLBRElement: base_config_1.TYPE_VALUE,
        HTMLBaseElement: base_config_1.TYPE_VALUE,
        HTMLBodyElementEventMap: base_config_1.TYPE,
        HTMLBodyElement: base_config_1.TYPE_VALUE,
        HTMLButtonElement: base_config_1.TYPE_VALUE,
        HTMLCanvasElement: base_config_1.TYPE_VALUE,
        HTMLCollectionBase: base_config_1.TYPE,
        HTMLCollection: base_config_1.TYPE_VALUE,
        HTMLCollectionOf: base_config_1.TYPE,
        HTMLDListElement: base_config_1.TYPE_VALUE,
        HTMLDataElement: base_config_1.TYPE_VALUE,
        HTMLDataListElement: base_config_1.TYPE_VALUE,
        HTMLDetailsElement: base_config_1.TYPE_VALUE,
        HTMLDialogElement: base_config_1.TYPE_VALUE,
        HTMLDirectoryElement: base_config_1.TYPE_VALUE,
        HTMLDivElement: base_config_1.TYPE_VALUE,
        HTMLDocument: base_config_1.TYPE_VALUE,
        HTMLElementEventMap: base_config_1.TYPE,
        HTMLElement: base_config_1.TYPE_VALUE,
        HTMLEmbedElement: base_config_1.TYPE_VALUE,
        HTMLFieldSetElement: base_config_1.TYPE_VALUE,
        HTMLFontElement: base_config_1.TYPE_VALUE,
        HTMLFormControlsCollection: base_config_1.TYPE_VALUE,
        HTMLFormElement: base_config_1.TYPE_VALUE,
        HTMLFrameElement: base_config_1.TYPE_VALUE,
        HTMLFrameSetElementEventMap: base_config_1.TYPE,
        HTMLFrameSetElement: base_config_1.TYPE_VALUE,
        HTMLHRElement: base_config_1.TYPE_VALUE,
        HTMLHeadElement: base_config_1.TYPE_VALUE,
        HTMLHeadingElement: base_config_1.TYPE_VALUE,
        HTMLHtmlElement: base_config_1.TYPE_VALUE,
        HTMLHyperlinkElementUtils: base_config_1.TYPE,
        HTMLIFrameElement: base_config_1.TYPE_VALUE,
        HTMLImageElement: base_config_1.TYPE_VALUE,
        HTMLInputElement: base_config_1.TYPE_VALUE,
        HTMLLIElement: base_config_1.TYPE_VALUE,
        HTMLLabelElement: base_config_1.TYPE_VALUE,
        HTMLLegendElement: base_config_1.TYPE_VALUE,
        HTMLLinkElement: base_config_1.TYPE_VALUE,
        HTMLMapElement: base_config_1.TYPE_VALUE,
        HTMLMarqueeElement: base_config_1.TYPE_VALUE,
        HTMLMediaElementEventMap: base_config_1.TYPE,
        HTMLMediaElement: base_config_1.TYPE_VALUE,
        HTMLMenuElement: base_config_1.TYPE_VALUE,
        HTMLMetaElement: base_config_1.TYPE_VALUE,
        HTMLMeterElement: base_config_1.TYPE_VALUE,
        HTMLModElement: base_config_1.TYPE_VALUE,
        HTMLOListElement: base_config_1.TYPE_VALUE,
        HTMLObjectElement: base_config_1.TYPE_VALUE,
        HTMLOptGroupElement: base_config_1.TYPE_VALUE,
        HTMLOptionElement: base_config_1.TYPE_VALUE,
        HTMLOptionsCollection: base_config_1.TYPE_VALUE,
        HTMLOrSVGElement: base_config_1.TYPE,
        HTMLOutputElement: base_config_1.TYPE_VALUE,
        HTMLParagraphElement: base_config_1.TYPE_VALUE,
        HTMLParamElement: base_config_1.TYPE_VALUE,
        HTMLPictureElement: base_config_1.TYPE_VALUE,
        HTMLPreElement: base_config_1.TYPE_VALUE,
        HTMLProgressElement: base_config_1.TYPE_VALUE,
        HTMLQuoteElement: base_config_1.TYPE_VALUE,
        HTMLScriptElement: base_config_1.TYPE_VALUE,
        HTMLSelectElement: base_config_1.TYPE_VALUE,
        HTMLSlotElement: base_config_1.TYPE_VALUE,
        HTMLSourceElement: base_config_1.TYPE_VALUE,
        HTMLSpanElement: base_config_1.TYPE_VALUE,
        HTMLStyleElement: base_config_1.TYPE_VALUE,
        HTMLTableCaptionElement: base_config_1.TYPE_VALUE,
        HTMLTableCellElement: base_config_1.TYPE_VALUE,
        HTMLTableColElement: base_config_1.TYPE_VALUE,
        HTMLTableDataCellElement: base_config_1.TYPE,
        HTMLTableElement: base_config_1.TYPE_VALUE,
        HTMLTableHeaderCellElement: base_config_1.TYPE,
        HTMLTableRowElement: base_config_1.TYPE_VALUE,
        HTMLTableSectionElement: base_config_1.TYPE_VALUE,
        HTMLTemplateElement: base_config_1.TYPE_VALUE,
        HTMLTextAreaElement: base_config_1.TYPE_VALUE,
        HTMLTimeElement: base_config_1.TYPE_VALUE,
        HTMLTitleElement: base_config_1.TYPE_VALUE,
        HTMLTrackElement: base_config_1.TYPE_VALUE,
        HTMLUListElement: base_config_1.TYPE_VALUE,
        HTMLUnknownElement: base_config_1.TYPE_VALUE,
        HTMLVideoElementEventMap: base_config_1.TYPE,
        HTMLVideoElement: base_config_1.TYPE_VALUE,
        HashChangeEvent: base_config_1.TYPE_VALUE,
        Headers: base_config_1.TYPE_VALUE,
        History: base_config_1.TYPE_VALUE,
        IDBCursor: base_config_1.TYPE_VALUE,
        IDBCursorWithValue: base_config_1.TYPE_VALUE,
        IDBDatabaseEventMap: base_config_1.TYPE,
        IDBDatabase: base_config_1.TYPE_VALUE,
        IDBFactory: base_config_1.TYPE_VALUE,
        IDBIndex: base_config_1.TYPE_VALUE,
        IDBKeyRange: base_config_1.TYPE_VALUE,
        IDBObjectStore: base_config_1.TYPE_VALUE,
        IDBOpenDBRequestEventMap: base_config_1.TYPE,
        IDBOpenDBRequest: base_config_1.TYPE_VALUE,
        IDBRequestEventMap: base_config_1.TYPE,
        IDBRequest: base_config_1.TYPE_VALUE,
        IDBTransactionEventMap: base_config_1.TYPE,
        IDBTransaction: base_config_1.TYPE_VALUE,
        IDBVersionChangeEvent: base_config_1.TYPE_VALUE,
        IIRFilterNode: base_config_1.TYPE_VALUE,
        IdleDeadline: base_config_1.TYPE_VALUE,
        ImageBitmap: base_config_1.TYPE_VALUE,
        ImageBitmapRenderingContext: base_config_1.TYPE_VALUE,
        ImageData: base_config_1.TYPE_VALUE,
        InnerHTML: base_config_1.TYPE,
        InputDeviceInfo: base_config_1.TYPE_VALUE,
        InputEvent: base_config_1.TYPE_VALUE,
        IntersectionObserver: base_config_1.TYPE_VALUE,
        IntersectionObserverEntry: base_config_1.TYPE_VALUE,
        KHR_parallel_shader_compile: base_config_1.TYPE,
        KeyboardEvent: base_config_1.TYPE_VALUE,
        KeyframeEffect: base_config_1.TYPE_VALUE,
        LinkStyle: base_config_1.TYPE,
        Location: base_config_1.TYPE_VALUE,
        Lock: base_config_1.TYPE_VALUE,
        LockManager: base_config_1.TYPE_VALUE,
        MIDIAccessEventMap: base_config_1.TYPE,
        MIDIAccess: base_config_1.TYPE_VALUE,
        MIDIConnectionEvent: base_config_1.TYPE_VALUE,
        MIDIInputEventMap: base_config_1.TYPE,
        MIDIInput: base_config_1.TYPE_VALUE,
        MIDIInputMap: base_config_1.TYPE_VALUE,
        MIDIMessageEvent: base_config_1.TYPE_VALUE,
        MIDIOutput: base_config_1.TYPE_VALUE,
        MIDIOutputMap: base_config_1.TYPE_VALUE,
        MIDIPortEventMap: base_config_1.TYPE,
        MIDIPort: base_config_1.TYPE_VALUE,
        MathMLElementEventMap: base_config_1.TYPE,
        MathMLElement: base_config_1.TYPE_VALUE,
        MediaCapabilities: base_config_1.TYPE_VALUE,
        MediaDeviceInfo: base_config_1.TYPE_VALUE,
        MediaDevicesEventMap: base_config_1.TYPE,
        MediaDevices: base_config_1.TYPE_VALUE,
        MediaElementAudioSourceNode: base_config_1.TYPE_VALUE,
        MediaEncryptedEvent: base_config_1.TYPE_VALUE,
        MediaError: base_config_1.TYPE_VALUE,
        MediaKeyMessageEvent: base_config_1.TYPE_VALUE,
        MediaKeySessionEventMap: base_config_1.TYPE,
        MediaKeySession: base_config_1.TYPE_VALUE,
        MediaKeyStatusMap: base_config_1.TYPE_VALUE,
        MediaKeySystemAccess: base_config_1.TYPE_VALUE,
        MediaKeys: base_config_1.TYPE_VALUE,
        MediaList: base_config_1.TYPE_VALUE,
        MediaMetadata: base_config_1.TYPE_VALUE,
        MediaQueryListEventMap: base_config_1.TYPE,
        MediaQueryList: base_config_1.TYPE_VALUE,
        MediaQueryListEvent: base_config_1.TYPE_VALUE,
        MediaRecorderEventMap: base_config_1.TYPE,
        MediaRecorder: base_config_1.TYPE_VALUE,
        MediaSession: base_config_1.TYPE_VALUE,
        MediaSourceEventMap: base_config_1.TYPE,
        MediaSource: base_config_1.TYPE_VALUE,
        MediaStreamEventMap: base_config_1.TYPE,
        MediaStream: base_config_1.TYPE_VALUE,
        MediaStreamAudioDestinationNode: base_config_1.TYPE_VALUE,
        MediaStreamAudioSourceNode: base_config_1.TYPE_VALUE,
        MediaStreamTrackEventMap: base_config_1.TYPE,
        MediaStreamTrack: base_config_1.TYPE_VALUE,
        MediaStreamTrackEvent: base_config_1.TYPE_VALUE,
        MessageChannel: base_config_1.TYPE_VALUE,
        MessageEvent: base_config_1.TYPE_VALUE,
        MessagePortEventMap: base_config_1.TYPE,
        MessagePort: base_config_1.TYPE_VALUE,
        MimeType: base_config_1.TYPE_VALUE,
        MimeTypeArray: base_config_1.TYPE_VALUE,
        MouseEvent: base_config_1.TYPE_VALUE,
        MutationEvent: base_config_1.TYPE_VALUE,
        MutationObserver: base_config_1.TYPE_VALUE,
        MutationRecord: base_config_1.TYPE_VALUE,
        NamedNodeMap: base_config_1.TYPE_VALUE,
        NavigationPreloadManager: base_config_1.TYPE_VALUE,
        Navigator: base_config_1.TYPE_VALUE,
        NavigatorAutomationInformation: base_config_1.TYPE,
        NavigatorConcurrentHardware: base_config_1.TYPE,
        NavigatorContentUtils: base_config_1.TYPE,
        NavigatorCookies: base_config_1.TYPE,
        NavigatorID: base_config_1.TYPE,
        NavigatorLanguage: base_config_1.TYPE,
        NavigatorLocks: base_config_1.TYPE,
        NavigatorOnLine: base_config_1.TYPE,
        NavigatorPlugins: base_config_1.TYPE,
        NavigatorStorage: base_config_1.TYPE,
        Node: base_config_1.TYPE_VALUE,
        NodeIterator: base_config_1.TYPE_VALUE,
        NodeList: base_config_1.TYPE_VALUE,
        NodeListOf: base_config_1.TYPE,
        NonDocumentTypeChildNode: base_config_1.TYPE,
        NonElementParentNode: base_config_1.TYPE,
        NotificationEventMap: base_config_1.TYPE,
        Notification: base_config_1.TYPE_VALUE,
        OES_draw_buffers_indexed: base_config_1.TYPE,
        OES_element_index_uint: base_config_1.TYPE,
        OES_fbo_render_mipmap: base_config_1.TYPE,
        OES_standard_derivatives: base_config_1.TYPE,
        OES_texture_float: base_config_1.TYPE,
        OES_texture_float_linear: base_config_1.TYPE,
        OES_texture_half_float: base_config_1.TYPE,
        OES_texture_half_float_linear: base_config_1.TYPE,
        OES_vertex_array_object: base_config_1.TYPE,
        OVR_multiview2: base_config_1.TYPE,
        OfflineAudioCompletionEvent: base_config_1.TYPE_VALUE,
        OfflineAudioContextEventMap: base_config_1.TYPE,
        OfflineAudioContext: base_config_1.TYPE_VALUE,
        OffscreenCanvasEventMap: base_config_1.TYPE,
        OffscreenCanvas: base_config_1.TYPE_VALUE,
        OffscreenCanvasRenderingContext2D: base_config_1.TYPE_VALUE,
        OscillatorNode: base_config_1.TYPE_VALUE,
        OverconstrainedError: base_config_1.TYPE_VALUE,
        PageTransitionEvent: base_config_1.TYPE_VALUE,
        PannerNode: base_config_1.TYPE_VALUE,
        ParentNode: base_config_1.TYPE,
        Path2D: base_config_1.TYPE_VALUE,
        PaymentMethodChangeEvent: base_config_1.TYPE_VALUE,
        PaymentRequestEventMap: base_config_1.TYPE,
        PaymentRequest: base_config_1.TYPE_VALUE,
        PaymentRequestUpdateEvent: base_config_1.TYPE_VALUE,
        PaymentResponse: base_config_1.TYPE_VALUE,
        PerformanceEventMap: base_config_1.TYPE,
        Performance: base_config_1.TYPE_VALUE,
        PerformanceEntry: base_config_1.TYPE_VALUE,
        PerformanceEventTiming: base_config_1.TYPE_VALUE,
        PerformanceMark: base_config_1.TYPE_VALUE,
        PerformanceMeasure: base_config_1.TYPE_VALUE,
        PerformanceNavigation: base_config_1.TYPE_VALUE,
        PerformanceNavigationTiming: base_config_1.TYPE_VALUE,
        PerformanceObserver: base_config_1.TYPE_VALUE,
        PerformanceObserverEntryList: base_config_1.TYPE_VALUE,
        PerformancePaintTiming: base_config_1.TYPE_VALUE,
        PerformanceResourceTiming: base_config_1.TYPE_VALUE,
        PerformanceServerTiming: base_config_1.TYPE_VALUE,
        PerformanceTiming: base_config_1.TYPE_VALUE,
        PeriodicWave: base_config_1.TYPE_VALUE,
        PermissionStatusEventMap: base_config_1.TYPE,
        PermissionStatus: base_config_1.TYPE_VALUE,
        Permissions: base_config_1.TYPE_VALUE,
        PictureInPictureEvent: base_config_1.TYPE_VALUE,
        PictureInPictureWindowEventMap: base_config_1.TYPE,
        PictureInPictureWindow: base_config_1.TYPE_VALUE,
        Plugin: base_config_1.TYPE_VALUE,
        PluginArray: base_config_1.TYPE_VALUE,
        PointerEvent: base_config_1.TYPE_VALUE,
        PopStateEvent: base_config_1.TYPE_VALUE,
        ProcessingInstruction: base_config_1.TYPE_VALUE,
        ProgressEvent: base_config_1.TYPE_VALUE,
        PromiseRejectionEvent: base_config_1.TYPE_VALUE,
        PublicKeyCredential: base_config_1.TYPE_VALUE,
        PushManager: base_config_1.TYPE_VALUE,
        PushSubscription: base_config_1.TYPE_VALUE,
        PushSubscriptionOptions: base_config_1.TYPE_VALUE,
        RTCCertificate: base_config_1.TYPE_VALUE,
        RTCDTMFSenderEventMap: base_config_1.TYPE,
        RTCDTMFSender: base_config_1.TYPE_VALUE,
        RTCDTMFToneChangeEvent: base_config_1.TYPE_VALUE,
        RTCDataChannelEventMap: base_config_1.TYPE,
        RTCDataChannel: base_config_1.TYPE_VALUE,
        RTCDataChannelEvent: base_config_1.TYPE_VALUE,
        RTCDtlsTransportEventMap: base_config_1.TYPE,
        RTCDtlsTransport: base_config_1.TYPE_VALUE,
        RTCEncodedAudioFrame: base_config_1.TYPE_VALUE,
        RTCEncodedVideoFrame: base_config_1.TYPE_VALUE,
        RTCError: base_config_1.TYPE_VALUE,
        RTCErrorEvent: base_config_1.TYPE_VALUE,
        RTCIceCandidate: base_config_1.TYPE_VALUE,
        RTCIceTransportEventMap: base_config_1.TYPE,
        RTCIceTransport: base_config_1.TYPE_VALUE,
        RTCPeerConnectionEventMap: base_config_1.TYPE,
        RTCPeerConnection: base_config_1.TYPE_VALUE,
        RTCPeerConnectionIceErrorEvent: base_config_1.TYPE_VALUE,
        RTCPeerConnectionIceEvent: base_config_1.TYPE_VALUE,
        RTCRtpReceiver: base_config_1.TYPE_VALUE,
        RTCRtpSender: base_config_1.TYPE_VALUE,
        RTCRtpTransceiver: base_config_1.TYPE_VALUE,
        RTCSctpTransportEventMap: base_config_1.TYPE,
        RTCSctpTransport: base_config_1.TYPE_VALUE,
        RTCSessionDescription: base_config_1.TYPE_VALUE,
        RTCStatsReport: base_config_1.TYPE_VALUE,
        RTCTrackEvent: base_config_1.TYPE_VALUE,
        RadioNodeList: base_config_1.TYPE_VALUE,
        Range: base_config_1.TYPE_VALUE,
        ReadableByteStreamController: base_config_1.TYPE_VALUE,
        ReadableStream: base_config_1.TYPE_VALUE,
        ReadableStreamBYOBReader: base_config_1.TYPE_VALUE,
        ReadableStreamBYOBRequest: base_config_1.TYPE_VALUE,
        ReadableStreamDefaultController: base_config_1.TYPE_VALUE,
        ReadableStreamDefaultReader: base_config_1.TYPE_VALUE,
        ReadableStreamGenericReader: base_config_1.TYPE,
        RemotePlaybackEventMap: base_config_1.TYPE,
        RemotePlayback: base_config_1.TYPE_VALUE,
        Request: base_config_1.TYPE_VALUE,
        ResizeObserver: base_config_1.TYPE_VALUE,
        ResizeObserverEntry: base_config_1.TYPE_VALUE,
        ResizeObserverSize: base_config_1.TYPE_VALUE,
        Response: base_config_1.TYPE_VALUE,
        SVGAElement: base_config_1.TYPE_VALUE,
        SVGAngle: base_config_1.TYPE_VALUE,
        SVGAnimateElement: base_config_1.TYPE_VALUE,
        SVGAnimateMotionElement: base_config_1.TYPE_VALUE,
        SVGAnimateTransformElement: base_config_1.TYPE_VALUE,
        SVGAnimatedAngle: base_config_1.TYPE_VALUE,
        SVGAnimatedBoolean: base_config_1.TYPE_VALUE,
        SVGAnimatedEnumeration: base_config_1.TYPE_VALUE,
        SVGAnimatedInteger: base_config_1.TYPE_VALUE,
        SVGAnimatedLength: base_config_1.TYPE_VALUE,
        SVGAnimatedLengthList: base_config_1.TYPE_VALUE,
        SVGAnimatedNumber: base_config_1.TYPE_VALUE,
        SVGAnimatedNumberList: base_config_1.TYPE_VALUE,
        SVGAnimatedPoints: base_config_1.TYPE,
        SVGAnimatedPreserveAspectRatio: base_config_1.TYPE_VALUE,
        SVGAnimatedRect: base_config_1.TYPE_VALUE,
        SVGAnimatedString: base_config_1.TYPE_VALUE,
        SVGAnimatedTransformList: base_config_1.TYPE_VALUE,
        SVGAnimationElement: base_config_1.TYPE_VALUE,
        SVGCircleElement: base_config_1.TYPE_VALUE,
        SVGClipPathElement: base_config_1.TYPE_VALUE,
        SVGComponentTransferFunctionElement: base_config_1.TYPE_VALUE,
        SVGDefsElement: base_config_1.TYPE_VALUE,
        SVGDescElement: base_config_1.TYPE_VALUE,
        SVGElementEventMap: base_config_1.TYPE,
        SVGElement: base_config_1.TYPE_VALUE,
        SVGEllipseElement: base_config_1.TYPE_VALUE,
        SVGFEBlendElement: base_config_1.TYPE_VALUE,
        SVGFEColorMatrixElement: base_config_1.TYPE_VALUE,
        SVGFEComponentTransferElement: base_config_1.TYPE_VALUE,
        SVGFECompositeElement: base_config_1.TYPE_VALUE,
        SVGFEConvolveMatrixElement: base_config_1.TYPE_VALUE,
        SVGFEDiffuseLightingElement: base_config_1.TYPE_VALUE,
        SVGFEDisplacementMapElement: base_config_1.TYPE_VALUE,
        SVGFEDistantLightElement: base_config_1.TYPE_VALUE,
        SVGFEDropShadowElement: base_config_1.TYPE_VALUE,
        SVGFEFloodElement: base_config_1.TYPE_VALUE,
        SVGFEFuncAElement: base_config_1.TYPE_VALUE,
        SVGFEFuncBElement: base_config_1.TYPE_VALUE,
        SVGFEFuncGElement: base_config_1.TYPE_VALUE,
        SVGFEFuncRElement: base_config_1.TYPE_VALUE,
        SVGFEGaussianBlurElement: base_config_1.TYPE_VALUE,
        SVGFEImageElement: base_config_1.TYPE_VALUE,
        SVGFEMergeElement: base_config_1.TYPE_VALUE,
        SVGFEMergeNodeElement: base_config_1.TYPE_VALUE,
        SVGFEMorphologyElement: base_config_1.TYPE_VALUE,
        SVGFEOffsetElement: base_config_1.TYPE_VALUE,
        SVGFEPointLightElement: base_config_1.TYPE_VALUE,
        SVGFESpecularLightingElement: base_config_1.TYPE_VALUE,
        SVGFESpotLightElement: base_config_1.TYPE_VALUE,
        SVGFETileElement: base_config_1.TYPE_VALUE,
        SVGFETurbulenceElement: base_config_1.TYPE_VALUE,
        SVGFilterElement: base_config_1.TYPE_VALUE,
        SVGFilterPrimitiveStandardAttributes: base_config_1.TYPE,
        SVGFitToViewBox: base_config_1.TYPE,
        SVGForeignObjectElement: base_config_1.TYPE_VALUE,
        SVGGElement: base_config_1.TYPE_VALUE,
        SVGGeometryElement: base_config_1.TYPE_VALUE,
        SVGGradientElement: base_config_1.TYPE_VALUE,
        SVGGraphicsElement: base_config_1.TYPE_VALUE,
        SVGImageElement: base_config_1.TYPE_VALUE,
        SVGLength: base_config_1.TYPE_VALUE,
        SVGLengthList: base_config_1.TYPE_VALUE,
        SVGLineElement: base_config_1.TYPE_VALUE,
        SVGLinearGradientElement: base_config_1.TYPE_VALUE,
        SVGMPathElement: base_config_1.TYPE_VALUE,
        SVGMarkerElement: base_config_1.TYPE_VALUE,
        SVGMaskElement: base_config_1.TYPE_VALUE,
        SVGMetadataElement: base_config_1.TYPE_VALUE,
        SVGNumber: base_config_1.TYPE_VALUE,
        SVGNumberList: base_config_1.TYPE_VALUE,
        SVGPathElement: base_config_1.TYPE_VALUE,
        SVGPatternElement: base_config_1.TYPE_VALUE,
        SVGPointList: base_config_1.TYPE_VALUE,
        SVGPolygonElement: base_config_1.TYPE_VALUE,
        SVGPolylineElement: base_config_1.TYPE_VALUE,
        SVGPreserveAspectRatio: base_config_1.TYPE_VALUE,
        SVGRadialGradientElement: base_config_1.TYPE_VALUE,
        SVGRectElement: base_config_1.TYPE_VALUE,
        SVGSVGElementEventMap: base_config_1.TYPE,
        SVGSVGElement: base_config_1.TYPE_VALUE,
        SVGScriptElement: base_config_1.TYPE_VALUE,
        SVGSetElement: base_config_1.TYPE_VALUE,
        SVGStopElement: base_config_1.TYPE_VALUE,
        SVGStringList: base_config_1.TYPE_VALUE,
        SVGStyleElement: base_config_1.TYPE_VALUE,
        SVGSwitchElement: base_config_1.TYPE_VALUE,
        SVGSymbolElement: base_config_1.TYPE_VALUE,
        SVGTSpanElement: base_config_1.TYPE_VALUE,
        SVGTests: base_config_1.TYPE,
        SVGTextContentElement: base_config_1.TYPE_VALUE,
        SVGTextElement: base_config_1.TYPE_VALUE,
        SVGTextPathElement: base_config_1.TYPE_VALUE,
        SVGTextPositioningElement: base_config_1.TYPE_VALUE,
        SVGTitleElement: base_config_1.TYPE_VALUE,
        SVGTransform: base_config_1.TYPE_VALUE,
        SVGTransformList: base_config_1.TYPE_VALUE,
        SVGURIReference: base_config_1.TYPE,
        SVGUnitTypes: base_config_1.TYPE_VALUE,
        SVGUseElement: base_config_1.TYPE_VALUE,
        SVGViewElement: base_config_1.TYPE_VALUE,
        Screen: base_config_1.TYPE_VALUE,
        ScreenOrientationEventMap: base_config_1.TYPE,
        ScreenOrientation: base_config_1.TYPE_VALUE,
        ScriptProcessorNodeEventMap: base_config_1.TYPE,
        ScriptProcessorNode: base_config_1.TYPE_VALUE,
        SecurityPolicyViolationEvent: base_config_1.TYPE_VALUE,
        Selection: base_config_1.TYPE_VALUE,
        ServiceWorkerEventMap: base_config_1.TYPE,
        ServiceWorker: base_config_1.TYPE_VALUE,
        ServiceWorkerContainerEventMap: base_config_1.TYPE,
        ServiceWorkerContainer: base_config_1.TYPE_VALUE,
        ServiceWorkerRegistrationEventMap: base_config_1.TYPE,
        ServiceWorkerRegistration: base_config_1.TYPE_VALUE,
        ShadowRootEventMap: base_config_1.TYPE,
        ShadowRoot: base_config_1.TYPE_VALUE,
        SharedWorker: base_config_1.TYPE_VALUE,
        Slottable: base_config_1.TYPE,
        SourceBufferEventMap: base_config_1.TYPE,
        SourceBuffer: base_config_1.TYPE_VALUE,
        SourceBufferListEventMap: base_config_1.TYPE,
        SourceBufferList: base_config_1.TYPE_VALUE,
        SpeechRecognitionAlternative: base_config_1.TYPE_VALUE,
        SpeechRecognitionResult: base_config_1.TYPE_VALUE,
        SpeechRecognitionResultList: base_config_1.TYPE_VALUE,
        SpeechSynthesisEventMap: base_config_1.TYPE,
        SpeechSynthesis: base_config_1.TYPE_VALUE,
        SpeechSynthesisErrorEvent: base_config_1.TYPE_VALUE,
        SpeechSynthesisEvent: base_config_1.TYPE_VALUE,
        SpeechSynthesisUtteranceEventMap: base_config_1.TYPE,
        SpeechSynthesisUtterance: base_config_1.TYPE_VALUE,
        SpeechSynthesisVoice: base_config_1.TYPE_VALUE,
        StaticRange: base_config_1.TYPE_VALUE,
        StereoPannerNode: base_config_1.TYPE_VALUE,
        Storage: base_config_1.TYPE_VALUE,
        StorageEvent: base_config_1.TYPE_VALUE,
        StorageManager: base_config_1.TYPE_VALUE,
        StyleMedia: base_config_1.TYPE,
        StyleSheet: base_config_1.TYPE_VALUE,
        StyleSheetList: base_config_1.TYPE_VALUE,
        SubmitEvent: base_config_1.TYPE_VALUE,
        SubtleCrypto: base_config_1.TYPE_VALUE,
        Text: base_config_1.TYPE_VALUE,
        TextDecoder: base_config_1.TYPE_VALUE,
        TextDecoderCommon: base_config_1.TYPE,
        TextDecoderStream: base_config_1.TYPE_VALUE,
        TextEncoder: base_config_1.TYPE_VALUE,
        TextEncoderCommon: base_config_1.TYPE,
        TextEncoderStream: base_config_1.TYPE_VALUE,
        TextMetrics: base_config_1.TYPE_VALUE,
        TextTrackEventMap: base_config_1.TYPE,
        TextTrack: base_config_1.TYPE_VALUE,
        TextTrackCueEventMap: base_config_1.TYPE,
        TextTrackCue: base_config_1.TYPE_VALUE,
        TextTrackCueList: base_config_1.TYPE_VALUE,
        TextTrackListEventMap: base_config_1.TYPE,
        TextTrackList: base_config_1.TYPE_VALUE,
        TimeRanges: base_config_1.TYPE_VALUE,
        Touch: base_config_1.TYPE_VALUE,
        TouchEvent: base_config_1.TYPE_VALUE,
        TouchList: base_config_1.TYPE_VALUE,
        TrackEvent: base_config_1.TYPE_VALUE,
        TransformStream: base_config_1.TYPE_VALUE,
        TransformStreamDefaultController: base_config_1.TYPE_VALUE,
        TransitionEvent: base_config_1.TYPE_VALUE,
        TreeWalker: base_config_1.TYPE_VALUE,
        UIEvent: base_config_1.TYPE_VALUE,
        URL: base_config_1.TYPE_VALUE,
        webkitURL: base_config_1.TYPE_VALUE,
        URLSearchParams: base_config_1.TYPE_VALUE,
        VTTCue: base_config_1.TYPE_VALUE,
        VTTRegion: base_config_1.TYPE_VALUE,
        ValidityState: base_config_1.TYPE_VALUE,
        VideoColorSpace: base_config_1.TYPE_VALUE,
        VideoPlaybackQuality: base_config_1.TYPE_VALUE,
        VisualViewportEventMap: base_config_1.TYPE,
        VisualViewport: base_config_1.TYPE_VALUE,
        WEBGL_color_buffer_float: base_config_1.TYPE,
        WEBGL_compressed_texture_astc: base_config_1.TYPE,
        WEBGL_compressed_texture_etc: base_config_1.TYPE,
        WEBGL_compressed_texture_etc1: base_config_1.TYPE,
        WEBGL_compressed_texture_s3tc: base_config_1.TYPE,
        WEBGL_compressed_texture_s3tc_srgb: base_config_1.TYPE,
        WEBGL_debug_renderer_info: base_config_1.TYPE,
        WEBGL_debug_shaders: base_config_1.TYPE,
        WEBGL_depth_texture: base_config_1.TYPE,
        WEBGL_draw_buffers: base_config_1.TYPE,
        WEBGL_lose_context: base_config_1.TYPE,
        WEBGL_multi_draw: base_config_1.TYPE,
        WaveShaperNode: base_config_1.TYPE_VALUE,
        WebGL2RenderingContext: base_config_1.TYPE_VALUE,
        WebGL2RenderingContextBase: base_config_1.TYPE,
        WebGL2RenderingContextOverloads: base_config_1.TYPE,
        WebGLActiveInfo: base_config_1.TYPE_VALUE,
        WebGLBuffer: base_config_1.TYPE_VALUE,
        WebGLContextEvent: base_config_1.TYPE_VALUE,
        WebGLFramebuffer: base_config_1.TYPE_VALUE,
        WebGLProgram: base_config_1.TYPE_VALUE,
        WebGLQuery: base_config_1.TYPE_VALUE,
        WebGLRenderbuffer: base_config_1.TYPE_VALUE,
        WebGLRenderingContext: base_config_1.TYPE_VALUE,
        WebGLRenderingContextBase: base_config_1.TYPE,
        WebGLRenderingContextOverloads: base_config_1.TYPE,
        WebGLSampler: base_config_1.TYPE_VALUE,
        WebGLShader: base_config_1.TYPE_VALUE,
        WebGLShaderPrecisionFormat: base_config_1.TYPE_VALUE,
        WebGLSync: base_config_1.TYPE_VALUE,
        WebGLTexture: base_config_1.TYPE_VALUE,
        WebGLTransformFeedback: base_config_1.TYPE_VALUE,
        WebGLUniformLocation: base_config_1.TYPE_VALUE,
        WebGLVertexArrayObject: base_config_1.TYPE_VALUE,
        WebGLVertexArrayObjectOES: base_config_1.TYPE,
        WebSocketEventMap: base_config_1.TYPE,
        WebSocket: base_config_1.TYPE_VALUE,
        WheelEvent: base_config_1.TYPE_VALUE,
        WindowEventMap: base_config_1.TYPE,
        Window: base_config_1.TYPE_VALUE,
        WindowEventHandlersEventMap: base_config_1.TYPE,
        WindowEventHandlers: base_config_1.TYPE,
        WindowLocalStorage: base_config_1.TYPE,
        WindowOrWorkerGlobalScope: base_config_1.TYPE,
        WindowSessionStorage: base_config_1.TYPE,
        WorkerEventMap: base_config_1.TYPE,
        Worker: base_config_1.TYPE_VALUE,
        Worklet: base_config_1.TYPE_VALUE,
        WritableStream: base_config_1.TYPE_VALUE,
        WritableStreamDefaultController: base_config_1.TYPE_VALUE,
        WritableStreamDefaultWriter: base_config_1.TYPE_VALUE,
        XMLDocument: base_config_1.TYPE_VALUE,
        XMLHttpRequestEventMap: base_config_1.TYPE,
        XMLHttpRequest: base_config_1.TYPE_VALUE,
        XMLHttpRequestEventTargetEventMap: base_config_1.TYPE,
        XMLHttpRequestEventTarget: base_config_1.TYPE_VALUE,
        XMLHttpRequestUpload: base_config_1.TYPE_VALUE,
        XMLSerializer: base_config_1.TYPE_VALUE,
        XPathEvaluator: base_config_1.TYPE_VALUE,
        XPathEvaluatorBase: base_config_1.TYPE,
        XPathExpression: base_config_1.TYPE_VALUE,
        XPathResult: base_config_1.TYPE_VALUE,
        XSLTProcessor: base_config_1.TYPE_VALUE,
        Console: base_config_1.TYPE,
        CSS: base_config_1.TYPE_VALUE,
        WebAssembly: base_config_1.TYPE_VALUE,
        BlobCallback: base_config_1.TYPE,
        CustomElementConstructor: base_config_1.TYPE,
        DecodeErrorCallback: base_config_1.TYPE,
        DecodeSuccessCallback: base_config_1.TYPE,
        ErrorCallback: base_config_1.TYPE,
        FileCallback: base_config_1.TYPE,
        FileSystemEntriesCallback: base_config_1.TYPE,
        FileSystemEntryCallback: base_config_1.TYPE,
        FrameRequestCallback: base_config_1.TYPE,
        FunctionStringCallback: base_config_1.TYPE,
        IdleRequestCallback: base_config_1.TYPE,
        IntersectionObserverCallback: base_config_1.TYPE,
        LockGrantedCallback: base_config_1.TYPE,
        MediaSessionActionHandler: base_config_1.TYPE,
        MutationCallback: base_config_1.TYPE,
        NotificationPermissionCallback: base_config_1.TYPE,
        OnBeforeUnloadEventHandlerNonNull: base_config_1.TYPE,
        OnErrorEventHandlerNonNull: base_config_1.TYPE,
        PerformanceObserverCallback: base_config_1.TYPE,
        PositionCallback: base_config_1.TYPE,
        PositionErrorCallback: base_config_1.TYPE,
        QueuingStrategySize: base_config_1.TYPE,
        RTCPeerConnectionErrorCallback: base_config_1.TYPE,
        RTCSessionDescriptionCallback: base_config_1.TYPE,
        RemotePlaybackAvailabilityCallback: base_config_1.TYPE,
        ResizeObserverCallback: base_config_1.TYPE,
        TransformerFlushCallback: base_config_1.TYPE,
        TransformerStartCallback: base_config_1.TYPE,
        TransformerTransformCallback: base_config_1.TYPE,
        UnderlyingSinkAbortCallback: base_config_1.TYPE,
        UnderlyingSinkCloseCallback: base_config_1.TYPE,
        UnderlyingSinkStartCallback: base_config_1.TYPE,
        UnderlyingSinkWriteCallback: base_config_1.TYPE,
        UnderlyingSourceCancelCallback: base_config_1.TYPE,
        UnderlyingSourcePullCallback: base_config_1.TYPE,
        UnderlyingSourceStartCallback: base_config_1.TYPE,
        VideoFrameRequestCallback: base_config_1.TYPE,
        VoidFunction: base_config_1.TYPE,
        HTMLElementTagNameMap: base_config_1.TYPE,
        HTMLElementDeprecatedTagNameMap: base_config_1.TYPE,
        SVGElementTagNameMap: base_config_1.TYPE,
        MathMLElementTagNameMap: base_config_1.TYPE,
        ElementTagNameMap: base_config_1.TYPE,
        AlgorithmIdentifier: base_config_1.TYPE,
        BigInteger: base_config_1.TYPE,
        BinaryData: base_config_1.TYPE,
        BlobPart: base_config_1.TYPE,
        BodyInit: base_config_1.TYPE,
        BufferSource: base_config_1.TYPE,
        COSEAlgorithmIdentifier: base_config_1.TYPE,
        CSSNumberish: base_config_1.TYPE,
        CanvasImageSource: base_config_1.TYPE,
        ClipboardItemData: base_config_1.TYPE,
        ClipboardItems: base_config_1.TYPE,
        ConstrainBoolean: base_config_1.TYPE,
        ConstrainDOMString: base_config_1.TYPE,
        ConstrainDouble: base_config_1.TYPE,
        ConstrainULong: base_config_1.TYPE,
        DOMHighResTimeStamp: base_config_1.TYPE,
        EpochTimeStamp: base_config_1.TYPE,
        EventListenerOrEventListenerObject: base_config_1.TYPE,
        Float32List: base_config_1.TYPE,
        FormDataEntryValue: base_config_1.TYPE,
        GLbitfield: base_config_1.TYPE,
        GLboolean: base_config_1.TYPE,
        GLclampf: base_config_1.TYPE,
        GLenum: base_config_1.TYPE,
        GLfloat: base_config_1.TYPE,
        GLint: base_config_1.TYPE,
        GLint64: base_config_1.TYPE,
        GLintptr: base_config_1.TYPE,
        GLsizei: base_config_1.TYPE,
        GLsizeiptr: base_config_1.TYPE,
        GLuint: base_config_1.TYPE,
        GLuint64: base_config_1.TYPE,
        HTMLOrSVGImageElement: base_config_1.TYPE,
        HTMLOrSVGScriptElement: base_config_1.TYPE,
        HashAlgorithmIdentifier: base_config_1.TYPE,
        HeadersInit: base_config_1.TYPE,
        IDBValidKey: base_config_1.TYPE,
        ImageBitmapSource: base_config_1.TYPE,
        Int32List: base_config_1.TYPE,
        LineAndPositionSetting: base_config_1.TYPE,
        MediaProvider: base_config_1.TYPE,
        MessageEventSource: base_config_1.TYPE,
        MutationRecordType: base_config_1.TYPE,
        NamedCurve: base_config_1.TYPE,
        OffscreenRenderingContext: base_config_1.TYPE,
        OnBeforeUnloadEventHandler: base_config_1.TYPE,
        OnErrorEventHandler: base_config_1.TYPE,
        PerformanceEntryList: base_config_1.TYPE,
        ReadableStreamController: base_config_1.TYPE,
        ReadableStreamReadResult: base_config_1.TYPE,
        ReadableStreamReader: base_config_1.TYPE,
        RenderingContext: base_config_1.TYPE,
        RequestInfo: base_config_1.TYPE,
        TexImageSource: base_config_1.TYPE,
        TimerHandler: base_config_1.TYPE,
        Transferable: base_config_1.TYPE,
        Uint32List: base_config_1.TYPE,
        VibratePattern: base_config_1.TYPE,
        WindowProxy: base_config_1.TYPE,
        XMLHttpRequestBodyInit: base_config_1.TYPE,
        AlignSetting: base_config_1.TYPE,
        AnimationPlayState: base_config_1.TYPE,
        AnimationReplaceState: base_config_1.TYPE,
        AppendMode: base_config_1.TYPE,
        AttestationConveyancePreference: base_config_1.TYPE,
        AudioContextLatencyCategory: base_config_1.TYPE,
        AudioContextState: base_config_1.TYPE,
        AuthenticatorAttachment: base_config_1.TYPE,
        AuthenticatorTransport: base_config_1.TYPE,
        AutoKeyword: base_config_1.TYPE,
        AutomationRate: base_config_1.TYPE,
        BinaryType: base_config_1.TYPE,
        BiquadFilterType: base_config_1.TYPE,
        CanPlayTypeResult: base_config_1.TYPE,
        CanvasDirection: base_config_1.TYPE,
        CanvasFillRule: base_config_1.TYPE,
        CanvasFontKerning: base_config_1.TYPE,
        CanvasFontStretch: base_config_1.TYPE,
        CanvasFontVariantCaps: base_config_1.TYPE,
        CanvasLineCap: base_config_1.TYPE,
        CanvasLineJoin: base_config_1.TYPE,
        CanvasTextAlign: base_config_1.TYPE,
        CanvasTextBaseline: base_config_1.TYPE,
        CanvasTextRendering: base_config_1.TYPE,
        ChannelCountMode: base_config_1.TYPE,
        ChannelInterpretation: base_config_1.TYPE,
        ClientTypes: base_config_1.TYPE,
        ColorGamut: base_config_1.TYPE,
        ColorSpaceConversion: base_config_1.TYPE,
        CompositeOperation: base_config_1.TYPE,
        CompositeOperationOrAuto: base_config_1.TYPE,
        CredentialMediationRequirement: base_config_1.TYPE,
        DOMParserSupportedType: base_config_1.TYPE,
        DirectionSetting: base_config_1.TYPE,
        DisplayCaptureSurfaceType: base_config_1.TYPE,
        DistanceModelType: base_config_1.TYPE,
        DocumentReadyState: base_config_1.TYPE,
        DocumentVisibilityState: base_config_1.TYPE,
        EndOfStreamError: base_config_1.TYPE,
        EndingType: base_config_1.TYPE,
        FileSystemHandleKind: base_config_1.TYPE,
        FillMode: base_config_1.TYPE,
        FontDisplay: base_config_1.TYPE,
        FontFaceLoadStatus: base_config_1.TYPE,
        FontFaceSetLoadStatus: base_config_1.TYPE,
        FullscreenNavigationUI: base_config_1.TYPE,
        GamepadHapticActuatorType: base_config_1.TYPE,
        GamepadMappingType: base_config_1.TYPE,
        GlobalCompositeOperation: base_config_1.TYPE,
        HdrMetadataType: base_config_1.TYPE,
        IDBCursorDirection: base_config_1.TYPE,
        IDBRequestReadyState: base_config_1.TYPE,
        IDBTransactionDurability: base_config_1.TYPE,
        IDBTransactionMode: base_config_1.TYPE,
        ImageOrientation: base_config_1.TYPE,
        ImageSmoothingQuality: base_config_1.TYPE,
        InsertPosition: base_config_1.TYPE,
        IterationCompositeOperation: base_config_1.TYPE,
        KeyFormat: base_config_1.TYPE,
        KeyType: base_config_1.TYPE,
        KeyUsage: base_config_1.TYPE,
        LineAlignSetting: base_config_1.TYPE,
        LockMode: base_config_1.TYPE,
        MIDIPortConnectionState: base_config_1.TYPE,
        MIDIPortDeviceState: base_config_1.TYPE,
        MIDIPortType: base_config_1.TYPE,
        MediaDecodingType: base_config_1.TYPE,
        MediaDeviceKind: base_config_1.TYPE,
        MediaEncodingType: base_config_1.TYPE,
        MediaKeyMessageType: base_config_1.TYPE,
        MediaKeySessionClosedReason: base_config_1.TYPE,
        MediaKeySessionType: base_config_1.TYPE,
        MediaKeyStatus: base_config_1.TYPE,
        MediaKeysRequirement: base_config_1.TYPE,
        MediaSessionAction: base_config_1.TYPE,
        MediaSessionPlaybackState: base_config_1.TYPE,
        MediaStreamTrackState: base_config_1.TYPE,
        NavigationTimingType: base_config_1.TYPE,
        NotificationDirection: base_config_1.TYPE,
        NotificationPermission: base_config_1.TYPE,
        OffscreenRenderingContextId: base_config_1.TYPE,
        OrientationLockType: base_config_1.TYPE,
        OrientationType: base_config_1.TYPE,
        OscillatorType: base_config_1.TYPE,
        OverSampleType: base_config_1.TYPE,
        PanningModelType: base_config_1.TYPE,
        PaymentComplete: base_config_1.TYPE,
        PermissionName: base_config_1.TYPE,
        PermissionState: base_config_1.TYPE,
        PlaybackDirection: base_config_1.TYPE,
        PositionAlignSetting: base_config_1.TYPE,
        PredefinedColorSpace: base_config_1.TYPE,
        PremultiplyAlpha: base_config_1.TYPE,
        PresentationStyle: base_config_1.TYPE,
        PublicKeyCredentialType: base_config_1.TYPE,
        PushEncryptionKeyName: base_config_1.TYPE,
        RTCBundlePolicy: base_config_1.TYPE,
        RTCDataChannelState: base_config_1.TYPE,
        RTCDegradationPreference: base_config_1.TYPE,
        RTCDtlsTransportState: base_config_1.TYPE,
        RTCEncodedVideoFrameType: base_config_1.TYPE,
        RTCErrorDetailType: base_config_1.TYPE,
        RTCIceCandidateType: base_config_1.TYPE,
        RTCIceComponent: base_config_1.TYPE,
        RTCIceConnectionState: base_config_1.TYPE,
        RTCIceGathererState: base_config_1.TYPE,
        RTCIceGatheringState: base_config_1.TYPE,
        RTCIceProtocol: base_config_1.TYPE,
        RTCIceTcpCandidateType: base_config_1.TYPE,
        RTCIceTransportPolicy: base_config_1.TYPE,
        RTCIceTransportState: base_config_1.TYPE,
        RTCPeerConnectionState: base_config_1.TYPE,
        RTCPriorityType: base_config_1.TYPE,
        RTCRtcpMuxPolicy: base_config_1.TYPE,
        RTCRtpTransceiverDirection: base_config_1.TYPE,
        RTCSctpTransportState: base_config_1.TYPE,
        RTCSdpType: base_config_1.TYPE,
        RTCSignalingState: base_config_1.TYPE,
        RTCStatsIceCandidatePairState: base_config_1.TYPE,
        RTCStatsType: base_config_1.TYPE,
        ReadableStreamReaderMode: base_config_1.TYPE,
        ReadableStreamType: base_config_1.TYPE,
        ReadyState: base_config_1.TYPE,
        RecordingState: base_config_1.TYPE,
        ReferrerPolicy: base_config_1.TYPE,
        RemotePlaybackState: base_config_1.TYPE,
        RequestCache: base_config_1.TYPE,
        RequestCredentials: base_config_1.TYPE,
        RequestDestination: base_config_1.TYPE,
        RequestMode: base_config_1.TYPE,
        RequestRedirect: base_config_1.TYPE,
        ResidentKeyRequirement: base_config_1.TYPE,
        ResizeObserverBoxOptions: base_config_1.TYPE,
        ResizeQuality: base_config_1.TYPE,
        ResponseType: base_config_1.TYPE,
        ScrollBehavior: base_config_1.TYPE,
        ScrollLogicalPosition: base_config_1.TYPE,
        ScrollRestoration: base_config_1.TYPE,
        ScrollSetting: base_config_1.TYPE,
        SecurityPolicyViolationEventDisposition: base_config_1.TYPE,
        SelectionMode: base_config_1.TYPE,
        ServiceWorkerState: base_config_1.TYPE,
        ServiceWorkerUpdateViaCache: base_config_1.TYPE,
        ShadowRootMode: base_config_1.TYPE,
        SlotAssignmentMode: base_config_1.TYPE,
        SpeechSynthesisErrorCode: base_config_1.TYPE,
        TextTrackKind: base_config_1.TYPE,
        TextTrackMode: base_config_1.TYPE,
        TouchType: base_config_1.TYPE,
        TransferFunction: base_config_1.TYPE,
        UserVerificationRequirement: base_config_1.TYPE,
        VideoColorPrimaries: base_config_1.TYPE,
        VideoFacingModeEnum: base_config_1.TYPE,
        VideoMatrixCoefficients: base_config_1.TYPE,
        VideoTransferCharacteristics: base_config_1.TYPE,
        WebGLPowerPreference: base_config_1.TYPE,
        WorkerType: base_config_1.TYPE,
        XMLHttpRequestResponseType: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/dom.iterable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.dom_iterable = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.dom_iterable = {
        AudioParam: base_config_1.TYPE,
        AudioParamMap: base_config_1.TYPE,
        BaseAudioContext: base_config_1.TYPE,
        CSSKeyframesRule: base_config_1.TYPE,
        CSSRuleList: base_config_1.TYPE,
        CSSStyleDeclaration: base_config_1.TYPE,
        Cache: base_config_1.TYPE,
        CanvasPath: base_config_1.TYPE,
        CanvasPathDrawingStyles: base_config_1.TYPE,
        DOMRectList: base_config_1.TYPE,
        DOMStringList: base_config_1.TYPE,
        DOMTokenList: base_config_1.TYPE,
        DataTransferItemList: base_config_1.TYPE,
        EventCounts: base_config_1.TYPE,
        FileList: base_config_1.TYPE,
        FontFaceSet: base_config_1.TYPE,
        FormData: base_config_1.TYPE,
        HTMLAllCollection: base_config_1.TYPE,
        HTMLCollectionBase: base_config_1.TYPE,
        HTMLCollectionOf: base_config_1.TYPE,
        HTMLFormElement: base_config_1.TYPE,
        HTMLSelectElement: base_config_1.TYPE,
        Headers: base_config_1.TYPE,
        IDBDatabase: base_config_1.TYPE,
        IDBObjectStore: base_config_1.TYPE,
        MIDIInputMap: base_config_1.TYPE,
        MIDIOutput: base_config_1.TYPE,
        MIDIOutputMap: base_config_1.TYPE,
        MediaKeyStatusMap: base_config_1.TYPE,
        MediaList: base_config_1.TYPE,
        MessageEvent: base_config_1.TYPE,
        MimeTypeArray: base_config_1.TYPE,
        NamedNodeMap: base_config_1.TYPE,
        Navigator: base_config_1.TYPE,
        NodeList: base_config_1.TYPE,
        NodeListOf: base_config_1.TYPE,
        Plugin: base_config_1.TYPE,
        PluginArray: base_config_1.TYPE,
        RTCRtpTransceiver: base_config_1.TYPE,
        RTCStatsReport: base_config_1.TYPE,
        SVGLengthList: base_config_1.TYPE,
        SVGNumberList: base_config_1.TYPE,
        SVGPointList: base_config_1.TYPE,
        SVGStringList: base_config_1.TYPE,
        SVGTransformList: base_config_1.TYPE,
        SourceBufferList: base_config_1.TYPE,
        SpeechRecognitionResult: base_config_1.TYPE,
        SpeechRecognitionResultList: base_config_1.TYPE,
        StyleSheetList: base_config_1.TYPE,
        SubtleCrypto: base_config_1.TYPE,
        TextTrackCueList: base_config_1.TYPE,
        TextTrackList: base_config_1.TYPE,
        TouchList: base_config_1.TYPE,
        URLSearchParams: base_config_1.TYPE,
        WEBGL_draw_buffers: base_config_1.TYPE,
        WEBGL_multi_draw: base_config_1.TYPE,
        WebGL2RenderingContextBase: base_config_1.TYPE,
        WebGL2RenderingContextOverloads: base_config_1.TYPE,
        WebGLRenderingContextBase: base_config_1.TYPE,
        WebGLRenderingContextOverloads: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es5.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es5 = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const decorators_1 = require(867) /* ./decorators */;
    const decorators_legacy_1 = require(869) /* ./decorators.legacy */;
    exports.es5 = Object.assign(Object.assign(Object.assign({}, decorators_1.decorators), decorators_legacy_1.decorators_legacy), { Symbol: base_config_1.TYPE, PropertyKey: base_config_1.TYPE, PropertyDescriptor: base_config_1.TYPE, PropertyDescriptorMap: base_config_1.TYPE, Object: base_config_1.TYPE_VALUE, ObjectConstructor: base_config_1.TYPE, Function: base_config_1.TYPE_VALUE, FunctionConstructor: base_config_1.TYPE, ThisParameterType: base_config_1.TYPE, OmitThisParameter: base_config_1.TYPE, CallableFunction: base_config_1.TYPE, NewableFunction: base_config_1.TYPE, IArguments: base_config_1.TYPE, String: base_config_1.TYPE_VALUE, StringConstructor: base_config_1.TYPE, Boolean: base_config_1.TYPE_VALUE, BooleanConstructor: base_config_1.TYPE, Number: base_config_1.TYPE_VALUE, NumberConstructor: base_config_1.TYPE, TemplateStringsArray: base_config_1.TYPE, ImportMeta: base_config_1.TYPE, ImportCallOptions: base_config_1.TYPE, ImportAssertions: base_config_1.TYPE, Math: base_config_1.TYPE_VALUE, Date: base_config_1.TYPE_VALUE, DateConstructor: base_config_1.TYPE, RegExpMatchArray: base_config_1.TYPE, RegExpExecArray: base_config_1.TYPE, RegExp: base_config_1.TYPE_VALUE, RegExpConstructor: base_config_1.TYPE, Error: base_config_1.TYPE_VALUE, ErrorConstructor: base_config_1.TYPE, EvalError: base_config_1.TYPE_VALUE, EvalErrorConstructor: base_config_1.TYPE, RangeError: base_config_1.TYPE_VALUE, RangeErrorConstructor: base_config_1.TYPE, ReferenceError: base_config_1.TYPE_VALUE, ReferenceErrorConstructor: base_config_1.TYPE, SyntaxError: base_config_1.TYPE_VALUE, SyntaxErrorConstructor: base_config_1.TYPE, TypeError: base_config_1.TYPE_VALUE, TypeErrorConstructor: base_config_1.TYPE, URIError: base_config_1.TYPE_VALUE, URIErrorConstructor: base_config_1.TYPE, JSON: base_config_1.TYPE_VALUE, ReadonlyArray: base_config_1.TYPE, ConcatArray: base_config_1.TYPE, Array: base_config_1.TYPE_VALUE, ArrayConstructor: base_config_1.TYPE, TypedPropertyDescriptor: base_config_1.TYPE, PromiseConstructorLike: base_config_1.TYPE, PromiseLike: base_config_1.TYPE, Promise: base_config_1.TYPE, Awaited: base_config_1.TYPE, ArrayLike: base_config_1.TYPE, Partial: base_config_1.TYPE, Required: base_config_1.TYPE, Readonly: base_config_1.TYPE, Pick: base_config_1.TYPE, Record: base_config_1.TYPE, Exclude: base_config_1.TYPE, Extract: base_config_1.TYPE, Omit: base_config_1.TYPE, NonNullable: base_config_1.TYPE, Parameters: base_config_1.TYPE, ConstructorParameters: base_config_1.TYPE, ReturnType: base_config_1.TYPE, InstanceType: base_config_1.TYPE, Uppercase: base_config_1.TYPE, Lowercase: base_config_1.TYPE, Capitalize: base_config_1.TYPE, Uncapitalize: base_config_1.TYPE, ThisType: base_config_1.TYPE, ArrayBuffer: base_config_1.TYPE_VALUE, ArrayBufferTypes: base_config_1.TYPE, ArrayBufferLike: base_config_1.TYPE, ArrayBufferConstructor: base_config_1.TYPE, ArrayBufferView: base_config_1.TYPE, DataView: base_config_1.TYPE_VALUE, DataViewConstructor: base_config_1.TYPE, Int8Array: base_config_1.TYPE_VALUE, Int8ArrayConstructor: base_config_1.TYPE, Uint8Array: base_config_1.TYPE_VALUE, Uint8ArrayConstructor: base_config_1.TYPE, Uint8ClampedArray: base_config_1.TYPE_VALUE, Uint8ClampedArrayConstructor: base_config_1.TYPE, Int16Array: base_config_1.TYPE_VALUE, Int16ArrayConstructor: base_config_1.TYPE, Uint16Array: base_config_1.TYPE_VALUE, Uint16ArrayConstructor: base_config_1.TYPE, Int32Array: base_config_1.TYPE_VALUE, Int32ArrayConstructor: base_config_1.TYPE, Uint32Array: base_config_1.TYPE_VALUE, Uint32ArrayConstructor: base_config_1.TYPE, Float32Array: base_config_1.TYPE_VALUE, Float32ArrayConstructor: base_config_1.TYPE, Float64Array: base_config_1.TYPE_VALUE, Float64ArrayConstructor: base_config_1.TYPE, Intl: base_config_1.TYPE_VALUE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es6.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es6 = void 0;
    const es5_1 = require(872) /* ./es5 */;
    const es2015_collection_1 = require(874) /* ./es2015.collection */;
    const es2015_core_1 = require(875) /* ./es2015.core */;
    const es2015_generator_1 = require(876) /* ./es2015.generator */;
    const es2015_iterable_1 = require(877) /* ./es2015.iterable */;
    const es2015_promise_1 = require(879) /* ./es2015.promise */;
    const es2015_proxy_1 = require(880) /* ./es2015.proxy */;
    const es2015_reflect_1 = require(881) /* ./es2015.reflect */;
    const es2015_symbol_1 = require(878) /* ./es2015.symbol */;
    const es2015_symbol_wellknown_1 = require(882) /* ./es2015.symbol.wellknown */;
    exports.es6 = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es5_1.es5), es2015_core_1.es2015_core), es2015_collection_1.es2015_collection), es2015_iterable_1.es2015_iterable), es2015_generator_1.es2015_generator), es2015_promise_1.es2015_promise), es2015_proxy_1.es2015_proxy), es2015_reflect_1.es2015_reflect), es2015_symbol_1.es2015_symbol), es2015_symbol_wellknown_1.es2015_symbol_wellknown);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.collection.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015_collection = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2015_collection = {
        Map: base_config_1.TYPE_VALUE,
        MapConstructor: base_config_1.TYPE,
        ReadonlyMap: base_config_1.TYPE,
        WeakMap: base_config_1.TYPE_VALUE,
        WeakMapConstructor: base_config_1.TYPE,
        Set: base_config_1.TYPE_VALUE,
        SetConstructor: base_config_1.TYPE,
        ReadonlySet: base_config_1.TYPE,
        WeakSet: base_config_1.TYPE_VALUE,
        WeakSetConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.core.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015_core = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2015_core = {
        Array: base_config_1.TYPE,
        ArrayConstructor: base_config_1.TYPE,
        DateConstructor: base_config_1.TYPE,
        Function: base_config_1.TYPE,
        Math: base_config_1.TYPE,
        NumberConstructor: base_config_1.TYPE,
        ObjectConstructor: base_config_1.TYPE,
        ReadonlyArray: base_config_1.TYPE,
        RegExp: base_config_1.TYPE,
        RegExpConstructor: base_config_1.TYPE,
        String: base_config_1.TYPE,
        StringConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.generator.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015_generator = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2015_iterable_1 = require(877) /* ./es2015.iterable */;
    exports.es2015_generator = Object.assign(Object.assign({}, es2015_iterable_1.es2015_iterable), { Generator: base_config_1.TYPE, GeneratorFunction: base_config_1.TYPE, GeneratorFunctionConstructor: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.iterable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015_iterable = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2015_symbol_1 = require(878) /* ./es2015.symbol */;
    exports.es2015_iterable = Object.assign(Object.assign({}, es2015_symbol_1.es2015_symbol), { SymbolConstructor: base_config_1.TYPE, IteratorYieldResult: base_config_1.TYPE, IteratorReturnResult: base_config_1.TYPE, IteratorResult: base_config_1.TYPE, Iterator: base_config_1.TYPE, Iterable: base_config_1.TYPE, IterableIterator: base_config_1.TYPE, Array: base_config_1.TYPE, ArrayConstructor: base_config_1.TYPE, ReadonlyArray: base_config_1.TYPE, IArguments: base_config_1.TYPE, Map: base_config_1.TYPE, ReadonlyMap: base_config_1.TYPE, MapConstructor: base_config_1.TYPE, WeakMap: base_config_1.TYPE, WeakMapConstructor: base_config_1.TYPE, Set: base_config_1.TYPE, ReadonlySet: base_config_1.TYPE, SetConstructor: base_config_1.TYPE, WeakSet: base_config_1.TYPE, WeakSetConstructor: base_config_1.TYPE, Promise: base_config_1.TYPE, PromiseConstructor: base_config_1.TYPE, String: base_config_1.TYPE, Int8Array: base_config_1.TYPE, Int8ArrayConstructor: base_config_1.TYPE, Uint8Array: base_config_1.TYPE, Uint8ArrayConstructor: base_config_1.TYPE, Uint8ClampedArray: base_config_1.TYPE, Uint8ClampedArrayConstructor: base_config_1.TYPE, Int16Array: base_config_1.TYPE, Int16ArrayConstructor: base_config_1.TYPE, Uint16Array: base_config_1.TYPE, Uint16ArrayConstructor: base_config_1.TYPE, Int32Array: base_config_1.TYPE, Int32ArrayConstructor: base_config_1.TYPE, Uint32Array: base_config_1.TYPE, Uint32ArrayConstructor: base_config_1.TYPE, Float32Array: base_config_1.TYPE, Float32ArrayConstructor: base_config_1.TYPE, Float64Array: base_config_1.TYPE, Float64ArrayConstructor: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.symbol.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015_symbol = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2015_symbol = {
        SymbolConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.promise.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015_promise = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2015_promise = {
        PromiseConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.proxy.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015_proxy = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2015_proxy = {
        ProxyHandler: base_config_1.TYPE,
        ProxyConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.reflect.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015_reflect = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2015_reflect = {
        Reflect: base_config_1.TYPE_VALUE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.symbol.wellknown.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015_symbol_wellknown = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2015_symbol_1 = require(878) /* ./es2015.symbol */;
    exports.es2015_symbol_wellknown = Object.assign(Object.assign({}, es2015_symbol_1.es2015_symbol), { SymbolConstructor: base_config_1.TYPE, Symbol: base_config_1.TYPE, Array: base_config_1.TYPE, ReadonlyArray: base_config_1.TYPE, Date: base_config_1.TYPE, Map: base_config_1.TYPE, WeakMap: base_config_1.TYPE, Set: base_config_1.TYPE, WeakSet: base_config_1.TYPE, JSON: base_config_1.TYPE, Function: base_config_1.TYPE, GeneratorFunction: base_config_1.TYPE, Math: base_config_1.TYPE, Promise: base_config_1.TYPE, PromiseConstructor: base_config_1.TYPE, RegExp: base_config_1.TYPE, RegExpConstructor: base_config_1.TYPE, String: base_config_1.TYPE, ArrayBuffer: base_config_1.TYPE, DataView: base_config_1.TYPE, Int8Array: base_config_1.TYPE, Uint8Array: base_config_1.TYPE, Uint8ClampedArray: base_config_1.TYPE, Int16Array: base_config_1.TYPE, Uint16Array: base_config_1.TYPE, Int32Array: base_config_1.TYPE, Uint32Array: base_config_1.TYPE, Float32Array: base_config_1.TYPE, Float64Array: base_config_1.TYPE, ArrayConstructor: base_config_1.TYPE, MapConstructor: base_config_1.TYPE, SetConstructor: base_config_1.TYPE, ArrayBufferConstructor: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es7.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es7 = void 0;
    const es2015_1 = require(884) /* ./es2015 */;
    const es2016_array_include_1 = require(885) /* ./es2016.array.include */;
    exports.es7 = Object.assign(Object.assign({}, es2015_1.es2015), es2016_array_include_1.es2016_array_include);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2015.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2015 = void 0;
    const es5_1 = require(872) /* ./es5 */;
    const es2015_collection_1 = require(874) /* ./es2015.collection */;
    const es2015_core_1 = require(875) /* ./es2015.core */;
    const es2015_generator_1 = require(876) /* ./es2015.generator */;
    const es2015_iterable_1 = require(877) /* ./es2015.iterable */;
    const es2015_promise_1 = require(879) /* ./es2015.promise */;
    const es2015_proxy_1 = require(880) /* ./es2015.proxy */;
    const es2015_reflect_1 = require(881) /* ./es2015.reflect */;
    const es2015_symbol_1 = require(878) /* ./es2015.symbol */;
    const es2015_symbol_wellknown_1 = require(882) /* ./es2015.symbol.wellknown */;
    exports.es2015 = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es5_1.es5), es2015_core_1.es2015_core), es2015_collection_1.es2015_collection), es2015_iterable_1.es2015_iterable), es2015_generator_1.es2015_generator), es2015_promise_1.es2015_promise), es2015_proxy_1.es2015_proxy), es2015_reflect_1.es2015_reflect), es2015_symbol_1.es2015_symbol), es2015_symbol_wellknown_1.es2015_symbol_wellknown);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2016.array.include.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2016_array_include = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2016_array_include = {
        Array: base_config_1.TYPE,
        ReadonlyArray: base_config_1.TYPE,
        Int8Array: base_config_1.TYPE,
        Uint8Array: base_config_1.TYPE,
        Uint8ClampedArray: base_config_1.TYPE,
        Int16Array: base_config_1.TYPE,
        Uint16Array: base_config_1.TYPE,
        Int32Array: base_config_1.TYPE,
        Uint32Array: base_config_1.TYPE,
        Float32Array: base_config_1.TYPE,
        Float64Array: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2016.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2016 = void 0;
    const es2015_1 = require(884) /* ./es2015 */;
    const es2016_array_include_1 = require(885) /* ./es2016.array.include */;
    exports.es2016 = Object.assign(Object.assign({}, es2015_1.es2015), es2016_array_include_1.es2016_array_include);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2016.full.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2016_full = void 0;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const es2016_1 = require(886) /* ./es2016 */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.es2016_full = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2016_1.es2016), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost), dom_iterable_1.dom_iterable);
    
},
/* @typescript-eslint/scope-manager/dist/lib/scripthost.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.scripthost = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.scripthost = {
        ActiveXObject: base_config_1.TYPE_VALUE,
        ITextWriter: base_config_1.TYPE,
        TextStreamBase: base_config_1.TYPE,
        TextStreamWriter: base_config_1.TYPE,
        TextStreamReader: base_config_1.TYPE,
        SafeArray: base_config_1.TYPE_VALUE,
        Enumerator: base_config_1.TYPE_VALUE,
        EnumeratorConstructor: base_config_1.TYPE,
        VBArray: base_config_1.TYPE_VALUE,
        VBArrayConstructor: base_config_1.TYPE,
        VarDate: base_config_1.TYPE_VALUE,
        DateConstructor: base_config_1.TYPE,
        Date: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/webworker.importscripts.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.webworker_importscripts = void 0;
    exports.webworker_importscripts = {};
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2017.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2017 = void 0;
    const es2016_1 = require(886) /* ./es2016 */;
    const es2017_intl_1 = require(891) /* ./es2017.intl */;
    const es2017_object_1 = require(892) /* ./es2017.object */;
    const es2017_sharedmemory_1 = require(893) /* ./es2017.sharedmemory */;
    const es2017_string_1 = require(894) /* ./es2017.string */;
    const es2017_typedarrays_1 = require(895) /* ./es2017.typedarrays */;
    exports.es2017 = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2016_1.es2016), es2017_object_1.es2017_object), es2017_sharedmemory_1.es2017_sharedmemory), es2017_string_1.es2017_string), es2017_intl_1.es2017_intl), es2017_typedarrays_1.es2017_typedarrays);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2017.intl.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2017_intl = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2017_intl = {
        Intl: base_config_1.TYPE_VALUE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2017.object.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2017_object = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2017_object = {
        ObjectConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2017.sharedmemory.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2017_sharedmemory = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2015_symbol_1 = require(878) /* ./es2015.symbol */;
    const es2015_symbol_wellknown_1 = require(882) /* ./es2015.symbol.wellknown */;
    exports.es2017_sharedmemory = Object.assign(Object.assign(Object.assign({}, es2015_symbol_1.es2015_symbol), es2015_symbol_wellknown_1.es2015_symbol_wellknown), { SharedArrayBuffer: base_config_1.TYPE_VALUE, SharedArrayBufferConstructor: base_config_1.TYPE, ArrayBufferTypes: base_config_1.TYPE, Atomics: base_config_1.TYPE_VALUE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2017.string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2017_string = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2017_string = {
        String: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2017.typedarrays.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2017_typedarrays = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2017_typedarrays = {
        Int8ArrayConstructor: base_config_1.TYPE,
        Uint8ArrayConstructor: base_config_1.TYPE,
        Uint8ClampedArrayConstructor: base_config_1.TYPE,
        Int16ArrayConstructor: base_config_1.TYPE,
        Uint16ArrayConstructor: base_config_1.TYPE,
        Int32ArrayConstructor: base_config_1.TYPE,
        Uint32ArrayConstructor: base_config_1.TYPE,
        Float32ArrayConstructor: base_config_1.TYPE,
        Float64ArrayConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2017.full.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2017_full = void 0;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const es2017_1 = require(890) /* ./es2017 */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.es2017_full = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2017_1.es2017), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost), dom_iterable_1.dom_iterable);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2018.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2018 = void 0;
    const es2017_1 = require(890) /* ./es2017 */;
    const es2018_asyncgenerator_1 = require(898) /* ./es2018.asyncgenerator */;
    const es2018_asynciterable_1 = require(899) /* ./es2018.asynciterable */;
    const es2018_intl_1 = require(900) /* ./es2018.intl */;
    const es2018_promise_1 = require(901) /* ./es2018.promise */;
    const es2018_regexp_1 = require(902) /* ./es2018.regexp */;
    exports.es2018 = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2017_1.es2017), es2018_asynciterable_1.es2018_asynciterable), es2018_asyncgenerator_1.es2018_asyncgenerator), es2018_promise_1.es2018_promise), es2018_regexp_1.es2018_regexp), es2018_intl_1.es2018_intl);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2018.asyncgenerator.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2018_asyncgenerator = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2018_asynciterable_1 = require(899) /* ./es2018.asynciterable */;
    exports.es2018_asyncgenerator = Object.assign(Object.assign({}, es2018_asynciterable_1.es2018_asynciterable), { AsyncGenerator: base_config_1.TYPE, AsyncGeneratorFunction: base_config_1.TYPE, AsyncGeneratorFunctionConstructor: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2018.asynciterable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2018_asynciterable = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2015_iterable_1 = require(877) /* ./es2015.iterable */;
    const es2015_symbol_1 = require(878) /* ./es2015.symbol */;
    exports.es2018_asynciterable = Object.assign(Object.assign(Object.assign({}, es2015_symbol_1.es2015_symbol), es2015_iterable_1.es2015_iterable), { SymbolConstructor: base_config_1.TYPE, AsyncIterator: base_config_1.TYPE, AsyncIterable: base_config_1.TYPE, AsyncIterableIterator: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2018.intl.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2018_intl = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2018_intl = {
        Intl: base_config_1.TYPE_VALUE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2018.promise.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2018_promise = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2018_promise = {
        Promise: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2018.regexp.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2018_regexp = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2018_regexp = {
        RegExpMatchArray: base_config_1.TYPE,
        RegExpExecArray: base_config_1.TYPE,
        RegExp: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2018.full.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2018_full = void 0;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const es2018_1 = require(897) /* ./es2018 */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.es2018_full = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2018_1.es2018), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost), dom_iterable_1.dom_iterable);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2019.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2019 = void 0;
    const es2018_1 = require(897) /* ./es2018 */;
    const es2019_array_1 = require(905) /* ./es2019.array */;
    const es2019_intl_1 = require(906) /* ./es2019.intl */;
    const es2019_object_1 = require(907) /* ./es2019.object */;
    const es2019_string_1 = require(908) /* ./es2019.string */;
    const es2019_symbol_1 = require(909) /* ./es2019.symbol */;
    exports.es2019 = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2018_1.es2018), es2019_array_1.es2019_array), es2019_object_1.es2019_object), es2019_string_1.es2019_string), es2019_symbol_1.es2019_symbol), es2019_intl_1.es2019_intl);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2019.array.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2019_array = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2019_array = {
        FlatArray: base_config_1.TYPE,
        ReadonlyArray: base_config_1.TYPE,
        Array: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2019.intl.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2019_intl = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2019_intl = {
        Intl: base_config_1.TYPE_VALUE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2019.object.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2019_object = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2015_iterable_1 = require(877) /* ./es2015.iterable */;
    exports.es2019_object = Object.assign(Object.assign({}, es2015_iterable_1.es2015_iterable), { ObjectConstructor: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2019.string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2019_string = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2019_string = {
        String: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2019.symbol.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2019_symbol = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2019_symbol = {
        Symbol: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2019.full.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2019_full = void 0;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const es2019_1 = require(904) /* ./es2019 */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.es2019_full = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2019_1.es2019), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost), dom_iterable_1.dom_iterable);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020 = void 0;
    const es2019_1 = require(904) /* ./es2019 */;
    const es2020_bigint_1 = require(912) /* ./es2020.bigint */;
    const es2020_date_1 = require(914) /* ./es2020.date */;
    const es2020_intl_1 = require(913) /* ./es2020.intl */;
    const es2020_number_1 = require(915) /* ./es2020.number */;
    const es2020_promise_1 = require(916) /* ./es2020.promise */;
    const es2020_sharedmemory_1 = require(917) /* ./es2020.sharedmemory */;
    const es2020_string_1 = require(918) /* ./es2020.string */;
    const es2020_symbol_wellknown_1 = require(919) /* ./es2020.symbol.wellknown */;
    exports.es2020 = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2019_1.es2019), es2020_bigint_1.es2020_bigint), es2020_date_1.es2020_date), es2020_number_1.es2020_number), es2020_promise_1.es2020_promise), es2020_sharedmemory_1.es2020_sharedmemory), es2020_string_1.es2020_string), es2020_symbol_wellknown_1.es2020_symbol_wellknown), es2020_intl_1.es2020_intl);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.bigint.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020_bigint = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2020_intl_1 = require(913) /* ./es2020.intl */;
    exports.es2020_bigint = Object.assign(Object.assign({}, es2020_intl_1.es2020_intl), { BigIntToLocaleStringOptions: base_config_1.TYPE, BigInt: base_config_1.TYPE_VALUE, BigIntConstructor: base_config_1.TYPE, BigInt64Array: base_config_1.TYPE_VALUE, BigInt64ArrayConstructor: base_config_1.TYPE, BigUint64Array: base_config_1.TYPE_VALUE, BigUint64ArrayConstructor: base_config_1.TYPE, DataView: base_config_1.TYPE, Intl: base_config_1.TYPE_VALUE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.intl.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020_intl = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2018_intl_1 = require(900) /* ./es2018.intl */;
    exports.es2020_intl = Object.assign(Object.assign({}, es2018_intl_1.es2018_intl), { Intl: base_config_1.TYPE_VALUE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.date.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020_date = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2020_intl_1 = require(913) /* ./es2020.intl */;
    exports.es2020_date = Object.assign(Object.assign({}, es2020_intl_1.es2020_intl), { Date: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.number.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020_number = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2020_intl_1 = require(913) /* ./es2020.intl */;
    exports.es2020_number = Object.assign(Object.assign({}, es2020_intl_1.es2020_intl), { Number: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.promise.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020_promise = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2020_promise = {
        PromiseFulfilledResult: base_config_1.TYPE,
        PromiseRejectedResult: base_config_1.TYPE,
        PromiseSettledResult: base_config_1.TYPE,
        PromiseConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.sharedmemory.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020_sharedmemory = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2020_sharedmemory = {
        Atomics: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020_string = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2015_iterable_1 = require(877) /* ./es2015.iterable */;
    exports.es2020_string = Object.assign(Object.assign({}, es2015_iterable_1.es2015_iterable), { String: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.symbol.wellknown.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020_symbol_wellknown = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2015_iterable_1 = require(877) /* ./es2015.iterable */;
    const es2015_symbol_1 = require(878) /* ./es2015.symbol */;
    exports.es2020_symbol_wellknown = Object.assign(Object.assign(Object.assign({}, es2015_iterable_1.es2015_iterable), es2015_symbol_1.es2015_symbol), { SymbolConstructor: base_config_1.TYPE, RegExp: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2020.full.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2020_full = void 0;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const es2020_1 = require(911) /* ./es2020 */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.es2020_full = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2020_1.es2020), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost), dom_iterable_1.dom_iterable);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2021.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2021 = void 0;
    const es2020_1 = require(911) /* ./es2020 */;
    const es2021_intl_1 = require(922) /* ./es2021.intl */;
    const es2021_promise_1 = require(923) /* ./es2021.promise */;
    const es2021_string_1 = require(924) /* ./es2021.string */;
    const es2021_weakref_1 = require(925) /* ./es2021.weakref */;
    exports.es2021 = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2020_1.es2020), es2021_promise_1.es2021_promise), es2021_string_1.es2021_string), es2021_weakref_1.es2021_weakref), es2021_intl_1.es2021_intl);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2021.intl.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2021_intl = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2021_intl = {
        Intl: base_config_1.TYPE_VALUE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2021.promise.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2021_promise = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2021_promise = {
        AggregateError: base_config_1.TYPE_VALUE,
        AggregateErrorConstructor: base_config_1.TYPE,
        PromiseConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2021.string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2021_string = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2021_string = {
        String: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2021.weakref.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2021_weakref = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2021_weakref = {
        WeakRef: base_config_1.TYPE_VALUE,
        WeakRefConstructor: base_config_1.TYPE,
        FinalizationRegistry: base_config_1.TYPE_VALUE,
        FinalizationRegistryConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2021.full.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2021_full = void 0;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const es2021_1 = require(921) /* ./es2021 */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.es2021_full = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2021_1.es2021), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost), dom_iterable_1.dom_iterable);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2022.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2022 = void 0;
    const es2021_1 = require(921) /* ./es2021 */;
    const es2022_array_1 = require(928) /* ./es2022.array */;
    const es2022_error_1 = require(929) /* ./es2022.error */;
    const es2022_intl_1 = require(930) /* ./es2022.intl */;
    const es2022_object_1 = require(931) /* ./es2022.object */;
    const es2022_regexp_1 = require(932) /* ./es2022.regexp */;
    const es2022_sharedmemory_1 = require(933) /* ./es2022.sharedmemory */;
    const es2022_string_1 = require(934) /* ./es2022.string */;
    exports.es2022 = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2021_1.es2021), es2022_array_1.es2022_array), es2022_error_1.es2022_error), es2022_intl_1.es2022_intl), es2022_object_1.es2022_object), es2022_sharedmemory_1.es2022_sharedmemory), es2022_string_1.es2022_string), es2022_regexp_1.es2022_regexp);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2022.array.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2022_array = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2022_array = {
        Array: base_config_1.TYPE,
        ReadonlyArray: base_config_1.TYPE,
        Int8Array: base_config_1.TYPE,
        Uint8Array: base_config_1.TYPE,
        Uint8ClampedArray: base_config_1.TYPE,
        Int16Array: base_config_1.TYPE,
        Uint16Array: base_config_1.TYPE,
        Int32Array: base_config_1.TYPE,
        Uint32Array: base_config_1.TYPE,
        Float32Array: base_config_1.TYPE,
        Float64Array: base_config_1.TYPE,
        BigInt64Array: base_config_1.TYPE,
        BigUint64Array: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2022.error.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2022_error = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2022_error = {
        ErrorOptions: base_config_1.TYPE,
        Error: base_config_1.TYPE,
        ErrorConstructor: base_config_1.TYPE,
        EvalErrorConstructor: base_config_1.TYPE,
        RangeErrorConstructor: base_config_1.TYPE,
        ReferenceErrorConstructor: base_config_1.TYPE,
        SyntaxErrorConstructor: base_config_1.TYPE,
        TypeErrorConstructor: base_config_1.TYPE,
        URIErrorConstructor: base_config_1.TYPE,
        AggregateErrorConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2022.intl.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2022_intl = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2022_intl = {
        Intl: base_config_1.TYPE_VALUE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2022.object.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2022_object = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2022_object = {
        ObjectConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2022.regexp.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2022_regexp = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2022_regexp = {
        RegExpMatchArray: base_config_1.TYPE,
        RegExpExecArray: base_config_1.TYPE,
        RegExpIndicesArray: base_config_1.TYPE,
        RegExp: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2022.sharedmemory.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2022_sharedmemory = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2022_sharedmemory = {
        Atomics: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2022.string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2022_string = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2022_string = {
        String: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2022.full.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2022_full = void 0;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const es2022_1 = require(927) /* ./es2022 */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.es2022_full = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2022_1.es2022), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost), dom_iterable_1.dom_iterable);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2023.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2023 = void 0;
    const es2022_1 = require(927) /* ./es2022 */;
    const es2023_array_1 = require(937) /* ./es2023.array */;
    exports.es2023 = Object.assign(Object.assign({}, es2022_1.es2022), es2023_array_1.es2023_array);
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2023.array.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2023_array = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.es2023_array = {
        Array: base_config_1.TYPE,
        ReadonlyArray: base_config_1.TYPE,
        Int8Array: base_config_1.TYPE,
        Uint8Array: base_config_1.TYPE,
        Uint8ClampedArray: base_config_1.TYPE,
        Int16Array: base_config_1.TYPE,
        Uint16Array: base_config_1.TYPE,
        Int32Array: base_config_1.TYPE,
        Uint32Array: base_config_1.TYPE,
        Float32Array: base_config_1.TYPE,
        Float64Array: base_config_1.TYPE,
        BigInt64Array: base_config_1.TYPE,
        BigUint64Array: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/es2023.full.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.es2023_full = void 0;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const es2023_1 = require(936) /* ./es2023 */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.es2023_full = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, es2023_1.es2023), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost), dom_iterable_1.dom_iterable);
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext = void 0;
    const es2023_1 = require(936) /* ./es2023 */;
    const esnext_intl_1 = require(940) /* ./esnext.intl */;
    exports.esnext = Object.assign(Object.assign({}, es2023_1.es2023), esnext_intl_1.esnext_intl);
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.intl.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext_intl = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.esnext_intl = {
        Intl: base_config_1.TYPE_VALUE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.array.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext_array = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.esnext_array = {
        Array: base_config_1.TYPE,
        ReadonlyArray: base_config_1.TYPE,
        Int8Array: base_config_1.TYPE,
        Uint8Array: base_config_1.TYPE,
        Uint8ClampedArray: base_config_1.TYPE,
        Int16Array: base_config_1.TYPE,
        Uint16Array: base_config_1.TYPE,
        Int32Array: base_config_1.TYPE,
        Uint32Array: base_config_1.TYPE,
        Float32Array: base_config_1.TYPE,
        Float64Array: base_config_1.TYPE,
        BigInt64Array: base_config_1.TYPE,
        BigUint64Array: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.asynciterable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext_asynciterable = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2015_iterable_1 = require(877) /* ./es2015.iterable */;
    const es2015_symbol_1 = require(878) /* ./es2015.symbol */;
    exports.esnext_asynciterable = Object.assign(Object.assign(Object.assign({}, es2015_symbol_1.es2015_symbol), es2015_iterable_1.es2015_iterable), { SymbolConstructor: base_config_1.TYPE, AsyncIterator: base_config_1.TYPE, AsyncIterable: base_config_1.TYPE, AsyncIterableIterator: base_config_1.TYPE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.bigint.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext_bigint = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    const es2020_intl_1 = require(913) /* ./es2020.intl */;
    exports.esnext_bigint = Object.assign(Object.assign({}, es2020_intl_1.es2020_intl), { BigIntToLocaleStringOptions: base_config_1.TYPE, BigInt: base_config_1.TYPE_VALUE, BigIntConstructor: base_config_1.TYPE, BigInt64Array: base_config_1.TYPE_VALUE, BigInt64ArrayConstructor: base_config_1.TYPE, BigUint64Array: base_config_1.TYPE_VALUE, BigUint64ArrayConstructor: base_config_1.TYPE, DataView: base_config_1.TYPE, Intl: base_config_1.TYPE_VALUE });
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.full.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext_full = void 0;
    const dom_1 = require(870) /* ./dom */;
    const dom_iterable_1 = require(871) /* ./dom.iterable */;
    const esnext_1 = require(939) /* ./esnext */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.esnext_full = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, esnext_1.esnext), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost), dom_iterable_1.dom_iterable);
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.promise.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext_promise = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.esnext_promise = {
        AggregateError: base_config_1.TYPE_VALUE,
        AggregateErrorConstructor: base_config_1.TYPE,
        PromiseConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext_string = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.esnext_string = {
        String: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.symbol.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext_symbol = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.esnext_symbol = {
        Symbol: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/esnext.weakref.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.esnext_weakref = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.esnext_weakref = {
        WeakRef: base_config_1.TYPE_VALUE,
        WeakRefConstructor: base_config_1.TYPE,
        FinalizationRegistry: base_config_1.TYPE_VALUE,
        FinalizationRegistryConstructor: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/lib.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.lib = void 0;
    const dom_1 = require(870) /* ./dom */;
    const es5_1 = require(872) /* ./es5 */;
    const scripthost_1 = require(888) /* ./scripthost */;
    const webworker_importscripts_1 = require(889) /* ./webworker.importscripts */;
    exports.lib = Object.assign(Object.assign(Object.assign(Object.assign({}, es5_1.es5), dom_1.dom), webworker_importscripts_1.webworker_importscripts), scripthost_1.scripthost);
    
},
/* @typescript-eslint/scope-manager/dist/lib/webworker.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.webworker = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.webworker = {
        AddEventListenerOptions: base_config_1.TYPE,
        AesCbcParams: base_config_1.TYPE,
        AesCtrParams: base_config_1.TYPE,
        AesDerivedKeyParams: base_config_1.TYPE,
        AesGcmParams: base_config_1.TYPE,
        AesKeyAlgorithm: base_config_1.TYPE,
        AesKeyGenParams: base_config_1.TYPE,
        Algorithm: base_config_1.TYPE,
        AudioConfiguration: base_config_1.TYPE,
        BlobPropertyBag: base_config_1.TYPE,
        CacheQueryOptions: base_config_1.TYPE,
        ClientQueryOptions: base_config_1.TYPE,
        CloseEventInit: base_config_1.TYPE,
        CryptoKeyPair: base_config_1.TYPE,
        CustomEventInit: base_config_1.TYPE,
        DOMMatrix2DInit: base_config_1.TYPE,
        DOMMatrixInit: base_config_1.TYPE,
        DOMPointInit: base_config_1.TYPE,
        DOMQuadInit: base_config_1.TYPE,
        DOMRectInit: base_config_1.TYPE,
        EcKeyGenParams: base_config_1.TYPE,
        EcKeyImportParams: base_config_1.TYPE,
        EcdhKeyDeriveParams: base_config_1.TYPE,
        EcdsaParams: base_config_1.TYPE,
        ErrorEventInit: base_config_1.TYPE,
        EventInit: base_config_1.TYPE,
        EventListenerOptions: base_config_1.TYPE,
        EventSourceInit: base_config_1.TYPE,
        ExtendableEventInit: base_config_1.TYPE,
        ExtendableMessageEventInit: base_config_1.TYPE,
        FetchEventInit: base_config_1.TYPE,
        FilePropertyBag: base_config_1.TYPE,
        FileSystemGetDirectoryOptions: base_config_1.TYPE,
        FileSystemGetFileOptions: base_config_1.TYPE,
        FileSystemReadWriteOptions: base_config_1.TYPE,
        FileSystemRemoveOptions: base_config_1.TYPE,
        FontFaceDescriptors: base_config_1.TYPE,
        FontFaceSetLoadEventInit: base_config_1.TYPE,
        GetNotificationOptions: base_config_1.TYPE,
        HkdfParams: base_config_1.TYPE,
        HmacImportParams: base_config_1.TYPE,
        HmacKeyGenParams: base_config_1.TYPE,
        IDBDatabaseInfo: base_config_1.TYPE,
        IDBIndexParameters: base_config_1.TYPE,
        IDBObjectStoreParameters: base_config_1.TYPE,
        IDBTransactionOptions: base_config_1.TYPE,
        IDBVersionChangeEventInit: base_config_1.TYPE,
        ImageBitmapOptions: base_config_1.TYPE,
        ImageBitmapRenderingContextSettings: base_config_1.TYPE,
        ImageDataSettings: base_config_1.TYPE,
        ImageEncodeOptions: base_config_1.TYPE,
        ImportMeta: base_config_1.TYPE,
        JsonWebKey: base_config_1.TYPE,
        KeyAlgorithm: base_config_1.TYPE,
        LockInfo: base_config_1.TYPE,
        LockManagerSnapshot: base_config_1.TYPE,
        LockOptions: base_config_1.TYPE,
        MediaCapabilitiesDecodingInfo: base_config_1.TYPE,
        MediaCapabilitiesEncodingInfo: base_config_1.TYPE,
        MediaCapabilitiesInfo: base_config_1.TYPE,
        MediaConfiguration: base_config_1.TYPE,
        MediaDecodingConfiguration: base_config_1.TYPE,
        MediaEncodingConfiguration: base_config_1.TYPE,
        MessageEventInit: base_config_1.TYPE,
        MultiCacheQueryOptions: base_config_1.TYPE,
        NavigationPreloadState: base_config_1.TYPE,
        NotificationAction: base_config_1.TYPE,
        NotificationEventInit: base_config_1.TYPE,
        NotificationOptions: base_config_1.TYPE,
        Pbkdf2Params: base_config_1.TYPE,
        PerformanceMarkOptions: base_config_1.TYPE,
        PerformanceMeasureOptions: base_config_1.TYPE,
        PerformanceObserverInit: base_config_1.TYPE,
        PermissionDescriptor: base_config_1.TYPE,
        ProgressEventInit: base_config_1.TYPE,
        PromiseRejectionEventInit: base_config_1.TYPE,
        PushEventInit: base_config_1.TYPE,
        PushSubscriptionJSON: base_config_1.TYPE,
        PushSubscriptionOptionsInit: base_config_1.TYPE,
        QueuingStrategy: base_config_1.TYPE,
        QueuingStrategyInit: base_config_1.TYPE,
        RTCEncodedAudioFrameMetadata: base_config_1.TYPE,
        RTCEncodedVideoFrameMetadata: base_config_1.TYPE,
        ReadableStreamGetReaderOptions: base_config_1.TYPE,
        ReadableStreamReadDoneResult: base_config_1.TYPE,
        ReadableStreamReadValueResult: base_config_1.TYPE,
        ReadableWritablePair: base_config_1.TYPE,
        RegistrationOptions: base_config_1.TYPE,
        RequestInit: base_config_1.TYPE,
        ResponseInit: base_config_1.TYPE,
        RsaHashedImportParams: base_config_1.TYPE,
        RsaHashedKeyGenParams: base_config_1.TYPE,
        RsaKeyGenParams: base_config_1.TYPE,
        RsaOaepParams: base_config_1.TYPE,
        RsaOtherPrimesInfo: base_config_1.TYPE,
        RsaPssParams: base_config_1.TYPE,
        SecurityPolicyViolationEventInit: base_config_1.TYPE,
        StorageEstimate: base_config_1.TYPE,
        StreamPipeOptions: base_config_1.TYPE,
        StructuredSerializeOptions: base_config_1.TYPE,
        TextDecodeOptions: base_config_1.TYPE,
        TextDecoderOptions: base_config_1.TYPE,
        TextEncoderEncodeIntoResult: base_config_1.TYPE,
        Transformer: base_config_1.TYPE,
        UnderlyingByteSource: base_config_1.TYPE,
        UnderlyingDefaultSource: base_config_1.TYPE,
        UnderlyingSink: base_config_1.TYPE,
        UnderlyingSource: base_config_1.TYPE,
        VideoColorSpaceInit: base_config_1.TYPE,
        VideoConfiguration: base_config_1.TYPE,
        WebGLContextAttributes: base_config_1.TYPE,
        WebGLContextEventInit: base_config_1.TYPE,
        WorkerOptions: base_config_1.TYPE,
        ANGLE_instanced_arrays: base_config_1.TYPE,
        AbortController: base_config_1.TYPE_VALUE,
        AbortSignalEventMap: base_config_1.TYPE,
        AbortSignal: base_config_1.TYPE_VALUE,
        AbstractWorkerEventMap: base_config_1.TYPE,
        AbstractWorker: base_config_1.TYPE,
        AnimationFrameProvider: base_config_1.TYPE,
        Blob: base_config_1.TYPE_VALUE,
        Body: base_config_1.TYPE,
        BroadcastChannelEventMap: base_config_1.TYPE,
        BroadcastChannel: base_config_1.TYPE_VALUE,
        ByteLengthQueuingStrategy: base_config_1.TYPE_VALUE,
        Cache: base_config_1.TYPE_VALUE,
        CacheStorage: base_config_1.TYPE_VALUE,
        CanvasCompositing: base_config_1.TYPE,
        CanvasDrawImage: base_config_1.TYPE,
        CanvasDrawPath: base_config_1.TYPE,
        CanvasFillStrokeStyles: base_config_1.TYPE,
        CanvasFilters: base_config_1.TYPE,
        CanvasGradient: base_config_1.TYPE_VALUE,
        CanvasImageData: base_config_1.TYPE,
        CanvasImageSmoothing: base_config_1.TYPE,
        CanvasPath: base_config_1.TYPE,
        CanvasPathDrawingStyles: base_config_1.TYPE,
        CanvasPattern: base_config_1.TYPE_VALUE,
        CanvasRect: base_config_1.TYPE,
        CanvasShadowStyles: base_config_1.TYPE,
        CanvasState: base_config_1.TYPE,
        CanvasText: base_config_1.TYPE,
        CanvasTextDrawingStyles: base_config_1.TYPE,
        CanvasTransform: base_config_1.TYPE,
        Client: base_config_1.TYPE_VALUE,
        Clients: base_config_1.TYPE_VALUE,
        CloseEvent: base_config_1.TYPE_VALUE,
        CountQueuingStrategy: base_config_1.TYPE_VALUE,
        Crypto: base_config_1.TYPE_VALUE,
        CryptoKey: base_config_1.TYPE_VALUE,
        CustomEvent: base_config_1.TYPE_VALUE,
        DOMException: base_config_1.TYPE_VALUE,
        DOMMatrix: base_config_1.TYPE_VALUE,
        DOMMatrixReadOnly: base_config_1.TYPE_VALUE,
        DOMPoint: base_config_1.TYPE_VALUE,
        DOMPointReadOnly: base_config_1.TYPE_VALUE,
        DOMQuad: base_config_1.TYPE_VALUE,
        DOMRect: base_config_1.TYPE_VALUE,
        DOMRectReadOnly: base_config_1.TYPE_VALUE,
        DOMStringList: base_config_1.TYPE_VALUE,
        DedicatedWorkerGlobalScopeEventMap: base_config_1.TYPE,
        DedicatedWorkerGlobalScope: base_config_1.TYPE_VALUE,
        EXT_blend_minmax: base_config_1.TYPE,
        EXT_color_buffer_float: base_config_1.TYPE,
        EXT_color_buffer_half_float: base_config_1.TYPE,
        EXT_float_blend: base_config_1.TYPE,
        EXT_frag_depth: base_config_1.TYPE,
        EXT_sRGB: base_config_1.TYPE,
        EXT_shader_texture_lod: base_config_1.TYPE,
        EXT_texture_compression_bptc: base_config_1.TYPE,
        EXT_texture_compression_rgtc: base_config_1.TYPE,
        EXT_texture_filter_anisotropic: base_config_1.TYPE,
        EXT_texture_norm16: base_config_1.TYPE,
        ErrorEvent: base_config_1.TYPE_VALUE,
        Event: base_config_1.TYPE_VALUE,
        EventListener: base_config_1.TYPE,
        EventListenerObject: base_config_1.TYPE,
        EventSourceEventMap: base_config_1.TYPE,
        EventSource: base_config_1.TYPE_VALUE,
        EventTarget: base_config_1.TYPE_VALUE,
        ExtendableEvent: base_config_1.TYPE_VALUE,
        ExtendableMessageEvent: base_config_1.TYPE_VALUE,
        FetchEvent: base_config_1.TYPE_VALUE,
        File: base_config_1.TYPE_VALUE,
        FileList: base_config_1.TYPE_VALUE,
        FileReaderEventMap: base_config_1.TYPE,
        FileReader: base_config_1.TYPE_VALUE,
        FileReaderSync: base_config_1.TYPE_VALUE,
        FileSystemDirectoryHandle: base_config_1.TYPE_VALUE,
        FileSystemFileHandle: base_config_1.TYPE_VALUE,
        FileSystemHandle: base_config_1.TYPE_VALUE,
        FileSystemSyncAccessHandle: base_config_1.TYPE_VALUE,
        FontFace: base_config_1.TYPE_VALUE,
        FontFaceSetEventMap: base_config_1.TYPE,
        FontFaceSet: base_config_1.TYPE_VALUE,
        FontFaceSetLoadEvent: base_config_1.TYPE_VALUE,
        FontFaceSource: base_config_1.TYPE,
        FormData: base_config_1.TYPE_VALUE,
        GenericTransformStream: base_config_1.TYPE,
        Headers: base_config_1.TYPE_VALUE,
        IDBCursor: base_config_1.TYPE_VALUE,
        IDBCursorWithValue: base_config_1.TYPE_VALUE,
        IDBDatabaseEventMap: base_config_1.TYPE,
        IDBDatabase: base_config_1.TYPE_VALUE,
        IDBFactory: base_config_1.TYPE_VALUE,
        IDBIndex: base_config_1.TYPE_VALUE,
        IDBKeyRange: base_config_1.TYPE_VALUE,
        IDBObjectStore: base_config_1.TYPE_VALUE,
        IDBOpenDBRequestEventMap: base_config_1.TYPE,
        IDBOpenDBRequest: base_config_1.TYPE_VALUE,
        IDBRequestEventMap: base_config_1.TYPE,
        IDBRequest: base_config_1.TYPE_VALUE,
        IDBTransactionEventMap: base_config_1.TYPE,
        IDBTransaction: base_config_1.TYPE_VALUE,
        IDBVersionChangeEvent: base_config_1.TYPE_VALUE,
        ImageBitmap: base_config_1.TYPE_VALUE,
        ImageBitmapRenderingContext: base_config_1.TYPE_VALUE,
        ImageData: base_config_1.TYPE_VALUE,
        KHR_parallel_shader_compile: base_config_1.TYPE,
        Lock: base_config_1.TYPE_VALUE,
        LockManager: base_config_1.TYPE_VALUE,
        MediaCapabilities: base_config_1.TYPE_VALUE,
        MessageChannel: base_config_1.TYPE_VALUE,
        MessageEvent: base_config_1.TYPE_VALUE,
        MessagePortEventMap: base_config_1.TYPE,
        MessagePort: base_config_1.TYPE_VALUE,
        NavigationPreloadManager: base_config_1.TYPE_VALUE,
        NavigatorConcurrentHardware: base_config_1.TYPE,
        NavigatorID: base_config_1.TYPE,
        NavigatorLanguage: base_config_1.TYPE,
        NavigatorLocks: base_config_1.TYPE,
        NavigatorOnLine: base_config_1.TYPE,
        NavigatorStorage: base_config_1.TYPE,
        NotificationEventMap: base_config_1.TYPE,
        Notification: base_config_1.TYPE_VALUE,
        NotificationEvent: base_config_1.TYPE_VALUE,
        OES_draw_buffers_indexed: base_config_1.TYPE,
        OES_element_index_uint: base_config_1.TYPE,
        OES_fbo_render_mipmap: base_config_1.TYPE,
        OES_standard_derivatives: base_config_1.TYPE,
        OES_texture_float: base_config_1.TYPE,
        OES_texture_float_linear: base_config_1.TYPE,
        OES_texture_half_float: base_config_1.TYPE,
        OES_texture_half_float_linear: base_config_1.TYPE,
        OES_vertex_array_object: base_config_1.TYPE,
        OVR_multiview2: base_config_1.TYPE,
        OffscreenCanvasEventMap: base_config_1.TYPE,
        OffscreenCanvas: base_config_1.TYPE_VALUE,
        OffscreenCanvasRenderingContext2D: base_config_1.TYPE_VALUE,
        Path2D: base_config_1.TYPE_VALUE,
        PerformanceEventMap: base_config_1.TYPE,
        Performance: base_config_1.TYPE_VALUE,
        PerformanceEntry: base_config_1.TYPE_VALUE,
        PerformanceMark: base_config_1.TYPE_VALUE,
        PerformanceMeasure: base_config_1.TYPE_VALUE,
        PerformanceObserver: base_config_1.TYPE_VALUE,
        PerformanceObserverEntryList: base_config_1.TYPE_VALUE,
        PerformanceResourceTiming: base_config_1.TYPE_VALUE,
        PerformanceServerTiming: base_config_1.TYPE_VALUE,
        PermissionStatusEventMap: base_config_1.TYPE,
        PermissionStatus: base_config_1.TYPE_VALUE,
        Permissions: base_config_1.TYPE_VALUE,
        ProgressEvent: base_config_1.TYPE_VALUE,
        PromiseRejectionEvent: base_config_1.TYPE_VALUE,
        PushEvent: base_config_1.TYPE_VALUE,
        PushManager: base_config_1.TYPE_VALUE,
        PushMessageData: base_config_1.TYPE_VALUE,
        PushSubscription: base_config_1.TYPE_VALUE,
        PushSubscriptionOptions: base_config_1.TYPE_VALUE,
        RTCEncodedAudioFrame: base_config_1.TYPE_VALUE,
        RTCEncodedVideoFrame: base_config_1.TYPE_VALUE,
        ReadableByteStreamController: base_config_1.TYPE_VALUE,
        ReadableStream: base_config_1.TYPE_VALUE,
        ReadableStreamBYOBReader: base_config_1.TYPE_VALUE,
        ReadableStreamBYOBRequest: base_config_1.TYPE_VALUE,
        ReadableStreamDefaultController: base_config_1.TYPE_VALUE,
        ReadableStreamDefaultReader: base_config_1.TYPE_VALUE,
        ReadableStreamGenericReader: base_config_1.TYPE,
        Request: base_config_1.TYPE_VALUE,
        Response: base_config_1.TYPE_VALUE,
        SecurityPolicyViolationEvent: base_config_1.TYPE_VALUE,
        ServiceWorkerEventMap: base_config_1.TYPE,
        ServiceWorker: base_config_1.TYPE_VALUE,
        ServiceWorkerContainerEventMap: base_config_1.TYPE,
        ServiceWorkerContainer: base_config_1.TYPE_VALUE,
        ServiceWorkerGlobalScopeEventMap: base_config_1.TYPE,
        ServiceWorkerGlobalScope: base_config_1.TYPE_VALUE,
        ServiceWorkerRegistrationEventMap: base_config_1.TYPE,
        ServiceWorkerRegistration: base_config_1.TYPE_VALUE,
        SharedWorkerGlobalScopeEventMap: base_config_1.TYPE,
        SharedWorkerGlobalScope: base_config_1.TYPE_VALUE,
        StorageManager: base_config_1.TYPE_VALUE,
        SubtleCrypto: base_config_1.TYPE_VALUE,
        TextDecoder: base_config_1.TYPE_VALUE,
        TextDecoderCommon: base_config_1.TYPE,
        TextDecoderStream: base_config_1.TYPE_VALUE,
        TextEncoder: base_config_1.TYPE_VALUE,
        TextEncoderCommon: base_config_1.TYPE,
        TextEncoderStream: base_config_1.TYPE_VALUE,
        TextMetrics: base_config_1.TYPE_VALUE,
        TransformStream: base_config_1.TYPE_VALUE,
        TransformStreamDefaultController: base_config_1.TYPE_VALUE,
        URL: base_config_1.TYPE_VALUE,
        URLSearchParams: base_config_1.TYPE_VALUE,
        VideoColorSpace: base_config_1.TYPE_VALUE,
        WEBGL_color_buffer_float: base_config_1.TYPE,
        WEBGL_compressed_texture_astc: base_config_1.TYPE,
        WEBGL_compressed_texture_etc: base_config_1.TYPE,
        WEBGL_compressed_texture_etc1: base_config_1.TYPE,
        WEBGL_compressed_texture_s3tc: base_config_1.TYPE,
        WEBGL_compressed_texture_s3tc_srgb: base_config_1.TYPE,
        WEBGL_debug_renderer_info: base_config_1.TYPE,
        WEBGL_debug_shaders: base_config_1.TYPE,
        WEBGL_depth_texture: base_config_1.TYPE,
        WEBGL_draw_buffers: base_config_1.TYPE,
        WEBGL_lose_context: base_config_1.TYPE,
        WEBGL_multi_draw: base_config_1.TYPE,
        WebGL2RenderingContext: base_config_1.TYPE_VALUE,
        WebGL2RenderingContextBase: base_config_1.TYPE,
        WebGL2RenderingContextOverloads: base_config_1.TYPE,
        WebGLActiveInfo: base_config_1.TYPE_VALUE,
        WebGLBuffer: base_config_1.TYPE_VALUE,
        WebGLContextEvent: base_config_1.TYPE_VALUE,
        WebGLFramebuffer: base_config_1.TYPE_VALUE,
        WebGLProgram: base_config_1.TYPE_VALUE,
        WebGLQuery: base_config_1.TYPE_VALUE,
        WebGLRenderbuffer: base_config_1.TYPE_VALUE,
        WebGLRenderingContext: base_config_1.TYPE_VALUE,
        WebGLRenderingContextBase: base_config_1.TYPE,
        WebGLRenderingContextOverloads: base_config_1.TYPE,
        WebGLSampler: base_config_1.TYPE_VALUE,
        WebGLShader: base_config_1.TYPE_VALUE,
        WebGLShaderPrecisionFormat: base_config_1.TYPE_VALUE,
        WebGLSync: base_config_1.TYPE_VALUE,
        WebGLTexture: base_config_1.TYPE_VALUE,
        WebGLTransformFeedback: base_config_1.TYPE_VALUE,
        WebGLUniformLocation: base_config_1.TYPE_VALUE,
        WebGLVertexArrayObject: base_config_1.TYPE_VALUE,
        WebGLVertexArrayObjectOES: base_config_1.TYPE,
        WebSocketEventMap: base_config_1.TYPE,
        WebSocket: base_config_1.TYPE_VALUE,
        WindowClient: base_config_1.TYPE_VALUE,
        WindowOrWorkerGlobalScope: base_config_1.TYPE,
        WorkerEventMap: base_config_1.TYPE,
        Worker: base_config_1.TYPE_VALUE,
        WorkerGlobalScopeEventMap: base_config_1.TYPE,
        WorkerGlobalScope: base_config_1.TYPE_VALUE,
        WorkerLocation: base_config_1.TYPE_VALUE,
        WorkerNavigator: base_config_1.TYPE_VALUE,
        WritableStream: base_config_1.TYPE_VALUE,
        WritableStreamDefaultController: base_config_1.TYPE_VALUE,
        WritableStreamDefaultWriter: base_config_1.TYPE_VALUE,
        XMLHttpRequestEventMap: base_config_1.TYPE,
        XMLHttpRequest: base_config_1.TYPE_VALUE,
        XMLHttpRequestEventTargetEventMap: base_config_1.TYPE,
        XMLHttpRequestEventTarget: base_config_1.TYPE_VALUE,
        XMLHttpRequestUpload: base_config_1.TYPE_VALUE,
        Console: base_config_1.TYPE,
        WebAssembly: base_config_1.TYPE_VALUE,
        FrameRequestCallback: base_config_1.TYPE,
        LockGrantedCallback: base_config_1.TYPE,
        OnErrorEventHandlerNonNull: base_config_1.TYPE,
        PerformanceObserverCallback: base_config_1.TYPE,
        QueuingStrategySize: base_config_1.TYPE,
        TransformerFlushCallback: base_config_1.TYPE,
        TransformerStartCallback: base_config_1.TYPE,
        TransformerTransformCallback: base_config_1.TYPE,
        UnderlyingSinkAbortCallback: base_config_1.TYPE,
        UnderlyingSinkCloseCallback: base_config_1.TYPE,
        UnderlyingSinkStartCallback: base_config_1.TYPE,
        UnderlyingSinkWriteCallback: base_config_1.TYPE,
        UnderlyingSourceCancelCallback: base_config_1.TYPE,
        UnderlyingSourcePullCallback: base_config_1.TYPE,
        UnderlyingSourceStartCallback: base_config_1.TYPE,
        VoidFunction: base_config_1.TYPE,
        AlgorithmIdentifier: base_config_1.TYPE,
        BigInteger: base_config_1.TYPE,
        BinaryData: base_config_1.TYPE,
        BlobPart: base_config_1.TYPE,
        BodyInit: base_config_1.TYPE,
        BufferSource: base_config_1.TYPE,
        CanvasImageSource: base_config_1.TYPE,
        DOMHighResTimeStamp: base_config_1.TYPE,
        EpochTimeStamp: base_config_1.TYPE,
        EventListenerOrEventListenerObject: base_config_1.TYPE,
        Float32List: base_config_1.TYPE,
        FormDataEntryValue: base_config_1.TYPE,
        GLbitfield: base_config_1.TYPE,
        GLboolean: base_config_1.TYPE,
        GLclampf: base_config_1.TYPE,
        GLenum: base_config_1.TYPE,
        GLfloat: base_config_1.TYPE,
        GLint: base_config_1.TYPE,
        GLint64: base_config_1.TYPE,
        GLintptr: base_config_1.TYPE,
        GLsizei: base_config_1.TYPE,
        GLsizeiptr: base_config_1.TYPE,
        GLuint: base_config_1.TYPE,
        GLuint64: base_config_1.TYPE,
        HashAlgorithmIdentifier: base_config_1.TYPE,
        HeadersInit: base_config_1.TYPE,
        IDBValidKey: base_config_1.TYPE,
        ImageBitmapSource: base_config_1.TYPE,
        Int32List: base_config_1.TYPE,
        MessageEventSource: base_config_1.TYPE,
        NamedCurve: base_config_1.TYPE,
        OffscreenRenderingContext: base_config_1.TYPE,
        OnErrorEventHandler: base_config_1.TYPE,
        PerformanceEntryList: base_config_1.TYPE,
        PushMessageDataInit: base_config_1.TYPE,
        ReadableStreamController: base_config_1.TYPE,
        ReadableStreamReadResult: base_config_1.TYPE,
        ReadableStreamReader: base_config_1.TYPE,
        RequestInfo: base_config_1.TYPE,
        TexImageSource: base_config_1.TYPE,
        TimerHandler: base_config_1.TYPE,
        Transferable: base_config_1.TYPE,
        Uint32List: base_config_1.TYPE,
        VibratePattern: base_config_1.TYPE,
        XMLHttpRequestBodyInit: base_config_1.TYPE,
        BinaryType: base_config_1.TYPE,
        CanvasDirection: base_config_1.TYPE,
        CanvasFillRule: base_config_1.TYPE,
        CanvasFontKerning: base_config_1.TYPE,
        CanvasFontStretch: base_config_1.TYPE,
        CanvasFontVariantCaps: base_config_1.TYPE,
        CanvasLineCap: base_config_1.TYPE,
        CanvasLineJoin: base_config_1.TYPE,
        CanvasTextAlign: base_config_1.TYPE,
        CanvasTextBaseline: base_config_1.TYPE,
        CanvasTextRendering: base_config_1.TYPE,
        ClientTypes: base_config_1.TYPE,
        ColorGamut: base_config_1.TYPE,
        ColorSpaceConversion: base_config_1.TYPE,
        DocumentVisibilityState: base_config_1.TYPE,
        EndingType: base_config_1.TYPE,
        FileSystemHandleKind: base_config_1.TYPE,
        FontDisplay: base_config_1.TYPE,
        FontFaceLoadStatus: base_config_1.TYPE,
        FontFaceSetLoadStatus: base_config_1.TYPE,
        FrameType: base_config_1.TYPE,
        GlobalCompositeOperation: base_config_1.TYPE,
        HdrMetadataType: base_config_1.TYPE,
        IDBCursorDirection: base_config_1.TYPE,
        IDBRequestReadyState: base_config_1.TYPE,
        IDBTransactionDurability: base_config_1.TYPE,
        IDBTransactionMode: base_config_1.TYPE,
        ImageOrientation: base_config_1.TYPE,
        ImageSmoothingQuality: base_config_1.TYPE,
        KeyFormat: base_config_1.TYPE,
        KeyType: base_config_1.TYPE,
        KeyUsage: base_config_1.TYPE,
        LockMode: base_config_1.TYPE,
        MediaDecodingType: base_config_1.TYPE,
        MediaEncodingType: base_config_1.TYPE,
        NotificationDirection: base_config_1.TYPE,
        NotificationPermission: base_config_1.TYPE,
        OffscreenRenderingContextId: base_config_1.TYPE,
        PermissionName: base_config_1.TYPE,
        PermissionState: base_config_1.TYPE,
        PredefinedColorSpace: base_config_1.TYPE,
        PremultiplyAlpha: base_config_1.TYPE,
        PushEncryptionKeyName: base_config_1.TYPE,
        RTCEncodedVideoFrameType: base_config_1.TYPE,
        ReadableStreamReaderMode: base_config_1.TYPE,
        ReadableStreamType: base_config_1.TYPE,
        ReferrerPolicy: base_config_1.TYPE,
        RequestCache: base_config_1.TYPE,
        RequestCredentials: base_config_1.TYPE,
        RequestDestination: base_config_1.TYPE,
        RequestMode: base_config_1.TYPE,
        RequestRedirect: base_config_1.TYPE,
        ResizeQuality: base_config_1.TYPE,
        ResponseType: base_config_1.TYPE,
        SecurityPolicyViolationEventDisposition: base_config_1.TYPE,
        ServiceWorkerState: base_config_1.TYPE,
        ServiceWorkerUpdateViaCache: base_config_1.TYPE,
        TransferFunction: base_config_1.TYPE,
        VideoColorPrimaries: base_config_1.TYPE,
        VideoMatrixCoefficients: base_config_1.TYPE,
        VideoTransferCharacteristics: base_config_1.TYPE,
        WebGLPowerPreference: base_config_1.TYPE,
        WorkerType: base_config_1.TYPE,
        XMLHttpRequestResponseType: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/lib/webworker.iterable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // THIS CODE WAS AUTOMATICALLY GENERATED
    // DO NOT EDIT THIS CODE BY HAND
    // RUN THE FOLLOWING COMMAND FROM THE WORKSPACE ROOT TO REGENERATE:
    // npx nx generate-lib @typescript-eslint/scope-manager
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.webworker_iterable = void 0;
    const base_config_1 = require(868) /* ./base-config */;
    exports.webworker_iterable = {
        Cache: base_config_1.TYPE,
        CanvasPath: base_config_1.TYPE,
        CanvasPathDrawingStyles: base_config_1.TYPE,
        DOMStringList: base_config_1.TYPE,
        FileList: base_config_1.TYPE,
        FontFaceSet: base_config_1.TYPE,
        FormData: base_config_1.TYPE,
        Headers: base_config_1.TYPE,
        IDBDatabase: base_config_1.TYPE,
        IDBObjectStore: base_config_1.TYPE,
        MessageEvent: base_config_1.TYPE,
        SubtleCrypto: base_config_1.TYPE,
        URLSearchParams: base_config_1.TYPE,
        WEBGL_draw_buffers: base_config_1.TYPE,
        WEBGL_multi_draw: base_config_1.TYPE,
        WebGL2RenderingContextBase: base_config_1.TYPE,
        WebGL2RenderingContextOverloads: base_config_1.TYPE,
        WebGLRenderingContextBase: base_config_1.TYPE,
        WebGLRenderingContextOverloads: base_config_1.TYPE,
    };
    
},
/* @typescript-eslint/scope-manager/dist/referencer/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Referencer = void 0;
    var Referencer_1 = require(953) /* ./Referencer */;
    Object.defineProperty(exports, "Referencer", { enumerable: true, get: function () { return Referencer_1.Referencer; } });
    
},
/* @typescript-eslint/scope-manager/dist/referencer/Referencer.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _Referencer_jsxPragma, _Referencer_jsxFragmentName, _Referencer_hasReferencedJsxFactory, _Referencer_hasReferencedJsxFragmentFactory, _Referencer_lib, _Referencer_emitDecoratorMetadata;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Referencer = void 0;
    const types_1 = require(789) /* @typescript-eslint/types */;
    const assert_1 = require(954) /* ../assert */;
    const definition_1 = require(955) /* ../definition */;
    const lib_1 = require(866) /* ../lib */;
    const ClassVisitor_1 = require(971) /* ./ClassVisitor */;
    const ExportVisitor_1 = require(1003) /* ./ExportVisitor */;
    const ImportVisitor_1 = require(1004) /* ./ImportVisitor */;
    const PatternVisitor_1 = require(1001) /* ./PatternVisitor */;
    const Reference_1 = require(976) /* ./Reference */;
    const TypeVisitor_1 = require(972) /* ./TypeVisitor */;
    const Visitor_1 = require(1000) /* ./Visitor */;
    // Referencing variables and creating bindings.
    class Referencer extends Visitor_1.Visitor {
        constructor(options, scopeManager) {
            super(options);
            _Referencer_jsxPragma.set(this, void 0);
            _Referencer_jsxFragmentName.set(this, void 0);
            _Referencer_hasReferencedJsxFactory.set(this, false);
            _Referencer_hasReferencedJsxFragmentFactory.set(this, false);
            _Referencer_lib.set(this, void 0);
            _Referencer_emitDecoratorMetadata.set(this, void 0);
            this.scopeManager = scopeManager;
            __classPrivateFieldSet(this, _Referencer_jsxPragma, options.jsxPragma, "f");
            __classPrivateFieldSet(this, _Referencer_jsxFragmentName, options.jsxFragmentName, "f");
            __classPrivateFieldSet(this, _Referencer_lib, options.lib, "f");
            __classPrivateFieldSet(this, _Referencer_emitDecoratorMetadata, options.emitDecoratorMetadata, "f");
        }
        currentScope(dontThrowOnNull) {
            if (!dontThrowOnNull) {
                (0, assert_1.assert)(this.scopeManager.currentScope, 'aaa');
            }
            return this.scopeManager.currentScope;
        }
        close(node) {
            while (this.currentScope(true) && node === this.currentScope().block) {
                this.scopeManager.currentScope = this.currentScope().close(this.scopeManager);
            }
        }
        referencingDefaultValue(pattern, assignments, maybeImplicitGlobal, init) {
            assignments.forEach(assignment => {
                this.currentScope().referenceValue(pattern, Reference_1.ReferenceFlag.Write, assignment.right, maybeImplicitGlobal, init);
            });
        }
        populateGlobalsFromLib(globalScope) {
            for (const lib of __classPrivateFieldGet(this, _Referencer_lib, "f")) {
                const variables = lib_1.lib[lib];
                /* istanbul ignore if */ if (!variables) {
                    throw new Error(`Invalid value for lib provided: ${lib}`);
                }
                for (const [name, variable] of Object.entries(variables)) {
                    globalScope.defineImplicitVariable(name, variable);
                }
            }
            // for const assertions (`{} as const` / `<const>{}`)
            globalScope.defineImplicitVariable('const', {
                eslintImplicitGlobalSetting: 'readonly',
                isTypeVariable: true,
                isValueVariable: false,
            });
        }
        /**
         * Searches for a variable named "name" in the upper scopes and adds a pseudo-reference from itself to itself
         */
        referenceInSomeUpperScope(name) {
            let scope = this.scopeManager.currentScope;
            while (scope) {
                const variable = scope.set.get(name);
                if (!variable) {
                    scope = scope.upper;
                    continue;
                }
                scope.referenceValue(variable.identifiers[0]);
                return true;
            }
            return false;
        }
        referenceJsxPragma() {
            if (__classPrivateFieldGet(this, _Referencer_jsxPragma, "f") == null || __classPrivateFieldGet(this, _Referencer_hasReferencedJsxFactory, "f")) {
                return;
            }
            __classPrivateFieldSet(this, _Referencer_hasReferencedJsxFactory, this.referenceInSomeUpperScope(__classPrivateFieldGet(this, _Referencer_jsxPragma, "f")), "f");
        }
        referenceJsxFragment() {
            if (__classPrivateFieldGet(this, _Referencer_jsxFragmentName, "f") == null ||
                __classPrivateFieldGet(this, _Referencer_hasReferencedJsxFragmentFactory, "f")) {
                return;
            }
            __classPrivateFieldSet(this, _Referencer_hasReferencedJsxFragmentFactory, this.referenceInSomeUpperScope(__classPrivateFieldGet(this, _Referencer_jsxFragmentName, "f")), "f");
        }
        ///////////////////
        // Visit helpers //
        ///////////////////
        visitClass(node) {
            ClassVisitor_1.ClassVisitor.visit(this, node, __classPrivateFieldGet(this, _Referencer_emitDecoratorMetadata, "f"));
        }
        visitForIn(node) {
            if (node.left.type === types_1.AST_NODE_TYPES.VariableDeclaration &&
                node.left.kind !== 'var') {
                this.scopeManager.nestForScope(node);
            }
            if (node.left.type === types_1.AST_NODE_TYPES.VariableDeclaration) {
                this.visit(node.left);
                this.visitPattern(node.left.declarations[0].id, pattern => {
                    this.currentScope().referenceValue(pattern, Reference_1.ReferenceFlag.Write, node.right, null, true);
                });
            }
            else {
                this.visitPattern(node.left, (pattern, info) => {
                    const maybeImplicitGlobal = !this.currentScope().isStrict
                        ? {
                            pattern,
                            node,
                        }
                        : null;
                    this.referencingDefaultValue(pattern, info.assignments, maybeImplicitGlobal, false);
                    this.currentScope().referenceValue(pattern, Reference_1.ReferenceFlag.Write, node.right, maybeImplicitGlobal, false);
                }, { processRightHandNodes: true });
            }
            this.visit(node.right);
            this.visit(node.body);
            this.close(node);
        }
        visitFunctionParameterTypeAnnotation(node) {
            if ('typeAnnotation' in node) {
                this.visitType(node.typeAnnotation);
            }
            else if (node.type === types_1.AST_NODE_TYPES.AssignmentPattern) {
                this.visitType(node.left.typeAnnotation);
            }
            else if (node.type === types_1.AST_NODE_TYPES.TSParameterProperty) {
                this.visitFunctionParameterTypeAnnotation(node.parameter);
            }
        }
        visitFunction(node) {
            // FunctionDeclaration name is defined in upper scope
            // NOTE: Not referring variableScope. It is intended.
            // Since
            //  in ES5, FunctionDeclaration should be in FunctionBody.
            //  in ES6, FunctionDeclaration should be block scoped.
            var _a;
            if (node.type === types_1.AST_NODE_TYPES.FunctionExpression) {
                if (node.id) {
                    // FunctionExpression with name creates its special scope;
                    // FunctionExpressionNameScope.
                    this.scopeManager.nestFunctionExpressionNameScope(node);
                }
            }
            else if (node.id) {
                // id is defined in upper scope
                this.currentScope().defineIdentifier(node.id, new definition_1.FunctionNameDefinition(node.id, node));
            }
            // Consider this function is in the MethodDefinition.
            this.scopeManager.nestFunctionScope(node, false);
            // Process parameter declarations.
            for (const param of node.params) {
                this.visitPattern(param, (pattern, info) => {
                    this.currentScope().defineIdentifier(pattern, new definition_1.ParameterDefinition(pattern, node, info.rest));
                    this.referencingDefaultValue(pattern, info.assignments, null, true);
                }, { processRightHandNodes: true });
                this.visitFunctionParameterTypeAnnotation(param);
                (_a = param.decorators) === null || _a === void 0 ? void 0 : _a.forEach(d => this.visit(d));
            }
            this.visitType(node.returnType);
            this.visitType(node.typeParameters);
            // In TypeScript there are a number of function-like constructs which have no body,
            // so check it exists before traversing
            if (node.body) {
                // Skip BlockStatement to prevent creating BlockStatement scope.
                if (node.body.type === types_1.AST_NODE_TYPES.BlockStatement) {
                    this.visitChildren(node.body);
                }
                else {
                    this.visit(node.body);
                }
            }
            this.close(node);
        }
        visitProperty(node) {
            if (node.computed) {
                this.visit(node.key);
            }
            this.visit(node.value);
        }
        visitType(node) {
            if (!node) {
                return;
            }
            TypeVisitor_1.TypeVisitor.visit(this, node);
        }
        visitTypeAssertion(node) {
            this.visit(node.expression);
            this.visitType(node.typeAnnotation);
        }
        /////////////////////
        // Visit selectors //
        /////////////////////
        ArrowFunctionExpression(node) {
            this.visitFunction(node);
        }
        AssignmentExpression(node) {
            let left = node.left;
            switch (left.type) {
                case types_1.AST_NODE_TYPES.TSAsExpression:
                case types_1.AST_NODE_TYPES.TSTypeAssertion:
                    // explicitly visit the type annotation
                    this.visitType(left.typeAnnotation);
                // intentional fallthrough
                case types_1.AST_NODE_TYPES.TSNonNullExpression:
                    // unwrap the expression
                    left = left.expression;
            }
            if (PatternVisitor_1.PatternVisitor.isPattern(left)) {
                if (node.operator === '=') {
                    this.visitPattern(left, (pattern, info) => {
                        const maybeImplicitGlobal = !this.currentScope().isStrict
                            ? {
                                pattern,
                                node,
                            }
                            : null;
                        this.referencingDefaultValue(pattern, info.assignments, maybeImplicitGlobal, false);
                        this.currentScope().referenceValue(pattern, Reference_1.ReferenceFlag.Write, node.right, maybeImplicitGlobal, false);
                    }, { processRightHandNodes: true });
                }
                else if (left.type === types_1.AST_NODE_TYPES.Identifier) {
                    this.currentScope().referenceValue(left, Reference_1.ReferenceFlag.ReadWrite, node.right);
                }
            }
            else {
                this.visit(left);
            }
            this.visit(node.right);
        }
        BlockStatement(node) {
            if (this.scopeManager.isES6()) {
                this.scopeManager.nestBlockScope(node);
            }
            this.visitChildren(node);
            this.close(node);
        }
        BreakStatement() {
            // don't reference the break statement's label
        }
        CallExpression(node) {
            this.visitChildren(node, ['typeParameters']);
            this.visitType(node.typeParameters);
        }
        CatchClause(node) {
            this.scopeManager.nestCatchScope(node);
            if (node.param) {
                const param = node.param;
                this.visitPattern(param, (pattern, info) => {
                    this.currentScope().defineIdentifier(pattern, new definition_1.CatchClauseDefinition(param, node));
                    this.referencingDefaultValue(pattern, info.assignments, null, true);
                }, { processRightHandNodes: true });
            }
            this.visit(node.body);
            this.close(node);
        }
        ClassExpression(node) {
            this.visitClass(node);
        }
        ClassDeclaration(node) {
            this.visitClass(node);
        }
        ContinueStatement() {
            // don't reference the continue statement's label
        }
        ExportAllDeclaration() {
            // this defines no local variables
        }
        ExportDefaultDeclaration(node) {
            if (node.declaration.type === types_1.AST_NODE_TYPES.Identifier) {
                ExportVisitor_1.ExportVisitor.visit(this, node);
            }
            else {
                this.visit(node.declaration);
            }
        }
        ExportNamedDeclaration(node) {
            if (node.declaration) {
                this.visit(node.declaration);
            }
            else {
                ExportVisitor_1.ExportVisitor.visit(this, node);
            }
        }
        ForInStatement(node) {
            this.visitForIn(node);
        }
        ForOfStatement(node) {
            this.visitForIn(node);
        }
        ForStatement(node) {
            // Create ForStatement declaration.
            // NOTE: In ES6, ForStatement dynamically generates per iteration environment. However, this is
            // a static analyzer, we only generate one scope for ForStatement.
            if (node.init &&
                node.init.type === types_1.AST_NODE_TYPES.VariableDeclaration &&
                node.init.kind !== 'var') {
                this.scopeManager.nestForScope(node);
            }
            this.visitChildren(node);
            this.close(node);
        }
        FunctionDeclaration(node) {
            this.visitFunction(node);
        }
        FunctionExpression(node) {
            this.visitFunction(node);
        }
        Identifier(node) {
            this.currentScope().referenceValue(node);
            this.visitType(node.typeAnnotation);
        }
        ImportDeclaration(node) {
            (0, assert_1.assert)(this.scopeManager.isES6() && this.scopeManager.isModule(), 'ImportDeclaration should appear when the mode is ES6 and in the module context.');
            ImportVisitor_1.ImportVisitor.visit(this, node);
        }
        JSXAttribute(node) {
            this.visit(node.value);
        }
        JSXClosingElement() {
            // should not be counted as a reference
        }
        JSXFragment(node) {
            this.referenceJsxPragma();
            this.referenceJsxFragment();
            this.visitChildren(node);
        }
        JSXIdentifier(node) {
            this.currentScope().referenceValue(node);
        }
        JSXMemberExpression(node) {
            if (node.object.type !== types_1.AST_NODE_TYPES.JSXIdentifier) {
                this.visit(node.object);
            }
            else {
                if (node.object.name !== 'this') {
                    this.visit(node.object);
                }
            }
            // we don't ever reference the property as it's always going to be a property on the thing
        }
        JSXOpeningElement(node) {
            this.referenceJsxPragma();
            if (node.name.type === types_1.AST_NODE_TYPES.JSXIdentifier) {
                if (node.name.name[0].toUpperCase() === node.name.name[0] ||
                    node.name.name === 'this') {
                    // lower cased component names are always treated as "intrinsic" names, and are converted to a string,
                    // not a variable by JSX transforms:
                    // <div /> => React.createElement("div", null)
                    // the only case we want to visit a lower-cased component has its name as "this",
                    this.visit(node.name);
                }
            }
            else {
                this.visit(node.name);
            }
            this.visitType(node.typeParameters);
            for (const attr of node.attributes) {
                this.visit(attr);
            }
        }
        LabeledStatement(node) {
            this.visit(node.body);
        }
        MemberExpression(node) {
            this.visit(node.object);
            if (node.computed) {
                this.visit(node.property);
            }
        }
        MetaProperty() {
            // meta properties all builtin globals
        }
        NewExpression(node) {
            this.visitChildren(node, ['typeParameters']);
            this.visitType(node.typeParameters);
        }
        PrivateIdentifier() {
            // private identifiers are members on classes and thus have no variables to to reference
        }
        Program(node) {
            const globalScope = this.scopeManager.nestGlobalScope(node);
            this.populateGlobalsFromLib(globalScope);
            if (this.scopeManager.isGlobalReturn()) {
                // Force strictness of GlobalScope to false when using node.js scope.
                this.currentScope().isStrict = false;
                this.scopeManager.nestFunctionScope(node, false);
            }
            if (this.scopeManager.isES6() && this.scopeManager.isModule()) {
                this.scopeManager.nestModuleScope(node);
            }
            if (this.scopeManager.isStrictModeSupported() &&
                this.scopeManager.isImpliedStrict()) {
                this.currentScope().isStrict = true;
            }
            this.visitChildren(node);
            this.close(node);
        }
        Property(node) {
            this.visitProperty(node);
        }
        SwitchStatement(node) {
            this.visit(node.discriminant);
            if (this.scopeManager.isES6()) {
                this.scopeManager.nestSwitchScope(node);
            }
            for (const switchCase of node.cases) {
                this.visit(switchCase);
            }
            this.close(node);
        }
        TaggedTemplateExpression(node) {
            this.visit(node.tag);
            this.visit(node.quasi);
            this.visitType(node.typeParameters);
        }
        TSAsExpression(node) {
            this.visitTypeAssertion(node);
        }
        TSDeclareFunction(node) {
            this.visitFunction(node);
        }
        TSImportEqualsDeclaration(node) {
            this.currentScope().defineIdentifier(node.id, new definition_1.ImportBindingDefinition(node.id, node, node));
            if (node.moduleReference.type === types_1.AST_NODE_TYPES.TSQualifiedName) {
                this.visit(node.moduleReference.left);
            }
            else {
                this.visit(node.moduleReference);
            }
        }
        TSEmptyBodyFunctionExpression(node) {
            this.visitFunction(node);
        }
        TSEnumDeclaration(node) {
            this.currentScope().defineIdentifier(node.id, new definition_1.TSEnumNameDefinition(node.id, node));
            // enum members can be referenced within the enum body
            this.scopeManager.nestTSEnumScope(node);
            // define the enum name again inside the new enum scope
            // references to the enum should not resolve directly to the enum
            this.currentScope().defineIdentifier(node.id, new definition_1.TSEnumNameDefinition(node.id, node));
            for (const member of node.members) {
                // TS resolves literal named members to be actual names
                // enum Foo {
                //   'a' = 1,
                //   b = a, // this references the 'a' member
                // }
                if (member.id.type === types_1.AST_NODE_TYPES.Literal &&
                    typeof member.id.value === 'string') {
                    const name = member.id;
                    this.currentScope().defineLiteralIdentifier(name, new definition_1.TSEnumMemberDefinition(name, member));
                }
                else if (!member.computed &&
                    member.id.type === types_1.AST_NODE_TYPES.Identifier) {
                    this.currentScope().defineIdentifier(member.id, new definition_1.TSEnumMemberDefinition(member.id, member));
                }
                this.visit(member.initializer);
            }
            this.close(node);
        }
        TSInstantiationExpression(node) {
            this.visitChildren(node, ['typeParameters']);
            this.visitType(node.typeParameters);
        }
        TSInterfaceDeclaration(node) {
            this.visitType(node);
        }
        TSModuleDeclaration(node) {
            if (node.id.type === types_1.AST_NODE_TYPES.Identifier && !node.global) {
                this.currentScope().defineIdentifier(node.id, new definition_1.TSModuleNameDefinition(node.id, node));
            }
            this.scopeManager.nestTSModuleScope(node);
            this.visit(node.body);
            this.close(node);
        }
        TSSatisfiesExpression(node) {
            this.visitTypeAssertion(node);
        }
        TSTypeAliasDeclaration(node) {
            this.visitType(node);
        }
        TSTypeAssertion(node) {
            this.visitTypeAssertion(node);
        }
        UpdateExpression(node) {
            if (PatternVisitor_1.PatternVisitor.isPattern(node.argument)) {
                this.visitPattern(node.argument, pattern => {
                    this.currentScope().referenceValue(pattern, Reference_1.ReferenceFlag.ReadWrite, null);
                });
            }
            else {
                this.visitChildren(node);
            }
        }
        VariableDeclaration(node) {
            const variableTargetScope = node.kind === 'var'
                ? this.currentScope().variableScope
                : this.currentScope();
            for (const decl of node.declarations) {
                const init = decl.init;
                this.visitPattern(decl.id, (pattern, info) => {
                    variableTargetScope.defineIdentifier(pattern, new definition_1.VariableDefinition(pattern, decl, node));
                    this.referencingDefaultValue(pattern, info.assignments, null, true);
                    if (init) {
                        this.currentScope().referenceValue(pattern, Reference_1.ReferenceFlag.Write, init, null, true);
                    }
                }, { processRightHandNodes: true });
                if (decl.init) {
                    this.visit(decl.init);
                }
                if ('typeAnnotation' in decl.id) {
                    this.visitType(decl.id.typeAnnotation);
                }
            }
        }
        WithStatement(node) {
            this.visit(node.object);
            // Then nest scope for WithStatement.
            this.scopeManager.nestWithScope(node);
            this.visit(node.body);
            this.close(node);
        }
        ImportAttribute() {
            // import assertions are module metadata and thus have no variables to reference
        }
    }
    exports.Referencer = Referencer;
    _Referencer_jsxPragma = new WeakMap(), _Referencer_jsxFragmentName = new WeakMap(), _Referencer_hasReferencedJsxFactory = new WeakMap(), _Referencer_hasReferencedJsxFragmentFactory = new WeakMap(), _Referencer_lib = new WeakMap(), _Referencer_emitDecoratorMetadata = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/assert.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.assert = void 0;
    // the base assert module doesn't use ts assertion syntax
    function assert(value, message) {
        if (value == null) {
            throw new Error(message);
        }
    }
    exports.assert = assert;
    
},
/* @typescript-eslint/scope-manager/dist/definition/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    __exportStar(require(956) /* ./CatchClauseDefinition */, exports);
    __exportStar(require(960) /* ./ClassNameDefinition */, exports);
    __exportStar(require(961) /* ./Definition */, exports);
    __exportStar(require(959) /* ./DefinitionType */, exports);
    __exportStar(require(962) /* ./FunctionNameDefinition */, exports);
    __exportStar(require(963) /* ./ImplicitGlobalVariableDefinition */, exports);
    __exportStar(require(964) /* ./ImportBindingDefinition */, exports);
    __exportStar(require(965) /* ./ParameterDefinition */, exports);
    __exportStar(require(966) /* ./TSEnumMemberDefinition */, exports);
    __exportStar(require(967) /* ./TSEnumNameDefinition */, exports);
    __exportStar(require(968) /* ./TSModuleNameDefinition */, exports);
    __exportStar(require(969) /* ./TypeDefinition */, exports);
    __exportStar(require(970) /* ./VariableDefinition */, exports);
    
},
/* @typescript-eslint/scope-manager/dist/definition/CatchClauseDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.CatchClauseDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class CatchClauseDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node) {
            super(DefinitionType_1.DefinitionType.CatchClause, name, node, null);
            this.isTypeDefinition = false;
            this.isVariableDefinition = true;
        }
    }
    exports.CatchClauseDefinition = CatchClauseDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/DefinitionBase.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.DefinitionBase = void 0;
    const ID_1 = require(958) /* ../ID */;
    const generator = (0, ID_1.createIdGenerator)();
    class DefinitionBase {
        constructor(type, name, node, parent) {
            /**
             * A unique ID for this instance - primarily used to help debugging and testing
             */
            this.$id = generator();
            this.type = type;
            this.name = name;
            this.node = node;
            this.parent = parent;
        }
    }
    exports.DefinitionBase = DefinitionBase;
    
},
/* @typescript-eslint/scope-manager/dist/ID.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.resetIds = exports.createIdGenerator = void 0;
    const ID_CACHE = new Map();
    let NEXT_KEY = 0;
    function createIdGenerator() {
        const key = (NEXT_KEY += 1);
        ID_CACHE.set(key, 0);
        return () => {
            var _a;
            const current = (_a = ID_CACHE.get(key)) !== null && _a !== void 0 ? _a : 0;
            const next = current + 1;
            ID_CACHE.set(key, next);
            return next;
        };
    }
    exports.createIdGenerator = createIdGenerator;
    function resetIds() {
        ID_CACHE.clear();
    }
    exports.resetIds = resetIds;
    
},
/* @typescript-eslint/scope-manager/dist/definition/DefinitionType.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.DefinitionType = void 0;
    var DefinitionType;
    (function (DefinitionType) {
        DefinitionType["CatchClause"] = "CatchClause";
        DefinitionType["ClassName"] = "ClassName";
        DefinitionType["FunctionName"] = "FunctionName";
        DefinitionType["ImplicitGlobalVariable"] = "ImplicitGlobalVariable";
        DefinitionType["ImportBinding"] = "ImportBinding";
        DefinitionType["Parameter"] = "Parameter";
        DefinitionType["TSEnumName"] = "TSEnumName";
        DefinitionType["TSEnumMember"] = "TSEnumMemberName";
        DefinitionType["TSModuleName"] = "TSModuleName";
        DefinitionType["Type"] = "Type";
        DefinitionType["Variable"] = "Variable";
    })(DefinitionType || (DefinitionType = {}));
    exports.DefinitionType = DefinitionType;
    
},
/* @typescript-eslint/scope-manager/dist/definition/ClassNameDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ClassNameDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class ClassNameDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node) {
            super(DefinitionType_1.DefinitionType.ClassName, name, node, null);
            this.isTypeDefinition = true;
            this.isVariableDefinition = true;
        }
    }
    exports.ClassNameDefinition = ClassNameDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/Definition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/scope-manager/dist/definition/FunctionNameDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.FunctionNameDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class FunctionNameDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node) {
            super(DefinitionType_1.DefinitionType.FunctionName, name, node, null);
            this.isTypeDefinition = false;
            this.isVariableDefinition = true;
        }
    }
    exports.FunctionNameDefinition = FunctionNameDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/ImplicitGlobalVariableDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ImplicitGlobalVariableDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class ImplicitGlobalVariableDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node) {
            super(DefinitionType_1.DefinitionType.ImplicitGlobalVariable, name, node, null);
            this.isTypeDefinition = false;
            this.isVariableDefinition = true;
        }
    }
    exports.ImplicitGlobalVariableDefinition = ImplicitGlobalVariableDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/ImportBindingDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ImportBindingDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class ImportBindingDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node, decl) {
            super(DefinitionType_1.DefinitionType.ImportBinding, name, node, decl);
            this.isTypeDefinition = true;
            this.isVariableDefinition = true;
        }
    }
    exports.ImportBindingDefinition = ImportBindingDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/ParameterDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ParameterDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class ParameterDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node, rest) {
            super(DefinitionType_1.DefinitionType.Parameter, name, node, null);
            this.isTypeDefinition = false;
            this.isVariableDefinition = true;
            this.rest = rest;
        }
    }
    exports.ParameterDefinition = ParameterDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/TSEnumMemberDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TSEnumMemberDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class TSEnumMemberDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node) {
            super(DefinitionType_1.DefinitionType.TSEnumMember, name, node, null);
            this.isTypeDefinition = true;
            this.isVariableDefinition = true;
        }
    }
    exports.TSEnumMemberDefinition = TSEnumMemberDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/TSEnumNameDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TSEnumNameDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class TSEnumNameDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node) {
            super(DefinitionType_1.DefinitionType.TSEnumName, name, node, null);
            this.isTypeDefinition = true;
            this.isVariableDefinition = true;
        }
    }
    exports.TSEnumNameDefinition = TSEnumNameDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/TSModuleNameDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TSModuleNameDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class TSModuleNameDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node) {
            super(DefinitionType_1.DefinitionType.TSModuleName, name, node, null);
            this.isTypeDefinition = true;
            this.isVariableDefinition = true;
        }
    }
    exports.TSModuleNameDefinition = TSModuleNameDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/TypeDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TypeDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class TypeDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node) {
            super(DefinitionType_1.DefinitionType.Type, name, node, null);
            this.isTypeDefinition = true;
            this.isVariableDefinition = false;
        }
    }
    exports.TypeDefinition = TypeDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/definition/VariableDefinition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.VariableDefinition = void 0;
    const DefinitionBase_1 = require(957) /* ./DefinitionBase */;
    const DefinitionType_1 = require(959) /* ./DefinitionType */;
    class VariableDefinition extends DefinitionBase_1.DefinitionBase {
        constructor(name, node, decl) {
            super(DefinitionType_1.DefinitionType.Variable, name, node, decl);
            this.isTypeDefinition = false;
            this.isVariableDefinition = true;
        }
    }
    exports.VariableDefinition = VariableDefinition;
    
},
/* @typescript-eslint/scope-manager/dist/referencer/ClassVisitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _ClassVisitor_classNode, _ClassVisitor_referencer, _ClassVisitor_emitDecoratorMetadata;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ClassVisitor = void 0;
    const types_1 = require(789) /* @typescript-eslint/types */;
    const definition_1 = require(955) /* ../definition */;
    const TypeVisitor_1 = require(972) /* ./TypeVisitor */;
    const Visitor_1 = require(1000) /* ./Visitor */;
    class ClassVisitor extends Visitor_1.Visitor {
        constructor(referencer, node, emitDecoratorMetadata) {
            super(referencer);
            _ClassVisitor_classNode.set(this, void 0);
            _ClassVisitor_referencer.set(this, void 0);
            _ClassVisitor_emitDecoratorMetadata.set(this, void 0);
            __classPrivateFieldSet(this, _ClassVisitor_referencer, referencer, "f");
            __classPrivateFieldSet(this, _ClassVisitor_classNode, node, "f");
            __classPrivateFieldSet(this, _ClassVisitor_emitDecoratorMetadata, emitDecoratorMetadata, "f");
        }
        static visit(referencer, node, emitDecoratorMetadata) {
            const classVisitor = new ClassVisitor(referencer, node, emitDecoratorMetadata);
            classVisitor.visitClass(node);
        }
        visit(node) {
            // make sure we only handle the nodes we are designed to handle
            if (node && node.type in this) {
                super.visit(node);
            }
            else {
                __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(node);
            }
        }
        ///////////////////
        // Visit helpers //
        ///////////////////
        visitClass(node) {
            var _a, _b;
            if (node.type === types_1.AST_NODE_TYPES.ClassDeclaration && node.id) {
                __classPrivateFieldGet(this, _ClassVisitor_referencer, "f")
                    .currentScope()
                    .defineIdentifier(node.id, new definition_1.ClassNameDefinition(node.id, node));
            }
            (_a = node.decorators) === null || _a === void 0 ? void 0 : _a.forEach(d => __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(d));
            __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").scopeManager.nestClassScope(node);
            if (node.id) {
                // define the class name again inside the new scope
                // references to the class should not resolve directly to the parent class
                __classPrivateFieldGet(this, _ClassVisitor_referencer, "f")
                    .currentScope()
                    .defineIdentifier(node.id, new definition_1.ClassNameDefinition(node.id, node));
            }
            __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(node.superClass);
            // visit the type param declarations
            this.visitType(node.typeParameters);
            // then the usages
            this.visitType(node.superTypeParameters);
            (_b = node.implements) === null || _b === void 0 ? void 0 : _b.forEach(imp => this.visitType(imp));
            this.visit(node.body);
            __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").close(node);
        }
        visitPropertyDefinition(node) {
            this.visitPropertyBase(node);
            /**
             * class A {
             *   @meta     // <--- check this
             *   foo: Type;
             * }
             */
            this.visitMetadataType(node.typeAnnotation, !!node.decorators);
        }
        visitFunctionParameterTypeAnnotation(node, withDecorators) {
            if ('typeAnnotation' in node) {
                this.visitMetadataType(node.typeAnnotation, withDecorators);
            }
            else if (node.type === types_1.AST_NODE_TYPES.AssignmentPattern) {
                this.visitMetadataType(node.left.typeAnnotation, withDecorators);
            }
            else if (node.type === types_1.AST_NODE_TYPES.TSParameterProperty) {
                this.visitFunctionParameterTypeAnnotation(node.parameter, withDecorators);
            }
        }
        visitMethodFunction(node, methodNode) {
            var _a, _b;
            if (node.id) {
                // FunctionExpression with name creates its special scope;
                // FunctionExpressionNameScope.
                __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").scopeManager.nestFunctionExpressionNameScope(node);
            }
            // Consider this function is in the MethodDefinition.
            __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").scopeManager.nestFunctionScope(node, true);
            /**
             * class A {
             *   @meta     // <--- check this
             *   foo(a: Type) {}
             *
             *   @meta     // <--- check this
             *   foo(): Type {}
             * }
             */
            let withMethodDecorators = !!methodNode.decorators;
            /**
             * class A {
             *   foo(
             *     @meta    // <--- check this
             *     a: Type
             *   ) {}
             *
             *   set foo(
             *     @meta    // <--- EXCEPT this. TS do nothing for this
             *     a: Type
             *   ) {}
             * }
             */
            withMethodDecorators =
                withMethodDecorators ||
                    (methodNode.kind !== 'set' &&
                        node.params.some(param => param.decorators));
            if (!withMethodDecorators && methodNode.kind === 'set') {
                const keyName = getLiteralMethodKeyName(methodNode);
                /**
                 * class A {
                 *   @meta      // <--- check this
                 *   get a() {}
                 *   set ['a'](v: Type) {}
                 * }
                 */
                if (keyName != null &&
                    ((_a = __classPrivateFieldGet(this, _ClassVisitor_classNode, "f").body.body.find((node) => node !== methodNode &&
                        node.type === types_1.AST_NODE_TYPES.MethodDefinition &&
                        // Node must both be static or not
                        node.static === methodNode.static &&
                        getLiteralMethodKeyName(node) === keyName)) === null || _a === void 0 ? void 0 : _a.decorators)) {
                    withMethodDecorators = true;
                }
            }
            /**
             * @meta      // <--- check this
             * class A {
             *   constructor(a: Type) {}
             * }
             */
            if (!withMethodDecorators &&
                methodNode.kind === 'constructor' &&
                __classPrivateFieldGet(this, _ClassVisitor_classNode, "f").decorators) {
                withMethodDecorators = true;
            }
            // Process parameter declarations.
            for (const param of node.params) {
                this.visitPattern(param, (pattern, info) => {
                    __classPrivateFieldGet(this, _ClassVisitor_referencer, "f")
                        .currentScope()
                        .defineIdentifier(pattern, new definition_1.ParameterDefinition(pattern, node, info.rest));
                    __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").referencingDefaultValue(pattern, info.assignments, null, true);
                }, { processRightHandNodes: true });
                this.visitFunctionParameterTypeAnnotation(param, withMethodDecorators);
                (_b = param.decorators) === null || _b === void 0 ? void 0 : _b.forEach(d => this.visit(d));
            }
            this.visitMetadataType(node.returnType, withMethodDecorators);
            this.visitType(node.typeParameters);
            // In TypeScript there are a number of function-like constructs which have no body,
            // so check it exists before traversing
            if (node.body) {
                // Skip BlockStatement to prevent creating BlockStatement scope.
                if (node.body.type === types_1.AST_NODE_TYPES.BlockStatement) {
                    __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visitChildren(node.body);
                }
                else {
                    __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(node.body);
                }
            }
            __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").close(node);
        }
        visitPropertyBase(node) {
            var _a;
            if (node.computed) {
                __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(node.key);
            }
            if (node.value) {
                if (node.type === types_1.AST_NODE_TYPES.PropertyDefinition ||
                    node.type === types_1.AST_NODE_TYPES.AccessorProperty) {
                    __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").scopeManager.nestClassFieldInitializerScope(node.value);
                }
                __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(node.value);
                if (node.type === types_1.AST_NODE_TYPES.PropertyDefinition ||
                    node.type === types_1.AST_NODE_TYPES.AccessorProperty) {
                    __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").close(node.value);
                }
            }
            if ('decorators' in node) {
                (_a = node.decorators) === null || _a === void 0 ? void 0 : _a.forEach(d => __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(d));
            }
        }
        visitMethod(node) {
            var _a;
            if (node.computed) {
                __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(node.key);
            }
            if (node.value.type === types_1.AST_NODE_TYPES.FunctionExpression) {
                this.visitMethodFunction(node.value, node);
            }
            else {
                __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(node.value);
            }
            if ('decorators' in node) {
                (_a = node.decorators) === null || _a === void 0 ? void 0 : _a.forEach(d => __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(d));
            }
        }
        visitType(node) {
            if (!node) {
                return;
            }
            TypeVisitor_1.TypeVisitor.visit(__classPrivateFieldGet(this, _ClassVisitor_referencer, "f"), node);
        }
        visitMetadataType(node, withDecorators) {
            if (!node) {
                return;
            }
            // emit decorators metadata only work for TSTypeReference in ClassDeclaration
            if (__classPrivateFieldGet(this, _ClassVisitor_classNode, "f").type === types_1.AST_NODE_TYPES.ClassDeclaration &&
                !__classPrivateFieldGet(this, _ClassVisitor_classNode, "f").declare &&
                node.typeAnnotation.type === types_1.AST_NODE_TYPES.TSTypeReference &&
                __classPrivateFieldGet(this, _ClassVisitor_emitDecoratorMetadata, "f")) {
                let entityName;
                if (node.typeAnnotation.typeName.type === types_1.AST_NODE_TYPES.TSQualifiedName) {
                    let iter = node.typeAnnotation.typeName;
                    while (iter.left.type === types_1.AST_NODE_TYPES.TSQualifiedName) {
                        iter = iter.left;
                    }
                    entityName = iter.left;
                }
                else {
                    entityName = node.typeAnnotation.typeName;
                }
                if (withDecorators) {
                    if (entityName.type === types_1.AST_NODE_TYPES.Identifier) {
                        __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").currentScope().referenceDualValueType(entityName);
                    }
                    if (node.typeAnnotation.typeParameters) {
                        this.visitType(node.typeAnnotation.typeParameters);
                    }
                    // everything is handled now
                    return;
                }
            }
            this.visitType(node);
        }
        /////////////////////
        // Visit selectors //
        /////////////////////
        AccessorProperty(node) {
            this.visitPropertyDefinition(node);
        }
        ClassBody(node) {
            // this is here on purpose so that this visitor explicitly declares visitors
            // for all nodes it cares about (see the instance visit method above)
            this.visitChildren(node);
        }
        PropertyDefinition(node) {
            this.visitPropertyDefinition(node);
        }
        MethodDefinition(node) {
            this.visitMethod(node);
        }
        TSAbstractAccessorProperty(node) {
            this.visitPropertyDefinition(node);
        }
        TSAbstractPropertyDefinition(node) {
            this.visitPropertyDefinition(node);
        }
        TSAbstractMethodDefinition(node) {
            this.visitPropertyBase(node);
        }
        Identifier(node) {
            __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").visit(node);
        }
        PrivateIdentifier() {
            // intentionally skip
        }
        StaticBlock(node) {
            __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").scopeManager.nestClassStaticBlockScope(node);
            node.body.forEach(b => this.visit(b));
            __classPrivateFieldGet(this, _ClassVisitor_referencer, "f").close(node);
        }
    }
    exports.ClassVisitor = ClassVisitor;
    _ClassVisitor_classNode = new WeakMap(), _ClassVisitor_referencer = new WeakMap(), _ClassVisitor_emitDecoratorMetadata = new WeakMap();
    /**
     * Only if key is one of [identifier, string, number], ts will combine metadata of accessors .
     * class A {
     *   get a() {}
     *   set ['a'](v: Type) {}
     *
     *   get [1]() {}
     *   set [1](v: Type) {}
     *
     *   // Following won't be combined
     *   get [key]() {}
     *   set [key](v: Type) {}
     *
     *   get [true]() {}
     *   set [true](v: Type) {}
     *
     *   get ['a'+'b']() {}
     *   set ['a'+'b']() {}
     * }
     */
    function getLiteralMethodKeyName(node) {
        if (node.computed && node.key.type === types_1.AST_NODE_TYPES.Literal) {
            if (typeof node.key.value === 'string' ||
                typeof node.key.value === 'number') {
                return node.key.value;
            }
        }
        else if (!node.computed && node.key.type === types_1.AST_NODE_TYPES.Identifier) {
            return node.key.name;
        }
        return null;
    }
    
},
/* @typescript-eslint/scope-manager/dist/referencer/TypeVisitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _TypeVisitor_referencer;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TypeVisitor = void 0;
    const types_1 = require(789) /* @typescript-eslint/types */;
    const definition_1 = require(955) /* ../definition */;
    const scope_1 = require(973) /* ../scope */;
    const Visitor_1 = require(1000) /* ./Visitor */;
    class TypeVisitor extends Visitor_1.Visitor {
        constructor(referencer) {
            super(referencer);
            _TypeVisitor_referencer.set(this, void 0);
            __classPrivateFieldSet(this, _TypeVisitor_referencer, referencer, "f");
        }
        static visit(referencer, node) {
            const typeReferencer = new TypeVisitor(referencer);
            typeReferencer.visit(node);
        }
        ///////////////////
        // Visit helpers //
        ///////////////////
        visitFunctionType(node) {
            // arguments and type parameters can only be referenced from within the function
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").scopeManager.nestFunctionTypeScope(node);
            this.visit(node.typeParameters);
            for (const param of node.params) {
                let didVisitAnnotation = false;
                this.visitPattern(param, (pattern, info) => {
                    // a parameter name creates a value type variable which can be referenced later via typeof arg
                    __classPrivateFieldGet(this, _TypeVisitor_referencer, "f")
                        .currentScope()
                        .defineIdentifier(pattern, new definition_1.ParameterDefinition(pattern, node, info.rest));
                    if (pattern.typeAnnotation) {
                        this.visit(pattern.typeAnnotation);
                        didVisitAnnotation = true;
                    }
                });
                // there are a few special cases where the type annotation is owned by the parameter, not the pattern
                if (!didVisitAnnotation && 'typeAnnotation' in param) {
                    this.visit(param.typeAnnotation);
                }
            }
            this.visit(node.returnType);
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").close(node);
        }
        visitPropertyKey(node) {
            if (!node.computed) {
                return;
            }
            // computed members are treated as value references, and TS expects they have a literal type
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").visit(node.key);
        }
        /////////////////////
        // Visit selectors //
        /////////////////////
        Identifier(node) {
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").currentScope().referenceType(node);
        }
        MemberExpression(node) {
            this.visit(node.object);
            // don't visit the property
        }
        TSCallSignatureDeclaration(node) {
            this.visitFunctionType(node);
        }
        TSConditionalType(node) {
            // conditional types can define inferred type parameters
            // which are only accessible from inside the conditional parameter
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").scopeManager.nestConditionalTypeScope(node);
            // type parameters inferred in the condition clause are not accessible within the false branch
            this.visitChildren(node, ['falseType']);
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").close(node);
            this.visit(node.falseType);
        }
        TSConstructorType(node) {
            this.visitFunctionType(node);
        }
        TSConstructSignatureDeclaration(node) {
            this.visitFunctionType(node);
        }
        TSFunctionType(node) {
            this.visitFunctionType(node);
        }
        TSImportType(node) {
            // the TS parser allows any type to be the parameter, but it's a syntax error - so we can ignore it
            this.visit(node.typeParameters);
            // the qualifier is just part of a standard EntityName, so it should not be visited
        }
        TSIndexSignature(node) {
            for (const param of node.parameters) {
                if (param.type === types_1.AST_NODE_TYPES.Identifier) {
                    this.visit(param.typeAnnotation);
                }
            }
            this.visit(node.typeAnnotation);
        }
        TSInferType(node) {
            const typeParameter = node.typeParameter;
            let scope = __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").currentScope();
            /*
            In cases where there is a sub-type scope created within a conditional type, then the generic should be defined in the
            conditional type's scope, not the child type scope.
            If we define it within the child type's scope then it won't be able to be referenced outside the child type
            */
            if (scope.type === scope_1.ScopeType.functionType ||
                scope.type === scope_1.ScopeType.mappedType) {
                // search up the scope tree to figure out if we're in a nested type scope
                let currentScope = scope.upper;
                while (currentScope) {
                    if (currentScope.type === scope_1.ScopeType.functionType ||
                        currentScope.type === scope_1.ScopeType.mappedType) {
                        // ensure valid type parents only
                        currentScope = currentScope.upper;
                        continue;
                    }
                    if (currentScope.type === scope_1.ScopeType.conditionalType) {
                        scope = currentScope;
                        break;
                    }
                    break;
                }
            }
            scope.defineIdentifier(typeParameter.name, new definition_1.TypeDefinition(typeParameter.name, typeParameter));
            this.visit(typeParameter.constraint);
        }
        TSInterfaceDeclaration(node) {
            var _a, _b;
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f")
                .currentScope()
                .defineIdentifier(node.id, new definition_1.TypeDefinition(node.id, node));
            if (node.typeParameters) {
                // type parameters cannot be referenced from outside their current scope
                __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").scopeManager.nestTypeScope(node);
                this.visit(node.typeParameters);
            }
            (_a = node.extends) === null || _a === void 0 ? void 0 : _a.forEach(this.visit, this);
            (_b = node.implements) === null || _b === void 0 ? void 0 : _b.forEach(this.visit, this);
            this.visit(node.body);
            if (node.typeParameters) {
                __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").close(node);
            }
        }
        TSMappedType(node) {
            // mapped types key can only be referenced within their return value
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").scopeManager.nestMappedTypeScope(node);
            this.visitChildren(node);
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").close(node);
        }
        TSMethodSignature(node) {
            this.visitPropertyKey(node);
            this.visitFunctionType(node);
        }
        TSNamedTupleMember(node) {
            this.visit(node.elementType);
            // we don't visit the label as the label only exists for the purposes of documentation
        }
        TSPropertySignature(node) {
            this.visitPropertyKey(node);
            this.visit(node.typeAnnotation);
        }
        TSQualifiedName(node) {
            this.visit(node.left);
            // we don't visit the right as it a name on the thing, not a name to reference
        }
        TSTypeAliasDeclaration(node) {
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f")
                .currentScope()
                .defineIdentifier(node.id, new definition_1.TypeDefinition(node.id, node));
            if (node.typeParameters) {
                // type parameters cannot be referenced from outside their current scope
                __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").scopeManager.nestTypeScope(node);
                this.visit(node.typeParameters);
            }
            this.visit(node.typeAnnotation);
            if (node.typeParameters) {
                __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").close(node);
            }
        }
        TSTypeParameter(node) {
            __classPrivateFieldGet(this, _TypeVisitor_referencer, "f")
                .currentScope()
                .defineIdentifier(node.name, new definition_1.TypeDefinition(node.name, node));
            this.visit(node.constraint);
            this.visit(node.default);
        }
        TSTypePredicate(node) {
            if (node.parameterName.type !== types_1.AST_NODE_TYPES.TSThisType) {
                __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").currentScope().referenceValue(node.parameterName);
            }
            this.visit(node.typeAnnotation);
        }
        // a type query `typeof foo` is a special case that references a _non-type_ variable,
        TSTypeQuery(node) {
            let entityName;
            if (node.exprName.type === types_1.AST_NODE_TYPES.TSQualifiedName) {
                let iter = node.exprName;
                while (iter.left.type === types_1.AST_NODE_TYPES.TSQualifiedName) {
                    iter = iter.left;
                }
                entityName = iter.left;
            }
            else {
                entityName = node.exprName;
            }
            if (entityName.type === types_1.AST_NODE_TYPES.Identifier) {
                __classPrivateFieldGet(this, _TypeVisitor_referencer, "f").currentScope().referenceValue(entityName);
            }
            this.visit(node.typeParameters);
        }
        TSTypeAnnotation(node) {
            // check
            this.visitChildren(node);
        }
    }
    exports.TypeVisitor = TypeVisitor;
    _TypeVisitor_referencer = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/scope/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    __exportStar(require(974) /* ./BlockScope */, exports);
    __exportStar(require(983) /* ./CatchScope */, exports);
    __exportStar(require(984) /* ./ClassFieldInitializerScope */, exports);
    __exportStar(require(985) /* ./ClassScope */, exports);
    __exportStar(require(986) /* ./ConditionalTypeScope */, exports);
    __exportStar(require(987) /* ./ForScope */, exports);
    __exportStar(require(988) /* ./FunctionExpressionNameScope */, exports);
    __exportStar(require(989) /* ./FunctionScope */, exports);
    __exportStar(require(990) /* ./FunctionTypeScope */, exports);
    __exportStar(require(991) /* ./GlobalScope */, exports);
    __exportStar(require(992) /* ./MappedTypeScope */, exports);
    __exportStar(require(993) /* ./ModuleScope */, exports);
    __exportStar(require(994) /* ./Scope */, exports);
    __exportStar(require(982) /* ./ScopeType */, exports);
    __exportStar(require(995) /* ./SwitchScope */, exports);
    __exportStar(require(996) /* ./TSEnumScope */, exports);
    __exportStar(require(997) /* ./TSModuleScope */, exports);
    __exportStar(require(998) /* ./TypeScope */, exports);
    __exportStar(require(999) /* ./WithScope */, exports);
    
},
/* @typescript-eslint/scope-manager/dist/scope/BlockScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.BlockScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class BlockScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.block, upperScope, block, false);
        }
    }
    exports.BlockScope = BlockScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/ScopeBase.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _ScopeBase_declaredVariables, _ScopeBase_dynamic, _ScopeBase_staticCloseRef, _ScopeBase_dynamicCloseRef, _ScopeBase_globalCloseRef;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ScopeBase = void 0;
    const types_1 = require(789) /* @typescript-eslint/types */;
    const assert_1 = require(954) /* ../assert */;
    const definition_1 = require(955) /* ../definition */;
    const ID_1 = require(958) /* ../ID */;
    const Reference_1 = require(976) /* ../referencer/Reference */;
    const variable_1 = require(977) /* ../variable */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    /**
     * Test if scope is strict
     */
    function isStrictScope(scope, block, isMethodDefinition) {
        var _a;
        let body;
        // When upper scope is exists and strict, inner scope is also strict.
        if ((_a = scope.upper) === null || _a === void 0 ? void 0 : _a.isStrict) {
            return true;
        }
        if (isMethodDefinition) {
            return true;
        }
        if (scope.type === ScopeType_1.ScopeType.class ||
            scope.type === ScopeType_1.ScopeType.conditionalType ||
            scope.type === ScopeType_1.ScopeType.functionType ||
            scope.type === ScopeType_1.ScopeType.mappedType ||
            scope.type === ScopeType_1.ScopeType.module ||
            scope.type === ScopeType_1.ScopeType.tsEnum ||
            scope.type === ScopeType_1.ScopeType.tsModule ||
            scope.type === ScopeType_1.ScopeType.type) {
            return true;
        }
        if (scope.type === ScopeType_1.ScopeType.block || scope.type === ScopeType_1.ScopeType.switch) {
            return false;
        }
        if (scope.type === ScopeType_1.ScopeType.function) {
            const functionBody = block;
            switch (functionBody.type) {
                case types_1.AST_NODE_TYPES.ArrowFunctionExpression:
                    if (functionBody.body.type !== types_1.AST_NODE_TYPES.BlockStatement) {
                        return false;
                    }
                    body = functionBody.body;
                    break;
                case types_1.AST_NODE_TYPES.Program:
                    body = functionBody;
                    break;
                default:
                    body = functionBody.body;
            }
            if (!body) {
                return false;
            }
        }
        else if (scope.type === ScopeType_1.ScopeType.global) {
            body = block;
        }
        else {
            return false;
        }
        // Search 'use strict' directive.
        for (const stmt of body.body) {
            if (stmt.type !== types_1.AST_NODE_TYPES.ExpressionStatement) {
                break;
            }
            if (stmt.directive === 'use strict') {
                return true;
            }
            const expr = stmt.expression;
            if (expr.type !== types_1.AST_NODE_TYPES.Literal) {
                break;
            }
            if (expr.raw === '"use strict"' || expr.raw === "'use strict'") {
                return true;
            }
            if (expr.value === 'use strict') {
                return true;
            }
        }
        return false;
    }
    /**
     * Register scope
     */
    function registerScope(scopeManager, scope) {
        scopeManager.scopes.push(scope);
        const scopes = scopeManager.nodeToScope.get(scope.block);
        if (scopes) {
            scopes.push(scope);
        }
        else {
            scopeManager.nodeToScope.set(scope.block, [scope]);
        }
    }
    const generator = (0, ID_1.createIdGenerator)();
    const VARIABLE_SCOPE_TYPES = new Set([
        ScopeType_1.ScopeType.classFieldInitializer,
        ScopeType_1.ScopeType.classStaticBlock,
        ScopeType_1.ScopeType.function,
        ScopeType_1.ScopeType.global,
        ScopeType_1.ScopeType.module,
        ScopeType_1.ScopeType.tsModule,
    ]);
    class ScopeBase {
        constructor(scopeManager, type, upperScope, block, isMethodDefinition) {
            /**
             * A unique ID for this instance - primarily used to help debugging and testing
             */
            this.$id = generator();
            /**
             * The array of child scopes. This does not include grandchild scopes.
             * @public
             */
            this.childScopes = [];
            /**
             * A map of the variables for each node in this scope.
             * This is map is a pointer to the one in the parent ScopeManager instance
             */
            _ScopeBase_declaredVariables.set(this, void 0);
            /**
             * Generally, through the lexical scoping of JS you can always know which variable an identifier in the source code
             * refers to. There are a few exceptions to this rule. With `global` and `with` scopes you can only decide at runtime
             * which variable a reference refers to.
             * All those scopes are considered "dynamic".
             */
            _ScopeBase_dynamic.set(this, void 0);
            /**
             * Whether this scope is created by a FunctionExpression.
             * @public
             */
            this.functionExpressionScope = false;
            /**
             * List of {@link Reference}s that are left to be resolved (i.e. which
             * need to be linked to the variable they refer to).
             */
            this.leftToResolve = [];
            /**
             * Any variable {@link Reference} found in this scope.
             * This includes occurrences of local variables as well as variables from parent scopes (including the global scope).
             * For local variables this also includes defining occurrences (like in a 'var' statement).
             * In a 'function' scope this does not include the occurrences of the formal parameter in the parameter list.
             * @public
             */
            this.references = [];
            /**
             * The map from variable names to variable objects.
             * @public
             */
            this.set = new Map();
            /**
             * The {@link Reference}s that are not resolved with this scope.
             * @public
             */
            this.through = [];
            /**
             * The scoped {@link Variable}s of this scope.
             * In the case of a 'function' scope this includes the automatic argument `arguments` as its first element, as well
             * as all further formal arguments.
             * This does not include variables which are defined in child scopes.
             * @public
             */
            this.variables = [];
            _ScopeBase_staticCloseRef.set(this, (ref) => {
                const resolve = () => {
                    const name = ref.identifier.name;
                    const variable = this.set.get(name);
                    if (!variable) {
                        return false;
                    }
                    if (!this.isValidResolution(ref, variable)) {
                        return false;
                    }
                    // make sure we don't match a type reference to a value variable
                    const isValidTypeReference = ref.isTypeReference && variable.isTypeVariable;
                    const isValidValueReference = ref.isValueReference && variable.isValueVariable;
                    if (!isValidTypeReference && !isValidValueReference) {
                        return false;
                    }
                    variable.references.push(ref);
                    ref.resolved = variable;
                    return true;
                };
                if (!resolve()) {
                    this.delegateToUpperScope(ref);
                }
            });
            _ScopeBase_dynamicCloseRef.set(this, (ref) => {
                // notify all names are through to global
                let current = this;
                do {
                    current.through.push(ref);
                    current = current.upper;
                } while (current);
            });
            _ScopeBase_globalCloseRef.set(this, (ref, scopeManager) => {
                // let/const/class declarations should be resolved statically.
                // others should be resolved dynamically.
                if (this.shouldStaticallyCloseForGlobal(ref, scopeManager)) {
                    __classPrivateFieldGet(this, _ScopeBase_staticCloseRef, "f").call(this, ref);
                }
                else {
                    __classPrivateFieldGet(this, _ScopeBase_dynamicCloseRef, "f").call(this, ref);
                }
            });
            const upperScopeAsScopeBase = upperScope;
            this.type = type;
            __classPrivateFieldSet(this, _ScopeBase_dynamic, this.type === ScopeType_1.ScopeType.global || this.type === ScopeType_1.ScopeType.with, "f");
            this.block = block;
            this.variableScope = this.isVariableScope()
                ? this
                : upperScopeAsScopeBase.variableScope;
            this.upper = upperScope;
            /**
             * Whether 'use strict' is in effect in this scope.
             * @member {boolean} Scope#isStrict
             */
            this.isStrict = isStrictScope(this, block, isMethodDefinition);
            if (upperScopeAsScopeBase) {
                // this is guaranteed to be correct at runtime
                upperScopeAsScopeBase.childScopes.push(this);
            }
            __classPrivateFieldSet(this, _ScopeBase_declaredVariables, scopeManager.declaredVariables, "f");
            registerScope(scopeManager, this);
        }
        isVariableScope() {
            return VARIABLE_SCOPE_TYPES.has(this.type);
        }
        shouldStaticallyClose() {
            return !__classPrivateFieldGet(this, _ScopeBase_dynamic, "f");
        }
        shouldStaticallyCloseForGlobal(ref, scopeManager) {
            // On global scope, let/const/class declarations should be resolved statically.
            const name = ref.identifier.name;
            const variable = this.set.get(name);
            if (!variable) {
                return false;
            }
            // variable exists on the scope
            // in module mode, we can statically resolve everything, regardless of its decl type
            if (scopeManager.isModule()) {
                return true;
            }
            // in script mode, only certain cases should be statically resolved
            // Example:
            // a `var` decl is ignored by the runtime if it clashes with a global name
            // this means that we should not resolve the reference to the variable
            const defs = variable.defs;
            return (defs.length > 0 &&
                defs.every(def => {
                    var _a;
                    if (def.type === definition_1.DefinitionType.Variable &&
                        ((_a = def.parent) === null || _a === void 0 ? void 0 : _a.type) === types_1.AST_NODE_TYPES.VariableDeclaration &&
                        def.parent.kind === 'var') {
                        return false;
                    }
                    return true;
                }));
        }
        close(scopeManager) {
            let closeRef;
            if (this.shouldStaticallyClose()) {
                closeRef = __classPrivateFieldGet(this, _ScopeBase_staticCloseRef, "f");
            }
            else if (this.type !== 'global') {
                closeRef = __classPrivateFieldGet(this, _ScopeBase_dynamicCloseRef, "f");
            }
            else {
                closeRef = __classPrivateFieldGet(this, _ScopeBase_globalCloseRef, "f");
            }
            // Try Resolving all references in this scope.
            (0, assert_1.assert)(this.leftToResolve);
            this.leftToResolve.forEach(ref => closeRef(ref, scopeManager));
            this.leftToResolve = null;
            return this.upper;
        }
        /**
         * To override by function scopes.
         * References in default parameters isn't resolved to variables which are in their function body.
         */
        isValidResolution(_ref, _variable) {
            return true;
        }
        delegateToUpperScope(ref) {
            const upper = this.upper;
            if (upper === null || upper === void 0 ? void 0 : upper.leftToResolve) {
                upper.leftToResolve.push(ref);
            }
            this.through.push(ref);
        }
        addDeclaredVariablesOfNode(variable, node) {
            if (node == null) {
                return;
            }
            let variables = __classPrivateFieldGet(this, _ScopeBase_declaredVariables, "f").get(node);
            if (variables == null) {
                variables = [];
                __classPrivateFieldGet(this, _ScopeBase_declaredVariables, "f").set(node, variables);
            }
            if (!variables.includes(variable)) {
                variables.push(variable);
            }
        }
        defineVariable(nameOrVariable, set, variables, node, def) {
            const name = typeof nameOrVariable === 'string' ? nameOrVariable : nameOrVariable.name;
            let variable = set.get(name);
            if (!variable) {
                variable =
                    typeof nameOrVariable === 'string'
                        ? new variable_1.Variable(name, this)
                        : nameOrVariable;
                set.set(name, variable);
                variables.push(variable);
            }
            if (def) {
                variable.defs.push(def);
                this.addDeclaredVariablesOfNode(variable, def.node);
                this.addDeclaredVariablesOfNode(variable, def.parent);
            }
            if (node) {
                variable.identifiers.push(node);
            }
        }
        defineIdentifier(node, def) {
            this.defineVariable(node.name, this.set, this.variables, node, def);
        }
        defineLiteralIdentifier(node, def) {
            this.defineVariable(node.value, this.set, this.variables, null, def);
        }
        referenceValue(node, assign = Reference_1.ReferenceFlag.Read, writeExpr, maybeImplicitGlobal, init = false) {
            var _a;
            const ref = new Reference_1.Reference(node, this, assign, writeExpr, maybeImplicitGlobal, init, Reference_1.ReferenceTypeFlag.Value);
            this.references.push(ref);
            (_a = this.leftToResolve) === null || _a === void 0 ? void 0 : _a.push(ref);
        }
        referenceType(node) {
            var _a;
            const ref = new Reference_1.Reference(node, this, Reference_1.ReferenceFlag.Read, null, null, false, Reference_1.ReferenceTypeFlag.Type);
            this.references.push(ref);
            (_a = this.leftToResolve) === null || _a === void 0 ? void 0 : _a.push(ref);
        }
        referenceDualValueType(node) {
            var _a;
            const ref = new Reference_1.Reference(node, this, Reference_1.ReferenceFlag.Read, null, null, false, Reference_1.ReferenceTypeFlag.Type | Reference_1.ReferenceTypeFlag.Value);
            this.references.push(ref);
            (_a = this.leftToResolve) === null || _a === void 0 ? void 0 : _a.push(ref);
        }
    }
    exports.ScopeBase = ScopeBase;
    _ScopeBase_declaredVariables = new WeakMap(), _ScopeBase_dynamic = new WeakMap(), _ScopeBase_staticCloseRef = new WeakMap(), _ScopeBase_dynamicCloseRef = new WeakMap(), _ScopeBase_globalCloseRef = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/referencer/Reference.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var _Reference_flag, _Reference_referenceType;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ReferenceTypeFlag = exports.ReferenceFlag = exports.Reference = void 0;
    const ID_1 = require(958) /* ../ID */;
    var ReferenceFlag;
    (function (ReferenceFlag) {
        ReferenceFlag[ReferenceFlag["Read"] = 1] = "Read";
        ReferenceFlag[ReferenceFlag["Write"] = 2] = "Write";
        ReferenceFlag[ReferenceFlag["ReadWrite"] = 3] = "ReadWrite";
    })(ReferenceFlag || (ReferenceFlag = {}));
    exports.ReferenceFlag = ReferenceFlag;
    const generator = (0, ID_1.createIdGenerator)();
    var ReferenceTypeFlag;
    (function (ReferenceTypeFlag) {
        ReferenceTypeFlag[ReferenceTypeFlag["Value"] = 1] = "Value";
        ReferenceTypeFlag[ReferenceTypeFlag["Type"] = 2] = "Type";
    })(ReferenceTypeFlag || (ReferenceTypeFlag = {}));
    exports.ReferenceTypeFlag = ReferenceTypeFlag;
    /**
     * A Reference represents a single occurrence of an identifier in code.
     */
    class Reference {
        /**
         * True if this reference can reference types
         */
        get isTypeReference() {
            return (__classPrivateFieldGet(this, _Reference_referenceType, "f") & ReferenceTypeFlag.Type) !== 0;
        }
        /**
         * True if this reference can reference values
         */
        get isValueReference() {
            return (__classPrivateFieldGet(this, _Reference_referenceType, "f") & ReferenceTypeFlag.Value) !== 0;
        }
        constructor(identifier, scope, flag, writeExpr, maybeImplicitGlobal, init, referenceType = ReferenceTypeFlag.Value) {
            /**
             * A unique ID for this instance - primarily used to help debugging and testing
             */
            this.$id = generator();
            /**
             * The read-write mode of the reference.
             */
            _Reference_flag.set(this, void 0);
            /**
             * In some cases, a reference may be a type, value or both a type and value reference.
             */
            _Reference_referenceType.set(this, void 0);
            this.identifier = identifier;
            this.from = scope;
            this.resolved = null;
            __classPrivateFieldSet(this, _Reference_flag, flag, "f");
            if (this.isWrite()) {
                this.writeExpr = writeExpr;
                this.init = init;
            }
            this.maybeImplicitGlobal = maybeImplicitGlobal;
            __classPrivateFieldSet(this, _Reference_referenceType, referenceType, "f");
        }
        /**
         * Whether the reference is writeable.
         * @public
         */
        isWrite() {
            return !!(__classPrivateFieldGet(this, _Reference_flag, "f") & ReferenceFlag.Write);
        }
        /**
         * Whether the reference is readable.
         * @public
         */
        isRead() {
            return !!(__classPrivateFieldGet(this, _Reference_flag, "f") & ReferenceFlag.Read);
        }
        /**
         * Whether the reference is read-only.
         * @public
         */
        isReadOnly() {
            return __classPrivateFieldGet(this, _Reference_flag, "f") === ReferenceFlag.Read;
        }
        /**
         * Whether the reference is write-only.
         * @public
         */
        isWriteOnly() {
            return __classPrivateFieldGet(this, _Reference_flag, "f") === ReferenceFlag.Write;
        }
        /**
         * Whether the reference is read-write.
         * @public
         */
        isReadWrite() {
            return __classPrivateFieldGet(this, _Reference_flag, "f") === ReferenceFlag.ReadWrite;
        }
    }
    exports.Reference = Reference;
    _Reference_flag = new WeakMap(), _Reference_referenceType = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/variable/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Variable = exports.ImplicitLibVariable = exports.ESLintScopeVariable = void 0;
    var ESLintScopeVariable_1 = require(978) /* ./ESLintScopeVariable */;
    Object.defineProperty(exports, "ESLintScopeVariable", { enumerable: true, get: function () { return ESLintScopeVariable_1.ESLintScopeVariable; } });
    var ImplicitLibVariable_1 = require(980) /* ./ImplicitLibVariable */;
    Object.defineProperty(exports, "ImplicitLibVariable", { enumerable: true, get: function () { return ImplicitLibVariable_1.ImplicitLibVariable; } });
    var Variable_1 = require(981) /* ./Variable */;
    Object.defineProperty(exports, "Variable", { enumerable: true, get: function () { return Variable_1.Variable; } });
    
},
/* @typescript-eslint/scope-manager/dist/variable/ESLintScopeVariable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ESLintScopeVariable = void 0;
    const VariableBase_1 = require(979) /* ./VariableBase */;
    /**
     * ESLint defines global variables using the eslint-scope Variable class
     * This is declared her for consumers to use
     */
    class ESLintScopeVariable extends VariableBase_1.VariableBase {
    }
    exports.ESLintScopeVariable = ESLintScopeVariable;
    
},
/* @typescript-eslint/scope-manager/dist/variable/VariableBase.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.VariableBase = void 0;
    const ID_1 = require(958) /* ../ID */;
    const generator = (0, ID_1.createIdGenerator)();
    class VariableBase {
        constructor(name, scope) {
            /**
             * A unique ID for this instance - primarily used to help debugging and testing
             */
            this.$id = generator();
            /**
             * The array of the definitions of this variable.
             * @public
             */
            this.defs = [];
            /**
             * True if the variable is considered used for the purposes of `no-unused-vars`, false otherwise.
             * @public
             */
            this.eslintUsed = false;
            /**
             * The array of `Identifier` nodes which define this variable.
             * If this variable is redeclared, this array includes two or more nodes.
             * @public
             */
            this.identifiers = [];
            /**
             * List of {@link Reference} of this variable (excluding parameter entries)  in its defining scope and all nested scopes.
             * For defining occurrences only see {@link Variable#defs}.
             * @public
             */
            this.references = [];
            this.name = name;
            this.scope = scope;
        }
    }
    exports.VariableBase = VariableBase;
    
},
/* @typescript-eslint/scope-manager/dist/variable/ImplicitLibVariable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ImplicitLibVariable = void 0;
    const ESLintScopeVariable_1 = require(978) /* ./ESLintScopeVariable */;
    /**
     * An variable implicitly defined by the TS Lib
     */
    class ImplicitLibVariable extends ESLintScopeVariable_1.ESLintScopeVariable {
        constructor(scope, name, { isTypeVariable, isValueVariable, writeable, eslintImplicitGlobalSetting, }) {
            super(name, scope);
            this.isTypeVariable = isTypeVariable !== null && isTypeVariable !== void 0 ? isTypeVariable : false;
            this.isValueVariable = isValueVariable !== null && isValueVariable !== void 0 ? isValueVariable : false;
            this.writeable = writeable !== null && writeable !== void 0 ? writeable : false;
            this.eslintImplicitGlobalSetting =
                eslintImplicitGlobalSetting !== null && eslintImplicitGlobalSetting !== void 0 ? eslintImplicitGlobalSetting : 'readonly';
        }
    }
    exports.ImplicitLibVariable = ImplicitLibVariable;
    
},
/* @typescript-eslint/scope-manager/dist/variable/Variable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Variable = void 0;
    const VariableBase_1 = require(979) /* ./VariableBase */;
    /**
     * A Variable represents a locally scoped identifier. These include arguments to functions.
     */
    class Variable extends VariableBase_1.VariableBase {
        /**
         * `true` if the variable is valid in a type context, false otherwise
         * @public
         */
        get isTypeVariable() {
            if (this.defs.length === 0) {
                // we don't statically know whether this is a type or a value
                return true;
            }
            return this.defs.some(def => def.isTypeDefinition);
        }
        /**
         * `true` if the variable is valid in a value context, false otherwise
         * @public
         */
        get isValueVariable() {
            if (this.defs.length === 0) {
                // we don't statically know whether this is a type or a value
                return true;
            }
            return this.defs.some(def => def.isVariableDefinition);
        }
    }
    exports.Variable = Variable;
    
},
/* @typescript-eslint/scope-manager/dist/scope/ScopeType.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ScopeType = void 0;
    var ScopeType;
    (function (ScopeType) {
        ScopeType["block"] = "block";
        ScopeType["catch"] = "catch";
        ScopeType["class"] = "class";
        ScopeType["classFieldInitializer"] = "class-field-initializer";
        ScopeType["classStaticBlock"] = "class-static-block";
        ScopeType["conditionalType"] = "conditionalType";
        ScopeType["for"] = "for";
        ScopeType["function"] = "function";
        ScopeType["functionExpressionName"] = "function-expression-name";
        ScopeType["functionType"] = "functionType";
        ScopeType["global"] = "global";
        ScopeType["mappedType"] = "mappedType";
        ScopeType["module"] = "module";
        ScopeType["switch"] = "switch";
        ScopeType["tsEnum"] = "tsEnum";
        ScopeType["tsModule"] = "tsModule";
        ScopeType["type"] = "type";
        ScopeType["with"] = "with";
    })(ScopeType || (ScopeType = {}));
    exports.ScopeType = ScopeType;
    
},
/* @typescript-eslint/scope-manager/dist/scope/CatchScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.CatchScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class CatchScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.catch, upperScope, block, false);
        }
    }
    exports.CatchScope = CatchScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/ClassFieldInitializerScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ClassFieldInitializerScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class ClassFieldInitializerScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.classFieldInitializer, upperScope, block, false);
        }
    }
    exports.ClassFieldInitializerScope = ClassFieldInitializerScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/ClassScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ClassScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class ClassScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.class, upperScope, block, false);
        }
    }
    exports.ClassScope = ClassScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/ConditionalTypeScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ConditionalTypeScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class ConditionalTypeScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.conditionalType, upperScope, block, false);
        }
    }
    exports.ConditionalTypeScope = ConditionalTypeScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/ForScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ForScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class ForScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.for, upperScope, block, false);
        }
    }
    exports.ForScope = ForScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/FunctionExpressionNameScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.FunctionExpressionNameScope = void 0;
    const definition_1 = require(955) /* ../definition */;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class FunctionExpressionNameScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.functionExpressionName, upperScope, block, false);
            if (block.id) {
                this.defineIdentifier(block.id, new definition_1.FunctionNameDefinition(block.id, block));
            }
            this.functionExpressionScope = true;
        }
    }
    exports.FunctionExpressionNameScope = FunctionExpressionNameScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/FunctionScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.FunctionScope = void 0;
    const types_1 = require(789) /* @typescript-eslint/types */;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class FunctionScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block, isMethodDefinition) {
            super(scopeManager, ScopeType_1.ScopeType.function, upperScope, block, isMethodDefinition);
            // section 9.2.13, FunctionDeclarationInstantiation.
            // NOTE Arrow functions never have an arguments objects.
            if (this.block.type !== types_1.AST_NODE_TYPES.ArrowFunctionExpression) {
                this.defineVariable('arguments', this.set, this.variables, null, null);
            }
        }
        // References in default parameters isn't resolved to variables which are in their function body.
        //     const x = 1
        //     function f(a = x) { // This `x` is resolved to the `x` in the outer scope.
        //         const x = 2
        //         console.log(a)
        //     }
        isValidResolution(ref, variable) {
            var _a, _b;
            // If `options.globalReturn` is true, `this.block` becomes a Program node.
            if (this.block.type === types_1.AST_NODE_TYPES.Program) {
                return true;
            }
            const bodyStart = (_b = (_a = this.block.body) === null || _a === void 0 ? void 0 : _a.range[0]) !== null && _b !== void 0 ? _b : -1;
            // It's invalid resolution in the following case:
            return !((variable.scope === this &&
                ref.identifier.range[0] < bodyStart && // the reference is in the parameter part.
                variable.defs.every(d => d.name.range[0] >= bodyStart)) // the variable is in the body.
            );
        }
    }
    exports.FunctionScope = FunctionScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/FunctionTypeScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.FunctionTypeScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class FunctionTypeScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.functionType, upperScope, block, false);
        }
    }
    exports.FunctionTypeScope = FunctionTypeScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/GlobalScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.GlobalScope = void 0;
    const types_1 = require(789) /* @typescript-eslint/types */;
    const assert_1 = require(954) /* ../assert */;
    const ImplicitGlobalVariableDefinition_1 = require(963) /* ../definition/ImplicitGlobalVariableDefinition */;
    const variable_1 = require(977) /* ../variable */;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class GlobalScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, block) {
            super(scopeManager, ScopeType_1.ScopeType.global, null, block, false);
            this.implicit = {
                set: new Map(),
                variables: [],
                leftToBeResolved: [],
            };
        }
        defineImplicitVariable(name, options) {
            this.defineVariable(new variable_1.ImplicitLibVariable(this, name, options), this.set, this.variables, null, null);
        }
        close(scopeManager) {
            (0, assert_1.assert)(this.leftToResolve);
            for (const ref of this.leftToResolve) {
                if (ref.maybeImplicitGlobal && !this.set.has(ref.identifier.name)) {
                    // create an implicit global variable from assignment expression
                    const info = ref.maybeImplicitGlobal;
                    const node = info.pattern;
                    if (node && node.type === types_1.AST_NODE_TYPES.Identifier) {
                        this.defineVariable(node.name, this.implicit.set, this.implicit.variables, node, new ImplicitGlobalVariableDefinition_1.ImplicitGlobalVariableDefinition(info.pattern, info.node));
                    }
                }
            }
            this.implicit.leftToBeResolved = this.leftToResolve;
            return super.close(scopeManager);
        }
    }
    exports.GlobalScope = GlobalScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/MappedTypeScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.MappedTypeScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class MappedTypeScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.mappedType, upperScope, block, false);
        }
    }
    exports.MappedTypeScope = MappedTypeScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/ModuleScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ModuleScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class ModuleScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.module, upperScope, block, false);
        }
    }
    exports.ModuleScope = ModuleScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/Scope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/scope-manager/dist/scope/SwitchScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.SwitchScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class SwitchScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.switch, upperScope, block, false);
        }
    }
    exports.SwitchScope = SwitchScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/TSEnumScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TSEnumScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class TSEnumScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.tsEnum, upperScope, block, false);
        }
    }
    exports.TSEnumScope = TSEnumScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/TSModuleScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TSModuleScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class TSModuleScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.tsModule, upperScope, block, false);
        }
    }
    exports.TSModuleScope = TSModuleScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/TypeScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TypeScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class TypeScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.type, upperScope, block, false);
        }
    }
    exports.TypeScope = TypeScope;
    
},
/* @typescript-eslint/scope-manager/dist/scope/WithScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.WithScope = void 0;
    const assert_1 = require(954) /* ../assert */;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class WithScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.with, upperScope, block, false);
        }
        close(scopeManager) {
            if (this.shouldStaticallyClose()) {
                return super.close(scopeManager);
            }
            (0, assert_1.assert)(this.leftToResolve);
            this.leftToResolve.forEach(ref => this.delegateToUpperScope(ref));
            this.leftToResolve = null;
            return this.upper;
        }
    }
    exports.WithScope = WithScope;
    
},
/* @typescript-eslint/scope-manager/dist/referencer/Visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var _Visitor_options;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.VisitorBase = exports.Visitor = void 0;
    const PatternVisitor_1 = require(1001) /* ./PatternVisitor */;
    const VisitorBase_1 = require(1002) /* ./VisitorBase */;
    Object.defineProperty(exports, "VisitorBase", { enumerable: true, get: function () { return VisitorBase_1.VisitorBase; } });
    class Visitor extends VisitorBase_1.VisitorBase {
        constructor(optionsOrVisitor) {
            super(optionsOrVisitor instanceof Visitor
                ? __classPrivateFieldGet(optionsOrVisitor, _Visitor_options, "f")
                : optionsOrVisitor);
            _Visitor_options.set(this, void 0);
            __classPrivateFieldSet(this, _Visitor_options, optionsOrVisitor instanceof Visitor
                ? __classPrivateFieldGet(optionsOrVisitor, _Visitor_options, "f")
                : optionsOrVisitor, "f");
        }
        visitPattern(node, callback, options = { processRightHandNodes: false }) {
            // Call the callback at left hand identifier nodes, and Collect right hand nodes.
            const visitor = new PatternVisitor_1.PatternVisitor(__classPrivateFieldGet(this, _Visitor_options, "f"), node, callback);
            visitor.visit(node);
            // Process the right hand nodes recursively.
            if (options.processRightHandNodes) {
                visitor.rightHandNodes.forEach(this.visit, this);
            }
        }
    }
    exports.Visitor = Visitor;
    _Visitor_options = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/referencer/PatternVisitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _PatternVisitor_rootPattern, _PatternVisitor_callback, _PatternVisitor_assignments, _PatternVisitor_restElements;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.PatternVisitor = void 0;
    const types_1 = require(789) /* @typescript-eslint/types */;
    const VisitorBase_1 = require(1002) /* ./VisitorBase */;
    class PatternVisitor extends VisitorBase_1.VisitorBase {
        static isPattern(node) {
            const nodeType = node.type;
            return (nodeType === types_1.AST_NODE_TYPES.Identifier ||
                nodeType === types_1.AST_NODE_TYPES.ObjectPattern ||
                nodeType === types_1.AST_NODE_TYPES.ArrayPattern ||
                nodeType === types_1.AST_NODE_TYPES.SpreadElement ||
                nodeType === types_1.AST_NODE_TYPES.RestElement ||
                nodeType === types_1.AST_NODE_TYPES.AssignmentPattern);
        }
        constructor(options, rootPattern, callback) {
            super(options);
            _PatternVisitor_rootPattern.set(this, void 0);
            _PatternVisitor_callback.set(this, void 0);
            _PatternVisitor_assignments.set(this, []);
            this.rightHandNodes = [];
            _PatternVisitor_restElements.set(this, []);
            __classPrivateFieldSet(this, _PatternVisitor_rootPattern, rootPattern, "f");
            __classPrivateFieldSet(this, _PatternVisitor_callback, callback, "f");
        }
        ArrayExpression(node) {
            node.elements.forEach(this.visit, this);
        }
        ArrayPattern(pattern) {
            for (const element of pattern.elements) {
                this.visit(element);
            }
        }
        AssignmentExpression(node) {
            __classPrivateFieldGet(this, _PatternVisitor_assignments, "f").push(node);
            this.visit(node.left);
            this.rightHandNodes.push(node.right);
            __classPrivateFieldGet(this, _PatternVisitor_assignments, "f").pop();
        }
        AssignmentPattern(pattern) {
            __classPrivateFieldGet(this, _PatternVisitor_assignments, "f").push(pattern);
            this.visit(pattern.left);
            this.rightHandNodes.push(pattern.right);
            __classPrivateFieldGet(this, _PatternVisitor_assignments, "f").pop();
        }
        CallExpression(node) {
            // arguments are right hand nodes.
            node.arguments.forEach(a => {
                this.rightHandNodes.push(a);
            });
            this.visit(node.callee);
        }
        Decorator() {
            // don't visit any decorators when exploring a pattern
        }
        Identifier(pattern) {
            var _a;
            const lastRestElement = (_a = __classPrivateFieldGet(this, _PatternVisitor_restElements, "f")[__classPrivateFieldGet(this, _PatternVisitor_restElements, "f").length - 1]) !== null && _a !== void 0 ? _a : null;
            __classPrivateFieldGet(this, _PatternVisitor_callback, "f").call(this, pattern, {
                topLevel: pattern === __classPrivateFieldGet(this, _PatternVisitor_rootPattern, "f"),
                rest: lastRestElement != null && lastRestElement.argument === pattern,
                assignments: __classPrivateFieldGet(this, _PatternVisitor_assignments, "f"),
            });
        }
        MemberExpression(node) {
            // Computed property's key is a right hand node.
            if (node.computed) {
                this.rightHandNodes.push(node.property);
            }
            // the object is only read, write to its property.
            this.rightHandNodes.push(node.object);
        }
        Property(property) {
            // Computed property's key is a right hand node.
            if (property.computed) {
                this.rightHandNodes.push(property.key);
            }
            // If it's shorthand, its key is same as its value.
            // If it's shorthand and has its default value, its key is same as its value.left (the value is AssignmentPattern).
            // If it's not shorthand, the name of new variable is its value's.
            this.visit(property.value);
        }
        RestElement(pattern) {
            __classPrivateFieldGet(this, _PatternVisitor_restElements, "f").push(pattern);
            this.visit(pattern.argument);
            __classPrivateFieldGet(this, _PatternVisitor_restElements, "f").pop();
        }
        SpreadElement(node) {
            this.visit(node.argument);
        }
        TSTypeAnnotation() {
            // we don't want to visit types
        }
    }
    exports.PatternVisitor = PatternVisitor;
    _PatternVisitor_rootPattern = new WeakMap(), _PatternVisitor_callback = new WeakMap(), _PatternVisitor_assignments = new WeakMap(), _PatternVisitor_restElements = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/referencer/VisitorBase.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _VisitorBase_childVisitorKeys, _VisitorBase_visitChildrenEvenIfSelectorExists;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.VisitorBase = void 0;
    const visitor_keys_1 = require(863) /* @typescript-eslint/visitor-keys */;
    function isObject(obj) {
        return typeof obj === 'object' && obj != null;
    }
    function isNode(node) {
        return isObject(node) && typeof node.type === 'string';
    }
    class VisitorBase {
        constructor(options) {
            var _a, _b;
            _VisitorBase_childVisitorKeys.set(this, void 0);
            _VisitorBase_visitChildrenEvenIfSelectorExists.set(this, void 0);
            __classPrivateFieldSet(this, _VisitorBase_childVisitorKeys, (_a = options.childVisitorKeys) !== null && _a !== void 0 ? _a : visitor_keys_1.visitorKeys, "f");
            __classPrivateFieldSet(this, _VisitorBase_visitChildrenEvenIfSelectorExists, (_b = options.visitChildrenEvenIfSelectorExists) !== null && _b !== void 0 ? _b : false, "f");
        }
        /**
         * Default method for visiting children.
         * @param node the node whose children should be visited
         * @param exclude a list of keys to not visit
         */
        visitChildren(node, excludeArr = []) {
            var _a;
            if (node == null || node.type == null) {
                return;
            }
            const exclude = new Set(excludeArr.concat(['parent']));
            const children = (_a = __classPrivateFieldGet(this, _VisitorBase_childVisitorKeys, "f")[node.type]) !== null && _a !== void 0 ? _a : Object.keys(node);
            for (const key of children) {
                if (exclude.has(key)) {
                    continue;
                }
                const child = node[key];
                if (!child) {
                    continue;
                }
                if (Array.isArray(child)) {
                    for (const subChild of child) {
                        if (isNode(subChild)) {
                            this.visit(subChild);
                        }
                    }
                }
                else if (isNode(child)) {
                    this.visit(child);
                }
            }
        }
        /**
         * Dispatching node.
         */
        visit(node) {
            if (node == null || node.type == null) {
                return;
            }
            const visitor = this[node.type];
            if (visitor) {
                visitor.call(this, node);
                if (!__classPrivateFieldGet(this, _VisitorBase_visitChildrenEvenIfSelectorExists, "f")) {
                    return;
                }
            }
            this.visitChildren(node);
        }
    }
    exports.VisitorBase = VisitorBase;
    _VisitorBase_childVisitorKeys = new WeakMap(), _VisitorBase_visitChildrenEvenIfSelectorExists = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/referencer/ExportVisitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _ExportVisitor_referencer, _ExportVisitor_exportNode;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ExportVisitor = void 0;
    const types_1 = require(789) /* @typescript-eslint/types */;
    const Visitor_1 = require(1000) /* ./Visitor */;
    class ExportVisitor extends Visitor_1.Visitor {
        constructor(node, referencer) {
            super(referencer);
            _ExportVisitor_referencer.set(this, void 0);
            _ExportVisitor_exportNode.set(this, void 0);
            __classPrivateFieldSet(this, _ExportVisitor_exportNode, node, "f");
            __classPrivateFieldSet(this, _ExportVisitor_referencer, referencer, "f");
        }
        static visit(referencer, node) {
            const exportReferencer = new ExportVisitor(node, referencer);
            exportReferencer.visit(node);
        }
        Identifier(node) {
            if (__classPrivateFieldGet(this, _ExportVisitor_exportNode, "f").exportKind === 'type') {
                // export type { T };
                // type exports can only reference types
                __classPrivateFieldGet(this, _ExportVisitor_referencer, "f").currentScope().referenceType(node);
            }
            else {
                __classPrivateFieldGet(this, _ExportVisitor_referencer, "f").currentScope().referenceDualValueType(node);
            }
        }
        ExportDefaultDeclaration(node) {
            if (node.declaration.type === types_1.AST_NODE_TYPES.Identifier) {
                // export default A;
                // this could be a type or a variable
                this.visit(node.declaration);
            }
            else {
                // export const a = 1;
                // export something();
                // etc
                // these not included in the scope of this visitor as they are all guaranteed to be values or declare variables
            }
        }
        ExportNamedDeclaration(node) {
            if (node.source) {
                // export ... from 'foo';
                // these are external identifiers so there shouldn't be references or defs
                return;
            }
            if (!node.declaration) {
                // export { x };
                this.visitChildren(node);
            }
            else {
                // export const x = 1;
                // this is not included in the scope of this visitor as it creates a variable
            }
        }
        ExportSpecifier(node) {
            if (node.exportKind === 'type') {
                // export { type T };
                // type exports can only reference types
                //
                // we can't let this fall through to the Identifier selector because the exportKind is on this node
                // and we don't have access to the `.parent` during scope analysis
                __classPrivateFieldGet(this, _ExportVisitor_referencer, "f").currentScope().referenceType(node.local);
            }
            else {
                this.visit(node.local);
            }
        }
    }
    exports.ExportVisitor = ExportVisitor;
    _ExportVisitor_referencer = new WeakMap(), _ExportVisitor_exportNode = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/referencer/ImportVisitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _ImportVisitor_declaration, _ImportVisitor_referencer;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ImportVisitor = void 0;
    const definition_1 = require(955) /* ../definition */;
    const Visitor_1 = require(1000) /* ./Visitor */;
    class ImportVisitor extends Visitor_1.Visitor {
        constructor(declaration, referencer) {
            super(referencer);
            _ImportVisitor_declaration.set(this, void 0);
            _ImportVisitor_referencer.set(this, void 0);
            __classPrivateFieldSet(this, _ImportVisitor_declaration, declaration, "f");
            __classPrivateFieldSet(this, _ImportVisitor_referencer, referencer, "f");
        }
        static visit(referencer, declaration) {
            const importReferencer = new ImportVisitor(declaration, referencer);
            importReferencer.visit(declaration);
        }
        visitImport(id, specifier) {
            __classPrivateFieldGet(this, _ImportVisitor_referencer, "f")
                .currentScope()
                .defineIdentifier(id, new definition_1.ImportBindingDefinition(id, specifier, __classPrivateFieldGet(this, _ImportVisitor_declaration, "f")));
        }
        ImportNamespaceSpecifier(node) {
            const local = node.local;
            this.visitImport(local, node);
        }
        ImportDefaultSpecifier(node) {
            const local = node.local;
            this.visitImport(local, node);
        }
        ImportSpecifier(node) {
            const local = node.local;
            this.visitImport(local, node);
        }
    }
    exports.ImportVisitor = ImportVisitor;
    _ImportVisitor_declaration = new WeakMap(), _ImportVisitor_referencer = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/ScopeManager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _ScopeManager_options;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ScopeManager = void 0;
    const assert_1 = require(954) /* ./assert */;
    const scope_1 = require(973) /* ./scope */;
    const ClassFieldInitializerScope_1 = require(984) /* ./scope/ClassFieldInitializerScope */;
    const ClassStaticBlockScope_1 = require(1006) /* ./scope/ClassStaticBlockScope */;
    class ScopeManager {
        get variables() {
            const variables = new Set();
            function recurse(scope) {
                scope.variables.forEach(v => variables.add(v));
                scope.childScopes.forEach(recurse);
            }
            this.scopes.forEach(recurse);
            return Array.from(variables).sort((a, b) => a.$id - b.$id);
        }
        constructor(options) {
            _ScopeManager_options.set(this, void 0);
            this.scopes = [];
            this.globalScope = null;
            this.nodeToScope = new WeakMap();
            this.currentScope = null;
            __classPrivateFieldSet(this, _ScopeManager_options, options, "f");
            this.declaredVariables = new WeakMap();
        }
        isGlobalReturn() {
            return __classPrivateFieldGet(this, _ScopeManager_options, "f").globalReturn === true;
        }
        isModule() {
            return __classPrivateFieldGet(this, _ScopeManager_options, "f").sourceType === 'module';
        }
        isImpliedStrict() {
            return __classPrivateFieldGet(this, _ScopeManager_options, "f").impliedStrict === true;
        }
        isStrictModeSupported() {
            return __classPrivateFieldGet(this, _ScopeManager_options, "f").ecmaVersion != null && __classPrivateFieldGet(this, _ScopeManager_options, "f").ecmaVersion >= 5;
        }
        isES6() {
            return __classPrivateFieldGet(this, _ScopeManager_options, "f").ecmaVersion != null && __classPrivateFieldGet(this, _ScopeManager_options, "f").ecmaVersion >= 6;
        }
        /**
         * Get the variables that a given AST node defines. The gotten variables' `def[].node`/`def[].parent` property is the node.
         * If the node does not define any variable, this returns an empty array.
         * @param node An AST node to get their variables.
         * @public
         */
        getDeclaredVariables(node) {
            var _a;
            return (_a = this.declaredVariables.get(node)) !== null && _a !== void 0 ? _a : [];
        }
        /**
         * Get the scope of a given AST node. The gotten scope's `block` property is the node.
         * This method never returns `function-expression-name` scope. If the node does not have their scope, this returns `null`.
         *
         * @param node An AST node to get their scope.
         * @param inner If the node has multiple scopes, this returns the outermost scope normally.
         *                If `inner` is `true` then this returns the innermost scope.
         * @public
         */
        acquire(node, inner = false) {
            var _a;
            function predicate(testScope) {
                if (testScope.type === 'function' && testScope.functionExpressionScope) {
                    return false;
                }
                return true;
            }
            const scopes = this.nodeToScope.get(node);
            if (!scopes || scopes.length === 0) {
                return null;
            }
            // Heuristic selection from all scopes.
            // If you would like to get all scopes, please use ScopeManager#acquireAll.
            if (scopes.length === 1) {
                return scopes[0];
            }
            if (inner) {
                for (let i = scopes.length - 1; i >= 0; --i) {
                    const scope = scopes[i];
                    if (predicate(scope)) {
                        return scope;
                    }
                }
                return null;
            }
            return (_a = scopes.find(predicate)) !== null && _a !== void 0 ? _a : null;
        }
        nestScope(scope) {
            if (scope instanceof scope_1.GlobalScope) {
                (0, assert_1.assert)(this.currentScope == null);
                this.globalScope = scope;
            }
            this.currentScope = scope;
            return scope;
        }
        nestBlockScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.BlockScope(this, this.currentScope, node));
        }
        nestCatchScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.CatchScope(this, this.currentScope, node));
        }
        nestClassScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.ClassScope(this, this.currentScope, node));
        }
        nestClassFieldInitializerScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new ClassFieldInitializerScope_1.ClassFieldInitializerScope(this, this.currentScope, node));
        }
        nestClassStaticBlockScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new ClassStaticBlockScope_1.ClassStaticBlockScope(this, this.currentScope, node));
        }
        nestConditionalTypeScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.ConditionalTypeScope(this, this.currentScope, node));
        }
        nestForScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.ForScope(this, this.currentScope, node));
        }
        nestFunctionExpressionNameScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.FunctionExpressionNameScope(this, this.currentScope, node));
        }
        nestFunctionScope(node, isMethodDefinition) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.FunctionScope(this, this.currentScope, node, isMethodDefinition));
        }
        nestFunctionTypeScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.FunctionTypeScope(this, this.currentScope, node));
        }
        nestGlobalScope(node) {
            return this.nestScope(new scope_1.GlobalScope(this, node));
        }
        nestMappedTypeScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.MappedTypeScope(this, this.currentScope, node));
        }
        nestModuleScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.ModuleScope(this, this.currentScope, node));
        }
        nestSwitchScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.SwitchScope(this, this.currentScope, node));
        }
        nestTSEnumScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.TSEnumScope(this, this.currentScope, node));
        }
        nestTSModuleScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.TSModuleScope(this, this.currentScope, node));
        }
        nestTypeScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.TypeScope(this, this.currentScope, node));
        }
        nestWithScope(node) {
            (0, assert_1.assert)(this.currentScope);
            return this.nestScope(new scope_1.WithScope(this, this.currentScope, node));
        }
    }
    exports.ScopeManager = ScopeManager;
    _ScopeManager_options = new WeakMap();
    
},
/* @typescript-eslint/scope-manager/dist/scope/ClassStaticBlockScope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ClassStaticBlockScope = void 0;
    const ScopeBase_1 = require(975) /* ./ScopeBase */;
    const ScopeType_1 = require(982) /* ./ScopeType */;
    class ClassStaticBlockScope extends ScopeBase_1.ScopeBase {
        constructor(scopeManager, upperScope, block) {
            super(scopeManager, ScopeType_1.ScopeType.classStaticBlock, upperScope, block, false);
        }
    }
    exports.ClassStaticBlockScope = ClassStaticBlockScope;
    
},
/* @typescript-eslint/utils/dist/ts-eslint/SourceCode.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /* eslint-disable @typescript-eslint/no-namespace */
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.SourceCode = void 0;
    const eslint_1 = require(216) /* eslint */;
    class SourceCode extends eslint_1.SourceCode {
    }
    exports.SourceCode = SourceCode;
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.version = void 0;
    const eslint_scope_1 = require(291) /* eslint-scope */;
    __exportStar(require(1009) /* ./analyze */, exports);
    __exportStar(require(1010) /* ./Definition */, exports);
    __exportStar(require(1011) /* ./Options */, exports);
    __exportStar(require(1012) /* ./PatternVisitor */, exports);
    __exportStar(require(1013) /* ./Reference */, exports);
    __exportStar(require(1014) /* ./Referencer */, exports);
    __exportStar(require(1015) /* ./Scope */, exports);
    __exportStar(require(1016) /* ./ScopeManager */, exports);
    __exportStar(require(1017) /* ./Variable */, exports);
    exports.version = eslint_scope_1.version;
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/analyze.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.analyze = void 0;
    const eslint_scope_1 = require(291) /* eslint-scope */;
    const analyze = eslint_scope_1.analyze;
    exports.analyze = analyze;
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/Definition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ParameterDefinition = exports.Definition = void 0;
    const definition_1 = require(298) /* eslint-scope/lib/definition */;
    const Definition = definition_1.Definition;
    exports.Definition = Definition;
    const ParameterDefinition = definition_1.ParameterDefinition;
    exports.ParameterDefinition = ParameterDefinition;
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/Options.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/PatternVisitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.PatternVisitor = void 0;
    const pattern_visitor_1 = __importDefault(require(302) /* eslint-scope/lib/pattern-visitor */);
    const PatternVisitor = pattern_visitor_1.default;
    exports.PatternVisitor = PatternVisitor;
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/Reference.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Reference = void 0;
    const reference_1 = __importDefault(require(296) /* eslint-scope/lib/reference */);
    const Reference = reference_1.default;
    exports.Reference = Reference;
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/Referencer.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Referencer = void 0;
    /* eslint-disable @typescript-eslint/no-explicit-any */
    const referencer_1 = __importDefault(require(299) /* eslint-scope/lib/referencer */);
    const Referencer = referencer_1.default;
    exports.Referencer = Referencer;
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/Scope.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /* eslint-disable @typescript-eslint/no-empty-interface, @typescript-eslint/no-explicit-any */
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ClassScope = exports.ForScope = exports.FunctionScope = exports.SwitchScope = exports.BlockScope = exports.WithScope = exports.CatchScope = exports.FunctionExpressionNameScope = exports.ModuleScope = exports.GlobalScope = exports.Scope = void 0;
    const scope_1 = require(293) /* eslint-scope/lib/scope */;
    const Scope = scope_1.Scope;
    exports.Scope = Scope;
    const GlobalScope = scope_1.GlobalScope;
    exports.GlobalScope = GlobalScope;
    const ModuleScope = scope_1.ModuleScope;
    exports.ModuleScope = ModuleScope;
    const FunctionExpressionNameScope = scope_1.FunctionExpressionNameScope;
    exports.FunctionExpressionNameScope = FunctionExpressionNameScope;
    const CatchScope = scope_1.CatchScope;
    exports.CatchScope = CatchScope;
    const WithScope = scope_1.WithScope;
    exports.WithScope = WithScope;
    const BlockScope = scope_1.BlockScope;
    exports.BlockScope = BlockScope;
    const SwitchScope = scope_1.SwitchScope;
    exports.SwitchScope = SwitchScope;
    const FunctionScope = scope_1.FunctionScope;
    exports.FunctionScope = FunctionScope;
    const ForScope = scope_1.ForScope;
    exports.ForScope = ForScope;
    const ClassScope = scope_1.ClassScope;
    exports.ClassScope = ClassScope;
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/ScopeManager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ScopeManager = void 0;
    const scope_manager_1 = __importDefault(require(292) /* eslint-scope/lib/scope-manager */);
    const ScopeManager = scope_manager_1.default;
    exports.ScopeManager = ScopeManager;
    
},
/* @typescript-eslint/utils/dist/ts-eslint-scope/Variable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Variable = void 0;
    const variable_1 = __importDefault(require(297) /* eslint-scope/lib/variable */);
    const Variable = variable_1.default;
    exports.Variable = Variable;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.NullThrowsReasons = exports.nullThrows = exports.getParserServices = exports.isObjectNotArray = exports.deepMerge = exports.applyDefault = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    __exportStar(require(1019) /* ./astUtils */, exports);
    __exportStar(require(1021) /* ./collectUnusedVariables */, exports);
    __exportStar(require(1022) /* ./createRule */, exports);
    __exportStar(require(1023) /* ./getFunctionHeadLoc */, exports);
    __exportStar(require(1024) /* ./getOperatorPrecedence */, exports);
    __exportStar(require(1025) /* ./getStringLength */, exports);
    __exportStar(require(1026) /* ./getThisExpression */, exports);
    __exportStar(require(1027) /* ./getWrappingFixer */, exports);
    __exportStar(require(1028) /* ./isNodeEqual */, exports);
    __exportStar(require(1029) /* ./isNullLiteral */, exports);
    __exportStar(require(1030) /* ./isUndefinedIdentifier */, exports);
    __exportStar(require(1031) /* ./misc */, exports);
    __exportStar(require(1148) /* ./objectIterators */, exports);
    // this is done for convenience - saves migrating all of the old rules
    __exportStar(require(1032) /* @typescript-eslint/type-utils */, exports);
    const { applyDefault, deepMerge, isObjectNotArray, getParserServices, nullThrows, NullThrowsReasons, } = utils_1.ESLintUtils;
    exports.applyDefault = applyDefault;
    exports.deepMerge = deepMerge;
    exports.isObjectNotArray = isObjectNotArray;
    exports.getParserServices = getParserServices;
    exports.nullThrows = nullThrows;
    exports.NullThrowsReasons = NullThrowsReasons;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/astUtils.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.forEachReturnStatement = exports.getNameLocationInGlobalDirectiveComment = void 0;
    const ts = __importStar(require(21) /* typescript */);
    const escapeRegExp_1 = require(1020) /* ./escapeRegExp */;
    // deeply re-export, for convenience
    __exportStar(require(778) /* @typescript-eslint/utils/dist/ast-utils */, exports);
    // The following is copied from `eslint`'s source code since it doesn't exist in eslint@5.
    // https://github.com/eslint/eslint/blob/145aec1ab9052fbca96a44d04927c595951b1536/lib/rules/utils/ast-utils.js#L1751-L1779
    // Could be export { getNameLocationInGlobalDirectiveComment } from 'eslint/lib/rules/utils/ast-utils'
    /**
     * Get the `loc` object of a given name in a `/*globals` directive comment.
     * @param {SourceCode} sourceCode The source code to convert index to loc.
     * @param {Comment} comment The `/*globals` directive comment which include the name.
     * @param {string} name The name to find.
     * @returns {SourceLocation} The `loc` object.
     */
    function getNameLocationInGlobalDirectiveComment(sourceCode, comment, name) {
        const namePattern = new RegExp(`[\\s,]${(0, escapeRegExp_1.escapeRegExp)(name)}(?:$|[\\s,:])`, 'gu');
        // To ignore the first text "global".
        namePattern.lastIndex = comment.value.indexOf('global') + 6;
        // Search a given variable name.
        const match = namePattern.exec(comment.value);
        // Convert the index to loc.
        const start = sourceCode.getLocFromIndex(comment.range[0] + '/*'.length + (match ? match.index + 1 : 0));
        const end = {
            line: start.line,
            column: start.column + (match ? name.length : 1),
        };
        return { start, end };
    }
    exports.getNameLocationInGlobalDirectiveComment = getNameLocationInGlobalDirectiveComment;
    // Copied from typescript https://github.com/microsoft/TypeScript/blob/42b0e3c4630c129ca39ce0df9fff5f0d1b4dd348/src/compiler/utilities.ts#L1335
    // Warning: This has the same semantics as the forEach family of functions,
    //          in that traversal terminates in the event that 'visitor' supplies a truthy value.
    function forEachReturnStatement(body, visitor) {
        return traverse(body);
        function traverse(node) {
            switch (node.kind) {
                case ts.SyntaxKind.ReturnStatement:
                    return visitor(node);
                case ts.SyntaxKind.CaseBlock:
                case ts.SyntaxKind.Block:
                case ts.SyntaxKind.IfStatement:
                case ts.SyntaxKind.DoStatement:
                case ts.SyntaxKind.WhileStatement:
                case ts.SyntaxKind.ForStatement:
                case ts.SyntaxKind.ForInStatement:
                case ts.SyntaxKind.ForOfStatement:
                case ts.SyntaxKind.WithStatement:
                case ts.SyntaxKind.SwitchStatement:
                case ts.SyntaxKind.CaseClause:
                case ts.SyntaxKind.DefaultClause:
                case ts.SyntaxKind.LabeledStatement:
                case ts.SyntaxKind.TryStatement:
                case ts.SyntaxKind.CatchClause:
                    return ts.forEachChild(node, traverse);
            }
            return undefined;
        }
    }
    exports.forEachReturnStatement = forEachReturnStatement;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/escapeRegExp.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.escapeRegExp = void 0;
    /**
     * Lodash <https://lodash.com/>
     * Released under MIT license <https://lodash.com/license>
     */
    const reRegExpChar = /[\\^$.*+?()[\]{}|]/g;
    const reHasRegExpChar = RegExp(reRegExpChar.source);
    function escapeRegExp(string = '') {
        return string && reHasRegExpChar.test(string)
            ? string.replace(reRegExpChar, '\\$&')
            : string;
    }
    exports.escapeRegExp = escapeRegExp;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/collectUnusedVariables.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _UnusedVarsVisitor_scopeManager;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.collectUnusedVariables = void 0;
    const scope_manager_1 = require(861) /* @typescript-eslint/scope-manager */;
    const Visitor_1 = require(1000) /* @typescript-eslint/scope-manager/dist/referencer/Visitor */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    class UnusedVarsVisitor extends Visitor_1.Visitor {
        // readonly #unusedVariables = new Set<TSESLint.Scope.Variable>();
        constructor(context) {
            super({
                visitChildrenEvenIfSelectorExists: true,
            });
            _UnusedVarsVisitor_scopeManager.set(this, void 0);
            //#endregion HELPERS
            //#region VISITORS
            // NOTE - This is a simple visitor - meaning it does not support selectors
            this.ClassDeclaration = this.visitClass;
            this.ClassExpression = this.visitClass;
            this.FunctionDeclaration = this.visitFunction;
            this.FunctionExpression = this.visitFunction;
            this.MethodDefinition = this.visitSetter;
            this.Property = this.visitSetter;
            this.TSCallSignatureDeclaration = this.visitFunctionTypeSignature;
            this.TSConstructorType = this.visitFunctionTypeSignature;
            this.TSConstructSignatureDeclaration = this.visitFunctionTypeSignature;
            this.TSDeclareFunction = this.visitFunctionTypeSignature;
            this.TSEmptyBodyFunctionExpression = this.visitFunctionTypeSignature;
            this.TSFunctionType = this.visitFunctionTypeSignature;
            this.TSMethodSignature = this.visitFunctionTypeSignature;
            __classPrivateFieldSet(this, _UnusedVarsVisitor_scopeManager, utils_1.ESLintUtils.nullThrows(context.getSourceCode().scopeManager, 'Missing required scope manager'), "f");
        }
        static collectUnusedVariables(context) {
            const program = context.getSourceCode().ast;
            const cached = this.RESULTS_CACHE.get(program);
            if (cached) {
                return cached;
            }
            const visitor = new this(context);
            visitor.visit(program);
            const unusedVars = visitor.collectUnusedVariables(visitor.getScope(program));
            this.RESULTS_CACHE.set(program, unusedVars);
            return unusedVars;
        }
        collectUnusedVariables(scope, unusedVariables = new Set()) {
            for (const variable of scope.variables) {
                if (
                // skip function expression names,
                scope.functionExpressionScope ||
                    // variables marked with markVariableAsUsed(),
                    variable.eslintUsed ||
                    // implicit lib variables (from @typescript-eslint/scope-manager),
                    variable instanceof scope_manager_1.ImplicitLibVariable ||
                    // basic exported variables
                    isExported(variable) ||
                    // variables implicitly exported via a merged declaration
                    isMergableExported(variable) ||
                    // used variables
                    isUsedVariable(variable)) {
                    continue;
                }
                unusedVariables.add(variable);
            }
            for (const childScope of scope.childScopes) {
                this.collectUnusedVariables(childScope, unusedVariables);
            }
            return unusedVariables;
        }
        //#region HELPERS
        getScope(currentNode) {
            // On Program node, get the outermost scope to avoid return Node.js special function scope or ES modules scope.
            const inner = currentNode.type !== utils_1.AST_NODE_TYPES.Program;
            let node = currentNode;
            while (node) {
                const scope = __classPrivateFieldGet(this, _UnusedVarsVisitor_scopeManager, "f").acquire(node, inner);
                if (scope) {
                    if (scope.type === 'function-expression-name') {
                        return scope.childScopes[0];
                    }
                    return scope;
                }
                node = node.parent;
            }
            return __classPrivateFieldGet(this, _UnusedVarsVisitor_scopeManager, "f").scopes[0];
        }
        markVariableAsUsed(variableOrIdentifierOrName, parent) {
            if (typeof variableOrIdentifierOrName !== 'string' &&
                !('type' in variableOrIdentifierOrName)) {
                variableOrIdentifierOrName.eslintUsed = true;
                return;
            }
            let name;
            let node;
            if (typeof variableOrIdentifierOrName === 'string') {
                name = variableOrIdentifierOrName;
                node = parent;
            }
            else {
                name = variableOrIdentifierOrName.name;
                node = variableOrIdentifierOrName;
            }
            let currentScope = this.getScope(node);
            while (currentScope) {
                const variable = currentScope.variables.find(scopeVar => scopeVar.name === name);
                if (variable) {
                    variable.eslintUsed = true;
                    return;
                }
                currentScope = currentScope.upper;
            }
        }
        visitClass(node) {
            // skip a variable of class itself name in the class scope
            const scope = this.getScope(node);
            for (const variable of scope.variables) {
                if (variable.identifiers[0] === scope.block.id) {
                    this.markVariableAsUsed(variable);
                    return;
                }
            }
        }
        visitFunction(node) {
            const scope = this.getScope(node);
            // skip implicit "arguments" variable
            const variable = scope.set.get('arguments');
            if ((variable === null || variable === void 0 ? void 0 : variable.defs.length) === 0) {
                this.markVariableAsUsed(variable);
            }
        }
        visitFunctionTypeSignature(node) {
            // function type signature params create variables because they can be referenced within the signature,
            // but they obviously aren't unused variables for the purposes of this rule.
            for (const param of node.params) {
                this.visitPattern(param, name => {
                    this.markVariableAsUsed(name);
                });
            }
        }
        visitSetter(node) {
            if (node.kind === 'set') {
                // ignore setter parameters because they're syntactically required to exist
                for (const param of node.value.params) {
                    this.visitPattern(param, id => {
                        this.markVariableAsUsed(id);
                    });
                }
            }
        }
        ForInStatement(node) {
            /**
             * (Brad Zacher): I hate that this has to exist.
             * But it is required for compat with the base ESLint rule.
             *
             * In 2015, ESLint decided to add an exception for these two specific cases
             * ```
             * for (var key in object) return;
             *
             * var key;
             * for (key in object) return;
             * ```
             *
             * I disagree with it, but what are you going to do...
             *
             * https://github.com/eslint/eslint/issues/2342
             */
            let idOrVariable;
            if (node.left.type === utils_1.AST_NODE_TYPES.VariableDeclaration) {
                const variable = __classPrivateFieldGet(this, _UnusedVarsVisitor_scopeManager, "f").getDeclaredVariables(node.left)[0];
                if (!variable) {
                    return;
                }
                idOrVariable = variable;
            }
            if (node.left.type === utils_1.AST_NODE_TYPES.Identifier) {
                idOrVariable = node.left;
            }
            if (idOrVariable == null) {
                return;
            }
            let body = node.body;
            if (node.body.type === utils_1.AST_NODE_TYPES.BlockStatement) {
                if (node.body.body.length !== 1) {
                    return;
                }
                body = node.body.body[0];
            }
            if (body.type !== utils_1.AST_NODE_TYPES.ReturnStatement) {
                return;
            }
            this.markVariableAsUsed(idOrVariable);
        }
        Identifier(node) {
            const scope = this.getScope(node);
            if (scope.type === utils_1.TSESLint.Scope.ScopeType.function &&
                node.name === 'this') {
                // this parameters should always be considered used as they're pseudo-parameters
                if ('params' in scope.block && scope.block.params.includes(node)) {
                    this.markVariableAsUsed(node);
                }
            }
        }
        TSEnumDeclaration(node) {
            // enum members create variables because they can be referenced within the enum,
            // but they obviously aren't unused variables for the purposes of this rule.
            const scope = this.getScope(node);
            for (const variable of scope.variables) {
                this.markVariableAsUsed(variable);
            }
        }
        TSMappedType(node) {
            // mapped types create a variable for their type name, but it's not necessary to reference it,
            // so we shouldn't consider it as unused for the purpose of this rule.
            this.markVariableAsUsed(node.typeParameter.name);
        }
        TSModuleDeclaration(node) {
            // -- global augmentation can be in any file, and they do not need exports
            if (node.global === true) {
                this.markVariableAsUsed('global', node.parent);
            }
        }
        TSParameterProperty(node) {
            let identifier = null;
            switch (node.parameter.type) {
                case utils_1.AST_NODE_TYPES.AssignmentPattern:
                    if (node.parameter.left.type === utils_1.AST_NODE_TYPES.Identifier) {
                        identifier = node.parameter.left;
                    }
                    break;
                case utils_1.AST_NODE_TYPES.Identifier:
                    identifier = node.parameter;
                    break;
            }
            if (identifier) {
                this.markVariableAsUsed(identifier);
            }
        }
    }
    _UnusedVarsVisitor_scopeManager = new WeakMap();
    UnusedVarsVisitor.RESULTS_CACHE = new WeakMap();
    //#region private helpers
    /**
     * Checks the position of given nodes.
     * @param inner A node which is expected as inside.
     * @param outer A node which is expected as outside.
     * @returns `true` if the `inner` node exists in the `outer` node.
     */
    function isInside(inner, outer) {
        return inner.range[0] >= outer.range[0] && inner.range[1] <= outer.range[1];
    }
    /**
     * Determine if an identifier is referencing an enclosing name.
     * This only applies to declarations that create their own scope (modules, functions, classes)
     * @param ref The reference to check.
     * @param nodes The candidate function nodes.
     * @returns True if it's a self-reference, false if not.
     */
    function isSelfReference(ref, nodes) {
        let scope = ref.from;
        while (scope) {
            if (nodes.has(scope.block)) {
                return true;
            }
            scope = scope.upper;
        }
        return false;
    }
    const MERGABLE_TYPES = new Set([
        utils_1.AST_NODE_TYPES.TSInterfaceDeclaration,
        utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration,
        utils_1.AST_NODE_TYPES.TSModuleDeclaration,
        utils_1.AST_NODE_TYPES.ClassDeclaration,
        utils_1.AST_NODE_TYPES.FunctionDeclaration,
    ]);
    /**
     * Determine if the variable is directly exported
     * @param variable the variable to check
     * @param target the type of node that is expected to be exported
     */
    function isMergableExported(variable) {
        var _a, _b;
        // If all of the merged things are of the same type, TS will error if not all of them are exported - so we only need to find one
        for (const def of variable.defs) {
            // parameters can never be exported.
            // their `node` prop points to the function decl, which can be exported
            // so we need to special case them
            if (def.type === utils_1.TSESLint.Scope.DefinitionType.Parameter) {
                continue;
            }
            if ((MERGABLE_TYPES.has(def.node.type) &&
                ((_a = def.node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ExportNamedDeclaration) ||
                ((_b = def.node.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.ExportDefaultDeclaration) {
                return true;
            }
        }
        return false;
    }
    /**
     * Determines if a given variable is being exported from a module.
     * @param variable eslint-scope variable object.
     * @returns True if the variable is exported, false if not.
     */
    function isExported(variable) {
        const definition = variable.defs[0];
        if (definition) {
            let node = definition.node;
            if (node.type === utils_1.AST_NODE_TYPES.VariableDeclarator) {
                node = node.parent;
            }
            else if (definition.type === utils_1.TSESLint.Scope.DefinitionType.Parameter) {
                return false;
            }
            return node.parent.type.indexOf('Export') === 0;
        }
        return false;
    }
    /**
     * Determines if the variable is used.
     * @param variable The variable to check.
     * @returns True if the variable is used
     */
    function isUsedVariable(variable) {
        /**
         * Gets a list of function definitions for a specified variable.
         * @param variable eslint-scope variable object.
         * @returns Function nodes.
         */
        function getFunctionDefinitions(variable) {
            const functionDefinitions = new Set();
            variable.defs.forEach(def => {
                var _a, _b;
                // FunctionDeclarations
                if (def.type === utils_1.TSESLint.Scope.DefinitionType.FunctionName) {
                    functionDefinitions.add(def.node);
                }
                // FunctionExpressions
                if (def.type === utils_1.TSESLint.Scope.DefinitionType.Variable &&
                    (((_a = def.node.init) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.FunctionExpression ||
                        ((_b = def.node.init) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.ArrowFunctionExpression)) {
                    functionDefinitions.add(def.node.init);
                }
            });
            return functionDefinitions;
        }
        function getTypeDeclarations(variable) {
            const nodes = new Set();
            variable.defs.forEach(def => {
                if (def.node.type === utils_1.AST_NODE_TYPES.TSInterfaceDeclaration ||
                    def.node.type === utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration) {
                    nodes.add(def.node);
                }
            });
            return nodes;
        }
        function getModuleDeclarations(variable) {
            const nodes = new Set();
            variable.defs.forEach(def => {
                if (def.node.type === utils_1.AST_NODE_TYPES.TSModuleDeclaration) {
                    nodes.add(def.node);
                }
            });
            return nodes;
        }
        /**
         * Checks if the ref is contained within one of the given nodes
         */
        function isInsideOneOf(ref, nodes) {
            for (const node of nodes) {
                if (isInside(ref.identifier, node)) {
                    return true;
                }
            }
            return false;
        }
        /**
         * If a given reference is left-hand side of an assignment, this gets
         * the right-hand side node of the assignment.
         *
         * In the following cases, this returns null.
         *
         * - The reference is not the LHS of an assignment expression.
         * - The reference is inside of a loop.
         * - The reference is inside of a function scope which is different from
         *   the declaration.
         * @param ref A reference to check.
         * @param prevRhsNode The previous RHS node.
         * @returns The RHS node or null.
         */
        function getRhsNode(ref, prevRhsNode) {
            /**
             * Checks whether the given node is in a loop or not.
             * @param node The node to check.
             * @returns `true` if the node is in a loop.
             */
            function isInLoop(node) {
                let currentNode = node;
                while (currentNode) {
                    if (utils_1.ASTUtils.isFunction(currentNode)) {
                        break;
                    }
                    if (utils_1.ASTUtils.isLoop(currentNode)) {
                        return true;
                    }
                    currentNode = currentNode.parent;
                }
                return false;
            }
            const id = ref.identifier;
            const parent = id.parent;
            const grandparent = parent.parent;
            const refScope = ref.from.variableScope;
            const varScope = ref.resolved.scope.variableScope;
            const canBeUsedLater = refScope !== varScope || isInLoop(id);
            /*
             * Inherits the previous node if this reference is in the node.
             * This is for `a = a + a`-like code.
             */
            if (prevRhsNode && isInside(id, prevRhsNode)) {
                return prevRhsNode;
            }
            if (parent.type === utils_1.AST_NODE_TYPES.AssignmentExpression &&
                grandparent.type === utils_1.AST_NODE_TYPES.ExpressionStatement &&
                id === parent.left &&
                !canBeUsedLater) {
                return parent.right;
            }
            return null;
        }
        /**
         * Checks whether a given reference is a read to update itself or not.
         * @param ref A reference to check.
         * @param rhsNode The RHS node of the previous assignment.
         * @returns The reference is a read to update itself.
         */
        function isReadForItself(ref, rhsNode) {
            /**
             * Checks whether a given Identifier node exists inside of a function node which can be used later.
             *
             * "can be used later" means:
             * - the function is assigned to a variable.
             * - the function is bound to a property and the object can be used later.
             * - the function is bound as an argument of a function call.
             *
             * If a reference exists in a function which can be used later, the reference is read when the function is called.
             * @param id An Identifier node to check.
             * @param rhsNode The RHS node of the previous assignment.
             * @returns `true` if the `id` node exists inside of a function node which can be used later.
             */
            function isInsideOfStorableFunction(id, rhsNode) {
                /**
                 * Finds a function node from ancestors of a node.
                 * @param node A start node to find.
                 * @returns A found function node.
                 */
                function getUpperFunction(node) {
                    let currentNode = node;
                    while (currentNode) {
                        if (utils_1.ASTUtils.isFunction(currentNode)) {
                            return currentNode;
                        }
                        currentNode = currentNode.parent;
                    }
                    return null;
                }
                /**
                 * Checks whether a given function node is stored to somewhere or not.
                 * If the function node is stored, the function can be used later.
                 * @param funcNode A function node to check.
                 * @param rhsNode The RHS node of the previous assignment.
                 * @returns `true` if under the following conditions:
                 *      - the funcNode is assigned to a variable.
                 *      - the funcNode is bound as an argument of a function call.
                 *      - the function is bound to a property and the object satisfies above conditions.
                 */
                function isStorableFunction(funcNode, rhsNode) {
                    let node = funcNode;
                    let parent = funcNode.parent;
                    while (parent && isInside(parent, rhsNode)) {
                        switch (parent.type) {
                            case utils_1.AST_NODE_TYPES.SequenceExpression:
                                if (parent.expressions[parent.expressions.length - 1] !== node) {
                                    return false;
                                }
                                break;
                            case utils_1.AST_NODE_TYPES.CallExpression:
                            case utils_1.AST_NODE_TYPES.NewExpression:
                                return parent.callee !== node;
                            case utils_1.AST_NODE_TYPES.AssignmentExpression:
                            case utils_1.AST_NODE_TYPES.TaggedTemplateExpression:
                            case utils_1.AST_NODE_TYPES.YieldExpression:
                                return true;
                            default:
                                if (parent.type.endsWith('Statement') ||
                                    parent.type.endsWith('Declaration')) {
                                    /*
                                     * If it encountered statements, this is a complex pattern.
                                     * Since analyzing complex patterns is hard, this returns `true` to avoid false positive.
                                     */
                                    return true;
                                }
                        }
                        node = parent;
                        parent = parent.parent;
                    }
                    return false;
                }
                const funcNode = getUpperFunction(id);
                return (!!funcNode &&
                    isInside(funcNode, rhsNode) &&
                    isStorableFunction(funcNode, rhsNode));
            }
            const id = ref.identifier;
            const parent = id.parent;
            const grandparent = parent.parent;
            return (ref.isRead() && // in RHS of an assignment for itself. e.g. `a = a + 1`
                // self update. e.g. `a += 1`, `a++`
                ((parent.type === utils_1.AST_NODE_TYPES.AssignmentExpression &&
                    grandparent.type === utils_1.AST_NODE_TYPES.ExpressionStatement &&
                    parent.left === id) ||
                    (parent.type === utils_1.AST_NODE_TYPES.UpdateExpression &&
                        grandparent.type === utils_1.AST_NODE_TYPES.ExpressionStatement) ||
                    (!!rhsNode &&
                        isInside(id, rhsNode) &&
                        !isInsideOfStorableFunction(id, rhsNode))));
        }
        const functionNodes = getFunctionDefinitions(variable);
        const isFunctionDefinition = functionNodes.size > 0;
        const typeDeclNodes = getTypeDeclarations(variable);
        const isTypeDecl = typeDeclNodes.size > 0;
        const moduleDeclNodes = getModuleDeclarations(variable);
        const isModuleDecl = moduleDeclNodes.size > 0;
        let rhsNode = null;
        return variable.references.some(ref => {
            const forItself = isReadForItself(ref, rhsNode);
            rhsNode = getRhsNode(ref, rhsNode);
            return (ref.isRead() &&
                !forItself &&
                !(isFunctionDefinition && isSelfReference(ref, functionNodes)) &&
                !(isTypeDecl && isInsideOneOf(ref, typeDeclNodes)) &&
                !(isModuleDecl && isSelfReference(ref, moduleDeclNodes)));
        });
    }
    //#endregion private helpers
    /**
     * Collects the set of unused variables for a given context.
     *
     * Due to complexity, this does not take into consideration:
     * - variables within declaration files
     * - variables within ambient module declarations
     */
    function collectUnusedVariables(context) {
        return UnusedVarsVisitor.collectUnusedVariables(context);
    }
    exports.collectUnusedVariables = collectUnusedVariables;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/createRule.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createRule = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    exports.createRule = utils_1.ESLintUtils.RuleCreator(name => `https://typescript-eslint.io/rules/${name}`);
    
},
/* @typescript-eslint/eslint-plugin/dist/util/getFunctionHeadLoc.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getFunctionHeadLoc = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    /**
     * Creates a report location for the given function.
     * The location only encompasses the "start" of the function, and not the body
     *
     * eg.
     *
     * ```
     * function foo(args) {}
     * ^^^^^^^^^^^^^^^^^^
     *
     * get y(args) {}
     * ^^^^^^^^^^^
     *
     * const x = (args) => {}
     *           ^^^^^^^^^
     * ```
     */
    function getFunctionHeadLoc(node, sourceCode) {
        function getLocStart() {
            if (node.parent && node.parent.type === utils_1.AST_NODE_TYPES.MethodDefinition) {
                // return the start location for class method
                if (node.parent.decorators && node.parent.decorators.length > 0) {
                    // exclude decorators
                    return sourceCode.getTokenAfter(node.parent.decorators[node.parent.decorators.length - 1]).loc.start;
                }
                return node.parent.loc.start;
            }
            if (node.parent &&
                node.parent.type === utils_1.AST_NODE_TYPES.Property &&
                node.parent.method) {
                // return the start location for object method shorthand
                return node.parent.loc.start;
            }
            // return the start location for a regular function
            return node.loc.start;
        }
        function getLocEnd() {
            if (node.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression) {
                // find the end location for arrow function expression
                return sourceCode.getTokenBefore(node.body, token => token.type === utils_1.AST_TOKEN_TYPES.Punctuator && token.value === '=>').loc.end;
            }
            // return the end location for a regular function
            return sourceCode.getTokenBefore(node.body).loc.end;
        }
        return {
            start: getLocStart(),
            end: getLocEnd(),
        };
    }
    exports.getFunctionHeadLoc = getFunctionHeadLoc;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/getOperatorPrecedence.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getBinaryOperatorPrecedence = exports.getOperatorPrecedence = exports.OperatorPrecedence = void 0;
    const typescript_1 = require(21) /* typescript */;
    var OperatorPrecedence;
    (function (OperatorPrecedence) {
        // Expression:
        //     AssignmentExpression
        //     Expression `,` AssignmentExpression
        OperatorPrecedence[OperatorPrecedence["Comma"] = 0] = "Comma";
        // NOTE: `Spread` is higher than `Comma` due to how it is parsed in |ElementList|
        // SpreadElement:
        //     `...` AssignmentExpression
        OperatorPrecedence[OperatorPrecedence["Spread"] = 1] = "Spread";
        // AssignmentExpression:
        //     ConditionalExpression
        //     YieldExpression
        //     ArrowFunction
        //     AsyncArrowFunction
        //     LeftHandSideExpression `=` AssignmentExpression
        //     LeftHandSideExpression AssignmentOperator AssignmentExpression
        //
        // NOTE: AssignmentExpression is broken down into several precedences due to the requirements
        //       of the parenthesize rules.
        // AssignmentExpression: YieldExpression
        // YieldExpression:
        //     `yield`
        //     `yield` AssignmentExpression
        //     `yield` `*` AssignmentExpression
        OperatorPrecedence[OperatorPrecedence["Yield"] = 2] = "Yield";
        // AssignmentExpression: LeftHandSideExpression `=` AssignmentExpression
        // AssignmentExpression: LeftHandSideExpression AssignmentOperator AssignmentExpression
        // AssignmentOperator: one of
        //     `*=` `/=` `%=` `+=` `-=` `<<=` `>>=` `>>>=` `&=` `^=` `|=` `**=`
        OperatorPrecedence[OperatorPrecedence["Assignment"] = 3] = "Assignment";
        // NOTE: `Conditional` is considered higher than `Assignment` here, but in reality they have
        //       the same precedence.
        // AssignmentExpression: ConditionalExpression
        // ConditionalExpression:
        //     ShortCircuitExpression
        //     ShortCircuitExpression `?` AssignmentExpression `:` AssignmentExpression
        // ShortCircuitExpression:
        //     LogicalORExpression
        //     CoalesceExpression
        OperatorPrecedence[OperatorPrecedence["Conditional"] = 4] = "Conditional";
        // CoalesceExpression:
        //     CoalesceExpressionHead `??` BitwiseORExpression
        // CoalesceExpressionHead:
        //     CoalesceExpression
        //     BitwiseORExpression
        OperatorPrecedence[OperatorPrecedence["Coalesce"] = 4] = "Coalesce";
        // LogicalORExpression:
        //     LogicalANDExpression
        //     LogicalORExpression `||` LogicalANDExpression
        OperatorPrecedence[OperatorPrecedence["LogicalOR"] = 5] = "LogicalOR";
        // LogicalANDExpression:
        //     BitwiseORExpression
        //     LogicalANDExpression `&&` BitwiseORExpression
        OperatorPrecedence[OperatorPrecedence["LogicalAND"] = 6] = "LogicalAND";
        // BitwiseORExpression:
        //     BitwiseXORExpression
        //     BitwiseORExpression `^` BitwiseXORExpression
        OperatorPrecedence[OperatorPrecedence["BitwiseOR"] = 7] = "BitwiseOR";
        // BitwiseXORExpression:
        //     BitwiseANDExpression
        //     BitwiseXORExpression `^` BitwiseANDExpression
        OperatorPrecedence[OperatorPrecedence["BitwiseXOR"] = 8] = "BitwiseXOR";
        // BitwiseANDExpression:
        //     EqualityExpression
        //     BitwiseANDExpression `^` EqualityExpression
        OperatorPrecedence[OperatorPrecedence["BitwiseAND"] = 9] = "BitwiseAND";
        // EqualityExpression:
        //     RelationalExpression
        //     EqualityExpression `==` RelationalExpression
        //     EqualityExpression `!=` RelationalExpression
        //     EqualityExpression `===` RelationalExpression
        //     EqualityExpression `!==` RelationalExpression
        OperatorPrecedence[OperatorPrecedence["Equality"] = 10] = "Equality";
        // RelationalExpression:
        //     ShiftExpression
        //     RelationalExpression `<` ShiftExpression
        //     RelationalExpression `>` ShiftExpression
        //     RelationalExpression `<=` ShiftExpression
        //     RelationalExpression `>=` ShiftExpression
        //     RelationalExpression `instanceof` ShiftExpression
        //     RelationalExpression `in` ShiftExpression
        //     [+TypeScript] RelationalExpression `as` Type
        OperatorPrecedence[OperatorPrecedence["Relational"] = 11] = "Relational";
        // ShiftExpression:
        //     AdditiveExpression
        //     ShiftExpression `<<` AdditiveExpression
        //     ShiftExpression `>>` AdditiveExpression
        //     ShiftExpression `>>>` AdditiveExpression
        OperatorPrecedence[OperatorPrecedence["Shift"] = 12] = "Shift";
        // AdditiveExpression:
        //     MultiplicativeExpression
        //     AdditiveExpression `+` MultiplicativeExpression
        //     AdditiveExpression `-` MultiplicativeExpression
        OperatorPrecedence[OperatorPrecedence["Additive"] = 13] = "Additive";
        // MultiplicativeExpression:
        //     ExponentiationExpression
        //     MultiplicativeExpression MultiplicativeOperator ExponentiationExpression
        // MultiplicativeOperator: one of `*`, `/`, `%`
        OperatorPrecedence[OperatorPrecedence["Multiplicative"] = 14] = "Multiplicative";
        // ExponentiationExpression:
        //     UnaryExpression
        //     UpdateExpression `**` ExponentiationExpression
        OperatorPrecedence[OperatorPrecedence["Exponentiation"] = 15] = "Exponentiation";
        // UnaryExpression:
        //     UpdateExpression
        //     `delete` UnaryExpression
        //     `void` UnaryExpression
        //     `typeof` UnaryExpression
        //     `+` UnaryExpression
        //     `-` UnaryExpression
        //     `~` UnaryExpression
        //     `!` UnaryExpression
        //     AwaitExpression
        // UpdateExpression:            // TODO: Do we need to investigate the precedence here?
        //     `++` UnaryExpression
        //     `--` UnaryExpression
        OperatorPrecedence[OperatorPrecedence["Unary"] = 16] = "Unary";
        // UpdateExpression:
        //     LeftHandSideExpression
        //     LeftHandSideExpression `++`
        //     LeftHandSideExpression `--`
        OperatorPrecedence[OperatorPrecedence["Update"] = 17] = "Update";
        // LeftHandSideExpression:
        //     NewExpression
        //     CallExpression
        // NewExpression:
        //     MemberExpression
        //     `new` NewExpression
        OperatorPrecedence[OperatorPrecedence["LeftHandSide"] = 18] = "LeftHandSide";
        // CallExpression:
        //     CoverCallExpressionAndAsyncArrowHead
        //     SuperCall
        //     ImportCall
        //     CallExpression Arguments
        //     CallExpression `[` Expression `]`
        //     CallExpression `.` IdentifierName
        //     CallExpression TemplateLiteral
        // MemberExpression:
        //     PrimaryExpression
        //     MemberExpression `[` Expression `]`
        //     MemberExpression `.` IdentifierName
        //     MemberExpression TemplateLiteral
        //     SuperProperty
        //     MetaProperty
        //     `new` MemberExpression Arguments
        OperatorPrecedence[OperatorPrecedence["Member"] = 19] = "Member";
        // TODO: JSXElement?
        // PrimaryExpression:
        //     `this`
        //     IdentifierReference
        //     Literal
        //     ArrayLiteral
        //     ObjectLiteral
        //     FunctionExpression
        //     ClassExpression
        //     GeneratorExpression
        //     AsyncFunctionExpression
        //     AsyncGeneratorExpression
        //     RegularExpressionLiteral
        //     TemplateLiteral
        //     CoverParenthesizedExpressionAndArrowParameterList
        OperatorPrecedence[OperatorPrecedence["Primary"] = 20] = "Primary";
        OperatorPrecedence[OperatorPrecedence["Highest"] = 20] = "Highest";
        OperatorPrecedence[OperatorPrecedence["Lowest"] = 0] = "Lowest";
        // -1 is lower than all other precedences. Returning it will cause binary expression
        // parsing to stop.
        OperatorPrecedence[OperatorPrecedence["Invalid"] = -1] = "Invalid";
    })(OperatorPrecedence = exports.OperatorPrecedence || (exports.OperatorPrecedence = {}));
    function getOperatorPrecedence(nodeKind, operatorKind, hasArguments) {
        switch (nodeKind) {
            case typescript_1.SyntaxKind.CommaListExpression:
                return OperatorPrecedence.Comma;
            case typescript_1.SyntaxKind.SpreadElement:
                return OperatorPrecedence.Spread;
            case typescript_1.SyntaxKind.YieldExpression:
                return OperatorPrecedence.Yield;
            case typescript_1.SyntaxKind.ConditionalExpression:
                return OperatorPrecedence.Conditional;
            case typescript_1.SyntaxKind.BinaryExpression:
                switch (operatorKind) {
                    case typescript_1.SyntaxKind.CommaToken:
                        return OperatorPrecedence.Comma;
                    case typescript_1.SyntaxKind.EqualsToken:
                    case typescript_1.SyntaxKind.PlusEqualsToken:
                    case typescript_1.SyntaxKind.MinusEqualsToken:
                    case typescript_1.SyntaxKind.AsteriskAsteriskEqualsToken:
                    case typescript_1.SyntaxKind.AsteriskEqualsToken:
                    case typescript_1.SyntaxKind.SlashEqualsToken:
                    case typescript_1.SyntaxKind.PercentEqualsToken:
                    case typescript_1.SyntaxKind.LessThanLessThanEqualsToken:
                    case typescript_1.SyntaxKind.GreaterThanGreaterThanEqualsToken:
                    case typescript_1.SyntaxKind.GreaterThanGreaterThanGreaterThanEqualsToken:
                    case typescript_1.SyntaxKind.AmpersandEqualsToken:
                    case typescript_1.SyntaxKind.CaretEqualsToken:
                    case typescript_1.SyntaxKind.BarEqualsToken:
                    case typescript_1.SyntaxKind.BarBarEqualsToken:
                    case typescript_1.SyntaxKind.AmpersandAmpersandEqualsToken:
                    case typescript_1.SyntaxKind.QuestionQuestionEqualsToken:
                        return OperatorPrecedence.Assignment;
                    default:
                        return getBinaryOperatorPrecedence(operatorKind);
                }
            // TODO: Should prefix `++` and `--` be moved to the `Update` precedence?
            case typescript_1.SyntaxKind.TypeAssertionExpression:
            case typescript_1.SyntaxKind.NonNullExpression:
            case typescript_1.SyntaxKind.PrefixUnaryExpression:
            case typescript_1.SyntaxKind.TypeOfExpression:
            case typescript_1.SyntaxKind.VoidExpression:
            case typescript_1.SyntaxKind.DeleteExpression:
            case typescript_1.SyntaxKind.AwaitExpression:
                return OperatorPrecedence.Unary;
            case typescript_1.SyntaxKind.PostfixUnaryExpression:
                return OperatorPrecedence.Update;
            case typescript_1.SyntaxKind.CallExpression:
                return OperatorPrecedence.LeftHandSide;
            case typescript_1.SyntaxKind.NewExpression:
                return hasArguments
                    ? OperatorPrecedence.Member
                    : OperatorPrecedence.LeftHandSide;
            case typescript_1.SyntaxKind.TaggedTemplateExpression:
            case typescript_1.SyntaxKind.PropertyAccessExpression:
            case typescript_1.SyntaxKind.ElementAccessExpression:
            case typescript_1.SyntaxKind.MetaProperty:
                return OperatorPrecedence.Member;
            case typescript_1.SyntaxKind.AsExpression:
                return OperatorPrecedence.Relational;
            case typescript_1.SyntaxKind.ThisKeyword:
            case typescript_1.SyntaxKind.SuperKeyword:
            case typescript_1.SyntaxKind.Identifier:
            case typescript_1.SyntaxKind.PrivateIdentifier:
            case typescript_1.SyntaxKind.NullKeyword:
            case typescript_1.SyntaxKind.TrueKeyword:
            case typescript_1.SyntaxKind.FalseKeyword:
            case typescript_1.SyntaxKind.NumericLiteral:
            case typescript_1.SyntaxKind.BigIntLiteral:
            case typescript_1.SyntaxKind.StringLiteral:
            case typescript_1.SyntaxKind.ArrayLiteralExpression:
            case typescript_1.SyntaxKind.ObjectLiteralExpression:
            case typescript_1.SyntaxKind.FunctionExpression:
            case typescript_1.SyntaxKind.ArrowFunction:
            case typescript_1.SyntaxKind.ClassExpression:
            case typescript_1.SyntaxKind.RegularExpressionLiteral:
            case typescript_1.SyntaxKind.NoSubstitutionTemplateLiteral:
            case typescript_1.SyntaxKind.TemplateExpression:
            case typescript_1.SyntaxKind.ParenthesizedExpression:
            case typescript_1.SyntaxKind.OmittedExpression:
            case typescript_1.SyntaxKind.JsxElement:
            case typescript_1.SyntaxKind.JsxSelfClosingElement:
            case typescript_1.SyntaxKind.JsxFragment:
                return OperatorPrecedence.Primary;
            default:
                return OperatorPrecedence.Invalid;
        }
    }
    exports.getOperatorPrecedence = getOperatorPrecedence;
    function getBinaryOperatorPrecedence(kind) {
        switch (kind) {
            case typescript_1.SyntaxKind.QuestionQuestionToken:
                return OperatorPrecedence.Coalesce;
            case typescript_1.SyntaxKind.BarBarToken:
                return OperatorPrecedence.LogicalOR;
            case typescript_1.SyntaxKind.AmpersandAmpersandToken:
                return OperatorPrecedence.LogicalAND;
            case typescript_1.SyntaxKind.BarToken:
                return OperatorPrecedence.BitwiseOR;
            case typescript_1.SyntaxKind.CaretToken:
                return OperatorPrecedence.BitwiseXOR;
            case typescript_1.SyntaxKind.AmpersandToken:
                return OperatorPrecedence.BitwiseAND;
            case typescript_1.SyntaxKind.EqualsEqualsToken:
            case typescript_1.SyntaxKind.ExclamationEqualsToken:
            case typescript_1.SyntaxKind.EqualsEqualsEqualsToken:
            case typescript_1.SyntaxKind.ExclamationEqualsEqualsToken:
                return OperatorPrecedence.Equality;
            case typescript_1.SyntaxKind.LessThanToken:
            case typescript_1.SyntaxKind.GreaterThanToken:
            case typescript_1.SyntaxKind.LessThanEqualsToken:
            case typescript_1.SyntaxKind.GreaterThanEqualsToken:
            case typescript_1.SyntaxKind.InstanceOfKeyword:
            case typescript_1.SyntaxKind.InKeyword:
            case typescript_1.SyntaxKind.AsKeyword:
                return OperatorPrecedence.Relational;
            case typescript_1.SyntaxKind.LessThanLessThanToken:
            case typescript_1.SyntaxKind.GreaterThanGreaterThanToken:
            case typescript_1.SyntaxKind.GreaterThanGreaterThanGreaterThanToken:
                return OperatorPrecedence.Shift;
            case typescript_1.SyntaxKind.PlusToken:
            case typescript_1.SyntaxKind.MinusToken:
                return OperatorPrecedence.Additive;
            case typescript_1.SyntaxKind.AsteriskToken:
            case typescript_1.SyntaxKind.SlashToken:
            case typescript_1.SyntaxKind.PercentToken:
                return OperatorPrecedence.Multiplicative;
            case typescript_1.SyntaxKind.AsteriskAsteriskToken:
                return OperatorPrecedence.Exponentiation;
        }
        // -1 is lower than all other precedences.  Returning it will cause binary expression
        // parsing to stop.
        return -1;
    }
    exports.getBinaryOperatorPrecedence = getBinaryOperatorPrecedence;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/getStringLength.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getStringLength = void 0;
    const grapheme_splitter_1 = __importDefault(require(414) /* grapheme-splitter */);
    let splitter;
    function isASCII(value) {
        return /^[\u0020-\u007f]*$/u.test(value);
    }
    function getStringLength(value) {
        if (isASCII(value)) {
            return value.length;
        }
        splitter !== null && splitter !== void 0 ? splitter : (splitter = new grapheme_splitter_1.default());
        return splitter.countGraphemes(value);
    }
    exports.getStringLength = getStringLength;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/getThisExpression.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getThisExpression = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    function getThisExpression(node) {
        while (node) {
            if (node.type === utils_1.AST_NODE_TYPES.CallExpression) {
                node = node.callee;
            }
            else if (node.type === utils_1.AST_NODE_TYPES.ThisExpression) {
                return node;
            }
            else if (node.type === utils_1.AST_NODE_TYPES.MemberExpression) {
                node = node.object;
            }
            else if (node.type === utils_1.AST_NODE_TYPES.ChainExpression) {
                node = node.expression;
            }
            else {
                break;
            }
        }
        return;
    }
    exports.getThisExpression = getThisExpression;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/getWrappingFixer.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isStrongPrecedenceNode = exports.getWrappingFixer = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    /**
     * Wraps node with some code. Adds parenthesis as necessary.
     * @returns Fixer which adds the specified code and parens if necessary.
     */
    function getWrappingFixer(params) {
        const { sourceCode, node, innerNode = node, wrap } = params;
        const innerNodes = Array.isArray(innerNode) ? innerNode : [innerNode];
        return (fixer) => {
            const innerCodes = innerNodes.map(innerNode => {
                let code = sourceCode.getText(innerNode);
                // check the inner expression's precedence
                if (!isStrongPrecedenceNode(innerNode)) {
                    // the code we are adding might have stronger precedence than our wrapped node
                    // let's wrap our node in parens in case it has a weaker precedence than the code we are wrapping it in
                    code = `(${code})`;
                }
                return code;
            });
            // do the wrapping
            let code = wrap(...innerCodes);
            // check the outer expression's precedence
            if (isWeakPrecedenceParent(node)) {
                // we wrapped the node in some expression which very likely has a different precedence than original wrapped node
                // let's wrap the whole expression in parens just in case
                if (!utils_1.ASTUtils.isParenthesized(node, sourceCode)) {
                    code = `(${code})`;
                }
            }
            // check if we need to insert semicolon
            if (/^[`([]/.exec(code) && isMissingSemicolonBefore(node, sourceCode)) {
                code = `;${code}`;
            }
            return fixer.replaceText(node, code);
        };
    }
    exports.getWrappingFixer = getWrappingFixer;
    /**
     * Check if a node will always have the same precedence if it's parent changes.
     */
    function isStrongPrecedenceNode(innerNode) {
        return (innerNode.type === utils_1.AST_NODE_TYPES.Literal ||
            innerNode.type === utils_1.AST_NODE_TYPES.Identifier ||
            innerNode.type === utils_1.AST_NODE_TYPES.ArrayExpression ||
            innerNode.type === utils_1.AST_NODE_TYPES.ObjectExpression ||
            innerNode.type === utils_1.AST_NODE_TYPES.MemberExpression ||
            innerNode.type === utils_1.AST_NODE_TYPES.CallExpression ||
            innerNode.type === utils_1.AST_NODE_TYPES.NewExpression ||
            innerNode.type === utils_1.AST_NODE_TYPES.TaggedTemplateExpression);
    }
    exports.isStrongPrecedenceNode = isStrongPrecedenceNode;
    /**
     * Check if a node's parent could have different precedence if the node changes.
     */
    function isWeakPrecedenceParent(node) {
        const parent = node.parent;
        if (parent.type === utils_1.AST_NODE_TYPES.UpdateExpression ||
            parent.type === utils_1.AST_NODE_TYPES.UnaryExpression ||
            parent.type === utils_1.AST_NODE_TYPES.BinaryExpression ||
            parent.type === utils_1.AST_NODE_TYPES.LogicalExpression ||
            parent.type === utils_1.AST_NODE_TYPES.ConditionalExpression ||
            parent.type === utils_1.AST_NODE_TYPES.AwaitExpression) {
            return true;
        }
        if (parent.type === utils_1.AST_NODE_TYPES.MemberExpression &&
            parent.object === node) {
            return true;
        }
        if ((parent.type === utils_1.AST_NODE_TYPES.CallExpression ||
            parent.type === utils_1.AST_NODE_TYPES.NewExpression) &&
            parent.callee === node) {
            return true;
        }
        if (parent.type === utils_1.AST_NODE_TYPES.TaggedTemplateExpression &&
            parent.tag === node) {
            return true;
        }
        return false;
    }
    /**
     * Returns true if a node is at the beginning of expression statement and the statement above doesn't end with semicolon.
     * Doesn't check if the node begins with `(`, `[` or `` ` ``.
     */
    function isMissingSemicolonBefore(node, sourceCode) {
        for (;;) {
            const parent = node.parent;
            if (parent.type === utils_1.AST_NODE_TYPES.ExpressionStatement) {
                const block = parent.parent;
                if (block.type === utils_1.AST_NODE_TYPES.Program ||
                    block.type === utils_1.AST_NODE_TYPES.BlockStatement) {
                    // parent is an expression statement in a block
                    const statementIndex = block.body.indexOf(parent);
                    const previousStatement = block.body[statementIndex - 1];
                    if (statementIndex > 0 &&
                        sourceCode.getLastToken(previousStatement).value !== ';') {
                        return true;
                    }
                }
            }
            if (!isLeftHandSide(node)) {
                return false;
            }
            node = parent;
        }
    }
    /**
     * Checks if a node is LHS of an operator.
     */
    function isLeftHandSide(node) {
        const parent = node.parent;
        // a++
        if (parent.type === utils_1.AST_NODE_TYPES.UpdateExpression) {
            return true;
        }
        // a + b
        if ((parent.type === utils_1.AST_NODE_TYPES.BinaryExpression ||
            parent.type === utils_1.AST_NODE_TYPES.LogicalExpression ||
            parent.type === utils_1.AST_NODE_TYPES.AssignmentExpression) &&
            node === parent.left) {
            return true;
        }
        // a ? b : c
        if (parent.type === utils_1.AST_NODE_TYPES.ConditionalExpression &&
            node === parent.test) {
            return true;
        }
        // a(b)
        if (parent.type === utils_1.AST_NODE_TYPES.CallExpression && node === parent.callee) {
            return true;
        }
        // a`b`
        if (parent.type === utils_1.AST_NODE_TYPES.TaggedTemplateExpression &&
            node === parent.tag) {
            return true;
        }
        return false;
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/util/isNodeEqual.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isNodeEqual = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    function isNodeEqual(a, b) {
        if (a.type !== b.type) {
            return false;
        }
        if (a.type === utils_1.AST_NODE_TYPES.ThisExpression &&
            b.type === utils_1.AST_NODE_TYPES.ThisExpression) {
            return true;
        }
        if (a.type === utils_1.AST_NODE_TYPES.Literal && b.type === utils_1.AST_NODE_TYPES.Literal) {
            return a.value === b.value;
        }
        if (a.type === utils_1.AST_NODE_TYPES.Identifier &&
            b.type === utils_1.AST_NODE_TYPES.Identifier) {
            return a.name === b.name;
        }
        if (a.type === utils_1.AST_NODE_TYPES.MemberExpression &&
            b.type === utils_1.AST_NODE_TYPES.MemberExpression) {
            return (isNodeEqual(a.property, b.property) && isNodeEqual(a.object, b.object));
        }
        return false;
    }
    exports.isNodeEqual = isNodeEqual;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/isNullLiteral.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isNullLiteral = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    function isNullLiteral(i) {
        return i.type === utils_1.AST_NODE_TYPES.Literal && i.value == null;
    }
    exports.isNullLiteral = isNullLiteral;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/isUndefinedIdentifier.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isUndefinedIdentifier = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    function isUndefinedIdentifier(i) {
        return i.type === utils_1.AST_NODE_TYPES.Identifier && i.name === 'undefined';
    }
    exports.isUndefinedIdentifier = isUndefinedIdentifier;
    
},
/* @typescript-eslint/eslint-plugin/dist/util/misc.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /**
     * @fileoverview Really small utility functions that didn't deserve their own files
     */
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.findLastIndex = exports.upperCaseFirst = exports.typeNodeRequiresParentheses = exports.MemberNameType = exports.isDefinitionFile = exports.getNameFromMember = exports.getNameFromIndexSignature = exports.getEnumNames = exports.formatWordList = exports.findFirstResult = exports.arraysAreEqual = exports.arrayGroupByToMap = void 0;
    const type_utils_1 = require(1032) /* @typescript-eslint/type-utils */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const ts = __importStar(require(21) /* typescript */);
    const DEFINITION_EXTENSIONS = [
        ts.Extension.Dts,
        ts.Extension.Dcts,
        ts.Extension.Dmts,
    ];
    /**
     * Check if the context file name is *.d.ts or *.d.tsx
     */
    function isDefinitionFile(fileName) {
        const lowerFileName = fileName.toLowerCase();
        for (const definitionExt of DEFINITION_EXTENSIONS) {
            if (lowerFileName.endsWith(definitionExt)) {
                return true;
            }
        }
        return false;
    }
    exports.isDefinitionFile = isDefinitionFile;
    /**
     * Upper cases the first character or the string
     */
    function upperCaseFirst(str) {
        return str[0].toUpperCase() + str.slice(1);
    }
    exports.upperCaseFirst = upperCaseFirst;
    function arrayGroupByToMap(array, getKey) {
        const groups = new Map();
        for (const item of array) {
            const key = getKey(item);
            const existing = groups.get(key);
            if (existing) {
                existing.push(item);
            }
            else {
                groups.set(key, [item]);
            }
        }
        return groups;
    }
    exports.arrayGroupByToMap = arrayGroupByToMap;
    function arraysAreEqual(a, b, eq) {
        return (a === b ||
            (a !== undefined &&
                b !== undefined &&
                a.length === b.length &&
                a.every((x, idx) => eq(x, b[idx]))));
    }
    exports.arraysAreEqual = arraysAreEqual;
    /** Returns the first non-`undefined` result. */
    function findFirstResult(inputs, getResult) {
        for (const element of inputs) {
            const result = getResult(element);
            if (result !== undefined) {
                return result;
            }
        }
        return undefined;
    }
    exports.findFirstResult = findFirstResult;
    /**
     * Gets a string representation of the name of the index signature.
     */
    function getNameFromIndexSignature(node) {
        const propName = node.parameters.find((parameter) => parameter.type === utils_1.AST_NODE_TYPES.Identifier);
        return propName ? propName.name : '(index signature)';
    }
    exports.getNameFromIndexSignature = getNameFromIndexSignature;
    var MemberNameType;
    (function (MemberNameType) {
        MemberNameType[MemberNameType["Private"] = 1] = "Private";
        MemberNameType[MemberNameType["Quoted"] = 2] = "Quoted";
        MemberNameType[MemberNameType["Normal"] = 3] = "Normal";
        MemberNameType[MemberNameType["Expression"] = 4] = "Expression";
    })(MemberNameType || (MemberNameType = {}));
    exports.MemberNameType = MemberNameType;
    /**
     * Gets a string name representation of the name of the given MethodDefinition
     * or PropertyDefinition node, with handling for computed property names.
     */
    function getNameFromMember(member, sourceCode) {
        if (member.key.type === utils_1.AST_NODE_TYPES.Identifier) {
            return {
                type: MemberNameType.Normal,
                name: member.key.name,
            };
        }
        if (member.key.type === utils_1.AST_NODE_TYPES.PrivateIdentifier) {
            return {
                type: MemberNameType.Private,
                name: `#${member.key.name}`,
            };
        }
        if (member.key.type === utils_1.AST_NODE_TYPES.Literal) {
            const name = `${member.key.value}`;
            if ((0, type_utils_1.requiresQuoting)(name)) {
                return {
                    type: MemberNameType.Quoted,
                    name: `"${name}"`,
                };
            }
            else {
                return {
                    type: MemberNameType.Normal,
                    name,
                };
            }
        }
        return {
            type: MemberNameType.Expression,
            name: sourceCode.text.slice(...member.key.range),
        };
    }
    exports.getNameFromMember = getNameFromMember;
    function getEnumNames(myEnum) {
        return Object.keys(myEnum).filter(x => isNaN(parseInt(x)));
    }
    exports.getEnumNames = getEnumNames;
    /**
     * Given an array of words, returns an English-friendly concatenation, separated with commas, with
     * the `and` clause inserted before the last item.
     *
     * Example: ['foo', 'bar', 'baz' ] returns the string "foo, bar, and baz".
     */
    function formatWordList(words) {
        if (!(words === null || words === void 0 ? void 0 : words.length)) {
            return '';
        }
        if (words.length === 1) {
            return words[0];
        }
        return [words.slice(0, -1).join(', '), words.slice(-1)[0]].join(' and ');
    }
    exports.formatWordList = formatWordList;
    /**
     * Iterates the array in reverse and returns the index of the first element it
     * finds which passes the predicate function.
     *
     * @returns Returns the index of the element if it finds it or -1 otherwise.
     */
    function findLastIndex(members, predicate) {
        let idx = members.length - 1;
        while (idx >= 0) {
            const valid = predicate(members[idx]);
            if (valid) {
                return idx;
            }
            idx--;
        }
        return -1;
    }
    exports.findLastIndex = findLastIndex;
    function typeNodeRequiresParentheses(node, text) {
        return (node.type === utils_1.AST_NODE_TYPES.TSFunctionType ||
            node.type === utils_1.AST_NODE_TYPES.TSConstructorType ||
            node.type === utils_1.AST_NODE_TYPES.TSConditionalType ||
            (node.type === utils_1.AST_NODE_TYPES.TSUnionType && text.startsWith('|')) ||
            (node.type === utils_1.AST_NODE_TYPES.TSIntersectionType && text.startsWith('&')));
    }
    exports.typeNodeRequiresParentheses = typeNodeRequiresParentheses;
    
},
/* @typescript-eslint/type-utils/dist/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.typescriptVersionIsAtLeast = exports.getModifiers = exports.getDecorators = void 0;
    __exportStar(require(1033) /* ./containsAllTypesByName */, exports);
    __exportStar(require(1054) /* ./getConstrainedTypeAtLocation */, exports);
    __exportStar(require(1055) /* ./getContextualType */, exports);
    __exportStar(require(1056) /* ./getDeclaration */, exports);
    __exportStar(require(1057) /* ./getSourceFileOfNode */, exports);
    __exportStar(require(1058) /* ./getTokenAtPosition */, exports);
    __exportStar(require(1059) /* ./getTypeArguments */, exports);
    __exportStar(require(1060) /* ./getTypeName */, exports);
    __exportStar(require(1061) /* ./isTypeReadonly */, exports);
    __exportStar(require(1063) /* ./isUnsafeAssignment */, exports);
    __exportStar(require(1064) /* ./predicates */, exports);
    __exportStar(require(1062) /* ./propertyTypes */, exports);
    __exportStar(require(1065) /* ./requiresQuoting */, exports);
    __exportStar(require(1053) /* ./typeFlagUtils */, exports);
    var typescript_estree_1 = require(1066) /* @typescript-eslint/typescript-estree */;
    Object.defineProperty(exports, "getDecorators", { enumerable: true, get: function () { return typescript_estree_1.getDecorators; } });
    Object.defineProperty(exports, "getModifiers", { enumerable: true, get: function () { return typescript_estree_1.getModifiers; } });
    Object.defineProperty(exports, "typescriptVersionIsAtLeast", { enumerable: true, get: function () { return typescript_estree_1.typescriptVersionIsAtLeast; } });
    
},
/* @typescript-eslint/type-utils/dist/containsAllTypesByName.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.containsAllTypesByName = void 0;
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    const typeFlagUtils_1 = require(1053) /* ./typeFlagUtils */;
    /**
     * @param type Type being checked by name.
     * @param allowAny Whether to consider `any` and `unknown` to match.
     * @param allowedNames Symbol names checking on the type.
     * @param matchAnyInstead Whether to instead just check if any parts match, rather than all parts.
     * @returns Whether the type is, extends, or contains the allowed names (or all matches the allowed names, if mustMatchAll is true).
     */
    function containsAllTypesByName(type, allowAny, allowedNames, matchAnyInstead = false) {
        if ((0, typeFlagUtils_1.isTypeFlagSet)(type, ts.TypeFlags.Any | ts.TypeFlags.Unknown)) {
            return !allowAny;
        }
        if ((0, tsutils_1.isTypeReference)(type)) {
            type = type.target;
        }
        const symbol = type.getSymbol();
        if (symbol && allowedNames.has(symbol.name)) {
            return true;
        }
        const predicate = (t) => containsAllTypesByName(t, allowAny, allowedNames, matchAnyInstead);
        if ((0, tsutils_1.isUnionOrIntersectionType)(type)) {
            return matchAnyInstead
                ? type.types.some(predicate)
                : type.types.every(predicate);
        }
        const bases = type.getBaseTypes();
        return (bases !== undefined &&
            (matchAnyInstead
                ? bases.some(predicate)
                : bases.length > 0 && bases.every(predicate)));
    }
    exports.containsAllTypesByName = containsAllTypesByName;
    
},
/* tsutils/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1035) /* ./typeguard */, exports);
    tslib_1.__exportStar(require(1046) /* ./util */, exports);
    
},
/* tsutils/typeguard/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1036) /* ./node */, exports);
    tslib_1.__exportStar(require(1041) /* ./type */, exports);
    
},
/* tsutils/typeguard/node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1037) /* ./3.2/node */, exports);
    
},
/* tsutils/typeguard/3.2/node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isBigIntLiteral = void 0;
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1038) /* ../3.0/node */, exports);
    const ts = require(21) /* typescript */;
    function isBigIntLiteral(node) {
        return node.kind === ts.SyntaxKind.BigIntLiteral;
    }
    exports.isBigIntLiteral = isBigIntLiteral;
    
},
/* tsutils/typeguard/3.0/node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isSyntheticExpression = exports.isRestTypeNode = exports.isOptionalTypeNode = void 0;
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1039) /* ../2.9/node */, exports);
    const ts = require(21) /* typescript */;
    function isOptionalTypeNode(node) {
        return node.kind === ts.SyntaxKind.OptionalType;
    }
    exports.isOptionalTypeNode = isOptionalTypeNode;
    function isRestTypeNode(node) {
        return node.kind === ts.SyntaxKind.RestType;
    }
    exports.isRestTypeNode = isRestTypeNode;
    function isSyntheticExpression(node) {
        return node.kind === ts.SyntaxKind.SyntheticExpression;
    }
    exports.isSyntheticExpression = isSyntheticExpression;
    
},
/* tsutils/typeguard/2.9/node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isImportTypeNode = void 0;
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1040) /* ../2.8/node */, exports);
    const ts = require(21) /* typescript */;
    function isImportTypeNode(node) {
        return node.kind === ts.SyntaxKind.ImportType;
    }
    exports.isImportTypeNode = isImportTypeNode;
    
},
/* tsutils/typeguard/2.8/node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isExpressionStatement = exports.isExpression = exports.isExportSpecifier = exports.isExportDeclaration = exports.isExportAssignment = exports.isEnumMember = exports.isEnumDeclaration = exports.isEntityNameExpression = exports.isEntityName = exports.isEmptyStatement = exports.isElementAccessExpression = exports.isDoStatement = exports.isDeleteExpression = exports.isDefaultClause = exports.isDecorator = exports.isDebuggerStatement = exports.isComputedPropertyName = exports.isContinueStatement = exports.isConstructSignatureDeclaration = exports.isConstructorTypeNode = exports.isConstructorDeclaration = exports.isConditionalTypeNode = exports.isConditionalExpression = exports.isCommaListExpression = exports.isClassLikeDeclaration = exports.isClassExpression = exports.isClassDeclaration = exports.isCatchClause = exports.isCaseOrDefaultClause = exports.isCaseClause = exports.isCaseBlock = exports.isCallSignatureDeclaration = exports.isCallLikeExpression = exports.isCallExpression = exports.isBreakStatement = exports.isBreakOrContinueStatement = exports.isBooleanLiteral = exports.isBlockLike = exports.isBlock = exports.isBindingPattern = exports.isBindingElement = exports.isBinaryExpression = exports.isAwaitExpression = exports.isAssertionExpression = exports.isAsExpression = exports.isArrowFunction = exports.isArrayTypeNode = exports.isArrayLiteralExpression = exports.isArrayBindingPattern = exports.isAccessorDeclaration = void 0;
    exports.isNamespaceImport = exports.isNamespaceDeclaration = exports.isNamedImports = exports.isNamedExports = exports.isModuleDeclaration = exports.isModuleBlock = exports.isMethodSignature = exports.isMethodDeclaration = exports.isMetaProperty = exports.isMappedTypeNode = exports.isLiteralTypeNode = exports.isLiteralExpression = exports.isLabeledStatement = exports.isJsxText = exports.isJsxSpreadAttribute = exports.isJsxSelfClosingElement = exports.isJsxOpeningLikeElement = exports.isJsxOpeningFragment = exports.isJsxOpeningElement = exports.isJsxFragment = exports.isJsxExpression = exports.isJsxElement = exports.isJsxClosingFragment = exports.isJsxClosingElement = exports.isJsxAttributes = exports.isJsxAttributeLike = exports.isJsxAttribute = exports.isJsDoc = exports.isIterationStatement = exports.isIntersectionTypeNode = exports.isInterfaceDeclaration = exports.isInferTypeNode = exports.isIndexSignatureDeclaration = exports.isIndexedAccessTypeNode = exports.isImportSpecifier = exports.isImportEqualsDeclaration = exports.isImportDeclaration = exports.isImportClause = exports.isIfStatement = exports.isIdentifier = exports.isGetAccessorDeclaration = exports.isFunctionTypeNode = exports.isFunctionExpression = exports.isFunctionDeclaration = exports.isForStatement = exports.isForOfStatement = exports.isForInOrOfStatement = exports.isForInStatement = exports.isExternalModuleReference = exports.isExpressionWithTypeArguments = void 0;
    exports.isVariableStatement = exports.isVariableDeclaration = exports.isUnionTypeNode = exports.isTypeQueryNode = exports.isTypeReferenceNode = exports.isTypePredicateNode = exports.isTypeParameterDeclaration = exports.isTypeOperatorNode = exports.isTypeOfExpression = exports.isTypeLiteralNode = exports.isTypeAssertion = exports.isTypeAliasDeclaration = exports.isTupleTypeNode = exports.isTryStatement = exports.isThrowStatement = exports.isTextualLiteral = exports.isTemplateLiteral = exports.isTemplateExpression = exports.isTaggedTemplateExpression = exports.isSyntaxList = exports.isSwitchStatement = exports.isStringLiteral = exports.isSpreadElement = exports.isSpreadAssignment = exports.isSourceFile = exports.isSignatureDeclaration = exports.isShorthandPropertyAssignment = exports.isSetAccessorDeclaration = exports.isReturnStatement = exports.isRegularExpressionLiteral = exports.isQualifiedName = exports.isPropertySignature = exports.isPropertyDeclaration = exports.isPropertyAssignment = exports.isPropertyAccessExpression = exports.isPrefixUnaryExpression = exports.isPostfixUnaryExpression = exports.isParenthesizedTypeNode = exports.isParenthesizedExpression = exports.isParameterDeclaration = exports.isOmittedExpression = exports.isObjectLiteralExpression = exports.isObjectBindingPattern = exports.isNumericOrStringLikeLiteral = exports.isNumericLiteral = exports.isNullLiteral = exports.isNoSubstitutionTemplateLiteral = exports.isNonNullExpression = exports.isNewExpression = exports.isNamespaceExportDeclaration = void 0;
    exports.isWithStatement = exports.isWhileStatement = exports.isVoidExpression = exports.isVariableDeclarationList = void 0;
    const ts = require(21) /* typescript */;
    function isAccessorDeclaration(node) {
        return node.kind === ts.SyntaxKind.GetAccessor ||
            node.kind === ts.SyntaxKind.SetAccessor;
    }
    exports.isAccessorDeclaration = isAccessorDeclaration;
    function isArrayBindingPattern(node) {
        return node.kind === ts.SyntaxKind.ArrayBindingPattern;
    }
    exports.isArrayBindingPattern = isArrayBindingPattern;
    function isArrayLiteralExpression(node) {
        return node.kind === ts.SyntaxKind.ArrayLiteralExpression;
    }
    exports.isArrayLiteralExpression = isArrayLiteralExpression;
    function isArrayTypeNode(node) {
        return node.kind === ts.SyntaxKind.ArrayType;
    }
    exports.isArrayTypeNode = isArrayTypeNode;
    function isArrowFunction(node) {
        return node.kind === ts.SyntaxKind.ArrowFunction;
    }
    exports.isArrowFunction = isArrowFunction;
    function isAsExpression(node) {
        return node.kind === ts.SyntaxKind.AsExpression;
    }
    exports.isAsExpression = isAsExpression;
    function isAssertionExpression(node) {
        return node.kind === ts.SyntaxKind.AsExpression ||
            node.kind === ts.SyntaxKind.TypeAssertionExpression;
    }
    exports.isAssertionExpression = isAssertionExpression;
    function isAwaitExpression(node) {
        return node.kind === ts.SyntaxKind.AwaitExpression;
    }
    exports.isAwaitExpression = isAwaitExpression;
    function isBinaryExpression(node) {
        return node.kind === ts.SyntaxKind.BinaryExpression;
    }
    exports.isBinaryExpression = isBinaryExpression;
    function isBindingElement(node) {
        return node.kind === ts.SyntaxKind.BindingElement;
    }
    exports.isBindingElement = isBindingElement;
    function isBindingPattern(node) {
        return node.kind === ts.SyntaxKind.ArrayBindingPattern ||
            node.kind === ts.SyntaxKind.ObjectBindingPattern;
    }
    exports.isBindingPattern = isBindingPattern;
    function isBlock(node) {
        return node.kind === ts.SyntaxKind.Block;
    }
    exports.isBlock = isBlock;
    function isBlockLike(node) {
        return node.statements !== undefined;
    }
    exports.isBlockLike = isBlockLike;
    function isBooleanLiteral(node) {
        return node.kind === ts.SyntaxKind.TrueKeyword || node.kind === ts.SyntaxKind.FalseKeyword;
    }
    exports.isBooleanLiteral = isBooleanLiteral;
    function isBreakOrContinueStatement(node) {
        return node.kind === ts.SyntaxKind.BreakStatement ||
            node.kind === ts.SyntaxKind.ContinueStatement;
    }
    exports.isBreakOrContinueStatement = isBreakOrContinueStatement;
    function isBreakStatement(node) {
        return node.kind === ts.SyntaxKind.BreakStatement;
    }
    exports.isBreakStatement = isBreakStatement;
    function isCallExpression(node) {
        return node.kind === ts.SyntaxKind.CallExpression;
    }
    exports.isCallExpression = isCallExpression;
    function isCallLikeExpression(node) {
        switch (node.kind) {
            case ts.SyntaxKind.CallExpression:
            case ts.SyntaxKind.Decorator:
            case ts.SyntaxKind.JsxOpeningElement:
            case ts.SyntaxKind.JsxSelfClosingElement:
            case ts.SyntaxKind.NewExpression:
            case ts.SyntaxKind.TaggedTemplateExpression:
                return true;
            default:
                return false;
        }
    }
    exports.isCallLikeExpression = isCallLikeExpression;
    function isCallSignatureDeclaration(node) {
        return node.kind === ts.SyntaxKind.CallSignature;
    }
    exports.isCallSignatureDeclaration = isCallSignatureDeclaration;
    function isCaseBlock(node) {
        return node.kind === ts.SyntaxKind.CaseBlock;
    }
    exports.isCaseBlock = isCaseBlock;
    function isCaseClause(node) {
        return node.kind === ts.SyntaxKind.CaseClause;
    }
    exports.isCaseClause = isCaseClause;
    function isCaseOrDefaultClause(node) {
        return node.kind === ts.SyntaxKind.CaseClause ||
            node.kind === ts.SyntaxKind.DefaultClause;
    }
    exports.isCaseOrDefaultClause = isCaseOrDefaultClause;
    function isCatchClause(node) {
        return node.kind === ts.SyntaxKind.CatchClause;
    }
    exports.isCatchClause = isCatchClause;
    function isClassDeclaration(node) {
        return node.kind === ts.SyntaxKind.ClassDeclaration;
    }
    exports.isClassDeclaration = isClassDeclaration;
    function isClassExpression(node) {
        return node.kind === ts.SyntaxKind.ClassExpression;
    }
    exports.isClassExpression = isClassExpression;
    function isClassLikeDeclaration(node) {
        return node.kind === ts.SyntaxKind.ClassDeclaration ||
            node.kind === ts.SyntaxKind.ClassExpression;
    }
    exports.isClassLikeDeclaration = isClassLikeDeclaration;
    function isCommaListExpression(node) {
        return node.kind === ts.SyntaxKind.CommaListExpression;
    }
    exports.isCommaListExpression = isCommaListExpression;
    function isConditionalExpression(node) {
        return node.kind === ts.SyntaxKind.ConditionalExpression;
    }
    exports.isConditionalExpression = isConditionalExpression;
    function isConditionalTypeNode(node) {
        return node.kind === ts.SyntaxKind.ConditionalType;
    }
    exports.isConditionalTypeNode = isConditionalTypeNode;
    function isConstructorDeclaration(node) {
        return node.kind === ts.SyntaxKind.Constructor;
    }
    exports.isConstructorDeclaration = isConstructorDeclaration;
    function isConstructorTypeNode(node) {
        return node.kind === ts.SyntaxKind.ConstructorType;
    }
    exports.isConstructorTypeNode = isConstructorTypeNode;
    function isConstructSignatureDeclaration(node) {
        return node.kind === ts.SyntaxKind.ConstructSignature;
    }
    exports.isConstructSignatureDeclaration = isConstructSignatureDeclaration;
    function isContinueStatement(node) {
        return node.kind === ts.SyntaxKind.ContinueStatement;
    }
    exports.isContinueStatement = isContinueStatement;
    function isComputedPropertyName(node) {
        return node.kind === ts.SyntaxKind.ComputedPropertyName;
    }
    exports.isComputedPropertyName = isComputedPropertyName;
    function isDebuggerStatement(node) {
        return node.kind === ts.SyntaxKind.DebuggerStatement;
    }
    exports.isDebuggerStatement = isDebuggerStatement;
    function isDecorator(node) {
        return node.kind === ts.SyntaxKind.Decorator;
    }
    exports.isDecorator = isDecorator;
    function isDefaultClause(node) {
        return node.kind === ts.SyntaxKind.DefaultClause;
    }
    exports.isDefaultClause = isDefaultClause;
    function isDeleteExpression(node) {
        return node.kind === ts.SyntaxKind.DeleteExpression;
    }
    exports.isDeleteExpression = isDeleteExpression;
    function isDoStatement(node) {
        return node.kind === ts.SyntaxKind.DoStatement;
    }
    exports.isDoStatement = isDoStatement;
    function isElementAccessExpression(node) {
        return node.kind === ts.SyntaxKind.ElementAccessExpression;
    }
    exports.isElementAccessExpression = isElementAccessExpression;
    function isEmptyStatement(node) {
        return node.kind === ts.SyntaxKind.EmptyStatement;
    }
    exports.isEmptyStatement = isEmptyStatement;
    function isEntityName(node) {
        return node.kind === ts.SyntaxKind.Identifier || isQualifiedName(node);
    }
    exports.isEntityName = isEntityName;
    function isEntityNameExpression(node) {
        return node.kind === ts.SyntaxKind.Identifier ||
            isPropertyAccessExpression(node) && isEntityNameExpression(node.expression);
    }
    exports.isEntityNameExpression = isEntityNameExpression;
    function isEnumDeclaration(node) {
        return node.kind === ts.SyntaxKind.EnumDeclaration;
    }
    exports.isEnumDeclaration = isEnumDeclaration;
    function isEnumMember(node) {
        return node.kind === ts.SyntaxKind.EnumMember;
    }
    exports.isEnumMember = isEnumMember;
    function isExportAssignment(node) {
        return node.kind === ts.SyntaxKind.ExportAssignment;
    }
    exports.isExportAssignment = isExportAssignment;
    function isExportDeclaration(node) {
        return node.kind === ts.SyntaxKind.ExportDeclaration;
    }
    exports.isExportDeclaration = isExportDeclaration;
    function isExportSpecifier(node) {
        return node.kind === ts.SyntaxKind.ExportSpecifier;
    }
    exports.isExportSpecifier = isExportSpecifier;
    function isExpression(node) {
        switch (node.kind) {
            case ts.SyntaxKind.ArrayLiteralExpression:
            case ts.SyntaxKind.ArrowFunction:
            case ts.SyntaxKind.AsExpression:
            case ts.SyntaxKind.AwaitExpression:
            case ts.SyntaxKind.BinaryExpression:
            case ts.SyntaxKind.CallExpression:
            case ts.SyntaxKind.ClassExpression:
            case ts.SyntaxKind.CommaListExpression:
            case ts.SyntaxKind.ConditionalExpression:
            case ts.SyntaxKind.DeleteExpression:
            case ts.SyntaxKind.ElementAccessExpression:
            case ts.SyntaxKind.FalseKeyword:
            case ts.SyntaxKind.FunctionExpression:
            case ts.SyntaxKind.Identifier:
            case ts.SyntaxKind.JsxElement:
            case ts.SyntaxKind.JsxFragment:
            case ts.SyntaxKind.JsxExpression:
            case ts.SyntaxKind.JsxOpeningElement:
            case ts.SyntaxKind.JsxOpeningFragment:
            case ts.SyntaxKind.JsxSelfClosingElement:
            case ts.SyntaxKind.MetaProperty:
            case ts.SyntaxKind.NewExpression:
            case ts.SyntaxKind.NonNullExpression:
            case ts.SyntaxKind.NoSubstitutionTemplateLiteral:
            case ts.SyntaxKind.NullKeyword:
            case ts.SyntaxKind.NumericLiteral:
            case ts.SyntaxKind.ObjectLiteralExpression:
            case ts.SyntaxKind.OmittedExpression:
            case ts.SyntaxKind.ParenthesizedExpression:
            case ts.SyntaxKind.PostfixUnaryExpression:
            case ts.SyntaxKind.PrefixUnaryExpression:
            case ts.SyntaxKind.PropertyAccessExpression:
            case ts.SyntaxKind.RegularExpressionLiteral:
            case ts.SyntaxKind.SpreadElement:
            case ts.SyntaxKind.StringLiteral:
            case ts.SyntaxKind.SuperKeyword:
            case ts.SyntaxKind.TaggedTemplateExpression:
            case ts.SyntaxKind.TemplateExpression:
            case ts.SyntaxKind.ThisKeyword:
            case ts.SyntaxKind.TrueKeyword:
            case ts.SyntaxKind.TypeAssertionExpression:
            case ts.SyntaxKind.TypeOfExpression:
            case ts.SyntaxKind.VoidExpression:
            case ts.SyntaxKind.YieldExpression:
                return true;
            default:
                return false;
        }
    }
    exports.isExpression = isExpression;
    function isExpressionStatement(node) {
        return node.kind === ts.SyntaxKind.ExpressionStatement;
    }
    exports.isExpressionStatement = isExpressionStatement;
    function isExpressionWithTypeArguments(node) {
        return node.kind === ts.SyntaxKind.ExpressionWithTypeArguments;
    }
    exports.isExpressionWithTypeArguments = isExpressionWithTypeArguments;
    function isExternalModuleReference(node) {
        return node.kind === ts.SyntaxKind.ExternalModuleReference;
    }
    exports.isExternalModuleReference = isExternalModuleReference;
    function isForInStatement(node) {
        return node.kind === ts.SyntaxKind.ForInStatement;
    }
    exports.isForInStatement = isForInStatement;
    function isForInOrOfStatement(node) {
        return node.kind === ts.SyntaxKind.ForOfStatement || node.kind === ts.SyntaxKind.ForInStatement;
    }
    exports.isForInOrOfStatement = isForInOrOfStatement;
    function isForOfStatement(node) {
        return node.kind === ts.SyntaxKind.ForOfStatement;
    }
    exports.isForOfStatement = isForOfStatement;
    function isForStatement(node) {
        return node.kind === ts.SyntaxKind.ForStatement;
    }
    exports.isForStatement = isForStatement;
    function isFunctionDeclaration(node) {
        return node.kind === ts.SyntaxKind.FunctionDeclaration;
    }
    exports.isFunctionDeclaration = isFunctionDeclaration;
    function isFunctionExpression(node) {
        return node.kind === ts.SyntaxKind.FunctionExpression;
    }
    exports.isFunctionExpression = isFunctionExpression;
    function isFunctionTypeNode(node) {
        return node.kind === ts.SyntaxKind.FunctionType;
    }
    exports.isFunctionTypeNode = isFunctionTypeNode;
    function isGetAccessorDeclaration(node) {
        return node.kind === ts.SyntaxKind.GetAccessor;
    }
    exports.isGetAccessorDeclaration = isGetAccessorDeclaration;
    function isIdentifier(node) {
        return node.kind === ts.SyntaxKind.Identifier;
    }
    exports.isIdentifier = isIdentifier;
    function isIfStatement(node) {
        return node.kind === ts.SyntaxKind.IfStatement;
    }
    exports.isIfStatement = isIfStatement;
    function isImportClause(node) {
        return node.kind === ts.SyntaxKind.ImportClause;
    }
    exports.isImportClause = isImportClause;
    function isImportDeclaration(node) {
        return node.kind === ts.SyntaxKind.ImportDeclaration;
    }
    exports.isImportDeclaration = isImportDeclaration;
    function isImportEqualsDeclaration(node) {
        return node.kind === ts.SyntaxKind.ImportEqualsDeclaration;
    }
    exports.isImportEqualsDeclaration = isImportEqualsDeclaration;
    function isImportSpecifier(node) {
        return node.kind === ts.SyntaxKind.ImportSpecifier;
    }
    exports.isImportSpecifier = isImportSpecifier;
    function isIndexedAccessTypeNode(node) {
        return node.kind === ts.SyntaxKind.IndexedAccessType;
    }
    exports.isIndexedAccessTypeNode = isIndexedAccessTypeNode;
    function isIndexSignatureDeclaration(node) {
        return node.kind === ts.SyntaxKind.IndexSignature;
    }
    exports.isIndexSignatureDeclaration = isIndexSignatureDeclaration;
    function isInferTypeNode(node) {
        return node.kind === ts.SyntaxKind.InferType;
    }
    exports.isInferTypeNode = isInferTypeNode;
    function isInterfaceDeclaration(node) {
        return node.kind === ts.SyntaxKind.InterfaceDeclaration;
    }
    exports.isInterfaceDeclaration = isInterfaceDeclaration;
    function isIntersectionTypeNode(node) {
        return node.kind === ts.SyntaxKind.IntersectionType;
    }
    exports.isIntersectionTypeNode = isIntersectionTypeNode;
    function isIterationStatement(node) {
        switch (node.kind) {
            case ts.SyntaxKind.ForStatement:
            case ts.SyntaxKind.ForOfStatement:
            case ts.SyntaxKind.ForInStatement:
            case ts.SyntaxKind.WhileStatement:
            case ts.SyntaxKind.DoStatement:
                return true;
            default:
                return false;
        }
    }
    exports.isIterationStatement = isIterationStatement;
    function isJsDoc(node) {
        return node.kind === ts.SyntaxKind.JSDocComment;
    }
    exports.isJsDoc = isJsDoc;
    function isJsxAttribute(node) {
        return node.kind === ts.SyntaxKind.JsxAttribute;
    }
    exports.isJsxAttribute = isJsxAttribute;
    function isJsxAttributeLike(node) {
        return node.kind === ts.SyntaxKind.JsxAttribute ||
            node.kind === ts.SyntaxKind.JsxSpreadAttribute;
    }
    exports.isJsxAttributeLike = isJsxAttributeLike;
    function isJsxAttributes(node) {
        return node.kind === ts.SyntaxKind.JsxAttributes;
    }
    exports.isJsxAttributes = isJsxAttributes;
    function isJsxClosingElement(node) {
        return node.kind === ts.SyntaxKind.JsxClosingElement;
    }
    exports.isJsxClosingElement = isJsxClosingElement;
    function isJsxClosingFragment(node) {
        return node.kind === ts.SyntaxKind.JsxClosingFragment;
    }
    exports.isJsxClosingFragment = isJsxClosingFragment;
    function isJsxElement(node) {
        return node.kind === ts.SyntaxKind.JsxElement;
    }
    exports.isJsxElement = isJsxElement;
    function isJsxExpression(node) {
        return node.kind === ts.SyntaxKind.JsxExpression;
    }
    exports.isJsxExpression = isJsxExpression;
    function isJsxFragment(node) {
        return node.kind === ts.SyntaxKind.JsxFragment;
    }
    exports.isJsxFragment = isJsxFragment;
    function isJsxOpeningElement(node) {
        return node.kind === ts.SyntaxKind.JsxOpeningElement;
    }
    exports.isJsxOpeningElement = isJsxOpeningElement;
    function isJsxOpeningFragment(node) {
        return node.kind === ts.SyntaxKind.JsxOpeningFragment;
    }
    exports.isJsxOpeningFragment = isJsxOpeningFragment;
    function isJsxOpeningLikeElement(node) {
        return node.kind === ts.SyntaxKind.JsxOpeningElement ||
            node.kind === ts.SyntaxKind.JsxSelfClosingElement;
    }
    exports.isJsxOpeningLikeElement = isJsxOpeningLikeElement;
    function isJsxSelfClosingElement(node) {
        return node.kind === ts.SyntaxKind.JsxSelfClosingElement;
    }
    exports.isJsxSelfClosingElement = isJsxSelfClosingElement;
    function isJsxSpreadAttribute(node) {
        return node.kind === ts.SyntaxKind.JsxSpreadAttribute;
    }
    exports.isJsxSpreadAttribute = isJsxSpreadAttribute;
    function isJsxText(node) {
        return node.kind === ts.SyntaxKind.JsxText;
    }
    exports.isJsxText = isJsxText;
    function isLabeledStatement(node) {
        return node.kind === ts.SyntaxKind.LabeledStatement;
    }
    exports.isLabeledStatement = isLabeledStatement;
    function isLiteralExpression(node) {
        return node.kind >= ts.SyntaxKind.FirstLiteralToken &&
            node.kind <= ts.SyntaxKind.LastLiteralToken;
    }
    exports.isLiteralExpression = isLiteralExpression;
    function isLiteralTypeNode(node) {
        return node.kind === ts.SyntaxKind.LiteralType;
    }
    exports.isLiteralTypeNode = isLiteralTypeNode;
    function isMappedTypeNode(node) {
        return node.kind === ts.SyntaxKind.MappedType;
    }
    exports.isMappedTypeNode = isMappedTypeNode;
    function isMetaProperty(node) {
        return node.kind === ts.SyntaxKind.MetaProperty;
    }
    exports.isMetaProperty = isMetaProperty;
    function isMethodDeclaration(node) {
        return node.kind === ts.SyntaxKind.MethodDeclaration;
    }
    exports.isMethodDeclaration = isMethodDeclaration;
    function isMethodSignature(node) {
        return node.kind === ts.SyntaxKind.MethodSignature;
    }
    exports.isMethodSignature = isMethodSignature;
    function isModuleBlock(node) {
        return node.kind === ts.SyntaxKind.ModuleBlock;
    }
    exports.isModuleBlock = isModuleBlock;
    function isModuleDeclaration(node) {
        return node.kind === ts.SyntaxKind.ModuleDeclaration;
    }
    exports.isModuleDeclaration = isModuleDeclaration;
    function isNamedExports(node) {
        return node.kind === ts.SyntaxKind.NamedExports;
    }
    exports.isNamedExports = isNamedExports;
    function isNamedImports(node) {
        return node.kind === ts.SyntaxKind.NamedImports;
    }
    exports.isNamedImports = isNamedImports;
    function isNamespaceDeclaration(node) {
        return isModuleDeclaration(node) &&
            node.name.kind === ts.SyntaxKind.Identifier &&
            node.body !== undefined &&
            (node.body.kind === ts.SyntaxKind.ModuleBlock ||
                isNamespaceDeclaration(node.body));
    }
    exports.isNamespaceDeclaration = isNamespaceDeclaration;
    function isNamespaceImport(node) {
        return node.kind === ts.SyntaxKind.NamespaceImport;
    }
    exports.isNamespaceImport = isNamespaceImport;
    function isNamespaceExportDeclaration(node) {
        return node.kind === ts.SyntaxKind.NamespaceExportDeclaration;
    }
    exports.isNamespaceExportDeclaration = isNamespaceExportDeclaration;
    function isNewExpression(node) {
        return node.kind === ts.SyntaxKind.NewExpression;
    }
    exports.isNewExpression = isNewExpression;
    function isNonNullExpression(node) {
        return node.kind === ts.SyntaxKind.NonNullExpression;
    }
    exports.isNonNullExpression = isNonNullExpression;
    function isNoSubstitutionTemplateLiteral(node) {
        return node.kind === ts.SyntaxKind.NoSubstitutionTemplateLiteral;
    }
    exports.isNoSubstitutionTemplateLiteral = isNoSubstitutionTemplateLiteral;
    function isNullLiteral(node) {
        return node.kind === ts.SyntaxKind.NullKeyword;
    }
    exports.isNullLiteral = isNullLiteral;
    function isNumericLiteral(node) {
        return node.kind === ts.SyntaxKind.NumericLiteral;
    }
    exports.isNumericLiteral = isNumericLiteral;
    function isNumericOrStringLikeLiteral(node) {
        switch (node.kind) {
            case ts.SyntaxKind.StringLiteral:
            case ts.SyntaxKind.NumericLiteral:
            case ts.SyntaxKind.NoSubstitutionTemplateLiteral:
                return true;
            default:
                return false;
        }
    }
    exports.isNumericOrStringLikeLiteral = isNumericOrStringLikeLiteral;
    function isObjectBindingPattern(node) {
        return node.kind === ts.SyntaxKind.ObjectBindingPattern;
    }
    exports.isObjectBindingPattern = isObjectBindingPattern;
    function isObjectLiteralExpression(node) {
        return node.kind === ts.SyntaxKind.ObjectLiteralExpression;
    }
    exports.isObjectLiteralExpression = isObjectLiteralExpression;
    function isOmittedExpression(node) {
        return node.kind === ts.SyntaxKind.OmittedExpression;
    }
    exports.isOmittedExpression = isOmittedExpression;
    function isParameterDeclaration(node) {
        return node.kind === ts.SyntaxKind.Parameter;
    }
    exports.isParameterDeclaration = isParameterDeclaration;
    function isParenthesizedExpression(node) {
        return node.kind === ts.SyntaxKind.ParenthesizedExpression;
    }
    exports.isParenthesizedExpression = isParenthesizedExpression;
    function isParenthesizedTypeNode(node) {
        return node.kind === ts.SyntaxKind.ParenthesizedType;
    }
    exports.isParenthesizedTypeNode = isParenthesizedTypeNode;
    function isPostfixUnaryExpression(node) {
        return node.kind === ts.SyntaxKind.PostfixUnaryExpression;
    }
    exports.isPostfixUnaryExpression = isPostfixUnaryExpression;
    function isPrefixUnaryExpression(node) {
        return node.kind === ts.SyntaxKind.PrefixUnaryExpression;
    }
    exports.isPrefixUnaryExpression = isPrefixUnaryExpression;
    function isPropertyAccessExpression(node) {
        return node.kind === ts.SyntaxKind.PropertyAccessExpression;
    }
    exports.isPropertyAccessExpression = isPropertyAccessExpression;
    function isPropertyAssignment(node) {
        return node.kind === ts.SyntaxKind.PropertyAssignment;
    }
    exports.isPropertyAssignment = isPropertyAssignment;
    function isPropertyDeclaration(node) {
        return node.kind === ts.SyntaxKind.PropertyDeclaration;
    }
    exports.isPropertyDeclaration = isPropertyDeclaration;
    function isPropertySignature(node) {
        return node.kind === ts.SyntaxKind.PropertySignature;
    }
    exports.isPropertySignature = isPropertySignature;
    function isQualifiedName(node) {
        return node.kind === ts.SyntaxKind.QualifiedName;
    }
    exports.isQualifiedName = isQualifiedName;
    function isRegularExpressionLiteral(node) {
        return node.kind === ts.SyntaxKind.RegularExpressionLiteral;
    }
    exports.isRegularExpressionLiteral = isRegularExpressionLiteral;
    function isReturnStatement(node) {
        return node.kind === ts.SyntaxKind.ReturnStatement;
    }
    exports.isReturnStatement = isReturnStatement;
    function isSetAccessorDeclaration(node) {
        return node.kind === ts.SyntaxKind.SetAccessor;
    }
    exports.isSetAccessorDeclaration = isSetAccessorDeclaration;
    function isShorthandPropertyAssignment(node) {
        return node.kind === ts.SyntaxKind.ShorthandPropertyAssignment;
    }
    exports.isShorthandPropertyAssignment = isShorthandPropertyAssignment;
    function isSignatureDeclaration(node) {
        return node.parameters !== undefined;
    }
    exports.isSignatureDeclaration = isSignatureDeclaration;
    function isSourceFile(node) {
        return node.kind === ts.SyntaxKind.SourceFile;
    }
    exports.isSourceFile = isSourceFile;
    function isSpreadAssignment(node) {
        return node.kind === ts.SyntaxKind.SpreadAssignment;
    }
    exports.isSpreadAssignment = isSpreadAssignment;
    function isSpreadElement(node) {
        return node.kind === ts.SyntaxKind.SpreadElement;
    }
    exports.isSpreadElement = isSpreadElement;
    function isStringLiteral(node) {
        return node.kind === ts.SyntaxKind.StringLiteral;
    }
    exports.isStringLiteral = isStringLiteral;
    function isSwitchStatement(node) {
        return node.kind === ts.SyntaxKind.SwitchStatement;
    }
    exports.isSwitchStatement = isSwitchStatement;
    function isSyntaxList(node) {
        return node.kind === ts.SyntaxKind.SyntaxList;
    }
    exports.isSyntaxList = isSyntaxList;
    function isTaggedTemplateExpression(node) {
        return node.kind === ts.SyntaxKind.TaggedTemplateExpression;
    }
    exports.isTaggedTemplateExpression = isTaggedTemplateExpression;
    function isTemplateExpression(node) {
        return node.kind === ts.SyntaxKind.TemplateExpression;
    }
    exports.isTemplateExpression = isTemplateExpression;
    function isTemplateLiteral(node) {
        return node.kind === ts.SyntaxKind.TemplateExpression ||
            node.kind === ts.SyntaxKind.NoSubstitutionTemplateLiteral;
    }
    exports.isTemplateLiteral = isTemplateLiteral;
    function isTextualLiteral(node) {
        return node.kind === ts.SyntaxKind.StringLiteral ||
            node.kind === ts.SyntaxKind.NoSubstitutionTemplateLiteral;
    }
    exports.isTextualLiteral = isTextualLiteral;
    function isThrowStatement(node) {
        return node.kind === ts.SyntaxKind.ThrowStatement;
    }
    exports.isThrowStatement = isThrowStatement;
    function isTryStatement(node) {
        return node.kind === ts.SyntaxKind.TryStatement;
    }
    exports.isTryStatement = isTryStatement;
    function isTupleTypeNode(node) {
        return node.kind === ts.SyntaxKind.TupleType;
    }
    exports.isTupleTypeNode = isTupleTypeNode;
    function isTypeAliasDeclaration(node) {
        return node.kind === ts.SyntaxKind.TypeAliasDeclaration;
    }
    exports.isTypeAliasDeclaration = isTypeAliasDeclaration;
    function isTypeAssertion(node) {
        return node.kind === ts.SyntaxKind.TypeAssertionExpression;
    }
    exports.isTypeAssertion = isTypeAssertion;
    function isTypeLiteralNode(node) {
        return node.kind === ts.SyntaxKind.TypeLiteral;
    }
    exports.isTypeLiteralNode = isTypeLiteralNode;
    function isTypeOfExpression(node) {
        return node.kind === ts.SyntaxKind.TypeOfExpression;
    }
    exports.isTypeOfExpression = isTypeOfExpression;
    function isTypeOperatorNode(node) {
        return node.kind === ts.SyntaxKind.TypeOperator;
    }
    exports.isTypeOperatorNode = isTypeOperatorNode;
    function isTypeParameterDeclaration(node) {
        return node.kind === ts.SyntaxKind.TypeParameter;
    }
    exports.isTypeParameterDeclaration = isTypeParameterDeclaration;
    function isTypePredicateNode(node) {
        return node.kind === ts.SyntaxKind.TypePredicate;
    }
    exports.isTypePredicateNode = isTypePredicateNode;
    function isTypeReferenceNode(node) {
        return node.kind === ts.SyntaxKind.TypeReference;
    }
    exports.isTypeReferenceNode = isTypeReferenceNode;
    function isTypeQueryNode(node) {
        return node.kind === ts.SyntaxKind.TypeQuery;
    }
    exports.isTypeQueryNode = isTypeQueryNode;
    function isUnionTypeNode(node) {
        return node.kind === ts.SyntaxKind.UnionType;
    }
    exports.isUnionTypeNode = isUnionTypeNode;
    function isVariableDeclaration(node) {
        return node.kind === ts.SyntaxKind.VariableDeclaration;
    }
    exports.isVariableDeclaration = isVariableDeclaration;
    function isVariableStatement(node) {
        return node.kind === ts.SyntaxKind.VariableStatement;
    }
    exports.isVariableStatement = isVariableStatement;
    function isVariableDeclarationList(node) {
        return node.kind === ts.SyntaxKind.VariableDeclarationList;
    }
    exports.isVariableDeclarationList = isVariableDeclarationList;
    function isVoidExpression(node) {
        return node.kind === ts.SyntaxKind.VoidExpression;
    }
    exports.isVoidExpression = isVoidExpression;
    function isWhileStatement(node) {
        return node.kind === ts.SyntaxKind.WhileStatement;
    }
    exports.isWhileStatement = isWhileStatement;
    function isWithStatement(node) {
        return node.kind === ts.SyntaxKind.WithStatement;
    }
    exports.isWithStatement = isWithStatement;
    
},
/* tsutils/typeguard/type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1042) /* ./3.2/type */, exports);
    
},
/* tsutils/typeguard/3.2/type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1043) /* ../3.0/type */, exports);
    
},
/* tsutils/typeguard/3.0/type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isTupleTypeReference = exports.isTupleType = void 0;
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1044) /* ../2.9/type */, exports);
    const ts = require(21) /* typescript */;
    const type_1 = require(1044) /* ../2.9/type */;
    function isTupleType(type) {
        return (type.flags & ts.TypeFlags.Object && type.objectFlags & ts.ObjectFlags.Tuple) !== 0;
    }
    exports.isTupleType = isTupleType;
    function isTupleTypeReference(type) {
        return type_1.isTypeReference(type) && isTupleType(type.target);
    }
    exports.isTupleTypeReference = isTupleTypeReference;
    
},
/* tsutils/typeguard/2.9/type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1045) /* ../2.8/type */, exports);
    
},
/* tsutils/typeguard/2.8/type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isUniqueESSymbolType = exports.isUnionType = exports.isUnionOrIntersectionType = exports.isTypeVariable = exports.isTypeReference = exports.isTypeParameter = exports.isSubstitutionType = exports.isObjectType = exports.isLiteralType = exports.isIntersectionType = exports.isInterfaceType = exports.isInstantiableType = exports.isIndexedAccessype = exports.isIndexedAccessType = exports.isGenericType = exports.isEnumType = exports.isConditionalType = void 0;
    const ts = require(21) /* typescript */;
    function isConditionalType(type) {
        return (type.flags & ts.TypeFlags.Conditional) !== 0;
    }
    exports.isConditionalType = isConditionalType;
    function isEnumType(type) {
        return (type.flags & ts.TypeFlags.Enum) !== 0;
    }
    exports.isEnumType = isEnumType;
    function isGenericType(type) {
        return (type.flags & ts.TypeFlags.Object) !== 0 &&
            (type.objectFlags & ts.ObjectFlags.ClassOrInterface) !== 0 &&
            (type.objectFlags & ts.ObjectFlags.Reference) !== 0;
    }
    exports.isGenericType = isGenericType;
    function isIndexedAccessType(type) {
        return (type.flags & ts.TypeFlags.IndexedAccess) !== 0;
    }
    exports.isIndexedAccessType = isIndexedAccessType;
    function isIndexedAccessype(type) {
        return (type.flags & ts.TypeFlags.Index) !== 0;
    }
    exports.isIndexedAccessype = isIndexedAccessype;
    function isInstantiableType(type) {
        return (type.flags & ts.TypeFlags.Instantiable) !== 0;
    }
    exports.isInstantiableType = isInstantiableType;
    function isInterfaceType(type) {
        return (type.flags & ts.TypeFlags.Object) !== 0 &&
            (type.objectFlags & ts.ObjectFlags.ClassOrInterface) !== 0;
    }
    exports.isInterfaceType = isInterfaceType;
    function isIntersectionType(type) {
        return (type.flags & ts.TypeFlags.Intersection) !== 0;
    }
    exports.isIntersectionType = isIntersectionType;
    function isLiteralType(type) {
        return (type.flags & (ts.TypeFlags.StringOrNumberLiteral | ts.TypeFlags.BigIntLiteral)) !== 0;
    }
    exports.isLiteralType = isLiteralType;
    function isObjectType(type) {
        return (type.flags & ts.TypeFlags.Object) !== 0;
    }
    exports.isObjectType = isObjectType;
    function isSubstitutionType(type) {
        return (type.flags & ts.TypeFlags.Substitution) !== 0;
    }
    exports.isSubstitutionType = isSubstitutionType;
    function isTypeParameter(type) {
        return (type.flags & ts.TypeFlags.TypeParameter) !== 0;
    }
    exports.isTypeParameter = isTypeParameter;
    function isTypeReference(type) {
        return (type.flags & ts.TypeFlags.Object) !== 0 &&
            (type.objectFlags & ts.ObjectFlags.Reference) !== 0;
    }
    exports.isTypeReference = isTypeReference;
    function isTypeVariable(type) {
        return (type.flags & ts.TypeFlags.TypeVariable) !== 0;
    }
    exports.isTypeVariable = isTypeVariable;
    function isUnionOrIntersectionType(type) {
        return (type.flags & ts.TypeFlags.UnionOrIntersection) !== 0;
    }
    exports.isUnionOrIntersectionType = isUnionOrIntersectionType;
    function isUnionType(type) {
        return (type.flags & ts.TypeFlags.Union) !== 0;
    }
    exports.isUnionType = isUnionType;
    function isUniqueESSymbolType(type) {
        return (type.flags & ts.TypeFlags.UniqueESSymbol) !== 0;
    }
    exports.isUniqueESSymbolType = isUniqueESSymbolType;
    
},
/* tsutils/util/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1047) /* ./util */, exports);
    tslib_1.__exportStar(require(1050) /* ./usage */, exports);
    tslib_1.__exportStar(require(1051) /* ./control-flow */, exports);
    tslib_1.__exportStar(require(1049) /* ./type */, exports);
    tslib_1.__exportStar(require(1052) /* ./convert-ast */, exports);
    
},
/* tsutils/util/util.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isValidIdentifier = exports.getLineBreakStyle = exports.getLineRanges = exports.forEachComment = exports.forEachTokenWithTrivia = exports.forEachToken = exports.isFunctionWithBody = exports.hasOwnThisReference = exports.isBlockScopeBoundary = exports.isFunctionScopeBoundary = exports.isTypeScopeBoundary = exports.isScopeBoundary = exports.ScopeBoundarySelector = exports.ScopeBoundary = exports.isInSingleStatementContext = exports.isBlockScopedDeclarationStatement = exports.isBlockScopedVariableDeclaration = exports.isBlockScopedVariableDeclarationList = exports.getVariableDeclarationKind = exports.VariableDeclarationKind = exports.forEachDeclaredVariable = exports.forEachDestructuringIdentifier = exports.getPropertyName = exports.getWrappedNodeAtPosition = exports.getAstNodeAtPosition = exports.commentText = exports.isPositionInComment = exports.getCommentAtPosition = exports.getTokenAtPosition = exports.getNextToken = exports.getPreviousToken = exports.getNextStatement = exports.getPreviousStatement = exports.isModifierFlagSet = exports.isObjectFlagSet = exports.isSymbolFlagSet = exports.isTypeFlagSet = exports.isNodeFlagSet = exports.hasAccessModifier = exports.isParameterProperty = exports.hasModifier = exports.getModifier = exports.isThisParameter = exports.isKeywordKind = exports.isJsDocKind = exports.isTypeNodeKind = exports.isAssignmentKind = exports.isNodeKind = exports.isTokenKind = exports.getChildOfKind = void 0;
    exports.getBaseOfClassLikeExpression = exports.hasExhaustiveCaseClauses = exports.formatPseudoBigInt = exports.unwrapParentheses = exports.getSingleLateBoundPropertyNameOfPropertyName = exports.getLateBoundPropertyNamesOfPropertyName = exports.getLateBoundPropertyNames = exports.getPropertyNameOfWellKnownSymbol = exports.isWellKnownSymbolLiterally = exports.isBindableObjectDefinePropertyCall = exports.isReadonlyAssignmentDeclaration = exports.isInConstContext = exports.isConstAssertion = exports.getTsCheckDirective = exports.getCheckJsDirective = exports.isAmbientModule = exports.isCompilerOptionEnabled = exports.isStrictCompilerOptionEnabled = exports.getIIFE = exports.isAmbientModuleBlock = exports.isStatementInAmbientContext = exports.findImportLikeNodes = exports.findImports = exports.ImportKind = exports.parseJsDocOfNode = exports.getJsDoc = exports.canHaveJsDoc = exports.isReassignmentTarget = exports.getAccessKind = exports.AccessKind = exports.isExpressionValueUsed = exports.getDeclarationOfBindingElement = exports.hasSideEffects = exports.SideEffectOptions = exports.isSameLine = exports.isNumericPropertyName = exports.isValidJsxIdentifier = exports.isValidNumericLiteral = exports.isValidPropertyName = exports.isValidPropertyAccess = void 0;
    const ts = require(21) /* typescript */;
    const node_1 = require(1036) /* ../typeguard/node */;
    const _3_2_1 = require(1048) /* ../typeguard/3.2 */;
    const type_1 = require(1049) /* ./type */;
    function getChildOfKind(node, kind, sourceFile) {
        for (const child of node.getChildren(sourceFile))
            if (child.kind === kind)
                return child;
    }
    exports.getChildOfKind = getChildOfKind;
    function isTokenKind(kind) {
        return kind >= ts.SyntaxKind.FirstToken && kind <= ts.SyntaxKind.LastToken;
    }
    exports.isTokenKind = isTokenKind;
    function isNodeKind(kind) {
        return kind >= ts.SyntaxKind.FirstNode;
    }
    exports.isNodeKind = isNodeKind;
    function isAssignmentKind(kind) {
        return kind >= ts.SyntaxKind.FirstAssignment && kind <= ts.SyntaxKind.LastAssignment;
    }
    exports.isAssignmentKind = isAssignmentKind;
    function isTypeNodeKind(kind) {
        return kind >= ts.SyntaxKind.FirstTypeNode && kind <= ts.SyntaxKind.LastTypeNode;
    }
    exports.isTypeNodeKind = isTypeNodeKind;
    function isJsDocKind(kind) {
        return kind >= ts.SyntaxKind.FirstJSDocNode && kind <= ts.SyntaxKind.LastJSDocNode;
    }
    exports.isJsDocKind = isJsDocKind;
    function isKeywordKind(kind) {
        return kind >= ts.SyntaxKind.FirstKeyword && kind <= ts.SyntaxKind.LastKeyword;
    }
    exports.isKeywordKind = isKeywordKind;
    function isThisParameter(parameter) {
        return parameter.name.kind === ts.SyntaxKind.Identifier && parameter.name.originalKeywordKind === ts.SyntaxKind.ThisKeyword;
    }
    exports.isThisParameter = isThisParameter;
    function getModifier(node, kind) {
        if (node.modifiers !== undefined)
            for (const modifier of node.modifiers)
                if (modifier.kind === kind)
                    return modifier;
    }
    exports.getModifier = getModifier;
    function hasModifier(modifiers, ...kinds) {
        if (modifiers === undefined)
            return false;
        for (const modifier of modifiers)
            if (kinds.includes(modifier.kind))
                return true;
        return false;
    }
    exports.hasModifier = hasModifier;
    function isParameterProperty(node) {
        return hasModifier(node.modifiers, ts.SyntaxKind.PublicKeyword, ts.SyntaxKind.ProtectedKeyword, ts.SyntaxKind.PrivateKeyword, ts.SyntaxKind.ReadonlyKeyword);
    }
    exports.isParameterProperty = isParameterProperty;
    function hasAccessModifier(node) {
        return isModifierFlagSet(node, ts.ModifierFlags.AccessibilityModifier);
    }
    exports.hasAccessModifier = hasAccessModifier;
    function isFlagSet(obj, flag) {
        return (obj.flags & flag) !== 0;
    }
    exports.isNodeFlagSet = isFlagSet;
    exports.isTypeFlagSet = isFlagSet;
    exports.isSymbolFlagSet = isFlagSet;
    function isObjectFlagSet(objectType, flag) {
        return (objectType.objectFlags & flag) !== 0;
    }
    exports.isObjectFlagSet = isObjectFlagSet;
    function isModifierFlagSet(node, flag) {
        return (ts.getCombinedModifierFlags(node) & flag) !== 0;
    }
    exports.isModifierFlagSet = isModifierFlagSet;
    function getPreviousStatement(statement) {
        const parent = statement.parent;
        if (node_1.isBlockLike(parent)) {
            const index = parent.statements.indexOf(statement);
            if (index > 0)
                return parent.statements[index - 1];
        }
    }
    exports.getPreviousStatement = getPreviousStatement;
    function getNextStatement(statement) {
        const parent = statement.parent;
        if (node_1.isBlockLike(parent)) {
            const index = parent.statements.indexOf(statement);
            if (index < parent.statements.length)
                return parent.statements[index + 1];
        }
    }
    exports.getNextStatement = getNextStatement;
    /** Returns the token before the start of `node` or `undefined` if there is none. */
    function getPreviousToken(node, sourceFile) {
        const { pos } = node;
        if (pos === 0)
            return;
        do
            node = node.parent;
        while (node.pos === pos);
        return getTokenAtPositionWorker(node, pos - 1, sourceFile !== null && sourceFile !== void 0 ? sourceFile : node.getSourceFile(), false);
    }
    exports.getPreviousToken = getPreviousToken;
    /** Returns the next token that begins after the end of `node`. Returns `undefined` for SourceFile and EndOfFileToken */
    function getNextToken(node, sourceFile) {
        if (node.kind === ts.SyntaxKind.SourceFile || node.kind === ts.SyntaxKind.EndOfFileToken)
            return;
        const end = node.end;
        node = node.parent;
        while (node.end === end) {
            if (node.parent === undefined)
                return node.endOfFileToken;
            node = node.parent;
        }
        return getTokenAtPositionWorker(node, end, sourceFile !== null && sourceFile !== void 0 ? sourceFile : node.getSourceFile(), false);
    }
    exports.getNextToken = getNextToken;
    /** Returns the token at or following the specified position or undefined if none is found inside `parent`. */
    function getTokenAtPosition(parent, pos, sourceFile, allowJsDoc) {
        if (pos < parent.pos || pos >= parent.end)
            return;
        if (isTokenKind(parent.kind))
            return parent;
        return getTokenAtPositionWorker(parent, pos, sourceFile !== null && sourceFile !== void 0 ? sourceFile : parent.getSourceFile(), allowJsDoc === true);
    }
    exports.getTokenAtPosition = getTokenAtPosition;
    function getTokenAtPositionWorker(node, pos, sourceFile, allowJsDoc) {
        if (!allowJsDoc) {
            // if we are not interested in JSDoc, we can skip to the deepest AST node at the given position
            node = getAstNodeAtPosition(node, pos);
            if (isTokenKind(node.kind))
                return node;
        }
        outer: while (true) {
            for (const child of node.getChildren(sourceFile)) {
                if (child.end > pos && (allowJsDoc || child.kind !== ts.SyntaxKind.JSDocComment)) {
                    if (isTokenKind(child.kind))
                        return child;
                    // next token is nested in another node
                    node = child;
                    continue outer;
                }
            }
            return;
        }
    }
    /**
     * Return the comment at the specified position.
     * You can pass an optional `parent` to avoid some work finding the corresponding token starting at `sourceFile`.
     * If the `parent` parameter is passed, `pos` must be between `parent.pos` and `parent.end`.
    */
    function getCommentAtPosition(sourceFile, pos, parent = sourceFile) {
        const token = getTokenAtPosition(parent, pos, sourceFile);
        if (token === undefined || token.kind === ts.SyntaxKind.JsxText || pos >= token.end - (ts.tokenToString(token.kind) || '').length)
            return;
        const startPos = token.pos === 0
            ? (ts.getShebang(sourceFile.text) || '').length
            : token.pos;
        return startPos !== 0 && ts.forEachTrailingCommentRange(sourceFile.text, startPos, commentAtPositionCallback, pos) ||
            ts.forEachLeadingCommentRange(sourceFile.text, startPos, commentAtPositionCallback, pos);
    }
    exports.getCommentAtPosition = getCommentAtPosition;
    function commentAtPositionCallback(pos, end, kind, _nl, at) {
        return at >= pos && at < end ? { pos, end, kind } : undefined;
    }
    /**
     * Returns whether the specified position is inside a comment.
     * You can pass an optional `parent` to avoid some work finding the corresponding token starting at `sourceFile`.
     * If the `parent` parameter is passed, `pos` must be between `parent.pos` and `parent.end`.
     */
    function isPositionInComment(sourceFile, pos, parent) {
        return getCommentAtPosition(sourceFile, pos, parent) !== undefined;
    }
    exports.isPositionInComment = isPositionInComment;
    function commentText(sourceText, comment) {
        return sourceText.substring(comment.pos + 2, comment.kind === ts.SyntaxKind.SingleLineCommentTrivia ? comment.end : comment.end - 2);
    }
    exports.commentText = commentText;
    /** Returns the deepest AST Node at `pos`. Returns undefined if `pos` is outside of the range of `node` */
    function getAstNodeAtPosition(node, pos) {
        if (node.pos > pos || node.end <= pos)
            return;
        while (isNodeKind(node.kind)) {
            const nested = ts.forEachChild(node, (child) => child.pos <= pos && child.end > pos ? child : undefined);
            if (nested === undefined)
                break;
            node = nested;
        }
        return node;
    }
    exports.getAstNodeAtPosition = getAstNodeAtPosition;
    /**
     * Returns the NodeWrap of deepest AST node that contains `pos` between its `pos` and `end`.
     * Only returns undefined if pos is outside of `wrap`
     */
    function getWrappedNodeAtPosition(wrap, pos) {
        if (wrap.node.pos > pos || wrap.node.end <= pos)
            return;
        outer: while (true) {
            for (const child of wrap.children) {
                if (child.node.pos > pos)
                    return wrap;
                if (child.node.end > pos) {
                    wrap = child;
                    continue outer;
                }
            }
            return wrap;
        }
    }
    exports.getWrappedNodeAtPosition = getWrappedNodeAtPosition;
    function getPropertyName(propertyName) {
        if (propertyName.kind === ts.SyntaxKind.ComputedPropertyName) {
            const expression = unwrapParentheses(propertyName.expression);
            if (node_1.isPrefixUnaryExpression(expression)) {
                let negate = false;
                switch (expression.operator) {
                    case ts.SyntaxKind.MinusToken:
                        negate = true;
                    // falls through
                    case ts.SyntaxKind.PlusToken:
                        return node_1.isNumericLiteral(expression.operand)
                            ? `${negate ? '-' : ''}${expression.operand.text}`
                            : _3_2_1.isBigIntLiteral(expression.operand)
                                ? `${negate ? '-' : ''}${expression.operand.text.slice(0, -1)}`
                                : undefined;
                    default:
                        return;
                }
            }
            if (_3_2_1.isBigIntLiteral(expression))
                // handle BigInt, even though TypeScript doesn't allow BigInt as computed property name
                return expression.text.slice(0, -1);
            if (node_1.isNumericOrStringLikeLiteral(expression))
                return expression.text;
            return;
        }
        return propertyName.kind === ts.SyntaxKind.PrivateIdentifier ? undefined : propertyName.text;
    }
    exports.getPropertyName = getPropertyName;
    function forEachDestructuringIdentifier(pattern, fn) {
        for (const element of pattern.elements) {
            if (element.kind !== ts.SyntaxKind.BindingElement)
                continue;
            let result;
            if (element.name.kind === ts.SyntaxKind.Identifier) {
                result = fn(element);
            }
            else {
                result = forEachDestructuringIdentifier(element.name, fn);
            }
            if (result)
                return result;
        }
    }
    exports.forEachDestructuringIdentifier = forEachDestructuringIdentifier;
    function forEachDeclaredVariable(declarationList, cb) {
        for (const declaration of declarationList.declarations) {
            let result;
            if (declaration.name.kind === ts.SyntaxKind.Identifier) {
                result = cb(declaration);
            }
            else {
                result = forEachDestructuringIdentifier(declaration.name, cb);
            }
            if (result)
                return result;
        }
    }
    exports.forEachDeclaredVariable = forEachDeclaredVariable;
    var VariableDeclarationKind;
    (function (VariableDeclarationKind) {
        VariableDeclarationKind[VariableDeclarationKind["Var"] = 0] = "Var";
        VariableDeclarationKind[VariableDeclarationKind["Let"] = 1] = "Let";
        VariableDeclarationKind[VariableDeclarationKind["Const"] = 2] = "Const";
    })(VariableDeclarationKind = exports.VariableDeclarationKind || (exports.VariableDeclarationKind = {}));
    function getVariableDeclarationKind(declarationList) {
        if (declarationList.flags & ts.NodeFlags.Let)
            return 1 /* Let */;
        if (declarationList.flags & ts.NodeFlags.Const)
            return 2 /* Const */;
        return 0 /* Var */;
    }
    exports.getVariableDeclarationKind = getVariableDeclarationKind;
    function isBlockScopedVariableDeclarationList(declarationList) {
        return (declarationList.flags & ts.NodeFlags.BlockScoped) !== 0;
    }
    exports.isBlockScopedVariableDeclarationList = isBlockScopedVariableDeclarationList;
    function isBlockScopedVariableDeclaration(declaration) {
        const parent = declaration.parent;
        return parent.kind === ts.SyntaxKind.CatchClause ||
            isBlockScopedVariableDeclarationList(parent);
    }
    exports.isBlockScopedVariableDeclaration = isBlockScopedVariableDeclaration;
    function isBlockScopedDeclarationStatement(statement) {
        switch (statement.kind) {
            case ts.SyntaxKind.VariableStatement:
                return isBlockScopedVariableDeclarationList(statement.declarationList);
            case ts.SyntaxKind.ClassDeclaration:
            case ts.SyntaxKind.EnumDeclaration:
            case ts.SyntaxKind.InterfaceDeclaration:
            case ts.SyntaxKind.TypeAliasDeclaration:
                return true;
            default:
                return false;
        }
    }
    exports.isBlockScopedDeclarationStatement = isBlockScopedDeclarationStatement;
    function isInSingleStatementContext(statement) {
        switch (statement.parent.kind) {
            case ts.SyntaxKind.ForStatement:
            case ts.SyntaxKind.ForInStatement:
            case ts.SyntaxKind.ForOfStatement:
            case ts.SyntaxKind.WhileStatement:
            case ts.SyntaxKind.DoStatement:
            case ts.SyntaxKind.IfStatement:
            case ts.SyntaxKind.WithStatement:
            case ts.SyntaxKind.LabeledStatement:
                return true;
            default:
                return false;
        }
    }
    exports.isInSingleStatementContext = isInSingleStatementContext;
    var ScopeBoundary;
    (function (ScopeBoundary) {
        ScopeBoundary[ScopeBoundary["None"] = 0] = "None";
        ScopeBoundary[ScopeBoundary["Function"] = 1] = "Function";
        ScopeBoundary[ScopeBoundary["Block"] = 2] = "Block";
        ScopeBoundary[ScopeBoundary["Type"] = 4] = "Type";
        ScopeBoundary[ScopeBoundary["ConditionalType"] = 8] = "ConditionalType";
    })(ScopeBoundary = exports.ScopeBoundary || (exports.ScopeBoundary = {}));
    var ScopeBoundarySelector;
    (function (ScopeBoundarySelector) {
        ScopeBoundarySelector[ScopeBoundarySelector["Function"] = 1] = "Function";
        ScopeBoundarySelector[ScopeBoundarySelector["Block"] = 3] = "Block";
        ScopeBoundarySelector[ScopeBoundarySelector["Type"] = 7] = "Type";
        ScopeBoundarySelector[ScopeBoundarySelector["InferType"] = 8] = "InferType";
    })(ScopeBoundarySelector = exports.ScopeBoundarySelector || (exports.ScopeBoundarySelector = {}));
    function isScopeBoundary(node) {
        return isFunctionScopeBoundary(node) || isBlockScopeBoundary(node) || isTypeScopeBoundary(node);
    }
    exports.isScopeBoundary = isScopeBoundary;
    function isTypeScopeBoundary(node) {
        switch (node.kind) {
            case ts.SyntaxKind.InterfaceDeclaration:
            case ts.SyntaxKind.TypeAliasDeclaration:
            case ts.SyntaxKind.MappedType:
                return 4 /* Type */;
            case ts.SyntaxKind.ConditionalType:
                return 8 /* ConditionalType */;
            default:
                return 0 /* None */;
        }
    }
    exports.isTypeScopeBoundary = isTypeScopeBoundary;
    function isFunctionScopeBoundary(node) {
        switch (node.kind) {
            case ts.SyntaxKind.FunctionExpression:
            case ts.SyntaxKind.ArrowFunction:
            case ts.SyntaxKind.Constructor:
            case ts.SyntaxKind.ModuleDeclaration:
            case ts.SyntaxKind.ClassDeclaration:
            case ts.SyntaxKind.ClassExpression:
            case ts.SyntaxKind.EnumDeclaration:
            case ts.SyntaxKind.MethodDeclaration:
            case ts.SyntaxKind.FunctionDeclaration:
            case ts.SyntaxKind.GetAccessor:
            case ts.SyntaxKind.SetAccessor:
            case ts.SyntaxKind.MethodSignature:
            case ts.SyntaxKind.CallSignature:
            case ts.SyntaxKind.ConstructSignature:
            case ts.SyntaxKind.ConstructorType:
            case ts.SyntaxKind.FunctionType:
                return 1 /* Function */;
            case ts.SyntaxKind.SourceFile:
                // if SourceFile is no module, it contributes to the global scope and is therefore no scope boundary
                return ts.isExternalModule(node) ? 1 /* Function */ : 0 /* None */;
            default:
                return 0 /* None */;
        }
    }
    exports.isFunctionScopeBoundary = isFunctionScopeBoundary;
    function isBlockScopeBoundary(node) {
        switch (node.kind) {
            case ts.SyntaxKind.Block:
                const parent = node.parent;
                return parent.kind !== ts.SyntaxKind.CatchClause &&
                    // blocks inside SourceFile are block scope boundaries
                    (parent.kind === ts.SyntaxKind.SourceFile ||
                        // blocks that are direct children of a function scope boundary are no scope boundary
                        // for example the FunctionBlock is part of the function scope of the containing function
                        !isFunctionScopeBoundary(parent))
                    ? 2 /* Block */
                    : 0 /* None */;
            case ts.SyntaxKind.ForStatement:
            case ts.SyntaxKind.ForInStatement:
            case ts.SyntaxKind.ForOfStatement:
            case ts.SyntaxKind.CaseBlock:
            case ts.SyntaxKind.CatchClause:
            case ts.SyntaxKind.WithStatement:
                return 2 /* Block */;
            default:
                return 0 /* None */;
        }
    }
    exports.isBlockScopeBoundary = isBlockScopeBoundary;
    /** Returns true for scope boundaries that have their own `this` reference instead of inheriting it from the containing scope */
    function hasOwnThisReference(node) {
        switch (node.kind) {
            case ts.SyntaxKind.ClassDeclaration:
            case ts.SyntaxKind.ClassExpression:
            case ts.SyntaxKind.FunctionExpression:
                return true;
            case ts.SyntaxKind.FunctionDeclaration:
                return node.body !== undefined;
            case ts.SyntaxKind.MethodDeclaration:
            case ts.SyntaxKind.GetAccessor:
            case ts.SyntaxKind.SetAccessor:
                return node.parent.kind === ts.SyntaxKind.ObjectLiteralExpression;
            default:
                return false;
        }
    }
    exports.hasOwnThisReference = hasOwnThisReference;
    function isFunctionWithBody(node) {
        switch (node.kind) {
            case ts.SyntaxKind.GetAccessor:
            case ts.SyntaxKind.SetAccessor:
            case ts.SyntaxKind.FunctionDeclaration:
            case ts.SyntaxKind.MethodDeclaration:
            case ts.SyntaxKind.Constructor:
                return node.body !== undefined;
            case ts.SyntaxKind.FunctionExpression:
            case ts.SyntaxKind.ArrowFunction:
                return true;
            default:
                return false;
        }
    }
    exports.isFunctionWithBody = isFunctionWithBody;
    /**
     * Iterate over all tokens of `node`
     *
     * @param node The node whose tokens should be visited
     * @param cb Is called for every token contained in `node`
     */
    function forEachToken(node, cb, sourceFile = node.getSourceFile()) {
        const queue = [];
        while (true) {
            if (isTokenKind(node.kind)) {
                cb(node);
            }
            else if (node.kind !== ts.SyntaxKind.JSDocComment) {
                const children = node.getChildren(sourceFile);
                if (children.length === 1) {
                    node = children[0];
                    continue;
                }
                for (let i = children.length - 1; i >= 0; --i)
                    queue.push(children[i]); // add children in reverse order, when we pop the next element from the queue, it's the first child
            }
            if (queue.length === 0)
                break;
            node = queue.pop();
        }
    }
    exports.forEachToken = forEachToken;
    /**
     * Iterate over all tokens and trivia of `node`
     *
     * @description JsDoc comments are treated like regular comments
     *
     * @param node The node whose tokens should be visited
     * @param cb Is called for every token contained in `node` and trivia before the token
     */
    function forEachTokenWithTrivia(node, cb, sourceFile = node.getSourceFile()) {
        const fullText = sourceFile.text;
        const scanner = ts.createScanner(sourceFile.languageVersion, false, sourceFile.languageVariant, fullText);
        return forEachToken(node, (token) => {
            const tokenStart = token.kind === ts.SyntaxKind.JsxText || token.pos === token.end ? token.pos : token.getStart(sourceFile);
            if (tokenStart !== token.pos) {
                // we only have to handle trivia before each token. whitespace at the end of the file is followed by EndOfFileToken
                scanner.setTextPos(token.pos);
                let kind = scanner.scan();
                let pos = scanner.getTokenPos();
                while (pos < tokenStart) {
                    const textPos = scanner.getTextPos();
                    cb(fullText, kind, { pos, end: textPos }, token.parent);
                    if (textPos === tokenStart)
                        break;
                    kind = scanner.scan();
                    pos = scanner.getTokenPos();
                }
            }
            return cb(fullText, token.kind, { end: token.end, pos: tokenStart }, token.parent);
        }, sourceFile);
    }
    exports.forEachTokenWithTrivia = forEachTokenWithTrivia;
    /** Iterate over all comments owned by `node` or its children */
    function forEachComment(node, cb, sourceFile = node.getSourceFile()) {
        /* Visit all tokens and skip trivia.
           Comment ranges between tokens are parsed without the need of a scanner.
           forEachTokenWithWhitespace does intentionally not pay attention to the correct comment ownership of nodes as it always
           scans all trivia before each token, which could include trailing comments of the previous token.
           Comment onwership is done right in this function*/
        const fullText = sourceFile.text;
        const notJsx = sourceFile.languageVariant !== ts.LanguageVariant.JSX;
        return forEachToken(node, (token) => {
            if (token.pos === token.end)
                return;
            if (token.kind !== ts.SyntaxKind.JsxText)
                ts.forEachLeadingCommentRange(fullText, 
                // skip shebang at position 0
                token.pos === 0 ? (ts.getShebang(fullText) || '').length : token.pos, commentCallback);
            if (notJsx || canHaveTrailingTrivia(token))
                return ts.forEachTrailingCommentRange(fullText, token.end, commentCallback);
        }, sourceFile);
        function commentCallback(pos, end, kind) {
            cb(fullText, { pos, end, kind });
        }
    }
    exports.forEachComment = forEachComment;
    /** Exclude trailing positions that would lead to scanning for trivia inside JsxText */
    function canHaveTrailingTrivia(token) {
        switch (token.kind) {
            case ts.SyntaxKind.CloseBraceToken:
                // after a JsxExpression inside a JsxElement's body can only be other JsxChild, but no trivia
                return token.parent.kind !== ts.SyntaxKind.JsxExpression || !isJsxElementOrFragment(token.parent.parent);
            case ts.SyntaxKind.GreaterThanToken:
                switch (token.parent.kind) {
                    case ts.SyntaxKind.JsxOpeningElement:
                        // if end is not equal, this is part of the type arguments list. in all other cases it would be inside the element body
                        return token.end !== token.parent.end;
                    case ts.SyntaxKind.JsxOpeningFragment:
                        return false; // would be inside the fragment
                    case ts.SyntaxKind.JsxSelfClosingElement:
                        return token.end !== token.parent.end || // if end is not equal, this is part of the type arguments list
                            !isJsxElementOrFragment(token.parent.parent); // there's only trailing trivia if it's the end of the top element
                    case ts.SyntaxKind.JsxClosingElement:
                    case ts.SyntaxKind.JsxClosingFragment:
                        // there's only trailing trivia if it's the end of the top element
                        return !isJsxElementOrFragment(token.parent.parent.parent);
                }
        }
        return true;
    }
    function isJsxElementOrFragment(node) {
        return node.kind === ts.SyntaxKind.JsxElement || node.kind === ts.SyntaxKind.JsxFragment;
    }
    function getLineRanges(sourceFile) {
        const lineStarts = sourceFile.getLineStarts();
        const result = [];
        const length = lineStarts.length;
        const sourceText = sourceFile.text;
        let pos = 0;
        for (let i = 1; i < length; ++i) {
            const end = lineStarts[i];
            let lineEnd = end;
            for (; lineEnd > pos; --lineEnd)
                if (!ts.isLineBreak(sourceText.charCodeAt(lineEnd - 1)))
                    break;
            result.push({
                pos,
                end,
                contentLength: lineEnd - pos,
            });
            pos = end;
        }
        result.push({
            pos,
            end: sourceFile.end,
            contentLength: sourceFile.end - pos,
        });
        return result;
    }
    exports.getLineRanges = getLineRanges;
    /** Get the line break style used in sourceFile. This function only looks at the first line break. If there is none, \n is assumed. */
    function getLineBreakStyle(sourceFile) {
        const lineStarts = sourceFile.getLineStarts();
        return lineStarts.length === 1 || lineStarts[1] < 2 || sourceFile.text[lineStarts[1] - 2] !== '\r'
            ? '\n'
            : '\r\n';
    }
    exports.getLineBreakStyle = getLineBreakStyle;
    let cachedScanner;
    function scanToken(text, languageVersion) {
        if (cachedScanner === undefined) {
            // cache scanner
            cachedScanner = ts.createScanner(languageVersion, false, undefined, text);
        }
        else {
            cachedScanner.setScriptTarget(languageVersion);
            cachedScanner.setText(text);
        }
        cachedScanner.scan();
        return cachedScanner;
    }
    /**
     * Determines whether the given text parses as a standalone identifier.
     * This is not a guarantee that it works in every context. The property name in PropertyAccessExpressions for example allows reserved words.
     * Depending on the context it could be parsed as contextual keyword or TypeScript keyword.
     */
    function isValidIdentifier(text, languageVersion = ts.ScriptTarget.Latest) {
        const scan = scanToken(text, languageVersion);
        return scan.isIdentifier() && scan.getTextPos() === text.length && scan.getTokenPos() === 0;
    }
    exports.isValidIdentifier = isValidIdentifier;
    function charSize(ch) {
        return ch >= 0x10000 ? 2 : 1;
    }
    /**
     * Determines whether the given text can be used to access a property with a PropertyAccessExpression while preserving the property's name.
     */
    function isValidPropertyAccess(text, languageVersion = ts.ScriptTarget.Latest) {
        if (text.length === 0)
            return false;
        let ch = text.codePointAt(0);
        if (!ts.isIdentifierStart(ch, languageVersion))
            return false;
        for (let i = charSize(ch); i < text.length; i += charSize(ch)) {
            ch = text.codePointAt(i);
            if (!ts.isIdentifierPart(ch, languageVersion))
                return false;
        }
        return true;
    }
    exports.isValidPropertyAccess = isValidPropertyAccess;
    /**
     * Determines whether the given text can be used as unquoted name of a property declaration while preserving the property's name.
     */
    function isValidPropertyName(text, languageVersion = ts.ScriptTarget.Latest) {
        if (isValidPropertyAccess(text, languageVersion))
            return true;
        const scan = scanToken(text, languageVersion);
        return scan.getTextPos() === text.length &&
            scan.getToken() === ts.SyntaxKind.NumericLiteral && scan.getTokenValue() === text; // ensure stringified number equals literal
    }
    exports.isValidPropertyName = isValidPropertyName;
    /**
     * Determines whether the given text can be parsed as a numeric literal.
     */
    function isValidNumericLiteral(text, languageVersion = ts.ScriptTarget.Latest) {
        const scan = scanToken(text, languageVersion);
        return scan.getToken() === ts.SyntaxKind.NumericLiteral && scan.getTextPos() === text.length && scan.getTokenPos() === 0;
    }
    exports.isValidNumericLiteral = isValidNumericLiteral;
    /**
     * Determines whether the given text can be used as JSX tag or attribute name while preserving the exact name.
     */
    function isValidJsxIdentifier(text, languageVersion = ts.ScriptTarget.Latest) {
        if (text.length === 0)
            return false;
        let seenNamespaceSeparator = false;
        let ch = text.codePointAt(0);
        if (!ts.isIdentifierStart(ch, languageVersion))
            return false;
        for (let i = charSize(ch); i < text.length; i += charSize(ch)) {
            ch = text.codePointAt(i);
            if (!ts.isIdentifierPart(ch, languageVersion) && ch !== 45 /* minus */) {
                if (!seenNamespaceSeparator && ch === 58 /* colon */ && i + charSize(ch) !== text.length) {
                    seenNamespaceSeparator = true;
                }
                else {
                    return false;
                }
            }
        }
        return true;
    }
    exports.isValidJsxIdentifier = isValidJsxIdentifier;
    function isNumericPropertyName(name) {
        return String(+name) === name;
    }
    exports.isNumericPropertyName = isNumericPropertyName;
    function isSameLine(sourceFile, pos1, pos2) {
        return ts.getLineAndCharacterOfPosition(sourceFile, pos1).line === ts.getLineAndCharacterOfPosition(sourceFile, pos2).line;
    }
    exports.isSameLine = isSameLine;
    var SideEffectOptions;
    (function (SideEffectOptions) {
        SideEffectOptions[SideEffectOptions["None"] = 0] = "None";
        SideEffectOptions[SideEffectOptions["TaggedTemplate"] = 1] = "TaggedTemplate";
        SideEffectOptions[SideEffectOptions["Constructor"] = 2] = "Constructor";
        SideEffectOptions[SideEffectOptions["JsxElement"] = 4] = "JsxElement";
    })(SideEffectOptions = exports.SideEffectOptions || (exports.SideEffectOptions = {}));
    function hasSideEffects(node, options) {
        var _a, _b;
        const queue = [];
        while (true) {
            switch (node.kind) {
                case ts.SyntaxKind.CallExpression:
                case ts.SyntaxKind.PostfixUnaryExpression:
                case ts.SyntaxKind.AwaitExpression:
                case ts.SyntaxKind.YieldExpression:
                case ts.SyntaxKind.DeleteExpression:
                    return true;
                case ts.SyntaxKind.TypeAssertionExpression:
                case ts.SyntaxKind.AsExpression:
                case ts.SyntaxKind.ParenthesizedExpression:
                case ts.SyntaxKind.NonNullExpression:
                case ts.SyntaxKind.VoidExpression:
                case ts.SyntaxKind.TypeOfExpression:
                case ts.SyntaxKind.PropertyAccessExpression:
                case ts.SyntaxKind.SpreadElement:
                case ts.SyntaxKind.PartiallyEmittedExpression:
                    node = node.expression;
                    continue;
                case ts.SyntaxKind.BinaryExpression:
                    if (isAssignmentKind(node.operatorToken.kind))
                        return true;
                    queue.push(node.right);
                    node = node.left;
                    continue;
                case ts.SyntaxKind.PrefixUnaryExpression:
                    switch (node.operator) {
                        case ts.SyntaxKind.PlusPlusToken:
                        case ts.SyntaxKind.MinusMinusToken:
                            return true;
                        default:
                            node = node.operand;
                            continue;
                    }
                case ts.SyntaxKind.ElementAccessExpression:
                    if (node.argumentExpression !== undefined) // for compatibility with typescript@<2.9.0
                        queue.push(node.argumentExpression);
                    node = node.expression;
                    continue;
                case ts.SyntaxKind.ConditionalExpression:
                    queue.push(node.whenTrue, node.whenFalse);
                    node = node.condition;
                    continue;
                case ts.SyntaxKind.NewExpression:
                    if (options & 2 /* Constructor */)
                        return true;
                    if (node.arguments !== undefined)
                        queue.push(...node.arguments);
                    node = node.expression;
                    continue;
                case ts.SyntaxKind.TaggedTemplateExpression:
                    if (options & 1 /* TaggedTemplate */)
                        return true;
                    queue.push(node.tag);
                    node = node.template;
                    if (node.kind === ts.SyntaxKind.NoSubstitutionTemplateLiteral)
                        break;
                // falls through
                case ts.SyntaxKind.TemplateExpression:
                    for (const child of node.templateSpans)
                        queue.push(child.expression);
                    break;
                case ts.SyntaxKind.ClassExpression: {
                    if (node.decorators !== undefined)
                        return true;
                    for (const child of node.members) {
                        if (child.decorators !== undefined)
                            return true;
                        if (!hasModifier(child.modifiers, ts.SyntaxKind.DeclareKeyword)) {
                            if (((_a = child.name) === null || _a === void 0 ? void 0 : _a.kind) === ts.SyntaxKind.ComputedPropertyName)
                                queue.push(child.name.expression);
                            if (node_1.isMethodDeclaration(child)) {
                                for (const p of child.parameters)
                                    if (p.decorators !== undefined)
                                        return true;
                            }
                            else if (node_1.isPropertyDeclaration(child) &&
                                child.initializer !== undefined &&
                                hasModifier(child.modifiers, ts.SyntaxKind.StaticKeyword)) {
                                queue.push(child.initializer);
                            }
                        }
                    }
                    const base = getBaseOfClassLikeExpression(node);
                    if (base === undefined)
                        break;
                    node = base.expression;
                    continue;
                }
                case ts.SyntaxKind.ArrayLiteralExpression:
                    queue.push(...node.elements);
                    break;
                case ts.SyntaxKind.ObjectLiteralExpression:
                    for (const child of node.properties) {
                        if (((_b = child.name) === null || _b === void 0 ? void 0 : _b.kind) === ts.SyntaxKind.ComputedPropertyName)
                            queue.push(child.name.expression);
                        switch (child.kind) {
                            case ts.SyntaxKind.PropertyAssignment:
                                queue.push(child.initializer);
                                break;
                            case ts.SyntaxKind.SpreadAssignment:
                                queue.push(child.expression);
                        }
                    }
                    break;
                case ts.SyntaxKind.JsxExpression:
                    if (node.expression === undefined)
                        break;
                    node = node.expression;
                    continue;
                case ts.SyntaxKind.JsxElement:
                case ts.SyntaxKind.JsxFragment:
                    for (const child of node.children)
                        if (child.kind !== ts.SyntaxKind.JsxText)
                            queue.push(child);
                    if (node.kind === ts.SyntaxKind.JsxFragment)
                        break;
                    node = node.openingElement;
                // falls through
                case ts.SyntaxKind.JsxSelfClosingElement:
                case ts.SyntaxKind.JsxOpeningElement:
                    if (options & 4 /* JsxElement */)
                        return true;
                    for (const child of node.attributes.properties) {
                        if (child.kind === ts.SyntaxKind.JsxSpreadAttribute) {
                            queue.push(child.expression);
                        }
                        else if (child.initializer !== undefined) {
                            queue.push(child.initializer);
                        }
                    }
                    break;
                case ts.SyntaxKind.CommaListExpression:
                    queue.push(...node.elements);
            }
            if (queue.length === 0)
                return false;
            node = queue.pop();
        }
    }
    exports.hasSideEffects = hasSideEffects;
    /** Returns the VariableDeclaration or ParameterDeclaration that contains the BindingElement */
    function getDeclarationOfBindingElement(node) {
        let parent = node.parent.parent;
        while (parent.kind === ts.SyntaxKind.BindingElement)
            parent = parent.parent.parent;
        return parent;
    }
    exports.getDeclarationOfBindingElement = getDeclarationOfBindingElement;
    function isExpressionValueUsed(node) {
        while (true) {
            const parent = node.parent;
            switch (parent.kind) {
                case ts.SyntaxKind.CallExpression:
                case ts.SyntaxKind.NewExpression:
                case ts.SyntaxKind.ElementAccessExpression:
                case ts.SyntaxKind.WhileStatement:
                case ts.SyntaxKind.DoStatement:
                case ts.SyntaxKind.WithStatement:
                case ts.SyntaxKind.ThrowStatement:
                case ts.SyntaxKind.ReturnStatement:
                case ts.SyntaxKind.JsxExpression:
                case ts.SyntaxKind.JsxSpreadAttribute:
                case ts.SyntaxKind.JsxElement:
                case ts.SyntaxKind.JsxFragment:
                case ts.SyntaxKind.JsxSelfClosingElement:
                case ts.SyntaxKind.ComputedPropertyName:
                case ts.SyntaxKind.ArrowFunction:
                case ts.SyntaxKind.ExportSpecifier:
                case ts.SyntaxKind.ExportAssignment:
                case ts.SyntaxKind.ImportDeclaration:
                case ts.SyntaxKind.ExternalModuleReference:
                case ts.SyntaxKind.Decorator:
                case ts.SyntaxKind.TaggedTemplateExpression:
                case ts.SyntaxKind.TemplateSpan:
                case ts.SyntaxKind.ExpressionWithTypeArguments:
                case ts.SyntaxKind.TypeOfExpression:
                case ts.SyntaxKind.AwaitExpression:
                case ts.SyntaxKind.YieldExpression:
                case ts.SyntaxKind.LiteralType:
                case ts.SyntaxKind.JsxAttributes:
                case ts.SyntaxKind.JsxOpeningElement:
                case ts.SyntaxKind.JsxClosingElement:
                case ts.SyntaxKind.IfStatement:
                case ts.SyntaxKind.CaseClause:
                case ts.SyntaxKind.SwitchStatement:
                    return true;
                case ts.SyntaxKind.PropertyAccessExpression:
                    return parent.expression === node;
                case ts.SyntaxKind.QualifiedName:
                    return parent.left === node;
                case ts.SyntaxKind.ShorthandPropertyAssignment:
                    return parent.objectAssignmentInitializer === node ||
                        !isInDestructuringAssignment(parent);
                case ts.SyntaxKind.PropertyAssignment:
                    return parent.initializer === node && !isInDestructuringAssignment(parent);
                case ts.SyntaxKind.SpreadAssignment:
                case ts.SyntaxKind.SpreadElement:
                case ts.SyntaxKind.ArrayLiteralExpression:
                    return !isInDestructuringAssignment(parent);
                case ts.SyntaxKind.ParenthesizedExpression:
                case ts.SyntaxKind.AsExpression:
                case ts.SyntaxKind.TypeAssertionExpression:
                case ts.SyntaxKind.PostfixUnaryExpression:
                case ts.SyntaxKind.PrefixUnaryExpression:
                case ts.SyntaxKind.NonNullExpression:
                    node = parent;
                    continue;
                case ts.SyntaxKind.ForStatement:
                    return parent.condition === node;
                case ts.SyntaxKind.ForInStatement:
                case ts.SyntaxKind.ForOfStatement:
                    return parent.expression === node;
                case ts.SyntaxKind.ConditionalExpression:
                    if (parent.condition === node)
                        return true;
                    node = parent;
                    break;
                case ts.SyntaxKind.PropertyDeclaration:
                case ts.SyntaxKind.BindingElement:
                case ts.SyntaxKind.VariableDeclaration:
                case ts.SyntaxKind.Parameter:
                case ts.SyntaxKind.EnumMember:
                    return parent.initializer === node;
                case ts.SyntaxKind.ImportEqualsDeclaration:
                    return parent.moduleReference === node;
                case ts.SyntaxKind.CommaListExpression:
                    if (parent.elements[parent.elements.length - 1] !== node)
                        return false;
                    node = parent;
                    break;
                case ts.SyntaxKind.BinaryExpression:
                    if (parent.right === node) {
                        if (parent.operatorToken.kind === ts.SyntaxKind.CommaToken) {
                            node = parent;
                            break;
                        }
                        return true;
                    }
                    switch (parent.operatorToken.kind) {
                        case ts.SyntaxKind.CommaToken:
                        case ts.SyntaxKind.EqualsToken:
                            return false;
                        case ts.SyntaxKind.EqualsEqualsEqualsToken:
                        case ts.SyntaxKind.EqualsEqualsToken:
                        case ts.SyntaxKind.ExclamationEqualsEqualsToken:
                        case ts.SyntaxKind.ExclamationEqualsToken:
                        case ts.SyntaxKind.InstanceOfKeyword:
                        case ts.SyntaxKind.PlusToken:
                        case ts.SyntaxKind.MinusToken:
                        case ts.SyntaxKind.AsteriskToken:
                        case ts.SyntaxKind.SlashToken:
                        case ts.SyntaxKind.PercentToken:
                        case ts.SyntaxKind.AsteriskAsteriskToken:
                        case ts.SyntaxKind.GreaterThanToken:
                        case ts.SyntaxKind.GreaterThanGreaterThanToken:
                        case ts.SyntaxKind.GreaterThanGreaterThanGreaterThanToken:
                        case ts.SyntaxKind.GreaterThanEqualsToken:
                        case ts.SyntaxKind.LessThanToken:
                        case ts.SyntaxKind.LessThanLessThanToken:
                        case ts.SyntaxKind.LessThanEqualsToken:
                        case ts.SyntaxKind.AmpersandToken:
                        case ts.SyntaxKind.BarToken:
                        case ts.SyntaxKind.CaretToken:
                        case ts.SyntaxKind.BarBarToken:
                        case ts.SyntaxKind.AmpersandAmpersandToken:
                        case ts.SyntaxKind.QuestionQuestionToken:
                        case ts.SyntaxKind.InKeyword:
                        case ts.SyntaxKind.QuestionQuestionEqualsToken:
                        case ts.SyntaxKind.AmpersandAmpersandEqualsToken:
                        case ts.SyntaxKind.BarBarEqualsToken:
                            return true;
                        default:
                            node = parent;
                    }
                    break;
                default:
                    return false;
            }
        }
    }
    exports.isExpressionValueUsed = isExpressionValueUsed;
    function isInDestructuringAssignment(node) {
        switch (node.kind) {
            case ts.SyntaxKind.ShorthandPropertyAssignment:
                if (node.objectAssignmentInitializer !== undefined)
                    return true;
            // falls through
            case ts.SyntaxKind.PropertyAssignment:
            case ts.SyntaxKind.SpreadAssignment:
                node = node.parent;
                break;
            case ts.SyntaxKind.SpreadElement:
                if (node.parent.kind !== ts.SyntaxKind.ArrayLiteralExpression)
                    return false;
                node = node.parent;
        }
        while (true) {
            switch (node.parent.kind) {
                case ts.SyntaxKind.BinaryExpression:
                    return node.parent.left === node &&
                        node.parent.operatorToken.kind === ts.SyntaxKind.EqualsToken;
                case ts.SyntaxKind.ForOfStatement:
                    return node.parent.initializer === node;
                case ts.SyntaxKind.ArrayLiteralExpression:
                case ts.SyntaxKind.ObjectLiteralExpression:
                    node = node.parent;
                    break;
                case ts.SyntaxKind.SpreadAssignment:
                case ts.SyntaxKind.PropertyAssignment:
                    node = node.parent.parent;
                    break;
                case ts.SyntaxKind.SpreadElement:
                    if (node.parent.parent.kind !== ts.SyntaxKind.ArrayLiteralExpression)
                        return false;
                    node = node.parent.parent;
                    break;
                default:
                    return false;
            }
        }
    }
    var AccessKind;
    (function (AccessKind) {
        AccessKind[AccessKind["None"] = 0] = "None";
        AccessKind[AccessKind["Read"] = 1] = "Read";
        AccessKind[AccessKind["Write"] = 2] = "Write";
        AccessKind[AccessKind["Delete"] = 4] = "Delete";
        AccessKind[AccessKind["ReadWrite"] = 3] = "ReadWrite";
        AccessKind[AccessKind["Modification"] = 6] = "Modification";
    })(AccessKind = exports.AccessKind || (exports.AccessKind = {}));
    function getAccessKind(node) {
        const parent = node.parent;
        switch (parent.kind) {
            case ts.SyntaxKind.DeleteExpression:
                return 4 /* Delete */;
            case ts.SyntaxKind.PostfixUnaryExpression:
                return 3 /* ReadWrite */;
            case ts.SyntaxKind.PrefixUnaryExpression:
                return parent.operator === ts.SyntaxKind.PlusPlusToken ||
                    parent.operator === ts.SyntaxKind.MinusMinusToken
                    ? 3 /* ReadWrite */
                    : 1 /* Read */;
            case ts.SyntaxKind.BinaryExpression:
                return parent.right === node
                    ? 1 /* Read */
                    : !isAssignmentKind(parent.operatorToken.kind)
                        ? 1 /* Read */
                        : parent.operatorToken.kind === ts.SyntaxKind.EqualsToken
                            ? 2 /* Write */
                            : 3 /* ReadWrite */;
            case ts.SyntaxKind.ShorthandPropertyAssignment:
                return parent.objectAssignmentInitializer === node
                    ? 1 /* Read */
                    : isInDestructuringAssignment(parent)
                        ? 2 /* Write */
                        : 1 /* Read */;
            case ts.SyntaxKind.PropertyAssignment:
                return parent.name === node
                    ? 0 /* None */
                    : isInDestructuringAssignment(parent)
                        ? 2 /* Write */
                        : 1 /* Read */;
            case ts.SyntaxKind.ArrayLiteralExpression:
            case ts.SyntaxKind.SpreadElement:
            case ts.SyntaxKind.SpreadAssignment:
                return isInDestructuringAssignment(parent)
                    ? 2 /* Write */
                    : 1 /* Read */;
            case ts.SyntaxKind.ParenthesizedExpression:
            case ts.SyntaxKind.NonNullExpression:
            case ts.SyntaxKind.TypeAssertionExpression:
            case ts.SyntaxKind.AsExpression:
                // (<number>foo! as {})++
                return getAccessKind(parent);
            case ts.SyntaxKind.ForOfStatement:
            case ts.SyntaxKind.ForInStatement:
                return parent.initializer === node
                    ? 2 /* Write */
                    : 1 /* Read */;
            case ts.SyntaxKind.ExpressionWithTypeArguments:
                return parent.parent.token === ts.SyntaxKind.ExtendsKeyword &&
                    parent.parent.parent.kind !== ts.SyntaxKind.InterfaceDeclaration
                    ? 1 /* Read */
                    : 0 /* None */;
            case ts.SyntaxKind.ComputedPropertyName:
            case ts.SyntaxKind.ExpressionStatement:
            case ts.SyntaxKind.TypeOfExpression:
            case ts.SyntaxKind.ElementAccessExpression:
            case ts.SyntaxKind.ForStatement:
            case ts.SyntaxKind.IfStatement:
            case ts.SyntaxKind.DoStatement:
            case ts.SyntaxKind.WhileStatement:
            case ts.SyntaxKind.SwitchStatement:
            case ts.SyntaxKind.WithStatement:
            case ts.SyntaxKind.ThrowStatement:
            case ts.SyntaxKind.CallExpression:
            case ts.SyntaxKind.NewExpression:
            case ts.SyntaxKind.TaggedTemplateExpression:
            case ts.SyntaxKind.JsxExpression:
            case ts.SyntaxKind.Decorator:
            case ts.SyntaxKind.TemplateSpan:
            case ts.SyntaxKind.JsxOpeningElement:
            case ts.SyntaxKind.JsxSelfClosingElement:
            case ts.SyntaxKind.JsxSpreadAttribute:
            case ts.SyntaxKind.VoidExpression:
            case ts.SyntaxKind.ReturnStatement:
            case ts.SyntaxKind.AwaitExpression:
            case ts.SyntaxKind.YieldExpression:
            case ts.SyntaxKind.ConditionalExpression:
            case ts.SyntaxKind.CaseClause:
            case ts.SyntaxKind.JsxElement:
                return 1 /* Read */;
            case ts.SyntaxKind.ArrowFunction:
                return parent.body === node
                    ? 1 /* Read */
                    : 2 /* Write */;
            case ts.SyntaxKind.PropertyDeclaration:
            case ts.SyntaxKind.VariableDeclaration:
            case ts.SyntaxKind.Parameter:
            case ts.SyntaxKind.EnumMember:
            case ts.SyntaxKind.BindingElement:
            case ts.SyntaxKind.JsxAttribute:
                return parent.initializer === node
                    ? 1 /* Read */
                    : 0 /* None */;
            case ts.SyntaxKind.PropertyAccessExpression:
                return parent.expression === node
                    ? 1 /* Read */
                    : 0 /* None */;
            case ts.SyntaxKind.ExportAssignment:
                return parent.isExportEquals
                    ? 1 /* Read */
                    : 0 /* None */;
        }
        return 0 /* None */;
    }
    exports.getAccessKind = getAccessKind;
    function isReassignmentTarget(node) {
        return (getAccessKind(node) & 2 /* Write */) !== 0;
    }
    exports.isReassignmentTarget = isReassignmentTarget;
    function canHaveJsDoc(node) {
        const kind = node.kind;
        switch (kind) {
            case ts.SyntaxKind.Parameter:
            case ts.SyntaxKind.CallSignature:
            case ts.SyntaxKind.ConstructSignature:
            case ts.SyntaxKind.MethodSignature:
            case ts.SyntaxKind.PropertySignature:
            case ts.SyntaxKind.ArrowFunction:
            case ts.SyntaxKind.ParenthesizedExpression:
            case ts.SyntaxKind.SpreadAssignment:
            case ts.SyntaxKind.ShorthandPropertyAssignment:
            case ts.SyntaxKind.PropertyAssignment:
            case ts.SyntaxKind.FunctionExpression:
            case ts.SyntaxKind.LabeledStatement:
            case ts.SyntaxKind.ExpressionStatement:
            case ts.SyntaxKind.VariableStatement:
            case ts.SyntaxKind.FunctionDeclaration:
            case ts.SyntaxKind.Constructor:
            case ts.SyntaxKind.MethodDeclaration:
            case ts.SyntaxKind.PropertyDeclaration:
            case ts.SyntaxKind.GetAccessor:
            case ts.SyntaxKind.SetAccessor:
            case ts.SyntaxKind.ClassDeclaration:
            case ts.SyntaxKind.ClassExpression:
            case ts.SyntaxKind.InterfaceDeclaration:
            case ts.SyntaxKind.TypeAliasDeclaration:
            case ts.SyntaxKind.EnumMember:
            case ts.SyntaxKind.EnumDeclaration:
            case ts.SyntaxKind.ModuleDeclaration:
            case ts.SyntaxKind.ImportEqualsDeclaration:
            case ts.SyntaxKind.ImportDeclaration:
            case ts.SyntaxKind.NamespaceExportDeclaration:
            case ts.SyntaxKind.ExportAssignment:
            case ts.SyntaxKind.IndexSignature:
            case ts.SyntaxKind.FunctionType:
            case ts.SyntaxKind.ConstructorType:
            case ts.SyntaxKind.JSDocFunctionType:
            case ts.SyntaxKind.ExportDeclaration:
            case ts.SyntaxKind.NamedTupleMember:
            case ts.SyntaxKind.EndOfFileToken:
                return true;
            default:
                return false;
        }
    }
    exports.canHaveJsDoc = canHaveJsDoc;
    /** Gets the JSDoc of a node. For performance reasons this function should only be called when `canHaveJsDoc` returns true. */
    function getJsDoc(node, sourceFile) {
        const result = [];
        for (const child of node.getChildren(sourceFile)) {
            if (!node_1.isJsDoc(child))
                break;
            result.push(child);
        }
        return result;
    }
    exports.getJsDoc = getJsDoc;
    /**
     * Parses the JsDoc of any node. This function is made for nodes that don't get their JsDoc parsed by the TypeScript parser.
     *
     * @param considerTrailingComments When set to `true` this function uses the trailing comments if the node starts on the same line
     *                                 as the previous node ends.
     */
    function parseJsDocOfNode(node, considerTrailingComments, sourceFile = node.getSourceFile()) {
        if (canHaveJsDoc(node) && node.kind !== ts.SyntaxKind.EndOfFileToken) {
            const result = getJsDoc(node, sourceFile);
            if (result.length !== 0 || !considerTrailingComments)
                return result;
        }
        return parseJsDocWorker(node, node.getStart(sourceFile), sourceFile, considerTrailingComments);
    }
    exports.parseJsDocOfNode = parseJsDocOfNode;
    function parseJsDocWorker(node, nodeStart, sourceFile, considerTrailingComments) {
        const start = ts[considerTrailingComments && isSameLine(sourceFile, node.pos, nodeStart)
            ? 'forEachTrailingCommentRange'
            : 'forEachLeadingCommentRange'](sourceFile.text, node.pos, 
        // return object to make `0` a truthy value
        (pos, _end, kind) => kind === ts.SyntaxKind.MultiLineCommentTrivia && sourceFile.text[pos + 2] === '*' ? { pos } : undefined);
        if (start === undefined)
            return [];
        const startPos = start.pos;
        const text = sourceFile.text.slice(startPos, nodeStart);
        const newSourceFile = ts.createSourceFile('jsdoc.ts', `${text}var a;`, sourceFile.languageVersion);
        const result = getJsDoc(newSourceFile.statements[0], newSourceFile);
        for (const doc of result)
            updateNode(doc, node);
        return result;
        function updateNode(n, parent) {
            n.pos += startPos;
            n.end += startPos;
            n.parent = parent;
            return ts.forEachChild(n, (child) => updateNode(child, n), (children) => {
                children.pos += startPos;
                children.end += startPos;
                for (const child of children)
                    updateNode(child, n);
            });
        }
    }
    var ImportKind;
    (function (ImportKind) {
        ImportKind[ImportKind["ImportDeclaration"] = 1] = "ImportDeclaration";
        ImportKind[ImportKind["ImportEquals"] = 2] = "ImportEquals";
        ImportKind[ImportKind["ExportFrom"] = 4] = "ExportFrom";
        ImportKind[ImportKind["DynamicImport"] = 8] = "DynamicImport";
        ImportKind[ImportKind["Require"] = 16] = "Require";
        ImportKind[ImportKind["ImportType"] = 32] = "ImportType";
        ImportKind[ImportKind["All"] = 63] = "All";
        ImportKind[ImportKind["AllImports"] = 59] = "AllImports";
        ImportKind[ImportKind["AllStaticImports"] = 3] = "AllStaticImports";
        ImportKind[ImportKind["AllImportExpressions"] = 24] = "AllImportExpressions";
        ImportKind[ImportKind["AllRequireLike"] = 18] = "AllRequireLike";
        // @internal
        ImportKind[ImportKind["AllNestedImports"] = 56] = "AllNestedImports";
        // @internal
        ImportKind[ImportKind["AllTopLevelImports"] = 7] = "AllTopLevelImports";
    })(ImportKind = exports.ImportKind || (exports.ImportKind = {}));
    function findImports(sourceFile, kinds, ignoreFileName = true) {
        const result = [];
        for (const node of findImportLikeNodes(sourceFile, kinds, ignoreFileName)) {
            switch (node.kind) {
                case ts.SyntaxKind.ImportDeclaration:
                    addIfTextualLiteral(node.moduleSpecifier);
                    break;
                case ts.SyntaxKind.ImportEqualsDeclaration:
                    addIfTextualLiteral(node.moduleReference.expression);
                    break;
                case ts.SyntaxKind.ExportDeclaration:
                    addIfTextualLiteral(node.moduleSpecifier);
                    break;
                case ts.SyntaxKind.CallExpression:
                    addIfTextualLiteral(node.arguments[0]);
                    break;
                case ts.SyntaxKind.ImportType:
                    if (node_1.isLiteralTypeNode(node.argument))
                        addIfTextualLiteral(node.argument.literal);
                    break;
                default:
                    throw new Error('unexpected node');
            }
        }
        return result;
        function addIfTextualLiteral(node) {
            if (node_1.isTextualLiteral(node))
                result.push(node);
        }
    }
    exports.findImports = findImports;
    function findImportLikeNodes(sourceFile, kinds, ignoreFileName = true) {
        return new ImportFinder(sourceFile, kinds, ignoreFileName).find();
    }
    exports.findImportLikeNodes = findImportLikeNodes;
    class ImportFinder {
        constructor(_sourceFile, _options, _ignoreFileName) {
            this._sourceFile = _sourceFile;
            this._options = _options;
            this._ignoreFileName = _ignoreFileName;
            this._result = [];
        }
        find() {
            if (this._sourceFile.isDeclarationFile)
                this._options &= ~24 /* AllImportExpressions */;
            if (this._options & 7 /* AllTopLevelImports */)
                this._findImports(this._sourceFile.statements);
            if (this._options & 56 /* AllNestedImports */)
                this._findNestedImports();
            return this._result;
        }
        _findImports(statements) {
            for (const statement of statements) {
                if (node_1.isImportDeclaration(statement)) {
                    if (this._options & 1 /* ImportDeclaration */)
                        this._result.push(statement);
                }
                else if (node_1.isImportEqualsDeclaration(statement)) {
                    if (this._options & 2 /* ImportEquals */ &&
                        statement.moduleReference.kind === ts.SyntaxKind.ExternalModuleReference)
                        this._result.push(statement);
                }
                else if (node_1.isExportDeclaration(statement)) {
                    if (statement.moduleSpecifier !== undefined && this._options & 4 /* ExportFrom */)
                        this._result.push(statement);
                }
                else if (node_1.isModuleDeclaration(statement)) {
                    this._findImportsInModule(statement);
                }
            }
        }
        _findImportsInModule(declaration) {
            if (declaration.body === undefined)
                return;
            if (declaration.body.kind === ts.SyntaxKind.ModuleDeclaration)
                return this._findImportsInModule(declaration.body);
            this._findImports(declaration.body.statements);
        }
        _findNestedImports() {
            const isJavaScriptFile = this._ignoreFileName || (this._sourceFile.flags & ts.NodeFlags.JavaScriptFile) !== 0;
            let re;
            let includeJsDoc;
            if ((this._options & 56 /* AllNestedImports */) === 16 /* Require */) {
                if (!isJavaScriptFile)
                    return; // don't look for 'require' in TS files
                re = /\brequire\s*[</(]/g;
                includeJsDoc = false;
            }
            else if (this._options & 16 /* Require */ && isJavaScriptFile) {
                re = /\b(?:import|require)\s*[</(]/g;
                includeJsDoc = (this._options & 32 /* ImportType */) !== 0;
            }
            else {
                re = /\bimport\s*[</(]/g;
                includeJsDoc = isJavaScriptFile && (this._options & 32 /* ImportType */) !== 0;
            }
            for (let match = re.exec(this._sourceFile.text); match !== null; match = re.exec(this._sourceFile.text)) {
                const token = getTokenAtPositionWorker(this._sourceFile, match.index, this._sourceFile, 
                // only look for ImportTypeNode within JSDoc in JS files
                match[0][0] === 'i' && includeJsDoc);
                if (token.kind === ts.SyntaxKind.ImportKeyword) {
                    if (token.end - 'import'.length !== match.index)
                        continue;
                    switch (token.parent.kind) {
                        case ts.SyntaxKind.ImportType:
                            this._result.push(token.parent);
                            break;
                        case ts.SyntaxKind.CallExpression:
                            if (token.parent.arguments.length > 1)
                                this._result.push(token.parent);
                    }
                }
                else if (token.kind === ts.SyntaxKind.Identifier &&
                    token.end - 'require'.length === match.index &&
                    token.parent.kind === ts.SyntaxKind.CallExpression &&
                    token.parent.expression === token &&
                    token.parent.arguments.length === 1) {
                    this._result.push(token.parent);
                }
            }
        }
    }
    /**
     * Ambient context means the statement itself has the `declare` keyword
     * or is inside a `declare namespace`,  `delcare module` or `declare global`.
     */
    function isStatementInAmbientContext(node) {
        while (node.flags & ts.NodeFlags.NestedNamespace)
            node = node.parent;
        return hasModifier(node.modifiers, ts.SyntaxKind.DeclareKeyword) || isAmbientModuleBlock(node.parent);
    }
    exports.isStatementInAmbientContext = isStatementInAmbientContext;
    /** Includes `declare namespace`, `declare module` and `declare global` and namespace nested in one of the aforementioned. */
    function isAmbientModuleBlock(node) {
        while (node.kind === ts.SyntaxKind.ModuleBlock) {
            do
                node = node.parent;
            while (node.flags & ts.NodeFlags.NestedNamespace);
            if (hasModifier(node.modifiers, ts.SyntaxKind.DeclareKeyword))
                return true;
            node = node.parent;
        }
        return false;
    }
    exports.isAmbientModuleBlock = isAmbientModuleBlock;
    function getIIFE(func) {
        let node = func.parent;
        while (node.kind === ts.SyntaxKind.ParenthesizedExpression)
            node = node.parent;
        return node_1.isCallExpression(node) && func.end <= node.expression.end ? node : undefined;
    }
    exports.getIIFE = getIIFE;
    function isStrictCompilerOptionEnabled(options, option) {
        return (options.strict ? options[option] !== false : options[option] === true) &&
            (option !== 'strictPropertyInitialization' || isStrictCompilerOptionEnabled(options, 'strictNullChecks'));
    }
    exports.isStrictCompilerOptionEnabled = isStrictCompilerOptionEnabled;
    // https://github.com/ajafff/tslint-consistent-codestyle/issues/85
    /**
     * Checks if a given compiler option is enabled.
     * It handles dependencies of options, e.g. `declaration` is implicitly enabled by `composite` or `strictNullChecks` is enabled by `strict`.
     * However, it does not check dependencies that are already checked and reported as errors, e.g. `checkJs` without `allowJs`.
     * This function only handles boolean flags.
     */
    function isCompilerOptionEnabled(options, option) {
        switch (option) {
            case 'stripInternal':
            case 'declarationMap':
            case 'emitDeclarationOnly':
                return options[option] === true && isCompilerOptionEnabled(options, 'declaration');
            case 'declaration':
                return options.declaration || isCompilerOptionEnabled(options, 'composite');
            case 'incremental':
                return options.incremental === undefined ? isCompilerOptionEnabled(options, 'composite') : options.incremental;
            case 'skipDefaultLibCheck':
                return options.skipDefaultLibCheck || isCompilerOptionEnabled(options, 'skipLibCheck');
            case 'suppressImplicitAnyIndexErrors':
                return options.suppressImplicitAnyIndexErrors === true && isCompilerOptionEnabled(options, 'noImplicitAny');
            case 'allowSyntheticDefaultImports':
                return options.allowSyntheticDefaultImports !== undefined
                    ? options.allowSyntheticDefaultImports
                    : isCompilerOptionEnabled(options, 'esModuleInterop') || options.module === ts.ModuleKind.System;
            case 'noUncheckedIndexedAccess':
                return options.noUncheckedIndexedAccess === true && isCompilerOptionEnabled(options, 'strictNullChecks');
            case 'allowJs':
                return options.allowJs === undefined ? isCompilerOptionEnabled(options, 'checkJs') : options.allowJs;
            case 'noImplicitAny':
            case 'noImplicitThis':
            case 'strictNullChecks':
            case 'strictFunctionTypes':
            case 'strictPropertyInitialization':
            case 'alwaysStrict':
            case 'strictBindCallApply':
                return isStrictCompilerOptionEnabled(options, option);
        }
        return options[option] === true;
    }
    exports.isCompilerOptionEnabled = isCompilerOptionEnabled;
    /**
     * Has nothing to do with `isAmbientModuleBlock`.
     *
     * @returns `true` if it's a global augmentation or has a string name.
     */
    function isAmbientModule(node) {
        return node.name.kind === ts.SyntaxKind.StringLiteral || (node.flags & ts.NodeFlags.GlobalAugmentation) !== 0;
    }
    exports.isAmbientModule = isAmbientModule;
    /**
     * @deprecated use `getTsCheckDirective` instead since `// @ts-nocheck` is no longer restricted to JS files.
     * @returns the last `// @ts-check` or `// @ts-nocheck` directive in the given file.
     */
    function getCheckJsDirective(source) {
        return getTsCheckDirective(source);
    }
    exports.getCheckJsDirective = getCheckJsDirective;
    /** @returns the last `// @ts-check` or `// @ts-nocheck` directive in the given file. */
    function getTsCheckDirective(source) {
        let directive;
        // needs to work around a shebang issue until https://github.com/Microsoft/TypeScript/issues/28477 is resolved
        ts.forEachLeadingCommentRange(source, (ts.getShebang(source) || '').length, (pos, end, kind) => {
            if (kind === ts.SyntaxKind.SingleLineCommentTrivia) {
                const text = source.slice(pos, end);
                const match = /^\/{2,3}\s*@ts-(no)?check(?:\s|$)/i.exec(text);
                if (match !== null)
                    directive = { pos, end, enabled: match[1] === undefined };
            }
        });
        return directive;
    }
    exports.getTsCheckDirective = getTsCheckDirective;
    function isConstAssertion(node) {
        return node_1.isTypeReferenceNode(node.type) &&
            node.type.typeName.kind === ts.SyntaxKind.Identifier &&
            node.type.typeName.escapedText === 'const';
    }
    exports.isConstAssertion = isConstAssertion;
    /** Detects whether an expression is affected by an enclosing 'as const' assertion and therefore treated literally. */
    function isInConstContext(node) {
        let current = node;
        while (true) {
            const parent = current.parent;
            outer: switch (parent.kind) {
                case ts.SyntaxKind.TypeAssertionExpression:
                case ts.SyntaxKind.AsExpression:
                    return isConstAssertion(parent);
                case ts.SyntaxKind.PrefixUnaryExpression:
                    if (current.kind !== ts.SyntaxKind.NumericLiteral)
                        return false;
                    switch (parent.operator) {
                        case ts.SyntaxKind.PlusToken:
                        case ts.SyntaxKind.MinusToken:
                            current = parent;
                            break outer;
                        default:
                            return false;
                    }
                case ts.SyntaxKind.PropertyAssignment:
                    if (parent.initializer !== current)
                        return false;
                    current = parent.parent;
                    break;
                case ts.SyntaxKind.ShorthandPropertyAssignment:
                    current = parent.parent;
                    break;
                case ts.SyntaxKind.ParenthesizedExpression:
                case ts.SyntaxKind.ArrayLiteralExpression:
                case ts.SyntaxKind.ObjectLiteralExpression:
                case ts.SyntaxKind.TemplateExpression:
                    current = parent;
                    break;
                default:
                    return false;
            }
        }
    }
    exports.isInConstContext = isInConstContext;
    /** Returns true for `Object.defineProperty(o, 'prop', {value, writable: false})` and  `Object.defineProperty(o, 'prop', {get: () => 1})`*/
    function isReadonlyAssignmentDeclaration(node, checker) {
        if (!isBindableObjectDefinePropertyCall(node))
            return false;
        const descriptorType = checker.getTypeAtLocation(node.arguments[2]);
        if (descriptorType.getProperty('value') === undefined)
            return descriptorType.getProperty('set') === undefined;
        const writableProp = descriptorType.getProperty('writable');
        if (writableProp === undefined)
            return false;
        const writableType = writableProp.valueDeclaration !== undefined && node_1.isPropertyAssignment(writableProp.valueDeclaration)
            ? checker.getTypeAtLocation(writableProp.valueDeclaration.initializer)
            : checker.getTypeOfSymbolAtLocation(writableProp, node.arguments[2]);
        return type_1.isBooleanLiteralType(writableType, false);
    }
    exports.isReadonlyAssignmentDeclaration = isReadonlyAssignmentDeclaration;
    /** Determines whether a call to `Object.defineProperty` is statically analyzable. */
    function isBindableObjectDefinePropertyCall(node) {
        return node.arguments.length === 3 &&
            node_1.isEntityNameExpression(node.arguments[0]) &&
            node_1.isNumericOrStringLikeLiteral(node.arguments[1]) &&
            node_1.isPropertyAccessExpression(node.expression) &&
            node.expression.name.escapedText === 'defineProperty' &&
            node_1.isIdentifier(node.expression.expression) &&
            node.expression.expression.escapedText === 'Object';
    }
    exports.isBindableObjectDefinePropertyCall = isBindableObjectDefinePropertyCall;
    function isWellKnownSymbolLiterally(node) {
        return ts.isPropertyAccessExpression(node) &&
            ts.isIdentifier(node.expression) &&
            node.expression.escapedText === 'Symbol';
    }
    exports.isWellKnownSymbolLiterally = isWellKnownSymbolLiterally;
    /** @deprecated typescript 4.3 removed the concept of literal well known symbols. Use `getPropertyNameFromType` instead. */
    function getPropertyNameOfWellKnownSymbol(node) {
        return {
            displayName: `[Symbol.${node.name.text}]`,
            symbolName: ('__@' + node.name.text),
        };
    }
    exports.getPropertyNameOfWellKnownSymbol = getPropertyNameOfWellKnownSymbol;
    const isTsBefore43 = (([major, minor]) => major < '4' || major === '4' && minor < '3')(ts.versionMajorMinor.split('.'));
    function getLateBoundPropertyNames(node, checker) {
        const result = {
            known: true,
            names: [],
        };
        node = unwrapParentheses(node);
        if (isTsBefore43 && isWellKnownSymbolLiterally(node)) {
            result.names.push(getPropertyNameOfWellKnownSymbol(node)); // wotan-disable-line no-unstable-api-use
        }
        else {
            const type = checker.getTypeAtLocation(node);
            for (const key of type_1.unionTypeParts(checker.getBaseConstraintOfType(type) || type)) {
                const propertyName = type_1.getPropertyNameFromType(key);
                if (propertyName) {
                    result.names.push(propertyName);
                }
                else {
                    result.known = false;
                }
            }
        }
        return result;
    }
    exports.getLateBoundPropertyNames = getLateBoundPropertyNames;
    function getLateBoundPropertyNamesOfPropertyName(node, checker) {
        const staticName = getPropertyName(node);
        return staticName !== undefined
            ? { known: true, names: [{ displayName: staticName, symbolName: ts.escapeLeadingUnderscores(staticName) }] }
            : node.kind === ts.SyntaxKind.PrivateIdentifier
                ? { known: true, names: [{ displayName: node.text, symbolName: checker.getSymbolAtLocation(node).escapedName }] }
                : getLateBoundPropertyNames(node.expression, checker);
    }
    exports.getLateBoundPropertyNamesOfPropertyName = getLateBoundPropertyNamesOfPropertyName;
    /** Most declarations demand there to be only one statically known name, e.g. class members with computed name. */
    function getSingleLateBoundPropertyNameOfPropertyName(node, checker) {
        const staticName = getPropertyName(node);
        if (staticName !== undefined)
            return { displayName: staticName, symbolName: ts.escapeLeadingUnderscores(staticName) };
        if (node.kind === ts.SyntaxKind.PrivateIdentifier)
            return { displayName: node.text, symbolName: checker.getSymbolAtLocation(node).escapedName };
        const { expression } = node;
        return isTsBefore43 && isWellKnownSymbolLiterally(expression)
            ? getPropertyNameOfWellKnownSymbol(expression) // wotan-disable-line no-unstable-api-use
            : type_1.getPropertyNameFromType(checker.getTypeAtLocation(expression));
    }
    exports.getSingleLateBoundPropertyNameOfPropertyName = getSingleLateBoundPropertyNameOfPropertyName;
    function unwrapParentheses(node) {
        while (node.kind === ts.SyntaxKind.ParenthesizedExpression)
            node = node.expression;
        return node;
    }
    exports.unwrapParentheses = unwrapParentheses;
    function formatPseudoBigInt(v) {
        return `${v.negative ? '-' : ''}${v.base10Value}n`;
    }
    exports.formatPseudoBigInt = formatPseudoBigInt;
    /**
     * Determines whether the given `SwitchStatement`'s `case` clauses cover every possible value of the switched expression.
     * The logic is the same as TypeScript's control flow analysis.
     * This does **not** check whether all `case` clauses do a certain action like assign a variable or return a value.
     * This function ignores the `default` clause if present.
     */
    function hasExhaustiveCaseClauses(node, checker) {
        const caseClauses = node.caseBlock.clauses.filter(node_1.isCaseClause);
        if (caseClauses.length === 0)
            return false;
        const typeParts = type_1.unionTypeParts(checker.getTypeAtLocation(node.expression));
        if (typeParts.length > caseClauses.length)
            return false;
        const types = new Set(typeParts.map(getPrimitiveLiteralFromType));
        if (types.has(undefined))
            return false;
        const seen = new Set();
        for (const clause of caseClauses) {
            const expressionType = checker.getTypeAtLocation(clause.expression);
            if (exports.isTypeFlagSet(expressionType, ts.TypeFlags.Never))
                continue; // additional case clause with 'never' is always allowed
            const type = getPrimitiveLiteralFromType(expressionType);
            if (types.has(type)) {
                seen.add(type);
            }
            else if (type !== 'null' && type !== 'undefined') { // additional case clauses with 'null' and 'undefined' are always allowed
                return false;
            }
        }
        return types.size === seen.size;
    }
    exports.hasExhaustiveCaseClauses = hasExhaustiveCaseClauses;
    function getPrimitiveLiteralFromType(t) {
        if (exports.isTypeFlagSet(t, ts.TypeFlags.Null))
            return 'null';
        if (exports.isTypeFlagSet(t, ts.TypeFlags.Undefined))
            return 'undefined';
        if (exports.isTypeFlagSet(t, ts.TypeFlags.NumberLiteral))
            return `${exports.isTypeFlagSet(t, ts.TypeFlags.EnumLiteral) ? 'enum:' : ''}${t.value}`;
        if (exports.isTypeFlagSet(t, ts.TypeFlags.StringLiteral))
            return `${exports.isTypeFlagSet(t, ts.TypeFlags.EnumLiteral) ? 'enum:' : ''}string:${t.value}`;
        if (exports.isTypeFlagSet(t, ts.TypeFlags.BigIntLiteral))
            return formatPseudoBigInt(t.value);
        if (_3_2_1.isUniqueESSymbolType(t))
            return t.escapedName;
        if (type_1.isBooleanLiteralType(t, true))
            return 'true';
        if (type_1.isBooleanLiteralType(t, false))
            return 'false';
    }
    function getBaseOfClassLikeExpression(node) {
        var _a;
        if (((_a = node.heritageClauses) === null || _a === void 0 ? void 0 : _a[0].token) === ts.SyntaxKind.ExtendsKeyword)
            return node.heritageClauses[0].types[0];
    }
    exports.getBaseOfClassLikeExpression = getBaseOfClassLikeExpression;
    
},
/* tsutils/typeguard/3.2/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const tslib_1 = require(58) /* tslib */;
    tslib_1.__exportStar(require(1037) /* ./node */, exports);
    tslib_1.__exportStar(require(1042) /* ./type */, exports);
    
},
/* tsutils/util/type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getBaseClassMemberOfClassElement = exports.getIteratorYieldResultFromIteratorResult = exports.getInstanceTypeOfClassLikeDeclaration = exports.getConstructorTypeOfClassLikeDeclaration = exports.getSymbolOfClassLikeDeclaration = exports.getPropertyNameFromType = exports.symbolHasReadonlyDeclaration = exports.isPropertyReadonlyInType = exports.getWellKnownSymbolPropertyOfType = exports.getPropertyOfType = exports.isBooleanLiteralType = exports.isFalsyType = exports.isThenableType = exports.someTypePart = exports.intersectionTypeParts = exports.unionTypeParts = exports.getCallSignaturesOfType = exports.isTypeAssignableToString = exports.isTypeAssignableToNumber = exports.isOptionalChainingUndefinedMarkerType = exports.removeOptionalChainingUndefinedMarkerType = exports.removeOptionalityFromType = exports.isEmptyObjectType = void 0;
    const ts = require(21) /* typescript */;
    const type_1 = require(1041) /* ../typeguard/type */;
    const util_1 = require(1047) /* ./util */;
    const node_1 = require(1036) /* ../typeguard/node */;
    function isEmptyObjectType(type) {
        if (type_1.isObjectType(type) &&
            type.objectFlags & ts.ObjectFlags.Anonymous &&
            type.getProperties().length === 0 &&
            type.getCallSignatures().length === 0 &&
            type.getConstructSignatures().length === 0 &&
            type.getStringIndexType() === undefined &&
            type.getNumberIndexType() === undefined) {
            const baseTypes = type.getBaseTypes();
            return baseTypes === undefined || baseTypes.every(isEmptyObjectType);
        }
        return false;
    }
    exports.isEmptyObjectType = isEmptyObjectType;
    function removeOptionalityFromType(checker, type) {
        if (!containsTypeWithFlag(type, ts.TypeFlags.Undefined))
            return type;
        const allowsNull = containsTypeWithFlag(type, ts.TypeFlags.Null);
        type = checker.getNonNullableType(type);
        return allowsNull ? checker.getNullableType(type, ts.TypeFlags.Null) : type;
    }
    exports.removeOptionalityFromType = removeOptionalityFromType;
    function containsTypeWithFlag(type, flag) {
        for (const t of unionTypeParts(type))
            if (util_1.isTypeFlagSet(t, flag))
                return true;
        return false;
    }
    function removeOptionalChainingUndefinedMarkerType(checker, type) {
        if (!type_1.isUnionType(type))
            return isOptionalChainingUndefinedMarkerType(checker, type) ? type.getNonNullableType() : type;
        let flags = 0;
        let containsUndefinedMarker = false;
        for (const t of type.types) {
            if (isOptionalChainingUndefinedMarkerType(checker, t)) {
                containsUndefinedMarker = true;
            }
            else {
                flags |= t.flags;
            }
        }
        return containsUndefinedMarker
            ? checker.getNullableType(type.getNonNullableType(), flags)
            : type;
    }
    exports.removeOptionalChainingUndefinedMarkerType = removeOptionalChainingUndefinedMarkerType;
    function isOptionalChainingUndefinedMarkerType(checker, t) {
        return util_1.isTypeFlagSet(t, ts.TypeFlags.Undefined) && checker.getNullableType(t.getNonNullableType(), ts.TypeFlags.Undefined) !== t;
    }
    exports.isOptionalChainingUndefinedMarkerType = isOptionalChainingUndefinedMarkerType;
    function isTypeAssignableToNumber(checker, type) {
        return isTypeAssignableTo(checker, type, ts.TypeFlags.NumberLike);
    }
    exports.isTypeAssignableToNumber = isTypeAssignableToNumber;
    function isTypeAssignableToString(checker, type) {
        return isTypeAssignableTo(checker, type, ts.TypeFlags.StringLike);
    }
    exports.isTypeAssignableToString = isTypeAssignableToString;
    function isTypeAssignableTo(checker, type, flags) {
        flags |= ts.TypeFlags.Any;
        let typeParametersSeen;
        return (function check(t) {
            if (type_1.isTypeParameter(t) && t.symbol !== undefined && t.symbol.declarations !== undefined) {
                if (typeParametersSeen === undefined) {
                    typeParametersSeen = new Set([t]);
                }
                else if (!typeParametersSeen.has(t)) {
                    typeParametersSeen.add(t);
                }
                else {
                    return false;
                }
                const declaration = t.symbol.declarations[0];
                if (declaration.constraint === undefined)
                    return true; // TODO really?
                return check(checker.getTypeFromTypeNode(declaration.constraint));
            }
            if (type_1.isUnionType(t))
                return t.types.every(check);
            if (type_1.isIntersectionType(t))
                return t.types.some(check);
            return util_1.isTypeFlagSet(t, flags);
        })(type);
    }
    function getCallSignaturesOfType(type) {
        if (type_1.isUnionType(type)) {
            const signatures = [];
            for (const t of type.types)
                signatures.push(...getCallSignaturesOfType(t));
            return signatures;
        }
        if (type_1.isIntersectionType(type)) {
            let signatures;
            for (const t of type.types) {
                const sig = getCallSignaturesOfType(t);
                if (sig.length !== 0) {
                    if (signatures !== undefined)
                        return []; // if more than one type of the intersection has call signatures, none of them is useful for inference
                    signatures = sig;
                }
            }
            return signatures === undefined ? [] : signatures;
        }
        return type.getCallSignatures();
    }
    exports.getCallSignaturesOfType = getCallSignaturesOfType;
    /** Returns all types of a union type or an array containing `type` itself if it's no union type. */
    function unionTypeParts(type) {
        return type_1.isUnionType(type) ? type.types : [type];
    }
    exports.unionTypeParts = unionTypeParts;
    /** Returns all types of a intersection type or an array containing `type` itself if it's no intersection type. */
    function intersectionTypeParts(type) {
        return type_1.isIntersectionType(type) ? type.types : [type];
    }
    exports.intersectionTypeParts = intersectionTypeParts;
    function someTypePart(type, predicate, cb) {
        return predicate(type) ? type.types.some(cb) : cb(type);
    }
    exports.someTypePart = someTypePart;
    function isThenableType(checker, node, type = checker.getTypeAtLocation(node)) {
        for (const ty of unionTypeParts(checker.getApparentType(type))) {
            const then = ty.getProperty('then');
            if (then === undefined)
                continue;
            const thenType = checker.getTypeOfSymbolAtLocation(then, node);
            for (const t of unionTypeParts(thenType))
                for (const signature of t.getCallSignatures())
                    if (signature.parameters.length !== 0 && isCallback(checker, signature.parameters[0], node))
                        return true;
        }
        return false;
    }
    exports.isThenableType = isThenableType;
    function isCallback(checker, param, node) {
        let type = checker.getApparentType(checker.getTypeOfSymbolAtLocation(param, node));
        if (param.valueDeclaration.dotDotDotToken) {
            // unwrap array type of rest parameter
            type = type.getNumberIndexType();
            if (type === undefined)
                return false;
        }
        for (const t of unionTypeParts(type))
            if (t.getCallSignatures().length !== 0)
                return true;
        return false;
    }
    /** Determine if a type is definitely falsy. This function doesn't unwrap union types. */
    function isFalsyType(type) {
        if (type.flags & (ts.TypeFlags.Undefined | ts.TypeFlags.Null | ts.TypeFlags.Void))
            return true;
        if (type_1.isLiteralType(type))
            return !type.value;
        return isBooleanLiteralType(type, false);
    }
    exports.isFalsyType = isFalsyType;
    /** Determines whether the given type is a boolean literal type and matches the given boolean literal (true or false). */
    function isBooleanLiteralType(type, literal) {
        return util_1.isTypeFlagSet(type, ts.TypeFlags.BooleanLiteral) &&
            type.intrinsicName === (literal ? 'true' : 'false');
    }
    exports.isBooleanLiteralType = isBooleanLiteralType;
    function getPropertyOfType(type, name) {
        if (!name.startsWith('__'))
            return type.getProperty(name);
        return type.getProperties().find((s) => s.escapedName === name);
    }
    exports.getPropertyOfType = getPropertyOfType;
    function getWellKnownSymbolPropertyOfType(type, wellKnownSymbolName, checker) {
        const prefix = '__@' + wellKnownSymbolName;
        for (const prop of type.getProperties()) {
            if (!prop.name.startsWith(prefix))
                continue;
            const globalSymbol = checker.getApparentType(checker.getTypeAtLocation(prop.valueDeclaration.name.expression)).symbol;
            if (prop.escapedName === getPropertyNameOfWellKnownSymbol(checker, globalSymbol, wellKnownSymbolName))
                return prop;
        }
        return;
    }
    exports.getWellKnownSymbolPropertyOfType = getWellKnownSymbolPropertyOfType;
    function getPropertyNameOfWellKnownSymbol(checker, symbolConstructor, symbolName) {
        const knownSymbol = symbolConstructor &&
            checker.getTypeOfSymbolAtLocation(symbolConstructor, symbolConstructor.valueDeclaration).getProperty(symbolName);
        const knownSymbolType = knownSymbol && checker.getTypeOfSymbolAtLocation(knownSymbol, knownSymbol.valueDeclaration);
        if (knownSymbolType && type_1.isUniqueESSymbolType(knownSymbolType))
            return knownSymbolType.escapedName;
        return ('__@' + symbolName);
    }
    /** Determines if writing to a certain property of a given type is allowed. */
    function isPropertyReadonlyInType(type, name, checker) {
        let seenProperty = false;
        let seenReadonlySignature = false;
        for (const t of unionTypeParts(type)) {
            if (getPropertyOfType(t, name) === undefined) {
                // property is not present in this part of the union -> check for readonly index signature
                const index = (util_1.isNumericPropertyName(name) ? checker.getIndexInfoOfType(t, ts.IndexKind.Number) : undefined) ||
                    checker.getIndexInfoOfType(t, ts.IndexKind.String);
                if (index !== undefined && index.isReadonly) {
                    if (seenProperty)
                        return true;
                    seenReadonlySignature = true;
                }
            }
            else if (seenReadonlySignature || isReadonlyPropertyIntersection(t, name, checker)) {
                return true;
            }
            else {
                seenProperty = true;
            }
        }
        return false;
    }
    exports.isPropertyReadonlyInType = isPropertyReadonlyInType;
    function isReadonlyPropertyIntersection(type, name, checker) {
        return someTypePart(type, type_1.isIntersectionType, (t) => {
            const prop = getPropertyOfType(t, name);
            if (prop === undefined)
                return false;
            if (prop.flags & ts.SymbolFlags.Transient) {
                if (/^(?:[1-9]\d*|0)$/.test(name) && type_1.isTupleTypeReference(t))
                    return t.target.readonly;
                switch (isReadonlyPropertyFromMappedType(t, name, checker)) {
                    case true:
                        return true;
                    case false:
                        return false;
                    default:
                    // `undefined` falls through
                }
            }
            return (
            // members of namespace import
            util_1.isSymbolFlagSet(prop, ts.SymbolFlags.ValueModule) ||
                // we unwrapped every mapped type, now we can check the actual declarations
                symbolHasReadonlyDeclaration(prop, checker));
        });
    }
    function isReadonlyPropertyFromMappedType(type, name, checker) {
        if (!type_1.isObjectType(type) || !util_1.isObjectFlagSet(type, ts.ObjectFlags.Mapped))
            return;
        const declaration = type.symbol.declarations[0];
        // well-known symbols are not affected by mapped types
        if (declaration.readonlyToken !== undefined && !/^__@[^@]+$/.test(name))
            return declaration.readonlyToken.kind !== ts.SyntaxKind.MinusToken;
        return isPropertyReadonlyInType(type.modifiersType, name, checker);
    }
    function symbolHasReadonlyDeclaration(symbol, checker) {
        return (symbol.flags & ts.SymbolFlags.Accessor) === ts.SymbolFlags.GetAccessor ||
            symbol.declarations !== undefined &&
                symbol.declarations.some((node) => util_1.isModifierFlagSet(node, ts.ModifierFlags.Readonly) ||
                    node_1.isVariableDeclaration(node) && util_1.isNodeFlagSet(node.parent, ts.NodeFlags.Const) ||
                    node_1.isCallExpression(node) && util_1.isReadonlyAssignmentDeclaration(node, checker) ||
                    node_1.isEnumMember(node) ||
                    (node_1.isPropertyAssignment(node) || node_1.isShorthandPropertyAssignment(node)) && util_1.isInConstContext(node.parent));
    }
    exports.symbolHasReadonlyDeclaration = symbolHasReadonlyDeclaration;
    /** Returns the the literal name or unique symbol name from a given type. Doesn't unwrap union types. */
    function getPropertyNameFromType(type) {
        // string or number literal. bigint is intentionally excluded
        if (type.flags & (ts.TypeFlags.StringLiteral | ts.TypeFlags.NumberLiteral)) {
            const value = String(type.value);
            return { displayName: value, symbolName: ts.escapeLeadingUnderscores(value) };
        }
        if (type_1.isUniqueESSymbolType(type))
            return {
                displayName: `[${type.symbol
                    ? `${isKnownSymbol(type.symbol) ? 'Symbol.' : ''}${type.symbol.name}`
                    : type.escapedName.replace(/^__@|@\d+$/g, '')}]`,
                symbolName: type.escapedName,
            };
    }
    exports.getPropertyNameFromType = getPropertyNameFromType;
    function isKnownSymbol(symbol) {
        return util_1.isSymbolFlagSet(symbol, ts.SymbolFlags.Property) &&
            symbol.valueDeclaration !== undefined &&
            node_1.isInterfaceDeclaration(symbol.valueDeclaration.parent) &&
            symbol.valueDeclaration.parent.name.text === 'SymbolConstructor' &&
            isGlobalDeclaration(symbol.valueDeclaration.parent);
    }
    function isGlobalDeclaration(node) {
        return util_1.isNodeFlagSet(node.parent, ts.NodeFlags.GlobalAugmentation) || node_1.isSourceFile(node.parent) && !ts.isExternalModule(node.parent);
    }
    function getSymbolOfClassLikeDeclaration(node, checker) {
        var _a;
        return checker.getSymbolAtLocation((_a = node.name) !== null && _a !== void 0 ? _a : util_1.getChildOfKind(node, ts.SyntaxKind.ClassKeyword));
    }
    exports.getSymbolOfClassLikeDeclaration = getSymbolOfClassLikeDeclaration;
    function getConstructorTypeOfClassLikeDeclaration(node, checker) {
        return node.kind === ts.SyntaxKind.ClassExpression
            ? checker.getTypeAtLocation(node)
            : checker.getTypeOfSymbolAtLocation(getSymbolOfClassLikeDeclaration(node, checker), node);
    }
    exports.getConstructorTypeOfClassLikeDeclaration = getConstructorTypeOfClassLikeDeclaration;
    function getInstanceTypeOfClassLikeDeclaration(node, checker) {
        return node.kind === ts.SyntaxKind.ClassDeclaration
            ? checker.getTypeAtLocation(node)
            : checker.getDeclaredTypeOfSymbol(getSymbolOfClassLikeDeclaration(node, checker));
    }
    exports.getInstanceTypeOfClassLikeDeclaration = getInstanceTypeOfClassLikeDeclaration;
    function getIteratorYieldResultFromIteratorResult(type, node, checker) {
        return type_1.isUnionType(type) && type.types.find((t) => {
            const done = t.getProperty('done');
            return done !== undefined &&
                isBooleanLiteralType(removeOptionalityFromType(checker, checker.getTypeOfSymbolAtLocation(done, node)), false);
        }) || type;
    }
    exports.getIteratorYieldResultFromIteratorResult = getIteratorYieldResultFromIteratorResult;
    /** Lookup the declaration of a class member in the super class. */
    function getBaseClassMemberOfClassElement(node, checker) {
        if (!node_1.isClassLikeDeclaration(node.parent))
            return;
        const base = util_1.getBaseOfClassLikeExpression(node.parent);
        if (base === undefined)
            return;
        const name = util_1.getSingleLateBoundPropertyNameOfPropertyName(node.name, checker);
        if (name === undefined)
            return;
        const baseType = checker.getTypeAtLocation(util_1.hasModifier(node.modifiers, ts.SyntaxKind.StaticKeyword)
            ? base.expression
            : base);
        return getPropertyOfType(baseType, name.symbolName);
    }
    exports.getBaseClassMemberOfClassElement = getBaseClassMemberOfClassElement;
    
},
/* tsutils/util/usage.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.collectVariableUsage = exports.getDeclarationDomain = exports.getUsageDomain = exports.UsageDomain = exports.DeclarationDomain = void 0;
    const util_1 = require(1047) /* ./util */;
    const ts = require(21) /* typescript */;
    var DeclarationDomain;
    (function (DeclarationDomain) {
        DeclarationDomain[DeclarationDomain["Namespace"] = 1] = "Namespace";
        DeclarationDomain[DeclarationDomain["Type"] = 2] = "Type";
        DeclarationDomain[DeclarationDomain["Value"] = 4] = "Value";
        DeclarationDomain[DeclarationDomain["Import"] = 8] = "Import";
        DeclarationDomain[DeclarationDomain["Any"] = 7] = "Any";
    })(DeclarationDomain = exports.DeclarationDomain || (exports.DeclarationDomain = {}));
    var UsageDomain;
    (function (UsageDomain) {
        UsageDomain[UsageDomain["Namespace"] = 1] = "Namespace";
        UsageDomain[UsageDomain["Type"] = 2] = "Type";
        UsageDomain[UsageDomain["Value"] = 4] = "Value";
        UsageDomain[UsageDomain["ValueOrNamespace"] = 5] = "ValueOrNamespace";
        UsageDomain[UsageDomain["Any"] = 7] = "Any";
        UsageDomain[UsageDomain["TypeQuery"] = 8] = "TypeQuery";
    })(UsageDomain = exports.UsageDomain || (exports.UsageDomain = {}));
    // TODO handle cases where values are used only for their types, e.g. `declare [propSymbol]: number`
    function getUsageDomain(node) {
        const parent = node.parent;
        switch (parent.kind) {
            case ts.SyntaxKind.TypeReference:
                return node.originalKeywordKind !== ts.SyntaxKind.ConstKeyword ? 2 /* Type */ : undefined;
            case ts.SyntaxKind.ExpressionWithTypeArguments:
                return parent.parent.token === ts.SyntaxKind.ImplementsKeyword ||
                    parent.parent.parent.kind === ts.SyntaxKind.InterfaceDeclaration
                    ? 2 /* Type */
                    : 4 /* Value */;
            case ts.SyntaxKind.TypeQuery:
                return 5 /* ValueOrNamespace */ | 8 /* TypeQuery */;
            case ts.SyntaxKind.QualifiedName:
                if (parent.left === node) {
                    if (getEntityNameParent(parent).kind === ts.SyntaxKind.TypeQuery)
                        return 1 /* Namespace */ | 8 /* TypeQuery */;
                    return 1 /* Namespace */;
                }
                break;
            case ts.SyntaxKind.ExportSpecifier:
                // either {name} or {propertyName as name}
                if (parent.propertyName === undefined ||
                    parent.propertyName === node)
                    return 7 /* Any */; // TODO handle type-only exports
                break;
            case ts.SyntaxKind.ExportAssignment:
                return 7 /* Any */;
            // Value
            case ts.SyntaxKind.BindingElement:
                if (parent.initializer === node)
                    return 5 /* ValueOrNamespace */;
                break;
            case ts.SyntaxKind.Parameter:
            case ts.SyntaxKind.EnumMember:
            case ts.SyntaxKind.PropertyDeclaration:
            case ts.SyntaxKind.VariableDeclaration:
            case ts.SyntaxKind.PropertyAssignment:
            case ts.SyntaxKind.PropertyAccessExpression:
            case ts.SyntaxKind.ImportEqualsDeclaration:
                if (parent.name !== node)
                    return 5 /* ValueOrNamespace */; // TODO handle type-only imports
                break;
            case ts.SyntaxKind.JsxAttribute:
            case ts.SyntaxKind.FunctionDeclaration:
            case ts.SyntaxKind.FunctionExpression:
            case ts.SyntaxKind.NamespaceImport:
            case ts.SyntaxKind.ClassDeclaration:
            case ts.SyntaxKind.ClassExpression:
            case ts.SyntaxKind.ModuleDeclaration:
            case ts.SyntaxKind.MethodDeclaration:
            case ts.SyntaxKind.EnumDeclaration:
            case ts.SyntaxKind.GetAccessor:
            case ts.SyntaxKind.SetAccessor:
            case ts.SyntaxKind.LabeledStatement:
            case ts.SyntaxKind.BreakStatement:
            case ts.SyntaxKind.ContinueStatement:
            case ts.SyntaxKind.ImportClause:
            case ts.SyntaxKind.ImportSpecifier:
            case ts.SyntaxKind.TypePredicate: // TODO this actually references a parameter
            case ts.SyntaxKind.MethodSignature:
            case ts.SyntaxKind.PropertySignature:
            case ts.SyntaxKind.NamespaceExportDeclaration:
            case ts.SyntaxKind.NamespaceExport:
            case ts.SyntaxKind.InterfaceDeclaration:
            case ts.SyntaxKind.TypeAliasDeclaration:
            case ts.SyntaxKind.TypeParameter:
            case ts.SyntaxKind.NamedTupleMember:
                break;
            default:
                return 5 /* ValueOrNamespace */;
        }
    }
    exports.getUsageDomain = getUsageDomain;
    function getDeclarationDomain(node) {
        switch (node.parent.kind) {
            case ts.SyntaxKind.TypeParameter:
            case ts.SyntaxKind.InterfaceDeclaration:
            case ts.SyntaxKind.TypeAliasDeclaration:
                return 2 /* Type */;
            case ts.SyntaxKind.ClassDeclaration:
            case ts.SyntaxKind.ClassExpression:
                return 2 /* Type */ | 4 /* Value */;
            case ts.SyntaxKind.EnumDeclaration:
                return 7 /* Any */;
            case ts.SyntaxKind.NamespaceImport:
            case ts.SyntaxKind.ImportClause:
                return 7 /* Any */ | 8 /* Import */; // TODO handle type-only imports
            case ts.SyntaxKind.ImportEqualsDeclaration:
            case ts.SyntaxKind.ImportSpecifier:
                return node.parent.name === node
                    ? 7 /* Any */ | 8 /* Import */ // TODO handle type-only imports
                    : undefined;
            case ts.SyntaxKind.ModuleDeclaration:
                return 1 /* Namespace */;
            case ts.SyntaxKind.Parameter:
                if (node.parent.parent.kind === ts.SyntaxKind.IndexSignature || node.originalKeywordKind === ts.SyntaxKind.ThisKeyword)
                    return;
            // falls through
            case ts.SyntaxKind.BindingElement:
            case ts.SyntaxKind.VariableDeclaration:
                return node.parent.name === node ? 4 /* Value */ : undefined;
            case ts.SyntaxKind.FunctionDeclaration:
            case ts.SyntaxKind.FunctionExpression:
                return 4 /* Value */;
        }
    }
    exports.getDeclarationDomain = getDeclarationDomain;
    function collectVariableUsage(sourceFile) {
        return new UsageWalker().getUsage(sourceFile);
    }
    exports.collectVariableUsage = collectVariableUsage;
    class AbstractScope {
        constructor(_global) {
            this._global = _global;
            this._variables = new Map();
            this._uses = [];
            this._namespaceScopes = undefined;
            this._enumScopes = undefined;
        }
        addVariable(identifier, name, selector, exported, domain) {
            const variables = this.getDestinationScope(selector).getVariables();
            const declaration = {
                domain,
                exported,
                declaration: name,
            };
            const variable = variables.get(identifier);
            if (variable === undefined) {
                variables.set(identifier, {
                    domain,
                    declarations: [declaration],
                    uses: [],
                });
            }
            else {
                variable.domain |= domain;
                variable.declarations.push(declaration);
            }
        }
        addUse(use) {
            this._uses.push(use);
        }
        getVariables() {
            return this._variables;
        }
        getFunctionScope() {
            return this;
        }
        end(cb) {
            if (this._namespaceScopes !== undefined)
                this._namespaceScopes.forEach((value) => value.finish(cb));
            this._namespaceScopes = this._enumScopes = undefined;
            this._applyUses();
            this._variables.forEach((variable) => {
                for (const declaration of variable.declarations) {
                    const result = {
                        declarations: [],
                        domain: declaration.domain,
                        exported: declaration.exported,
                        inGlobalScope: this._global,
                        uses: [],
                    };
                    for (const other of variable.declarations)
                        if (other.domain & declaration.domain)
                            result.declarations.push(other.declaration);
                    for (const use of variable.uses)
                        if (use.domain & declaration.domain)
                            result.uses.push(use);
                    cb(result, declaration.declaration, this);
                }
            });
        }
        // tslint:disable-next-line:prefer-function-over-method
        markExported(_name) { } // only relevant for the root scope
        createOrReuseNamespaceScope(name, _exported, ambient, hasExportStatement) {
            let scope;
            if (this._namespaceScopes === undefined) {
                this._namespaceScopes = new Map();
            }
            else {
                scope = this._namespaceScopes.get(name);
            }
            if (scope === undefined) {
                scope = new NamespaceScope(ambient, hasExportStatement, this);
                this._namespaceScopes.set(name, scope);
            }
            else {
                scope.refresh(ambient, hasExportStatement);
            }
            return scope;
        }
        createOrReuseEnumScope(name, _exported) {
            let scope;
            if (this._enumScopes === undefined) {
                this._enumScopes = new Map();
            }
            else {
                scope = this._enumScopes.get(name);
            }
            if (scope === undefined) {
                scope = new EnumScope(this);
                this._enumScopes.set(name, scope);
            }
            return scope;
        }
        _applyUses() {
            for (const use of this._uses)
                if (!this._applyUse(use))
                    this._addUseToParent(use);
            this._uses = [];
        }
        _applyUse(use, variables = this._variables) {
            const variable = variables.get(use.location.text);
            if (variable === undefined || (variable.domain & use.domain) === 0)
                return false;
            variable.uses.push(use);
            return true;
        }
        _addUseToParent(_use) { } // tslint:disable-line:prefer-function-over-method
    }
    class RootScope extends AbstractScope {
        constructor(_exportAll, global) {
            super(global);
            this._exportAll = _exportAll;
            this._exports = undefined;
            this._innerScope = new NonRootScope(this, 1 /* Function */);
        }
        addVariable(identifier, name, selector, exported, domain) {
            if (domain & 8 /* Import */)
                return super.addVariable(identifier, name, selector, exported, domain);
            return this._innerScope.addVariable(identifier, name, selector, exported, domain);
        }
        addUse(use, origin) {
            if (origin === this._innerScope)
                return super.addUse(use);
            return this._innerScope.addUse(use);
        }
        markExported(id) {
            if (this._exports === undefined) {
                this._exports = [id.text];
            }
            else {
                this._exports.push(id.text);
            }
        }
        end(cb) {
            this._innerScope.end((value, key) => {
                value.exported = value.exported || this._exportAll
                    || this._exports !== undefined && this._exports.includes(key.text);
                value.inGlobalScope = this._global;
                return cb(value, key, this);
            });
            return super.end((value, key, scope) => {
                value.exported = value.exported || scope === this
                    && this._exports !== undefined && this._exports.includes(key.text);
                return cb(value, key, scope);
            });
        }
        getDestinationScope() {
            return this;
        }
    }
    class NonRootScope extends AbstractScope {
        constructor(_parent, _boundary) {
            super(false);
            this._parent = _parent;
            this._boundary = _boundary;
        }
        _addUseToParent(use) {
            return this._parent.addUse(use, this);
        }
        getDestinationScope(selector) {
            return this._boundary & selector
                ? this
                : this._parent.getDestinationScope(selector);
        }
    }
    class EnumScope extends NonRootScope {
        constructor(parent) {
            super(parent, 1 /* Function */);
        }
        end() {
            this._applyUses();
        }
    }
    class ConditionalTypeScope extends NonRootScope {
        constructor(parent) {
            super(parent, 8 /* ConditionalType */);
            this._state = 0 /* Initial */;
        }
        updateState(newState) {
            this._state = newState;
        }
        addUse(use) {
            if (this._state === 2 /* TrueType */)
                return void this._uses.push(use);
            return this._parent.addUse(use, this);
        }
    }
    class FunctionScope extends NonRootScope {
        constructor(parent) {
            super(parent, 1 /* Function */);
        }
        beginBody() {
            this._applyUses();
        }
    }
    class AbstractNamedExpressionScope extends NonRootScope {
        constructor(_name, _domain, parent) {
            super(parent, 1 /* Function */);
            this._name = _name;
            this._domain = _domain;
        }
        end(cb) {
            this._innerScope.end(cb);
            return cb({
                declarations: [this._name],
                domain: this._domain,
                exported: false,
                uses: this._uses,
                inGlobalScope: false,
            }, this._name, this);
        }
        addUse(use, source) {
            if (source !== this._innerScope)
                return this._innerScope.addUse(use);
            if (use.domain & this._domain && use.location.text === this._name.text) {
                this._uses.push(use);
            }
            else {
                return this._parent.addUse(use, this);
            }
        }
        getFunctionScope() {
            return this._innerScope;
        }
        getDestinationScope() {
            return this._innerScope;
        }
    }
    class FunctionExpressionScope extends AbstractNamedExpressionScope {
        constructor(name, parent) {
            super(name, 4 /* Value */, parent);
            this._innerScope = new FunctionScope(this);
        }
        beginBody() {
            return this._innerScope.beginBody();
        }
    }
    class ClassExpressionScope extends AbstractNamedExpressionScope {
        constructor(name, parent) {
            super(name, 4 /* Value */ | 2 /* Type */, parent);
            this._innerScope = new NonRootScope(this, 1 /* Function */);
        }
    }
    class BlockScope extends NonRootScope {
        constructor(_functionScope, parent) {
            super(parent, 2 /* Block */);
            this._functionScope = _functionScope;
        }
        getFunctionScope() {
            return this._functionScope;
        }
    }
    function mapDeclaration(declaration) {
        return {
            declaration,
            exported: true,
            domain: getDeclarationDomain(declaration),
        };
    }
    class NamespaceScope extends NonRootScope {
        constructor(_ambient, _hasExport, parent) {
            super(parent, 1 /* Function */);
            this._ambient = _ambient;
            this._hasExport = _hasExport;
            this._innerScope = new NonRootScope(this, 1 /* Function */);
            this._exports = undefined;
        }
        finish(cb) {
            return super.end(cb);
        }
        end(cb) {
            this._innerScope.end((variable, key, scope) => {
                if (scope !== this._innerScope ||
                    !variable.exported && (!this._ambient || this._exports !== undefined && !this._exports.has(key.text)))
                    return cb(variable, key, scope);
                const namespaceVar = this._variables.get(key.text);
                if (namespaceVar === undefined) {
                    this._variables.set(key.text, {
                        declarations: variable.declarations.map(mapDeclaration),
                        domain: variable.domain,
                        uses: [...variable.uses],
                    });
                }
                else {
                    outer: for (const declaration of variable.declarations) {
                        for (const existing of namespaceVar.declarations)
                            if (existing.declaration === declaration)
                                continue outer;
                        namespaceVar.declarations.push(mapDeclaration(declaration));
                    }
                    namespaceVar.domain |= variable.domain;
                    for (const use of variable.uses) {
                        if (namespaceVar.uses.includes(use))
                            continue;
                        namespaceVar.uses.push(use);
                    }
                }
            });
            this._applyUses();
            this._innerScope = new NonRootScope(this, 1 /* Function */);
        }
        createOrReuseNamespaceScope(name, exported, ambient, hasExportStatement) {
            if (!exported && (!this._ambient || this._hasExport))
                return this._innerScope.createOrReuseNamespaceScope(name, exported, ambient || this._ambient, hasExportStatement);
            return super.createOrReuseNamespaceScope(name, exported, ambient || this._ambient, hasExportStatement);
        }
        createOrReuseEnumScope(name, exported) {
            if (!exported && (!this._ambient || this._hasExport))
                return this._innerScope.createOrReuseEnumScope(name, exported);
            return super.createOrReuseEnumScope(name, exported);
        }
        addUse(use, source) {
            if (source !== this._innerScope)
                return this._innerScope.addUse(use);
            this._uses.push(use);
        }
        refresh(ambient, hasExport) {
            this._ambient = ambient;
            this._hasExport = hasExport;
        }
        markExported(name, _as) {
            if (this._exports === undefined)
                this._exports = new Set();
            this._exports.add(name.text);
        }
        getDestinationScope() {
            return this._innerScope;
        }
    }
    function getEntityNameParent(name) {
        let parent = name.parent;
        while (parent.kind === ts.SyntaxKind.QualifiedName)
            parent = parent.parent;
        return parent;
    }
    // TODO class decorators resolve outside of class, element and parameter decorator resolve inside/at the class
    // TODO computed property name resolves inside/at the cass
    // TODO this and super in all of them are resolved outside of the class
    class UsageWalker {
        constructor() {
            this._result = new Map();
        }
        getUsage(sourceFile) {
            const variableCallback = (variable, key) => {
                this._result.set(key, variable);
            };
            const isModule = ts.isExternalModule(sourceFile);
            this._scope = new RootScope(sourceFile.isDeclarationFile && isModule && !containsExportStatement(sourceFile), !isModule);
            const cb = (node) => {
                if (util_1.isBlockScopeBoundary(node))
                    return continueWithScope(node, new BlockScope(this._scope.getFunctionScope(), this._scope), handleBlockScope);
                switch (node.kind) {
                    case ts.SyntaxKind.ClassExpression:
                        return continueWithScope(node, node.name !== undefined
                            ? new ClassExpressionScope(node.name, this._scope)
                            : new NonRootScope(this._scope, 1 /* Function */));
                    case ts.SyntaxKind.ClassDeclaration:
                        this._handleDeclaration(node, true, 4 /* Value */ | 2 /* Type */);
                        return continueWithScope(node, new NonRootScope(this._scope, 1 /* Function */));
                    case ts.SyntaxKind.InterfaceDeclaration:
                    case ts.SyntaxKind.TypeAliasDeclaration:
                        this._handleDeclaration(node, true, 2 /* Type */);
                        return continueWithScope(node, new NonRootScope(this._scope, 4 /* Type */));
                    case ts.SyntaxKind.EnumDeclaration:
                        this._handleDeclaration(node, true, 7 /* Any */);
                        return continueWithScope(node, this._scope.createOrReuseEnumScope(node.name.text, util_1.hasModifier(node.modifiers, ts.SyntaxKind.ExportKeyword)));
                    case ts.SyntaxKind.ModuleDeclaration:
                        return this._handleModule(node, continueWithScope);
                    case ts.SyntaxKind.MappedType:
                        return continueWithScope(node, new NonRootScope(this._scope, 4 /* Type */));
                    case ts.SyntaxKind.FunctionExpression:
                    case ts.SyntaxKind.ArrowFunction:
                    case ts.SyntaxKind.Constructor:
                    case ts.SyntaxKind.MethodDeclaration:
                    case ts.SyntaxKind.FunctionDeclaration:
                    case ts.SyntaxKind.GetAccessor:
                    case ts.SyntaxKind.SetAccessor:
                    case ts.SyntaxKind.MethodSignature:
                    case ts.SyntaxKind.CallSignature:
                    case ts.SyntaxKind.ConstructSignature:
                    case ts.SyntaxKind.ConstructorType:
                    case ts.SyntaxKind.FunctionType:
                        return this._handleFunctionLikeDeclaration(node, cb, variableCallback);
                    case ts.SyntaxKind.ConditionalType:
                        return this._handleConditionalType(node, cb, variableCallback);
                    // End of Scope specific handling
                    case ts.SyntaxKind.VariableDeclarationList:
                        this._handleVariableDeclaration(node);
                        break;
                    case ts.SyntaxKind.Parameter:
                        if (node.parent.kind !== ts.SyntaxKind.IndexSignature &&
                            (node.name.kind !== ts.SyntaxKind.Identifier ||
                                node.name.originalKeywordKind !== ts.SyntaxKind.ThisKeyword))
                            this._handleBindingName(node.name, false, false);
                        break;
                    case ts.SyntaxKind.EnumMember:
                        this._scope.addVariable(util_1.getPropertyName(node.name), node.name, 1 /* Function */, true, 4 /* Value */);
                        break;
                    case ts.SyntaxKind.ImportClause:
                    case ts.SyntaxKind.ImportSpecifier:
                    case ts.SyntaxKind.NamespaceImport:
                    case ts.SyntaxKind.ImportEqualsDeclaration:
                        this._handleDeclaration(node, false, 7 /* Any */ | 8 /* Import */);
                        break;
                    case ts.SyntaxKind.TypeParameter:
                        this._scope.addVariable(node.name.text, node.name, node.parent.kind === ts.SyntaxKind.InferType ? 8 /* InferType */ : 7 /* Type */, false, 2 /* Type */);
                        break;
                    case ts.SyntaxKind.ExportSpecifier:
                        if (node.propertyName !== undefined)
                            return this._scope.markExported(node.propertyName, node.name);
                        return this._scope.markExported(node.name);
                    case ts.SyntaxKind.ExportAssignment:
                        if (node.expression.kind === ts.SyntaxKind.Identifier)
                            return this._scope.markExported(node.expression);
                        break;
                    case ts.SyntaxKind.Identifier:
                        const domain = getUsageDomain(node);
                        if (domain !== undefined)
                            this._scope.addUse({ domain, location: node });
                        return;
                }
                return ts.forEachChild(node, cb);
            };
            const continueWithScope = (node, scope, next = forEachChild) => {
                const savedScope = this._scope;
                this._scope = scope;
                next(node);
                this._scope.end(variableCallback);
                this._scope = savedScope;
            };
            const handleBlockScope = (node) => {
                if (node.kind === ts.SyntaxKind.CatchClause && node.variableDeclaration !== undefined)
                    this._handleBindingName(node.variableDeclaration.name, true, false);
                return ts.forEachChild(node, cb);
            };
            ts.forEachChild(sourceFile, cb);
            this._scope.end(variableCallback);
            return this._result;
            function forEachChild(node) {
                return ts.forEachChild(node, cb);
            }
        }
        _handleConditionalType(node, cb, varCb) {
            const savedScope = this._scope;
            const scope = this._scope = new ConditionalTypeScope(savedScope);
            cb(node.checkType);
            scope.updateState(1 /* Extends */);
            cb(node.extendsType);
            scope.updateState(2 /* TrueType */);
            cb(node.trueType);
            scope.updateState(3 /* FalseType */);
            cb(node.falseType);
            scope.end(varCb);
            this._scope = savedScope;
        }
        _handleFunctionLikeDeclaration(node, cb, varCb) {
            if (node.decorators !== undefined)
                node.decorators.forEach(cb);
            const savedScope = this._scope;
            if (node.kind === ts.SyntaxKind.FunctionDeclaration)
                this._handleDeclaration(node, false, 4 /* Value */);
            const scope = this._scope = node.kind === ts.SyntaxKind.FunctionExpression && node.name !== undefined
                ? new FunctionExpressionScope(node.name, savedScope)
                : new FunctionScope(savedScope);
            if (node.name !== undefined)
                cb(node.name);
            if (node.typeParameters !== undefined)
                node.typeParameters.forEach(cb);
            node.parameters.forEach(cb);
            if (node.type !== undefined)
                cb(node.type);
            if (node.body !== undefined) {
                scope.beginBody();
                cb(node.body);
            }
            scope.end(varCb);
            this._scope = savedScope;
        }
        _handleModule(node, next) {
            if (node.flags & ts.NodeFlags.GlobalAugmentation)
                return next(node, this._scope.createOrReuseNamespaceScope('-global', false, true, false));
            if (node.name.kind === ts.SyntaxKind.Identifier) {
                const exported = isNamespaceExported(node);
                this._scope.addVariable(node.name.text, node.name, 1 /* Function */, exported, 1 /* Namespace */ | 4 /* Value */);
                const ambient = util_1.hasModifier(node.modifiers, ts.SyntaxKind.DeclareKeyword);
                return next(node, this._scope.createOrReuseNamespaceScope(node.name.text, exported, ambient, ambient && namespaceHasExportStatement(node)));
            }
            return next(node, this._scope.createOrReuseNamespaceScope(`"${node.name.text}"`, false, true, namespaceHasExportStatement(node)));
        }
        _handleDeclaration(node, blockScoped, domain) {
            if (node.name !== undefined)
                this._scope.addVariable(node.name.text, node.name, blockScoped ? 3 /* Block */ : 1 /* Function */, util_1.hasModifier(node.modifiers, ts.SyntaxKind.ExportKeyword), domain);
        }
        _handleBindingName(name, blockScoped, exported) {
            if (name.kind === ts.SyntaxKind.Identifier)
                return this._scope.addVariable(name.text, name, blockScoped ? 3 /* Block */ : 1 /* Function */, exported, 4 /* Value */);
            util_1.forEachDestructuringIdentifier(name, (declaration) => {
                this._scope.addVariable(declaration.name.text, declaration.name, blockScoped ? 3 /* Block */ : 1 /* Function */, exported, 4 /* Value */);
            });
        }
        _handleVariableDeclaration(declarationList) {
            const blockScoped = util_1.isBlockScopedVariableDeclarationList(declarationList);
            const exported = declarationList.parent.kind === ts.SyntaxKind.VariableStatement &&
                util_1.hasModifier(declarationList.parent.modifiers, ts.SyntaxKind.ExportKeyword);
            for (const declaration of declarationList.declarations)
                this._handleBindingName(declaration.name, blockScoped, exported);
        }
    }
    function isNamespaceExported(node) {
        return node.parent.kind === ts.SyntaxKind.ModuleDeclaration || util_1.hasModifier(node.modifiers, ts.SyntaxKind.ExportKeyword);
    }
    function namespaceHasExportStatement(ns) {
        if (ns.body === undefined || ns.body.kind !== ts.SyntaxKind.ModuleBlock)
            return false;
        return containsExportStatement(ns.body);
    }
    function containsExportStatement(block) {
        for (const statement of block.statements)
            if (statement.kind === ts.SyntaxKind.ExportDeclaration || statement.kind === ts.SyntaxKind.ExportAssignment)
                return true;
        return false;
    }
    
},
/* tsutils/util/control-flow.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.callExpressionAffectsControlFlow = exports.SignatureEffect = exports.getControlFlowEnd = exports.endsControlFlow = void 0;
    const ts = require(21) /* typescript */;
    const node_1 = require(1036) /* ../typeguard/node */;
    const util_1 = require(1047) /* ./util */;
    function endsControlFlow(statement, checker) {
        return getControlFlowEnd(statement, checker).end;
    }
    exports.endsControlFlow = endsControlFlow;
    const defaultControlFlowEnd = { statements: [], end: false };
    function getControlFlowEnd(statement, checker) {
        return node_1.isBlockLike(statement) ? handleBlock(statement, checker) : getControlFlowEndWorker(statement, checker);
    }
    exports.getControlFlowEnd = getControlFlowEnd;
    function getControlFlowEndWorker(statement, checker) {
        switch (statement.kind) {
            case ts.SyntaxKind.ReturnStatement:
            case ts.SyntaxKind.ThrowStatement:
            case ts.SyntaxKind.ContinueStatement:
            case ts.SyntaxKind.BreakStatement:
                return { statements: [statement], end: true };
            case ts.SyntaxKind.Block:
                return handleBlock(statement, checker);
            case ts.SyntaxKind.ForStatement:
            case ts.SyntaxKind.WhileStatement:
                return handleForAndWhileStatement(statement, checker);
            case ts.SyntaxKind.ForOfStatement:
            case ts.SyntaxKind.ForInStatement:
                return handleForInOrOfStatement(statement, checker);
            case ts.SyntaxKind.DoStatement:
                return matchBreakOrContinue(getControlFlowEndWorker(statement.statement, checker), node_1.isBreakOrContinueStatement);
            case ts.SyntaxKind.IfStatement:
                return handleIfStatement(statement, checker);
            case ts.SyntaxKind.SwitchStatement:
                return matchBreakOrContinue(handleSwitchStatement(statement, checker), node_1.isBreakStatement);
            case ts.SyntaxKind.TryStatement:
                return handleTryStatement(statement, checker);
            case ts.SyntaxKind.LabeledStatement:
                return matchLabel(getControlFlowEndWorker(statement.statement, checker), statement.label);
            case ts.SyntaxKind.WithStatement:
                return getControlFlowEndWorker(statement.statement, checker);
            case ts.SyntaxKind.ExpressionStatement:
                if (checker === undefined)
                    return defaultControlFlowEnd;
                return handleExpressionStatement(statement, checker);
            default:
                return defaultControlFlowEnd;
        }
    }
    function handleBlock(statement, checker) {
        const result = { statements: [], end: false };
        for (const s of statement.statements) {
            const current = getControlFlowEndWorker(s, checker);
            result.statements.push(...current.statements);
            if (current.end) {
                result.end = true;
                break;
            }
        }
        return result;
    }
    function handleForInOrOfStatement(statement, checker) {
        const end = matchBreakOrContinue(getControlFlowEndWorker(statement.statement, checker), node_1.isBreakOrContinueStatement);
        end.end = false; // loop body is guaranteed to be executed
        return end;
    }
    function handleForAndWhileStatement(statement, checker) {
        const constantCondition = statement.kind === ts.SyntaxKind.WhileStatement
            ? getConstantCondition(statement.expression)
            : statement.condition === undefined || getConstantCondition(statement.condition);
        if (constantCondition === false)
            return defaultControlFlowEnd; // loop body is never executed
        const end = matchBreakOrContinue(getControlFlowEndWorker(statement.statement, checker), node_1.isBreakOrContinueStatement);
        if (constantCondition === undefined)
            end.end = false; // can't be sure that loop body is executed at all
        return end;
    }
    /** Simply detects `true` and `false` in conditions. That matches TypeScript's behavior. */
    function getConstantCondition(node) {
        switch (node.kind) {
            case ts.SyntaxKind.TrueKeyword:
                return true;
            case ts.SyntaxKind.FalseKeyword:
                return false;
            default:
                return;
        }
    }
    function handleIfStatement(node, checker) {
        switch (getConstantCondition(node.expression)) {
            case true:
                // else branch is never executed
                return getControlFlowEndWorker(node.thenStatement, checker);
            case false:
                // then branch is never executed
                return node.elseStatement === undefined
                    ? defaultControlFlowEnd
                    : getControlFlowEndWorker(node.elseStatement, checker);
        }
        const then = getControlFlowEndWorker(node.thenStatement, checker);
        if (node.elseStatement === undefined)
            return {
                statements: then.statements,
                end: false,
            };
        const elze = getControlFlowEndWorker(node.elseStatement, checker);
        return {
            statements: [...then.statements, ...elze.statements],
            end: then.end && elze.end,
        };
    }
    function handleSwitchStatement(node, checker) {
        let hasDefault = false;
        const result = {
            statements: [],
            end: false,
        };
        for (const clause of node.caseBlock.clauses) {
            if (clause.kind === ts.SyntaxKind.DefaultClause)
                hasDefault = true;
            const current = handleBlock(clause, checker);
            result.end = current.end;
            result.statements.push(...current.statements);
        }
        result.end && (result.end = hasDefault || checker !== undefined && util_1.hasExhaustiveCaseClauses(node, checker));
        return result;
    }
    function handleTryStatement(node, checker) {
        let finallyResult;
        if (node.finallyBlock !== undefined) {
            finallyResult = handleBlock(node.finallyBlock, checker);
            // if 'finally' always ends control flow, we are not interested in any jump statements from 'try' or 'catch'
            if (finallyResult.end)
                return finallyResult;
        }
        const tryResult = handleBlock(node.tryBlock, checker);
        if (node.catchClause === undefined)
            return { statements: finallyResult.statements.concat(tryResult.statements), end: tryResult.end };
        const catchResult = handleBlock(node.catchClause.block, checker);
        return {
            statements: tryResult.statements
                // remove all throw statements and throwing function calls from the list of control flow statements inside tryBlock
                .filter((s) => s.kind !== ts.SyntaxKind.ThrowStatement && s.kind !== ts.SyntaxKind.ExpressionStatement)
                .concat(catchResult.statements, finallyResult === undefined ? [] : finallyResult.statements),
            end: tryResult.end && catchResult.end, // only ends control flow if try AND catch definitely end control flow
        };
    }
    /** Dotted name as TypeScript requires it for assertion signatures to affect control flow. */
    function isDottedNameWithExplicitTypeAnnotation(node, checker) {
        while (true) {
            switch (node.kind) {
                case ts.SyntaxKind.Identifier: {
                    const symbol = checker.getExportSymbolOfSymbol(checker.getSymbolAtLocation(node));
                    return isExplicitlyTypedSymbol(util_1.isSymbolFlagSet(symbol, ts.SymbolFlags.Alias) ? checker.getAliasedSymbol(symbol) : symbol, checker);
                }
                case ts.SyntaxKind.ThisKeyword:
                    return isExplicitlyTypedThis(node);
                case ts.SyntaxKind.SuperKeyword:
                    return true;
                case ts.SyntaxKind.PropertyAccessExpression:
                    if (!isExplicitlyTypedSymbol(checker.getSymbolAtLocation(node), checker))
                        return false;
                // falls through
                case ts.SyntaxKind.ParenthesizedExpression:
                    node = node.expression;
                    continue;
                default:
                    return false;
            }
        }
    }
    function isExplicitlyTypedSymbol(symbol, checker) {
        if (symbol === undefined)
            return false;
        if (util_1.isSymbolFlagSet(symbol, ts.SymbolFlags.Function | ts.SymbolFlags.Method | ts.SymbolFlags.Class | ts.SymbolFlags.ValueModule))
            return true;
        if (!util_1.isSymbolFlagSet(symbol, ts.SymbolFlags.Variable | ts.SymbolFlags.Property))
            return false;
        if (symbol.valueDeclaration === undefined)
            return false;
        if (declarationHasExplicitTypeAnnotation(symbol.valueDeclaration))
            return true;
        return node_1.isVariableDeclaration(symbol.valueDeclaration) &&
            symbol.valueDeclaration.parent.parent.kind === ts.SyntaxKind.ForOfStatement &&
            isDottedNameWithExplicitTypeAnnotation(symbol.valueDeclaration.parent.parent.expression, checker);
    }
    function declarationHasExplicitTypeAnnotation(node) {
        if (ts.isJSDocPropertyLikeTag(node))
            return node.typeExpression !== undefined;
        return (node_1.isVariableDeclaration(node) ||
            node_1.isParameterDeclaration(node) ||
            node_1.isPropertyDeclaration(node) ||
            node_1.isPropertySignature(node)) && (util_1.isNodeFlagSet(node, ts.NodeFlags.JavaScriptFile)
            ? ts.getJSDocType(node)
            : node.type) !== undefined;
    }
    function isExplicitlyTypedThis(node) {
        var _a;
        do {
            node = node.parent;
            if (node_1.isDecorator(node)) {
                // `this` in decorators always resolves outside of the containing class
                if (node.parent.kind === ts.SyntaxKind.Parameter && node_1.isClassLikeDeclaration(node.parent.parent.parent)) {
                    node = node.parent.parent.parent.parent;
                }
                else if (node_1.isClassLikeDeclaration(node.parent.parent)) {
                    node = node.parent.parent.parent;
                }
                else if (node_1.isClassLikeDeclaration(node.parent)) {
                    node = node.parent.parent;
                }
            }
        } while (util_1.isFunctionScopeBoundary(node) !== 1 /* Function */ || node.kind === ts.SyntaxKind.ArrowFunction);
        return util_1.isFunctionWithBody(node) &&
            (util_1.isNodeFlagSet(node, ts.NodeFlags.JavaScriptFile)
                ? ((_a = ts.getJSDocThisTag(node)) === null || _a === void 0 ? void 0 : _a.typeExpression) !== undefined
                : node.parameters.length !== 0 && util_1.isThisParameter(node.parameters[0]) && node.parameters[0].type !== undefined) ||
            node_1.isClassLikeDeclaration(node.parent);
    }
    var SignatureEffect;
    (function (SignatureEffect) {
        SignatureEffect[SignatureEffect["Never"] = 1] = "Never";
        SignatureEffect[SignatureEffect["Asserts"] = 2] = "Asserts";
    })(SignatureEffect = exports.SignatureEffect || (exports.SignatureEffect = {}));
    /**
     * Dermines whether a top level CallExpression has a control flow effect according to TypeScript's rules.
     * This handles functions returning `never` and `asserts`.
     */
    function callExpressionAffectsControlFlow(node, checker) {
        var _a, _b, _c;
        if (!node_1.isExpressionStatement(node.parent) ||
            ts.isOptionalChain(node) ||
            !isDottedNameWithExplicitTypeAnnotation(node.expression, checker))
            return;
        const signature = checker.getResolvedSignature(node);
        if ((signature === null || signature === void 0 ? void 0 : signature.declaration) === undefined)
            return;
        const typeNode = ts.isJSDocSignature(signature.declaration)
            ? (_b = (_a = signature.declaration.type) === null || _a === void 0 ? void 0 : _a.typeExpression) === null || _b === void 0 ? void 0 : _b.type
            : (_c = signature.declaration.type) !== null && _c !== void 0 ? _c : (util_1.isNodeFlagSet(signature.declaration, ts.NodeFlags.JavaScriptFile)
                ? ts.getJSDocReturnType(signature.declaration)
                : undefined);
        if (typeNode === undefined)
            return;
        if (node_1.isTypePredicateNode(typeNode) && typeNode.assertsModifier !== undefined)
            return 2 /* Asserts */;
        return util_1.isTypeFlagSet(checker.getTypeFromTypeNode(typeNode), ts.TypeFlags.Never) ? 1 /* Never */ : undefined;
    }
    exports.callExpressionAffectsControlFlow = callExpressionAffectsControlFlow;
    function handleExpressionStatement(node, checker) {
        if (!node_1.isCallExpression(node.expression))
            return defaultControlFlowEnd;
        switch (callExpressionAffectsControlFlow(node.expression, checker)) {
            case 2 /* Asserts */:
                return { statements: [node], end: false };
            case 1 /* Never */:
                return { statements: [node], end: true };
            case undefined:
                return defaultControlFlowEnd;
        }
    }
    function matchBreakOrContinue(current, pred) {
        const result = {
            statements: [],
            end: current.end,
        };
        for (const statement of current.statements) {
            if (pred(statement) && statement.label === undefined) {
                result.end = false;
                continue;
            }
            result.statements.push(statement);
        }
        return result;
    }
    function matchLabel(current, label) {
        const result = {
            statements: [],
            end: current.end,
        };
        const labelText = label.text;
        for (const statement of current.statements) {
            switch (statement.kind) {
                case ts.SyntaxKind.BreakStatement:
                case ts.SyntaxKind.ContinueStatement:
                    if (statement.label !== undefined && statement.label.text === labelText) {
                        result.end = false;
                        continue;
                    }
            }
            result.statements.push(statement);
        }
        return result;
    }
    
},
/* tsutils/util/convert-ast.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.convertAst = void 0;
    const ts = require(21) /* typescript */;
    const util_1 = require(1047) /* ./util */;
    /**
     * Takes a `ts.SourceFile` and creates data structures that are easier (or more performant) to traverse.
     * Note that there is only a performance gain if you can reuse these structures. It's not recommended for one-time AST walks.
     */
    function convertAst(sourceFile) {
        const wrapped = {
            node: sourceFile,
            parent: undefined,
            kind: ts.SyntaxKind.SourceFile,
            children: [],
            next: undefined,
            skip: undefined,
        };
        const flat = [];
        let current = wrapped;
        function collectChildren(node) {
            current.children.push({
                node,
                parent: current,
                kind: node.kind,
                children: [],
                next: undefined,
                skip: undefined,
            });
        }
        const stack = [];
        while (true) {
            if (current.children.length === 0) {
                ts.forEachChild(current.node, collectChildren);
                if (current.children.length === 0) {
                    current = current.parent; // nothing to do here, go back to parent
                }
                else {
                    // recurse into first child
                    const firstChild = current.children[0];
                    current.next = firstChild;
                    flat.push(firstChild.node);
                    if (util_1.isNodeKind(firstChild.kind))
                        current = firstChild;
                    stack.push(1); // set index in stack so we know where to continue processing children
                }
            }
            else {
                const index = stack[stack.length - 1];
                if (index < current.children.length) { // handles 2nd child to the last
                    const currentChild = current.children[index];
                    flat.push(currentChild.node);
                    let previous = current.children[index - 1];
                    while (previous.children.length !== 0) {
                        previous.skip = currentChild;
                        previous = previous.children[previous.children.length - 1];
                    }
                    previous.skip = previous.next = currentChild;
                    ++stack[stack.length - 1];
                    if (util_1.isNodeKind(currentChild.kind))
                        current = currentChild; // recurse into child
                }
                else {
                    // done on this node
                    if (stack.length === 1)
                        break;
                    // remove index from stack and go back to parent
                    stack.pop();
                    current = current.parent;
                }
            }
        }
        return {
            wrapped,
            flat,
        };
    }
    exports.convertAst = convertAst;
    
},
/* @typescript-eslint/type-utils/dist/typeFlagUtils.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isTypeFlagSet = exports.getTypeFlags = void 0;
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    /**
     * Gets all of the type flags in a type, iterating through unions automatically
     */
    function getTypeFlags(type) {
        // @ts-expect-error Since typescript 5.0, this is invalid, but uses 0 as the default value of TypeFlags.
        let flags = 0;
        for (const t of (0, tsutils_1.unionTypeParts)(type)) {
            flags |= t.flags;
        }
        return flags;
    }
    exports.getTypeFlags = getTypeFlags;
    /**
     * Checks if the given type is (or accepts) the given flags
     * @param isReceiver true if the type is a receiving type (i.e. the type of a called function's parameter)
     */
    function isTypeFlagSet(type, flagsToCheck, isReceiver) {
        const flags = getTypeFlags(type);
        if (isReceiver && flags & (ts.TypeFlags.Any | ts.TypeFlags.Unknown)) {
            return true;
        }
        return (flags & flagsToCheck) !== 0;
    }
    exports.isTypeFlagSet = isTypeFlagSet;
    
},
/* @typescript-eslint/type-utils/dist/getConstrainedTypeAtLocation.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getConstrainedTypeAtLocation = void 0;
    /**
     * Resolves the given node's type. Will resolve to the type's generic constraint, if it has one.
     */
    function getConstrainedTypeAtLocation(checker, node) {
        const nodeType = checker.getTypeAtLocation(node);
        const constrained = checker.getBaseConstraintOfType(nodeType);
        return constrained !== null && constrained !== void 0 ? constrained : nodeType;
    }
    exports.getConstrainedTypeAtLocation = getConstrainedTypeAtLocation;
    
},
/* @typescript-eslint/type-utils/dist/getContextualType.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getContextualType = void 0;
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    /**
     * Returns the contextual type of a given node.
     * Contextual type is the type of the target the node is going into.
     * i.e. the type of a called function's parameter, or the defined type of a variable declaration
     */
    function getContextualType(checker, node) {
        const parent = node.parent;
        if (!parent) {
            return;
        }
        if ((0, tsutils_1.isCallExpression)(parent) || (0, tsutils_1.isNewExpression)(parent)) {
            if (node === parent.expression) {
                // is the callee, so has no contextual type
                return;
            }
        }
        else if ((0, tsutils_1.isVariableDeclaration)(parent) ||
            (0, tsutils_1.isPropertyDeclaration)(parent) ||
            (0, tsutils_1.isParameterDeclaration)(parent)) {
            return parent.type ? checker.getTypeFromTypeNode(parent.type) : undefined;
        }
        else if ((0, tsutils_1.isJsxExpression)(parent)) {
            return checker.getContextualType(parent);
        }
        else if ((0, tsutils_1.isPropertyAssignment)(parent) && (0, tsutils_1.isIdentifier)(node)) {
            return checker.getContextualType(node);
        }
        else if ((0, tsutils_1.isBinaryExpression)(parent) &&
            parent.operatorToken.kind === ts.SyntaxKind.EqualsToken &&
            parent.right === node) {
            // is RHS of assignment
            return checker.getTypeAtLocation(parent.left);
        }
        else if (![ts.SyntaxKind.TemplateSpan, ts.SyntaxKind.JsxExpression].includes(parent.kind)) {
            // parent is not something we know we can get the contextual type of
            return;
        }
        // TODO - support return statement checking
        return checker.getContextualType(node);
    }
    exports.getContextualType = getContextualType;
    
},
/* @typescript-eslint/type-utils/dist/getDeclaration.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getDeclaration = void 0;
    /**
     * Gets the declaration for the given variable
     */
    function getDeclaration(checker, node) {
        var _a;
        const symbol = checker.getSymbolAtLocation(node);
        if (!symbol) {
            return null;
        }
        const declarations = symbol.getDeclarations();
        return (_a = declarations === null || declarations === void 0 ? void 0 : declarations[0]) !== null && _a !== void 0 ? _a : null;
    }
    exports.getDeclaration = getDeclaration;
    
},
/* @typescript-eslint/type-utils/dist/getSourceFileOfNode.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getSourceFileOfNode = void 0;
    const ts = __importStar(require(21) /* typescript */);
    /**
     * Gets the source file for a given node
     */
    function getSourceFileOfNode(node) {
        while (node && node.kind !== ts.SyntaxKind.SourceFile) {
            node = node.parent;
        }
        return node;
    }
    exports.getSourceFileOfNode = getSourceFileOfNode;
    
},
/* @typescript-eslint/type-utils/dist/getTokenAtPosition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getTokenAtPosition = void 0;
    const ts = __importStar(require(21) /* typescript */);
    function getTokenAtPosition(sourceFile, position) {
        const queue = [sourceFile];
        let current;
        while (queue.length > 0) {
            current = queue.shift();
            // find the child that contains 'position'
            for (const child of current.getChildren(sourceFile)) {
                const start = child.getFullStart();
                if (start > position) {
                    // If this child begins after position, then all subsequent children will as well.
                    return current;
                }
                const end = child.getEnd();
                if (position < end ||
                    (position === end && child.kind === ts.SyntaxKind.EndOfFileToken)) {
                    queue.push(child);
                    break;
                }
            }
        }
        return current;
    }
    exports.getTokenAtPosition = getTokenAtPosition;
    
},
/* @typescript-eslint/type-utils/dist/getTypeArguments.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getTypeArguments = void 0;
    function getTypeArguments(type, checker) {
        var _a;
        // getTypeArguments was only added in TS3.7
        if (checker.getTypeArguments) {
            return checker.getTypeArguments(type);
        }
        return (_a = type.typeArguments) !== null && _a !== void 0 ? _a : [];
    }
    exports.getTypeArguments = getTypeArguments;
    
},
/* @typescript-eslint/type-utils/dist/getTypeName.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getTypeName = void 0;
    const ts = __importStar(require(21) /* typescript */);
    /**
     * Get the type name of a given type.
     * @param typeChecker The context sensitive TypeScript TypeChecker.
     * @param type The type to get the name of.
     */
    function getTypeName(typeChecker, type) {
        // It handles `string` and string literal types as string.
        if ((type.flags & ts.TypeFlags.StringLike) !== 0) {
            return 'string';
        }
        // If the type is a type parameter which extends primitive string types,
        // but it was not recognized as a string like. So check the constraint
        // type of the type parameter.
        if ((type.flags & ts.TypeFlags.TypeParameter) !== 0) {
            // `type.getConstraint()` method doesn't return the constraint type of
            // the type parameter for some reason. So this gets the constraint type
            // via AST.
            const symbol = type.getSymbol();
            const decls = symbol === null || symbol === void 0 ? void 0 : symbol.getDeclarations();
            const typeParamDecl = decls === null || decls === void 0 ? void 0 : decls[0];
            if (ts.isTypeParameterDeclaration(typeParamDecl) &&
                typeParamDecl.constraint != null) {
                return getTypeName(typeChecker, typeChecker.getTypeFromTypeNode(typeParamDecl.constraint));
            }
        }
        // If the type is a union and all types in the union are string like,
        // return `string`. For example:
        // - `"a" | "b"` is string.
        // - `string | string[]` is not string.
        if (type.isUnion() &&
            type.types
                .map(value => getTypeName(typeChecker, value))
                .every(t => t === 'string')) {
            return 'string';
        }
        // If the type is an intersection and a type in the intersection is string
        // like, return `string`. For example: `string & {__htmlEscaped: void}`
        if (type.isIntersection() &&
            type.types
                .map(value => getTypeName(typeChecker, value))
                .some(t => t === 'string')) {
            return 'string';
        }
        return typeChecker.typeToString(type);
    }
    exports.getTypeName = getTypeName;
    
},
/* @typescript-eslint/type-utils/dist/isTypeReadonly.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isTypeReadonly = exports.readonlynessOptionsDefaults = exports.readonlynessOptionsSchema = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    const propertyTypes_1 = require(1062) /* ./propertyTypes */;
    exports.readonlynessOptionsSchema = {
        type: 'object',
        additionalProperties: false,
        properties: {
            treatMethodsAsReadonly: {
                type: 'boolean',
            },
        },
    };
    exports.readonlynessOptionsDefaults = {
        treatMethodsAsReadonly: false,
    };
    function hasSymbol(node) {
        return Object.prototype.hasOwnProperty.call(node, 'symbol');
    }
    function isTypeReadonlyArrayOrTuple(checker, type, options, seenTypes) {
        function checkTypeArguments(arrayType) {
            var _a;
            const typeArguments = 
            // getTypeArguments was only added in TS3.7
            checker.getTypeArguments
                ? checker.getTypeArguments(arrayType)
                : (_a = arrayType.typeArguments) !== null && _a !== void 0 ? _a : [];
            // this shouldn't happen in reality as:
            // - tuples require at least 1 type argument
            // - ReadonlyArray requires at least 1 type argument
            /* istanbul ignore if */ if (typeArguments.length === 0) {
                return 3 /* Readonlyness.Readonly */;
            }
            // validate the element types are also readonly
            if (typeArguments.some(typeArg => isTypeReadonlyRecurser(checker, typeArg, options, seenTypes) ===
                2 /* Readonlyness.Mutable */)) {
                return 2 /* Readonlyness.Mutable */;
            }
            return 3 /* Readonlyness.Readonly */;
        }
        if (checker.isArrayType(type)) {
            const symbol = utils_1.ESLintUtils.nullThrows(type.getSymbol(), utils_1.ESLintUtils.NullThrowsReasons.MissingToken('symbol', 'array type'));
            const escapedName = symbol.getEscapedName();
            if (escapedName === 'Array') {
                return 2 /* Readonlyness.Mutable */;
            }
            return checkTypeArguments(type);
        }
        if (checker.isTupleType(type)) {
            if (!type.target.readonly) {
                return 2 /* Readonlyness.Mutable */;
            }
            return checkTypeArguments(type);
        }
        return 1 /* Readonlyness.UnknownType */;
    }
    function isTypeReadonlyObject(checker, type, options, seenTypes) {
        function checkIndexSignature(kind) {
            const indexInfo = checker.getIndexInfoOfType(type, kind);
            if (indexInfo) {
                if (!indexInfo.isReadonly) {
                    return 2 /* Readonlyness.Mutable */;
                }
                if (indexInfo.type === type || seenTypes.has(indexInfo.type)) {
                    return 3 /* Readonlyness.Readonly */;
                }
                return isTypeReadonlyRecurser(checker, indexInfo.type, options, seenTypes);
            }
            return 1 /* Readonlyness.UnknownType */;
        }
        const properties = type.getProperties();
        if (properties.length) {
            // ensure the properties are marked as readonly
            for (const property of properties) {
                if (options.treatMethodsAsReadonly) {
                    if (property.valueDeclaration !== undefined &&
                        hasSymbol(property.valueDeclaration) &&
                        (0, tsutils_1.isSymbolFlagSet)(property.valueDeclaration.symbol, ts.SymbolFlags.Method)) {
                        continue;
                    }
                    const declarations = property.getDeclarations();
                    const lastDeclaration = declarations !== undefined && declarations.length > 0
                        ? declarations[declarations.length - 1]
                        : undefined;
                    if (lastDeclaration !== undefined &&
                        hasSymbol(lastDeclaration) &&
                        (0, tsutils_1.isSymbolFlagSet)(lastDeclaration.symbol, ts.SymbolFlags.Method)) {
                        continue;
                    }
                }
                if ((0, tsutils_1.isPropertyReadonlyInType)(type, property.getEscapedName(), checker)) {
                    continue;
                }
                const name = ts.getNameOfDeclaration(property.valueDeclaration);
                if (name && ts.isPrivateIdentifier(name)) {
                    continue;
                }
                return 2 /* Readonlyness.Mutable */;
            }
            // all properties were readonly
            // now ensure that all of the values are readonly also.
            // do this after checking property readonly-ness as a perf optimization,
            // as we might be able to bail out early due to a mutable property before
            // doing this deep, potentially expensive check.
            for (const property of properties) {
                const propertyType = utils_1.ESLintUtils.nullThrows((0, propertyTypes_1.getTypeOfPropertyOfType)(checker, type, property), utils_1.ESLintUtils.NullThrowsReasons.MissingToken(`property "${property.name}"`, 'type'));
                // handle recursive types.
                // we only need this simple check, because a mutable recursive type will break via the above prop readonly check
                if (seenTypes.has(propertyType)) {
                    continue;
                }
                if (isTypeReadonlyRecurser(checker, propertyType, options, seenTypes) ===
                    2 /* Readonlyness.Mutable */) {
                    return 2 /* Readonlyness.Mutable */;
                }
            }
        }
        const isStringIndexSigReadonly = checkIndexSignature(ts.IndexKind.String);
        if (isStringIndexSigReadonly === 2 /* Readonlyness.Mutable */) {
            return isStringIndexSigReadonly;
        }
        const isNumberIndexSigReadonly = checkIndexSignature(ts.IndexKind.Number);
        if (isNumberIndexSigReadonly === 2 /* Readonlyness.Mutable */) {
            return isNumberIndexSigReadonly;
        }
        return 3 /* Readonlyness.Readonly */;
    }
    // a helper function to ensure the seenTypes map is always passed down, except by the external caller
    function isTypeReadonlyRecurser(checker, type, options, seenTypes) {
        seenTypes.add(type);
        if ((0, tsutils_1.isUnionType)(type)) {
            // all types in the union must be readonly
            const result = (0, tsutils_1.unionTypeParts)(type).every(t => seenTypes.has(t) ||
                isTypeReadonlyRecurser(checker, t, options, seenTypes) ===
                    3 /* Readonlyness.Readonly */);
            const readonlyness = result ? 3 /* Readonlyness.Readonly */ : 2 /* Readonlyness.Mutable */;
            return readonlyness;
        }
        if ((0, tsutils_1.isIntersectionType)(type)) {
            // Special case for handling arrays/tuples (as readonly arrays/tuples always have mutable methods).
            if (type.types.some(t => checker.isArrayType(t) || checker.isTupleType(t))) {
                const allReadonlyParts = type.types.every(t => seenTypes.has(t) ||
                    isTypeReadonlyRecurser(checker, t, options, seenTypes) ===
                        3 /* Readonlyness.Readonly */);
                return allReadonlyParts ? 3 /* Readonlyness.Readonly */ : 2 /* Readonlyness.Mutable */;
            }
            // Normal case.
            const isReadonlyObject = isTypeReadonlyObject(checker, type, options, seenTypes);
            if (isReadonlyObject !== 1 /* Readonlyness.UnknownType */) {
                return isReadonlyObject;
            }
        }
        if ((0, tsutils_1.isConditionalType)(type)) {
            const result = [type.root.node.trueType, type.root.node.falseType]
                .map(checker.getTypeFromTypeNode)
                .every(t => seenTypes.has(t) ||
                isTypeReadonlyRecurser(checker, t, options, seenTypes) ===
                    3 /* Readonlyness.Readonly */);
            const readonlyness = result ? 3 /* Readonlyness.Readonly */ : 2 /* Readonlyness.Mutable */;
            return readonlyness;
        }
        // all non-object, non-intersection types are readonly.
        // this should only be primitive types
        if (!(0, tsutils_1.isObjectType)(type)) {
            return 3 /* Readonlyness.Readonly */;
        }
        // pure function types are readonly
        if (type.getCallSignatures().length > 0 &&
            type.getProperties().length === 0) {
            return 3 /* Readonlyness.Readonly */;
        }
        const isReadonlyArray = isTypeReadonlyArrayOrTuple(checker, type, options, seenTypes);
        if (isReadonlyArray !== 1 /* Readonlyness.UnknownType */) {
            return isReadonlyArray;
        }
        const isReadonlyObject = isTypeReadonlyObject(checker, type, options, seenTypes);
        /* istanbul ignore else */ if (isReadonlyObject !== 1 /* Readonlyness.UnknownType */) {
            return isReadonlyObject;
        }
        throw new Error('Unhandled type');
    }
    /**
     * Checks if the given type is readonly
     */
    function isTypeReadonly(checker, type, options = exports.readonlynessOptionsDefaults) {
        return (isTypeReadonlyRecurser(checker, type, options, new Set()) ===
            3 /* Readonlyness.Readonly */);
    }
    exports.isTypeReadonly = isTypeReadonly;
    
},
/* @typescript-eslint/type-utils/dist/propertyTypes.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getTypeOfPropertyOfType = exports.getTypeOfPropertyOfName = void 0;
    function getTypeOfPropertyOfName(checker, type, name, escapedName) {
        // Most names are directly usable in the checker and aren't different from escaped names
        if (!escapedName || !isSymbol(escapedName)) {
            return checker.getTypeOfPropertyOfType(type, name);
        }
        // Symbolic names may differ in their escaped name compared to their human-readable name
        // https://github.com/typescript-eslint/typescript-eslint/issues/2143
        const escapedProperty = type
            .getProperties()
            .find(property => property.escapedName === escapedName);
        return escapedProperty
            ? checker.getDeclaredTypeOfSymbol(escapedProperty)
            : undefined;
    }
    exports.getTypeOfPropertyOfName = getTypeOfPropertyOfName;
    function getTypeOfPropertyOfType(checker, type, property) {
        return getTypeOfPropertyOfName(checker, type, property.getName(), property.getEscapedName());
    }
    exports.getTypeOfPropertyOfType = getTypeOfPropertyOfType;
    // Symbolic names need to be specially handled because TS api is not sufficient for these cases.
    // Source based on:
    // https://github.com/microsoft/TypeScript/blob/0043abe982aae0d35f8df59f9715be6ada758ff7/src/compiler/utilities.ts#L3388-L3402
    function isSymbol(escapedName) {
        return isKnownSymbol(escapedName) || isPrivateIdentifierSymbol(escapedName);
    }
    // case for escapedName: "__@foo@10", name: "__@foo@10"
    function isKnownSymbol(escapedName) {
        return escapedName.startsWith('__@');
    }
    // case for escapedName: "__#1@#foo", name: "#foo"
    function isPrivateIdentifierSymbol(escapedName) {
        return escapedName.startsWith('__#');
    }
    
},
/* @typescript-eslint/type-utils/dist/isUnsafeAssignment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isUnsafeAssignment = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils_1 = require(1034) /* tsutils */;
    const predicates_1 = require(1064) /* ./predicates */;
    /**
     * Does a simple check to see if there is an any being assigned to a non-any type.
     *
     * This also checks generic positions to ensure there's no unsafe sub-assignments.
     * Note: in the case of generic positions, it makes the assumption that the two types are the same.
     *
     * @example See tests for examples
     *
     * @returns false if it's safe, or an object with the two types if it's unsafe
     */
    function isUnsafeAssignment(type, receiver, checker, senderNode) {
        var _a, _b;
        if ((0, predicates_1.isTypeAnyType)(type)) {
            // Allow assignment of any ==> unknown.
            if ((0, predicates_1.isTypeUnknownType)(receiver)) {
                return false;
            }
            if (!(0, predicates_1.isTypeAnyType)(receiver)) {
                return { sender: type, receiver };
            }
        }
        if ((0, tsutils_1.isTypeReference)(type) && (0, tsutils_1.isTypeReference)(receiver)) {
            // TODO - figure out how to handle cases like this,
            // where the types are assignable, but not the same type
            /*
            function foo(): ReadonlySet<number> { return new Set<any>(); }
        
            // and
        
            type Test<T> = { prop: T }
            type Test2 = { prop: string }
            declare const a: Test<any>;
            const b: Test2 = a;
            */
            if (type.target !== receiver.target) {
                // if the type references are different, assume safe, as we won't know how to compare the two types
                // the generic positions might not be equivalent for both types
                return false;
            }
            if ((senderNode === null || senderNode === void 0 ? void 0 : senderNode.type) === utils_1.AST_NODE_TYPES.NewExpression &&
                senderNode.callee.type === utils_1.AST_NODE_TYPES.Identifier &&
                senderNode.callee.name === 'Map' &&
                senderNode.arguments.length === 0 &&
                senderNode.typeParameters == null) {
                // special case to handle `new Map()`
                // unfortunately Map's default empty constructor is typed to return `Map<any, any>` :(
                // https://github.com/typescript-eslint/typescript-eslint/issues/2109#issuecomment-634144396
                return false;
            }
            const typeArguments = (_a = type.typeArguments) !== null && _a !== void 0 ? _a : [];
            const receiverTypeArguments = (_b = receiver.typeArguments) !== null && _b !== void 0 ? _b : [];
            for (let i = 0; i < typeArguments.length; i += 1) {
                const arg = typeArguments[i];
                const receiverArg = receiverTypeArguments[i];
                const unsafe = isUnsafeAssignment(arg, receiverArg, checker, senderNode);
                if (unsafe) {
                    return { sender: type, receiver };
                }
            }
            return false;
        }
        return false;
    }
    exports.isUnsafeAssignment = isUnsafeAssignment;
    
},
/* @typescript-eslint/type-utils/dist/predicates.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isTypeTemplateLiteralType = exports.isTypeBigIntLiteralType = exports.typeIsOrHasBaseType = exports.isAnyOrAnyArrayTypeDiscriminated = exports.AnyType = exports.isTypeUnknownArrayType = exports.isTypeAnyArrayType = exports.isTypeAnyType = exports.isTypeReferenceType = exports.isTypeUnknownType = exports.isTypeNeverType = exports.isTypeArrayTypeOrUnionOfArrayTypes = exports.isNullableType = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    const getTypeArguments_1 = require(1059) /* ./getTypeArguments */;
    const typeFlagUtils_1 = require(1053) /* ./typeFlagUtils */;
    const log = (0, debug_1.default)('typescript-eslint:eslint-plugin:utils:types');
    /**
     * Checks if the given type is (or accepts) nullable
     * @param isReceiver true if the type is a receiving type (i.e. the type of a called function's parameter)
     */
    function isNullableType(type, { isReceiver = false, allowUndefined = true, } = {}) {
        const flags = (0, typeFlagUtils_1.getTypeFlags)(type);
        if (isReceiver && flags & (ts.TypeFlags.Any | ts.TypeFlags.Unknown)) {
            return true;
        }
        if (allowUndefined) {
            return (flags & (ts.TypeFlags.Null | ts.TypeFlags.Undefined)) !== 0;
        }
        else {
            return (flags & ts.TypeFlags.Null) !== 0;
        }
    }
    exports.isNullableType = isNullableType;
    /**
     * Checks if the given type is either an array type,
     * or a union made up solely of array types.
     */
    function isTypeArrayTypeOrUnionOfArrayTypes(type, checker) {
        for (const t of (0, tsutils_1.unionTypeParts)(type)) {
            if (!checker.isArrayType(t)) {
                return false;
            }
        }
        return true;
    }
    exports.isTypeArrayTypeOrUnionOfArrayTypes = isTypeArrayTypeOrUnionOfArrayTypes;
    /**
     * @returns true if the type is `never`
     */
    function isTypeNeverType(type) {
        return (0, typeFlagUtils_1.isTypeFlagSet)(type, ts.TypeFlags.Never);
    }
    exports.isTypeNeverType = isTypeNeverType;
    /**
     * @returns true if the type is `unknown`
     */
    function isTypeUnknownType(type) {
        return (0, typeFlagUtils_1.isTypeFlagSet)(type, ts.TypeFlags.Unknown);
    }
    exports.isTypeUnknownType = isTypeUnknownType;
    // https://github.com/microsoft/TypeScript/blob/42aa18bf442c4df147e30deaf27261a41cbdc617/src/compiler/types.ts#L5157
    const Nullable = ts.TypeFlags.Undefined | ts.TypeFlags.Null;
    // https://github.com/microsoft/TypeScript/blob/42aa18bf442c4df147e30deaf27261a41cbdc617/src/compiler/types.ts#L5187
    const ObjectFlagsType = ts.TypeFlags.Any |
        Nullable |
        ts.TypeFlags.Never |
        ts.TypeFlags.Object |
        ts.TypeFlags.Union |
        ts.TypeFlags.Intersection;
    function isTypeReferenceType(type) {
        if ((type.flags & ObjectFlagsType) === 0) {
            return false;
        }
        const objectTypeFlags = type.objectFlags;
        return (objectTypeFlags & ts.ObjectFlags.Reference) !== 0;
    }
    exports.isTypeReferenceType = isTypeReferenceType;
    /**
     * @returns true if the type is `any`
     */
    function isTypeAnyType(type) {
        if ((0, typeFlagUtils_1.isTypeFlagSet)(type, ts.TypeFlags.Any)) {
            if (type.intrinsicName === 'error') {
                log('Found an "error" any type');
            }
            return true;
        }
        return false;
    }
    exports.isTypeAnyType = isTypeAnyType;
    /**
     * @returns true if the type is `any[]`
     */
    function isTypeAnyArrayType(type, checker) {
        return (checker.isArrayType(type) &&
            isTypeAnyType(
            // getTypeArguments was only added in TS3.7
            (0, getTypeArguments_1.getTypeArguments)(type, checker)[0]));
    }
    exports.isTypeAnyArrayType = isTypeAnyArrayType;
    /**
     * @returns true if the type is `unknown[]`
     */
    function isTypeUnknownArrayType(type, checker) {
        return (checker.isArrayType(type) &&
            isTypeUnknownType(
            // getTypeArguments was only added in TS3.7
            (0, getTypeArguments_1.getTypeArguments)(type, checker)[0]));
    }
    exports.isTypeUnknownArrayType = isTypeUnknownArrayType;
    var AnyType;
    (function (AnyType) {
        AnyType[AnyType["Any"] = 0] = "Any";
        AnyType[AnyType["AnyArray"] = 1] = "AnyArray";
        AnyType[AnyType["Safe"] = 2] = "Safe";
    })(AnyType = exports.AnyType || (exports.AnyType = {}));
    /**
     * @returns `AnyType.Any` if the type is `any`, `AnyType.AnyArray` if the type is `any[]` or `readonly any[]`,
     *          otherwise it returns `AnyType.Safe`.
     */
    function isAnyOrAnyArrayTypeDiscriminated(node, checker) {
        const type = checker.getTypeAtLocation(node);
        if (isTypeAnyType(type)) {
            return AnyType.Any;
        }
        if (isTypeAnyArrayType(type, checker)) {
            return AnyType.AnyArray;
        }
        return AnyType.Safe;
    }
    exports.isAnyOrAnyArrayTypeDiscriminated = isAnyOrAnyArrayTypeDiscriminated;
    /**
     * @returns Whether a type is an instance of the parent type, including for the parent's base types.
     */
    function typeIsOrHasBaseType(type, parentType) {
        const parentSymbol = parentType.getSymbol();
        if (!type.getSymbol() || !parentSymbol) {
            return false;
        }
        const typeAndBaseTypes = [type];
        const ancestorTypes = type.getBaseTypes();
        if (ancestorTypes) {
            typeAndBaseTypes.push(...ancestorTypes);
        }
        for (const baseType of typeAndBaseTypes) {
            const baseSymbol = baseType.getSymbol();
            if (baseSymbol && baseSymbol.name === parentSymbol.name) {
                return true;
            }
        }
        return false;
    }
    exports.typeIsOrHasBaseType = typeIsOrHasBaseType;
    function isTypeBigIntLiteralType(type) {
        return (0, typeFlagUtils_1.isTypeFlagSet)(type, ts.TypeFlags.BigIntLiteral);
    }
    exports.isTypeBigIntLiteralType = isTypeBigIntLiteralType;
    function isTypeTemplateLiteralType(type) {
        return (0, typeFlagUtils_1.isTypeFlagSet)(type, ts.TypeFlags.TemplateLiteral);
    }
    exports.isTypeTemplateLiteralType = isTypeTemplateLiteralType;
    
},
/* @typescript-eslint/type-utils/dist/requiresQuoting.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.requiresQuoting = void 0;
    const ts = __importStar(require(21) /* typescript */);
    function requiresQuoting(name, target = ts.ScriptTarget.ESNext) {
        if (name.length === 0) {
            return true;
        }
        if (!ts.isIdentifierStart(name.charCodeAt(0), target)) {
            return true;
        }
        for (let i = 1; i < name.length; i += 1) {
            if (!ts.isIdentifierPart(name.charCodeAt(i), target)) {
                return true;
            }
        }
        return false;
    }
    exports.requiresQuoting = requiresQuoting;
    
},
/* @typescript-eslint/typescript-estree/dist/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.version = exports.visitorKeys = exports.typescriptVersionIsAtLeast = exports.createProgram = exports.simpleTraverse = exports.parseWithNodeMaps = exports.parseAndGenerateServices = exports.parse = void 0;
    var parser_1 = require(1067) /* ./parser */;
    Object.defineProperty(exports, "parse", { enumerable: true, get: function () { return parser_1.parse; } });
    Object.defineProperty(exports, "parseAndGenerateServices", { enumerable: true, get: function () { return parser_1.parseAndGenerateServices; } });
    Object.defineProperty(exports, "parseWithNodeMaps", { enumerable: true, get: function () { return parser_1.parseWithNodeMaps; } });
    var simple_traverse_1 = require(1078) /* ./simple-traverse */;
    Object.defineProperty(exports, "simpleTraverse", { enumerable: true, get: function () { return simple_traverse_1.simpleTraverse; } });
    __exportStar(require(1074) /* ./ts-estree */, exports);
    var useProvidedPrograms_1 = require(1087) /* ./create-program/useProvidedPrograms */;
    Object.defineProperty(exports, "createProgram", { enumerable: true, get: function () { return useProvidedPrograms_1.createProgramFromConfigFile; } });
    __exportStar(require(1082) /* ./create-program/getScriptKind */, exports);
    var version_check_1 = require(1071) /* ./version-check */;
    Object.defineProperty(exports, "typescriptVersionIsAtLeast", { enumerable: true, get: function () { return version_check_1.typescriptVersionIsAtLeast; } });
    __exportStar(require(1070) /* ./getModifiers */, exports);
    __exportStar(require(1146) /* ./clear-caches */, exports);
    // re-export for backwards-compat
    var visitor_keys_1 = require(863) /* @typescript-eslint/visitor-keys */;
    Object.defineProperty(exports, "visitorKeys", { enumerable: true, get: function () { return visitor_keys_1.visitorKeys; } });
    // note - cannot migrate this to an import statement because it will make TSC copy the package.json to the dist folder
    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment, @typescript-eslint/no-unsafe-member-access
    exports.version = require(1147) /* ../package.json */.version;
    
},
/* @typescript-eslint/typescript-estree/dist/parser.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.clearParseAndGenerateServicesCalls = exports.clearProgramCache = exports.parseWithNodeMaps = exports.parseAndGenerateServices = exports.parse = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const ast_converter_1 = require(1068) /* ./ast-converter */;
    const convert_1 = require(1069) /* ./convert */;
    const createDefaultProgram_1 = require(1079) /* ./create-program/createDefaultProgram */;
    const createIsolatedProgram_1 = require(1081) /* ./create-program/createIsolatedProgram */;
    const createProjectProgram_1 = require(1083) /* ./create-program/createProjectProgram */;
    const createSourceFile_1 = require(1086) /* ./create-program/createSourceFile */;
    const useProvidedPrograms_1 = require(1087) /* ./create-program/useProvidedPrograms */;
    const createParseSettings_1 = require(1088) /* ./parseSettings/createParseSettings */;
    const semantic_or_syntactic_errors_1 = require(1145) /* ./semantic-or-syntactic-errors */;
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:parser');
    /**
     * Cache existing programs for the single run use-case.
     *
     * clearProgramCache() is only intended to be used in testing to ensure the parser is clean between tests.
     */
    const existingPrograms = new Map();
    function clearProgramCache() {
        existingPrograms.clear();
    }
    exports.clearProgramCache = clearProgramCache;
    /**
     * @param parseSettings Internal settings for parsing the file
     * @param shouldProvideParserServices True if the program should be attempted to be calculated from provided tsconfig files
     * @returns Returns a source file and program corresponding to the linted code
     */
    function getProgramAndAST(parseSettings, shouldProvideParserServices) {
        return ((parseSettings.programs &&
            (0, useProvidedPrograms_1.useProvidedPrograms)(parseSettings.programs, parseSettings)) ||
            (shouldProvideParserServices && (0, createProjectProgram_1.createProjectProgram)(parseSettings)) ||
            (shouldProvideParserServices &&
                parseSettings.createDefaultProgram &&
                (0, createDefaultProgram_1.createDefaultProgram)(parseSettings)) ||
            (0, createIsolatedProgram_1.createIsolatedProgram)(parseSettings));
    }
    function parse(code, options) {
        const { ast } = parseWithNodeMapsInternal(code, options, false);
        return ast;
    }
    exports.parse = parse;
    function parseWithNodeMapsInternal(code, options, shouldPreserveNodeMaps) {
        /**
         * Reset the parse configuration
         */
        const parseSettings = (0, createParseSettings_1.createParseSettings)(code, options);
        /**
         * Ensure users do not attempt to use parse() when they need parseAndGenerateServices()
         */
        if (options === null || options === void 0 ? void 0 : options.errorOnTypeScriptSyntacticAndSemanticIssues) {
            throw new Error(`"errorOnTypeScriptSyntacticAndSemanticIssues" is only supported for parseAndGenerateServices()`);
        }
        /**
         * Create a ts.SourceFile directly, no ts.Program is needed for a simple parse
         */
        const ast = (0, createSourceFile_1.createSourceFile)(parseSettings);
        /**
         * Convert the TypeScript AST to an ESTree-compatible one
         */
        const { estree, astMaps } = (0, ast_converter_1.astConverter)(ast, parseSettings, shouldPreserveNodeMaps);
        return {
            ast: estree,
            esTreeNodeToTSNodeMap: astMaps.esTreeNodeToTSNodeMap,
            tsNodeToESTreeNodeMap: astMaps.tsNodeToESTreeNodeMap,
        };
    }
    function parseWithNodeMaps(code, options) {
        return parseWithNodeMapsInternal(code, options, true);
    }
    exports.parseWithNodeMaps = parseWithNodeMaps;
    let parseAndGenerateServicesCalls = {};
    // Privately exported utility intended for use in typescript-eslint unit tests only
    function clearParseAndGenerateServicesCalls() {
        parseAndGenerateServicesCalls = {};
    }
    exports.clearParseAndGenerateServicesCalls = clearParseAndGenerateServicesCalls;
    function parseAndGenerateServices(code, options) {
        var _a, _b;
        /**
         * Reset the parse configuration
         */
        const parseSettings = (0, createParseSettings_1.createParseSettings)(code, options);
        if (options !== undefined) {
            if (typeof options.errorOnTypeScriptSyntacticAndSemanticIssues ===
                'boolean' &&
                options.errorOnTypeScriptSyntacticAndSemanticIssues) {
                parseSettings.errorOnTypeScriptSyntacticAndSemanticIssues = true;
            }
        }
        /**
         * If this is a single run in which the user has not provided any existing programs but there
         * are programs which need to be created from the provided "project" option,
         * create an Iterable which will lazily create the programs as needed by the iteration logic
         */
        if (parseSettings.singleRun &&
            !parseSettings.programs &&
            ((_a = parseSettings.projects) === null || _a === void 0 ? void 0 : _a.length) > 0) {
            parseSettings.programs = {
                *[Symbol.iterator]() {
                    for (const configFile of parseSettings.projects) {
                        const existingProgram = existingPrograms.get(configFile);
                        if (existingProgram) {
                            yield existingProgram;
                        }
                        else {
                            log('Detected single-run/CLI usage, creating Program once ahead of time for project: %s', configFile);
                            const newProgram = (0, useProvidedPrograms_1.createProgramFromConfigFile)(configFile);
                            existingPrograms.set(configFile, newProgram);
                            yield newProgram;
                        }
                    }
                },
            };
        }
        /**
         * Generate a full ts.Program or offer provided instances in order to be able to provide parser services, such as type-checking
         */
        const shouldProvideParserServices = parseSettings.programs != null || ((_b = parseSettings.projects) === null || _b === void 0 ? void 0 : _b.length) > 0;
        /**
         * If we are in singleRun mode but the parseAndGenerateServices() function has been called more than once for the current file,
         * it must mean that we are in the middle of an ESLint automated fix cycle (in which parsing can be performed up to an additional
         * 10 times in order to apply all possible fixes for the file).
         *
         * In this scenario we cannot rely upon the singleRun AOT compiled programs because the SourceFiles will not contain the source
         * with the latest fixes applied. Therefore we fallback to creating the quickest possible isolated program from the updated source.
         */
        if (parseSettings.singleRun && options.filePath) {
            parseAndGenerateServicesCalls[options.filePath] =
                (parseAndGenerateServicesCalls[options.filePath] || 0) + 1;
        }
        const { ast, program } = parseSettings.singleRun &&
            options.filePath &&
            parseAndGenerateServicesCalls[options.filePath] > 1
            ? (0, createIsolatedProgram_1.createIsolatedProgram)(parseSettings)
            : getProgramAndAST(parseSettings, shouldProvideParserServices);
        /**
         * Convert the TypeScript AST to an ESTree-compatible one, and optionally preserve
         * mappings between converted and original AST nodes
         */
        const shouldPreserveNodeMaps = typeof parseSettings.preserveNodeMaps === 'boolean'
            ? parseSettings.preserveNodeMaps
            : true;
        const { estree, astMaps } = (0, ast_converter_1.astConverter)(ast, parseSettings, shouldPreserveNodeMaps);
        /**
         * Even if TypeScript parsed the source code ok, and we had no problems converting the AST,
         * there may be other syntactic or semantic issues in the code that we can optionally report on.
         */
        if (program && parseSettings.errorOnTypeScriptSyntacticAndSemanticIssues) {
            const error = (0, semantic_or_syntactic_errors_1.getFirstSemanticOrSyntacticError)(program, ast);
            if (error) {
                throw (0, convert_1.convertError)(error);
            }
        }
        /**
         * Return the converted AST and additional parser services
         */
        return {
            ast: estree,
            services: {
                hasFullTypeInformation: shouldProvideParserServices,
                program,
                esTreeNodeToTSNodeMap: astMaps.esTreeNodeToTSNodeMap,
                tsNodeToESTreeNodeMap: astMaps.tsNodeToESTreeNodeMap,
            },
        };
    }
    exports.parseAndGenerateServices = parseAndGenerateServices;
    
},
/* @typescript-eslint/typescript-estree/dist/ast-converter.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.astConverter = void 0;
    const convert_1 = require(1069) /* ./convert */;
    const convert_comments_1 = require(1077) /* ./convert-comments */;
    const node_utils_1 = require(1072) /* ./node-utils */;
    const simple_traverse_1 = require(1078) /* ./simple-traverse */;
    function astConverter(ast, parseSettings, shouldPreserveNodeMaps) {
        /**
         * The TypeScript compiler produced fundamental parse errors when parsing the
         * source.
         */
        const { parseDiagnostics } = ast;
        if (parseDiagnostics.length) {
            throw (0, convert_1.convertError)(parseDiagnostics[0]);
        }
        /**
         * Recursively convert the TypeScript AST into an ESTree-compatible AST
         */
        const instance = new convert_1.Converter(ast, {
            errorOnUnknownASTType: parseSettings.errorOnUnknownASTType || false,
            shouldPreserveNodeMaps,
        });
        const estree = instance.convertProgram();
        /**
         * Optionally remove range and loc if specified
         */
        if (!parseSettings.range || !parseSettings.loc) {
            (0, simple_traverse_1.simpleTraverse)(estree, {
                enter: node => {
                    if (!parseSettings.range) {
                        // eslint-disable-next-line @typescript-eslint/ban-ts-comment -- TS 4.0 made this an error because the types aren't optional
                        // @ts-expect-error
                        delete node.range;
                    }
                    if (!parseSettings.loc) {
                        // eslint-disable-next-line @typescript-eslint/ban-ts-comment -- TS 4.0 made this an error because the types aren't optional
                        // @ts-expect-error
                        delete node.loc;
                    }
                },
            });
        }
        /**
         * Optionally convert and include all tokens in the AST
         */
        if (parseSettings.tokens) {
            estree.tokens = (0, node_utils_1.convertTokens)(ast);
        }
        /**
         * Optionally convert and include all comments in the AST
         */
        if (parseSettings.comment) {
            estree.comments = (0, convert_comments_1.convertComments)(ast, parseSettings.code);
        }
        const astMaps = instance.getASTMaps();
        return { estree, astMaps };
    }
    exports.astConverter = astConverter;
    
},
/* @typescript-eslint/typescript-estree/dist/convert.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Converter = exports.convertError = void 0;
    // There's lots of funny stuff due to the typing of ts.Node
    /* eslint-disable @typescript-eslint/no-explicit-any, @typescript-eslint/no-unsafe-assignment, @typescript-eslint/no-unsafe-call, @typescript-eslint/no-unsafe-return, @typescript-eslint/no-unsafe-member-access */
    const ts = __importStar(require(21) /* typescript */);
    const getModifiers_1 = require(1070) /* ./getModifiers */;
    const node_utils_1 = require(1072) /* ./node-utils */;
    const ts_estree_1 = require(1074) /* ./ts-estree */;
    const version_check_1 = require(1071) /* ./version-check */;
    const SyntaxKind = ts.SyntaxKind;
    /**
     * Extends and formats a given error object
     * @param error the error object
     * @returns converted error object
     */
    function convertError(error) {
        return (0, node_utils_1.createError)(error.file, error.start, ('message' in error && error.message) || error.messageText);
    }
    exports.convertError = convertError;
    class Converter {
        /**
         * Converts a TypeScript node into an ESTree node
         * @param ast the full TypeScript AST
         * @param options additional options for the conversion
         * @returns the converted ESTreeNode
         */
        constructor(ast, options) {
            this.esTreeNodeToTSNodeMap = new WeakMap();
            this.tsNodeToESTreeNodeMap = new WeakMap();
            this.allowPattern = false;
            this.inTypeMode = false;
            this.ast = ast;
            this.options = Object.assign({}, options);
        }
        getASTMaps() {
            return {
                esTreeNodeToTSNodeMap: this.esTreeNodeToTSNodeMap,
                tsNodeToESTreeNodeMap: this.tsNodeToESTreeNodeMap,
            };
        }
        convertProgram() {
            return this.converter(this.ast);
        }
        /**
         * Converts a TypeScript node into an ESTree node.
         * @param node the child ts.Node
         * @param parent parentNode
         * @param inTypeMode flag to determine if we are in typeMode
         * @param allowPattern flag to determine if patterns are allowed
         * @returns the converted ESTree node
         */
        converter(node, parent, inTypeMode, allowPattern) {
            /**
             * Exit early for null and undefined
             */
            if (!node) {
                return null;
            }
            const typeMode = this.inTypeMode;
            const pattern = this.allowPattern;
            if (inTypeMode !== undefined) {
                this.inTypeMode = inTypeMode;
            }
            if (allowPattern !== undefined) {
                this.allowPattern = allowPattern;
            }
            const result = this.convertNode(node, (parent !== null && parent !== void 0 ? parent : node.parent));
            this.registerTSNodeInNodeMap(node, result);
            this.inTypeMode = typeMode;
            this.allowPattern = pattern;
            return result;
        }
        /**
         * Fixes the exports of the given ts.Node
         * @param node the ts.Node
         * @param result result
         * @returns the ESTreeNode with fixed exports
         */
        fixExports(node, result) {
            // check for exports
            const modifiers = (0, getModifiers_1.getModifiers)(node);
            if ((modifiers === null || modifiers === void 0 ? void 0 : modifiers[0].kind) === SyntaxKind.ExportKeyword) {
                /**
                 * Make sure that original node is registered instead of export
                 */
                this.registerTSNodeInNodeMap(node, result);
                const exportKeyword = modifiers[0];
                const nextModifier = modifiers[1];
                const declarationIsDefault = nextModifier && nextModifier.kind === SyntaxKind.DefaultKeyword;
                const varToken = declarationIsDefault
                    ? (0, node_utils_1.findNextToken)(nextModifier, this.ast, this.ast)
                    : (0, node_utils_1.findNextToken)(exportKeyword, this.ast, this.ast);
                result.range[0] = varToken.getStart(this.ast);
                result.loc = (0, node_utils_1.getLocFor)(result.range[0], result.range[1], this.ast);
                if (declarationIsDefault) {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ExportDefaultDeclaration,
                        declaration: result,
                        range: [exportKeyword.getStart(this.ast), result.range[1]],
                        exportKind: 'value',
                    });
                }
                else {
                    const isType = result.type === ts_estree_1.AST_NODE_TYPES.TSInterfaceDeclaration ||
                        result.type === ts_estree_1.AST_NODE_TYPES.TSTypeAliasDeclaration;
                    const isDeclare = 'declare' in result && result.declare === true;
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ExportNamedDeclaration,
                        // @ts-expect-error - TODO, narrow the types here
                        declaration: result,
                        specifiers: [],
                        source: null,
                        exportKind: isType || isDeclare ? 'type' : 'value',
                        range: [exportKeyword.getStart(this.ast), result.range[1]],
                        assertions: [],
                    });
                }
            }
            return result;
        }
        /**
         * Register specific TypeScript node into map with first ESTree node provided
         */
        registerTSNodeInNodeMap(node, result) {
            if (result && this.options.shouldPreserveNodeMaps) {
                if (!this.tsNodeToESTreeNodeMap.has(node)) {
                    this.tsNodeToESTreeNodeMap.set(node, result);
                }
            }
        }
        /**
         * Converts a TypeScript node into an ESTree node.
         * @param child the child ts.Node
         * @param parent parentNode
         * @returns the converted ESTree node
         */
        convertPattern(child, parent) {
            return this.converter(child, parent, this.inTypeMode, true);
        }
        /**
         * Converts a TypeScript node into an ESTree node.
         * @param child the child ts.Node
         * @param parent parentNode
         * @returns the converted ESTree node
         */
        convertChild(child, parent) {
            return this.converter(child, parent, this.inTypeMode, false);
        }
        /**
         * Converts a TypeScript node into an ESTree node.
         * @param child the child ts.Node
         * @param parent parentNode
         * @returns the converted ESTree node
         */
        convertType(child, parent) {
            return this.converter(child, parent, true, false);
        }
        createNode(node, data) {
            const result = data;
            if (!result.range) {
                result.range = (0, node_utils_1.getRange)(
                // this is completely valid, but TS hates it
                node, this.ast);
            }
            if (!result.loc) {
                result.loc = (0, node_utils_1.getLocFor)(result.range[0], result.range[1], this.ast);
            }
            if (result && this.options.shouldPreserveNodeMaps) {
                this.esTreeNodeToTSNodeMap.set(result, node);
            }
            return result;
        }
        convertBindingNameWithTypeAnnotation(name, tsType, parent) {
            const id = this.convertPattern(name);
            if (tsType) {
                id.typeAnnotation = this.convertTypeAnnotation(tsType, parent);
                this.fixParentLocation(id, id.typeAnnotation.range);
            }
            return id;
        }
        /**
         * Converts a child into a type annotation. This creates an intermediary
         * TypeAnnotation node to match what Flow does.
         * @param child The TypeScript AST node to convert.
         * @param parent parentNode
         * @returns The type annotation node.
         */
        convertTypeAnnotation(child, parent) {
            // in FunctionType and ConstructorType typeAnnotation has 2 characters `=>` and in other places is just colon
            const offset = (parent === null || parent === void 0 ? void 0 : parent.kind) === SyntaxKind.FunctionType ||
                (parent === null || parent === void 0 ? void 0 : parent.kind) === SyntaxKind.ConstructorType
                ? 2
                : 1;
            const annotationStartCol = child.getFullStart() - offset;
            const loc = (0, node_utils_1.getLocFor)(annotationStartCol, child.end, this.ast);
            return {
                type: ts_estree_1.AST_NODE_TYPES.TSTypeAnnotation,
                loc,
                range: [annotationStartCol, child.end],
                typeAnnotation: this.convertType(child),
            };
        }
        /**
         * Coverts body Nodes and add a directive field to StringLiterals
         * @param nodes of ts.Node
         * @param parent parentNode
         * @returns Array of body statements
         */
        convertBodyExpressions(nodes, parent) {
            let allowDirectives = (0, node_utils_1.canContainDirective)(parent);
            return (nodes
                .map(statement => {
                const child = this.convertChild(statement);
                if (allowDirectives) {
                    if ((child === null || child === void 0 ? void 0 : child.expression) &&
                        ts.isExpressionStatement(statement) &&
                        ts.isStringLiteral(statement.expression)) {
                        const raw = child.expression.raw;
                        child.directive = raw.slice(1, -1);
                        return child; // child can be null, but it's filtered below
                    }
                    else {
                        allowDirectives = false;
                    }
                }
                return child; // child can be null, but it's filtered below
            })
                // filter out unknown nodes for now
                .filter(statement => statement));
        }
        /**
         * Converts a ts.Node's typeArguments to TSTypeParameterInstantiation node
         * @param typeArguments ts.NodeArray typeArguments
         * @param node parent used to create this node
         * @returns TypeParameterInstantiation node
         */
        convertTypeArgumentsToTypeParameters(typeArguments, node) {
            const greaterThanToken = (0, node_utils_1.findNextToken)(typeArguments, this.ast, this.ast);
            return this.createNode(node, {
                type: ts_estree_1.AST_NODE_TYPES.TSTypeParameterInstantiation,
                range: [typeArguments.pos - 1, greaterThanToken.end],
                params: typeArguments.map(typeArgument => this.convertType(typeArgument)),
            });
        }
        /**
         * Converts a ts.Node's typeParameters to TSTypeParameterDeclaration node
         * @param typeParameters ts.Node typeParameters
         * @returns TypeParameterDeclaration node
         */
        convertTSTypeParametersToTypeParametersDeclaration(typeParameters) {
            const greaterThanToken = (0, node_utils_1.findNextToken)(typeParameters, this.ast, this.ast);
            return {
                type: ts_estree_1.AST_NODE_TYPES.TSTypeParameterDeclaration,
                range: [typeParameters.pos - 1, greaterThanToken.end],
                loc: (0, node_utils_1.getLocFor)(typeParameters.pos - 1, greaterThanToken.end, this.ast),
                params: typeParameters.map(typeParameter => this.convertType(typeParameter)),
            };
        }
        /**
         * Converts an array of ts.Node parameters into an array of ESTreeNode params
         * @param parameters An array of ts.Node params to be converted
         * @returns an array of converted ESTreeNode params
         */
        convertParameters(parameters) {
            if (!(parameters === null || parameters === void 0 ? void 0 : parameters.length)) {
                return [];
            }
            return parameters.map(param => {
                const convertedParam = this.convertChild(param);
                const decorators = (0, getModifiers_1.getDecorators)(param);
                if (decorators === null || decorators === void 0 ? void 0 : decorators.length) {
                    convertedParam.decorators = decorators.map(el => this.convertChild(el));
                }
                return convertedParam;
            });
        }
        convertChainExpression(node, tsNode) {
            const { child, isOptional } = (() => {
                if (node.type === ts_estree_1.AST_NODE_TYPES.MemberExpression) {
                    return { child: node.object, isOptional: node.optional };
                }
                if (node.type === ts_estree_1.AST_NODE_TYPES.CallExpression) {
                    return { child: node.callee, isOptional: node.optional };
                }
                return { child: node.expression, isOptional: false };
            })();
            const isChildUnwrappable = (0, node_utils_1.isChildUnwrappableOptionalChain)(tsNode, child);
            if (!isChildUnwrappable && !isOptional) {
                return node;
            }
            if (isChildUnwrappable && (0, node_utils_1.isChainExpression)(child)) {
                // unwrap the chain expression child
                const newChild = child.expression;
                if (node.type === ts_estree_1.AST_NODE_TYPES.MemberExpression) {
                    node.object = newChild;
                }
                else if (node.type === ts_estree_1.AST_NODE_TYPES.CallExpression) {
                    node.callee = newChild;
                }
                else {
                    node.expression = newChild;
                }
            }
            return this.createNode(tsNode, {
                type: ts_estree_1.AST_NODE_TYPES.ChainExpression,
                expression: node,
            });
        }
        /**
         * For nodes that are copied directly from the TypeScript AST into
         * ESTree mostly as-is. The only difference is the addition of a type
         * property instead of a kind property. Recursively copies all children.
         */
        deeplyCopy(node) {
            if (node.kind === ts.SyntaxKind.JSDocFunctionType) {
                throw (0, node_utils_1.createError)(this.ast, node.pos, 'JSDoc types can only be used inside documentation comments.');
            }
            const customType = `TS${SyntaxKind[node.kind]}`;
            /**
             * If the "errorOnUnknownASTType" option is set to true, throw an error,
             * otherwise fallback to just including the unknown type as-is.
             */
            if (this.options.errorOnUnknownASTType && !ts_estree_1.AST_NODE_TYPES[customType]) {
                throw new Error(`Unknown AST_NODE_TYPE: "${customType}"`);
            }
            const result = this.createNode(node, {
                type: customType,
            });
            if ('type' in node) {
                result.typeAnnotation =
                    node.type && 'kind' in node.type && ts.isTypeNode(node.type)
                        ? this.convertTypeAnnotation(node.type, node)
                        : null;
            }
            if ('typeArguments' in node) {
                result.typeParameters =
                    node.typeArguments && 'pos' in node.typeArguments
                        ? this.convertTypeArgumentsToTypeParameters(node.typeArguments, node)
                        : null;
            }
            if ('typeParameters' in node) {
                result.typeParameters =
                    node.typeParameters && 'pos' in node.typeParameters
                        ? this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters)
                        : null;
            }
            const decorators = (0, getModifiers_1.getDecorators)(node);
            if (decorators === null || decorators === void 0 ? void 0 : decorators.length) {
                result.decorators = decorators.map(el => this.convertChild(el));
            }
            // keys we never want to clone from the base typescript node as they
            // introduce garbage into our AST
            const KEYS_TO_NOT_COPY = new Set([
                '_children',
                'decorators',
                'end',
                'flags',
                'illegalDecorators',
                'heritageClauses',
                'locals',
                'localSymbol',
                'jsDoc',
                'kind',
                'modifierFlagsCache',
                'modifiers',
                'nextContainer',
                'parent',
                'pos',
                'symbol',
                'transformFlags',
                'type',
                'typeArguments',
                'typeParameters',
            ]);
            Object.entries(node)
                .filter(([key]) => !KEYS_TO_NOT_COPY.has(key))
                .forEach(([key, value]) => {
                if (Array.isArray(value)) {
                    result[key] = value.map(el => this.convertChild(el));
                }
                else if (value && typeof value === 'object' && value.kind) {
                    // need to check node[key].kind to ensure we don't try to convert a symbol
                    result[key] = this.convertChild(value);
                }
                else {
                    result[key] = value;
                }
            });
            return result;
        }
        convertJSXIdentifier(node) {
            const result = this.createNode(node, {
                type: ts_estree_1.AST_NODE_TYPES.JSXIdentifier,
                name: node.getText(),
            });
            this.registerTSNodeInNodeMap(node, result);
            return result;
        }
        convertJSXNamespaceOrIdentifier(node) {
            const text = node.getText();
            const colonIndex = text.indexOf(':');
            // this is intentional we can ignore conversion if `:` is in first character
            if (colonIndex > 0) {
                const range = (0, node_utils_1.getRange)(node, this.ast);
                const result = this.createNode(node, {
                    type: ts_estree_1.AST_NODE_TYPES.JSXNamespacedName,
                    namespace: this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXIdentifier,
                        name: text.slice(0, colonIndex),
                        range: [range[0], range[0] + colonIndex],
                    }),
                    name: this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXIdentifier,
                        name: text.slice(colonIndex + 1),
                        range: [range[0] + colonIndex + 1, range[1]],
                    }),
                    range,
                });
                this.registerTSNodeInNodeMap(node, result);
                return result;
            }
            return this.convertJSXIdentifier(node);
        }
        /**
         * Converts a TypeScript JSX node.tagName into an ESTree node.name
         * @param node the tagName object from a JSX ts.Node
         * @param parent
         * @returns the converted ESTree name object
         */
        convertJSXTagName(node, parent) {
            let result;
            switch (node.kind) {
                case SyntaxKind.PropertyAccessExpression:
                    if (node.name.kind === SyntaxKind.PrivateIdentifier) {
                        // This is one of the few times where TS explicitly errors, and doesn't even gracefully handle the syntax.
                        // So we shouldn't ever get into this state to begin with.
                        throw new Error('Non-private identifier expected.');
                    }
                    result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXMemberExpression,
                        object: this.convertJSXTagName(node.expression, parent),
                        property: this.convertJSXIdentifier(node.name),
                    });
                    break;
                case SyntaxKind.ThisKeyword:
                case SyntaxKind.Identifier:
                default:
                    return this.convertJSXNamespaceOrIdentifier(node);
            }
            this.registerTSNodeInNodeMap(node, result);
            return result;
        }
        convertMethodSignature(node) {
            const result = this.createNode(node, {
                type: ts_estree_1.AST_NODE_TYPES.TSMethodSignature,
                computed: (0, node_utils_1.isComputedProperty)(node.name),
                key: this.convertChild(node.name),
                params: this.convertParameters(node.parameters),
                kind: (() => {
                    switch (node.kind) {
                        case SyntaxKind.GetAccessor:
                            return 'get';
                        case SyntaxKind.SetAccessor:
                            return 'set';
                        case SyntaxKind.MethodSignature:
                            return 'method';
                    }
                })(),
            });
            if ((0, node_utils_1.isOptional)(node)) {
                result.optional = true;
            }
            if (node.type) {
                result.returnType = this.convertTypeAnnotation(node.type, node);
            }
            if ((0, node_utils_1.hasModifier)(SyntaxKind.ReadonlyKeyword, node)) {
                result.readonly = true;
            }
            if (node.typeParameters) {
                result.typeParameters =
                    this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
            }
            const accessibility = (0, node_utils_1.getTSNodeAccessibility)(node);
            if (accessibility) {
                result.accessibility = accessibility;
            }
            if ((0, node_utils_1.hasModifier)(SyntaxKind.ExportKeyword, node)) {
                result.export = true;
            }
            if ((0, node_utils_1.hasModifier)(SyntaxKind.StaticKeyword, node)) {
                result.static = true;
            }
            return result;
        }
        convertAssertClasue(node) {
            return node === undefined
                ? []
                : node.elements.map(element => this.convertChild(element));
        }
        /**
         * Applies the given TS modifiers to the given result object.
         *
         * This method adds not standardized `modifiers` property in nodes
         *
         * @param result
         * @param modifiers original ts.Nodes from the node.modifiers array
         * @returns the current result object will be mutated
         */
        applyModifiersToResult(result, modifiers) {
            if (!modifiers) {
                return;
            }
            const remainingModifiers = [];
            /**
             * Some modifiers are explicitly handled by applying them as
             * boolean values on the result node. As well as adding them
             * to the result, we remove them from the array, so that they
             * are not handled twice.
             */
            for (const modifier of modifiers) {
                switch (modifier.kind) {
                    /**
                     * Ignore ExportKeyword and DefaultKeyword, they are handled
                     * via the fixExports utility function
                     */
                    case SyntaxKind.ExportKeyword:
                    case SyntaxKind.DefaultKeyword:
                        break;
                    case SyntaxKind.ConstKeyword:
                        result.const = true;
                        break;
                    case SyntaxKind.DeclareKeyword:
                        result.declare = true;
                        break;
                    default:
                        remainingModifiers.push(this.convertChild(modifier));
                        break;
                }
            }
            /**
             * If there are still valid modifiers available which have
             * not been explicitly handled above, we just convert and
             * add the modifiers array to the result node.
             */
            if (remainingModifiers.length > 0) {
                result.modifiers = remainingModifiers;
            }
        }
        /**
         * Uses the provided range location to adjust the location data of the given Node
         * @param result The node that will have its location data mutated
         * @param childRange The child node range used to expand location
         */
        fixParentLocation(result, childRange) {
            if (childRange[0] < result.range[0]) {
                result.range[0] = childRange[0];
                result.loc.start = (0, node_utils_1.getLineAndCharacterFor)(result.range[0], this.ast);
            }
            if (childRange[1] > result.range[1]) {
                result.range[1] = childRange[1];
                result.loc.end = (0, node_utils_1.getLineAndCharacterFor)(result.range[1], this.ast);
            }
        }
        assertModuleSpecifier(node, allowNull) {
            var _a;
            if (!allowNull && node.moduleSpecifier == null) {
                throw (0, node_utils_1.createError)(this.ast, node.pos, 'Module specifier must be a string literal.');
            }
            if (node.moduleSpecifier &&
                ((_a = node.moduleSpecifier) === null || _a === void 0 ? void 0 : _a.kind) !== SyntaxKind.StringLiteral) {
                throw (0, node_utils_1.createError)(this.ast, node.moduleSpecifier.pos, 'Module specifier must be a string literal.');
            }
        }
        /**
         * Converts a TypeScript node into an ESTree node.
         * The core of the conversion logic:
         * Identify and convert each relevant TypeScript SyntaxKind
         * @param node the child ts.Node
         * @param parent parentNode
         * @returns the converted ESTree node
         */
        convertNode(node, parent) {
            var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
            switch (node.kind) {
                case SyntaxKind.SourceFile: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Program,
                        body: this.convertBodyExpressions(node.statements, node),
                        sourceType: node.externalModuleIndicator ? 'module' : 'script',
                        range: [node.getStart(this.ast), node.endOfFileToken.end],
                    });
                }
                case SyntaxKind.Block: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.BlockStatement,
                        body: this.convertBodyExpressions(node.statements, node),
                    });
                }
                case SyntaxKind.Identifier: {
                    if ((0, node_utils_1.isThisInTypeQuery)(node)) {
                        // special case for `typeof this.foo` - TS emits an Identifier for `this`
                        // but we want to treat it as a ThisExpression for consistency
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ThisExpression,
                        });
                    }
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Identifier,
                        name: node.text,
                    });
                }
                case SyntaxKind.PrivateIdentifier: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.PrivateIdentifier,
                        // typescript includes the `#` in the text
                        name: node.text.slice(1),
                    });
                }
                case SyntaxKind.WithStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.WithStatement,
                        object: this.convertChild(node.expression),
                        body: this.convertChild(node.statement),
                    });
                // Control Flow
                case SyntaxKind.ReturnStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ReturnStatement,
                        argument: this.convertChild(node.expression),
                    });
                case SyntaxKind.LabeledStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.LabeledStatement,
                        label: this.convertChild(node.label),
                        body: this.convertChild(node.statement),
                    });
                case SyntaxKind.ContinueStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ContinueStatement,
                        label: this.convertChild(node.label),
                    });
                case SyntaxKind.BreakStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.BreakStatement,
                        label: this.convertChild(node.label),
                    });
                // Choice
                case SyntaxKind.IfStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.IfStatement,
                        test: this.convertChild(node.expression),
                        consequent: this.convertChild(node.thenStatement),
                        alternate: this.convertChild(node.elseStatement),
                    });
                case SyntaxKind.SwitchStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.SwitchStatement,
                        discriminant: this.convertChild(node.expression),
                        cases: node.caseBlock.clauses.map(el => this.convertChild(el)),
                    });
                case SyntaxKind.CaseClause:
                case SyntaxKind.DefaultClause:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.SwitchCase,
                        // expression is present in case only
                        test: node.kind === SyntaxKind.CaseClause
                            ? this.convertChild(node.expression)
                            : null,
                        consequent: node.statements.map(el => this.convertChild(el)),
                    });
                // Exceptions
                case SyntaxKind.ThrowStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ThrowStatement,
                        argument: this.convertChild(node.expression),
                    });
                case SyntaxKind.TryStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TryStatement,
                        block: this.convertChild(node.tryBlock),
                        handler: this.convertChild(node.catchClause),
                        finalizer: this.convertChild(node.finallyBlock),
                    });
                case SyntaxKind.CatchClause:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.CatchClause,
                        param: node.variableDeclaration
                            ? this.convertBindingNameWithTypeAnnotation(node.variableDeclaration.name, node.variableDeclaration.type)
                            : null,
                        body: this.convertChild(node.block),
                    });
                // Loops
                case SyntaxKind.WhileStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.WhileStatement,
                        test: this.convertChild(node.expression),
                        body: this.convertChild(node.statement),
                    });
                /**
                 * Unlike other parsers, TypeScript calls a "DoWhileStatement"
                 * a "DoStatement"
                 */
                case SyntaxKind.DoStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.DoWhileStatement,
                        test: this.convertChild(node.expression),
                        body: this.convertChild(node.statement),
                    });
                case SyntaxKind.ForStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ForStatement,
                        init: this.convertChild(node.initializer),
                        test: this.convertChild(node.condition),
                        update: this.convertChild(node.incrementor),
                        body: this.convertChild(node.statement),
                    });
                case SyntaxKind.ForInStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ForInStatement,
                        left: this.convertPattern(node.initializer),
                        right: this.convertChild(node.expression),
                        body: this.convertChild(node.statement),
                    });
                case SyntaxKind.ForOfStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ForOfStatement,
                        left: this.convertPattern(node.initializer),
                        right: this.convertChild(node.expression),
                        body: this.convertChild(node.statement),
                        await: Boolean(node.awaitModifier &&
                            node.awaitModifier.kind === SyntaxKind.AwaitKeyword),
                    });
                // Declarations
                case SyntaxKind.FunctionDeclaration: {
                    const isDeclare = (0, node_utils_1.hasModifier)(SyntaxKind.DeclareKeyword, node);
                    const result = this.createNode(node, {
                        type: isDeclare || !node.body
                            ? ts_estree_1.AST_NODE_TYPES.TSDeclareFunction
                            : ts_estree_1.AST_NODE_TYPES.FunctionDeclaration,
                        id: this.convertChild(node.name),
                        generator: !!node.asteriskToken,
                        expression: false,
                        async: (0, node_utils_1.hasModifier)(SyntaxKind.AsyncKeyword, node),
                        params: this.convertParameters(node.parameters),
                        body: this.convertChild(node.body) || undefined,
                    });
                    // Process returnType
                    if (node.type) {
                        result.returnType = this.convertTypeAnnotation(node.type, node);
                    }
                    // Process typeParameters
                    if (node.typeParameters) {
                        result.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                    }
                    if (isDeclare) {
                        result.declare = true;
                    }
                    // check for exports
                    return this.fixExports(node, result);
                }
                case SyntaxKind.VariableDeclaration: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.VariableDeclarator,
                        id: this.convertBindingNameWithTypeAnnotation(node.name, node.type, node),
                        init: this.convertChild(node.initializer),
                    });
                    if (node.exclamationToken) {
                        result.definite = true;
                    }
                    return result;
                }
                case SyntaxKind.VariableStatement: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.VariableDeclaration,
                        declarations: node.declarationList.declarations.map(el => this.convertChild(el)),
                        kind: (0, node_utils_1.getDeclarationKind)(node.declarationList),
                    });
                    /**
                     * Semantically, decorators are not allowed on variable declarations,
                     * Pre 4.8 TS would include them in the AST, so we did as well.
                     * However as of 4.8 TS no longer includes it (as it is, well, invalid).
                     *
                     * So for consistency across versions, we no longer include it either.
                     */
                    if ((0, node_utils_1.hasModifier)(SyntaxKind.DeclareKeyword, node)) {
                        result.declare = true;
                    }
                    // check for exports
                    return this.fixExports(node, result);
                }
                // mostly for for-of, for-in
                case SyntaxKind.VariableDeclarationList:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.VariableDeclaration,
                        declarations: node.declarations.map(el => this.convertChild(el)),
                        kind: (0, node_utils_1.getDeclarationKind)(node),
                    });
                // Expressions
                case SyntaxKind.ExpressionStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ExpressionStatement,
                        expression: this.convertChild(node.expression),
                    });
                case SyntaxKind.ThisKeyword:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ThisExpression,
                    });
                case SyntaxKind.ArrayLiteralExpression: {
                    // TypeScript uses ArrayLiteralExpression in destructuring assignment, too
                    if (this.allowPattern) {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ArrayPattern,
                            elements: node.elements.map(el => this.convertPattern(el)),
                        });
                    }
                    else {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ArrayExpression,
                            elements: node.elements.map(el => this.convertChild(el)),
                        });
                    }
                }
                case SyntaxKind.ObjectLiteralExpression: {
                    // TypeScript uses ObjectLiteralExpression in destructuring assignment, too
                    if (this.allowPattern) {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ObjectPattern,
                            properties: node.properties.map(el => this.convertPattern(el)),
                        });
                    }
                    else {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ObjectExpression,
                            properties: node.properties.map(el => this.convertChild(el)),
                        });
                    }
                }
                case SyntaxKind.PropertyAssignment:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Property,
                        key: this.convertChild(node.name),
                        value: this.converter(node.initializer, node, this.inTypeMode, this.allowPattern),
                        computed: (0, node_utils_1.isComputedProperty)(node.name),
                        method: false,
                        shorthand: false,
                        kind: 'init',
                    });
                case SyntaxKind.ShorthandPropertyAssignment: {
                    if (node.objectAssignmentInitializer) {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.Property,
                            key: this.convertChild(node.name),
                            value: this.createNode(node, {
                                type: ts_estree_1.AST_NODE_TYPES.AssignmentPattern,
                                left: this.convertPattern(node.name),
                                right: this.convertChild(node.objectAssignmentInitializer),
                            }),
                            computed: false,
                            method: false,
                            shorthand: true,
                            kind: 'init',
                        });
                    }
                    else {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.Property,
                            key: this.convertChild(node.name),
                            value: this.convertChild(node.name),
                            computed: false,
                            method: false,
                            shorthand: true,
                            kind: 'init',
                        });
                    }
                }
                case SyntaxKind.ComputedPropertyName:
                    return this.convertChild(node.expression);
                case SyntaxKind.PropertyDeclaration: {
                    const isAbstract = (0, node_utils_1.hasModifier)(SyntaxKind.AbstractKeyword, node);
                    const isAccessor = (0, node_utils_1.hasModifier)(SyntaxKind.AccessorKeyword, node);
                    // eslint-disable-next-line @typescript-eslint/explicit-function-return-type -- TODO - add ignore IIFE option
                    const type = (() => {
                        if (isAccessor) {
                            if (isAbstract) {
                                return ts_estree_1.AST_NODE_TYPES.TSAbstractAccessorProperty;
                            }
                            return ts_estree_1.AST_NODE_TYPES.AccessorProperty;
                        }
                        if (isAbstract) {
                            return ts_estree_1.AST_NODE_TYPES.TSAbstractPropertyDefinition;
                        }
                        return ts_estree_1.AST_NODE_TYPES.PropertyDefinition;
                    })();
                    const result = this.createNode(node, {
                        type,
                        key: this.convertChild(node.name),
                        value: isAbstract ? null : this.convertChild(node.initializer),
                        computed: (0, node_utils_1.isComputedProperty)(node.name),
                        static: (0, node_utils_1.hasModifier)(SyntaxKind.StaticKeyword, node),
                        readonly: (0, node_utils_1.hasModifier)(SyntaxKind.ReadonlyKeyword, node) || undefined,
                        declare: (0, node_utils_1.hasModifier)(SyntaxKind.DeclareKeyword, node),
                        override: (0, node_utils_1.hasModifier)(SyntaxKind.OverrideKeyword, node),
                    });
                    if (node.type) {
                        result.typeAnnotation = this.convertTypeAnnotation(node.type, node);
                    }
                    const decorators = (0, getModifiers_1.getDecorators)(node);
                    if (decorators) {
                        result.decorators = decorators.map(el => this.convertChild(el));
                    }
                    const accessibility = (0, node_utils_1.getTSNodeAccessibility)(node);
                    if (accessibility) {
                        result.accessibility = accessibility;
                    }
                    if ((node.name.kind === SyntaxKind.Identifier ||
                        node.name.kind === SyntaxKind.ComputedPropertyName ||
                        node.name.kind === SyntaxKind.PrivateIdentifier) &&
                        node.questionToken) {
                        result.optional = true;
                    }
                    if (node.exclamationToken) {
                        result.definite = true;
                    }
                    if (result.key.type === ts_estree_1.AST_NODE_TYPES.Literal && node.questionToken) {
                        result.optional = true;
                    }
                    return result;
                }
                case SyntaxKind.GetAccessor:
                case SyntaxKind.SetAccessor: {
                    if (node.parent.kind === SyntaxKind.InterfaceDeclaration ||
                        node.parent.kind === SyntaxKind.TypeLiteral) {
                        return this.convertMethodSignature(node);
                    }
                }
                // otherwise, it is a non-type accessor - intentional fallthrough
                case SyntaxKind.MethodDeclaration: {
                    const method = this.createNode(node, {
                        type: !node.body
                            ? ts_estree_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression
                            : ts_estree_1.AST_NODE_TYPES.FunctionExpression,
                        id: null,
                        generator: !!node.asteriskToken,
                        expression: false,
                        async: (0, node_utils_1.hasModifier)(SyntaxKind.AsyncKeyword, node),
                        body: this.convertChild(node.body),
                        range: [node.parameters.pos - 1, node.end],
                        params: [],
                    });
                    if (node.type) {
                        method.returnType = this.convertTypeAnnotation(node.type, node);
                    }
                    // Process typeParameters
                    if (node.typeParameters) {
                        method.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                        this.fixParentLocation(method, method.typeParameters.range);
                    }
                    let result;
                    if (parent.kind === SyntaxKind.ObjectLiteralExpression) {
                        method.params = node.parameters.map(el => this.convertChild(el));
                        result = this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.Property,
                            key: this.convertChild(node.name),
                            value: method,
                            computed: (0, node_utils_1.isComputedProperty)(node.name),
                            method: node.kind === SyntaxKind.MethodDeclaration,
                            shorthand: false,
                            kind: 'init',
                        });
                    }
                    else {
                        // class
                        /**
                         * Unlike in object literal methods, class method params can have decorators
                         */
                        method.params = this.convertParameters(node.parameters);
                        /**
                         * TypeScript class methods can be defined as "abstract"
                         */
                        const methodDefinitionType = (0, node_utils_1.hasModifier)(SyntaxKind.AbstractKeyword, node)
                            ? ts_estree_1.AST_NODE_TYPES.TSAbstractMethodDefinition
                            : ts_estree_1.AST_NODE_TYPES.MethodDefinition;
                        result = this.createNode(node, {
                            type: methodDefinitionType,
                            key: this.convertChild(node.name),
                            value: method,
                            computed: (0, node_utils_1.isComputedProperty)(node.name),
                            static: (0, node_utils_1.hasModifier)(SyntaxKind.StaticKeyword, node),
                            kind: 'method',
                            override: (0, node_utils_1.hasModifier)(SyntaxKind.OverrideKeyword, node),
                        });
                        const decorators = (0, getModifiers_1.getDecorators)(node);
                        if (decorators) {
                            result.decorators = decorators.map(el => this.convertChild(el));
                        }
                        const accessibility = (0, node_utils_1.getTSNodeAccessibility)(node);
                        if (accessibility) {
                            result.accessibility = accessibility;
                        }
                    }
                    if (node.questionToken) {
                        result.optional = true;
                    }
                    if (node.kind === SyntaxKind.GetAccessor) {
                        result.kind = 'get';
                    }
                    else if (node.kind === SyntaxKind.SetAccessor) {
                        result.kind = 'set';
                    }
                    else if (!result.static &&
                        node.name.kind === SyntaxKind.StringLiteral &&
                        node.name.text === 'constructor' &&
                        result.type !== ts_estree_1.AST_NODE_TYPES.Property) {
                        result.kind = 'constructor';
                    }
                    return result;
                }
                // TypeScript uses this even for static methods named "constructor"
                case SyntaxKind.Constructor: {
                    const lastModifier = (0, node_utils_1.getLastModifier)(node);
                    const constructorToken = (lastModifier && (0, node_utils_1.findNextToken)(lastModifier, node, this.ast)) ||
                        node.getFirstToken();
                    const constructor = this.createNode(node, {
                        type: !node.body
                            ? ts_estree_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression
                            : ts_estree_1.AST_NODE_TYPES.FunctionExpression,
                        id: null,
                        params: this.convertParameters(node.parameters),
                        generator: false,
                        expression: false,
                        async: false,
                        body: this.convertChild(node.body),
                        range: [node.parameters.pos - 1, node.end],
                    });
                    // Process typeParameters
                    if (node.typeParameters) {
                        constructor.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                        this.fixParentLocation(constructor, constructor.typeParameters.range);
                    }
                    // Process returnType
                    if (node.type) {
                        constructor.returnType = this.convertTypeAnnotation(node.type, node);
                    }
                    const constructorKey = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Identifier,
                        name: 'constructor',
                        range: [constructorToken.getStart(this.ast), constructorToken.end],
                    });
                    const isStatic = (0, node_utils_1.hasModifier)(SyntaxKind.StaticKeyword, node);
                    const result = this.createNode(node, {
                        type: (0, node_utils_1.hasModifier)(SyntaxKind.AbstractKeyword, node)
                            ? ts_estree_1.AST_NODE_TYPES.TSAbstractMethodDefinition
                            : ts_estree_1.AST_NODE_TYPES.MethodDefinition,
                        key: constructorKey,
                        value: constructor,
                        computed: false,
                        static: isStatic,
                        kind: isStatic ? 'method' : 'constructor',
                        override: false,
                    });
                    const accessibility = (0, node_utils_1.getTSNodeAccessibility)(node);
                    if (accessibility) {
                        result.accessibility = accessibility;
                    }
                    return result;
                }
                case SyntaxKind.FunctionExpression: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.FunctionExpression,
                        id: this.convertChild(node.name),
                        generator: !!node.asteriskToken,
                        params: this.convertParameters(node.parameters),
                        body: this.convertChild(node.body),
                        async: (0, node_utils_1.hasModifier)(SyntaxKind.AsyncKeyword, node),
                        expression: false,
                    });
                    // Process returnType
                    if (node.type) {
                        result.returnType = this.convertTypeAnnotation(node.type, node);
                    }
                    // Process typeParameters
                    if (node.typeParameters) {
                        result.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                    }
                    return result;
                }
                case SyntaxKind.SuperKeyword:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Super,
                    });
                case SyntaxKind.ArrayBindingPattern:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ArrayPattern,
                        elements: node.elements.map(el => this.convertPattern(el)),
                    });
                // occurs with missing array elements like [,]
                case SyntaxKind.OmittedExpression:
                    return null;
                case SyntaxKind.ObjectBindingPattern:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ObjectPattern,
                        properties: node.elements.map(el => this.convertPattern(el)),
                    });
                case SyntaxKind.BindingElement: {
                    if (parent.kind === SyntaxKind.ArrayBindingPattern) {
                        const arrayItem = this.convertChild(node.name, parent);
                        if (node.initializer) {
                            return this.createNode(node, {
                                type: ts_estree_1.AST_NODE_TYPES.AssignmentPattern,
                                left: arrayItem,
                                right: this.convertChild(node.initializer),
                            });
                        }
                        else if (node.dotDotDotToken) {
                            return this.createNode(node, {
                                type: ts_estree_1.AST_NODE_TYPES.RestElement,
                                argument: arrayItem,
                            });
                        }
                        else {
                            return arrayItem;
                        }
                    }
                    else {
                        let result;
                        if (node.dotDotDotToken) {
                            result = this.createNode(node, {
                                type: ts_estree_1.AST_NODE_TYPES.RestElement,
                                argument: this.convertChild((_a = node.propertyName) !== null && _a !== void 0 ? _a : node.name),
                            });
                        }
                        else {
                            result = this.createNode(node, {
                                type: ts_estree_1.AST_NODE_TYPES.Property,
                                key: this.convertChild((_b = node.propertyName) !== null && _b !== void 0 ? _b : node.name),
                                value: this.convertChild(node.name),
                                computed: Boolean(node.propertyName &&
                                    node.propertyName.kind === SyntaxKind.ComputedPropertyName),
                                method: false,
                                shorthand: !node.propertyName,
                                kind: 'init',
                            });
                        }
                        if (node.initializer) {
                            result.value = this.createNode(node, {
                                type: ts_estree_1.AST_NODE_TYPES.AssignmentPattern,
                                left: this.convertChild(node.name),
                                right: this.convertChild(node.initializer),
                                range: [node.name.getStart(this.ast), node.initializer.end],
                            });
                        }
                        return result;
                    }
                }
                case SyntaxKind.ArrowFunction: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ArrowFunctionExpression,
                        generator: false,
                        id: null,
                        params: this.convertParameters(node.parameters),
                        body: this.convertChild(node.body),
                        async: (0, node_utils_1.hasModifier)(SyntaxKind.AsyncKeyword, node),
                        expression: node.body.kind !== SyntaxKind.Block,
                    });
                    // Process returnType
                    if (node.type) {
                        result.returnType = this.convertTypeAnnotation(node.type, node);
                    }
                    // Process typeParameters
                    if (node.typeParameters) {
                        result.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                    }
                    return result;
                }
                case SyntaxKind.YieldExpression:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.YieldExpression,
                        delegate: !!node.asteriskToken,
                        argument: this.convertChild(node.expression),
                    });
                case SyntaxKind.AwaitExpression:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.AwaitExpression,
                        argument: this.convertChild(node.expression),
                    });
                // Template Literals
                case SyntaxKind.NoSubstitutionTemplateLiteral:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TemplateLiteral,
                        quasis: [
                            this.createNode(node, {
                                type: ts_estree_1.AST_NODE_TYPES.TemplateElement,
                                value: {
                                    raw: this.ast.text.slice(node.getStart(this.ast) + 1, node.end - 1),
                                    cooked: node.text,
                                },
                                tail: true,
                            }),
                        ],
                        expressions: [],
                    });
                case SyntaxKind.TemplateExpression: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TemplateLiteral,
                        quasis: [this.convertChild(node.head)],
                        expressions: [],
                    });
                    node.templateSpans.forEach(templateSpan => {
                        result.expressions.push(this.convertChild(templateSpan.expression));
                        result.quasis.push(this.convertChild(templateSpan.literal));
                    });
                    return result;
                }
                case SyntaxKind.TaggedTemplateExpression:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TaggedTemplateExpression,
                        typeParameters: node.typeArguments
                            ? this.convertTypeArgumentsToTypeParameters(node.typeArguments, node)
                            : undefined,
                        tag: this.convertChild(node.tag),
                        quasi: this.convertChild(node.template),
                    });
                case SyntaxKind.TemplateHead:
                case SyntaxKind.TemplateMiddle:
                case SyntaxKind.TemplateTail: {
                    const tail = node.kind === SyntaxKind.TemplateTail;
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TemplateElement,
                        value: {
                            raw: this.ast.text.slice(node.getStart(this.ast) + 1, node.end - (tail ? 1 : 2)),
                            cooked: node.text,
                        },
                        tail,
                    });
                }
                // Patterns
                case SyntaxKind.SpreadAssignment:
                case SyntaxKind.SpreadElement: {
                    if (this.allowPattern) {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.RestElement,
                            argument: this.convertPattern(node.expression),
                        });
                    }
                    else {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.SpreadElement,
                            argument: this.convertChild(node.expression),
                        });
                    }
                }
                case SyntaxKind.Parameter: {
                    let parameter;
                    let result;
                    if (node.dotDotDotToken) {
                        parameter = result = this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.RestElement,
                            argument: this.convertChild(node.name),
                        });
                    }
                    else if (node.initializer) {
                        parameter = this.convertChild(node.name);
                        result = this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.AssignmentPattern,
                            left: parameter,
                            right: this.convertChild(node.initializer),
                        });
                        const modifiers = (0, getModifiers_1.getModifiers)(node);
                        if (modifiers) {
                            // AssignmentPattern should not contain modifiers in range
                            result.range[0] = parameter.range[0];
                            result.loc = (0, node_utils_1.getLocFor)(result.range[0], result.range[1], this.ast);
                        }
                    }
                    else {
                        parameter = result = this.convertChild(node.name, parent);
                    }
                    if (node.type) {
                        parameter.typeAnnotation = this.convertTypeAnnotation(node.type, node);
                        this.fixParentLocation(parameter, parameter.typeAnnotation.range);
                    }
                    if (node.questionToken) {
                        if (node.questionToken.end > parameter.range[1]) {
                            parameter.range[1] = node.questionToken.end;
                            parameter.loc.end = (0, node_utils_1.getLineAndCharacterFor)(parameter.range[1], this.ast);
                        }
                        parameter.optional = true;
                    }
                    const modifiers = (0, getModifiers_1.getModifiers)(node);
                    if (modifiers) {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.TSParameterProperty,
                            accessibility: (_c = (0, node_utils_1.getTSNodeAccessibility)(node)) !== null && _c !== void 0 ? _c : undefined,
                            readonly: (0, node_utils_1.hasModifier)(SyntaxKind.ReadonlyKeyword, node) || undefined,
                            static: (0, node_utils_1.hasModifier)(SyntaxKind.StaticKeyword, node) || undefined,
                            export: (0, node_utils_1.hasModifier)(SyntaxKind.ExportKeyword, node) || undefined,
                            override: (0, node_utils_1.hasModifier)(SyntaxKind.OverrideKeyword, node) || undefined,
                            parameter: result,
                        });
                    }
                    return result;
                }
                // Classes
                case SyntaxKind.ClassDeclaration:
                case SyntaxKind.ClassExpression: {
                    const heritageClauses = (_d = node.heritageClauses) !== null && _d !== void 0 ? _d : [];
                    const classNodeType = node.kind === SyntaxKind.ClassDeclaration
                        ? ts_estree_1.AST_NODE_TYPES.ClassDeclaration
                        : ts_estree_1.AST_NODE_TYPES.ClassExpression;
                    const superClass = heritageClauses.find(clause => clause.token === SyntaxKind.ExtendsKeyword);
                    const implementsClause = heritageClauses.find(clause => clause.token === SyntaxKind.ImplementsKeyword);
                    const result = this.createNode(node, {
                        type: classNodeType,
                        id: this.convertChild(node.name),
                        body: this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ClassBody,
                            body: [],
                            range: [node.members.pos - 1, node.end],
                        }),
                        superClass: (superClass === null || superClass === void 0 ? void 0 : superClass.types[0])
                            ? this.convertChild(superClass.types[0].expression)
                            : null,
                    });
                    if (superClass) {
                        if (superClass.types.length > 1) {
                            throw (0, node_utils_1.createError)(this.ast, superClass.types[1].pos, 'Classes can only extend a single class.');
                        }
                        if ((_e = superClass.types[0]) === null || _e === void 0 ? void 0 : _e.typeArguments) {
                            result.superTypeParameters =
                                this.convertTypeArgumentsToTypeParameters(superClass.types[0].typeArguments, superClass.types[0]);
                        }
                    }
                    if (node.typeParameters) {
                        result.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                    }
                    if (implementsClause) {
                        result.implements = implementsClause.types.map(el => this.convertChild(el));
                    }
                    /**
                     * TypeScript class declarations can be defined as "abstract"
                     */
                    if ((0, node_utils_1.hasModifier)(SyntaxKind.AbstractKeyword, node)) {
                        result.abstract = true;
                    }
                    if ((0, node_utils_1.hasModifier)(SyntaxKind.DeclareKeyword, node)) {
                        result.declare = true;
                    }
                    const decorators = (0, getModifiers_1.getDecorators)(node);
                    if (decorators) {
                        result.decorators = decorators.map(el => this.convertChild(el));
                    }
                    const filteredMembers = node.members.filter(node_utils_1.isESTreeClassMember);
                    if (filteredMembers.length) {
                        result.body.body = filteredMembers.map(el => this.convertChild(el));
                    }
                    // check for exports
                    return this.fixExports(node, result);
                }
                // Modules
                case SyntaxKind.ModuleBlock:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSModuleBlock,
                        body: this.convertBodyExpressions(node.statements, node),
                    });
                case SyntaxKind.ImportDeclaration: {
                    this.assertModuleSpecifier(node, false);
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ImportDeclaration,
                        source: this.convertChild(node.moduleSpecifier),
                        specifiers: [],
                        importKind: 'value',
                        assertions: this.convertAssertClasue(node.assertClause),
                    });
                    if (node.importClause) {
                        if (node.importClause.isTypeOnly) {
                            result.importKind = 'type';
                        }
                        if (node.importClause.name) {
                            result.specifiers.push(this.convertChild(node.importClause));
                        }
                        if (node.importClause.namedBindings) {
                            switch (node.importClause.namedBindings.kind) {
                                case SyntaxKind.NamespaceImport:
                                    result.specifiers.push(this.convertChild(node.importClause.namedBindings));
                                    break;
                                case SyntaxKind.NamedImports:
                                    result.specifiers = result.specifiers.concat(node.importClause.namedBindings.elements.map(el => this.convertChild(el)));
                                    break;
                            }
                        }
                    }
                    return result;
                }
                case SyntaxKind.NamespaceImport:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ImportNamespaceSpecifier,
                        local: this.convertChild(node.name),
                    });
                case SyntaxKind.ImportSpecifier:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ImportSpecifier,
                        local: this.convertChild(node.name),
                        imported: this.convertChild((_f = node.propertyName) !== null && _f !== void 0 ? _f : node.name),
                        importKind: node.isTypeOnly ? 'type' : 'value',
                    });
                case SyntaxKind.ImportClause: {
                    const local = this.convertChild(node.name);
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ImportDefaultSpecifier,
                        local,
                        range: local.range,
                    });
                }
                case SyntaxKind.ExportDeclaration: {
                    if (((_g = node.exportClause) === null || _g === void 0 ? void 0 : _g.kind) === SyntaxKind.NamedExports) {
                        this.assertModuleSpecifier(node, true);
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ExportNamedDeclaration,
                            source: this.convertChild(node.moduleSpecifier),
                            specifiers: node.exportClause.elements.map(el => this.convertChild(el)),
                            exportKind: node.isTypeOnly ? 'type' : 'value',
                            declaration: null,
                            assertions: this.convertAssertClasue(node.assertClause),
                        });
                    }
                    else {
                        this.assertModuleSpecifier(node, false);
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ExportAllDeclaration,
                            source: this.convertChild(node.moduleSpecifier),
                            exportKind: node.isTypeOnly ? 'type' : 'value',
                            exported: 
                            // note - for compat with 3.7.x, where node.exportClause is always undefined and
                            //        SyntaxKind.NamespaceExport does not exist yet (i.e. is undefined), this
                            //        cannot be shortened to an optional chain, or else you end up with
                            //        undefined === undefined, and the true path will hard error at runtime
                            node.exportClause &&
                                node.exportClause.kind === SyntaxKind.NamespaceExport
                                ? this.convertChild(node.exportClause.name)
                                : null,
                            assertions: this.convertAssertClasue(node.assertClause),
                        });
                    }
                }
                case SyntaxKind.ExportSpecifier:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ExportSpecifier,
                        local: this.convertChild((_h = node.propertyName) !== null && _h !== void 0 ? _h : node.name),
                        exported: this.convertChild(node.name),
                        exportKind: node.isTypeOnly ? 'type' : 'value',
                    });
                case SyntaxKind.ExportAssignment:
                    if (node.isExportEquals) {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.TSExportAssignment,
                            expression: this.convertChild(node.expression),
                        });
                    }
                    else {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ExportDefaultDeclaration,
                            declaration: this.convertChild(node.expression),
                            exportKind: 'value',
                        });
                    }
                // Unary Operations
                case SyntaxKind.PrefixUnaryExpression:
                case SyntaxKind.PostfixUnaryExpression: {
                    const operator = (0, node_utils_1.getTextForTokenKind)(node.operator);
                    /**
                     * ESTree uses UpdateExpression for ++/--
                     */
                    if (operator === '++' || operator === '--') {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.UpdateExpression,
                            operator,
                            prefix: node.kind === SyntaxKind.PrefixUnaryExpression,
                            argument: this.convertChild(node.operand),
                        });
                    }
                    else {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.UnaryExpression,
                            operator,
                            prefix: node.kind === SyntaxKind.PrefixUnaryExpression,
                            argument: this.convertChild(node.operand),
                        });
                    }
                }
                case SyntaxKind.DeleteExpression:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.UnaryExpression,
                        operator: 'delete',
                        prefix: true,
                        argument: this.convertChild(node.expression),
                    });
                case SyntaxKind.VoidExpression:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.UnaryExpression,
                        operator: 'void',
                        prefix: true,
                        argument: this.convertChild(node.expression),
                    });
                case SyntaxKind.TypeOfExpression:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.UnaryExpression,
                        operator: 'typeof',
                        prefix: true,
                        argument: this.convertChild(node.expression),
                    });
                case SyntaxKind.TypeOperator:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTypeOperator,
                        operator: (0, node_utils_1.getTextForTokenKind)(node.operator),
                        typeAnnotation: this.convertChild(node.type),
                    });
                // Binary Operations
                case SyntaxKind.BinaryExpression: {
                    // TypeScript uses BinaryExpression for sequences as well
                    if ((0, node_utils_1.isComma)(node.operatorToken)) {
                        const result = this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.SequenceExpression,
                            expressions: [],
                        });
                        const left = this.convertChild(node.left);
                        if (left.type === ts_estree_1.AST_NODE_TYPES.SequenceExpression &&
                            node.left.kind !== SyntaxKind.ParenthesizedExpression) {
                            result.expressions = result.expressions.concat(left.expressions);
                        }
                        else {
                            result.expressions.push(left);
                        }
                        result.expressions.push(this.convertChild(node.right));
                        return result;
                    }
                    else {
                        const type = (0, node_utils_1.getBinaryExpressionType)(node.operatorToken);
                        if (this.allowPattern &&
                            type === ts_estree_1.AST_NODE_TYPES.AssignmentExpression) {
                            return this.createNode(node, {
                                type: ts_estree_1.AST_NODE_TYPES.AssignmentPattern,
                                left: this.convertPattern(node.left, node),
                                right: this.convertChild(node.right),
                            });
                        }
                        return this.createNode(node, {
                            type,
                            operator: (0, node_utils_1.getTextForTokenKind)(node.operatorToken.kind),
                            left: this.converter(node.left, node, this.inTypeMode, type === ts_estree_1.AST_NODE_TYPES.AssignmentExpression),
                            right: this.convertChild(node.right),
                        });
                    }
                }
                case SyntaxKind.PropertyAccessExpression: {
                    const object = this.convertChild(node.expression);
                    const property = this.convertChild(node.name);
                    const computed = false;
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.MemberExpression,
                        object,
                        property,
                        computed,
                        optional: node.questionDotToken !== undefined,
                    });
                    return this.convertChainExpression(result, node);
                }
                case SyntaxKind.ElementAccessExpression: {
                    const object = this.convertChild(node.expression);
                    const property = this.convertChild(node.argumentExpression);
                    const computed = true;
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.MemberExpression,
                        object,
                        property,
                        computed,
                        optional: node.questionDotToken !== undefined,
                    });
                    return this.convertChainExpression(result, node);
                }
                case SyntaxKind.CallExpression: {
                    if (node.expression.kind === SyntaxKind.ImportKeyword) {
                        if (node.arguments.length !== 1 && node.arguments.length !== 2) {
                            throw (0, node_utils_1.createError)(this.ast, node.arguments.pos, 'Dynamic import requires exactly one or two arguments.');
                        }
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.ImportExpression,
                            source: this.convertChild(node.arguments[0]),
                            attributes: node.arguments[1]
                                ? this.convertChild(node.arguments[1])
                                : null,
                        });
                    }
                    const callee = this.convertChild(node.expression);
                    const args = node.arguments.map(el => this.convertChild(el));
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.CallExpression,
                        callee,
                        arguments: args,
                        optional: node.questionDotToken !== undefined,
                    });
                    if (node.typeArguments) {
                        result.typeParameters = this.convertTypeArgumentsToTypeParameters(node.typeArguments, node);
                    }
                    return this.convertChainExpression(result, node);
                }
                case SyntaxKind.NewExpression: {
                    // NOTE - NewExpression cannot have an optional chain in it
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.NewExpression,
                        callee: this.convertChild(node.expression),
                        arguments: node.arguments
                            ? node.arguments.map(el => this.convertChild(el))
                            : [],
                    });
                    if (node.typeArguments) {
                        result.typeParameters = this.convertTypeArgumentsToTypeParameters(node.typeArguments, node);
                    }
                    return result;
                }
                case SyntaxKind.ConditionalExpression:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ConditionalExpression,
                        test: this.convertChild(node.condition),
                        consequent: this.convertChild(node.whenTrue),
                        alternate: this.convertChild(node.whenFalse),
                    });
                case SyntaxKind.MetaProperty: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.MetaProperty,
                        meta: this.createNode(
                        // TODO: do we really want to convert it to Token?
                        node.getFirstToken(), {
                            type: ts_estree_1.AST_NODE_TYPES.Identifier,
                            name: (0, node_utils_1.getTextForTokenKind)(node.keywordToken),
                        }),
                        property: this.convertChild(node.name),
                    });
                }
                case SyntaxKind.Decorator: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Decorator,
                        expression: this.convertChild(node.expression),
                    });
                }
                // Literals
                case SyntaxKind.StringLiteral: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Literal,
                        value: parent.kind === SyntaxKind.JsxAttribute
                            ? (0, node_utils_1.unescapeStringLiteralText)(node.text)
                            : node.text,
                        raw: node.getText(),
                    });
                }
                case SyntaxKind.NumericLiteral: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Literal,
                        value: Number(node.text),
                        raw: node.getText(),
                    });
                }
                case SyntaxKind.BigIntLiteral: {
                    const range = (0, node_utils_1.getRange)(node, this.ast);
                    const rawValue = this.ast.text.slice(range[0], range[1]);
                    const bigint = rawValue
                        // remove suffix `n`
                        .slice(0, -1)
                        // `BigInt` doesn't accept numeric separator
                        // and `bigint` property should not include numeric separator
                        .replace(/_/g, '');
                    const value = typeof BigInt !== 'undefined' ? BigInt(bigint) : null;
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Literal,
                        raw: rawValue,
                        value: value,
                        bigint: value == null ? bigint : String(value),
                        range,
                    });
                }
                case SyntaxKind.RegularExpressionLiteral: {
                    const pattern = node.text.slice(1, node.text.lastIndexOf('/'));
                    const flags = node.text.slice(node.text.lastIndexOf('/') + 1);
                    let regex = null;
                    try {
                        regex = new RegExp(pattern, flags);
                    }
                    catch (exception) {
                        regex = null;
                    }
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Literal,
                        value: regex,
                        raw: node.text,
                        regex: {
                            pattern,
                            flags,
                        },
                    });
                }
                case SyntaxKind.TrueKeyword:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Literal,
                        value: true,
                        raw: 'true',
                    });
                case SyntaxKind.FalseKeyword:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Literal,
                        value: false,
                        raw: 'false',
                    });
                case SyntaxKind.NullKeyword: {
                    if (!version_check_1.typescriptVersionIsAtLeast['4.0'] && this.inTypeMode) {
                        // 4.0 started nesting null types inside a LiteralType node, but we still need to support pre-4.0
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.TSNullKeyword,
                        });
                    }
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.Literal,
                        value: null,
                        raw: 'null',
                    });
                }
                case SyntaxKind.EmptyStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.EmptyStatement,
                    });
                case SyntaxKind.DebuggerStatement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.DebuggerStatement,
                    });
                // JSX
                case SyntaxKind.JsxElement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXElement,
                        openingElement: this.convertChild(node.openingElement),
                        closingElement: this.convertChild(node.closingElement),
                        children: node.children.map(el => this.convertChild(el)),
                    });
                case SyntaxKind.JsxFragment:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXFragment,
                        openingFragment: this.convertChild(node.openingFragment),
                        closingFragment: this.convertChild(node.closingFragment),
                        children: node.children.map(el => this.convertChild(el)),
                    });
                case SyntaxKind.JsxSelfClosingElement: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXElement,
                        /**
                         * Convert SyntaxKind.JsxSelfClosingElement to SyntaxKind.JsxOpeningElement,
                         * TypeScript does not seem to have the idea of openingElement when tag is self-closing
                         */
                        openingElement: this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.JSXOpeningElement,
                            typeParameters: node.typeArguments
                                ? this.convertTypeArgumentsToTypeParameters(node.typeArguments, node)
                                : undefined,
                            selfClosing: true,
                            name: this.convertJSXTagName(node.tagName, node),
                            attributes: node.attributes.properties.map(el => this.convertChild(el)),
                            range: (0, node_utils_1.getRange)(node, this.ast),
                        }),
                        closingElement: null,
                        children: [],
                    });
                }
                case SyntaxKind.JsxOpeningElement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXOpeningElement,
                        typeParameters: node.typeArguments
                            ? this.convertTypeArgumentsToTypeParameters(node.typeArguments, node)
                            : undefined,
                        selfClosing: false,
                        name: this.convertJSXTagName(node.tagName, node),
                        attributes: node.attributes.properties.map(el => this.convertChild(el)),
                    });
                case SyntaxKind.JsxClosingElement:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXClosingElement,
                        name: this.convertJSXTagName(node.tagName, node),
                    });
                case SyntaxKind.JsxOpeningFragment:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXOpeningFragment,
                    });
                case SyntaxKind.JsxClosingFragment:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXClosingFragment,
                    });
                case SyntaxKind.JsxExpression: {
                    const expression = node.expression
                        ? this.convertChild(node.expression)
                        : this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.JSXEmptyExpression,
                            range: [node.getStart(this.ast) + 1, node.getEnd() - 1],
                        });
                    if (node.dotDotDotToken) {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.JSXSpreadChild,
                            expression,
                        });
                    }
                    else {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.JSXExpressionContainer,
                            expression,
                        });
                    }
                }
                case SyntaxKind.JsxAttribute: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXAttribute,
                        name: this.convertJSXNamespaceOrIdentifier(node.name),
                        value: this.convertChild(node.initializer),
                    });
                }
                case SyntaxKind.JsxText: {
                    const start = node.getFullStart();
                    const end = node.getEnd();
                    const text = this.ast.text.slice(start, end);
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXText,
                        value: (0, node_utils_1.unescapeStringLiteralText)(text),
                        raw: text,
                        range: [start, end],
                    });
                }
                case SyntaxKind.JsxSpreadAttribute:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.JSXSpreadAttribute,
                        argument: this.convertChild(node.expression),
                    });
                case SyntaxKind.QualifiedName: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSQualifiedName,
                        left: this.convertChild(node.left),
                        right: this.convertChild(node.right),
                    });
                }
                // TypeScript specific
                case SyntaxKind.TypeReference: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTypeReference,
                        typeName: this.convertType(node.typeName),
                        typeParameters: node.typeArguments
                            ? this.convertTypeArgumentsToTypeParameters(node.typeArguments, node)
                            : undefined,
                    });
                }
                case SyntaxKind.TypeParameter: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTypeParameter,
                        name: this.convertType(node.name),
                        constraint: node.constraint
                            ? this.convertType(node.constraint)
                            : undefined,
                        default: node.default ? this.convertType(node.default) : undefined,
                        in: (0, node_utils_1.hasModifier)(SyntaxKind.InKeyword, node),
                        out: (0, node_utils_1.hasModifier)(SyntaxKind.OutKeyword, node),
                        const: (0, node_utils_1.hasModifier)(SyntaxKind.ConstKeyword, node),
                    });
                }
                case SyntaxKind.ThisType:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSThisType,
                    });
                case SyntaxKind.AnyKeyword:
                case SyntaxKind.BigIntKeyword:
                case SyntaxKind.BooleanKeyword:
                case SyntaxKind.NeverKeyword:
                case SyntaxKind.NumberKeyword:
                case SyntaxKind.ObjectKeyword:
                case SyntaxKind.StringKeyword:
                case SyntaxKind.SymbolKeyword:
                case SyntaxKind.UnknownKeyword:
                case SyntaxKind.VoidKeyword:
                case SyntaxKind.UndefinedKeyword:
                case SyntaxKind.IntrinsicKeyword: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES[`TS${SyntaxKind[node.kind]}`],
                    });
                }
                case SyntaxKind.NonNullExpression: {
                    const nnExpr = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSNonNullExpression,
                        expression: this.convertChild(node.expression),
                    });
                    return this.convertChainExpression(nnExpr, node);
                }
                case SyntaxKind.TypeLiteral: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTypeLiteral,
                        members: node.members.map(el => this.convertChild(el)),
                    });
                }
                case SyntaxKind.ArrayType: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSArrayType,
                        elementType: this.convertType(node.elementType),
                    });
                }
                case SyntaxKind.IndexedAccessType: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSIndexedAccessType,
                        objectType: this.convertType(node.objectType),
                        indexType: this.convertType(node.indexType),
                    });
                }
                case SyntaxKind.ConditionalType: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSConditionalType,
                        checkType: this.convertType(node.checkType),
                        extendsType: this.convertType(node.extendsType),
                        trueType: this.convertType(node.trueType),
                        falseType: this.convertType(node.falseType),
                    });
                }
                case SyntaxKind.TypeQuery: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTypeQuery,
                        exprName: this.convertType(node.exprName),
                        typeParameters: node.typeArguments &&
                            this.convertTypeArgumentsToTypeParameters(node.typeArguments, node),
                    });
                }
                case SyntaxKind.MappedType: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSMappedType,
                        typeParameter: this.convertType(node.typeParameter),
                        nameType: (_j = this.convertType(node.nameType)) !== null && _j !== void 0 ? _j : null,
                    });
                    if (node.readonlyToken) {
                        if (node.readonlyToken.kind === SyntaxKind.ReadonlyKeyword) {
                            result.readonly = true;
                        }
                        else {
                            result.readonly = (0, node_utils_1.getTextForTokenKind)(node.readonlyToken.kind);
                        }
                    }
                    if (node.questionToken) {
                        if (node.questionToken.kind === SyntaxKind.QuestionToken) {
                            result.optional = true;
                        }
                        else {
                            result.optional = (0, node_utils_1.getTextForTokenKind)(node.questionToken.kind);
                        }
                    }
                    if (node.type) {
                        result.typeAnnotation = this.convertType(node.type);
                    }
                    return result;
                }
                case SyntaxKind.ParenthesizedExpression:
                    return this.convertChild(node.expression, parent);
                case SyntaxKind.TypeAliasDeclaration: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTypeAliasDeclaration,
                        id: this.convertChild(node.name),
                        typeAnnotation: this.convertType(node.type),
                    });
                    if ((0, node_utils_1.hasModifier)(SyntaxKind.DeclareKeyword, node)) {
                        result.declare = true;
                    }
                    // Process typeParameters
                    if (node.typeParameters) {
                        result.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                    }
                    // check for exports
                    return this.fixExports(node, result);
                }
                case SyntaxKind.MethodSignature: {
                    return this.convertMethodSignature(node);
                }
                case SyntaxKind.PropertySignature: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSPropertySignature,
                        optional: (0, node_utils_1.isOptional)(node) || undefined,
                        computed: (0, node_utils_1.isComputedProperty)(node.name),
                        key: this.convertChild(node.name),
                        typeAnnotation: node.type
                            ? this.convertTypeAnnotation(node.type, node)
                            : undefined,
                        initializer: this.convertChild(
                        // @ts-expect-error TODO breaking change remove this from the AST
                        node.initializer) || undefined,
                        readonly: (0, node_utils_1.hasModifier)(SyntaxKind.ReadonlyKeyword, node) || undefined,
                        static: (0, node_utils_1.hasModifier)(SyntaxKind.StaticKeyword, node) || undefined,
                        export: (0, node_utils_1.hasModifier)(SyntaxKind.ExportKeyword, node) || undefined,
                    });
                    const accessibility = (0, node_utils_1.getTSNodeAccessibility)(node);
                    if (accessibility) {
                        result.accessibility = accessibility;
                    }
                    return result;
                }
                case SyntaxKind.IndexSignature: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSIndexSignature,
                        parameters: node.parameters.map(el => this.convertChild(el)),
                    });
                    if (node.type) {
                        result.typeAnnotation = this.convertTypeAnnotation(node.type, node);
                    }
                    if ((0, node_utils_1.hasModifier)(SyntaxKind.ReadonlyKeyword, node)) {
                        result.readonly = true;
                    }
                    const accessibility = (0, node_utils_1.getTSNodeAccessibility)(node);
                    if (accessibility) {
                        result.accessibility = accessibility;
                    }
                    if ((0, node_utils_1.hasModifier)(SyntaxKind.ExportKeyword, node)) {
                        result.export = true;
                    }
                    if ((0, node_utils_1.hasModifier)(SyntaxKind.StaticKeyword, node)) {
                        result.static = true;
                    }
                    return result;
                }
                case SyntaxKind.ConstructorType: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSConstructorType,
                        params: this.convertParameters(node.parameters),
                        abstract: (0, node_utils_1.hasModifier)(SyntaxKind.AbstractKeyword, node),
                    });
                    if (node.type) {
                        result.returnType = this.convertTypeAnnotation(node.type, node);
                    }
                    if (node.typeParameters) {
                        result.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                    }
                    return result;
                }
                case SyntaxKind.FunctionType:
                case SyntaxKind.ConstructSignature:
                case SyntaxKind.CallSignature: {
                    const type = node.kind === SyntaxKind.ConstructSignature
                        ? ts_estree_1.AST_NODE_TYPES.TSConstructSignatureDeclaration
                        : node.kind === SyntaxKind.CallSignature
                            ? ts_estree_1.AST_NODE_TYPES.TSCallSignatureDeclaration
                            : ts_estree_1.AST_NODE_TYPES.TSFunctionType;
                    const result = this.createNode(node, {
                        type: type,
                        params: this.convertParameters(node.parameters),
                    });
                    if (node.type) {
                        result.returnType = this.convertTypeAnnotation(node.type, node);
                    }
                    if (node.typeParameters) {
                        result.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                    }
                    return result;
                }
                case SyntaxKind.ExpressionWithTypeArguments: {
                    const parentKind = parent.kind;
                    const type = parentKind === SyntaxKind.InterfaceDeclaration
                        ? ts_estree_1.AST_NODE_TYPES.TSInterfaceHeritage
                        : parentKind === SyntaxKind.HeritageClause
                            ? ts_estree_1.AST_NODE_TYPES.TSClassImplements
                            : ts_estree_1.AST_NODE_TYPES.TSInstantiationExpression;
                    const result = this.createNode(node, {
                        type,
                        expression: this.convertChild(node.expression),
                    });
                    if (node.typeArguments) {
                        result.typeParameters = this.convertTypeArgumentsToTypeParameters(node.typeArguments, node);
                    }
                    return result;
                }
                case SyntaxKind.InterfaceDeclaration: {
                    const interfaceHeritageClauses = (_k = node.heritageClauses) !== null && _k !== void 0 ? _k : [];
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSInterfaceDeclaration,
                        body: this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.TSInterfaceBody,
                            body: node.members.map(member => this.convertChild(member)),
                            range: [node.members.pos - 1, node.end],
                        }),
                        id: this.convertChild(node.name),
                    });
                    if (node.typeParameters) {
                        result.typeParameters =
                            this.convertTSTypeParametersToTypeParametersDeclaration(node.typeParameters);
                    }
                    if (interfaceHeritageClauses.length > 0) {
                        const interfaceExtends = [];
                        const interfaceImplements = [];
                        for (const heritageClause of interfaceHeritageClauses) {
                            if (heritageClause.token === SyntaxKind.ExtendsKeyword) {
                                for (const n of heritageClause.types) {
                                    interfaceExtends.push(this.convertChild(n, node));
                                }
                            }
                            else {
                                for (const n of heritageClause.types) {
                                    interfaceImplements.push(this.convertChild(n, node));
                                }
                            }
                        }
                        if (interfaceExtends.length) {
                            result.extends = interfaceExtends;
                        }
                        if (interfaceImplements.length) {
                            result.implements = interfaceImplements;
                        }
                    }
                    if ((0, node_utils_1.hasModifier)(SyntaxKind.AbstractKeyword, node)) {
                        result.abstract = true;
                    }
                    if ((0, node_utils_1.hasModifier)(SyntaxKind.DeclareKeyword, node)) {
                        result.declare = true;
                    }
                    // check for exports
                    return this.fixExports(node, result);
                }
                case SyntaxKind.TypePredicate: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTypePredicate,
                        asserts: node.assertsModifier !== undefined,
                        parameterName: this.convertChild(node.parameterName),
                        typeAnnotation: null,
                    });
                    /**
                     * Specific fix for type-guard location data
                     */
                    if (node.type) {
                        result.typeAnnotation = this.convertTypeAnnotation(node.type, node);
                        result.typeAnnotation.loc = result.typeAnnotation.typeAnnotation.loc;
                        result.typeAnnotation.range =
                            result.typeAnnotation.typeAnnotation.range;
                    }
                    return result;
                }
                case SyntaxKind.ImportType:
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSImportType,
                        isTypeOf: !!node.isTypeOf,
                        parameter: this.convertChild(node.argument),
                        qualifier: this.convertChild(node.qualifier),
                        typeParameters: node.typeArguments
                            ? this.convertTypeArgumentsToTypeParameters(node.typeArguments, node)
                            : null,
                    });
                case SyntaxKind.EnumDeclaration: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSEnumDeclaration,
                        id: this.convertChild(node.name),
                        members: node.members.map(el => this.convertChild(el)),
                    });
                    // apply modifiers first...
                    this.applyModifiersToResult(result, (0, getModifiers_1.getModifiers)(node));
                    // ...then check for exports
                    return this.fixExports(node, result);
                }
                case SyntaxKind.EnumMember: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSEnumMember,
                        id: this.convertChild(node.name),
                    });
                    if (node.initializer) {
                        result.initializer = this.convertChild(node.initializer);
                    }
                    if (node.name.kind === ts.SyntaxKind.ComputedPropertyName) {
                        result.computed = true;
                    }
                    return result;
                }
                case SyntaxKind.ModuleDeclaration: {
                    const result = this.createNode(node, Object.assign({ type: ts_estree_1.AST_NODE_TYPES.TSModuleDeclaration }, (() => {
                        const id = this.convertChild(node.name);
                        const body = this.convertChild(node.body);
                        // the constraints checked by this function are syntactically enforced by TS
                        // the checks mostly exist for type's sake
                        if (node.flags & ts.NodeFlags.GlobalAugmentation) {
                            if (body == null ||
                                body.type === ts_estree_1.AST_NODE_TYPES.TSModuleDeclaration) {
                                throw new Error('Expected a valid module body');
                            }
                            if (id.type !== ts_estree_1.AST_NODE_TYPES.Identifier) {
                                throw new Error('global module augmentation must have an Identifier id');
                            }
                            return {
                                kind: 'global',
                                id,
                                body,
                                global: true,
                            };
                        }
                        else if (node.flags & ts.NodeFlags.Namespace) {
                            if (body == null) {
                                throw new Error('Expected a module body');
                            }
                            if (id.type !== ts_estree_1.AST_NODE_TYPES.Identifier) {
                                throw new Error('`namespace`s must have an Identifier id');
                            }
                            return {
                                kind: 'namespace',
                                id,
                                body,
                            };
                        }
                        else {
                            return Object.assign({ kind: 'module', id }, (body != null ? { body } : {}));
                        }
                    })()));
                    this.applyModifiersToResult(result, (0, getModifiers_1.getModifiers)(node));
                    // ...then check for exports
                    return this.fixExports(node, result);
                }
                // TypeScript specific types
                case SyntaxKind.ParenthesizedType: {
                    return this.convertType(node.type);
                }
                case SyntaxKind.UnionType: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSUnionType,
                        types: node.types.map(el => this.convertType(el)),
                    });
                }
                case SyntaxKind.IntersectionType: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSIntersectionType,
                        types: node.types.map(el => this.convertType(el)),
                    });
                }
                case SyntaxKind.AsExpression: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSAsExpression,
                        expression: this.convertChild(node.expression),
                        typeAnnotation: this.convertType(node.type),
                    });
                }
                case SyntaxKind.InferType: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSInferType,
                        typeParameter: this.convertType(node.typeParameter),
                    });
                }
                case SyntaxKind.LiteralType: {
                    if (version_check_1.typescriptVersionIsAtLeast['4.0'] &&
                        node.literal.kind === SyntaxKind.NullKeyword) {
                        // 4.0 started nesting null types inside a LiteralType node
                        // but our AST is designed around the old way of null being a keyword
                        return this.createNode(node.literal, {
                            type: ts_estree_1.AST_NODE_TYPES.TSNullKeyword,
                        });
                    }
                    else {
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.TSLiteralType,
                            literal: this.convertType(node.literal),
                        });
                    }
                }
                case SyntaxKind.TypeAssertionExpression: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTypeAssertion,
                        typeAnnotation: this.convertType(node.type),
                        expression: this.convertChild(node.expression),
                    });
                }
                case SyntaxKind.ImportEqualsDeclaration: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSImportEqualsDeclaration,
                        id: this.convertChild(node.name),
                        moduleReference: this.convertChild(node.moduleReference),
                        importKind: node.isTypeOnly ? 'type' : 'value',
                        isExport: (0, node_utils_1.hasModifier)(SyntaxKind.ExportKeyword, node),
                    });
                }
                case SyntaxKind.ExternalModuleReference: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSExternalModuleReference,
                        expression: this.convertChild(node.expression),
                    });
                }
                case SyntaxKind.NamespaceExportDeclaration: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSNamespaceExportDeclaration,
                        id: this.convertChild(node.name),
                    });
                }
                case SyntaxKind.AbstractKeyword: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSAbstractKeyword,
                    });
                }
                // Tuple
                case SyntaxKind.TupleType: {
                    // In TS 4.0, the `elementTypes` property was changed to `elements`.
                    // To support both at compile time, we cast to access the newer version
                    // if the former does not exist.
                    const elementTypes = 'elementTypes' in node
                        ? node.elementTypes.map((el) => this.convertType(el))
                        : node.elements.map(el => this.convertType(el));
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTupleType,
                        elementTypes,
                    });
                }
                case SyntaxKind.NamedTupleMember: {
                    const member = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSNamedTupleMember,
                        elementType: this.convertType(node.type, node),
                        label: this.convertChild(node.name, node),
                        optional: node.questionToken != null,
                    });
                    if (node.dotDotDotToken) {
                        // adjust the start to account for the "..."
                        member.range[0] = member.label.range[0];
                        member.loc.start = member.label.loc.start;
                        return this.createNode(node, {
                            type: ts_estree_1.AST_NODE_TYPES.TSRestType,
                            typeAnnotation: member,
                        });
                    }
                    return member;
                }
                case SyntaxKind.OptionalType: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSOptionalType,
                        typeAnnotation: this.convertType(node.type),
                    });
                }
                case SyntaxKind.RestType: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSRestType,
                        typeAnnotation: this.convertType(node.type),
                    });
                }
                // Template Literal Types
                case SyntaxKind.TemplateLiteralType: {
                    const result = this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSTemplateLiteralType,
                        quasis: [this.convertChild(node.head)],
                        types: [],
                    });
                    node.templateSpans.forEach(templateSpan => {
                        result.types.push(this.convertChild(templateSpan.type));
                        result.quasis.push(this.convertChild(templateSpan.literal));
                    });
                    return result;
                }
                case SyntaxKind.ClassStaticBlockDeclaration: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.StaticBlock,
                        body: this.convertBodyExpressions(node.body.statements, node),
                    });
                }
                case SyntaxKind.AssertEntry: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.ImportAttribute,
                        key: this.convertChild(node.name),
                        value: this.convertChild(node.value),
                    });
                }
                case SyntaxKind.SatisfiesExpression: {
                    return this.createNode(node, {
                        type: ts_estree_1.AST_NODE_TYPES.TSSatisfiesExpression,
                        expression: this.convertChild(node.expression),
                        typeAnnotation: this.convertChild(node.type),
                    });
                }
                default:
                    return this.deeplyCopy(node);
            }
        }
    }
    exports.Converter = Converter;
    
},
/* @typescript-eslint/typescript-estree/dist/getModifiers.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getDecorators = exports.getModifiers = void 0;
    const ts = __importStar(require(21) /* typescript */);
    const version_check_1 = require(1071) /* ./version-check */;
    const isAtLeast48 = version_check_1.typescriptVersionIsAtLeast['4.8'];
    function getModifiers(node) {
        var _a;
        if (node == null) {
            return undefined;
        }
        if (isAtLeast48) {
            // eslint-disable-next-line deprecation/deprecation -- this is safe as it's guarded
            if (ts.canHaveModifiers(node)) {
                // eslint-disable-next-line deprecation/deprecation -- this is safe as it's guarded
                const modifiers = ts.getModifiers(node);
                return modifiers ? Array.from(modifiers) : undefined;
            }
            return undefined;
        }
        return (
        // @ts-expect-error intentional fallback for older TS versions
        (_a = node.modifiers) === null || _a === void 0 ? void 0 : _a.filter((m) => !ts.isDecorator(m)));
    }
    exports.getModifiers = getModifiers;
    function getDecorators(node) {
        var _a;
        if (node == null) {
            return undefined;
        }
        if (isAtLeast48) {
            // eslint-disable-next-line deprecation/deprecation -- this is safe as it's guarded
            if (ts.canHaveDecorators(node)) {
                // eslint-disable-next-line deprecation/deprecation -- this is safe as it's guarded
                const decorators = ts.getDecorators(node);
                return decorators ? Array.from(decorators) : undefined;
            }
            return undefined;
        }
        return (
        // @ts-expect-error intentional fallback for older TS versions
        (_a = node.decorators) === null || _a === void 0 ? void 0 : _a.filter(ts.isDecorator));
    }
    exports.getDecorators = getDecorators;
    
},
/* @typescript-eslint/typescript-estree/dist/version-check.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.typescriptVersionIsAtLeast = void 0;
    const semver = __importStar(require(802) /* semver */);
    const ts = __importStar(require(21) /* typescript */);
    function semverCheck(version) {
        return semver.satisfies(ts.version, `>= ${version}.0 || >= ${version}.1-rc || >= ${version}.0-beta`, {
            includePrerelease: true,
        });
    }
    const versions = [
        '3.7',
        '3.8',
        '3.9',
        '4.0',
        '4.1',
        '4.2',
        '4.3',
        '4.4',
        '4.5',
        '4.6',
        '4.7',
        '4.8',
        '4.9',
        '5.0',
    ];
    const typescriptVersionIsAtLeast = {};
    exports.typescriptVersionIsAtLeast = typescriptVersionIsAtLeast;
    for (const version of versions) {
        typescriptVersionIsAtLeast[version] = semverCheck(version);
    }
    
},
/* @typescript-eslint/typescript-estree/dist/node-utils.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isThisInTypeQuery = exports.isThisIdentifier = exports.identifierIsThisKeyword = exports.firstDefined = exports.nodeHasTokens = exports.createError = exports.TSError = exports.convertTokens = exports.convertToken = exports.getTokenType = exports.isChildUnwrappableOptionalChain = exports.isChainExpression = exports.isOptional = exports.isComputedProperty = exports.unescapeStringLiteralText = exports.hasJSXAncestor = exports.findFirstMatchingAncestor = exports.findNextToken = exports.getTSNodeAccessibility = exports.getDeclarationKind = exports.isJSXToken = exports.isToken = exports.getRange = exports.canContainDirective = exports.getLocFor = exports.getLineAndCharacterFor = exports.getBinaryExpressionType = exports.isJSDocComment = exports.isComment = exports.isComma = exports.getLastModifier = exports.hasModifier = exports.isESTreeClassMember = exports.getTextForTokenKind = exports.isLogicalOperator = exports.isAssignmentOperator = void 0;
    const ts = __importStar(require(21) /* typescript */);
    const getModifiers_1 = require(1070) /* ./getModifiers */;
    const xhtml_entities_1 = require(1073) /* ./jsx/xhtml-entities */;
    const ts_estree_1 = require(1074) /* ./ts-estree */;
    const version_check_1 = require(1071) /* ./version-check */;
    const isAtLeast50 = version_check_1.typescriptVersionIsAtLeast['5.0'];
    const SyntaxKind = ts.SyntaxKind;
    const LOGICAL_OPERATORS = [
        SyntaxKind.BarBarToken,
        SyntaxKind.AmpersandAmpersandToken,
        SyntaxKind.QuestionQuestionToken,
    ];
    /**
     * Returns true if the given ts.Token is the assignment operator
     * @param operator the operator token
     * @returns is assignment
     */
    function isAssignmentOperator(operator) {
        return (operator.kind >= SyntaxKind.FirstAssignment &&
            operator.kind <= SyntaxKind.LastAssignment);
    }
    exports.isAssignmentOperator = isAssignmentOperator;
    /**
     * Returns true if the given ts.Token is a logical operator
     * @param operator the operator token
     * @returns is a logical operator
     */
    function isLogicalOperator(operator) {
        return LOGICAL_OPERATORS.includes(operator.kind);
    }
    exports.isLogicalOperator = isLogicalOperator;
    /**
     * Returns the string form of the given TSToken SyntaxKind
     * @param kind the token's SyntaxKind
     * @returns the token applicable token as a string
     */
    function getTextForTokenKind(kind) {
        return ts.tokenToString(kind);
    }
    exports.getTextForTokenKind = getTextForTokenKind;
    /**
     * Returns true if the given ts.Node is a valid ESTree class member
     * @param node TypeScript AST node
     * @returns is valid ESTree class member
     */
    function isESTreeClassMember(node) {
        return node.kind !== SyntaxKind.SemicolonClassElement;
    }
    exports.isESTreeClassMember = isESTreeClassMember;
    /**
     * Checks if a ts.Node has a modifier
     * @param modifierKind TypeScript SyntaxKind modifier
     * @param node TypeScript AST node
     * @returns has the modifier specified
     */
    function hasModifier(modifierKind, node) {
        const modifiers = (0, getModifiers_1.getModifiers)(node);
        return (modifiers === null || modifiers === void 0 ? void 0 : modifiers.some(modifier => modifier.kind === modifierKind)) === true;
    }
    exports.hasModifier = hasModifier;
    /**
     * Get last last modifier in ast
     * @param node TypeScript AST node
     * @returns returns last modifier if present or null
     */
    function getLastModifier(node) {
        var _a;
        const modifiers = (0, getModifiers_1.getModifiers)(node);
        if (modifiers == null) {
            return null;
        }
        return (_a = modifiers[modifiers.length - 1]) !== null && _a !== void 0 ? _a : null;
    }
    exports.getLastModifier = getLastModifier;
    /**
     * Returns true if the given ts.Token is a comma
     * @param token the TypeScript token
     * @returns is comma
     */
    function isComma(token) {
        return token.kind === SyntaxKind.CommaToken;
    }
    exports.isComma = isComma;
    /**
     * Returns true if the given ts.Node is a comment
     * @param node the TypeScript node
     * @returns is comment
     */
    function isComment(node) {
        return (node.kind === SyntaxKind.SingleLineCommentTrivia ||
            node.kind === SyntaxKind.MultiLineCommentTrivia);
    }
    exports.isComment = isComment;
    /**
     * Returns true if the given ts.Node is a JSDoc comment
     * @param node the TypeScript node
     * @returns is JSDoc comment
     */
    function isJSDocComment(node) {
        return node.kind === SyntaxKind.JSDocComment;
    }
    exports.isJSDocComment = isJSDocComment;
    /**
     * Returns the binary expression type of the given ts.Token
     * @param operator the operator token
     * @returns the binary expression type
     */
    function getBinaryExpressionType(operator) {
        if (isAssignmentOperator(operator)) {
            return ts_estree_1.AST_NODE_TYPES.AssignmentExpression;
        }
        else if (isLogicalOperator(operator)) {
            return ts_estree_1.AST_NODE_TYPES.LogicalExpression;
        }
        return ts_estree_1.AST_NODE_TYPES.BinaryExpression;
    }
    exports.getBinaryExpressionType = getBinaryExpressionType;
    /**
     * Returns line and column data for the given positions,
     * @param pos position to check
     * @param ast the AST object
     * @returns line and column
     */
    function getLineAndCharacterFor(pos, ast) {
        const loc = ast.getLineAndCharacterOfPosition(pos);
        return {
            line: loc.line + 1,
            column: loc.character,
        };
    }
    exports.getLineAndCharacterFor = getLineAndCharacterFor;
    /**
     * Returns line and column data for the given start and end positions,
     * for the given AST
     * @param start start data
     * @param end   end data
     * @param ast   the AST object
     * @returns the loc data
     */
    function getLocFor(start, end, ast) {
        return {
            start: getLineAndCharacterFor(start, ast),
            end: getLineAndCharacterFor(end, ast),
        };
    }
    exports.getLocFor = getLocFor;
    /**
     * Check whatever node can contain directive
     * @param node
     * @returns returns true if node can contain directive
     */
    function canContainDirective(node) {
        if (node.kind === ts.SyntaxKind.Block) {
            switch (node.parent.kind) {
                case ts.SyntaxKind.Constructor:
                case ts.SyntaxKind.GetAccessor:
                case ts.SyntaxKind.SetAccessor:
                case ts.SyntaxKind.ArrowFunction:
                case ts.SyntaxKind.FunctionExpression:
                case ts.SyntaxKind.FunctionDeclaration:
                case ts.SyntaxKind.MethodDeclaration:
                    return true;
                default:
                    return false;
            }
        }
        return true;
    }
    exports.canContainDirective = canContainDirective;
    /**
     * Returns range for the given ts.Node
     * @param node the ts.Node or ts.Token
     * @param ast the AST object
     * @returns the range data
     */
    function getRange(node, ast) {
        return [node.getStart(ast), node.getEnd()];
    }
    exports.getRange = getRange;
    /**
     * Returns true if a given ts.Node is a token
     * @param node the ts.Node
     * @returns is a token
     */
    function isToken(node) {
        return (node.kind >= SyntaxKind.FirstToken && node.kind <= SyntaxKind.LastToken);
    }
    exports.isToken = isToken;
    /**
     * Returns true if a given ts.Node is a JSX token
     * @param node ts.Node to be checked
     * @returns is a JSX token
     */
    function isJSXToken(node) {
        return (node.kind >= SyntaxKind.JsxElement && node.kind <= SyntaxKind.JsxAttribute);
    }
    exports.isJSXToken = isJSXToken;
    /**
     * Returns the declaration kind of the given ts.Node
     * @param node TypeScript AST node
     * @returns declaration kind
     */
    function getDeclarationKind(node) {
        if (node.flags & ts.NodeFlags.Let) {
            return 'let';
        }
        if (node.flags & ts.NodeFlags.Const) {
            return 'const';
        }
        return 'var';
    }
    exports.getDeclarationKind = getDeclarationKind;
    /**
     * Gets a ts.Node's accessibility level
     * @param node The ts.Node
     * @returns accessibility "public", "protected", "private", or null
     */
    function getTSNodeAccessibility(node) {
        const modifiers = (0, getModifiers_1.getModifiers)(node);
        if (modifiers == null) {
            return null;
        }
        for (const modifier of modifiers) {
            switch (modifier.kind) {
                case SyntaxKind.PublicKeyword:
                    return 'public';
                case SyntaxKind.ProtectedKeyword:
                    return 'protected';
                case SyntaxKind.PrivateKeyword:
                    return 'private';
                default:
                    break;
            }
        }
        return null;
    }
    exports.getTSNodeAccessibility = getTSNodeAccessibility;
    /**
     * Finds the next token based on the previous one and its parent
     * Had to copy this from TS instead of using TS's version because theirs doesn't pass the ast to getChildren
     * @param previousToken The previous TSToken
     * @param parent The parent TSNode
     * @param ast The TS AST
     * @returns the next TSToken
     */
    function findNextToken(previousToken, parent, ast) {
        return find(parent);
        function find(n) {
            if (ts.isToken(n) && n.pos === previousToken.end) {
                // this is token that starts at the end of previous token - return it
                return n;
            }
            return firstDefined(n.getChildren(ast), (child) => {
                const shouldDiveInChildNode = 
                // previous token is enclosed somewhere in the child
                (child.pos <= previousToken.pos && child.end > previousToken.end) ||
                    // previous token ends exactly at the beginning of child
                    child.pos === previousToken.end;
                return shouldDiveInChildNode && nodeHasTokens(child, ast)
                    ? find(child)
                    : undefined;
            });
        }
    }
    exports.findNextToken = findNextToken;
    /**
     * Find the first matching ancestor based on the given predicate function.
     * @param node The current ts.Node
     * @param predicate The predicate function to apply to each checked ancestor
     * @returns a matching parent ts.Node
     */
    function findFirstMatchingAncestor(node, predicate) {
        while (node) {
            if (predicate(node)) {
                return node;
            }
            node = node.parent;
        }
        return undefined;
    }
    exports.findFirstMatchingAncestor = findFirstMatchingAncestor;
    /**
     * Returns true if a given ts.Node has a JSX token within its hierarchy
     * @param node ts.Node to be checked
     * @returns has JSX ancestor
     */
    function hasJSXAncestor(node) {
        return !!findFirstMatchingAncestor(node, isJSXToken);
    }
    exports.hasJSXAncestor = hasJSXAncestor;
    /**
     * Unescape the text content of string literals, e.g. &amp; -> &
     * @param text The escaped string literal text.
     * @returns The unescaped string literal text.
     */
    function unescapeStringLiteralText(text) {
        return text.replace(/&(?:#\d+|#x[\da-fA-F]+|[0-9a-zA-Z]+);/g, entity => {
            const item = entity.slice(1, -1);
            if (item[0] === '#') {
                const codePoint = item[1] === 'x'
                    ? parseInt(item.slice(2), 16)
                    : parseInt(item.slice(1), 10);
                return codePoint > 0x10ffff // RangeError: Invalid code point
                    ? entity
                    : String.fromCodePoint(codePoint);
            }
            return xhtml_entities_1.xhtmlEntities[item] || entity;
        });
    }
    exports.unescapeStringLiteralText = unescapeStringLiteralText;
    /**
     * Returns true if a given ts.Node is a computed property
     * @param node ts.Node to be checked
     * @returns is Computed Property
     */
    function isComputedProperty(node) {
        return node.kind === SyntaxKind.ComputedPropertyName;
    }
    exports.isComputedProperty = isComputedProperty;
    /**
     * Returns true if a given ts.Node is optional (has QuestionToken)
     * @param node ts.Node to be checked
     * @returns is Optional
     */
    function isOptional(node) {
        return node.questionToken
            ? node.questionToken.kind === SyntaxKind.QuestionToken
            : false;
    }
    exports.isOptional = isOptional;
    /**
     * Returns true if the node is an optional chain node
     */
    function isChainExpression(node) {
        return node.type === ts_estree_1.AST_NODE_TYPES.ChainExpression;
    }
    exports.isChainExpression = isChainExpression;
    /**
     * Returns true of the child of property access expression is an optional chain
     */
    function isChildUnwrappableOptionalChain(node, child) {
        return (isChainExpression(child) &&
            // (x?.y).z is semantically different, and as such .z is no longer optional
            node.expression.kind !== ts.SyntaxKind.ParenthesizedExpression);
    }
    exports.isChildUnwrappableOptionalChain = isChildUnwrappableOptionalChain;
    /**
     * Returns the type of a given ts.Token
     * @param token the ts.Token
     * @returns the token type
     */
    function getTokenType(token) {
        let keywordKind;
        if (isAtLeast50 && token.kind === SyntaxKind.Identifier) {
            keywordKind = ts.identifierToKeywordKind(token);
        }
        else if ('originalKeywordKind' in token) {
            // eslint-disable-next-line deprecation/deprecation -- intentional fallback for older TS versions
            keywordKind = token.originalKeywordKind;
        }
        if (keywordKind) {
            if (keywordKind === SyntaxKind.NullKeyword) {
                return ts_estree_1.AST_TOKEN_TYPES.Null;
            }
            else if (keywordKind >= SyntaxKind.FirstFutureReservedWord &&
                keywordKind <= SyntaxKind.LastKeyword) {
                return ts_estree_1.AST_TOKEN_TYPES.Identifier;
            }
            return ts_estree_1.AST_TOKEN_TYPES.Keyword;
        }
        if (token.kind >= SyntaxKind.FirstKeyword &&
            token.kind <= SyntaxKind.LastFutureReservedWord) {
            if (token.kind === SyntaxKind.FalseKeyword ||
                token.kind === SyntaxKind.TrueKeyword) {
                return ts_estree_1.AST_TOKEN_TYPES.Boolean;
            }
            return ts_estree_1.AST_TOKEN_TYPES.Keyword;
        }
        if (token.kind >= SyntaxKind.FirstPunctuation &&
            token.kind <= SyntaxKind.LastPunctuation) {
            return ts_estree_1.AST_TOKEN_TYPES.Punctuator;
        }
        if (token.kind >= SyntaxKind.NoSubstitutionTemplateLiteral &&
            token.kind <= SyntaxKind.TemplateTail) {
            return ts_estree_1.AST_TOKEN_TYPES.Template;
        }
        switch (token.kind) {
            case SyntaxKind.NumericLiteral:
                return ts_estree_1.AST_TOKEN_TYPES.Numeric;
            case SyntaxKind.JsxText:
                return ts_estree_1.AST_TOKEN_TYPES.JSXText;
            case SyntaxKind.StringLiteral:
                // A TypeScript-StringLiteral token with a TypeScript-JsxAttribute or TypeScript-JsxElement parent,
                // must actually be an ESTree-JSXText token
                if (token.parent &&
                    (token.parent.kind === SyntaxKind.JsxAttribute ||
                        token.parent.kind === SyntaxKind.JsxElement)) {
                    return ts_estree_1.AST_TOKEN_TYPES.JSXText;
                }
                return ts_estree_1.AST_TOKEN_TYPES.String;
            case SyntaxKind.RegularExpressionLiteral:
                return ts_estree_1.AST_TOKEN_TYPES.RegularExpression;
            case SyntaxKind.Identifier:
            case SyntaxKind.ConstructorKeyword:
            case SyntaxKind.GetKeyword:
            case SyntaxKind.SetKeyword:
            // intentional fallthrough
            default:
        }
        // Some JSX tokens have to be determined based on their parent
        if (token.parent && token.kind === SyntaxKind.Identifier) {
            if (isJSXToken(token.parent)) {
                return ts_estree_1.AST_TOKEN_TYPES.JSXIdentifier;
            }
            if (token.parent.kind === SyntaxKind.PropertyAccessExpression &&
                hasJSXAncestor(token)) {
                return ts_estree_1.AST_TOKEN_TYPES.JSXIdentifier;
            }
        }
        return ts_estree_1.AST_TOKEN_TYPES.Identifier;
    }
    exports.getTokenType = getTokenType;
    /**
     * Extends and formats a given ts.Token, for a given AST
     * @param token the ts.Token
     * @param ast   the AST object
     * @returns the converted Token
     */
    function convertToken(token, ast) {
        const start = token.kind === SyntaxKind.JsxText
            ? token.getFullStart()
            : token.getStart(ast);
        const end = token.getEnd();
        const value = ast.text.slice(start, end);
        const tokenType = getTokenType(token);
        if (tokenType === ts_estree_1.AST_TOKEN_TYPES.RegularExpression) {
            return {
                type: tokenType,
                value,
                range: [start, end],
                loc: getLocFor(start, end, ast),
                regex: {
                    pattern: value.slice(1, value.lastIndexOf('/')),
                    flags: value.slice(value.lastIndexOf('/') + 1),
                },
            };
        }
        else {
            // @ts-expect-error TS is complaining about `value` not being the correct
            // type but it is
            return {
                type: tokenType,
                value,
                range: [start, end],
                loc: getLocFor(start, end, ast),
            };
        }
    }
    exports.convertToken = convertToken;
    /**
     * Converts all tokens for the given AST
     * @param ast the AST object
     * @returns the converted Tokens
     */
    function convertTokens(ast) {
        const result = [];
        /**
         * @param node the ts.Node
         */
        function walk(node) {
            // TypeScript generates tokens for types in JSDoc blocks. Comment tokens
            // and their children should not be walked or added to the resulting tokens list.
            if (isComment(node) || isJSDocComment(node)) {
                return;
            }
            if (isToken(node) && node.kind !== SyntaxKind.EndOfFileToken) {
                const converted = convertToken(node, ast);
                if (converted) {
                    result.push(converted);
                }
            }
            else {
                node.getChildren(ast).forEach(walk);
            }
        }
        walk(ast);
        return result;
    }
    exports.convertTokens = convertTokens;
    class TSError extends Error {
        constructor(message, fileName, index, lineNumber, column) {
            super(message);
            this.fileName = fileName;
            this.index = index;
            this.lineNumber = lineNumber;
            this.column = column;
            Object.defineProperty(this, 'name', {
                value: new.target.name,
                enumerable: false,
                configurable: true,
            });
        }
    }
    exports.TSError = TSError;
    /**
     * @param ast     the AST object
     * @param start   the index at which the error starts
     * @param message the error message
     * @returns converted error object
     */
    function createError(ast, start, message) {
        const loc = ast.getLineAndCharacterOfPosition(start);
        return new TSError(message, ast.fileName, start, loc.line + 1, loc.character);
    }
    exports.createError = createError;
    /**
     * @param n the TSNode
     * @param ast the TS AST
     */
    function nodeHasTokens(n, ast) {
        // If we have a token or node that has a non-zero width, it must have tokens.
        // Note: getWidth() does not take trivia into account.
        return n.kind === SyntaxKind.EndOfFileToken
            ? !!n.jsDoc
            : n.getWidth(ast) !== 0;
    }
    exports.nodeHasTokens = nodeHasTokens;
    /**
     * Like `forEach`, but suitable for use with numbers and strings (which may be falsy).
     * @template T
     * @template U
     * @param array
     * @param callback
     */
    function firstDefined(array, callback) {
        if (array === undefined) {
            return undefined;
        }
        for (let i = 0; i < array.length; i++) {
            const result = callback(array[i], i);
            if (result !== undefined) {
                return result;
            }
        }
        return undefined;
    }
    exports.firstDefined = firstDefined;
    function identifierIsThisKeyword(id) {
        return (
        // eslint-disable-next-line deprecation/deprecation -- intentional for older TS versions
        (isAtLeast50 ? ts.identifierToKeywordKind(id) : id.originalKeywordKind) ===
            SyntaxKind.ThisKeyword);
    }
    exports.identifierIsThisKeyword = identifierIsThisKeyword;
    function isThisIdentifier(node) {
        return (!!node &&
            node.kind === SyntaxKind.Identifier &&
            identifierIsThisKeyword(node));
    }
    exports.isThisIdentifier = isThisIdentifier;
    function isThisInTypeQuery(node) {
        if (!isThisIdentifier(node)) {
            return false;
        }
        while (ts.isQualifiedName(node.parent) && node.parent.left === node) {
            node = node.parent;
        }
        return node.parent.kind === SyntaxKind.TypeQuery;
    }
    exports.isThisInTypeQuery = isThisInTypeQuery;
    
},
/* @typescript-eslint/typescript-estree/dist/jsx/xhtml-entities.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.xhtmlEntities = void 0;
    exports.xhtmlEntities = {
        quot: '\u0022',
        amp: '&',
        apos: '\u0027',
        lt: '<',
        gt: '>',
        nbsp: '\u00A0',
        iexcl: '\u00A1',
        cent: '\u00A2',
        pound: '\u00A3',
        curren: '\u00A4',
        yen: '\u00A5',
        brvbar: '\u00A6',
        sect: '\u00A7',
        uml: '\u00A8',
        copy: '\u00A9',
        ordf: '\u00AA',
        laquo: '\u00AB',
        not: '\u00AC',
        shy: '\u00AD',
        reg: '\u00AE',
        macr: '\u00AF',
        deg: '\u00B0',
        plusmn: '\u00B1',
        sup2: '\u00B2',
        sup3: '\u00B3',
        acute: '\u00B4',
        micro: '\u00B5',
        para: '\u00B6',
        middot: '\u00B7',
        cedil: '\u00B8',
        sup1: '\u00B9',
        ordm: '\u00BA',
        raquo: '\u00BB',
        frac14: '\u00BC',
        frac12: '\u00BD',
        frac34: '\u00BE',
        iquest: '\u00BF',
        Agrave: '\u00C0',
        Aacute: '\u00C1',
        Acirc: '\u00C2',
        Atilde: '\u00C3',
        Auml: '\u00C4',
        Aring: '\u00C5',
        AElig: '\u00C6',
        Ccedil: '\u00C7',
        Egrave: '\u00C8',
        Eacute: '\u00C9',
        Ecirc: '\u00CA',
        Euml: '\u00CB',
        Igrave: '\u00CC',
        Iacute: '\u00CD',
        Icirc: '\u00CE',
        Iuml: '\u00CF',
        ETH: '\u00D0',
        Ntilde: '\u00D1',
        Ograve: '\u00D2',
        Oacute: '\u00D3',
        Ocirc: '\u00D4',
        Otilde: '\u00D5',
        Ouml: '\u00D6',
        times: '\u00D7',
        Oslash: '\u00D8',
        Ugrave: '\u00D9',
        Uacute: '\u00DA',
        Ucirc: '\u00DB',
        Uuml: '\u00DC',
        Yacute: '\u00DD',
        THORN: '\u00DE',
        szlig: '\u00DF',
        agrave: '\u00E0',
        aacute: '\u00E1',
        acirc: '\u00E2',
        atilde: '\u00E3',
        auml: '\u00E4',
        aring: '\u00E5',
        aelig: '\u00E6',
        ccedil: '\u00E7',
        egrave: '\u00E8',
        eacute: '\u00E9',
        ecirc: '\u00EA',
        euml: '\u00EB',
        igrave: '\u00EC',
        iacute: '\u00ED',
        icirc: '\u00EE',
        iuml: '\u00EF',
        eth: '\u00F0',
        ntilde: '\u00F1',
        ograve: '\u00F2',
        oacute: '\u00F3',
        ocirc: '\u00F4',
        otilde: '\u00F5',
        ouml: '\u00F6',
        divide: '\u00F7',
        oslash: '\u00F8',
        ugrave: '\u00F9',
        uacute: '\u00FA',
        ucirc: '\u00FB',
        uuml: '\u00FC',
        yacute: '\u00FD',
        thorn: '\u00FE',
        yuml: '\u00FF',
        OElig: '\u0152',
        oelig: '\u0153',
        Scaron: '\u0160',
        scaron: '\u0161',
        Yuml: '\u0178',
        fnof: '\u0192',
        circ: '\u02C6',
        tilde: '\u02DC',
        Alpha: '\u0391',
        Beta: '\u0392',
        Gamma: '\u0393',
        Delta: '\u0394',
        Epsilon: '\u0395',
        Zeta: '\u0396',
        Eta: '\u0397',
        Theta: '\u0398',
        Iota: '\u0399',
        Kappa: '\u039A',
        Lambda: '\u039B',
        Mu: '\u039C',
        Nu: '\u039D',
        Xi: '\u039E',
        Omicron: '\u039F',
        Pi: '\u03A0',
        Rho: '\u03A1',
        Sigma: '\u03A3',
        Tau: '\u03A4',
        Upsilon: '\u03A5',
        Phi: '\u03A6',
        Chi: '\u03A7',
        Psi: '\u03A8',
        Omega: '\u03A9',
        alpha: '\u03B1',
        beta: '\u03B2',
        gamma: '\u03B3',
        delta: '\u03B4',
        epsilon: '\u03B5',
        zeta: '\u03B6',
        eta: '\u03B7',
        theta: '\u03B8',
        iota: '\u03B9',
        kappa: '\u03BA',
        lambda: '\u03BB',
        mu: '\u03BC',
        nu: '\u03BD',
        xi: '\u03BE',
        omicron: '\u03BF',
        pi: '\u03C0',
        rho: '\u03C1',
        sigmaf: '\u03C2',
        sigma: '\u03C3',
        tau: '\u03C4',
        upsilon: '\u03C5',
        phi: '\u03C6',
        chi: '\u03C7',
        psi: '\u03C8',
        omega: '\u03C9',
        thetasym: '\u03D1',
        upsih: '\u03D2',
        piv: '\u03D6',
        ensp: '\u2002',
        emsp: '\u2003',
        thinsp: '\u2009',
        zwnj: '\u200C',
        zwj: '\u200D',
        lrm: '\u200E',
        rlm: '\u200F',
        ndash: '\u2013',
        mdash: '\u2014',
        lsquo: '\u2018',
        rsquo: '\u2019',
        sbquo: '\u201A',
        ldquo: '\u201C',
        rdquo: '\u201D',
        bdquo: '\u201E',
        dagger: '\u2020',
        Dagger: '\u2021',
        bull: '\u2022',
        hellip: '\u2026',
        permil: '\u2030',
        prime: '\u2032',
        Prime: '\u2033',
        lsaquo: '\u2039',
        rsaquo: '\u203A',
        oline: '\u203E',
        frasl: '\u2044',
        euro: '\u20AC',
        image: '\u2111',
        weierp: '\u2118',
        real: '\u211C',
        trade: '\u2122',
        alefsym: '\u2135',
        larr: '\u2190',
        uarr: '\u2191',
        rarr: '\u2192',
        darr: '\u2193',
        harr: '\u2194',
        crarr: '\u21B5',
        lArr: '\u21D0',
        uArr: '\u21D1',
        rArr: '\u21D2',
        dArr: '\u21D3',
        hArr: '\u21D4',
        forall: '\u2200',
        part: '\u2202',
        exist: '\u2203',
        empty: '\u2205',
        nabla: '\u2207',
        isin: '\u2208',
        notin: '\u2209',
        ni: '\u220B',
        prod: '\u220F',
        sum: '\u2211',
        minus: '\u2212',
        lowast: '\u2217',
        radic: '\u221A',
        prop: '\u221D',
        infin: '\u221E',
        ang: '\u2220',
        and: '\u2227',
        or: '\u2228',
        cap: '\u2229',
        cup: '\u222A',
        int: '\u222B',
        there4: '\u2234',
        sim: '\u223C',
        cong: '\u2245',
        asymp: '\u2248',
        ne: '\u2260',
        equiv: '\u2261',
        le: '\u2264',
        ge: '\u2265',
        sub: '\u2282',
        sup: '\u2283',
        nsub: '\u2284',
        sube: '\u2286',
        supe: '\u2287',
        oplus: '\u2295',
        otimes: '\u2297',
        perp: '\u22A5',
        sdot: '\u22C5',
        lceil: '\u2308',
        rceil: '\u2309',
        lfloor: '\u230A',
        rfloor: '\u230B',
        lang: '\u2329',
        rang: '\u232A',
        loz: '\u25CA',
        spades: '\u2660',
        clubs: '\u2663',
        hearts: '\u2665',
        diams: '\u2666',
    };
    
},
/* @typescript-eslint/typescript-estree/dist/ts-estree/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __exportStar = (this && this.__exportStar) || function (m, exports) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p))
                __createBinding(exports, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TSESTree = exports.AST_TOKEN_TYPES = exports.AST_NODE_TYPES = void 0;
    // for simplicity and backwards-compatibility
    var types_1 = require(789) /* @typescript-eslint/types */;
    Object.defineProperty(exports, "AST_NODE_TYPES", { enumerable: true, get: function () { return types_1.AST_NODE_TYPES; } });
    Object.defineProperty(exports, "AST_TOKEN_TYPES", { enumerable: true, get: function () { return types_1.AST_TOKEN_TYPES; } });
    Object.defineProperty(exports, "TSESTree", { enumerable: true, get: function () { return types_1.TSESTree; } });
    __exportStar(require(1075) /* ./ts-nodes */, exports);
    __exportStar(require(1076) /* ./estree-to-ts-node-types */, exports);
    
},
/* @typescript-eslint/typescript-estree/dist/ts-estree/ts-nodes.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/typescript-estree/dist/ts-estree/estree-to-ts-node-types.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    
},
/* @typescript-eslint/typescript-estree/dist/convert-comments.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.convertComments = void 0;
    const util_1 = require(1047) /* tsutils/util/util */;
    const ts = __importStar(require(21) /* typescript */);
    const node_utils_1 = require(1072) /* ./node-utils */;
    const ts_estree_1 = require(1074) /* ./ts-estree */;
    /**
     * Convert all comments for the given AST.
     * @param ast the AST object
     * @param code the TypeScript code
     * @returns the converted ESTreeComment
     * @private
     */
    function convertComments(ast, code) {
        const comments = [];
        (0, util_1.forEachComment)(ast, (_, comment) => {
            const type = comment.kind === ts.SyntaxKind.SingleLineCommentTrivia
                ? ts_estree_1.AST_TOKEN_TYPES.Line
                : ts_estree_1.AST_TOKEN_TYPES.Block;
            const range = [comment.pos, comment.end];
            const loc = (0, node_utils_1.getLocFor)(range[0], range[1], ast);
            // both comments start with 2 characters - /* or //
            const textStart = range[0] + 2;
            const textEnd = comment.kind === ts.SyntaxKind.SingleLineCommentTrivia
                ? // single line comments end at the end
                    range[1] - textStart
                : // multiline comments end 2 characters early
                    range[1] - textStart - 2;
            comments.push({
                type,
                value: code.slice(textStart, textStart + textEnd),
                range,
                loc,
            });
        }, ast);
        return comments;
    }
    exports.convertComments = convertComments;
    
},
/* @typescript-eslint/typescript-estree/dist/simple-traverse.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.simpleTraverse = void 0;
    const visitor_keys_1 = require(863) /* @typescript-eslint/visitor-keys */;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    function isValidNode(x) {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
        return x != null && typeof x === 'object' && typeof x.type === 'string';
    }
    function getVisitorKeysForNode(allVisitorKeys, node) {
        const keys = allVisitorKeys[node.type];
        return (keys !== null && keys !== void 0 ? keys : []);
    }
    class SimpleTraverser {
        constructor(selectors, setParentPointers = false) {
            this.allVisitorKeys = visitor_keys_1.visitorKeys;
            this.selectors = selectors;
            this.setParentPointers = setParentPointers;
        }
        traverse(node, parent) {
            if (!isValidNode(node)) {
                return;
            }
            if (this.setParentPointers) {
                node.parent = parent;
            }
            if ('enter' in this.selectors) {
                this.selectors.enter(node, parent);
            }
            else if (node.type in this.selectors) {
                this.selectors[node.type](node, parent);
            }
            const keys = getVisitorKeysForNode(this.allVisitorKeys, node);
            if (keys.length < 1) {
                return;
            }
            for (const key of keys) {
                const childOrChildren = node[key];
                if (Array.isArray(childOrChildren)) {
                    for (const child of childOrChildren) {
                        this.traverse(child, node);
                    }
                }
                else {
                    this.traverse(childOrChildren, node);
                }
            }
        }
    }
    function simpleTraverse(startingNode, options, setParentPointers = false) {
        new SimpleTraverser(options, setParentPointers).traverse(startingNode, undefined);
    }
    exports.simpleTraverse = simpleTraverse;
    
},
/* @typescript-eslint/typescript-estree/dist/create-program/createDefaultProgram.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createDefaultProgram = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const path_1 = __importDefault(require("path"));
    const ts = __importStar(require(21) /* typescript */);
    const shared_1 = require(1080) /* ./shared */;
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:createDefaultProgram');
    /**
     * @param parseSettings Internal settings for parsing the file
     * @returns If found, returns the source file corresponding to the code and the containing program
     */
    function createDefaultProgram(parseSettings) {
        var _a;
        log('Getting default program for: %s', parseSettings.filePath || 'unnamed file');
        if (((_a = parseSettings.projects) === null || _a === void 0 ? void 0 : _a.length) !== 1) {
            return undefined;
        }
        const tsconfigPath = parseSettings.projects[0];
        const commandLine = ts.getParsedCommandLineOfConfigFile(tsconfigPath, (0, shared_1.createDefaultCompilerOptionsFromExtra)(parseSettings), Object.assign(Object.assign({}, ts.sys), { onUnRecoverableConfigFileDiagnostic: () => { } }));
        if (!commandLine) {
            return undefined;
        }
        const compilerHost = ts.createCompilerHost(commandLine.options, 
        /* setParentNodes */ true);
        if (parseSettings.moduleResolver) {
            // eslint-disable-next-line deprecation/deprecation -- intentional for older TS versions
            compilerHost.resolveModuleNames = (0, shared_1.getModuleResolver)(parseSettings.moduleResolver).resolveModuleNames;
        }
        const oldReadFile = compilerHost.readFile;
        compilerHost.readFile = (fileName) => path_1.default.normalize(fileName) === path_1.default.normalize(parseSettings.filePath)
            ? parseSettings.code
            : oldReadFile(fileName);
        const program = ts.createProgram([parseSettings.filePath], commandLine.options, compilerHost);
        const ast = program.getSourceFile(parseSettings.filePath);
        return ast && { ast, program };
    }
    exports.createDefaultProgram = createDefaultProgram;
    
},
/* @typescript-eslint/typescript-estree/dist/create-program/shared.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getModuleResolver = exports.getAstFromProgram = exports.getCanonicalFileName = exports.ensureAbsolutePath = exports.createHash = exports.createDefaultCompilerOptionsFromExtra = exports.canonicalDirname = exports.CORE_COMPILER_OPTIONS = void 0;
    const path_1 = __importDefault(require("path"));
    const ts = __importStar(require(21) /* typescript */);
    /**
     * Compiler options required to avoid critical functionality issues
     */
    const CORE_COMPILER_OPTIONS = {
        noEmit: true,
        /**
         * Flags required to make no-unused-vars work
         */
        noUnusedLocals: true,
        noUnusedParameters: true,
    };
    exports.CORE_COMPILER_OPTIONS = CORE_COMPILER_OPTIONS;
    /**
     * Default compiler options for program generation
     */
    const DEFAULT_COMPILER_OPTIONS = Object.assign(Object.assign({}, CORE_COMPILER_OPTIONS), { allowNonTsExtensions: true, allowJs: true, checkJs: true });
    function createDefaultCompilerOptionsFromExtra(parseSettings) {
        if (parseSettings.debugLevel.has('typescript')) {
            return Object.assign(Object.assign({}, DEFAULT_COMPILER_OPTIONS), { extendedDiagnostics: true });
        }
        return DEFAULT_COMPILER_OPTIONS;
    }
    exports.createDefaultCompilerOptionsFromExtra = createDefaultCompilerOptionsFromExtra;
    // typescript doesn't provide a ts.sys implementation for browser environments
    const useCaseSensitiveFileNames = ts.sys !== undefined ? ts.sys.useCaseSensitiveFileNames : true;
    const correctPathCasing = useCaseSensitiveFileNames
        ? (filePath) => filePath
        : (filePath) => filePath.toLowerCase();
    function getCanonicalFileName(filePath) {
        let normalized = path_1.default.normalize(filePath);
        if (normalized.endsWith(path_1.default.sep)) {
            normalized = normalized.slice(0, -1);
        }
        return correctPathCasing(normalized);
    }
    exports.getCanonicalFileName = getCanonicalFileName;
    function ensureAbsolutePath(p, tsconfigRootDir) {
        return path_1.default.isAbsolute(p)
            ? p
            : path_1.default.join(tsconfigRootDir || process.cwd(), p);
    }
    exports.ensureAbsolutePath = ensureAbsolutePath;
    function canonicalDirname(p) {
        return path_1.default.dirname(p);
    }
    exports.canonicalDirname = canonicalDirname;
    const DEFINITION_EXTENSIONS = [
        ts.Extension.Dts,
        ts.Extension.Dcts,
        ts.Extension.Dmts,
    ];
    function getExtension(fileName) {
        var _a;
        if (!fileName) {
            return null;
        }
        return ((_a = DEFINITION_EXTENSIONS.find(definitionExt => fileName.endsWith(definitionExt))) !== null && _a !== void 0 ? _a : path_1.default.extname(fileName));
    }
    function getAstFromProgram(currentProgram, parseSettings) {
        const ast = currentProgram.getSourceFile(parseSettings.filePath);
        // working around https://github.com/typescript-eslint/typescript-eslint/issues/1573
        const expectedExt = getExtension(parseSettings.filePath);
        const returnedExt = getExtension(ast === null || ast === void 0 ? void 0 : ast.fileName);
        if (expectedExt !== returnedExt) {
            return undefined;
        }
        return ast && { ast, program: currentProgram };
    }
    exports.getAstFromProgram = getAstFromProgram;
    function getModuleResolver(moduleResolverPath) {
        let moduleResolver;
        try {
            moduleResolver = require(moduleResolverPath);
        }
        catch (error) {
            const errorLines = [
                'Could not find the provided parserOptions.moduleResolver.',
                'Hint: use an absolute path if you are not in control over where the ESLint instance runs.',
            ];
            throw new Error(errorLines.join('\n'));
        }
        return moduleResolver;
    }
    exports.getModuleResolver = getModuleResolver;
    /**
     * Hash content for compare content.
     * @param content hashed contend
     * @returns hashed result
     */
    function createHash(content) {
        var _a;
        // No ts.sys in browser environments.
        if ((_a = ts.sys) === null || _a === void 0 ? void 0 : _a.createHash) {
            return ts.sys.createHash(content);
        }
        return content;
    }
    exports.createHash = createHash;
    
},
/* @typescript-eslint/typescript-estree/dist/create-program/createIsolatedProgram.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createIsolatedProgram = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const ts = __importStar(require(21) /* typescript */);
    const getScriptKind_1 = require(1082) /* ./getScriptKind */;
    const shared_1 = require(1080) /* ./shared */;
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:createIsolatedProgram');
    /**
     * @param code The code of the file being linted
     * @returns Returns a new source file and program corresponding to the linted code
     */
    function createIsolatedProgram(parseSettings) {
        log('Getting isolated program in %s mode for: %s', parseSettings.jsx ? 'TSX' : 'TS', parseSettings.filePath);
        const compilerHost = {
            fileExists() {
                return true;
            },
            getCanonicalFileName() {
                return parseSettings.filePath;
            },
            getCurrentDirectory() {
                return '';
            },
            getDirectories() {
                return [];
            },
            getDefaultLibFileName() {
                return 'lib.d.ts';
            },
            // TODO: Support Windows CRLF
            getNewLine() {
                return '\n';
            },
            getSourceFile(filename) {
                return ts.createSourceFile(filename, parseSettings.code, ts.ScriptTarget.Latest, 
                /* setParentNodes */ true, (0, getScriptKind_1.getScriptKind)(parseSettings.filePath, parseSettings.jsx));
            },
            readFile() {
                return undefined;
            },
            useCaseSensitiveFileNames() {
                return true;
            },
            writeFile() {
                return null;
            },
        };
        const program = ts.createProgram([parseSettings.filePath], Object.assign({ noResolve: true, target: ts.ScriptTarget.Latest, jsx: parseSettings.jsx ? ts.JsxEmit.Preserve : undefined }, (0, shared_1.createDefaultCompilerOptionsFromExtra)(parseSettings)), compilerHost);
        const ast = program.getSourceFile(parseSettings.filePath);
        if (!ast) {
            throw new Error('Expected an ast to be returned for the single-file isolated program.');
        }
        return { ast, program };
    }
    exports.createIsolatedProgram = createIsolatedProgram;
    
},
/* @typescript-eslint/typescript-estree/dist/create-program/getScriptKind.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getLanguageVariant = exports.getScriptKind = void 0;
    const path_1 = __importDefault(require("path"));
    const ts = __importStar(require(21) /* typescript */);
    function getScriptKind(filePath, jsx) {
        const extension = path_1.default.extname(filePath).toLowerCase();
        // note - we only respect the user's jsx setting for unknown extensions
        // this is so that we always match TS's internal script kind logic, preventing
        // weird errors due to a mismatch.
        // https://github.com/microsoft/TypeScript/blob/da00ba67ed1182ad334f7c713b8254fba174aeba/src/compiler/utilities.ts#L6948-L6968
        switch (extension) {
            case ts.Extension.Js:
            case ts.Extension.Cjs:
            case ts.Extension.Mjs:
                return ts.ScriptKind.JS;
            case ts.Extension.Jsx:
                return ts.ScriptKind.JSX;
            case ts.Extension.Ts:
            case ts.Extension.Cts:
            case ts.Extension.Mts:
                return ts.ScriptKind.TS;
            case ts.Extension.Tsx:
                return ts.ScriptKind.TSX;
            case ts.Extension.Json:
                return ts.ScriptKind.JSON;
            default:
                // unknown extension, force typescript to ignore the file extension, and respect the user's setting
                return jsx ? ts.ScriptKind.TSX : ts.ScriptKind.TS;
        }
    }
    exports.getScriptKind = getScriptKind;
    function getLanguageVariant(scriptKind) {
        // https://github.com/microsoft/TypeScript/blob/d6e483b8dabd8fd37c00954c3f2184bb7f1eb90c/src/compiler/utilities.ts#L6281-L6285
        switch (scriptKind) {
            case ts.ScriptKind.TSX:
            case ts.ScriptKind.JSX:
            case ts.ScriptKind.JS:
            case ts.ScriptKind.JSON:
                return ts.LanguageVariant.JSX;
            default:
                return ts.LanguageVariant.Standard;
        }
    }
    exports.getLanguageVariant = getLanguageVariant;
    
},
/* @typescript-eslint/typescript-estree/dist/create-program/createProjectProgram.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createProjectProgram = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const path_1 = __importDefault(require("path"));
    const ts = __importStar(require(21) /* typescript */);
    const node_utils_1 = require(1072) /* ../node-utils */;
    const describeFilePath_1 = require(1084) /* ./describeFilePath */;
    const getWatchProgramsForProjects_1 = require(1085) /* ./getWatchProgramsForProjects */;
    const shared_1 = require(1080) /* ./shared */;
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:createProjectProgram');
    const DEFAULT_EXTRA_FILE_EXTENSIONS = [
        ts.Extension.Ts,
        ts.Extension.Tsx,
        ts.Extension.Js,
        ts.Extension.Jsx,
        ts.Extension.Mjs,
        ts.Extension.Mts,
        ts.Extension.Cjs,
        ts.Extension.Cts,
    ];
    /**
     * @param parseSettings Internal settings for parsing the file
     * @returns If found, the source file corresponding to the code and the containing program
     */
    function createProjectProgram(parseSettings) {
        log('Creating project program for: %s', parseSettings.filePath);
        const programsForProjects = (0, getWatchProgramsForProjects_1.getWatchProgramsForProjects)(parseSettings);
        const astAndProgram = (0, node_utils_1.firstDefined)(programsForProjects, currentProgram => (0, shared_1.getAstFromProgram)(currentProgram, parseSettings));
        // The file was either matched within the tsconfig, or we allow creating a default program
        if (astAndProgram || parseSettings.createDefaultProgram) {
            return astAndProgram;
        }
        const describeProjectFilePath = (projectFile) => (0, describeFilePath_1.describeFilePath)(projectFile, parseSettings.tsconfigRootDir);
        const describedFilePath = (0, describeFilePath_1.describeFilePath)(parseSettings.filePath, parseSettings.tsconfigRootDir);
        const relativeProjects = parseSettings.projects.map(describeProjectFilePath);
        const describedPrograms = relativeProjects.length === 1
            ? relativeProjects[0]
            : `\n${relativeProjects.map(project => `- ${project}`).join('\n')}`;
        const errorLines = [
            `ESLint was configured to run on \`${describedFilePath}\` using \`parserOptions.project\`: ${describedPrograms}`,
        ];
        let hasMatchedAnError = false;
        const extraFileExtensions = parseSettings.extraFileExtensions || [];
        extraFileExtensions.forEach(extraExtension => {
            if (!extraExtension.startsWith('.')) {
                errorLines.push(`Found unexpected extension \`${extraExtension}\` specified with the \`parserOptions.extraFileExtensions\` option. Did you mean \`.${extraExtension}\`?`);
            }
            if (DEFAULT_EXTRA_FILE_EXTENSIONS.includes(extraExtension)) {
                errorLines.push(`You unnecessarily included the extension \`${extraExtension}\` with the \`parserOptions.extraFileExtensions\` option. This extension is already handled by the parser by default.`);
            }
        });
        const fileExtension = path_1.default.extname(parseSettings.filePath);
        if (!DEFAULT_EXTRA_FILE_EXTENSIONS.includes(fileExtension)) {
            const nonStandardExt = `The extension for the file (\`${fileExtension}\`) is non-standard`;
            if (extraFileExtensions.length > 0) {
                if (!extraFileExtensions.includes(fileExtension)) {
                    errorLines.push(`${nonStandardExt}. It should be added to your existing \`parserOptions.extraFileExtensions\`.`);
                    hasMatchedAnError = true;
                }
            }
            else {
                errorLines.push(`${nonStandardExt}. You should add \`parserOptions.extraFileExtensions\` to your config.`);
                hasMatchedAnError = true;
            }
        }
        if (!hasMatchedAnError) {
            const [describedInclusions, describedSpecifiers] = parseSettings.projects.length === 1
                ? ['that TSConfig does not', 'that TSConfig']
                : ['none of those TSConfigs', 'one of those TSConfigs'];
            errorLines.push(`However, ${describedInclusions} include this file. Either:`, `- Change ESLint's list of included files to not include this file`, `- Change ${describedSpecifiers} to include this file`, `- Create a new TSConfig that includes this file and include it in your parserOptions.project`, `See the typescript-eslint docs for more info: https://typescript-eslint.io/linting/troubleshooting#i-get-errors-telling-me-eslint-was-configured-to-run--however-that-tsconfig-does-not--none-of-those-tsconfigs-include-this-file`);
        }
        throw new Error(errorLines.join('\n'));
    }
    exports.createProjectProgram = createProjectProgram;
    
},
/* @typescript-eslint/typescript-estree/dist/create-program/describeFilePath.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.describeFilePath = void 0;
    const path_1 = __importDefault(require("path"));
    function describeFilePath(filePath, tsconfigRootDir) {
        // If the TSConfig root dir is a parent of the filePath, use
        // `<tsconfigRootDir>` as a prefix for the path.
        const relative = path_1.default.relative(tsconfigRootDir, filePath);
        if (relative && !relative.startsWith('..') && !path_1.default.isAbsolute(relative)) {
            return `<tsconfigRootDir>/${relative}`;
        }
        // Root-like Mac/Linux (~/*, ~*) or Windows (C:/*, /) paths that aren't
        // relative to the TSConfig root dir should be fully described.
        // This avoids strings like <tsconfigRootDir>/../../../../repo/file.ts.
        // https://github.com/typescript-eslint/typescript-eslint/issues/6289
        if (/^[(\w+:)\\/~]/.test(filePath)) {
            return filePath;
        }
        // Similarly, if the relative path would contain a lot of ../.., then
        // ignore it and print the file path directly.
        if (/\.\.[/\\]\.\./.test(relative)) {
            return filePath;
        }
        // Lastly, since we've eliminated all special cases, we know the cleanest
        // path to print is probably the prefixed relative one.
        return `<tsconfigRootDir>/${relative}`;
    }
    exports.describeFilePath = describeFilePath;
    
},
/* @typescript-eslint/typescript-estree/dist/create-program/getWatchProgramsForProjects.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getWatchProgramsForProjects = exports.clearWatchCaches = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const fs_1 = __importDefault(require("fs"));
    const semver_1 = __importDefault(require(802) /* semver */);
    const ts = __importStar(require(21) /* typescript */);
    const shared_1 = require(1080) /* ./shared */;
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:createWatchProgram');
    /**
     * Maps tsconfig paths to their corresponding file contents and resulting watches
     */
    const knownWatchProgramMap = new Map();
    /**
     * Maps file/folder paths to their set of corresponding watch callbacks
     * There may be more than one per file/folder if a file/folder is shared between projects
     */
    const fileWatchCallbackTrackingMap = new Map();
    const folderWatchCallbackTrackingMap = new Map();
    /**
     * Stores the list of known files for each program
     */
    const programFileListCache = new Map();
    /**
     * Caches the last modified time of the tsconfig files
     */
    const tsconfigLastModifiedTimestampCache = new Map();
    const parsedFilesSeenHash = new Map();
    /**
     * Clear all of the parser caches.
     * This should only be used in testing to ensure the parser is clean between tests.
     */
    function clearWatchCaches() {
        knownWatchProgramMap.clear();
        fileWatchCallbackTrackingMap.clear();
        folderWatchCallbackTrackingMap.clear();
        parsedFilesSeenHash.clear();
        programFileListCache.clear();
        tsconfigLastModifiedTimestampCache.clear();
    }
    exports.clearWatchCaches = clearWatchCaches;
    function saveWatchCallback(trackingMap) {
        return (fileName, callback) => {
            const normalizedFileName = (0, shared_1.getCanonicalFileName)(fileName);
            const watchers = (() => {
                let watchers = trackingMap.get(normalizedFileName);
                if (!watchers) {
                    watchers = new Set();
                    trackingMap.set(normalizedFileName, watchers);
                }
                return watchers;
            })();
            watchers.add(callback);
            return {
                close: () => {
                    watchers.delete(callback);
                },
            };
        };
    }
    /**
     * Holds information about the file currently being linted
     */
    const currentLintOperationState = {
        code: '',
        filePath: '',
    };
    /**
     * Appropriately report issues found when reading a config file
     * @param diagnostic The diagnostic raised when creating a program
     */
    function diagnosticReporter(diagnostic) {
        throw new Error(ts.flattenDiagnosticMessageText(diagnostic.messageText, ts.sys.newLine));
    }
    function updateCachedFileList(tsconfigPath, program, parseSettings) {
        const fileList = parseSettings.EXPERIMENTAL_useSourceOfProjectReferenceRedirect
            ? new Set(program.getSourceFiles().map(sf => (0, shared_1.getCanonicalFileName)(sf.fileName)))
            : new Set(program.getRootFileNames().map(f => (0, shared_1.getCanonicalFileName)(f)));
        programFileListCache.set(tsconfigPath, fileList);
        return fileList;
    }
    /**
     * Calculate project environments using options provided by consumer and paths from config
     * @param parseSettings Internal settings for parsing the file
     * @returns The programs corresponding to the supplied tsconfig paths
     */
    function getWatchProgramsForProjects(parseSettings) {
        const filePath = (0, shared_1.getCanonicalFileName)(parseSettings.filePath);
        const results = [];
        // preserve reference to code and file being linted
        currentLintOperationState.code = parseSettings.code;
        currentLintOperationState.filePath = filePath;
        // Update file version if necessary
        const fileWatchCallbacks = fileWatchCallbackTrackingMap.get(filePath);
        const codeHash = (0, shared_1.createHash)(parseSettings.code);
        if (parsedFilesSeenHash.get(filePath) !== codeHash &&
            fileWatchCallbacks &&
            fileWatchCallbacks.size > 0) {
            fileWatchCallbacks.forEach(cb => cb(filePath, ts.FileWatcherEventKind.Changed));
        }
        const currentProjectsFromSettings = new Set(parseSettings.projects);
        /*
         * before we go into the process of attempting to find and update every program
         * see if we know of a program that contains this file
         */
        for (const [tsconfigPath, existingWatch] of knownWatchProgramMap.entries()) {
            if (!currentProjectsFromSettings.has(tsconfigPath)) {
                // the current parser run doesn't specify this tsconfig in parserOptions.project
                // so we don't want to consider it for caching purposes.
                //
                // if we did consider it we might return a program for a project
                // that wasn't specified in the current parser run (which is obv bad!).
                continue;
            }
            let fileList = programFileListCache.get(tsconfigPath);
            let updatedProgram = null;
            if (!fileList) {
                updatedProgram = existingWatch.getProgram().getProgram();
                fileList = updateCachedFileList(tsconfigPath, updatedProgram, parseSettings);
            }
            if (fileList.has(filePath)) {
                log('Found existing program for file. %s', filePath);
                updatedProgram =
                    updatedProgram !== null && updatedProgram !== void 0 ? updatedProgram : existingWatch.getProgram().getProgram();
                // sets parent pointers in source files
                updatedProgram.getTypeChecker();
                return [updatedProgram];
            }
        }
        log('File did not belong to any existing programs, moving to create/update. %s', filePath);
        /*
         * We don't know of a program that contains the file, this means that either:
         * - the required program hasn't been created yet, or
         * - the file is new/renamed, and the program hasn't been updated.
         */
        for (const tsconfigPath of parseSettings.projects) {
            const existingWatch = knownWatchProgramMap.get(tsconfigPath);
            if (existingWatch) {
                const updatedProgram = maybeInvalidateProgram(existingWatch, filePath, tsconfigPath);
                if (!updatedProgram) {
                    continue;
                }
                // sets parent pointers in source files
                updatedProgram.getTypeChecker();
                // cache and check the file list
                const fileList = updateCachedFileList(tsconfigPath, updatedProgram, parseSettings);
                if (fileList.has(filePath)) {
                    log('Found updated program for file. %s', filePath);
                    // we can return early because we know this program contains the file
                    return [updatedProgram];
                }
                results.push(updatedProgram);
                continue;
            }
            const programWatch = createWatchProgram(tsconfigPath, parseSettings);
            knownWatchProgramMap.set(tsconfigPath, programWatch);
            const program = programWatch.getProgram().getProgram();
            // sets parent pointers in source files
            program.getTypeChecker();
            // cache and check the file list
            const fileList = updateCachedFileList(tsconfigPath, program, parseSettings);
            if (fileList.has(filePath)) {
                log('Found program for file. %s', filePath);
                // we can return early because we know this program contains the file
                return [program];
            }
            results.push(program);
        }
        return results;
    }
    exports.getWatchProgramsForProjects = getWatchProgramsForProjects;
    const isRunningNoTimeoutFix = semver_1.default.satisfies(ts.version, '>=3.9.0-beta', {
        includePrerelease: true,
    });
    function createWatchProgram(tsconfigPath, parseSettings) {
        log('Creating watch program for %s.', tsconfigPath);
        // create compiler host
        const watchCompilerHost = ts.createWatchCompilerHost(tsconfigPath, (0, shared_1.createDefaultCompilerOptionsFromExtra)(parseSettings), ts.sys, ts.createAbstractBuilder, diagnosticReporter, 
        /*reportWatchStatus*/ () => { });
        if (parseSettings.moduleResolver) {
            // eslint-disable-next-line deprecation/deprecation -- intentional for older TS versions
            watchCompilerHost.resolveModuleNames = (0, shared_1.getModuleResolver)(parseSettings.moduleResolver).resolveModuleNames;
        }
        // ensure readFile reads the code being linted instead of the copy on disk
        const oldReadFile = watchCompilerHost.readFile;
        watchCompilerHost.readFile = (filePathIn, encoding) => {
            const filePath = (0, shared_1.getCanonicalFileName)(filePathIn);
            const fileContent = filePath === currentLintOperationState.filePath
                ? currentLintOperationState.code
                : oldReadFile(filePath, encoding);
            if (fileContent !== undefined) {
                parsedFilesSeenHash.set(filePath, (0, shared_1.createHash)(fileContent));
            }
            return fileContent;
        };
        // ensure process reports error on failure instead of exiting process immediately
        watchCompilerHost.onUnRecoverableConfigFileDiagnostic = diagnosticReporter;
        // ensure process doesn't emit programs
        watchCompilerHost.afterProgramCreate = (program) => {
            // report error if there are any errors in the config file
            const configFileDiagnostics = program
                .getConfigFileParsingDiagnostics()
                .filter(diag => diag.category === ts.DiagnosticCategory.Error && diag.code !== 18003);
            if (configFileDiagnostics.length > 0) {
                diagnosticReporter(configFileDiagnostics[0]);
            }
        };
        /*
         * From the CLI, the file watchers won't matter, as the files will be parsed once and then forgotten.
         * When running from an IDE, these watchers will let us tell typescript about changes.
         *
         * ESLint IDE plugins will send us unfinished file content as the user types (before it's saved to disk).
         * We use the file watchers to tell typescript about this latest file content.
         *
         * When files are created (or renamed), we won't know about them because we have no filesystem watchers attached.
         * We use the folder watchers to tell typescript it needs to go and find new files in the project folders.
         */
        watchCompilerHost.watchFile = saveWatchCallback(fileWatchCallbackTrackingMap);
        watchCompilerHost.watchDirectory = saveWatchCallback(folderWatchCallbackTrackingMap);
        // allow files with custom extensions to be included in program (uses internal ts api)
        const oldOnDirectoryStructureHostCreate = watchCompilerHost.onCachedDirectoryStructureHostCreate;
        watchCompilerHost.onCachedDirectoryStructureHostCreate = (host) => {
            const oldReadDirectory = host.readDirectory;
            host.readDirectory = (path, extensions, exclude, include, depth) => oldReadDirectory(path, !extensions
                ? undefined
                : extensions.concat(parseSettings.extraFileExtensions), exclude, include, depth);
            oldOnDirectoryStructureHostCreate(host);
        };
        // This works only on 3.9
        watchCompilerHost.extraFileExtensions = parseSettings.extraFileExtensions.map(extension => ({
            extension,
            isMixedContent: true,
            scriptKind: ts.ScriptKind.Deferred,
        }));
        watchCompilerHost.trace = log;
        /**
         * TODO: this needs refinement and development, but we're allowing users to opt-in to this for now for testing and feedback.
         * See https://github.com/typescript-eslint/typescript-eslint/issues/2094
         */
        watchCompilerHost.useSourceOfProjectReferenceRedirect = () => parseSettings.EXPERIMENTAL_useSourceOfProjectReferenceRedirect;
        // Since we don't want to asynchronously update program we want to disable timeout methods
        // So any changes in the program will be delayed and updated when getProgram is called on watch
        let callback;
        if (isRunningNoTimeoutFix) {
            watchCompilerHost.setTimeout = undefined;
            watchCompilerHost.clearTimeout = undefined;
        }
        else {
            log('Running without timeout fix');
            // But because of https://github.com/microsoft/TypeScript/pull/37308 we cannot just set it to undefined
            // instead save it and call before getProgram is called
            watchCompilerHost.setTimeout = (cb, _ms, ...args) => {
                callback = cb.bind(/*this*/ undefined, ...args);
                return callback;
            };
            watchCompilerHost.clearTimeout = () => {
                callback = undefined;
            };
        }
        const watch = ts.createWatchProgram(watchCompilerHost);
        if (!isRunningNoTimeoutFix) {
            const originalGetProgram = watch.getProgram;
            watch.getProgram = () => {
                if (callback) {
                    callback();
                }
                callback = undefined;
                return originalGetProgram.call(watch);
            };
        }
        return watch;
    }
    function hasTSConfigChanged(tsconfigPath) {
        const stat = fs_1.default.statSync(tsconfigPath);
        const lastModifiedAt = stat.mtimeMs;
        const cachedLastModifiedAt = tsconfigLastModifiedTimestampCache.get(tsconfigPath);
        tsconfigLastModifiedTimestampCache.set(tsconfigPath, lastModifiedAt);
        if (cachedLastModifiedAt === undefined) {
            return false;
        }
        return Math.abs(cachedLastModifiedAt - lastModifiedAt) > Number.EPSILON;
    }
    function maybeInvalidateProgram(existingWatch, filePath, tsconfigPath) {
        /*
         * By calling watchProgram.getProgram(), it will trigger a resync of the program based on
         * whatever new file content we've given it from our input.
         */
        let updatedProgram = existingWatch.getProgram().getProgram();
        // In case this change causes problems in larger real world codebases
        // Provide an escape hatch so people don't _have_ to revert to an older version
        if (process.env.TSESTREE_NO_INVALIDATION === 'true') {
            return updatedProgram;
        }
        if (hasTSConfigChanged(tsconfigPath)) {
            /*
             * If the stat of the tsconfig has changed, that could mean the include/exclude/files lists has changed
             * We need to make sure typescript knows this so it can update appropriately
             */
            log('tsconfig has changed - triggering program update. %s', tsconfigPath);
            fileWatchCallbackTrackingMap
                .get(tsconfigPath)
                .forEach(cb => cb(tsconfigPath, ts.FileWatcherEventKind.Changed));
            // tsconfig change means that the file list more than likely changed, so clear the cache
            programFileListCache.delete(tsconfigPath);
        }
        let sourceFile = updatedProgram.getSourceFile(filePath);
        if (sourceFile) {
            return updatedProgram;
        }
        /*
         * Missing source file means our program's folder structure might be out of date.
         * So we need to tell typescript it needs to update the correct folder.
         */
        log('File was not found in program - triggering folder update. %s', filePath);
        // Find the correct directory callback by climbing the folder tree
        const currentDir = (0, shared_1.canonicalDirname)(filePath);
        let current = null;
        let next = currentDir;
        let hasCallback = false;
        while (current !== next) {
            current = next;
            const folderWatchCallbacks = folderWatchCallbackTrackingMap.get(current);
            if (folderWatchCallbacks) {
                folderWatchCallbacks.forEach(cb => {
                    if (currentDir !== current) {
                        cb(currentDir, ts.FileWatcherEventKind.Changed);
                    }
                    cb(current, ts.FileWatcherEventKind.Changed);
                });
                hasCallback = true;
            }
            next = (0, shared_1.canonicalDirname)(current);
        }
        if (!hasCallback) {
            /*
             * No callback means the paths don't matchup - so no point returning any program
             * this will signal to the caller to skip this program
             */
            log('No callback found for file, not part of this program. %s', filePath);
            return null;
        }
        // directory update means that the file list more than likely changed, so clear the cache
        programFileListCache.delete(tsconfigPath);
        // force the immediate resync
        updatedProgram = existingWatch.getProgram().getProgram();
        sourceFile = updatedProgram.getSourceFile(filePath);
        if (sourceFile) {
            return updatedProgram;
        }
        /*
         * At this point we're in one of two states:
         * - The file isn't supposed to be in this program due to exclusions
         * - The file is new, and was renamed from an old, included filename
         *
         * For the latter case, we need to tell typescript that the old filename is now deleted
         */
        log('File was still not found in program after directory update - checking file deletions. %s', filePath);
        const rootFilenames = updatedProgram.getRootFileNames();
        // use find because we only need to "delete" one file to cause typescript to do a full resync
        const deletedFile = rootFilenames.find(file => !fs_1.default.existsSync(file));
        if (!deletedFile) {
            // There are no deleted files, so it must be the former case of the file not belonging to this program
            return null;
        }
        const fileWatchCallbacks = fileWatchCallbackTrackingMap.get((0, shared_1.getCanonicalFileName)(deletedFile));
        if (!fileWatchCallbacks) {
            // shouldn't happen, but just in case
            log('Could not find watch callbacks for root file. %s', deletedFile);
            return updatedProgram;
        }
        log('Marking file as deleted. %s', deletedFile);
        fileWatchCallbacks.forEach(cb => cb(deletedFile, ts.FileWatcherEventKind.Deleted));
        // deleted files means that the file list _has_ changed, so clear the cache
        programFileListCache.delete(tsconfigPath);
        updatedProgram = existingWatch.getProgram().getProgram();
        sourceFile = updatedProgram.getSourceFile(filePath);
        if (sourceFile) {
            return updatedProgram;
        }
        log('File was still not found in program after deletion check, assuming it is not part of this program. %s', filePath);
        return null;
    }
    
},
/* @typescript-eslint/typescript-estree/dist/create-program/createSourceFile.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createSourceFile = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const ts = __importStar(require(21) /* typescript */);
    const getScriptKind_1 = require(1082) /* ./getScriptKind */;
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:createSourceFile');
    function createSourceFile(parseSettings) {
        log('Getting AST without type information in %s mode for: %s', parseSettings.jsx ? 'TSX' : 'TS', parseSettings.filePath);
        return ts.createSourceFile(parseSettings.filePath, parseSettings.code, ts.ScriptTarget.Latest, 
        /* setParentNodes */ true, (0, getScriptKind_1.getScriptKind)(parseSettings.filePath, parseSettings.jsx));
    }
    exports.createSourceFile = createSourceFile;
    
},
/* @typescript-eslint/typescript-estree/dist/create-program/useProvidedPrograms.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createProgramFromConfigFile = exports.useProvidedPrograms = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const fs = __importStar(require("fs"));
    const path = __importStar(require("path"));
    const ts = __importStar(require(21) /* typescript */);
    const shared_1 = require(1080) /* ./shared */;
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:useProvidedProgram');
    function useProvidedPrograms(programInstances, parseSettings) {
        log('Retrieving ast for %s from provided program instance(s)', parseSettings.filePath);
        let astAndProgram;
        for (const programInstance of programInstances) {
            astAndProgram = (0, shared_1.getAstFromProgram)(programInstance, parseSettings);
            // Stop at the first applicable program instance
            if (astAndProgram) {
                break;
            }
        }
        if (!astAndProgram) {
            const relativeFilePath = path.relative(parseSettings.tsconfigRootDir || process.cwd(), parseSettings.filePath);
            const errorLines = [
                '"parserOptions.programs" has been provided for @typescript-eslint/parser.',
                `The file was not found in any of the provided program instance(s): ${relativeFilePath}`,
            ];
            throw new Error(errorLines.join('\n'));
        }
        astAndProgram.program.getTypeChecker(); // ensure parent pointers are set in source files
        return astAndProgram;
    }
    exports.useProvidedPrograms = useProvidedPrograms;
    /**
     * Utility offered by parser to help consumers construct their own program instance.
     *
     * @param configFile the path to the tsconfig.json file, relative to `projectDirectory`
     * @param projectDirectory the project directory to use as the CWD, defaults to `process.cwd()`
     */
    function createProgramFromConfigFile(configFile, projectDirectory) {
        if (ts.sys === undefined) {
            throw new Error('`createProgramFromConfigFile` is only supported in a Node-like environment.');
        }
        const parsed = ts.getParsedCommandLineOfConfigFile(configFile, shared_1.CORE_COMPILER_OPTIONS, {
            onUnRecoverableConfigFileDiagnostic: diag => {
                throw new Error(formatDiagnostics([diag])); // ensures that `parsed` is defined.
            },
            fileExists: fs.existsSync,
            getCurrentDirectory: () => (projectDirectory && path.resolve(projectDirectory)) || process.cwd(),
            readDirectory: ts.sys.readDirectory,
            readFile: file => fs.readFileSync(file, 'utf-8'),
            useCaseSensitiveFileNames: ts.sys.useCaseSensitiveFileNames,
        });
        const result = parsed; // parsed is not undefined, since we throw on failure.
        if (result.errors.length) {
            throw new Error(formatDiagnostics(result.errors));
        }
        const host = ts.createCompilerHost(result.options, true);
        return ts.createProgram(result.fileNames, result.options, host);
    }
    exports.createProgramFromConfigFile = createProgramFromConfigFile;
    function formatDiagnostics(diagnostics) {
        return ts.formatDiagnostics(diagnostics, {
            getCanonicalFileName: f => f,
            getCurrentDirectory: process.cwd,
            getNewLine: () => '\n',
        });
    }
    
},
/* @typescript-eslint/typescript-estree/dist/parseSettings/createParseSettings.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.clearTSConfigMatchCache = exports.createParseSettings = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const shared_1 = require(1080) /* ../create-program/shared */;
    const ExpiringCache_1 = require(1089) /* ./ExpiringCache */;
    const getProjectConfigFiles_1 = require(1090) /* ./getProjectConfigFiles */;
    const inferSingleRun_1 = require(1091) /* ./inferSingleRun */;
    const resolveProjectList_1 = require(1092) /* ./resolveProjectList */;
    const warnAboutTSVersion_1 = require(1144) /* ./warnAboutTSVersion */;
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:parser:parseSettings:createParseSettings');
    let TSCONFIG_MATCH_CACHE;
    function createParseSettings(code, options = {}) {
        var _a, _b, _c;
        const singleRun = (0, inferSingleRun_1.inferSingleRun)(options);
        const tsconfigRootDir = typeof options.tsconfigRootDir === 'string'
            ? options.tsconfigRootDir
            : process.cwd();
        const parseSettings = {
            code: enforceString(code),
            comment: options.comment === true,
            comments: [],
            createDefaultProgram: options.createDefaultProgram === true,
            debugLevel: options.debugLevel === true
                ? new Set(['typescript-eslint'])
                : Array.isArray(options.debugLevel)
                    ? new Set(options.debugLevel)
                    : new Set(),
            errorOnTypeScriptSyntacticAndSemanticIssues: false,
            errorOnUnknownASTType: options.errorOnUnknownASTType === true,
            EXPERIMENTAL_useSourceOfProjectReferenceRedirect: options.EXPERIMENTAL_useSourceOfProjectReferenceRedirect === true,
            extraFileExtensions: Array.isArray(options.extraFileExtensions) &&
                options.extraFileExtensions.every(ext => typeof ext === 'string')
                ? options.extraFileExtensions
                : [],
            filePath: (0, shared_1.ensureAbsolutePath)(typeof options.filePath === 'string' && options.filePath !== '<input>'
                ? options.filePath
                : getFileName(options.jsx), tsconfigRootDir),
            jsx: options.jsx === true,
            loc: options.loc === true,
            log: typeof options.loggerFn === 'function'
                ? options.loggerFn
                : options.loggerFn === false
                    ? () => { }
                    : console.log,
            moduleResolver: (_a = options.moduleResolver) !== null && _a !== void 0 ? _a : '',
            preserveNodeMaps: options.preserveNodeMaps !== false,
            programs: Array.isArray(options.programs) ? options.programs : null,
            projects: [],
            range: options.range === true,
            singleRun,
            tokens: options.tokens === true ? [] : null,
            tsconfigMatchCache: (TSCONFIG_MATCH_CACHE !== null && TSCONFIG_MATCH_CACHE !== void 0 ? TSCONFIG_MATCH_CACHE : (TSCONFIG_MATCH_CACHE = new ExpiringCache_1.ExpiringCache(singleRun
                ? 'Infinity'
                : (_c = (_b = options.cacheLifetime) === null || _b === void 0 ? void 0 : _b.glob) !== null && _c !== void 0 ? _c : ExpiringCache_1.DEFAULT_TSCONFIG_CACHE_DURATION_SECONDS))),
            tsconfigRootDir,
        };
        // debug doesn't support multiple `enable` calls, so have to do it all at once
        if (parseSettings.debugLevel.size > 0) {
            const namespaces = [];
            if (parseSettings.debugLevel.has('typescript-eslint')) {
                namespaces.push('typescript-eslint:*');
            }
            if (parseSettings.debugLevel.has('eslint') ||
                // make sure we don't turn off the eslint debug if it was enabled via --debug
                debug_1.default.enabled('eslint:*,-eslint:code-path')) {
                // https://github.com/eslint/eslint/blob/9dfc8501fb1956c90dc11e6377b4cb38a6bea65d/bin/eslint.js#L25
                namespaces.push('eslint:*,-eslint:code-path');
            }
            debug_1.default.enable(namespaces.join(','));
        }
        if (Array.isArray(options.programs)) {
            if (!options.programs.length) {
                throw new Error(`You have set parserOptions.programs to an empty array. This will cause all files to not be found in existing programs. Either provide one or more existing TypeScript Program instances in the array, or remove the parserOptions.programs setting.`);
            }
            log('parserOptions.programs was provided, so parserOptions.project will be ignored.');
        }
        // Providing a program overrides project resolution
        if (!parseSettings.programs) {
            parseSettings.projects = (0, resolveProjectList_1.resolveProjectList)({
                cacheLifetime: options.cacheLifetime,
                project: (0, getProjectConfigFiles_1.getProjectConfigFiles)(parseSettings, options.project),
                projectFolderIgnoreList: options.projectFolderIgnoreList,
                singleRun: parseSettings.singleRun,
                tsconfigRootDir: tsconfigRootDir,
            });
        }
        (0, warnAboutTSVersion_1.warnAboutTSVersion)(parseSettings);
        return parseSettings;
    }
    exports.createParseSettings = createParseSettings;
    function clearTSConfigMatchCache() {
        TSCONFIG_MATCH_CACHE === null || TSCONFIG_MATCH_CACHE === void 0 ? void 0 : TSCONFIG_MATCH_CACHE.clear();
    }
    exports.clearTSConfigMatchCache = clearTSConfigMatchCache;
    /**
     * Ensures source code is a string.
     */
    function enforceString(code) {
        if (typeof code !== 'string') {
            return String(code);
        }
        return code;
    }
    /**
     * Compute the filename based on the parser options.
     *
     * Even if jsx option is set in typescript compiler, filename still has to
     * contain .tsx file extension.
     *
     * @param options Parser options
     */
    function getFileName(jsx) {
        return jsx ? 'estree.tsx' : 'estree.ts';
    }
    
},
/* @typescript-eslint/typescript-estree/dist/parseSettings/ExpiringCache.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    };
    var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    var _ExpiringCache_cacheDurationSeconds, _ExpiringCache_map;
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ExpiringCache = exports.DEFAULT_TSCONFIG_CACHE_DURATION_SECONDS = void 0;
    exports.DEFAULT_TSCONFIG_CACHE_DURATION_SECONDS = 30;
    const ZERO_HR_TIME = [0, 0];
    /**
     * A map with key-level expiration.
     */
    class ExpiringCache {
        constructor(cacheDurationSeconds) {
            _ExpiringCache_cacheDurationSeconds.set(this, void 0);
            _ExpiringCache_map.set(this, new Map());
            __classPrivateFieldSet(this, _ExpiringCache_cacheDurationSeconds, cacheDurationSeconds, "f");
        }
        set(key, value) {
            __classPrivateFieldGet(this, _ExpiringCache_map, "f").set(key, {
                value,
                lastSeen: __classPrivateFieldGet(this, _ExpiringCache_cacheDurationSeconds, "f") === 'Infinity'
                    ? // no need to waste time calculating the hrtime in infinity mode as there's no expiry
                        ZERO_HR_TIME
                    : process.hrtime(),
            });
            return this;
        }
        get(key) {
            const entry = __classPrivateFieldGet(this, _ExpiringCache_map, "f").get(key);
            if ((entry === null || entry === void 0 ? void 0 : entry.value) != null) {
                if (__classPrivateFieldGet(this, _ExpiringCache_cacheDurationSeconds, "f") === 'Infinity') {
                    return entry.value;
                }
                const ageSeconds = process.hrtime(entry.lastSeen)[0];
                if (ageSeconds < __classPrivateFieldGet(this, _ExpiringCache_cacheDurationSeconds, "f")) {
                    // cache hit woo!
                    return entry.value;
                }
                else {
                    // key has expired - clean it up to free up memory
                    __classPrivateFieldGet(this, _ExpiringCache_map, "f").delete(key);
                }
            }
            // no hit :'(
            return undefined;
        }
        clear() {
            __classPrivateFieldGet(this, _ExpiringCache_map, "f").clear();
        }
    }
    exports.ExpiringCache = ExpiringCache;
    _ExpiringCache_cacheDurationSeconds = new WeakMap(), _ExpiringCache_map = new WeakMap();
    
},
/* @typescript-eslint/typescript-estree/dist/parseSettings/getProjectConfigFiles.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getProjectConfigFiles = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const fs = __importStar(require("fs"));
    const path = __importStar(require("path"));
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:getProjectConfigFiles');
    /**
     * Checks for a matching TSConfig to a file including its parent directories,
     * permanently caching results under each directory it checks.
     *
     * @remarks
     * We don't (yet!) have a way to attach file watchers on disk, but still need to
     * cache file checks for rapid subsequent calls to fs.existsSync. See discussion
     * in https://github.com/typescript-eslint/typescript-eslint/issues/101.
     */
    function getProjectConfigFiles(parseSettings, project) {
        var _a;
        if (project !== true) {
            return project === undefined || Array.isArray(project)
                ? project
                : [project];
        }
        log('Looking for tsconfig.json at or above file: %s', parseSettings.filePath);
        let directory = path.dirname(parseSettings.filePath);
        const checkedDirectories = [directory];
        do {
            log('Checking tsconfig.json path: %s', directory);
            const tsconfigPath = path.join(directory, 'tsconfig.json');
            const cached = (_a = parseSettings.tsconfigMatchCache.get(directory)) !== null && _a !== void 0 ? _a : (fs.existsSync(tsconfigPath) && tsconfigPath);
            if (cached) {
                for (const directory of checkedDirectories) {
                    parseSettings.tsconfigMatchCache.set(directory, cached);
                }
                return [cached];
            }
            directory = path.dirname(directory);
            checkedDirectories.push(directory);
        } while (directory.length > 1 &&
            directory.length >= parseSettings.tsconfigRootDir.length);
        throw new Error(`project was set to \`true\` but couldn't find any tsconfig.json relative to '${parseSettings.filePath}' within '${parseSettings.tsconfigRootDir}'.`);
    }
    exports.getProjectConfigFiles = getProjectConfigFiles;
    
},
/* @typescript-eslint/typescript-estree/dist/parseSettings/inferSingleRun.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.inferSingleRun = void 0;
    const path_1 = require("path");
    /**
     * ESLint (and therefore typescript-eslint) is used in both "single run"/one-time contexts,
     * such as an ESLint CLI invocation, and long-running sessions (such as continuous feedback
     * on a file in an IDE).
     *
     * When typescript-eslint handles TypeScript Program management behind the scenes, this distinction
     * is important because there is significant overhead to managing the so called Watch Programs
     * needed for the long-running use-case. We therefore use the following logic to figure out which
     * of these contexts applies to the current execution.
     *
     * @returns Whether this is part of a single run, rather than a long-running process.
     */
    function inferSingleRun(options) {
        if (
        // single-run implies type-aware linting - no projects means we can't be in single-run mode
        (options === null || options === void 0 ? void 0 : options.project) == null ||
            // programs passed via options means the user should be managing the programs, so we shouldn't
            // be creating our own single-run programs accidentally
            (options === null || options === void 0 ? void 0 : options.programs) != null) {
            return false;
        }
        // Allow users to explicitly inform us of their intent to perform a single run (or not) with TSESTREE_SINGLE_RUN
        if (process.env.TSESTREE_SINGLE_RUN === 'false') {
            return false;
        }
        if (process.env.TSESTREE_SINGLE_RUN === 'true') {
            return true;
        }
        // Currently behind a flag while we gather real-world feedback
        if (options === null || options === void 0 ? void 0 : options.allowAutomaticSingleRunInference) {
            if (
            // Default to single runs for CI processes. CI=true is set by most CI providers by default.
            process.env.CI === 'true' ||
                // This will be true for invocations such as `npx eslint ...` and `./node_modules/.bin/eslint ...`
                process.argv[1].endsWith((0, path_1.normalize)('node_modules/.bin/eslint'))) {
                return true;
            }
        }
        /**
         * We default to assuming that this run could be part of a long-running session (e.g. in an IDE)
         * and watch programs will therefore be required.
         *
         * Unless we can reliably infer otherwise, we default to assuming that this run could be part
         * of a long-running session (e.g. in an IDE) and watch programs will therefore be required
         */
        return false;
    }
    exports.inferSingleRun = inferSingleRun;
    
},
/* @typescript-eslint/typescript-estree/dist/parseSettings/resolveProjectList.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.clearGlobResolutionCache = exports.resolveProjectList = exports.clearGlobCache = void 0;
    const debug_1 = __importDefault(require(72) /* debug */);
    const globby_1 = require(1093) /* globby */;
    const is_glob_1 = __importDefault(require(283) /* is-glob */);
    const shared_1 = require(1080) /* ../create-program/shared */;
    const ExpiringCache_1 = require(1089) /* ./ExpiringCache */;
    const log = (0, debug_1.default)('typescript-eslint:typescript-estree:parser:parseSettings:resolveProjectList');
    let RESOLUTION_CACHE = null;
    function clearGlobCache() {
        RESOLUTION_CACHE === null || RESOLUTION_CACHE === void 0 ? void 0 : RESOLUTION_CACHE.clear();
    }
    exports.clearGlobCache = clearGlobCache;
    /**
     * Normalizes, sanitizes, resolves and filters the provided project paths
     */
    function resolveProjectList(options) {
        var _a, _b, _c;
        const sanitizedProjects = [];
        // Normalize and sanitize the project paths
        if (typeof options.project === 'string') {
            sanitizedProjects.push(options.project);
        }
        else if (Array.isArray(options.project)) {
            for (const project of options.project) {
                if (typeof project === 'string') {
                    sanitizedProjects.push(project);
                }
            }
        }
        if (sanitizedProjects.length === 0) {
            return [];
        }
        const projectFolderIgnoreList = ((_a = options.projectFolderIgnoreList) !== null && _a !== void 0 ? _a : ['**/node_modules/**'])
            .reduce((acc, folder) => {
            if (typeof folder === 'string') {
                acc.push(folder);
            }
            return acc;
        }, [])
            // prefix with a ! for not match glob
            .map(folder => (folder.startsWith('!') ? folder : `!${folder}`));
        const cacheKey = getHash({
            project: sanitizedProjects,
            projectFolderIgnoreList,
            tsconfigRootDir: options.tsconfigRootDir,
        });
        if (RESOLUTION_CACHE == null) {
            // note - we initialize the global cache based on the first config we encounter.
            //        this does mean that you can't have multiple lifetimes set per folder
            //        I doubt that anyone will really bother reconfiguring this, let alone
            //        try to do complicated setups, so we'll deal with this later if ever.
            RESOLUTION_CACHE = new ExpiringCache_1.ExpiringCache(options.singleRun
                ? 'Infinity'
                : (_c = (_b = options.cacheLifetime) === null || _b === void 0 ? void 0 : _b.glob) !== null && _c !== void 0 ? _c : ExpiringCache_1.DEFAULT_TSCONFIG_CACHE_DURATION_SECONDS);
        }
        else {
            const cached = RESOLUTION_CACHE.get(cacheKey);
            if (cached) {
                return cached;
            }
        }
        // Transform glob patterns into paths
        const nonGlobProjects = sanitizedProjects.filter(project => !(0, is_glob_1.default)(project));
        const globProjects = sanitizedProjects.filter(project => (0, is_glob_1.default)(project));
        const uniqueCanonicalProjectPaths = new Set(nonGlobProjects
            .concat(globProjects.length === 0
            ? []
            : (0, globby_1.sync)([...globProjects, ...projectFolderIgnoreList], {
                cwd: options.tsconfigRootDir,
            }))
            .map(project => (0, shared_1.getCanonicalFileName)((0, shared_1.ensureAbsolutePath)(project, options.tsconfigRootDir))));
        log('parserOptions.project (excluding ignored) matched projects: %s', uniqueCanonicalProjectPaths);
        const returnValue = Array.from(uniqueCanonicalProjectPaths);
        RESOLUTION_CACHE.set(cacheKey, returnValue);
        return returnValue;
    }
    exports.resolveProjectList = resolveProjectList;
    function getHash({ project, projectFolderIgnoreList, tsconfigRootDir, }) {
        // create a stable representation of the config
        const hashObject = {
            tsconfigRootDir,
            // the project order does matter and can impact the resolved globs
            project,
            // the ignore order won't doesn't ever matter
            projectFolderIgnoreList: [...projectFolderIgnoreList].sort(),
        };
        return (0, shared_1.createHash)(JSON.stringify(hashObject));
    }
    /**
     * Exported for testing purposes only
     * @internal
     */
    function clearGlobResolutionCache() {
        RESOLUTION_CACHE === null || RESOLUTION_CACHE === void 0 ? void 0 : RESOLUTION_CACHE.clear();
        RESOLUTION_CACHE = null;
    }
    exports.clearGlobResolutionCache = clearGlobResolutionCache;
    
},
/* globby/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const fs = require('fs');
    const arrayUnion = require(1094) /* array-union */;
    const merge2 = require(1095) /* merge2 */;
    const fastGlob = require(1096) /* fast-glob */;
    const dirGlob = require(1139) /* dir-glob */;
    const gitignore = require(1141) /* ./gitignore */;
    const { FilterStream, UniqueStream } = require(1143) /* ./stream-utils */;
    const DEFAULT_FILTER = () => false;
    const isNegative = pattern => pattern[0] === '!';
    const assertPatternsInput = patterns => {
        if (!patterns.every(pattern => typeof pattern === 'string')) {
            throw new TypeError('Patterns must be a string or an array of strings');
        }
    };
    const checkCwdOption = (options = {}) => {
        if (!options.cwd) {
            return;
        }
        let stat;
        try {
            stat = fs.statSync(options.cwd);
        }
        catch {
            return;
        }
        if (!stat.isDirectory()) {
            throw new Error('The `cwd` option must be a path to a directory');
        }
    };
    const getPathString = p => p.stats instanceof fs.Stats ? p.path : p;
    const generateGlobTasks = (patterns, taskOptions) => {
        patterns = arrayUnion([].concat(patterns));
        assertPatternsInput(patterns);
        checkCwdOption(taskOptions);
        const globTasks = [];
        taskOptions = {
            ignore: [],
            expandDirectories: true,
            ...taskOptions
        };
        for (const [index, pattern] of patterns.entries()) {
            if (isNegative(pattern)) {
                continue;
            }
            const ignore = patterns
                .slice(index)
                .filter(pattern => isNegative(pattern))
                .map(pattern => pattern.slice(1));
            const options = {
                ...taskOptions,
                ignore: taskOptions.ignore.concat(ignore)
            };
            globTasks.push({ pattern, options });
        }
        return globTasks;
    };
    const globDirs = (task, fn) => {
        let options = {};
        if (task.options.cwd) {
            options.cwd = task.options.cwd;
        }
        if (Array.isArray(task.options.expandDirectories)) {
            options = {
                ...options,
                files: task.options.expandDirectories
            };
        }
        else if (typeof task.options.expandDirectories === 'object') {
            options = {
                ...options,
                ...task.options.expandDirectories
            };
        }
        return fn(task.pattern, options);
    };
    const getPattern = (task, fn) => task.options.expandDirectories ? globDirs(task, fn) : [task.pattern];
    const getFilterSync = options => {
        return options && options.gitignore ?
            gitignore.sync({ cwd: options.cwd, ignore: options.ignore }) :
            DEFAULT_FILTER;
    };
    const globToTask = task => glob => {
        const { options } = task;
        if (options.ignore && Array.isArray(options.ignore) && options.expandDirectories) {
            options.ignore = dirGlob.sync(options.ignore);
        }
        return {
            pattern: glob,
            options
        };
    };
    module.exports = async (patterns, options) => {
        const globTasks = generateGlobTasks(patterns, options);
        const getFilter = async () => {
            return options && options.gitignore ?
                gitignore({ cwd: options.cwd, ignore: options.ignore }) :
                DEFAULT_FILTER;
        };
        const getTasks = async () => {
            const tasks = await Promise.all(globTasks.map(async (task) => {
                const globs = await getPattern(task, dirGlob);
                return Promise.all(globs.map(globToTask(task)));
            }));
            return arrayUnion(...tasks);
        };
        const [filter, tasks] = await Promise.all([getFilter(), getTasks()]);
        const paths = await Promise.all(tasks.map(task => fastGlob(task.pattern, task.options)));
        return arrayUnion(...paths).filter(path_ => !filter(getPathString(path_)));
    };
    module.exports.sync = (patterns, options) => {
        const globTasks = generateGlobTasks(patterns, options);
        const tasks = [];
        for (const task of globTasks) {
            const newTask = getPattern(task, dirGlob.sync).map(globToTask(task));
            tasks.push(...newTask);
        }
        const filter = getFilterSync(options);
        let matches = [];
        for (const task of tasks) {
            matches = arrayUnion(matches, fastGlob.sync(task.pattern, task.options));
        }
        return matches.filter(path_ => !filter(path_));
    };
    module.exports.stream = (patterns, options) => {
        const globTasks = generateGlobTasks(patterns, options);
        const tasks = [];
        for (const task of globTasks) {
            const newTask = getPattern(task, dirGlob.sync).map(globToTask(task));
            tasks.push(...newTask);
        }
        const filter = getFilterSync(options);
        const filterStream = new FilterStream(p => !filter(p));
        const uniqueStream = new UniqueStream();
        return merge2(tasks.map(task => fastGlob.stream(task.pattern, task.options)))
            .pipe(filterStream)
            .pipe(uniqueStream);
    };
    module.exports.generateGlobTasks = generateGlobTasks;
    module.exports.hasMagic = (patterns, options) => []
        .concat(patterns)
        .some(pattern => fastGlob.isDynamicPattern(pattern, options));
    module.exports.gitignore = gitignore;
},
/* array-union/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = (...arguments_) => {
        return [...new Set([].concat(...arguments_))];
    };
},
/* merge2/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    /*
     * merge2
     * https://github.com/teambition/merge2
     *
     * Copyright (c) 2014-2020 Teambition
     * Licensed under the MIT license.
     */
    const Stream = require('stream');
    const PassThrough = Stream.PassThrough;
    const slice = Array.prototype.slice;
    module.exports = merge2;
    function merge2() {
        const streamsQueue = [];
        const args = slice.call(arguments);
        let merging = false;
        let options = args[args.length - 1];
        if (options && !Array.isArray(options) && options.pipe == null) {
            args.pop();
        }
        else {
            options = {};
        }
        const doEnd = options.end !== false;
        const doPipeError = options.pipeError === true;
        if (options.objectMode == null) {
            options.objectMode = true;
        }
        if (options.highWaterMark == null) {
            options.highWaterMark = 64 * 1024;
        }
        const mergedStream = PassThrough(options);
        function addStream() {
            for (let i = 0, len = arguments.length; i < len; i++) {
                streamsQueue.push(pauseStreams(arguments[i], options));
            }
            mergeStream();
            return this;
        }
        function mergeStream() {
            if (merging) {
                return;
            }
            merging = true;
            let streams = streamsQueue.shift();
            if (!streams) {
                process.nextTick(endStream);
                return;
            }
            if (!Array.isArray(streams)) {
                streams = [streams];
            }
            let pipesCount = streams.length + 1;
            function next() {
                if (--pipesCount > 0) {
                    return;
                }
                merging = false;
                mergeStream();
            }
            function pipe(stream) {
                function onend() {
                    stream.removeListener('merge2UnpipeEnd', onend);
                    stream.removeListener('end', onend);
                    if (doPipeError) {
                        stream.removeListener('error', onerror);
                    }
                    next();
                }
                function onerror(err) {
                    mergedStream.emit('error', err);
                }
                // skip ended stream
                if (stream._readableState.endEmitted) {
                    return next();
                }
                stream.on('merge2UnpipeEnd', onend);
                stream.on('end', onend);
                if (doPipeError) {
                    stream.on('error', onerror);
                }
                stream.pipe(mergedStream, { end: false });
                // compatible for old stream
                stream.resume();
            }
            for (let i = 0; i < streams.length; i++) {
                pipe(streams[i]);
            }
            next();
        }
        function endStream() {
            merging = false;
            // emit 'queueDrain' when all streams merged.
            mergedStream.emit('queueDrain');
            if (doEnd) {
                mergedStream.end();
            }
        }
        mergedStream.setMaxListeners(0);
        mergedStream.add = addStream;
        mergedStream.on('unpipe', function (stream) {
            stream.emit('merge2UnpipeEnd');
        });
        if (args.length) {
            addStream.apply(null, args);
        }
        return mergedStream;
    }
    // check and pause streams for pipe.
    function pauseStreams(streams, options) {
        if (!Array.isArray(streams)) {
            // Backwards-compat with old-style streams
            if (!streams._readableState && streams.pipe) {
                streams = streams.pipe(PassThrough(options));
            }
            if (!streams._readableState || !streams.pause || !streams.pipe) {
                throw new Error('Only readable stream can be merged.');
            }
            streams.pause();
        }
        else {
            for (let i = 0, len = streams.length; i < len; i++) {
                streams[i] = pauseStreams(streams[i], options);
            }
        }
        return streams;
    }
},
/* fast-glob/out/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const taskManager = require(1097) /* ./managers/tasks */;
    const patternManager = require(1123) /* ./managers/patterns */;
    const async_1 = require(1124) /* ./providers/async */;
    const stream_1 = require(1135) /* ./providers/stream */;
    const sync_1 = require(1136) /* ./providers/sync */;
    const settings_1 = require(1138) /* ./settings */;
    const utils = require(1098) /* ./utils */;
    async function FastGlob(source, options) {
        assertPatternsInput(source);
        const works = getWorks(source, async_1.default, options);
        const result = await Promise.all(works);
        return utils.array.flatten(result);
    }
    // https://github.com/typescript-eslint/typescript-eslint/issues/60
    // eslint-disable-next-line no-redeclare
    (function (FastGlob) {
        function sync(source, options) {
            assertPatternsInput(source);
            const works = getWorks(source, sync_1.default, options);
            return utils.array.flatten(works);
        }
        FastGlob.sync = sync;
        function stream(source, options) {
            assertPatternsInput(source);
            const works = getWorks(source, stream_1.default, options);
            /**
             * The stream returned by the provider cannot work with an asynchronous iterator.
             * To support asynchronous iterators, regardless of the number of tasks, we always multiplex streams.
             * This affects performance (+25%). I don't see best solution right now.
             */
            return utils.stream.merge(works);
        }
        FastGlob.stream = stream;
        function generateTasks(source, options) {
            assertPatternsInput(source);
            const patterns = patternManager.transform([].concat(source));
            const settings = new settings_1.default(options);
            return taskManager.generate(patterns, settings);
        }
        FastGlob.generateTasks = generateTasks;
        function isDynamicPattern(source, options) {
            assertPatternsInput(source);
            const settings = new settings_1.default(options);
            return utils.pattern.isDynamicPattern(source, settings);
        }
        FastGlob.isDynamicPattern = isDynamicPattern;
        function escapePath(source) {
            assertPatternsInput(source);
            return utils.path.escape(source);
        }
        FastGlob.escapePath = escapePath;
    })(FastGlob || (FastGlob = {}));
    function getWorks(source, _Provider, options) {
        const patterns = patternManager.transform([].concat(source));
        const settings = new settings_1.default(options);
        const tasks = taskManager.generate(patterns, settings);
        const provider = new _Provider(settings);
        return tasks.map(provider.read, provider);
    }
    function assertPatternsInput(input) {
        const source = [].concat(input);
        const isValidSource = source.every((item) => utils.string.isString(item) && !utils.string.isEmpty(item));
        if (!isValidSource) {
            throw new TypeError('Patterns must be a string (non empty) or an array of strings');
        }
    }
    module.exports = FastGlob;
},
/* fast-glob/out/managers/tasks.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.convertPatternGroupToTask = exports.convertPatternGroupsToTasks = exports.groupPatternsByBaseDirectory = exports.getNegativePatternsAsPositive = exports.getPositivePatterns = exports.convertPatternsToTasks = exports.generate = void 0;
    const utils = require(1098) /* ../utils */;
    function generate(patterns, settings) {
        const positivePatterns = getPositivePatterns(patterns);
        const negativePatterns = getNegativePatternsAsPositive(patterns, settings.ignore);
        const staticPatterns = positivePatterns.filter((pattern) => utils.pattern.isStaticPattern(pattern, settings));
        const dynamicPatterns = positivePatterns.filter((pattern) => utils.pattern.isDynamicPattern(pattern, settings));
        const staticTasks = convertPatternsToTasks(staticPatterns, negativePatterns, /* dynamic */ false);
        const dynamicTasks = convertPatternsToTasks(dynamicPatterns, negativePatterns, /* dynamic */ true);
        return staticTasks.concat(dynamicTasks);
    }
    exports.generate = generate;
    /**
     * Returns tasks grouped by basic pattern directories.
     *
     * Patterns that can be found inside (`./`) and outside (`../`) the current directory are handled separately.
     * This is necessary because directory traversal starts at the base directory and goes deeper.
     */
    function convertPatternsToTasks(positive, negative, dynamic) {
        const tasks = [];
        const patternsOutsideCurrentDirectory = utils.pattern.getPatternsOutsideCurrentDirectory(positive);
        const patternsInsideCurrentDirectory = utils.pattern.getPatternsInsideCurrentDirectory(positive);
        const outsideCurrentDirectoryGroup = groupPatternsByBaseDirectory(patternsOutsideCurrentDirectory);
        const insideCurrentDirectoryGroup = groupPatternsByBaseDirectory(patternsInsideCurrentDirectory);
        tasks.push(...convertPatternGroupsToTasks(outsideCurrentDirectoryGroup, negative, dynamic));
        /*
         * For the sake of reducing future accesses to the file system, we merge all tasks within the current directory
         * into a global task, if at least one pattern refers to the root (`.`). In this case, the global task covers the rest.
         */
        if ('.' in insideCurrentDirectoryGroup) {
            tasks.push(convertPatternGroupToTask('.', patternsInsideCurrentDirectory, negative, dynamic));
        }
        else {
            tasks.push(...convertPatternGroupsToTasks(insideCurrentDirectoryGroup, negative, dynamic));
        }
        return tasks;
    }
    exports.convertPatternsToTasks = convertPatternsToTasks;
    function getPositivePatterns(patterns) {
        return utils.pattern.getPositivePatterns(patterns);
    }
    exports.getPositivePatterns = getPositivePatterns;
    function getNegativePatternsAsPositive(patterns, ignore) {
        const negative = utils.pattern.getNegativePatterns(patterns).concat(ignore);
        const positive = negative.map(utils.pattern.convertToPositivePattern);
        return positive;
    }
    exports.getNegativePatternsAsPositive = getNegativePatternsAsPositive;
    function groupPatternsByBaseDirectory(patterns) {
        const group = {};
        return patterns.reduce((collection, pattern) => {
            const base = utils.pattern.getBaseDirectory(pattern);
            if (base in collection) {
                collection[base].push(pattern);
            }
            else {
                collection[base] = [pattern];
            }
            return collection;
        }, group);
    }
    exports.groupPatternsByBaseDirectory = groupPatternsByBaseDirectory;
    function convertPatternGroupsToTasks(positive, negative, dynamic) {
        return Object.keys(positive).map((base) => {
            return convertPatternGroupToTask(base, positive[base], negative, dynamic);
        });
    }
    exports.convertPatternGroupsToTasks = convertPatternGroupsToTasks;
    function convertPatternGroupToTask(base, positive, negative, dynamic) {
        return {
            dynamic,
            positive,
            negative,
            base,
            patterns: [].concat(positive, negative.map(utils.pattern.convertToNegativePattern))
        };
    }
    exports.convertPatternGroupToTask = convertPatternGroupToTask;
},
/* fast-glob/out/utils/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.string = exports.stream = exports.pattern = exports.path = exports.fs = exports.errno = exports.array = void 0;
    const array = require(1099) /* ./array */;
    exports.array = array;
    const errno = require(1100) /* ./errno */;
    exports.errno = errno;
    const fs = require(1101) /* ./fs */;
    exports.fs = fs;
    const path = require(1102) /* ./path */;
    exports.path = path;
    const pattern = require(1103) /* ./pattern */;
    exports.pattern = pattern;
    const stream = require(1121) /* ./stream */;
    exports.stream = stream;
    const string = require(1122) /* ./string */;
    exports.string = string;
},
/* fast-glob/out/utils/array.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.splitWhen = exports.flatten = void 0;
    function flatten(items) {
        return items.reduce((collection, item) => [].concat(collection, item), []);
    }
    exports.flatten = flatten;
    function splitWhen(items, predicate) {
        const result = [[]];
        let groupIndex = 0;
        for (const item of items) {
            if (predicate(item)) {
                groupIndex++;
                result[groupIndex] = [];
            }
            else {
                result[groupIndex].push(item);
            }
        }
        return result;
    }
    exports.splitWhen = splitWhen;
},
/* fast-glob/out/utils/errno.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isEnoentCodeError = void 0;
    function isEnoentCodeError(error) {
        return error.code === 'ENOENT';
    }
    exports.isEnoentCodeError = isEnoentCodeError;
},
/* fast-glob/out/utils/fs.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createDirentFromStats = void 0;
    class DirentFromStats {
        constructor(name, stats) {
            this.name = name;
            this.isBlockDevice = stats.isBlockDevice.bind(stats);
            this.isCharacterDevice = stats.isCharacterDevice.bind(stats);
            this.isDirectory = stats.isDirectory.bind(stats);
            this.isFIFO = stats.isFIFO.bind(stats);
            this.isFile = stats.isFile.bind(stats);
            this.isSocket = stats.isSocket.bind(stats);
            this.isSymbolicLink = stats.isSymbolicLink.bind(stats);
        }
    }
    function createDirentFromStats(name, stats) {
        return new DirentFromStats(name, stats);
    }
    exports.createDirentFromStats = createDirentFromStats;
},
/* fast-glob/out/utils/path.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.removeLeadingDotSegment = exports.escape = exports.makeAbsolute = exports.unixify = void 0;
    const path = require("path");
    const LEADING_DOT_SEGMENT_CHARACTERS_COUNT = 2; // ./ or .\\
    const UNESCAPED_GLOB_SYMBOLS_RE = /(\\?)([()*?[\]{|}]|^!|[!+@](?=\())/g;
    /**
     * Designed to work only with simple paths: `dir\\file`.
     */
    function unixify(filepath) {
        return filepath.replace(/\\/g, '/');
    }
    exports.unixify = unixify;
    function makeAbsolute(cwd, filepath) {
        return path.resolve(cwd, filepath);
    }
    exports.makeAbsolute = makeAbsolute;
    function escape(pattern) {
        return pattern.replace(UNESCAPED_GLOB_SYMBOLS_RE, '\\$2');
    }
    exports.escape = escape;
    function removeLeadingDotSegment(entry) {
        // We do not use `startsWith` because this is 10x slower than current implementation for some cases.
        // eslint-disable-next-line @typescript-eslint/prefer-string-starts-ends-with
        if (entry.charAt(0) === '.') {
            const secondCharactery = entry.charAt(1);
            if (secondCharactery === '/' || secondCharactery === '\\') {
                return entry.slice(LEADING_DOT_SEGMENT_CHARACTERS_COUNT);
            }
        }
        return entry;
    }
    exports.removeLeadingDotSegment = removeLeadingDotSegment;
},
/* fast-glob/out/utils/pattern.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.matchAny = exports.convertPatternsToRe = exports.makeRe = exports.getPatternParts = exports.expandBraceExpansion = exports.expandPatternsWithBraceExpansion = exports.isAffectDepthOfReadingPattern = exports.endsWithSlashGlobStar = exports.hasGlobStar = exports.getBaseDirectory = exports.isPatternRelatedToParentDirectory = exports.getPatternsOutsideCurrentDirectory = exports.getPatternsInsideCurrentDirectory = exports.getPositivePatterns = exports.getNegativePatterns = exports.isPositivePattern = exports.isNegativePattern = exports.convertToNegativePattern = exports.convertToPositivePattern = exports.isDynamicPattern = exports.isStaticPattern = void 0;
    const path = require("path");
    const globParent = require(282) /* glob-parent */;
    const micromatch = require(1104) /* micromatch */;
    const GLOBSTAR = '**';
    const ESCAPE_SYMBOL = '\\';
    const COMMON_GLOB_SYMBOLS_RE = /[*?]|^!/;
    const REGEX_CHARACTER_CLASS_SYMBOLS_RE = /\[[^[]*]/;
    const REGEX_GROUP_SYMBOLS_RE = /(?:^|[^!*+?@])\([^(]*\|[^|]*\)/;
    const GLOB_EXTENSION_SYMBOLS_RE = /[!*+?@]\([^(]*\)/;
    const BRACE_EXPANSION_SEPARATORS_RE = /,|\.\./;
    function isStaticPattern(pattern, options = {}) {
        return !isDynamicPattern(pattern, options);
    }
    exports.isStaticPattern = isStaticPattern;
    function isDynamicPattern(pattern, options = {}) {
        /**
         * A special case with an empty string is necessary for matching patterns that start with a forward slash.
         * An empty string cannot be a dynamic pattern.
         * For example, the pattern `/lib/*` will be spread into parts: '', 'lib', '*'.
         */
        if (pattern === '') {
            return false;
        }
        /**
         * When the `caseSensitiveMatch` option is disabled, all patterns must be marked as dynamic, because we cannot check
         * filepath directly (without read directory).
         */
        if (options.caseSensitiveMatch === false || pattern.includes(ESCAPE_SYMBOL)) {
            return true;
        }
        if (COMMON_GLOB_SYMBOLS_RE.test(pattern) || REGEX_CHARACTER_CLASS_SYMBOLS_RE.test(pattern) || REGEX_GROUP_SYMBOLS_RE.test(pattern)) {
            return true;
        }
        if (options.extglob !== false && GLOB_EXTENSION_SYMBOLS_RE.test(pattern)) {
            return true;
        }
        if (options.braceExpansion !== false && hasBraceExpansion(pattern)) {
            return true;
        }
        return false;
    }
    exports.isDynamicPattern = isDynamicPattern;
    function hasBraceExpansion(pattern) {
        const openingBraceIndex = pattern.indexOf('{');
        if (openingBraceIndex === -1) {
            return false;
        }
        const closingBraceIndex = pattern.indexOf('}', openingBraceIndex + 1);
        if (closingBraceIndex === -1) {
            return false;
        }
        const braceContent = pattern.slice(openingBraceIndex, closingBraceIndex);
        return BRACE_EXPANSION_SEPARATORS_RE.test(braceContent);
    }
    function convertToPositivePattern(pattern) {
        return isNegativePattern(pattern) ? pattern.slice(1) : pattern;
    }
    exports.convertToPositivePattern = convertToPositivePattern;
    function convertToNegativePattern(pattern) {
        return '!' + pattern;
    }
    exports.convertToNegativePattern = convertToNegativePattern;
    function isNegativePattern(pattern) {
        return pattern.startsWith('!') && pattern[1] !== '(';
    }
    exports.isNegativePattern = isNegativePattern;
    function isPositivePattern(pattern) {
        return !isNegativePattern(pattern);
    }
    exports.isPositivePattern = isPositivePattern;
    function getNegativePatterns(patterns) {
        return patterns.filter(isNegativePattern);
    }
    exports.getNegativePatterns = getNegativePatterns;
    function getPositivePatterns(patterns) {
        return patterns.filter(isPositivePattern);
    }
    exports.getPositivePatterns = getPositivePatterns;
    /**
     * Returns patterns that can be applied inside the current directory.
     *
     * @example
     * // ['./*', '*', 'a/*']
     * getPatternsInsideCurrentDirectory(['./*', '*', 'a/*', '../*', './../*'])
     */
    function getPatternsInsideCurrentDirectory(patterns) {
        return patterns.filter((pattern) => !isPatternRelatedToParentDirectory(pattern));
    }
    exports.getPatternsInsideCurrentDirectory = getPatternsInsideCurrentDirectory;
    /**
     * Returns patterns to be expanded relative to (outside) the current directory.
     *
     * @example
     * // ['../*', './../*']
     * getPatternsInsideCurrentDirectory(['./*', '*', 'a/*', '../*', './../*'])
     */
    function getPatternsOutsideCurrentDirectory(patterns) {
        return patterns.filter(isPatternRelatedToParentDirectory);
    }
    exports.getPatternsOutsideCurrentDirectory = getPatternsOutsideCurrentDirectory;
    function isPatternRelatedToParentDirectory(pattern) {
        return pattern.startsWith('..') || pattern.startsWith('./..');
    }
    exports.isPatternRelatedToParentDirectory = isPatternRelatedToParentDirectory;
    function getBaseDirectory(pattern) {
        return globParent(pattern, { flipBackslashes: false });
    }
    exports.getBaseDirectory = getBaseDirectory;
    function hasGlobStar(pattern) {
        return pattern.includes(GLOBSTAR);
    }
    exports.hasGlobStar = hasGlobStar;
    function endsWithSlashGlobStar(pattern) {
        return pattern.endsWith('/' + GLOBSTAR);
    }
    exports.endsWithSlashGlobStar = endsWithSlashGlobStar;
    function isAffectDepthOfReadingPattern(pattern) {
        const basename = path.basename(pattern);
        return endsWithSlashGlobStar(pattern) || isStaticPattern(basename);
    }
    exports.isAffectDepthOfReadingPattern = isAffectDepthOfReadingPattern;
    function expandPatternsWithBraceExpansion(patterns) {
        return patterns.reduce((collection, pattern) => {
            return collection.concat(expandBraceExpansion(pattern));
        }, []);
    }
    exports.expandPatternsWithBraceExpansion = expandPatternsWithBraceExpansion;
    function expandBraceExpansion(pattern) {
        return micromatch.braces(pattern, {
            expand: true,
            nodupes: true
        });
    }
    exports.expandBraceExpansion = expandBraceExpansion;
    function getPatternParts(pattern, options) {
        let { parts } = micromatch.scan(pattern, Object.assign(Object.assign({}, options), { parts: true }));
        /**
         * The scan method returns an empty array in some cases.
         * See micromatch/picomatch#58 for more details.
         */
        if (parts.length === 0) {
            parts = [pattern];
        }
        /**
         * The scan method does not return an empty part for the pattern with a forward slash.
         * This is another part of micromatch/picomatch#58.
         */
        if (parts[0].startsWith('/')) {
            parts[0] = parts[0].slice(1);
            parts.unshift('');
        }
        return parts;
    }
    exports.getPatternParts = getPatternParts;
    function makeRe(pattern, options) {
        return micromatch.makeRe(pattern, options);
    }
    exports.makeRe = makeRe;
    function convertPatternsToRe(patterns, options) {
        return patterns.map((pattern) => makeRe(pattern, options));
    }
    exports.convertPatternsToRe = convertPatternsToRe;
    function matchAny(entry, patternsRe) {
        return patternsRe.some((patternRe) => patternRe.test(entry));
    }
    exports.matchAny = matchAny;
},
/* micromatch/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const util = require('util');
    const braces = require(1105) /* braces */;
    const picomatch = require(1115) /* picomatch */;
    const utils = require(1118) /* picomatch/lib/utils */;
    const isEmptyString = val => val === '' || val === './';
    /**
     * Returns an array of strings that match one or more glob patterns.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm(list, patterns[, options]);
     *
     * console.log(mm(['a.js', 'a.txt'], ['*.js']));
     * //=> [ 'a.js' ]
     * ```
     * @param {String|Array<string>} `list` List of strings to match.
     * @param {String|Array<string>} `patterns` One or more glob patterns to use for matching.
     * @param {Object} `options` See available [options](#options)
     * @return {Array} Returns an array of matches
     * @summary false
     * @api public
     */
    const micromatch = (list, patterns, options) => {
        patterns = [].concat(patterns);
        list = [].concat(list);
        let omit = new Set();
        let keep = new Set();
        let items = new Set();
        let negatives = 0;
        let onResult = state => {
            items.add(state.output);
            if (options && options.onResult) {
                options.onResult(state);
            }
        };
        for (let i = 0; i < patterns.length; i++) {
            let isMatch = picomatch(String(patterns[i]), { ...options, onResult }, true);
            let negated = isMatch.state.negated || isMatch.state.negatedExtglob;
            if (negated)
                negatives++;
            for (let item of list) {
                let matched = isMatch(item, true);
                let match = negated ? !matched.isMatch : matched.isMatch;
                if (!match)
                    continue;
                if (negated) {
                    omit.add(matched.output);
                }
                else {
                    omit.delete(matched.output);
                    keep.add(matched.output);
                }
            }
        }
        let result = negatives === patterns.length ? [...items] : [...keep];
        let matches = result.filter(item => !omit.has(item));
        if (options && matches.length === 0) {
            if (options.failglob === true) {
                throw new Error(`No matches found for "${patterns.join(', ')}"`);
            }
            if (options.nonull === true || options.nullglob === true) {
                return options.unescape ? patterns.map(p => p.replace(/\\/g, '')) : patterns;
            }
        }
        return matches;
    };
    /**
     * Backwards compatibility
     */
    micromatch.match = micromatch;
    /**
     * Returns a matcher function from the given glob `pattern` and `options`.
     * The returned function takes a string to match as its only argument and returns
     * true if the string is a match.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm.matcher(pattern[, options]);
     *
     * const isMatch = mm.matcher('*.!(*a)');
     * console.log(isMatch('a.a')); //=> false
     * console.log(isMatch('a.b')); //=> true
     * ```
     * @param {String} `pattern` Glob pattern
     * @param {Object} `options`
     * @return {Function} Returns a matcher function.
     * @api public
     */
    micromatch.matcher = (pattern, options) => picomatch(pattern, options);
    /**
     * Returns true if **any** of the given glob `patterns` match the specified `string`.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm.isMatch(string, patterns[, options]);
     *
     * console.log(mm.isMatch('a.a', ['b.*', '*.a'])); //=> true
     * console.log(mm.isMatch('a.a', 'b.*')); //=> false
     * ```
     * @param {String} `str` The string to test.
     * @param {String|Array} `patterns` One or more glob patterns to use for matching.
     * @param {Object} `[options]` See available [options](#options).
     * @return {Boolean} Returns true if any patterns match `str`
     * @api public
     */
    micromatch.isMatch = (str, patterns, options) => picomatch(patterns, options)(str);
    /**
     * Backwards compatibility
     */
    micromatch.any = micromatch.isMatch;
    /**
     * Returns a list of strings that _**do not match any**_ of the given `patterns`.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm.not(list, patterns[, options]);
     *
     * console.log(mm.not(['a.a', 'b.b', 'c.c'], '*.a'));
     * //=> ['b.b', 'c.c']
     * ```
     * @param {Array} `list` Array of strings to match.
     * @param {String|Array} `patterns` One or more glob pattern to use for matching.
     * @param {Object} `options` See available [options](#options) for changing how matches are performed
     * @return {Array} Returns an array of strings that **do not match** the given patterns.
     * @api public
     */
    micromatch.not = (list, patterns, options = {}) => {
        patterns = [].concat(patterns).map(String);
        let result = new Set();
        let items = [];
        let onResult = state => {
            if (options.onResult)
                options.onResult(state);
            items.push(state.output);
        };
        let matches = new Set(micromatch(list, patterns, { ...options, onResult }));
        for (let item of items) {
            if (!matches.has(item)) {
                result.add(item);
            }
        }
        return [...result];
    };
    /**
     * Returns true if the given `string` contains the given pattern. Similar
     * to [.isMatch](#isMatch) but the pattern can match any part of the string.
     *
     * ```js
     * var mm = require('micromatch');
     * // mm.contains(string, pattern[, options]);
     *
     * console.log(mm.contains('aa/bb/cc', '*b'));
     * //=> true
     * console.log(mm.contains('aa/bb/cc', '*d'));
     * //=> false
     * ```
     * @param {String} `str` The string to match.
     * @param {String|Array} `patterns` Glob pattern to use for matching.
     * @param {Object} `options` See available [options](#options) for changing how matches are performed
     * @return {Boolean} Returns true if any of the patterns matches any part of `str`.
     * @api public
     */
    micromatch.contains = (str, pattern, options) => {
        if (typeof str !== 'string') {
            throw new TypeError(`Expected a string: "${util.inspect(str)}"`);
        }
        if (Array.isArray(pattern)) {
            return pattern.some(p => micromatch.contains(str, p, options));
        }
        if (typeof pattern === 'string') {
            if (isEmptyString(str) || isEmptyString(pattern)) {
                return false;
            }
            if (str.includes(pattern) || (str.startsWith('./') && str.slice(2).includes(pattern))) {
                return true;
            }
        }
        return micromatch.isMatch(str, pattern, { ...options, contains: true });
    };
    /**
     * Filter the keys of the given object with the given `glob` pattern
     * and `options`. Does not attempt to match nested keys. If you need this feature,
     * use [glob-object][] instead.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm.matchKeys(object, patterns[, options]);
     *
     * const obj = { aa: 'a', ab: 'b', ac: 'c' };
     * console.log(mm.matchKeys(obj, '*b'));
     * //=> { ab: 'b' }
     * ```
     * @param {Object} `object` The object with keys to filter.
     * @param {String|Array} `patterns` One or more glob patterns to use for matching.
     * @param {Object} `options` See available [options](#options) for changing how matches are performed
     * @return {Object} Returns an object with only keys that match the given patterns.
     * @api public
     */
    micromatch.matchKeys = (obj, patterns, options) => {
        if (!utils.isObject(obj)) {
            throw new TypeError('Expected the first argument to be an object');
        }
        let keys = micromatch(Object.keys(obj), patterns, options);
        let res = {};
        for (let key of keys)
            res[key] = obj[key];
        return res;
    };
    /**
     * Returns true if some of the strings in the given `list` match any of the given glob `patterns`.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm.some(list, patterns[, options]);
     *
     * console.log(mm.some(['foo.js', 'bar.js'], ['*.js', '!foo.js']));
     * // true
     * console.log(mm.some(['foo.js'], ['*.js', '!foo.js']));
     * // false
     * ```
     * @param {String|Array} `list` The string or array of strings to test. Returns as soon as the first match is found.
     * @param {String|Array} `patterns` One or more glob patterns to use for matching.
     * @param {Object} `options` See available [options](#options) for changing how matches are performed
     * @return {Boolean} Returns true if any `patterns` matches any of the strings in `list`
     * @api public
     */
    micromatch.some = (list, patterns, options) => {
        let items = [].concat(list);
        for (let pattern of [].concat(patterns)) {
            let isMatch = picomatch(String(pattern), options);
            if (items.some(item => isMatch(item))) {
                return true;
            }
        }
        return false;
    };
    /**
     * Returns true if every string in the given `list` matches
     * any of the given glob `patterns`.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm.every(list, patterns[, options]);
     *
     * console.log(mm.every('foo.js', ['foo.js']));
     * // true
     * console.log(mm.every(['foo.js', 'bar.js'], ['*.js']));
     * // true
     * console.log(mm.every(['foo.js', 'bar.js'], ['*.js', '!foo.js']));
     * // false
     * console.log(mm.every(['foo.js'], ['*.js', '!foo.js']));
     * // false
     * ```
     * @param {String|Array} `list` The string or array of strings to test.
     * @param {String|Array} `patterns` One or more glob patterns to use for matching.
     * @param {Object} `options` See available [options](#options) for changing how matches are performed
     * @return {Boolean} Returns true if all `patterns` matches all of the strings in `list`
     * @api public
     */
    micromatch.every = (list, patterns, options) => {
        let items = [].concat(list);
        for (let pattern of [].concat(patterns)) {
            let isMatch = picomatch(String(pattern), options);
            if (!items.every(item => isMatch(item))) {
                return false;
            }
        }
        return true;
    };
    /**
     * Returns true if **all** of the given `patterns` match
     * the specified string.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm.all(string, patterns[, options]);
     *
     * console.log(mm.all('foo.js', ['foo.js']));
     * // true
     *
     * console.log(mm.all('foo.js', ['*.js', '!foo.js']));
     * // false
     *
     * console.log(mm.all('foo.js', ['*.js', 'foo.js']));
     * // true
     *
     * console.log(mm.all('foo.js', ['*.js', 'f*', '*o*', '*o.js']));
     * // true
     * ```
     * @param {String|Array} `str` The string to test.
     * @param {String|Array} `patterns` One or more glob patterns to use for matching.
     * @param {Object} `options` See available [options](#options) for changing how matches are performed
     * @return {Boolean} Returns true if any patterns match `str`
     * @api public
     */
    micromatch.all = (str, patterns, options) => {
        if (typeof str !== 'string') {
            throw new TypeError(`Expected a string: "${util.inspect(str)}"`);
        }
        return [].concat(patterns).every(p => picomatch(p, options)(str));
    };
    /**
     * Returns an array of matches captured by `pattern` in `string, or `null` if the pattern did not match.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm.capture(pattern, string[, options]);
     *
     * console.log(mm.capture('test/*.js', 'test/foo.js'));
     * //=> ['foo']
     * console.log(mm.capture('test/*.js', 'foo/bar.css'));
     * //=> null
     * ```
     * @param {String} `glob` Glob pattern to use for matching.
     * @param {String} `input` String to match
     * @param {Object} `options` See available [options](#options) for changing how matches are performed
     * @return {Array|null} Returns an array of captures if the input matches the glob pattern, otherwise `null`.
     * @api public
     */
    micromatch.capture = (glob, input, options) => {
        let posix = utils.isWindows(options);
        let regex = picomatch.makeRe(String(glob), { ...options, capture: true });
        let match = regex.exec(posix ? utils.toPosixSlashes(input) : input);
        if (match) {
            return match.slice(1).map(v => v === void 0 ? '' : v);
        }
    };
    /**
     * Create a regular expression from the given glob `pattern`.
     *
     * ```js
     * const mm = require('micromatch');
     * // mm.makeRe(pattern[, options]);
     *
     * console.log(mm.makeRe('*.js'));
     * //=> /^(?:(\.[\\\/])?(?!\.)(?=.)[^\/]*?\.js)$/
     * ```
     * @param {String} `pattern` A glob pattern to convert to regex.
     * @param {Object} `options`
     * @return {RegExp} Returns a regex created from the given pattern.
     * @api public
     */
    micromatch.makeRe = (...args) => picomatch.makeRe(...args);
    /**
     * Scan a glob pattern to separate the pattern into segments. Used
     * by the [split](#split) method.
     *
     * ```js
     * const mm = require('micromatch');
     * const state = mm.scan(pattern[, options]);
     * ```
     * @param {String} `pattern`
     * @param {Object} `options`
     * @return {Object} Returns an object with
     * @api public
     */
    micromatch.scan = (...args) => picomatch.scan(...args);
    /**
     * Parse a glob pattern to create the source string for a regular
     * expression.
     *
     * ```js
     * const mm = require('micromatch');
     * const state = mm.parse(pattern[, options]);
     * ```
     * @param {String} `glob`
     * @param {Object} `options`
     * @return {Object} Returns an object with useful properties and output to be used as regex source string.
     * @api public
     */
    micromatch.parse = (patterns, options) => {
        let res = [];
        for (let pattern of [].concat(patterns || [])) {
            for (let str of braces(String(pattern), options)) {
                res.push(picomatch.parse(str, options));
            }
        }
        return res;
    };
    /**
     * Process the given brace `pattern`.
     *
     * ```js
     * const { braces } = require('micromatch');
     * console.log(braces('foo/{a,b,c}/bar'));
     * //=> [ 'foo/(a|b|c)/bar' ]
     *
     * console.log(braces('foo/{a,b,c}/bar', { expand: true }));
     * //=> [ 'foo/a/bar', 'foo/b/bar', 'foo/c/bar' ]
     * ```
     * @param {String} `pattern` String with brace pattern to process.
     * @param {Object} `options` Any [options](#options) to change how expansion is performed. See the [braces][] library for all available options.
     * @return {Array}
     * @api public
     */
    micromatch.braces = (pattern, options) => {
        if (typeof pattern !== 'string')
            throw new TypeError('Expected a string');
        if ((options && options.nobrace === true) || !/\{.*\}/.test(pattern)) {
            return [pattern];
        }
        return braces(pattern, options);
    };
    /**
     * Expand braces
     */
    micromatch.braceExpand = (pattern, options) => {
        if (typeof pattern !== 'string')
            throw new TypeError('Expected a string');
        return micromatch.braces(pattern, { ...options, expand: true });
    };
    /**
     * Expose micromatch
     */
    module.exports = micromatch;
},
/* braces/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const stringify = require(1106) /* ./lib/stringify */;
    const compile = require(1108) /* ./lib/compile */;
    const expand = require(1112) /* ./lib/expand */;
    const parse = require(1113) /* ./lib/parse */;
    /**
     * Expand the given pattern or create a regex-compatible string.
     *
     * ```js
     * const braces = require('braces');
     * console.log(braces('{a,b,c}', { compile: true })); //=> ['(a|b|c)']
     * console.log(braces('{a,b,c}')); //=> ['a', 'b', 'c']
     * ```
     * @param {String} `str`
     * @param {Object} `options`
     * @return {String}
     * @api public
     */
    const braces = (input, options = {}) => {
        let output = [];
        if (Array.isArray(input)) {
            for (let pattern of input) {
                let result = braces.create(pattern, options);
                if (Array.isArray(result)) {
                    output.push(...result);
                }
                else {
                    output.push(result);
                }
            }
        }
        else {
            output = [].concat(braces.create(input, options));
        }
        if (options && options.expand === true && options.nodupes === true) {
            output = [...new Set(output)];
        }
        return output;
    };
    /**
     * Parse the given `str` with the given `options`.
     *
     * ```js
     * // braces.parse(pattern, [, options]);
     * const ast = braces.parse('a/{b,c}/d');
     * console.log(ast);
     * ```
     * @param {String} pattern Brace pattern to parse
     * @param {Object} options
     * @return {Object} Returns an AST
     * @api public
     */
    braces.parse = (input, options = {}) => parse(input, options);
    /**
     * Creates a braces string from an AST, or an AST node.
     *
     * ```js
     * const braces = require('braces');
     * let ast = braces.parse('foo/{a,b}/bar');
     * console.log(stringify(ast.nodes[2])); //=> '{a,b}'
     * ```
     * @param {String} `input` Brace pattern or AST.
     * @param {Object} `options`
     * @return {Array} Returns an array of expanded values.
     * @api public
     */
    braces.stringify = (input, options = {}) => {
        if (typeof input === 'string') {
            return stringify(braces.parse(input, options), options);
        }
        return stringify(input, options);
    };
    /**
     * Compiles a brace pattern into a regex-compatible, optimized string.
     * This method is called by the main [braces](#braces) function by default.
     *
     * ```js
     * const braces = require('braces');
     * console.log(braces.compile('a/{b,c}/d'));
     * //=> ['a/(b|c)/d']
     * ```
     * @param {String} `input` Brace pattern or AST.
     * @param {Object} `options`
     * @return {Array} Returns an array of expanded values.
     * @api public
     */
    braces.compile = (input, options = {}) => {
        if (typeof input === 'string') {
            input = braces.parse(input, options);
        }
        return compile(input, options);
    };
    /**
     * Expands a brace pattern into an array. This method is called by the
     * main [braces](#braces) function when `options.expand` is true. Before
     * using this method it's recommended that you read the [performance notes](#performance))
     * and advantages of using [.compile](#compile) instead.
     *
     * ```js
     * const braces = require('braces');
     * console.log(braces.expand('a/{b,c}/d'));
     * //=> ['a/b/d', 'a/c/d'];
     * ```
     * @param {String} `pattern` Brace pattern
     * @param {Object} `options`
     * @return {Array} Returns an array of expanded values.
     * @api public
     */
    braces.expand = (input, options = {}) => {
        if (typeof input === 'string') {
            input = braces.parse(input, options);
        }
        let result = expand(input, options);
        // filter out empty strings if specified
        if (options.noempty === true) {
            result = result.filter(Boolean);
        }
        // filter out duplicates if specified
        if (options.nodupes === true) {
            result = [...new Set(result)];
        }
        return result;
    };
    /**
     * Processes a brace pattern and returns either an expanded array
     * (if `options.expand` is true), a highly optimized regex-compatible string.
     * This method is called by the main [braces](#braces) function.
     *
     * ```js
     * const braces = require('braces');
     * console.log(braces.create('user-{200..300}/project-{a,b,c}-{1..10}'))
     * //=> 'user-(20[0-9]|2[1-9][0-9]|300)/project-(a|b|c)-([1-9]|10)'
     * ```
     * @param {String} `pattern` Brace pattern
     * @param {Object} `options`
     * @return {Array} Returns an array of expanded values.
     * @api public
     */
    braces.create = (input, options = {}) => {
        if (input === '' || input.length < 3) {
            return [input];
        }
        return options.expand !== true
            ? braces.compile(input, options)
            : braces.expand(input, options);
    };
    /**
     * Expose "braces"
     */
    module.exports = braces;
},
/* braces/lib/stringify.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const utils = require(1107) /* ./utils */;
    module.exports = (ast, options = {}) => {
        let stringify = (node, parent = {}) => {
            let invalidBlock = options.escapeInvalid && utils.isInvalidBrace(parent);
            let invalidNode = node.invalid === true && options.escapeInvalid === true;
            let output = '';
            if (node.value) {
                if ((invalidBlock || invalidNode) && utils.isOpenOrClose(node)) {
                    return '\\' + node.value;
                }
                return node.value;
            }
            if (node.value) {
                return node.value;
            }
            if (node.nodes) {
                for (let child of node.nodes) {
                    output += stringify(child);
                }
            }
            return output;
        };
        return stringify(ast);
    };
},
/* braces/lib/utils.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    exports.isInteger = num => {
        if (typeof num === 'number') {
            return Number.isInteger(num);
        }
        if (typeof num === 'string' && num.trim() !== '') {
            return Number.isInteger(Number(num));
        }
        return false;
    };
    /**
     * Find a node of the given type
     */
    exports.find = (node, type) => node.nodes.find(node => node.type === type);
    /**
     * Find a node of the given type
     */
    exports.exceedsLimit = (min, max, step = 1, limit) => {
        if (limit === false)
            return false;
        if (!exports.isInteger(min) || !exports.isInteger(max))
            return false;
        return ((Number(max) - Number(min)) / Number(step)) >= limit;
    };
    /**
     * Escape the given node with '\\' before node.value
     */
    exports.escapeNode = (block, n = 0, type) => {
        let node = block.nodes[n];
        if (!node)
            return;
        if ((type && node.type === type) || node.type === 'open' || node.type === 'close') {
            if (node.escaped !== true) {
                node.value = '\\' + node.value;
                node.escaped = true;
            }
        }
    };
    /**
     * Returns true if the given brace node should be enclosed in literal braces
     */
    exports.encloseBrace = node => {
        if (node.type !== 'brace')
            return false;
        if ((node.commas >> 0 + node.ranges >> 0) === 0) {
            node.invalid = true;
            return true;
        }
        return false;
    };
    /**
     * Returns true if a brace node is invalid.
     */
    exports.isInvalidBrace = block => {
        if (block.type !== 'brace')
            return false;
        if (block.invalid === true || block.dollar)
            return true;
        if ((block.commas >> 0 + block.ranges >> 0) === 0) {
            block.invalid = true;
            return true;
        }
        if (block.open !== true || block.close !== true) {
            block.invalid = true;
            return true;
        }
        return false;
    };
    /**
     * Returns true if a node is an open or close node
     */
    exports.isOpenOrClose = node => {
        if (node.type === 'open' || node.type === 'close') {
            return true;
        }
        return node.open === true || node.close === true;
    };
    /**
     * Reduce an array of text nodes.
     */
    exports.reduce = nodes => nodes.reduce((acc, node) => {
        if (node.type === 'text')
            acc.push(node.value);
        if (node.type === 'range')
            node.type = 'text';
        return acc;
    }, []);
    /**
     * Flatten an array
     */
    exports.flatten = (...args) => {
        const result = [];
        const flat = arr => {
            for (let i = 0; i < arr.length; i++) {
                let ele = arr[i];
                Array.isArray(ele) ? flat(ele, result) : ele !== void 0 && result.push(ele);
            }
            return result;
        };
        flat(args);
        return result;
    };
},
/* braces/lib/compile.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const fill = require(1109) /* fill-range */;
    const utils = require(1107) /* ./utils */;
    const compile = (ast, options = {}) => {
        let walk = (node, parent = {}) => {
            let invalidBlock = utils.isInvalidBrace(parent);
            let invalidNode = node.invalid === true && options.escapeInvalid === true;
            let invalid = invalidBlock === true || invalidNode === true;
            let prefix = options.escapeInvalid === true ? '\\' : '';
            let output = '';
            if (node.isOpen === true) {
                return prefix + node.value;
            }
            if (node.isClose === true) {
                return prefix + node.value;
            }
            if (node.type === 'open') {
                return invalid ? (prefix + node.value) : '(';
            }
            if (node.type === 'close') {
                return invalid ? (prefix + node.value) : ')';
            }
            if (node.type === 'comma') {
                return node.prev.type === 'comma' ? '' : (invalid ? node.value : '|');
            }
            if (node.value) {
                return node.value;
            }
            if (node.nodes && node.ranges > 0) {
                let args = utils.reduce(node.nodes);
                let range = fill(...args, { ...options, wrap: false, toRegex: true });
                if (range.length !== 0) {
                    return args.length > 1 && range.length > 1 ? `(${range})` : range;
                }
            }
            if (node.nodes) {
                for (let child of node.nodes) {
                    output += walk(child, node);
                }
            }
            return output;
        };
        return walk(ast);
    };
    module.exports = compile;
},
/* fill-range/index.js */ function _(require, module, exports, __esModule, __esExport) {/*!
     * fill-range <https://github.com/jonschlinkert/fill-range>
     *
     * Copyright (c) 2014-present, Jon Schlinkert.
     * Licensed under the MIT License.
     */
    'use strict';
    const util = require('util');
    const toRegexRange = require(1110) /* to-regex-range */;
    const isObject = val => val !== null && typeof val === 'object' && !Array.isArray(val);
    const transform = toNumber => {
        return value => toNumber === true ? Number(value) : String(value);
    };
    const isValidValue = value => {
        return typeof value === 'number' || (typeof value === 'string' && value !== '');
    };
    const isNumber = num => Number.isInteger(+num);
    const zeros = input => {
        let value = `${input}`;
        let index = -1;
        if (value[0] === '-')
            value = value.slice(1);
        if (value === '0')
            return false;
        while (value[++index] === '0')
            ;
        return index > 0;
    };
    const stringify = (start, end, options) => {
        if (typeof start === 'string' || typeof end === 'string') {
            return true;
        }
        return options.stringify === true;
    };
    const pad = (input, maxLength, toNumber) => {
        if (maxLength > 0) {
            let dash = input[0] === '-' ? '-' : '';
            if (dash)
                input = input.slice(1);
            input = (dash + input.padStart(dash ? maxLength - 1 : maxLength, '0'));
        }
        if (toNumber === false) {
            return String(input);
        }
        return input;
    };
    const toMaxLen = (input, maxLength) => {
        let negative = input[0] === '-' ? '-' : '';
        if (negative) {
            input = input.slice(1);
            maxLength--;
        }
        while (input.length < maxLength)
            input = '0' + input;
        return negative ? ('-' + input) : input;
    };
    const toSequence = (parts, options) => {
        parts.negatives.sort((a, b) => a < b ? -1 : a > b ? 1 : 0);
        parts.positives.sort((a, b) => a < b ? -1 : a > b ? 1 : 0);
        let prefix = options.capture ? '' : '?:';
        let positives = '';
        let negatives = '';
        let result;
        if (parts.positives.length) {
            positives = parts.positives.join('|');
        }
        if (parts.negatives.length) {
            negatives = `-(${prefix}${parts.negatives.join('|')})`;
        }
        if (positives && negatives) {
            result = `${positives}|${negatives}`;
        }
        else {
            result = positives || negatives;
        }
        if (options.wrap) {
            return `(${prefix}${result})`;
        }
        return result;
    };
    const toRange = (a, b, isNumbers, options) => {
        if (isNumbers) {
            return toRegexRange(a, b, { wrap: false, ...options });
        }
        let start = String.fromCharCode(a);
        if (a === b)
            return start;
        let stop = String.fromCharCode(b);
        return `[${start}-${stop}]`;
    };
    const toRegex = (start, end, options) => {
        if (Array.isArray(start)) {
            let wrap = options.wrap === true;
            let prefix = options.capture ? '' : '?:';
            return wrap ? `(${prefix}${start.join('|')})` : start.join('|');
        }
        return toRegexRange(start, end, options);
    };
    const rangeError = (...args) => {
        return new RangeError('Invalid range arguments: ' + util.inspect(...args));
    };
    const invalidRange = (start, end, options) => {
        if (options.strictRanges === true)
            throw rangeError([start, end]);
        return [];
    };
    const invalidStep = (step, options) => {
        if (options.strictRanges === true) {
            throw new TypeError(`Expected step "${step}" to be a number`);
        }
        return [];
    };
    const fillNumbers = (start, end, step = 1, options = {}) => {
        let a = Number(start);
        let b = Number(end);
        if (!Number.isInteger(a) || !Number.isInteger(b)) {
            if (options.strictRanges === true)
                throw rangeError([start, end]);
            return [];
        }
        // fix negative zero
        if (a === 0)
            a = 0;
        if (b === 0)
            b = 0;
        let descending = a > b;
        let startString = String(start);
        let endString = String(end);
        let stepString = String(step);
        step = Math.max(Math.abs(step), 1);
        let padded = zeros(startString) || zeros(endString) || zeros(stepString);
        let maxLen = padded ? Math.max(startString.length, endString.length, stepString.length) : 0;
        let toNumber = padded === false && stringify(start, end, options) === false;
        let format = options.transform || transform(toNumber);
        if (options.toRegex && step === 1) {
            return toRange(toMaxLen(start, maxLen), toMaxLen(end, maxLen), true, options);
        }
        let parts = { negatives: [], positives: [] };
        let push = num => parts[num < 0 ? 'negatives' : 'positives'].push(Math.abs(num));
        let range = [];
        let index = 0;
        while (descending ? a >= b : a <= b) {
            if (options.toRegex === true && step > 1) {
                push(a);
            }
            else {
                range.push(pad(format(a, index), maxLen, toNumber));
            }
            a = descending ? a - step : a + step;
            index++;
        }
        if (options.toRegex === true) {
            return step > 1
                ? toSequence(parts, options)
                : toRegex(range, null, { wrap: false, ...options });
        }
        return range;
    };
    const fillLetters = (start, end, step = 1, options = {}) => {
        if ((!isNumber(start) && start.length > 1) || (!isNumber(end) && end.length > 1)) {
            return invalidRange(start, end, options);
        }
        let format = options.transform || (val => String.fromCharCode(val));
        let a = `${start}`.charCodeAt(0);
        let b = `${end}`.charCodeAt(0);
        let descending = a > b;
        let min = Math.min(a, b);
        let max = Math.max(a, b);
        if (options.toRegex && step === 1) {
            return toRange(min, max, false, options);
        }
        let range = [];
        let index = 0;
        while (descending ? a >= b : a <= b) {
            range.push(format(a, index));
            a = descending ? a - step : a + step;
            index++;
        }
        if (options.toRegex === true) {
            return toRegex(range, null, { wrap: false, options });
        }
        return range;
    };
    const fill = (start, end, step, options = {}) => {
        if (end == null && isValidValue(start)) {
            return [start];
        }
        if (!isValidValue(start) || !isValidValue(end)) {
            return invalidRange(start, end, options);
        }
        if (typeof step === 'function') {
            return fill(start, end, 1, { transform: step });
        }
        if (isObject(step)) {
            return fill(start, end, 0, step);
        }
        let opts = { ...options };
        if (opts.capture === true)
            opts.wrap = true;
        step = step || opts.step || 1;
        if (!isNumber(step)) {
            if (step != null && !isObject(step))
                return invalidStep(step, opts);
            return fill(start, end, 1, step);
        }
        if (isNumber(start) && isNumber(end)) {
            return fillNumbers(start, end, step, opts);
        }
        return fillLetters(start, end, Math.max(Math.abs(step), 1), opts);
    };
    module.exports = fill;
},
/* to-regex-range/index.js */ function _(require, module, exports, __esModule, __esExport) {/*!
     * to-regex-range <https://github.com/micromatch/to-regex-range>
     *
     * Copyright (c) 2015-present, Jon Schlinkert.
     * Released under the MIT License.
     */
    'use strict';
    const isNumber = require(1111) /* is-number */;
    const toRegexRange = (min, max, options) => {
        if (isNumber(min) === false) {
            throw new TypeError('toRegexRange: expected the first argument to be a number');
        }
        if (max === void 0 || min === max) {
            return String(min);
        }
        if (isNumber(max) === false) {
            throw new TypeError('toRegexRange: expected the second argument to be a number.');
        }
        let opts = { relaxZeros: true, ...options };
        if (typeof opts.strictZeros === 'boolean') {
            opts.relaxZeros = opts.strictZeros === false;
        }
        let relax = String(opts.relaxZeros);
        let shorthand = String(opts.shorthand);
        let capture = String(opts.capture);
        let wrap = String(opts.wrap);
        let cacheKey = min + ':' + max + '=' + relax + shorthand + capture + wrap;
        if (toRegexRange.cache.hasOwnProperty(cacheKey)) {
            return toRegexRange.cache[cacheKey].result;
        }
        let a = Math.min(min, max);
        let b = Math.max(min, max);
        if (Math.abs(a - b) === 1) {
            let result = min + '|' + max;
            if (opts.capture) {
                return `(${result})`;
            }
            if (opts.wrap === false) {
                return result;
            }
            return `(?:${result})`;
        }
        let isPadded = hasPadding(min) || hasPadding(max);
        let state = { min, max, a, b };
        let positives = [];
        let negatives = [];
        if (isPadded) {
            state.isPadded = isPadded;
            state.maxLen = String(state.max).length;
        }
        if (a < 0) {
            let newMin = b < 0 ? Math.abs(b) : 1;
            negatives = splitToPatterns(newMin, Math.abs(a), state, opts);
            a = state.a = 0;
        }
        if (b >= 0) {
            positives = splitToPatterns(a, b, state, opts);
        }
        state.negatives = negatives;
        state.positives = positives;
        state.result = collatePatterns(negatives, positives, opts);
        if (opts.capture === true) {
            state.result = `(${state.result})`;
        }
        else if (opts.wrap !== false && (positives.length + negatives.length) > 1) {
            state.result = `(?:${state.result})`;
        }
        toRegexRange.cache[cacheKey] = state;
        return state.result;
    };
    function collatePatterns(neg, pos, options) {
        let onlyNegative = filterPatterns(neg, pos, '-', false, options) || [];
        let onlyPositive = filterPatterns(pos, neg, '', false, options) || [];
        let intersected = filterPatterns(neg, pos, '-?', true, options) || [];
        let subpatterns = onlyNegative.concat(intersected).concat(onlyPositive);
        return subpatterns.join('|');
    }
    function splitToRanges(min, max) {
        let nines = 1;
        let zeros = 1;
        let stop = countNines(min, nines);
        let stops = new Set([max]);
        while (min <= stop && stop <= max) {
            stops.add(stop);
            nines += 1;
            stop = countNines(min, nines);
        }
        stop = countZeros(max + 1, zeros) - 1;
        while (min < stop && stop <= max) {
            stops.add(stop);
            zeros += 1;
            stop = countZeros(max + 1, zeros) - 1;
        }
        stops = [...stops];
        stops.sort(compare);
        return stops;
    }
    /**
     * Convert a range to a regex pattern
     * @param {Number} `start`
     * @param {Number} `stop`
     * @return {String}
     */
    function rangeToPattern(start, stop, options) {
        if (start === stop) {
            return { pattern: start, count: [], digits: 0 };
        }
        let zipped = zip(start, stop);
        let digits = zipped.length;
        let pattern = '';
        let count = 0;
        for (let i = 0; i < digits; i++) {
            let [startDigit, stopDigit] = zipped[i];
            if (startDigit === stopDigit) {
                pattern += startDigit;
            }
            else if (startDigit !== '0' || stopDigit !== '9') {
                pattern += toCharacterClass(startDigit, stopDigit, options);
            }
            else {
                count++;
            }
        }
        if (count) {
            pattern += options.shorthand === true ? '\\d' : '[0-9]';
        }
        return { pattern, count: [count], digits };
    }
    function splitToPatterns(min, max, tok, options) {
        let ranges = splitToRanges(min, max);
        let tokens = [];
        let start = min;
        let prev;
        for (let i = 0; i < ranges.length; i++) {
            let max = ranges[i];
            let obj = rangeToPattern(String(start), String(max), options);
            let zeros = '';
            if (!tok.isPadded && prev && prev.pattern === obj.pattern) {
                if (prev.count.length > 1) {
                    prev.count.pop();
                }
                prev.count.push(obj.count[0]);
                prev.string = prev.pattern + toQuantifier(prev.count);
                start = max + 1;
                continue;
            }
            if (tok.isPadded) {
                zeros = padZeros(max, tok, options);
            }
            obj.string = zeros + obj.pattern + toQuantifier(obj.count);
            tokens.push(obj);
            start = max + 1;
            prev = obj;
        }
        return tokens;
    }
    function filterPatterns(arr, comparison, prefix, intersection, options) {
        let result = [];
        for (let ele of arr) {
            let { string } = ele;
            // only push if _both_ are negative...
            if (!intersection && !contains(comparison, 'string', string)) {
                result.push(prefix + string);
            }
            // or _both_ are positive
            if (intersection && contains(comparison, 'string', string)) {
                result.push(prefix + string);
            }
        }
        return result;
    }
    /**
     * Zip strings
     */
    function zip(a, b) {
        let arr = [];
        for (let i = 0; i < a.length; i++)
            arr.push([a[i], b[i]]);
        return arr;
    }
    function compare(a, b) {
        return a > b ? 1 : b > a ? -1 : 0;
    }
    function contains(arr, key, val) {
        return arr.some(ele => ele[key] === val);
    }
    function countNines(min, len) {
        return Number(String(min).slice(0, -len) + '9'.repeat(len));
    }
    function countZeros(integer, zeros) {
        return integer - (integer % Math.pow(10, zeros));
    }
    function toQuantifier(digits) {
        let [start = 0, stop = ''] = digits;
        if (stop || start > 1) {
            return `{${start + (stop ? ',' + stop : '')}}`;
        }
        return '';
    }
    function toCharacterClass(a, b, options) {
        return `[${a}${(b - a === 1) ? '' : '-'}${b}]`;
    }
    function hasPadding(str) {
        return /^-?(0+)\d/.test(str);
    }
    function padZeros(value, tok, options) {
        if (!tok.isPadded) {
            return value;
        }
        let diff = Math.abs(tok.maxLen - String(value).length);
        let relax = options.relaxZeros !== false;
        switch (diff) {
            case 0:
                return '';
            case 1:
                return relax ? '0?' : '0';
            case 2:
                return relax ? '0{0,2}' : '00';
            default: {
                return relax ? `0{0,${diff}}` : `0{${diff}}`;
            }
        }
    }
    /**
     * Cache
     */
    toRegexRange.cache = {};
    toRegexRange.clearCache = () => (toRegexRange.cache = {});
    /**
     * Expose `toRegexRange`
     */
    module.exports = toRegexRange;
},
/* is-number/index.js */ function _(require, module, exports, __esModule, __esExport) {/*!
     * is-number <https://github.com/jonschlinkert/is-number>
     *
     * Copyright (c) 2014-present, Jon Schlinkert.
     * Released under the MIT License.
     */
    'use strict';
    module.exports = function (num) {
        if (typeof num === 'number') {
            return num - num === 0;
        }
        if (typeof num === 'string' && num.trim() !== '') {
            return Number.isFinite ? Number.isFinite(+num) : isFinite(+num);
        }
        return false;
    };
},
/* braces/lib/expand.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const fill = require(1109) /* fill-range */;
    const stringify = require(1106) /* ./stringify */;
    const utils = require(1107) /* ./utils */;
    const append = (queue = '', stash = '', enclose = false) => {
        let result = [];
        queue = [].concat(queue);
        stash = [].concat(stash);
        if (!stash.length)
            return queue;
        if (!queue.length) {
            return enclose ? utils.flatten(stash).map(ele => `{${ele}}`) : stash;
        }
        for (let item of queue) {
            if (Array.isArray(item)) {
                for (let value of item) {
                    result.push(append(value, stash, enclose));
                }
            }
            else {
                for (let ele of stash) {
                    if (enclose === true && typeof ele === 'string')
                        ele = `{${ele}}`;
                    result.push(Array.isArray(ele) ? append(item, ele, enclose) : (item + ele));
                }
            }
        }
        return utils.flatten(result);
    };
    const expand = (ast, options = {}) => {
        let rangeLimit = options.rangeLimit === void 0 ? 1000 : options.rangeLimit;
        let walk = (node, parent = {}) => {
            node.queue = [];
            let p = parent;
            let q = parent.queue;
            while (p.type !== 'brace' && p.type !== 'root' && p.parent) {
                p = p.parent;
                q = p.queue;
            }
            if (node.invalid || node.dollar) {
                q.push(append(q.pop(), stringify(node, options)));
                return;
            }
            if (node.type === 'brace' && node.invalid !== true && node.nodes.length === 2) {
                q.push(append(q.pop(), ['{}']));
                return;
            }
            if (node.nodes && node.ranges > 0) {
                let args = utils.reduce(node.nodes);
                if (utils.exceedsLimit(...args, options.step, rangeLimit)) {
                    throw new RangeError('expanded array length exceeds range limit. Use options.rangeLimit to increase or disable the limit.');
                }
                let range = fill(...args, options);
                if (range.length === 0) {
                    range = stringify(node, options);
                }
                q.push(append(q.pop(), range));
                node.nodes = [];
                return;
            }
            let enclose = utils.encloseBrace(node);
            let queue = node.queue;
            let block = node;
            while (block.type !== 'brace' && block.type !== 'root' && block.parent) {
                block = block.parent;
                queue = block.queue;
            }
            for (let i = 0; i < node.nodes.length; i++) {
                let child = node.nodes[i];
                if (child.type === 'comma' && node.type === 'brace') {
                    if (i === 1)
                        queue.push('');
                    queue.push('');
                    continue;
                }
                if (child.type === 'close') {
                    q.push(append(q.pop(), queue, enclose));
                    continue;
                }
                if (child.value && child.type !== 'open') {
                    queue.push(append(queue.pop(), child.value));
                    continue;
                }
                if (child.nodes) {
                    walk(child, node);
                }
            }
            return queue;
        };
        return utils.flatten(walk(ast));
    };
    module.exports = expand;
},
/* braces/lib/parse.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const stringify = require(1106) /* ./stringify */;
    /**
     * Constants
     */
    const { MAX_LENGTH, CHAR_BACKSLASH, /* \ */ CHAR_BACKTICK, /* ` */ CHAR_COMMA, /* , */ CHAR_DOT, /* . */ CHAR_LEFT_PARENTHESES, /* ( */ CHAR_RIGHT_PARENTHESES, /* ) */ CHAR_LEFT_CURLY_BRACE, /* { */ CHAR_RIGHT_CURLY_BRACE, /* } */ CHAR_LEFT_SQUARE_BRACKET, /* [ */ CHAR_RIGHT_SQUARE_BRACKET, /* ] */ CHAR_DOUBLE_QUOTE, /* " */ CHAR_SINGLE_QUOTE, /* ' */ CHAR_NO_BREAK_SPACE, CHAR_ZERO_WIDTH_NOBREAK_SPACE } = require(1114) /* ./constants */;
    /**
     * parse
     */
    const parse = (input, options = {}) => {
        if (typeof input !== 'string') {
            throw new TypeError('Expected a string');
        }
        let opts = options || {};
        let max = typeof opts.maxLength === 'number' ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
        if (input.length > max) {
            throw new SyntaxError(`Input length (${input.length}), exceeds max characters (${max})`);
        }
        let ast = { type: 'root', input, nodes: [] };
        let stack = [ast];
        let block = ast;
        let prev = ast;
        let brackets = 0;
        let length = input.length;
        let index = 0;
        let depth = 0;
        let value;
        let memo = {};
        /**
         * Helpers
         */
        const advance = () => input[index++];
        const push = node => {
            if (node.type === 'text' && prev.type === 'dot') {
                prev.type = 'text';
            }
            if (prev && prev.type === 'text' && node.type === 'text') {
                prev.value += node.value;
                return;
            }
            block.nodes.push(node);
            node.parent = block;
            node.prev = prev;
            prev = node;
            return node;
        };
        push({ type: 'bos' });
        while (index < length) {
            block = stack[stack.length - 1];
            value = advance();
            /**
             * Invalid chars
             */
            if (value === CHAR_ZERO_WIDTH_NOBREAK_SPACE || value === CHAR_NO_BREAK_SPACE) {
                continue;
            }
            /**
             * Escaped chars
             */
            if (value === CHAR_BACKSLASH) {
                push({ type: 'text', value: (options.keepEscaping ? value : '') + advance() });
                continue;
            }
            /**
             * Right square bracket (literal): ']'
             */
            if (value === CHAR_RIGHT_SQUARE_BRACKET) {
                push({ type: 'text', value: '\\' + value });
                continue;
            }
            /**
             * Left square bracket: '['
             */
            if (value === CHAR_LEFT_SQUARE_BRACKET) {
                brackets++;
                let closed = true;
                let next;
                while (index < length && (next = advance())) {
                    value += next;
                    if (next === CHAR_LEFT_SQUARE_BRACKET) {
                        brackets++;
                        continue;
                    }
                    if (next === CHAR_BACKSLASH) {
                        value += advance();
                        continue;
                    }
                    if (next === CHAR_RIGHT_SQUARE_BRACKET) {
                        brackets--;
                        if (brackets === 0) {
                            break;
                        }
                    }
                }
                push({ type: 'text', value });
                continue;
            }
            /**
             * Parentheses
             */
            if (value === CHAR_LEFT_PARENTHESES) {
                block = push({ type: 'paren', nodes: [] });
                stack.push(block);
                push({ type: 'text', value });
                continue;
            }
            if (value === CHAR_RIGHT_PARENTHESES) {
                if (block.type !== 'paren') {
                    push({ type: 'text', value });
                    continue;
                }
                block = stack.pop();
                push({ type: 'text', value });
                block = stack[stack.length - 1];
                continue;
            }
            /**
             * Quotes: '|"|`
             */
            if (value === CHAR_DOUBLE_QUOTE || value === CHAR_SINGLE_QUOTE || value === CHAR_BACKTICK) {
                let open = value;
                let next;
                if (options.keepQuotes !== true) {
                    value = '';
                }
                while (index < length && (next = advance())) {
                    if (next === CHAR_BACKSLASH) {
                        value += next + advance();
                        continue;
                    }
                    if (next === open) {
                        if (options.keepQuotes === true)
                            value += next;
                        break;
                    }
                    value += next;
                }
                push({ type: 'text', value });
                continue;
            }
            /**
             * Left curly brace: '{'
             */
            if (value === CHAR_LEFT_CURLY_BRACE) {
                depth++;
                let dollar = prev.value && prev.value.slice(-1) === '$' || block.dollar === true;
                let brace = {
                    type: 'brace',
                    open: true,
                    close: false,
                    dollar,
                    depth,
                    commas: 0,
                    ranges: 0,
                    nodes: []
                };
                block = push(brace);
                stack.push(block);
                push({ type: 'open', value });
                continue;
            }
            /**
             * Right curly brace: '}'
             */
            if (value === CHAR_RIGHT_CURLY_BRACE) {
                if (block.type !== 'brace') {
                    push({ type: 'text', value });
                    continue;
                }
                let type = 'close';
                block = stack.pop();
                block.close = true;
                push({ type, value });
                depth--;
                block = stack[stack.length - 1];
                continue;
            }
            /**
             * Comma: ','
             */
            if (value === CHAR_COMMA && depth > 0) {
                if (block.ranges > 0) {
                    block.ranges = 0;
                    let open = block.nodes.shift();
                    block.nodes = [open, { type: 'text', value: stringify(block) }];
                }
                push({ type: 'comma', value });
                block.commas++;
                continue;
            }
            /**
             * Dot: '.'
             */
            if (value === CHAR_DOT && depth > 0 && block.commas === 0) {
                let siblings = block.nodes;
                if (depth === 0 || siblings.length === 0) {
                    push({ type: 'text', value });
                    continue;
                }
                if (prev.type === 'dot') {
                    block.range = [];
                    prev.value += value;
                    prev.type = 'range';
                    if (block.nodes.length !== 3 && block.nodes.length !== 5) {
                        block.invalid = true;
                        block.ranges = 0;
                        prev.type = 'text';
                        continue;
                    }
                    block.ranges++;
                    block.args = [];
                    continue;
                }
                if (prev.type === 'range') {
                    siblings.pop();
                    let before = siblings[siblings.length - 1];
                    before.value += prev.value + value;
                    prev = before;
                    block.ranges--;
                    continue;
                }
                push({ type: 'dot', value });
                continue;
            }
            /**
             * Text
             */
            push({ type: 'text', value });
        }
        // Mark imbalanced braces and brackets as invalid
        do {
            block = stack.pop();
            if (block.type !== 'root') {
                block.nodes.forEach(node => {
                    if (!node.nodes) {
                        if (node.type === 'open')
                            node.isOpen = true;
                        if (node.type === 'close')
                            node.isClose = true;
                        if (!node.nodes)
                            node.type = 'text';
                        node.invalid = true;
                    }
                });
                // get the location of the block on parent.nodes (block's siblings)
                let parent = stack[stack.length - 1];
                let index = parent.nodes.indexOf(block);
                // replace the (invalid) block with it's nodes
                parent.nodes.splice(index, 1, ...block.nodes);
            }
        } while (stack.length > 0);
        push({ type: 'eos' });
        return ast;
    };
    module.exports = parse;
},
/* braces/lib/constants.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = {
        MAX_LENGTH: 1024 * 64,
        // Digits
        CHAR_0: '0',
        CHAR_9: '9',
        // Alphabet chars.
        CHAR_UPPERCASE_A: 'A',
        CHAR_LOWERCASE_A: 'a',
        CHAR_UPPERCASE_Z: 'Z',
        CHAR_LOWERCASE_Z: 'z',
        CHAR_LEFT_PARENTHESES: '(',
        CHAR_RIGHT_PARENTHESES: ')',
        CHAR_ASTERISK: '*',
        // Non-alphabetic chars.
        CHAR_AMPERSAND: '&',
        CHAR_AT: '@',
        CHAR_BACKSLASH: '\\',
        CHAR_BACKTICK: '`',
        CHAR_CARRIAGE_RETURN: '\r',
        CHAR_CIRCUMFLEX_ACCENT: '^',
        CHAR_COLON: ':',
        CHAR_COMMA: ',',
        CHAR_DOLLAR: '$',
        CHAR_DOT: '.',
        CHAR_DOUBLE_QUOTE: '"',
        CHAR_EQUAL: '=',
        CHAR_EXCLAMATION_MARK: '!',
        CHAR_FORM_FEED: '\f',
        CHAR_FORWARD_SLASH: '/',
        CHAR_HASH: '#',
        CHAR_HYPHEN_MINUS: '-',
        CHAR_LEFT_ANGLE_BRACKET: '<',
        CHAR_LEFT_CURLY_BRACE: '{',
        CHAR_LEFT_SQUARE_BRACKET: '[',
        CHAR_LINE_FEED: '\n',
        CHAR_NO_BREAK_SPACE: '\u00A0',
        CHAR_PERCENT: '%',
        CHAR_PLUS: '+',
        CHAR_QUESTION_MARK: '?',
        CHAR_RIGHT_ANGLE_BRACKET: '>',
        CHAR_RIGHT_CURLY_BRACE: '}',
        CHAR_RIGHT_SQUARE_BRACKET: ']',
        CHAR_SEMICOLON: ';',
        CHAR_SINGLE_QUOTE: '\'',
        CHAR_SPACE: ' ',
        CHAR_TAB: '\t',
        CHAR_UNDERSCORE: '_',
        CHAR_VERTICAL_LINE: '|',
        CHAR_ZERO_WIDTH_NOBREAK_SPACE: '\uFEFF' /* \uFEFF */
    };
},
/* picomatch/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = require(1116) /* ./lib/picomatch */;
},
/* picomatch/lib/picomatch.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const path = require('path');
    const scan = require(1117) /* ./scan */;
    const parse = require(1120) /* ./parse */;
    const utils = require(1118) /* ./utils */;
    const constants = require(1119) /* ./constants */;
    const isObject = val => val && typeof val === 'object' && !Array.isArray(val);
    /**
     * Creates a matcher function from one or more glob patterns. The
     * returned function takes a string to match as its first argument,
     * and returns true if the string is a match. The returned matcher
     * function also takes a boolean as the second argument that, when true,
     * returns an object with additional information.
     *
     * ```js
     * const picomatch = require('picomatch');
     * // picomatch(glob[, options]);
     *
     * const isMatch = picomatch('*.!(*a)');
     * console.log(isMatch('a.a')); //=> false
     * console.log(isMatch('a.b')); //=> true
     * ```
     * @name picomatch
     * @param {String|Array} `globs` One or more glob patterns.
     * @param {Object=} `options`
     * @return {Function=} Returns a matcher function.
     * @api public
     */
    const picomatch = (glob, options, returnState = false) => {
        if (Array.isArray(glob)) {
            const fns = glob.map(input => picomatch(input, options, returnState));
            const arrayMatcher = str => {
                for (const isMatch of fns) {
                    const state = isMatch(str);
                    if (state)
                        return state;
                }
                return false;
            };
            return arrayMatcher;
        }
        const isState = isObject(glob) && glob.tokens && glob.input;
        if (glob === '' || (typeof glob !== 'string' && !isState)) {
            throw new TypeError('Expected pattern to be a non-empty string');
        }
        const opts = options || {};
        const posix = utils.isWindows(options);
        const regex = isState
            ? picomatch.compileRe(glob, options)
            : picomatch.makeRe(glob, options, false, true);
        const state = regex.state;
        delete regex.state;
        let isIgnored = () => false;
        if (opts.ignore) {
            const ignoreOpts = { ...options, ignore: null, onMatch: null, onResult: null };
            isIgnored = picomatch(opts.ignore, ignoreOpts, returnState);
        }
        const matcher = (input, returnObject = false) => {
            const { isMatch, match, output } = picomatch.test(input, regex, options, { glob, posix });
            const result = { glob, state, regex, posix, input, output, match, isMatch };
            if (typeof opts.onResult === 'function') {
                opts.onResult(result);
            }
            if (isMatch === false) {
                result.isMatch = false;
                return returnObject ? result : false;
            }
            if (isIgnored(input)) {
                if (typeof opts.onIgnore === 'function') {
                    opts.onIgnore(result);
                }
                result.isMatch = false;
                return returnObject ? result : false;
            }
            if (typeof opts.onMatch === 'function') {
                opts.onMatch(result);
            }
            return returnObject ? result : true;
        };
        if (returnState) {
            matcher.state = state;
        }
        return matcher;
    };
    /**
     * Test `input` with the given `regex`. This is used by the main
     * `picomatch()` function to test the input string.
     *
     * ```js
     * const picomatch = require('picomatch');
     * // picomatch.test(input, regex[, options]);
     *
     * console.log(picomatch.test('foo/bar', /^(?:([^/]*?)\/([^/]*?))$/));
     * // { isMatch: true, match: [ 'foo/', 'foo', 'bar' ], output: 'foo/bar' }
     * ```
     * @param {String} `input` String to test.
     * @param {RegExp} `regex`
     * @return {Object} Returns an object with matching info.
     * @api public
     */
    picomatch.test = (input, regex, options, { glob, posix } = {}) => {
        if (typeof input !== 'string') {
            throw new TypeError('Expected input to be a string');
        }
        if (input === '') {
            return { isMatch: false, output: '' };
        }
        const opts = options || {};
        const format = opts.format || (posix ? utils.toPosixSlashes : null);
        let match = input === glob;
        let output = (match && format) ? format(input) : input;
        if (match === false) {
            output = format ? format(input) : input;
            match = output === glob;
        }
        if (match === false || opts.capture === true) {
            if (opts.matchBase === true || opts.basename === true) {
                match = picomatch.matchBase(input, regex, options, posix);
            }
            else {
                match = regex.exec(output);
            }
        }
        return { isMatch: Boolean(match), match, output };
    };
    /**
     * Match the basename of a filepath.
     *
     * ```js
     * const picomatch = require('picomatch');
     * // picomatch.matchBase(input, glob[, options]);
     * console.log(picomatch.matchBase('foo/bar.js', '*.js'); // true
     * ```
     * @param {String} `input` String to test.
     * @param {RegExp|String} `glob` Glob pattern or regex created by [.makeRe](#makeRe).
     * @return {Boolean}
     * @api public
     */
    picomatch.matchBase = (input, glob, options, posix = utils.isWindows(options)) => {
        const regex = glob instanceof RegExp ? glob : picomatch.makeRe(glob, options);
        return regex.test(path.basename(input));
    };
    /**
     * Returns true if **any** of the given glob `patterns` match the specified `string`.
     *
     * ```js
     * const picomatch = require('picomatch');
     * // picomatch.isMatch(string, patterns[, options]);
     *
     * console.log(picomatch.isMatch('a.a', ['b.*', '*.a'])); //=> true
     * console.log(picomatch.isMatch('a.a', 'b.*')); //=> false
     * ```
     * @param {String|Array} str The string to test.
     * @param {String|Array} patterns One or more glob patterns to use for matching.
     * @param {Object} [options] See available [options](#options).
     * @return {Boolean} Returns true if any patterns match `str`
     * @api public
     */
    picomatch.isMatch = (str, patterns, options) => picomatch(patterns, options)(str);
    /**
     * Parse a glob pattern to create the source string for a regular
     * expression.
     *
     * ```js
     * const picomatch = require('picomatch');
     * const result = picomatch.parse(pattern[, options]);
     * ```
     * @param {String} `pattern`
     * @param {Object} `options`
     * @return {Object} Returns an object with useful properties and output to be used as a regex source string.
     * @api public
     */
    picomatch.parse = (pattern, options) => {
        if (Array.isArray(pattern))
            return pattern.map(p => picomatch.parse(p, options));
        return parse(pattern, { ...options, fastpaths: false });
    };
    /**
     * Scan a glob pattern to separate the pattern into segments.
     *
     * ```js
     * const picomatch = require('picomatch');
     * // picomatch.scan(input[, options]);
     *
     * const result = picomatch.scan('!./foo/*.js');
     * console.log(result);
     * { prefix: '!./',
     *   input: '!./foo/*.js',
     *   start: 3,
     *   base: 'foo',
     *   glob: '*.js',
     *   isBrace: false,
     *   isBracket: false,
     *   isGlob: true,
     *   isExtglob: false,
     *   isGlobstar: false,
     *   negated: true }
     * ```
     * @param {String} `input` Glob pattern to scan.
     * @param {Object} `options`
     * @return {Object} Returns an object with
     * @api public
     */
    picomatch.scan = (input, options) => scan(input, options);
    /**
     * Compile a regular expression from the `state` object returned by the
     * [parse()](#parse) method.
     *
     * @param {Object} `state`
     * @param {Object} `options`
     * @param {Boolean} `returnOutput` Intended for implementors, this argument allows you to return the raw output from the parser.
     * @param {Boolean} `returnState` Adds the state to a `state` property on the returned regex. Useful for implementors and debugging.
     * @return {RegExp}
     * @api public
     */
    picomatch.compileRe = (state, options, returnOutput = false, returnState = false) => {
        if (returnOutput === true) {
            return state.output;
        }
        const opts = options || {};
        const prepend = opts.contains ? '' : '^';
        const append = opts.contains ? '' : '$';
        let source = `${prepend}(?:${state.output})${append}`;
        if (state && state.negated === true) {
            source = `^(?!${source}).*$`;
        }
        const regex = picomatch.toRegex(source, options);
        if (returnState === true) {
            regex.state = state;
        }
        return regex;
    };
    /**
     * Create a regular expression from a parsed glob pattern.
     *
     * ```js
     * const picomatch = require('picomatch');
     * const state = picomatch.parse('*.js');
     * // picomatch.compileRe(state[, options]);
     *
     * console.log(picomatch.compileRe(state));
     * //=> /^(?:(?!\.)(?=.)[^/]*?\.js)$/
     * ```
     * @param {String} `state` The object returned from the `.parse` method.
     * @param {Object} `options`
     * @param {Boolean} `returnOutput` Implementors may use this argument to return the compiled output, instead of a regular expression. This is not exposed on the options to prevent end-users from mutating the result.
     * @param {Boolean} `returnState` Implementors may use this argument to return the state from the parsed glob with the returned regular expression.
     * @return {RegExp} Returns a regex created from the given pattern.
     * @api public
     */
    picomatch.makeRe = (input, options = {}, returnOutput = false, returnState = false) => {
        if (!input || typeof input !== 'string') {
            throw new TypeError('Expected a non-empty string');
        }
        let parsed = { negated: false, fastpaths: true };
        if (options.fastpaths !== false && (input[0] === '.' || input[0] === '*')) {
            parsed.output = parse.fastpaths(input, options);
        }
        if (!parsed.output) {
            parsed = parse(input, options);
        }
        return picomatch.compileRe(parsed, options, returnOutput, returnState);
    };
    /**
     * Create a regular expression from the given regex source string.
     *
     * ```js
     * const picomatch = require('picomatch');
     * // picomatch.toRegex(source[, options]);
     *
     * const { output } = picomatch.parse('*.js');
     * console.log(picomatch.toRegex(output));
     * //=> /^(?:(?!\.)(?=.)[^/]*?\.js)$/
     * ```
     * @param {String} `source` Regular expression source string.
     * @param {Object} `options`
     * @return {RegExp}
     * @api public
     */
    picomatch.toRegex = (source, options) => {
        try {
            const opts = options || {};
            return new RegExp(source, opts.flags || (opts.nocase ? 'i' : ''));
        }
        catch (err) {
            if (options && options.debug === true)
                throw err;
            return /$^/;
        }
    };
    /**
     * Picomatch constants.
     * @return {Object}
     */
    picomatch.constants = constants;
    /**
     * Expose "picomatch"
     */
    module.exports = picomatch;
},
/* picomatch/lib/scan.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const utils = require(1118) /* ./utils */;
    const { CHAR_ASTERISK, /* * */ CHAR_AT, /* @ */ CHAR_BACKWARD_SLASH, /* \ */ CHAR_COMMA, /* , */ CHAR_DOT, /* . */ CHAR_EXCLAMATION_MARK, /* ! */ CHAR_FORWARD_SLASH, /* / */ CHAR_LEFT_CURLY_BRACE, /* { */ CHAR_LEFT_PARENTHESES, /* ( */ CHAR_LEFT_SQUARE_BRACKET, /* [ */ CHAR_PLUS, /* + */ CHAR_QUESTION_MARK, /* ? */ CHAR_RIGHT_CURLY_BRACE, /* } */ CHAR_RIGHT_PARENTHESES, /* ) */ CHAR_RIGHT_SQUARE_BRACKET /* ] */ } = require(1119) /* ./constants */;
    const isPathSeparator = code => {
        return code === CHAR_FORWARD_SLASH || code === CHAR_BACKWARD_SLASH;
    };
    const depth = token => {
        if (token.isPrefix !== true) {
            token.depth = token.isGlobstar ? Infinity : 1;
        }
    };
    /**
     * Quickly scans a glob pattern and returns an object with a handful of
     * useful properties, like `isGlob`, `path` (the leading non-glob, if it exists),
     * `glob` (the actual pattern), `negated` (true if the path starts with `!` but not
     * with `!(`) and `negatedExtglob` (true if the path starts with `!(`).
     *
     * ```js
     * const pm = require('picomatch');
     * console.log(pm.scan('foo/bar/*.js'));
     * { isGlob: true, input: 'foo/bar/*.js', base: 'foo/bar', glob: '*.js' }
     * ```
     * @param {String} `str`
     * @param {Object} `options`
     * @return {Object} Returns an object with tokens and regex source string.
     * @api public
     */
    const scan = (input, options) => {
        const opts = options || {};
        const length = input.length - 1;
        const scanToEnd = opts.parts === true || opts.scanToEnd === true;
        const slashes = [];
        const tokens = [];
        const parts = [];
        let str = input;
        let index = -1;
        let start = 0;
        let lastIndex = 0;
        let isBrace = false;
        let isBracket = false;
        let isGlob = false;
        let isExtglob = false;
        let isGlobstar = false;
        let braceEscaped = false;
        let backslashes = false;
        let negated = false;
        let negatedExtglob = false;
        let finished = false;
        let braces = 0;
        let prev;
        let code;
        let token = { value: '', depth: 0, isGlob: false };
        const eos = () => index >= length;
        const peek = () => str.charCodeAt(index + 1);
        const advance = () => {
            prev = code;
            return str.charCodeAt(++index);
        };
        while (index < length) {
            code = advance();
            let next;
            if (code === CHAR_BACKWARD_SLASH) {
                backslashes = token.backslashes = true;
                code = advance();
                if (code === CHAR_LEFT_CURLY_BRACE) {
                    braceEscaped = true;
                }
                continue;
            }
            if (braceEscaped === true || code === CHAR_LEFT_CURLY_BRACE) {
                braces++;
                while (eos() !== true && (code = advance())) {
                    if (code === CHAR_BACKWARD_SLASH) {
                        backslashes = token.backslashes = true;
                        advance();
                        continue;
                    }
                    if (code === CHAR_LEFT_CURLY_BRACE) {
                        braces++;
                        continue;
                    }
                    if (braceEscaped !== true && code === CHAR_DOT && (code = advance()) === CHAR_DOT) {
                        isBrace = token.isBrace = true;
                        isGlob = token.isGlob = true;
                        finished = true;
                        if (scanToEnd === true) {
                            continue;
                        }
                        break;
                    }
                    if (braceEscaped !== true && code === CHAR_COMMA) {
                        isBrace = token.isBrace = true;
                        isGlob = token.isGlob = true;
                        finished = true;
                        if (scanToEnd === true) {
                            continue;
                        }
                        break;
                    }
                    if (code === CHAR_RIGHT_CURLY_BRACE) {
                        braces--;
                        if (braces === 0) {
                            braceEscaped = false;
                            isBrace = token.isBrace = true;
                            finished = true;
                            break;
                        }
                    }
                }
                if (scanToEnd === true) {
                    continue;
                }
                break;
            }
            if (code === CHAR_FORWARD_SLASH) {
                slashes.push(index);
                tokens.push(token);
                token = { value: '', depth: 0, isGlob: false };
                if (finished === true)
                    continue;
                if (prev === CHAR_DOT && index === (start + 1)) {
                    start += 2;
                    continue;
                }
                lastIndex = index + 1;
                continue;
            }
            if (opts.noext !== true) {
                const isExtglobChar = code === CHAR_PLUS
                    || code === CHAR_AT
                    || code === CHAR_ASTERISK
                    || code === CHAR_QUESTION_MARK
                    || code === CHAR_EXCLAMATION_MARK;
                if (isExtglobChar === true && peek() === CHAR_LEFT_PARENTHESES) {
                    isGlob = token.isGlob = true;
                    isExtglob = token.isExtglob = true;
                    finished = true;
                    if (code === CHAR_EXCLAMATION_MARK && index === start) {
                        negatedExtglob = true;
                    }
                    if (scanToEnd === true) {
                        while (eos() !== true && (code = advance())) {
                            if (code === CHAR_BACKWARD_SLASH) {
                                backslashes = token.backslashes = true;
                                code = advance();
                                continue;
                            }
                            if (code === CHAR_RIGHT_PARENTHESES) {
                                isGlob = token.isGlob = true;
                                finished = true;
                                break;
                            }
                        }
                        continue;
                    }
                    break;
                }
            }
            if (code === CHAR_ASTERISK) {
                if (prev === CHAR_ASTERISK)
                    isGlobstar = token.isGlobstar = true;
                isGlob = token.isGlob = true;
                finished = true;
                if (scanToEnd === true) {
                    continue;
                }
                break;
            }
            if (code === CHAR_QUESTION_MARK) {
                isGlob = token.isGlob = true;
                finished = true;
                if (scanToEnd === true) {
                    continue;
                }
                break;
            }
            if (code === CHAR_LEFT_SQUARE_BRACKET) {
                while (eos() !== true && (next = advance())) {
                    if (next === CHAR_BACKWARD_SLASH) {
                        backslashes = token.backslashes = true;
                        advance();
                        continue;
                    }
                    if (next === CHAR_RIGHT_SQUARE_BRACKET) {
                        isBracket = token.isBracket = true;
                        isGlob = token.isGlob = true;
                        finished = true;
                        break;
                    }
                }
                if (scanToEnd === true) {
                    continue;
                }
                break;
            }
            if (opts.nonegate !== true && code === CHAR_EXCLAMATION_MARK && index === start) {
                negated = token.negated = true;
                start++;
                continue;
            }
            if (opts.noparen !== true && code === CHAR_LEFT_PARENTHESES) {
                isGlob = token.isGlob = true;
                if (scanToEnd === true) {
                    while (eos() !== true && (code = advance())) {
                        if (code === CHAR_LEFT_PARENTHESES) {
                            backslashes = token.backslashes = true;
                            code = advance();
                            continue;
                        }
                        if (code === CHAR_RIGHT_PARENTHESES) {
                            finished = true;
                            break;
                        }
                    }
                    continue;
                }
                break;
            }
            if (isGlob === true) {
                finished = true;
                if (scanToEnd === true) {
                    continue;
                }
                break;
            }
        }
        if (opts.noext === true) {
            isExtglob = false;
            isGlob = false;
        }
        let base = str;
        let prefix = '';
        let glob = '';
        if (start > 0) {
            prefix = str.slice(0, start);
            str = str.slice(start);
            lastIndex -= start;
        }
        if (base && isGlob === true && lastIndex > 0) {
            base = str.slice(0, lastIndex);
            glob = str.slice(lastIndex);
        }
        else if (isGlob === true) {
            base = '';
            glob = str;
        }
        else {
            base = str;
        }
        if (base && base !== '' && base !== '/' && base !== str) {
            if (isPathSeparator(base.charCodeAt(base.length - 1))) {
                base = base.slice(0, -1);
            }
        }
        if (opts.unescape === true) {
            if (glob)
                glob = utils.removeBackslashes(glob);
            if (base && backslashes === true) {
                base = utils.removeBackslashes(base);
            }
        }
        const state = {
            prefix,
            input,
            start,
            base,
            glob,
            isBrace,
            isBracket,
            isGlob,
            isExtglob,
            isGlobstar,
            negated,
            negatedExtglob
        };
        if (opts.tokens === true) {
            state.maxDepth = 0;
            if (!isPathSeparator(code)) {
                tokens.push(token);
            }
            state.tokens = tokens;
        }
        if (opts.parts === true || opts.tokens === true) {
            let prevIndex;
            for (let idx = 0; idx < slashes.length; idx++) {
                const n = prevIndex ? prevIndex + 1 : start;
                const i = slashes[idx];
                const value = input.slice(n, i);
                if (opts.tokens) {
                    if (idx === 0 && start !== 0) {
                        tokens[idx].isPrefix = true;
                        tokens[idx].value = prefix;
                    }
                    else {
                        tokens[idx].value = value;
                    }
                    depth(tokens[idx]);
                    state.maxDepth += tokens[idx].depth;
                }
                if (idx !== 0 || value !== '') {
                    parts.push(value);
                }
                prevIndex = i;
            }
            if (prevIndex && prevIndex + 1 < input.length) {
                const value = input.slice(prevIndex + 1);
                parts.push(value);
                if (opts.tokens) {
                    tokens[tokens.length - 1].value = value;
                    depth(tokens[tokens.length - 1]);
                    state.maxDepth += tokens[tokens.length - 1].depth;
                }
            }
            state.slashes = slashes;
            state.parts = parts;
        }
        return state;
    };
    module.exports = scan;
},
/* picomatch/lib/utils.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const path = require('path');
    const win32 = process.platform === 'win32';
    const { REGEX_BACKSLASH, REGEX_REMOVE_BACKSLASH, REGEX_SPECIAL_CHARS, REGEX_SPECIAL_CHARS_GLOBAL } = require(1119) /* ./constants */;
    exports.isObject = val => val !== null && typeof val === 'object' && !Array.isArray(val);
    exports.hasRegexChars = str => REGEX_SPECIAL_CHARS.test(str);
    exports.isRegexChar = str => str.length === 1 && exports.hasRegexChars(str);
    exports.escapeRegex = str => str.replace(REGEX_SPECIAL_CHARS_GLOBAL, '\\$1');
    exports.toPosixSlashes = str => str.replace(REGEX_BACKSLASH, '/');
    exports.removeBackslashes = str => {
        return str.replace(REGEX_REMOVE_BACKSLASH, match => {
            return match === '\\' ? '' : match;
        });
    };
    exports.supportsLookbehinds = () => {
        const segs = process.version.slice(1).split('.').map(Number);
        if (segs.length === 3 && segs[0] >= 9 || (segs[0] === 8 && segs[1] >= 10)) {
            return true;
        }
        return false;
    };
    exports.isWindows = options => {
        if (options && typeof options.windows === 'boolean') {
            return options.windows;
        }
        return win32 === true || path.sep === '\\';
    };
    exports.escapeLast = (input, char, lastIdx) => {
        const idx = input.lastIndexOf(char, lastIdx);
        if (idx === -1)
            return input;
        if (input[idx - 1] === '\\')
            return exports.escapeLast(input, char, idx - 1);
        return `${input.slice(0, idx)}\\${input.slice(idx)}`;
    };
    exports.removePrefix = (input, state = {}) => {
        let output = input;
        if (output.startsWith('./')) {
            output = output.slice(2);
            state.prefix = './';
        }
        return output;
    };
    exports.wrapOutput = (input, state = {}, options = {}) => {
        const prepend = options.contains ? '' : '^';
        const append = options.contains ? '' : '$';
        let output = `${prepend}(?:${input})${append}`;
        if (state.negated === true) {
            output = `(?:^(?!${output}).*$)`;
        }
        return output;
    };
},
/* picomatch/lib/constants.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const path = require('path');
    const WIN_SLASH = '\\\\/';
    const WIN_NO_SLASH = `[^${WIN_SLASH}]`;
    /**
     * Posix glob regex
     */
    const DOT_LITERAL = '\\.';
    const PLUS_LITERAL = '\\+';
    const QMARK_LITERAL = '\\?';
    const SLASH_LITERAL = '\\/';
    const ONE_CHAR = '(?=.)';
    const QMARK = '[^/]';
    const END_ANCHOR = `(?:${SLASH_LITERAL}|$)`;
    const START_ANCHOR = `(?:^|${SLASH_LITERAL})`;
    const DOTS_SLASH = `${DOT_LITERAL}{1,2}${END_ANCHOR}`;
    const NO_DOT = `(?!${DOT_LITERAL})`;
    const NO_DOTS = `(?!${START_ANCHOR}${DOTS_SLASH})`;
    const NO_DOT_SLASH = `(?!${DOT_LITERAL}{0,1}${END_ANCHOR})`;
    const NO_DOTS_SLASH = `(?!${DOTS_SLASH})`;
    const QMARK_NO_DOT = `[^.${SLASH_LITERAL}]`;
    const STAR = `${QMARK}*?`;
    const POSIX_CHARS = {
        DOT_LITERAL,
        PLUS_LITERAL,
        QMARK_LITERAL,
        SLASH_LITERAL,
        ONE_CHAR,
        QMARK,
        END_ANCHOR,
        DOTS_SLASH,
        NO_DOT,
        NO_DOTS,
        NO_DOT_SLASH,
        NO_DOTS_SLASH,
        QMARK_NO_DOT,
        STAR,
        START_ANCHOR
    };
    /**
     * Windows glob regex
     */
    const WINDOWS_CHARS = {
        ...POSIX_CHARS,
        SLASH_LITERAL: `[${WIN_SLASH}]`,
        QMARK: WIN_NO_SLASH,
        STAR: `${WIN_NO_SLASH}*?`,
        DOTS_SLASH: `${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$)`,
        NO_DOT: `(?!${DOT_LITERAL})`,
        NO_DOTS: `(?!(?:^|[${WIN_SLASH}])${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$))`,
        NO_DOT_SLASH: `(?!${DOT_LITERAL}{0,1}(?:[${WIN_SLASH}]|$))`,
        NO_DOTS_SLASH: `(?!${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$))`,
        QMARK_NO_DOT: `[^.${WIN_SLASH}]`,
        START_ANCHOR: `(?:^|[${WIN_SLASH}])`,
        END_ANCHOR: `(?:[${WIN_SLASH}]|$)`
    };
    /**
     * POSIX Bracket Regex
     */
    const POSIX_REGEX_SOURCE = {
        alnum: 'a-zA-Z0-9',
        alpha: 'a-zA-Z',
        ascii: '\\x00-\\x7F',
        blank: ' \\t',
        cntrl: '\\x00-\\x1F\\x7F',
        digit: '0-9',
        graph: '\\x21-\\x7E',
        lower: 'a-z',
        print: '\\x20-\\x7E ',
        punct: '\\-!"#$%&\'()\\*+,./:;<=>?@[\\]^_`{|}~',
        space: ' \\t\\r\\n\\v\\f',
        upper: 'A-Z',
        word: 'A-Za-z0-9_',
        xdigit: 'A-Fa-f0-9'
    };
    module.exports = {
        MAX_LENGTH: 1024 * 64,
        POSIX_REGEX_SOURCE,
        // regular expressions
        REGEX_BACKSLASH: /\\(?![*+?^${}(|)[\]])/g,
        REGEX_NON_SPECIAL_CHARS: /^[^@![\].,$*+?^{}()|\\/]+/,
        REGEX_SPECIAL_CHARS: /[-*+?.^${}(|)[\]]/,
        REGEX_SPECIAL_CHARS_BACKREF: /(\\?)((\W)(\3*))/g,
        REGEX_SPECIAL_CHARS_GLOBAL: /([-*+?.^${}(|)[\]])/g,
        REGEX_REMOVE_BACKSLASH: /(?:\[.*?[^\\]\]|\\(?=.))/g,
        // Replace globs with equivalent patterns to reduce parsing time.
        REPLACEMENTS: {
            '***': '*',
            '**/**': '**',
            '**/**/**': '**'
        },
        // Digits
        CHAR_0: 48,
        CHAR_9: 57,
        // Alphabet chars.
        CHAR_UPPERCASE_A: 65,
        CHAR_LOWERCASE_A: 97,
        CHAR_UPPERCASE_Z: 90,
        CHAR_LOWERCASE_Z: 122,
        CHAR_LEFT_PARENTHESES: 40,
        CHAR_RIGHT_PARENTHESES: 41,
        CHAR_ASTERISK: 42,
        // Non-alphabetic chars.
        CHAR_AMPERSAND: 38,
        CHAR_AT: 64,
        CHAR_BACKWARD_SLASH: 92,
        CHAR_CARRIAGE_RETURN: 13,
        CHAR_CIRCUMFLEX_ACCENT: 94,
        CHAR_COLON: 58,
        CHAR_COMMA: 44,
        CHAR_DOT: 46,
        CHAR_DOUBLE_QUOTE: 34,
        CHAR_EQUAL: 61,
        CHAR_EXCLAMATION_MARK: 33,
        CHAR_FORM_FEED: 12,
        CHAR_FORWARD_SLASH: 47,
        CHAR_GRAVE_ACCENT: 96,
        CHAR_HASH: 35,
        CHAR_HYPHEN_MINUS: 45,
        CHAR_LEFT_ANGLE_BRACKET: 60,
        CHAR_LEFT_CURLY_BRACE: 123,
        CHAR_LEFT_SQUARE_BRACKET: 91,
        CHAR_LINE_FEED: 10,
        CHAR_NO_BREAK_SPACE: 160,
        CHAR_PERCENT: 37,
        CHAR_PLUS: 43,
        CHAR_QUESTION_MARK: 63,
        CHAR_RIGHT_ANGLE_BRACKET: 62,
        CHAR_RIGHT_CURLY_BRACE: 125,
        CHAR_RIGHT_SQUARE_BRACKET: 93,
        CHAR_SEMICOLON: 59,
        CHAR_SINGLE_QUOTE: 39,
        CHAR_SPACE: 32,
        CHAR_TAB: 9,
        CHAR_UNDERSCORE: 95,
        CHAR_VERTICAL_LINE: 124,
        CHAR_ZERO_WIDTH_NOBREAK_SPACE: 65279,
        SEP: path.sep,
        /**
         * Create EXTGLOB_CHARS
         */
        extglobChars(chars) {
            return {
                '!': { type: 'negate', open: '(?:(?!(?:', close: `))${chars.STAR})` },
                '?': { type: 'qmark', open: '(?:', close: ')?' },
                '+': { type: 'plus', open: '(?:', close: ')+' },
                '*': { type: 'star', open: '(?:', close: ')*' },
                '@': { type: 'at', open: '(?:', close: ')' }
            };
        },
        /**
         * Create GLOB_CHARS
         */
        globChars(win32) {
            return win32 === true ? WINDOWS_CHARS : POSIX_CHARS;
        }
    };
},
/* picomatch/lib/parse.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const constants = require(1119) /* ./constants */;
    const utils = require(1118) /* ./utils */;
    /**
     * Constants
     */
    const { MAX_LENGTH, POSIX_REGEX_SOURCE, REGEX_NON_SPECIAL_CHARS, REGEX_SPECIAL_CHARS_BACKREF, REPLACEMENTS } = constants;
    /**
     * Helpers
     */
    const expandRange = (args, options) => {
        if (typeof options.expandRange === 'function') {
            return options.expandRange(...args, options);
        }
        args.sort();
        const value = `[${args.join('-')}]`;
        try {
            /* eslint-disable-next-line no-new */
            new RegExp(value);
        }
        catch (ex) {
            return args.map(v => utils.escapeRegex(v)).join('..');
        }
        return value;
    };
    /**
     * Create the message for a syntax error
     */
    const syntaxError = (type, char) => {
        return `Missing ${type}: "${char}" - use "\\\\${char}" to match literal characters`;
    };
    /**
     * Parse the given input string.
     * @param {String} input
     * @param {Object} options
     * @return {Object}
     */
    const parse = (input, options) => {
        if (typeof input !== 'string') {
            throw new TypeError('Expected a string');
        }
        input = REPLACEMENTS[input] || input;
        const opts = { ...options };
        const max = typeof opts.maxLength === 'number' ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
        let len = input.length;
        if (len > max) {
            throw new SyntaxError(`Input length: ${len}, exceeds maximum allowed length: ${max}`);
        }
        const bos = { type: 'bos', value: '', output: opts.prepend || '' };
        const tokens = [bos];
        const capture = opts.capture ? '' : '?:';
        const win32 = utils.isWindows(options);
        // create constants based on platform, for windows or posix
        const PLATFORM_CHARS = constants.globChars(win32);
        const EXTGLOB_CHARS = constants.extglobChars(PLATFORM_CHARS);
        const { DOT_LITERAL, PLUS_LITERAL, SLASH_LITERAL, ONE_CHAR, DOTS_SLASH, NO_DOT, NO_DOT_SLASH, NO_DOTS_SLASH, QMARK, QMARK_NO_DOT, STAR, START_ANCHOR } = PLATFORM_CHARS;
        const globstar = opts => {
            return `(${capture}(?:(?!${START_ANCHOR}${opts.dot ? DOTS_SLASH : DOT_LITERAL}).)*?)`;
        };
        const nodot = opts.dot ? '' : NO_DOT;
        const qmarkNoDot = opts.dot ? QMARK : QMARK_NO_DOT;
        let star = opts.bash === true ? globstar(opts) : STAR;
        if (opts.capture) {
            star = `(${star})`;
        }
        // minimatch options support
        if (typeof opts.noext === 'boolean') {
            opts.noextglob = opts.noext;
        }
        const state = {
            input,
            index: -1,
            start: 0,
            dot: opts.dot === true,
            consumed: '',
            output: '',
            prefix: '',
            backtrack: false,
            negated: false,
            brackets: 0,
            braces: 0,
            parens: 0,
            quotes: 0,
            globstar: false,
            tokens
        };
        input = utils.removePrefix(input, state);
        len = input.length;
        const extglobs = [];
        const braces = [];
        const stack = [];
        let prev = bos;
        let value;
        /**
         * Tokenizing helpers
         */
        const eos = () => state.index === len - 1;
        const peek = state.peek = (n = 1) => input[state.index + n];
        const advance = state.advance = () => input[++state.index] || '';
        const remaining = () => input.slice(state.index + 1);
        const consume = (value = '', num = 0) => {
            state.consumed += value;
            state.index += num;
        };
        const append = token => {
            state.output += token.output != null ? token.output : token.value;
            consume(token.value);
        };
        const negate = () => {
            let count = 1;
            while (peek() === '!' && (peek(2) !== '(' || peek(3) === '?')) {
                advance();
                state.start++;
                count++;
            }
            if (count % 2 === 0) {
                return false;
            }
            state.negated = true;
            state.start++;
            return true;
        };
        const increment = type => {
            state[type]++;
            stack.push(type);
        };
        const decrement = type => {
            state[type]--;
            stack.pop();
        };
        /**
         * Push tokens onto the tokens array. This helper speeds up
         * tokenizing by 1) helping us avoid backtracking as much as possible,
         * and 2) helping us avoid creating extra tokens when consecutive
         * characters are plain text. This improves performance and simplifies
         * lookbehinds.
         */
        const push = tok => {
            if (prev.type === 'globstar') {
                const isBrace = state.braces > 0 && (tok.type === 'comma' || tok.type === 'brace');
                const isExtglob = tok.extglob === true || (extglobs.length && (tok.type === 'pipe' || tok.type === 'paren'));
                if (tok.type !== 'slash' && tok.type !== 'paren' && !isBrace && !isExtglob) {
                    state.output = state.output.slice(0, -prev.output.length);
                    prev.type = 'star';
                    prev.value = '*';
                    prev.output = star;
                    state.output += prev.output;
                }
            }
            if (extglobs.length && tok.type !== 'paren') {
                extglobs[extglobs.length - 1].inner += tok.value;
            }
            if (tok.value || tok.output)
                append(tok);
            if (prev && prev.type === 'text' && tok.type === 'text') {
                prev.value += tok.value;
                prev.output = (prev.output || '') + tok.value;
                return;
            }
            tok.prev = prev;
            tokens.push(tok);
            prev = tok;
        };
        const extglobOpen = (type, value) => {
            const token = { ...EXTGLOB_CHARS[value], conditions: 1, inner: '' };
            token.prev = prev;
            token.parens = state.parens;
            token.output = state.output;
            const output = (opts.capture ? '(' : '') + token.open;
            increment('parens');
            push({ type, value, output: state.output ? '' : ONE_CHAR });
            push({ type: 'paren', extglob: true, value: advance(), output });
            extglobs.push(token);
        };
        const extglobClose = token => {
            let output = token.close + (opts.capture ? ')' : '');
            let rest;
            if (token.type === 'negate') {
                let extglobStar = star;
                if (token.inner && token.inner.length > 1 && token.inner.includes('/')) {
                    extglobStar = globstar(opts);
                }
                if (extglobStar !== star || eos() || /^\)+$/.test(remaining())) {
                    output = token.close = `)$))${extglobStar}`;
                }
                if (token.inner.includes('*') && (rest = remaining()) && /^\.[^\\/.]+$/.test(rest)) {
                    // Any non-magical string (`.ts`) or even nested expression (`.{ts,tsx}`) can follow after the closing parenthesis.
                    // In this case, we need to parse the string and use it in the output of the original pattern.
                    // Suitable patterns: `/!(*.d).ts`, `/!(*.d).{ts,tsx}`, `**/!(*-dbg).@(js)`.
                    //
                    // Disabling the `fastpaths` option due to a problem with parsing strings as `.ts` in the pattern like `**/!(*.d).ts`.
                    const expression = parse(rest, { ...options, fastpaths: false }).output;
                    output = token.close = `)${expression})${extglobStar})`;
                }
                if (token.prev.type === 'bos') {
                    state.negatedExtglob = true;
                }
            }
            push({ type: 'paren', extglob: true, value, output });
            decrement('parens');
        };
        /**
         * Fast paths
         */
        if (opts.fastpaths !== false && !/(^[*!]|[/()[\]{}"])/.test(input)) {
            let backslashes = false;
            let output = input.replace(REGEX_SPECIAL_CHARS_BACKREF, (m, esc, chars, first, rest, index) => {
                if (first === '\\') {
                    backslashes = true;
                    return m;
                }
                if (first === '?') {
                    if (esc) {
                        return esc + first + (rest ? QMARK.repeat(rest.length) : '');
                    }
                    if (index === 0) {
                        return qmarkNoDot + (rest ? QMARK.repeat(rest.length) : '');
                    }
                    return QMARK.repeat(chars.length);
                }
                if (first === '.') {
                    return DOT_LITERAL.repeat(chars.length);
                }
                if (first === '*') {
                    if (esc) {
                        return esc + first + (rest ? star : '');
                    }
                    return star;
                }
                return esc ? m : `\\${m}`;
            });
            if (backslashes === true) {
                if (opts.unescape === true) {
                    output = output.replace(/\\/g, '');
                }
                else {
                    output = output.replace(/\\+/g, m => {
                        return m.length % 2 === 0 ? '\\\\' : (m ? '\\' : '');
                    });
                }
            }
            if (output === input && opts.contains === true) {
                state.output = input;
                return state;
            }
            state.output = utils.wrapOutput(output, state, options);
            return state;
        }
        /**
         * Tokenize input until we reach end-of-string
         */
        while (!eos()) {
            value = advance();
            if (value === '\u0000') {
                continue;
            }
            /**
             * Escaped characters
             */
            if (value === '\\') {
                const next = peek();
                if (next === '/' && opts.bash !== true) {
                    continue;
                }
                if (next === '.' || next === ';') {
                    continue;
                }
                if (!next) {
                    value += '\\';
                    push({ type: 'text', value });
                    continue;
                }
                // collapse slashes to reduce potential for exploits
                const match = /^\\+/.exec(remaining());
                let slashes = 0;
                if (match && match[0].length > 2) {
                    slashes = match[0].length;
                    state.index += slashes;
                    if (slashes % 2 !== 0) {
                        value += '\\';
                    }
                }
                if (opts.unescape === true) {
                    value = advance();
                }
                else {
                    value += advance();
                }
                if (state.brackets === 0) {
                    push({ type: 'text', value });
                    continue;
                }
            }
            /**
             * If we're inside a regex character class, continue
             * until we reach the closing bracket.
             */
            if (state.brackets > 0 && (value !== ']' || prev.value === '[' || prev.value === '[^')) {
                if (opts.posix !== false && value === ':') {
                    const inner = prev.value.slice(1);
                    if (inner.includes('[')) {
                        prev.posix = true;
                        if (inner.includes(':')) {
                            const idx = prev.value.lastIndexOf('[');
                            const pre = prev.value.slice(0, idx);
                            const rest = prev.value.slice(idx + 2);
                            const posix = POSIX_REGEX_SOURCE[rest];
                            if (posix) {
                                prev.value = pre + posix;
                                state.backtrack = true;
                                advance();
                                if (!bos.output && tokens.indexOf(prev) === 1) {
                                    bos.output = ONE_CHAR;
                                }
                                continue;
                            }
                        }
                    }
                }
                if ((value === '[' && peek() !== ':') || (value === '-' && peek() === ']')) {
                    value = `\\${value}`;
                }
                if (value === ']' && (prev.value === '[' || prev.value === '[^')) {
                    value = `\\${value}`;
                }
                if (opts.posix === true && value === '!' && prev.value === '[') {
                    value = '^';
                }
                prev.value += value;
                append({ value });
                continue;
            }
            /**
             * If we're inside a quoted string, continue
             * until we reach the closing double quote.
             */
            if (state.quotes === 1 && value !== '"') {
                value = utils.escapeRegex(value);
                prev.value += value;
                append({ value });
                continue;
            }
            /**
             * Double quotes
             */
            if (value === '"') {
                state.quotes = state.quotes === 1 ? 0 : 1;
                if (opts.keepQuotes === true) {
                    push({ type: 'text', value });
                }
                continue;
            }
            /**
             * Parentheses
             */
            if (value === '(') {
                increment('parens');
                push({ type: 'paren', value });
                continue;
            }
            if (value === ')') {
                if (state.parens === 0 && opts.strictBrackets === true) {
                    throw new SyntaxError(syntaxError('opening', '('));
                }
                const extglob = extglobs[extglobs.length - 1];
                if (extglob && state.parens === extglob.parens + 1) {
                    extglobClose(extglobs.pop());
                    continue;
                }
                push({ type: 'paren', value, output: state.parens ? ')' : '\\)' });
                decrement('parens');
                continue;
            }
            /**
             * Square brackets
             */
            if (value === '[') {
                if (opts.nobracket === true || !remaining().includes(']')) {
                    if (opts.nobracket !== true && opts.strictBrackets === true) {
                        throw new SyntaxError(syntaxError('closing', ']'));
                    }
                    value = `\\${value}`;
                }
                else {
                    increment('brackets');
                }
                push({ type: 'bracket', value });
                continue;
            }
            if (value === ']') {
                if (opts.nobracket === true || (prev && prev.type === 'bracket' && prev.value.length === 1)) {
                    push({ type: 'text', value, output: `\\${value}` });
                    continue;
                }
                if (state.brackets === 0) {
                    if (opts.strictBrackets === true) {
                        throw new SyntaxError(syntaxError('opening', '['));
                    }
                    push({ type: 'text', value, output: `\\${value}` });
                    continue;
                }
                decrement('brackets');
                const prevValue = prev.value.slice(1);
                if (prev.posix !== true && prevValue[0] === '^' && !prevValue.includes('/')) {
                    value = `/${value}`;
                }
                prev.value += value;
                append({ value });
                // when literal brackets are explicitly disabled
                // assume we should match with a regex character class
                if (opts.literalBrackets === false || utils.hasRegexChars(prevValue)) {
                    continue;
                }
                const escaped = utils.escapeRegex(prev.value);
                state.output = state.output.slice(0, -prev.value.length);
                // when literal brackets are explicitly enabled
                // assume we should escape the brackets to match literal characters
                if (opts.literalBrackets === true) {
                    state.output += escaped;
                    prev.value = escaped;
                    continue;
                }
                // when the user specifies nothing, try to match both
                prev.value = `(${capture}${escaped}|${prev.value})`;
                state.output += prev.value;
                continue;
            }
            /**
             * Braces
             */
            if (value === '{' && opts.nobrace !== true) {
                increment('braces');
                const open = {
                    type: 'brace',
                    value,
                    output: '(',
                    outputIndex: state.output.length,
                    tokensIndex: state.tokens.length
                };
                braces.push(open);
                push(open);
                continue;
            }
            if (value === '}') {
                const brace = braces[braces.length - 1];
                if (opts.nobrace === true || !brace) {
                    push({ type: 'text', value, output: value });
                    continue;
                }
                let output = ')';
                if (brace.dots === true) {
                    const arr = tokens.slice();
                    const range = [];
                    for (let i = arr.length - 1; i >= 0; i--) {
                        tokens.pop();
                        if (arr[i].type === 'brace') {
                            break;
                        }
                        if (arr[i].type !== 'dots') {
                            range.unshift(arr[i].value);
                        }
                    }
                    output = expandRange(range, opts);
                    state.backtrack = true;
                }
                if (brace.comma !== true && brace.dots !== true) {
                    const out = state.output.slice(0, brace.outputIndex);
                    const toks = state.tokens.slice(brace.tokensIndex);
                    brace.value = brace.output = '\\{';
                    value = output = '\\}';
                    state.output = out;
                    for (const t of toks) {
                        state.output += (t.output || t.value);
                    }
                }
                push({ type: 'brace', value, output });
                decrement('braces');
                braces.pop();
                continue;
            }
            /**
             * Pipes
             */
            if (value === '|') {
                if (extglobs.length > 0) {
                    extglobs[extglobs.length - 1].conditions++;
                }
                push({ type: 'text', value });
                continue;
            }
            /**
             * Commas
             */
            if (value === ',') {
                let output = value;
                const brace = braces[braces.length - 1];
                if (brace && stack[stack.length - 1] === 'braces') {
                    brace.comma = true;
                    output = '|';
                }
                push({ type: 'comma', value, output });
                continue;
            }
            /**
             * Slashes
             */
            if (value === '/') {
                // if the beginning of the glob is "./", advance the start
                // to the current index, and don't add the "./" characters
                // to the state. This greatly simplifies lookbehinds when
                // checking for BOS characters like "!" and "." (not "./")
                if (prev.type === 'dot' && state.index === state.start + 1) {
                    state.start = state.index + 1;
                    state.consumed = '';
                    state.output = '';
                    tokens.pop();
                    prev = bos; // reset "prev" to the first token
                    continue;
                }
                push({ type: 'slash', value, output: SLASH_LITERAL });
                continue;
            }
            /**
             * Dots
             */
            if (value === '.') {
                if (state.braces > 0 && prev.type === 'dot') {
                    if (prev.value === '.')
                        prev.output = DOT_LITERAL;
                    const brace = braces[braces.length - 1];
                    prev.type = 'dots';
                    prev.output += value;
                    prev.value += value;
                    brace.dots = true;
                    continue;
                }
                if ((state.braces + state.parens) === 0 && prev.type !== 'bos' && prev.type !== 'slash') {
                    push({ type: 'text', value, output: DOT_LITERAL });
                    continue;
                }
                push({ type: 'dot', value, output: DOT_LITERAL });
                continue;
            }
            /**
             * Question marks
             */
            if (value === '?') {
                const isGroup = prev && prev.value === '(';
                if (!isGroup && opts.noextglob !== true && peek() === '(' && peek(2) !== '?') {
                    extglobOpen('qmark', value);
                    continue;
                }
                if (prev && prev.type === 'paren') {
                    const next = peek();
                    let output = value;
                    if (next === '<' && !utils.supportsLookbehinds()) {
                        throw new Error('Node.js v10 or higher is required for regex lookbehinds');
                    }
                    if ((prev.value === '(' && !/[!=<:]/.test(next)) || (next === '<' && !/<([!=]|\w+>)/.test(remaining()))) {
                        output = `\\${value}`;
                    }
                    push({ type: 'text', value, output });
                    continue;
                }
                if (opts.dot !== true && (prev.type === 'slash' || prev.type === 'bos')) {
                    push({ type: 'qmark', value, output: QMARK_NO_DOT });
                    continue;
                }
                push({ type: 'qmark', value, output: QMARK });
                continue;
            }
            /**
             * Exclamation
             */
            if (value === '!') {
                if (opts.noextglob !== true && peek() === '(') {
                    if (peek(2) !== '?' || !/[!=<:]/.test(peek(3))) {
                        extglobOpen('negate', value);
                        continue;
                    }
                }
                if (opts.nonegate !== true && state.index === 0) {
                    negate();
                    continue;
                }
            }
            /**
             * Plus
             */
            if (value === '+') {
                if (opts.noextglob !== true && peek() === '(' && peek(2) !== '?') {
                    extglobOpen('plus', value);
                    continue;
                }
                if ((prev && prev.value === '(') || opts.regex === false) {
                    push({ type: 'plus', value, output: PLUS_LITERAL });
                    continue;
                }
                if ((prev && (prev.type === 'bracket' || prev.type === 'paren' || prev.type === 'brace')) || state.parens > 0) {
                    push({ type: 'plus', value });
                    continue;
                }
                push({ type: 'plus', value: PLUS_LITERAL });
                continue;
            }
            /**
             * Plain text
             */
            if (value === '@') {
                if (opts.noextglob !== true && peek() === '(' && peek(2) !== '?') {
                    push({ type: 'at', extglob: true, value, output: '' });
                    continue;
                }
                push({ type: 'text', value });
                continue;
            }
            /**
             * Plain text
             */
            if (value !== '*') {
                if (value === '$' || value === '^') {
                    value = `\\${value}`;
                }
                const match = REGEX_NON_SPECIAL_CHARS.exec(remaining());
                if (match) {
                    value += match[0];
                    state.index += match[0].length;
                }
                push({ type: 'text', value });
                continue;
            }
            /**
             * Stars
             */
            if (prev && (prev.type === 'globstar' || prev.star === true)) {
                prev.type = 'star';
                prev.star = true;
                prev.value += value;
                prev.output = star;
                state.backtrack = true;
                state.globstar = true;
                consume(value);
                continue;
            }
            let rest = remaining();
            if (opts.noextglob !== true && /^\([^?]/.test(rest)) {
                extglobOpen('star', value);
                continue;
            }
            if (prev.type === 'star') {
                if (opts.noglobstar === true) {
                    consume(value);
                    continue;
                }
                const prior = prev.prev;
                const before = prior.prev;
                const isStart = prior.type === 'slash' || prior.type === 'bos';
                const afterStar = before && (before.type === 'star' || before.type === 'globstar');
                if (opts.bash === true && (!isStart || (rest[0] && rest[0] !== '/'))) {
                    push({ type: 'star', value, output: '' });
                    continue;
                }
                const isBrace = state.braces > 0 && (prior.type === 'comma' || prior.type === 'brace');
                const isExtglob = extglobs.length && (prior.type === 'pipe' || prior.type === 'paren');
                if (!isStart && prior.type !== 'paren' && !isBrace && !isExtglob) {
                    push({ type: 'star', value, output: '' });
                    continue;
                }
                // strip consecutive `/**/`
                while (rest.slice(0, 3) === '/**') {
                    const after = input[state.index + 4];
                    if (after && after !== '/') {
                        break;
                    }
                    rest = rest.slice(3);
                    consume('/**', 3);
                }
                if (prior.type === 'bos' && eos()) {
                    prev.type = 'globstar';
                    prev.value += value;
                    prev.output = globstar(opts);
                    state.output = prev.output;
                    state.globstar = true;
                    consume(value);
                    continue;
                }
                if (prior.type === 'slash' && prior.prev.type !== 'bos' && !afterStar && eos()) {
                    state.output = state.output.slice(0, -(prior.output + prev.output).length);
                    prior.output = `(?:${prior.output}`;
                    prev.type = 'globstar';
                    prev.output = globstar(opts) + (opts.strictSlashes ? ')' : '|$)');
                    prev.value += value;
                    state.globstar = true;
                    state.output += prior.output + prev.output;
                    consume(value);
                    continue;
                }
                if (prior.type === 'slash' && prior.prev.type !== 'bos' && rest[0] === '/') {
                    const end = rest[1] !== void 0 ? '|$' : '';
                    state.output = state.output.slice(0, -(prior.output + prev.output).length);
                    prior.output = `(?:${prior.output}`;
                    prev.type = 'globstar';
                    prev.output = `${globstar(opts)}${SLASH_LITERAL}|${SLASH_LITERAL}${end})`;
                    prev.value += value;
                    state.output += prior.output + prev.output;
                    state.globstar = true;
                    consume(value + advance());
                    push({ type: 'slash', value: '/', output: '' });
                    continue;
                }
                if (prior.type === 'bos' && rest[0] === '/') {
                    prev.type = 'globstar';
                    prev.value += value;
                    prev.output = `(?:^|${SLASH_LITERAL}|${globstar(opts)}${SLASH_LITERAL})`;
                    state.output = prev.output;
                    state.globstar = true;
                    consume(value + advance());
                    push({ type: 'slash', value: '/', output: '' });
                    continue;
                }
                // remove single star from output
                state.output = state.output.slice(0, -prev.output.length);
                // reset previous token to globstar
                prev.type = 'globstar';
                prev.output = globstar(opts);
                prev.value += value;
                // reset output with globstar
                state.output += prev.output;
                state.globstar = true;
                consume(value);
                continue;
            }
            const token = { type: 'star', value, output: star };
            if (opts.bash === true) {
                token.output = '.*?';
                if (prev.type === 'bos' || prev.type === 'slash') {
                    token.output = nodot + token.output;
                }
                push(token);
                continue;
            }
            if (prev && (prev.type === 'bracket' || prev.type === 'paren') && opts.regex === true) {
                token.output = value;
                push(token);
                continue;
            }
            if (state.index === state.start || prev.type === 'slash' || prev.type === 'dot') {
                if (prev.type === 'dot') {
                    state.output += NO_DOT_SLASH;
                    prev.output += NO_DOT_SLASH;
                }
                else if (opts.dot === true) {
                    state.output += NO_DOTS_SLASH;
                    prev.output += NO_DOTS_SLASH;
                }
                else {
                    state.output += nodot;
                    prev.output += nodot;
                }
                if (peek() !== '*') {
                    state.output += ONE_CHAR;
                    prev.output += ONE_CHAR;
                }
            }
            push(token);
        }
        while (state.brackets > 0) {
            if (opts.strictBrackets === true)
                throw new SyntaxError(syntaxError('closing', ']'));
            state.output = utils.escapeLast(state.output, '[');
            decrement('brackets');
        }
        while (state.parens > 0) {
            if (opts.strictBrackets === true)
                throw new SyntaxError(syntaxError('closing', ')'));
            state.output = utils.escapeLast(state.output, '(');
            decrement('parens');
        }
        while (state.braces > 0) {
            if (opts.strictBrackets === true)
                throw new SyntaxError(syntaxError('closing', '}'));
            state.output = utils.escapeLast(state.output, '{');
            decrement('braces');
        }
        if (opts.strictSlashes !== true && (prev.type === 'star' || prev.type === 'bracket')) {
            push({ type: 'maybe_slash', value: '', output: `${SLASH_LITERAL}?` });
        }
        // rebuild the output if we had to backtrack at any point
        if (state.backtrack === true) {
            state.output = '';
            for (const token of state.tokens) {
                state.output += token.output != null ? token.output : token.value;
                if (token.suffix) {
                    state.output += token.suffix;
                }
            }
        }
        return state;
    };
    /**
     * Fast paths for creating regular expressions for common glob patterns.
     * This can significantly speed up processing and has very little downside
     * impact when none of the fast paths match.
     */
    parse.fastpaths = (input, options) => {
        const opts = { ...options };
        const max = typeof opts.maxLength === 'number' ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
        const len = input.length;
        if (len > max) {
            throw new SyntaxError(`Input length: ${len}, exceeds maximum allowed length: ${max}`);
        }
        input = REPLACEMENTS[input] || input;
        const win32 = utils.isWindows(options);
        // create constants based on platform, for windows or posix
        const { DOT_LITERAL, SLASH_LITERAL, ONE_CHAR, DOTS_SLASH, NO_DOT, NO_DOTS, NO_DOTS_SLASH, STAR, START_ANCHOR } = constants.globChars(win32);
        const nodot = opts.dot ? NO_DOTS : NO_DOT;
        const slashDot = opts.dot ? NO_DOTS_SLASH : NO_DOT;
        const capture = opts.capture ? '' : '?:';
        const state = { negated: false, prefix: '' };
        let star = opts.bash === true ? '.*?' : STAR;
        if (opts.capture) {
            star = `(${star})`;
        }
        const globstar = opts => {
            if (opts.noglobstar === true)
                return star;
            return `(${capture}(?:(?!${START_ANCHOR}${opts.dot ? DOTS_SLASH : DOT_LITERAL}).)*?)`;
        };
        const create = str => {
            switch (str) {
                case '*':
                    return `${nodot}${ONE_CHAR}${star}`;
                case '.*':
                    return `${DOT_LITERAL}${ONE_CHAR}${star}`;
                case '*.*':
                    return `${nodot}${star}${DOT_LITERAL}${ONE_CHAR}${star}`;
                case '*/*':
                    return `${nodot}${star}${SLASH_LITERAL}${ONE_CHAR}${slashDot}${star}`;
                case '**':
                    return nodot + globstar(opts);
                case '**/*':
                    return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${slashDot}${ONE_CHAR}${star}`;
                case '**/*.*':
                    return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${slashDot}${star}${DOT_LITERAL}${ONE_CHAR}${star}`;
                case '**/.*':
                    return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${DOT_LITERAL}${ONE_CHAR}${star}`;
                default: {
                    const match = /^(.*?)\.(\w+)$/.exec(str);
                    if (!match)
                        return;
                    const source = create(match[1]);
                    if (!source)
                        return;
                    return source + DOT_LITERAL + match[2];
                }
            }
        };
        const output = utils.removePrefix(input, state);
        let source = create(output);
        if (source && opts.strictSlashes !== true) {
            source += `${SLASH_LITERAL}?`;
        }
        return source;
    };
    module.exports = parse;
},
/* fast-glob/out/utils/stream.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.merge = void 0;
    const merge2 = require(1095) /* merge2 */;
    function merge(streams) {
        const mergedStream = merge2(streams);
        streams.forEach((stream) => {
            stream.once('error', (error) => mergedStream.emit('error', error));
        });
        mergedStream.once('close', () => propagateCloseEventToSources(streams));
        mergedStream.once('end', () => propagateCloseEventToSources(streams));
        return mergedStream;
    }
    exports.merge = merge;
    function propagateCloseEventToSources(streams) {
        streams.forEach((stream) => stream.emit('close'));
    }
},
/* fast-glob/out/utils/string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isEmpty = exports.isString = void 0;
    function isString(input) {
        return typeof input === 'string';
    }
    exports.isString = isString;
    function isEmpty(input) {
        return input === '';
    }
    exports.isEmpty = isEmpty;
},
/* fast-glob/out/managers/patterns.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.removeDuplicateSlashes = exports.transform = void 0;
    /**
     * Matches a sequence of two or more consecutive slashes, excluding the first two slashes at the beginning of the string.
     * The latter is due to the presence of the device path at the beginning of the UNC path.
     * @todo rewrite to negative lookbehind with the next major release.
     */
    const DOUBLE_SLASH_RE = /(?!^)\/{2,}/g;
    function transform(patterns) {
        return patterns.map((pattern) => removeDuplicateSlashes(pattern));
    }
    exports.transform = transform;
    /**
     * This package only works with forward slashes as a path separator.
     * Because of this, we cannot use the standard `path.normalize` method, because on Windows platform it will use of backslashes.
     */
    function removeDuplicateSlashes(pattern) {
        return pattern.replace(DOUBLE_SLASH_RE, '/');
    }
    exports.removeDuplicateSlashes = removeDuplicateSlashes;
},
/* fast-glob/out/providers/async.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const async_1 = require(1125) /* ../readers/async */;
    const provider_1 = require(1128) /* ./provider */;
    class ProviderAsync extends provider_1.default {
        constructor() {
            super(...arguments);
            this._reader = new async_1.default(this._settings);
        }
        async read(task) {
            const root = this._getRootDirectory(task);
            const options = this._getReaderOptions(task);
            const entries = await this.api(root, task, options);
            return entries.map((entry) => options.transform(entry));
        }
        api(root, task, options) {
            if (task.dynamic) {
                return this._reader.dynamic(root, options);
            }
            return this._reader.static(task.patterns, options);
        }
    }
    exports.default = ProviderAsync;
},
/* fast-glob/out/readers/async.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const fsWalk = require(735) /* @nodelib/fs.walk */;
    const reader_1 = require(1126) /* ./reader */;
    const stream_1 = require(1127) /* ./stream */;
    class ReaderAsync extends reader_1.default {
        constructor() {
            super(...arguments);
            this._walkAsync = fsWalk.walk;
            this._readerStream = new stream_1.default(this._settings);
        }
        dynamic(root, options) {
            return new Promise((resolve, reject) => {
                this._walkAsync(root, options, (error, entries) => {
                    if (error === null) {
                        resolve(entries);
                    }
                    else {
                        reject(error);
                    }
                });
            });
        }
        async static(patterns, options) {
            const entries = [];
            const stream = this._readerStream.static(patterns, options);
            // After #235, replace it with an asynchronous iterator.
            return new Promise((resolve, reject) => {
                stream.once('error', reject);
                stream.on('data', (entry) => entries.push(entry));
                stream.once('end', () => resolve(entries));
            });
        }
    }
    exports.default = ReaderAsync;
},
/* fast-glob/out/readers/reader.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const path = require("path");
    const fsStat = require(740) /* @nodelib/fs.stat */;
    const utils = require(1098) /* ../utils */;
    class Reader {
        constructor(_settings) {
            this._settings = _settings;
            this._fsStatSettings = new fsStat.Settings({
                followSymbolicLink: this._settings.followSymbolicLinks,
                fs: this._settings.fs,
                throwErrorOnBrokenSymbolicLink: this._settings.followSymbolicLinks
            });
        }
        _getFullEntryPath(filepath) {
            return path.resolve(this._settings.cwd, filepath);
        }
        _makeEntry(stats, pattern) {
            const entry = {
                name: pattern,
                path: pattern,
                dirent: utils.fs.createDirentFromStats(pattern, stats)
            };
            if (this._settings.stats) {
                entry.stats = stats;
            }
            return entry;
        }
        _isFatalError(error) {
            return !utils.errno.isEnoentCodeError(error) && !this._settings.suppressErrors;
        }
    }
    exports.default = Reader;
},
/* fast-glob/out/readers/stream.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const stream_1 = require("stream");
    const fsStat = require(740) /* @nodelib/fs.stat */;
    const fsWalk = require(735) /* @nodelib/fs.walk */;
    const reader_1 = require(1126) /* ./reader */;
    class ReaderStream extends reader_1.default {
        constructor() {
            super(...arguments);
            this._walkStream = fsWalk.walkStream;
            this._stat = fsStat.stat;
        }
        dynamic(root, options) {
            return this._walkStream(root, options);
        }
        static(patterns, options) {
            const filepaths = patterns.map(this._getFullEntryPath, this);
            const stream = new stream_1.PassThrough({ objectMode: true });
            stream._write = (index, _enc, done) => {
                return this._getEntry(filepaths[index], patterns[index], options)
                    .then((entry) => {
                    if (entry !== null && options.entryFilter(entry)) {
                        stream.push(entry);
                    }
                    if (index === filepaths.length - 1) {
                        stream.end();
                    }
                    done();
                })
                    .catch(done);
            };
            for (let i = 0; i < filepaths.length; i++) {
                stream.write(i);
            }
            return stream;
        }
        _getEntry(filepath, pattern, options) {
            return this._getStat(filepath)
                .then((stats) => this._makeEntry(stats, pattern))
                .catch((error) => {
                if (options.errorFilter(error)) {
                    return null;
                }
                throw error;
            });
        }
        _getStat(filepath) {
            return new Promise((resolve, reject) => {
                this._stat(filepath, this._fsStatSettings, (error, stats) => {
                    return error === null ? resolve(stats) : reject(error);
                });
            });
        }
    }
    exports.default = ReaderStream;
},
/* fast-glob/out/providers/provider.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const path = require("path");
    const deep_1 = require(1129) /* ./filters/deep */;
    const entry_1 = require(1132) /* ./filters/entry */;
    const error_1 = require(1133) /* ./filters/error */;
    const entry_2 = require(1134) /* ./transformers/entry */;
    class Provider {
        constructor(_settings) {
            this._settings = _settings;
            this.errorFilter = new error_1.default(this._settings);
            this.entryFilter = new entry_1.default(this._settings, this._getMicromatchOptions());
            this.deepFilter = new deep_1.default(this._settings, this._getMicromatchOptions());
            this.entryTransformer = new entry_2.default(this._settings);
        }
        _getRootDirectory(task) {
            return path.resolve(this._settings.cwd, task.base);
        }
        _getReaderOptions(task) {
            const basePath = task.base === '.' ? '' : task.base;
            return {
                basePath,
                pathSegmentSeparator: '/',
                concurrency: this._settings.concurrency,
                deepFilter: this.deepFilter.getFilter(basePath, task.positive, task.negative),
                entryFilter: this.entryFilter.getFilter(task.positive, task.negative),
                errorFilter: this.errorFilter.getFilter(),
                followSymbolicLinks: this._settings.followSymbolicLinks,
                fs: this._settings.fs,
                stats: this._settings.stats,
                throwErrorOnBrokenSymbolicLink: this._settings.throwErrorOnBrokenSymbolicLink,
                transform: this.entryTransformer.getTransformer()
            };
        }
        _getMicromatchOptions() {
            return {
                dot: this._settings.dot,
                matchBase: this._settings.baseNameMatch,
                nobrace: !this._settings.braceExpansion,
                nocase: !this._settings.caseSensitiveMatch,
                noext: !this._settings.extglob,
                noglobstar: !this._settings.globstar,
                posix: true,
                strictSlashes: false
            };
        }
    }
    exports.default = Provider;
},
/* fast-glob/out/providers/filters/deep.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils = require(1098) /* ../../utils */;
    const partial_1 = require(1130) /* ../matchers/partial */;
    class DeepFilter {
        constructor(_settings, _micromatchOptions) {
            this._settings = _settings;
            this._micromatchOptions = _micromatchOptions;
        }
        getFilter(basePath, positive, negative) {
            const matcher = this._getMatcher(positive);
            const negativeRe = this._getNegativePatternsRe(negative);
            return (entry) => this._filter(basePath, entry, matcher, negativeRe);
        }
        _getMatcher(patterns) {
            return new partial_1.default(patterns, this._settings, this._micromatchOptions);
        }
        _getNegativePatternsRe(patterns) {
            const affectDepthOfReadingPatterns = patterns.filter(utils.pattern.isAffectDepthOfReadingPattern);
            return utils.pattern.convertPatternsToRe(affectDepthOfReadingPatterns, this._micromatchOptions);
        }
        _filter(basePath, entry, matcher, negativeRe) {
            if (this._isSkippedByDeep(basePath, entry.path)) {
                return false;
            }
            if (this._isSkippedSymbolicLink(entry)) {
                return false;
            }
            const filepath = utils.path.removeLeadingDotSegment(entry.path);
            if (this._isSkippedByPositivePatterns(filepath, matcher)) {
                return false;
            }
            return this._isSkippedByNegativePatterns(filepath, negativeRe);
        }
        _isSkippedByDeep(basePath, entryPath) {
            /**
             * Avoid unnecessary depth calculations when it doesn't matter.
             */
            if (this._settings.deep === Infinity) {
                return false;
            }
            return this._getEntryLevel(basePath, entryPath) >= this._settings.deep;
        }
        _getEntryLevel(basePath, entryPath) {
            const entryPathDepth = entryPath.split('/').length;
            if (basePath === '') {
                return entryPathDepth;
            }
            const basePathDepth = basePath.split('/').length;
            return entryPathDepth - basePathDepth;
        }
        _isSkippedSymbolicLink(entry) {
            return !this._settings.followSymbolicLinks && entry.dirent.isSymbolicLink();
        }
        _isSkippedByPositivePatterns(entryPath, matcher) {
            return !this._settings.baseNameMatch && !matcher.match(entryPath);
        }
        _isSkippedByNegativePatterns(entryPath, patternsRe) {
            return !utils.pattern.matchAny(entryPath, patternsRe);
        }
    }
    exports.default = DeepFilter;
},
/* fast-glob/out/providers/matchers/partial.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const matcher_1 = require(1131) /* ./matcher */;
    class PartialMatcher extends matcher_1.default {
        match(filepath) {
            const parts = filepath.split('/');
            const levels = parts.length;
            const patterns = this._storage.filter((info) => !info.complete || info.segments.length > levels);
            for (const pattern of patterns) {
                const section = pattern.sections[0];
                /**
                 * In this case, the pattern has a globstar and we must read all directories unconditionally,
                 * but only if the level has reached the end of the first group.
                 *
                 * fixtures/{a,b}/**
                 *  ^ true/false  ^ always true
                */
                if (!pattern.complete && levels > section.length) {
                    return true;
                }
                const match = parts.every((part, index) => {
                    const segment = pattern.segments[index];
                    if (segment.dynamic && segment.patternRe.test(part)) {
                        return true;
                    }
                    if (!segment.dynamic && segment.pattern === part) {
                        return true;
                    }
                    return false;
                });
                if (match) {
                    return true;
                }
            }
            return false;
        }
    }
    exports.default = PartialMatcher;
},
/* fast-glob/out/providers/matchers/matcher.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils = require(1098) /* ../../utils */;
    class Matcher {
        constructor(_patterns, _settings, _micromatchOptions) {
            this._patterns = _patterns;
            this._settings = _settings;
            this._micromatchOptions = _micromatchOptions;
            this._storage = [];
            this._fillStorage();
        }
        _fillStorage() {
            /**
             * The original pattern may include `{,*,**,a/*}`, which will lead to problems with matching (unresolved level).
             * So, before expand patterns with brace expansion into separated patterns.
             */
            const patterns = utils.pattern.expandPatternsWithBraceExpansion(this._patterns);
            for (const pattern of patterns) {
                const segments = this._getPatternSegments(pattern);
                const sections = this._splitSegmentsIntoSections(segments);
                this._storage.push({
                    complete: sections.length <= 1,
                    pattern,
                    segments,
                    sections
                });
            }
        }
        _getPatternSegments(pattern) {
            const parts = utils.pattern.getPatternParts(pattern, this._micromatchOptions);
            return parts.map((part) => {
                const dynamic = utils.pattern.isDynamicPattern(part, this._settings);
                if (!dynamic) {
                    return {
                        dynamic: false,
                        pattern: part
                    };
                }
                return {
                    dynamic: true,
                    pattern: part,
                    patternRe: utils.pattern.makeRe(part, this._micromatchOptions)
                };
            });
        }
        _splitSegmentsIntoSections(segments) {
            return utils.array.splitWhen(segments, (segment) => segment.dynamic && utils.pattern.hasGlobStar(segment.pattern));
        }
    }
    exports.default = Matcher;
},
/* fast-glob/out/providers/filters/entry.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils = require(1098) /* ../../utils */;
    class EntryFilter {
        constructor(_settings, _micromatchOptions) {
            this._settings = _settings;
            this._micromatchOptions = _micromatchOptions;
            this.index = new Map();
        }
        getFilter(positive, negative) {
            const positiveRe = utils.pattern.convertPatternsToRe(positive, this._micromatchOptions);
            const negativeRe = utils.pattern.convertPatternsToRe(negative, this._micromatchOptions);
            return (entry) => this._filter(entry, positiveRe, negativeRe);
        }
        _filter(entry, positiveRe, negativeRe) {
            if (this._settings.unique && this._isDuplicateEntry(entry)) {
                return false;
            }
            if (this._onlyFileFilter(entry) || this._onlyDirectoryFilter(entry)) {
                return false;
            }
            if (this._isSkippedByAbsoluteNegativePatterns(entry.path, negativeRe)) {
                return false;
            }
            const filepath = this._settings.baseNameMatch ? entry.name : entry.path;
            const isDirectory = entry.dirent.isDirectory();
            const isMatched = this._isMatchToPatterns(filepath, positiveRe, isDirectory) && !this._isMatchToPatterns(entry.path, negativeRe, isDirectory);
            if (this._settings.unique && isMatched) {
                this._createIndexRecord(entry);
            }
            return isMatched;
        }
        _isDuplicateEntry(entry) {
            return this.index.has(entry.path);
        }
        _createIndexRecord(entry) {
            this.index.set(entry.path, undefined);
        }
        _onlyFileFilter(entry) {
            return this._settings.onlyFiles && !entry.dirent.isFile();
        }
        _onlyDirectoryFilter(entry) {
            return this._settings.onlyDirectories && !entry.dirent.isDirectory();
        }
        _isSkippedByAbsoluteNegativePatterns(entryPath, patternsRe) {
            if (!this._settings.absolute) {
                return false;
            }
            const fullpath = utils.path.makeAbsolute(this._settings.cwd, entryPath);
            return utils.pattern.matchAny(fullpath, patternsRe);
        }
        _isMatchToPatterns(entryPath, patternsRe, isDirectory) {
            const filepath = utils.path.removeLeadingDotSegment(entryPath);
            // Trying to match files and directories by patterns.
            const isMatched = utils.pattern.matchAny(filepath, patternsRe);
            // A pattern with a trailling slash can be used for directory matching.
            // To apply such pattern, we need to add a tralling slash to the path.
            if (!isMatched && isDirectory) {
                return utils.pattern.matchAny(filepath + '/', patternsRe);
            }
            return isMatched;
        }
    }
    exports.default = EntryFilter;
},
/* fast-glob/out/providers/filters/error.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils = require(1098) /* ../../utils */;
    class ErrorFilter {
        constructor(_settings) {
            this._settings = _settings;
        }
        getFilter() {
            return (error) => this._isNonFatalError(error);
        }
        _isNonFatalError(error) {
            return utils.errno.isEnoentCodeError(error) || this._settings.suppressErrors;
        }
    }
    exports.default = ErrorFilter;
},
/* fast-glob/out/providers/transformers/entry.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils = require(1098) /* ../../utils */;
    class EntryTransformer {
        constructor(_settings) {
            this._settings = _settings;
        }
        getTransformer() {
            return (entry) => this._transform(entry);
        }
        _transform(entry) {
            let filepath = entry.path;
            if (this._settings.absolute) {
                filepath = utils.path.makeAbsolute(this._settings.cwd, filepath);
                filepath = utils.path.unixify(filepath);
            }
            if (this._settings.markDirectories && entry.dirent.isDirectory()) {
                filepath += '/';
            }
            if (!this._settings.objectMode) {
                return filepath;
            }
            return Object.assign(Object.assign({}, entry), { path: filepath });
        }
    }
    exports.default = EntryTransformer;
},
/* fast-glob/out/providers/stream.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const stream_1 = require("stream");
    const stream_2 = require(1127) /* ../readers/stream */;
    const provider_1 = require(1128) /* ./provider */;
    class ProviderStream extends provider_1.default {
        constructor() {
            super(...arguments);
            this._reader = new stream_2.default(this._settings);
        }
        read(task) {
            const root = this._getRootDirectory(task);
            const options = this._getReaderOptions(task);
            const source = this.api(root, task, options);
            const destination = new stream_1.Readable({ objectMode: true, read: () => { } });
            source
                .once('error', (error) => destination.emit('error', error))
                .on('data', (entry) => destination.emit('data', options.transform(entry)))
                .once('end', () => destination.emit('end'));
            destination
                .once('close', () => source.destroy());
            return destination;
        }
        api(root, task, options) {
            if (task.dynamic) {
                return this._reader.dynamic(root, options);
            }
            return this._reader.static(task.patterns, options);
        }
    }
    exports.default = ProviderStream;
},
/* fast-glob/out/providers/sync.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const sync_1 = require(1137) /* ../readers/sync */;
    const provider_1 = require(1128) /* ./provider */;
    class ProviderSync extends provider_1.default {
        constructor() {
            super(...arguments);
            this._reader = new sync_1.default(this._settings);
        }
        read(task) {
            const root = this._getRootDirectory(task);
            const options = this._getReaderOptions(task);
            const entries = this.api(root, task, options);
            return entries.map(options.transform);
        }
        api(root, task, options) {
            if (task.dynamic) {
                return this._reader.dynamic(root, options);
            }
            return this._reader.static(task.patterns, options);
        }
    }
    exports.default = ProviderSync;
},
/* fast-glob/out/readers/sync.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const fsStat = require(740) /* @nodelib/fs.stat */;
    const fsWalk = require(735) /* @nodelib/fs.walk */;
    const reader_1 = require(1126) /* ./reader */;
    class ReaderSync extends reader_1.default {
        constructor() {
            super(...arguments);
            this._walkSync = fsWalk.walkSync;
            this._statSync = fsStat.statSync;
        }
        dynamic(root, options) {
            return this._walkSync(root, options);
        }
        static(patterns, options) {
            const entries = [];
            for (const pattern of patterns) {
                const filepath = this._getFullEntryPath(pattern);
                const entry = this._getEntry(filepath, pattern, options);
                if (entry === null || !options.entryFilter(entry)) {
                    continue;
                }
                entries.push(entry);
            }
            return entries;
        }
        _getEntry(filepath, pattern, options) {
            try {
                const stats = this._getStat(filepath);
                return this._makeEntry(stats, pattern);
            }
            catch (error) {
                if (options.errorFilter(error)) {
                    return null;
                }
                throw error;
            }
        }
        _getStat(filepath) {
            return this._statSync(filepath, this._fsStatSettings);
        }
    }
    exports.default = ReaderSync;
},
/* fast-glob/out/settings.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.DEFAULT_FILE_SYSTEM_ADAPTER = void 0;
    const fs = require("fs");
    const os = require("os");
    /**
     * The `os.cpus` method can return zero. We expect the number of cores to be greater than zero.
     * https://github.com/nodejs/node/blob/7faeddf23a98c53896f8b574a6e66589e8fb1eb8/lib/os.js#L106-L107
     */
    const CPU_COUNT = Math.max(os.cpus().length, 1);
    exports.DEFAULT_FILE_SYSTEM_ADAPTER = {
        lstat: fs.lstat,
        lstatSync: fs.lstatSync,
        stat: fs.stat,
        statSync: fs.statSync,
        readdir: fs.readdir,
        readdirSync: fs.readdirSync
    };
    class Settings {
        constructor(_options = {}) {
            this._options = _options;
            this.absolute = this._getValue(this._options.absolute, false);
            this.baseNameMatch = this._getValue(this._options.baseNameMatch, false);
            this.braceExpansion = this._getValue(this._options.braceExpansion, true);
            this.caseSensitiveMatch = this._getValue(this._options.caseSensitiveMatch, true);
            this.concurrency = this._getValue(this._options.concurrency, CPU_COUNT);
            this.cwd = this._getValue(this._options.cwd, process.cwd());
            this.deep = this._getValue(this._options.deep, Infinity);
            this.dot = this._getValue(this._options.dot, false);
            this.extglob = this._getValue(this._options.extglob, true);
            this.followSymbolicLinks = this._getValue(this._options.followSymbolicLinks, true);
            this.fs = this._getFileSystemMethods(this._options.fs);
            this.globstar = this._getValue(this._options.globstar, true);
            this.ignore = this._getValue(this._options.ignore, []);
            this.markDirectories = this._getValue(this._options.markDirectories, false);
            this.objectMode = this._getValue(this._options.objectMode, false);
            this.onlyDirectories = this._getValue(this._options.onlyDirectories, false);
            this.onlyFiles = this._getValue(this._options.onlyFiles, true);
            this.stats = this._getValue(this._options.stats, false);
            this.suppressErrors = this._getValue(this._options.suppressErrors, false);
            this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, false);
            this.unique = this._getValue(this._options.unique, true);
            if (this.onlyDirectories) {
                this.onlyFiles = false;
            }
            if (this.stats) {
                this.objectMode = true;
            }
        }
        _getValue(option, value) {
            return option === undefined ? value : option;
        }
        _getFileSystemMethods(methods = {}) {
            return Object.assign(Object.assign({}, exports.DEFAULT_FILE_SYSTEM_ADAPTER), methods);
        }
    }
    exports.default = Settings;
},
/* dir-glob/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const path = require('path');
    const pathType = require(1140) /* path-type */;
    const getExtensions = extensions => extensions.length > 1 ? `{${extensions.join(',')}}` : extensions[0];
    const getPath = (filepath, cwd) => {
        const pth = filepath[0] === '!' ? filepath.slice(1) : filepath;
        return path.isAbsolute(pth) ? pth : path.join(cwd, pth);
    };
    const addExtensions = (file, extensions) => {
        if (path.extname(file)) {
            return `**/${file}`;
        }
        return `**/${file}.${getExtensions(extensions)}`;
    };
    const getGlob = (directory, options) => {
        if (options.files && !Array.isArray(options.files)) {
            throw new TypeError(`Expected \`files\` to be of type \`Array\` but received type \`${typeof options.files}\``);
        }
        if (options.extensions && !Array.isArray(options.extensions)) {
            throw new TypeError(`Expected \`extensions\` to be of type \`Array\` but received type \`${typeof options.extensions}\``);
        }
        if (options.files && options.extensions) {
            return options.files.map(x => path.posix.join(directory, addExtensions(x, options.extensions)));
        }
        if (options.files) {
            return options.files.map(x => path.posix.join(directory, `**/${x}`));
        }
        if (options.extensions) {
            return [path.posix.join(directory, `**/*.${getExtensions(options.extensions)}`)];
        }
        return [path.posix.join(directory, '**')];
    };
    module.exports = async (input, options) => {
        options = {
            cwd: process.cwd(),
            ...options
        };
        if (typeof options.cwd !== 'string') {
            throw new TypeError(`Expected \`cwd\` to be of type \`string\` but received type \`${typeof options.cwd}\``);
        }
        const globs = await Promise.all([].concat(input).map(async (x) => {
            const isDirectory = await pathType.isDirectory(getPath(x, options.cwd));
            return isDirectory ? getGlob(x, options) : x;
        }));
        return [].concat.apply([], globs); // eslint-disable-line prefer-spread
    };
    module.exports.sync = (input, options) => {
        options = {
            cwd: process.cwd(),
            ...options
        };
        if (typeof options.cwd !== 'string') {
            throw new TypeError(`Expected \`cwd\` to be of type \`string\` but received type \`${typeof options.cwd}\``);
        }
        const globs = [].concat(input).map(x => pathType.isDirectorySync(getPath(x, options.cwd)) ? getGlob(x, options) : x);
        return [].concat.apply([], globs); // eslint-disable-line prefer-spread
    };
},
/* path-type/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const { promisify } = require('util');
    const fs = require('fs');
    async function isType(fsStatType, statsMethodName, filePath) {
        if (typeof filePath !== 'string') {
            throw new TypeError(`Expected a string, got ${typeof filePath}`);
        }
        try {
            const stats = await promisify(fs[fsStatType])(filePath);
            return stats[statsMethodName]();
        }
        catch (error) {
            if (error.code === 'ENOENT') {
                return false;
            }
            throw error;
        }
    }
    function isTypeSync(fsStatType, statsMethodName, filePath) {
        if (typeof filePath !== 'string') {
            throw new TypeError(`Expected a string, got ${typeof filePath}`);
        }
        try {
            return fs[fsStatType](filePath)[statsMethodName]();
        }
        catch (error) {
            if (error.code === 'ENOENT') {
                return false;
            }
            throw error;
        }
    }
    exports.isFile = isType.bind(null, 'stat', 'isFile');
    exports.isDirectory = isType.bind(null, 'stat', 'isDirectory');
    exports.isSymlink = isType.bind(null, 'lstat', 'isSymbolicLink');
    exports.isFileSync = isTypeSync.bind(null, 'statSync', 'isFile');
    exports.isDirectorySync = isTypeSync.bind(null, 'statSync', 'isDirectory');
    exports.isSymlinkSync = isTypeSync.bind(null, 'lstatSync', 'isSymbolicLink');
},
/* globby/gitignore.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const { promisify } = require('util');
    const fs = require('fs');
    const path = require('path');
    const fastGlob = require(1096) /* fast-glob */;
    const gitIgnore = require(228) /* ignore */;
    const slash = require(1142) /* slash */;
    const DEFAULT_IGNORE = [
        '**/node_modules/**',
        '**/flow-typed/**',
        '**/coverage/**',
        '**/.git'
    ];
    const readFileP = promisify(fs.readFile);
    const mapGitIgnorePatternTo = base => ignore => {
        if (ignore.startsWith('!')) {
            return '!' + path.posix.join(base, ignore.slice(1));
        }
        return path.posix.join(base, ignore);
    };
    const parseGitIgnore = (content, options) => {
        const base = slash(path.relative(options.cwd, path.dirname(options.fileName)));
        return content
            .split(/\r?\n/)
            .filter(Boolean)
            .filter(line => !line.startsWith('#'))
            .map(mapGitIgnorePatternTo(base));
    };
    const reduceIgnore = files => {
        const ignores = gitIgnore();
        for (const file of files) {
            ignores.add(parseGitIgnore(file.content, {
                cwd: file.cwd,
                fileName: file.filePath
            }));
        }
        return ignores;
    };
    const ensureAbsolutePathForCwd = (cwd, p) => {
        cwd = slash(cwd);
        if (path.isAbsolute(p)) {
            if (slash(p).startsWith(cwd)) {
                return p;
            }
            throw new Error(`Path ${p} is not in cwd ${cwd}`);
        }
        return path.join(cwd, p);
    };
    const getIsIgnoredPredecate = (ignores, cwd) => {
        return p => ignores.ignores(slash(path.relative(cwd, ensureAbsolutePathForCwd(cwd, p.path || p))));
    };
    const getFile = async (file, cwd) => {
        const filePath = path.join(cwd, file);
        const content = await readFileP(filePath, 'utf8');
        return {
            cwd,
            filePath,
            content
        };
    };
    const getFileSync = (file, cwd) => {
        const filePath = path.join(cwd, file);
        const content = fs.readFileSync(filePath, 'utf8');
        return {
            cwd,
            filePath,
            content
        };
    };
    const normalizeOptions = ({ ignore = [], cwd = slash(process.cwd()) } = {}) => {
        return { ignore, cwd };
    };
    module.exports = async (options) => {
        options = normalizeOptions(options);
        const paths = await fastGlob('**/.gitignore', {
            ignore: DEFAULT_IGNORE.concat(options.ignore),
            cwd: options.cwd
        });
        const files = await Promise.all(paths.map(file => getFile(file, options.cwd)));
        const ignores = reduceIgnore(files);
        return getIsIgnoredPredecate(ignores, options.cwd);
    };
    module.exports.sync = options => {
        options = normalizeOptions(options);
        const paths = fastGlob.sync('**/.gitignore', {
            ignore: DEFAULT_IGNORE.concat(options.ignore),
            cwd: options.cwd
        });
        const files = paths.map(file => getFileSync(file, options.cwd));
        const ignores = reduceIgnore(files);
        return getIsIgnoredPredecate(ignores, options.cwd);
    };
},
/* slash/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = path => {
        const isExtendedLengthPath = /^\\\\\?\\/.test(path);
        const hasNonAscii = /[^\u0000-\u0080]+/.test(path); // eslint-disable-line no-control-regex
        if (isExtendedLengthPath || hasNonAscii) {
            return path;
        }
        return path.replace(/\\/g, '/');
    };
},
/* globby/stream-utils.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const { Transform } = require('stream');
    class ObjectTransform extends Transform {
        constructor() {
            super({
                objectMode: true
            });
        }
    }
    class FilterStream extends ObjectTransform {
        constructor(filter) {
            super();
            this._filter = filter;
        }
        _transform(data, encoding, callback) {
            if (this._filter(data)) {
                this.push(data);
            }
            callback();
        }
    }
    class UniqueStream extends ObjectTransform {
        constructor() {
            super();
            this._pushed = new Set();
        }
        _transform(data, encoding, callback) {
            if (!this._pushed.has(data)) {
                this.push(data);
                this._pushed.add(data);
            }
            callback();
        }
    }
    module.exports = {
        FilterStream,
        UniqueStream
    };
},
/* @typescript-eslint/typescript-estree/dist/parseSettings/warnAboutTSVersion.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.warnAboutTSVersion = void 0;
    const semver_1 = __importDefault(require(802) /* semver */);
    const ts = __importStar(require(21) /* typescript */);
    /**
     * This needs to be kept in sync with /docs/maintenance/Versioning.md
     * in the typescript-eslint monorepo
     */
    const SUPPORTED_TYPESCRIPT_VERSIONS = '>=3.3.1 <5.1.0';
    /*
     * The semver package will ignore prerelease ranges, and we don't want to explicitly document every one
     * List them all separately here, so we can automatically create the full string
     */
    const SUPPORTED_PRERELEASE_RANGES = ['5.0.1-rc'];
    const ACTIVE_TYPESCRIPT_VERSION = ts.version;
    const isRunningSupportedTypeScriptVersion = semver_1.default.satisfies(ACTIVE_TYPESCRIPT_VERSION, [SUPPORTED_TYPESCRIPT_VERSIONS]
        .concat(SUPPORTED_PRERELEASE_RANGES)
        .join(' || '));
    let warnedAboutTSVersion = false;
    function warnAboutTSVersion(parseSettings) {
        var _a;
        if (!isRunningSupportedTypeScriptVersion && !warnedAboutTSVersion) {
            const isTTY = typeof process === 'undefined' ? false : (_a = process.stdout) === null || _a === void 0 ? void 0 : _a.isTTY;
            if (isTTY) {
                const border = '=============';
                const versionWarning = [
                    border,
                    'WARNING: You are currently running a version of TypeScript which is not officially supported by @typescript-eslint/typescript-estree.',
                    'You may find that it works just fine, or you may not.',
                    `SUPPORTED TYPESCRIPT VERSIONS: ${SUPPORTED_TYPESCRIPT_VERSIONS}`,
                    `YOUR TYPESCRIPT VERSION: ${ACTIVE_TYPESCRIPT_VERSION}`,
                    'Please only submit bug reports when using the officially supported version.',
                    border,
                ];
                parseSettings.log(versionWarning.join('\n\n'));
            }
            warnedAboutTSVersion = true;
        }
    }
    exports.warnAboutTSVersion = warnAboutTSVersion;
    
},
/* @typescript-eslint/typescript-estree/dist/semantic-or-syntactic-errors.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getFirstSemanticOrSyntacticError = void 0;
    const typescript_1 = require(21) /* typescript */;
    /**
     * By default, diagnostics from the TypeScript compiler contain all errors - regardless of whether
     * they are related to generic ECMAScript standards, or TypeScript-specific constructs.
     *
     * Therefore, we filter out all diagnostics, except for the ones we explicitly want to consider when
     * the user opts in to throwing errors on semantic issues.
     */
    function getFirstSemanticOrSyntacticError(program, ast) {
        try {
            const supportedSyntacticDiagnostics = whitelistSupportedDiagnostics(program.getSyntacticDiagnostics(ast));
            if (supportedSyntacticDiagnostics.length) {
                return convertDiagnosticToSemanticOrSyntacticError(supportedSyntacticDiagnostics[0]);
            }
            const supportedSemanticDiagnostics = whitelistSupportedDiagnostics(program.getSemanticDiagnostics(ast));
            if (supportedSemanticDiagnostics.length) {
                return convertDiagnosticToSemanticOrSyntacticError(supportedSemanticDiagnostics[0]);
            }
            return undefined;
        }
        catch (e) {
            /**
             * TypeScript compiler has certain Debug.fail() statements in, which will cause the diagnostics
             * retrieval above to throw.
             *
             * E.g. from ast-alignment-tests
             * "Debug Failure. Shouldn't ever directly check a JsxOpeningElement"
             *
             * For our current use-cases this is undesired behavior, so we just suppress it
             * and log a a warning.
             */
            /* istanbul ignore next */
            console.warn(`Warning From TSC: "${e.message}`); // eslint-disable-line no-console
            /* istanbul ignore next */
            return undefined;
        }
    }
    exports.getFirstSemanticOrSyntacticError = getFirstSemanticOrSyntacticError;
    function whitelistSupportedDiagnostics(diagnostics) {
        return diagnostics.filter(diagnostic => {
            switch (diagnostic.code) {
                case 1013: // "A rest parameter or binding pattern may not have a trailing comma."
                case 1014: // "A rest parameter must be last in a parameter list."
                case 1044: // "'{0}' modifier cannot appear on a module or namespace element."
                case 1045: // "A '{0}' modifier cannot be used with an interface declaration."
                case 1048: // "A rest parameter cannot have an initializer."
                case 1049: // "A 'set' accessor must have exactly one parameter."
                case 1070: // "'{0}' modifier cannot appear on a type member."
                case 1071: // "'{0}' modifier cannot appear on an index signature."
                case 1085: // "Octal literals are not available when targeting ECMAScript 5 and higher. Use the syntax '{0}'."
                case 1090: // "'{0}' modifier cannot appear on a parameter."
                case 1096: // "An index signature must have exactly one parameter."
                case 1097: // "'{0}' list cannot be empty."
                case 1098: // "Type parameter list cannot be empty."
                case 1099: // "Type argument list cannot be empty."
                case 1117: // "An object literal cannot have multiple properties with the same name in strict mode."
                case 1121: // "Octal literals are not allowed in strict mode."
                case 1123: //  "Variable declaration list cannot be empty."
                case 1141: // "String literal expected."
                case 1162: // "An object member cannot be declared optional."
                case 1164: // "Computed property names are not allowed in enums."
                case 1172: // "'extends' clause already seen."
                case 1173: // "'extends' clause must precede 'implements' clause."
                case 1175: // "'implements' clause already seen."
                case 1176: // "Interface declaration cannot have 'implements' clause."
                case 1190: // "The variable declaration of a 'for...of' statement cannot have an initializer."
                case 1196: // "Catch clause variable type annotation must be 'any' or 'unknown' if specified."
                case 1200: // "Line terminator not permitted before arrow."
                case 1206: // "Decorators are not valid here."
                case 1211: // "A class declaration without the 'default' modifier must have a name."
                case 1242: // "'abstract' modifier can only appear on a class, method, or property declaration."
                case 1246: // "An interface property cannot have an initializer."
                case 1255: // "A definite assignment assertion '!' is not permitted in this context."
                case 1308: // "'await' expression is only allowed within an async function."
                case 2364: // "The left-hand side of an assignment expression must be a variable or a property access."
                case 2369: // "A parameter property is only allowed in a constructor implementation."
                case 2452: // "An enum member cannot have a numeric name."
                case 2462: // "A rest element must be last in a destructuring pattern."
                case 8017: // "Octal literal types must use ES2015 syntax. Use the syntax '{0}'."
                case 17012: // "'{0}' is not a valid meta-property for keyword '{1}'. Did you mean '{2}'?"
                case 17013: // "Meta-property '{0}' is only allowed in the body of a function declaration, function expression, or constructor."
                    return true;
            }
            return false;
        });
    }
    function convertDiagnosticToSemanticOrSyntacticError(diagnostic) {
        return Object.assign(Object.assign({}, diagnostic), { message: (0, typescript_1.flattenDiagnosticMessageText)(diagnostic.messageText, typescript_1.sys.newLine) });
    }
    
},
/* @typescript-eslint/typescript-estree/dist/clear-caches.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.clearProgramCache = exports.clearCaches = void 0;
    const getWatchProgramsForProjects_1 = require(1085) /* ./create-program/getWatchProgramsForProjects */;
    const parser_1 = require(1067) /* ./parser */;
    const createParseSettings_1 = require(1088) /* ./parseSettings/createParseSettings */;
    const resolveProjectList_1 = require(1092) /* ./parseSettings/resolveProjectList */;
    /**
     * Clears all of the internal caches.
     * Generally you shouldn't need or want to use this.
     * Examples of intended uses:
     * - In tests to reset parser state to keep tests isolated.
     * - In custom lint tooling that iteratively lints one project at a time to prevent OOMs.
     */
    function clearCaches() {
        (0, parser_1.clearProgramCache)();
        (0, getWatchProgramsForProjects_1.clearWatchCaches)();
        (0, createParseSettings_1.clearTSConfigMatchCache)();
        (0, resolveProjectList_1.clearGlobCache)();
    }
    exports.clearCaches = clearCaches;
    // TODO - delete this in next major
    exports.clearProgramCache = clearCaches;
    
},
/* @typescript-eslint/typescript-estree/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "@typescript-eslint/typescript-estree",
        "version": "5.55.0",
        "description": "A parser that converts TypeScript source code into an ESTree compatible form",
        "main": "dist/index.js",
        "types": "dist/index.d.ts",
        "files": [
            "dist",
            "_ts3.4",
            "README.md",
            "LICENSE"
        ],
        "engines": {
            "node": "^12.22.0 || ^14.17.0 || >=16.0.0"
        },
        "repository": {
            "type": "git",
            "url": "https://github.com/typescript-eslint/typescript-eslint.git",
            "directory": "packages/typescript-estree"
        },
        "bugs": {
            "url": "https://github.com/typescript-eslint/typescript-eslint/issues"
        },
        "license": "BSD-2-Clause",
        "keywords": [
            "ast",
            "estree",
            "ecmascript",
            "javascript",
            "typescript",
            "parser",
            "syntax"
        ],
        "scripts": {
            "build": "tsc -b tsconfig.build.json",
            "postbuild": "downlevel-dts dist _ts3.4/dist",
            "clean": "tsc -b tsconfig.build.json --clean",
            "postclean": "rimraf dist && rimraf _ts3.4 && rimraf coverage",
            "format": "prettier --write \"./**/*.{ts,mts,cts,tsx,js,mjs,cjs,jsx,json,md,css}\" --ignore-path ../../.prettierignore",
            "lint": "nx lint",
            "test": "jest --coverage",
            "typecheck": "tsc -p tsconfig.json --noEmit"
        },
        "dependencies": {
            "@typescript-eslint/types": "5.55.0",
            "@typescript-eslint/visitor-keys": "5.55.0",
            "debug": "^4.3.4",
            "globby": "^11.1.0",
            "is-glob": "^4.0.3",
            "semver": "^7.3.7",
            "tsutils": "^3.21.0"
        },
        "devDependencies": {
            "@babel/code-frame": "*",
            "@babel/parser": "*",
            "@types/babel__code-frame": "*",
            "@types/debug": "*",
            "@types/glob": "*",
            "@types/is-glob": "*",
            "@types/semver": "*",
            "@types/tmp": "*",
            "glob": "*",
            "jest-specific-snapshot": "*",
            "make-dir": "*",
            "tmp": "*",
            "typescript": "*"
        },
        "peerDependenciesMeta": {
            "typescript": {
                "optional": true
            }
        },
        "funding": {
            "type": "opencollective",
            "url": "https://opencollective.com/typescript-eslint"
        },
        "typesVersions": {
            "<3.8": {
                "*": [
                    "_ts3.4/*"
                ]
            }
        },
        "gitHead": "877d73327fca3bdbe7e170e8b3a906d090a6de37"
    };
    module.exports = json;
},
/* @typescript-eslint/eslint-plugin/dist/util/objectIterators.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.objectReduceKey = exports.objectMapKey = exports.objectForEachKey = void 0;
    function objectForEachKey(obj, callback) {
        const keys = Object.keys(obj);
        for (const key of keys) {
            callback(key);
        }
    }
    exports.objectForEachKey = objectForEachKey;
    function objectMapKey(obj, callback) {
        const values = [];
        objectForEachKey(obj, key => {
            values.push(callback(key));
        });
        return values;
    }
    exports.objectMapKey = objectMapKey;
    function objectReduceKey(obj, callback, initial) {
        let accumulator = initial;
        objectForEachKey(obj, key => {
            accumulator = callback(accumulator, key);
        });
        return accumulator;
    }
    exports.objectReduceKey = objectReduceKey;
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/array-type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    /**
     * Check whatever node can be considered as simple
     * @param node the node to be evaluated.
     */
    function isSimpleType(node) {
        switch (node.type) {
            case utils_1.AST_NODE_TYPES.Identifier:
            case utils_1.AST_NODE_TYPES.TSAnyKeyword:
            case utils_1.AST_NODE_TYPES.TSBooleanKeyword:
            case utils_1.AST_NODE_TYPES.TSNeverKeyword:
            case utils_1.AST_NODE_TYPES.TSNumberKeyword:
            case utils_1.AST_NODE_TYPES.TSBigIntKeyword:
            case utils_1.AST_NODE_TYPES.TSObjectKeyword:
            case utils_1.AST_NODE_TYPES.TSStringKeyword:
            case utils_1.AST_NODE_TYPES.TSSymbolKeyword:
            case utils_1.AST_NODE_TYPES.TSUnknownKeyword:
            case utils_1.AST_NODE_TYPES.TSVoidKeyword:
            case utils_1.AST_NODE_TYPES.TSNullKeyword:
            case utils_1.AST_NODE_TYPES.TSArrayType:
            case utils_1.AST_NODE_TYPES.TSUndefinedKeyword:
            case utils_1.AST_NODE_TYPES.TSThisType:
            case utils_1.AST_NODE_TYPES.TSQualifiedName:
                return true;
            case utils_1.AST_NODE_TYPES.TSTypeReference:
                if (node.typeName &&
                    node.typeName.type === utils_1.AST_NODE_TYPES.Identifier &&
                    node.typeName.name === 'Array') {
                    if (!node.typeParameters) {
                        return true;
                    }
                    if (node.typeParameters.params.length === 1) {
                        return isSimpleType(node.typeParameters.params[0]);
                    }
                }
                else {
                    if (node.typeParameters) {
                        return false;
                    }
                    return isSimpleType(node.typeName);
                }
                return false;
            default:
                return false;
        }
    }
    /**
     * Check if node needs parentheses
     * @param node the node to be evaluated.
     */
    function typeNeedsParentheses(node) {
        switch (node.type) {
            case utils_1.AST_NODE_TYPES.TSTypeReference:
                return typeNeedsParentheses(node.typeName);
            case utils_1.AST_NODE_TYPES.TSUnionType:
            case utils_1.AST_NODE_TYPES.TSFunctionType:
            case utils_1.AST_NODE_TYPES.TSIntersectionType:
            case utils_1.AST_NODE_TYPES.TSTypeOperator:
            case utils_1.AST_NODE_TYPES.TSInferType:
            case utils_1.AST_NODE_TYPES.TSConstructorType:
                return true;
            case utils_1.AST_NODE_TYPES.Identifier:
                return node.name === 'ReadonlyArray';
            default:
                return false;
        }
    }
    exports.default = util.createRule({
        name: 'array-type',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require consistently using either `T[]` or `Array<T>` for arrays',
                recommended: 'strict',
            },
            fixable: 'code',
            messages: {
                errorStringGeneric: "Array type using '{{readonlyPrefix}}{{type}}[]' is forbidden. Use '{{className}}<{{type}}>' instead.",
                errorStringArray: "Array type using '{{className}}<{{type}}>' is forbidden. Use '{{readonlyPrefix}}{{type}}[]' instead.",
                errorStringArraySimple: "Array type using '{{className}}<{{type}}>' is forbidden for simple types. Use '{{readonlyPrefix}}{{type}}[]' instead.",
                errorStringGenericSimple: "Array type using '{{readonlyPrefix}}{{type}}[]' is forbidden for non-simple types. Use '{{className}}<{{type}}>' instead.",
            },
            schema: {
                $defs: {
                    arrayOption: {
                        enum: ['array', 'generic', 'array-simple'],
                    },
                },
                prefixItems: [
                    {
                        properties: {
                            default: {
                                $ref: '#/$defs/arrayOption',
                                description: 'The array type expected for mutable cases...',
                            },
                            readonly: {
                                $ref: '#/$defs/arrayOption',
                                description: 'The array type expected for readonly cases. If omitted, the value for `default` will be used.',
                            },
                        },
                        type: 'object',
                    },
                ],
                type: 'array',
            },
        },
        defaultOptions: [
            {
                default: 'array',
            },
        ],
        create(context, [options]) {
            var _a;
            const sourceCode = context.getSourceCode();
            const defaultOption = options.default;
            const readonlyOption = (_a = options.readonly) !== null && _a !== void 0 ? _a : defaultOption;
            /**
             * @param node the node to be evaluated.
             */
            function getMessageType(node) {
                if (node && isSimpleType(node)) {
                    return sourceCode.getText(node);
                }
                return 'T';
            }
            return {
                TSArrayType(node) {
                    const isReadonly = node.parent &&
                        node.parent.type === utils_1.AST_NODE_TYPES.TSTypeOperator &&
                        node.parent.operator === 'readonly';
                    const currentOption = isReadonly ? readonlyOption : defaultOption;
                    if (currentOption === 'array' ||
                        (currentOption === 'array-simple' && isSimpleType(node.elementType))) {
                        return;
                    }
                    const messageId = currentOption === 'generic'
                        ? 'errorStringGeneric'
                        : 'errorStringGenericSimple';
                    const errorNode = isReadonly ? node.parent : node;
                    context.report({
                        node: errorNode,
                        messageId,
                        data: {
                            className: isReadonly ? 'ReadonlyArray' : 'Array',
                            readonlyPrefix: isReadonly ? 'readonly ' : '',
                            type: getMessageType(node.elementType),
                        },
                        fix(fixer) {
                            const typeNode = node.elementType;
                            const arrayType = isReadonly ? 'ReadonlyArray' : 'Array';
                            return [
                                fixer.replaceTextRange([errorNode.range[0], typeNode.range[0]], `${arrayType}<`),
                                fixer.replaceTextRange([typeNode.range[1], errorNode.range[1]], '>'),
                            ];
                        },
                    });
                },
                TSTypeReference(node) {
                    var _a, _b;
                    if (node.typeName.type !== utils_1.AST_NODE_TYPES.Identifier ||
                        !(node.typeName.name === 'Array' ||
                            node.typeName.name === 'ReadonlyArray')) {
                        return;
                    }
                    const isReadonlyArrayType = node.typeName.name === 'ReadonlyArray';
                    const currentOption = isReadonlyArrayType
                        ? readonlyOption
                        : defaultOption;
                    if (currentOption === 'generic') {
                        return;
                    }
                    const readonlyPrefix = isReadonlyArrayType ? 'readonly ' : '';
                    const typeParams = (_a = node.typeParameters) === null || _a === void 0 ? void 0 : _a.params;
                    const messageId = currentOption === 'array'
                        ? 'errorStringArray'
                        : 'errorStringArraySimple';
                    if (!typeParams || typeParams.length === 0) {
                        // Create an 'any' array
                        context.report({
                            node,
                            messageId,
                            data: {
                                className: isReadonlyArrayType ? 'ReadonlyArray' : 'Array',
                                readonlyPrefix,
                                type: 'any',
                            },
                            fix(fixer) {
                                return fixer.replaceText(node, `${readonlyPrefix}any[]`);
                            },
                        });
                        return;
                    }
                    if (typeParams.length !== 1 ||
                        (currentOption === 'array-simple' && !isSimpleType(typeParams[0]))) {
                        return;
                    }
                    const type = typeParams[0];
                    const typeParens = typeNeedsParentheses(type);
                    const parentParens = readonlyPrefix &&
                        ((_b = node.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.TSArrayType &&
                        !util.isParenthesized(node.parent.elementType, sourceCode);
                    const start = `${parentParens ? '(' : ''}${readonlyPrefix}${typeParens ? '(' : ''}`;
                    const end = `${typeParens ? ')' : ''}[]${parentParens ? ')' : ''}`;
                    context.report({
                        node,
                        messageId,
                        data: {
                            className: isReadonlyArrayType ? 'ReadonlyArray' : 'Array',
                            readonlyPrefix,
                            type: getMessageType(type),
                        },
                        fix(fixer) {
                            return [
                                fixer.replaceTextRange([node.range[0], type.range[0]], start),
                                fixer.replaceTextRange([type.range[1], node.range[1]], end),
                            ];
                        },
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/await-thenable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const tsutils = __importStar(require(1034) /* tsutils */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'await-thenable',
        meta: {
            docs: {
                description: 'Disallow awaiting a value that is not a Thenable',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                await: 'Unexpected `await` of a non-Promise (non-"Thenable") value.',
            },
            schema: [],
            type: 'problem',
        },
        defaultOptions: [],
        create(context) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            return {
                AwaitExpression(node) {
                    const originalNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                    const type = checker.getTypeAtLocation(originalNode.expression);
                    if (!util.isTypeAnyType(type) &&
                        !util.isTypeUnknownType(type) &&
                        !tsutils.isThenableType(checker, originalNode.expression, type)) {
                        context.report({
                            messageId: 'await',
                            node,
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/ban-ts-comment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.defaultMinimumDescriptionLength = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.defaultMinimumDescriptionLength = 3;
    exports.default = util.createRule({
        name: 'ban-ts-comment',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow `@ts-<directive>` comments or require descriptions after directives',
                recommended: 'error',
            },
            messages: {
                tsDirectiveComment: 'Do not use "@ts-{{directive}}" because it alters compilation errors.',
                tsDirectiveCommentRequiresDescription: 'Include a description after the "@ts-{{directive}}" directive to explain why the @ts-{{directive}} is necessary. The description must be {{minimumDescriptionLength}} characters or longer.',
                tsDirectiveCommentDescriptionNotMatchPattern: 'The description for the "@ts-{{directive}}" directive must match the {{format}} format.',
            },
            schema: {
                $defs: {
                    directiveConfigSchema: {
                        oneOf: [
                            {
                                type: 'boolean',
                                default: true,
                            },
                            {
                                enum: ['allow-with-description'],
                            },
                            {
                                type: 'object',
                                properties: {
                                    descriptionFormat: { type: 'string' },
                                },
                            },
                        ],
                    },
                },
                prefixItems: [
                    {
                        properties: {
                            'ts-expect-error': {
                                $ref: '#/$defs/directiveConfigSchema',
                            },
                            'ts-ignore': { $ref: '#/$defs/directiveConfigSchema' },
                            'ts-nocheck': { $ref: '#/$defs/directiveConfigSchema' },
                            'ts-check': { $ref: '#/$defs/directiveConfigSchema' },
                            minimumDescriptionLength: {
                                type: 'number',
                                default: exports.defaultMinimumDescriptionLength,
                            },
                        },
                        additionalProperties: false,
                    },
                ],
                type: 'array',
            },
        },
        defaultOptions: [
            {
                'ts-expect-error': 'allow-with-description',
                'ts-ignore': true,
                'ts-nocheck': true,
                'ts-check': false,
                minimumDescriptionLength: exports.defaultMinimumDescriptionLength,
            },
        ],
        create(context, [options]) {
            /*
              The regex used are taken from the ones used in the official TypeScript repo -
              https://github.com/microsoft/TypeScript/blob/408c760fae66080104bc85c449282c2d207dfe8e/src/compiler/scanner.ts#L288-L296
            */
            const commentDirectiveRegExSingleLine = /^\/*\s*@ts-(?<directive>expect-error|ignore|check|nocheck)(?<description>.*)/;
            const commentDirectiveRegExMultiLine = /^\s*(?:\/|\*)*\s*@ts-(?<directive>expect-error|ignore|check|nocheck)(?<description>.*)/;
            const sourceCode = context.getSourceCode();
            const descriptionFormats = new Map();
            for (const directive of [
                'ts-expect-error',
                'ts-ignore',
                'ts-nocheck',
                'ts-check',
            ]) {
                const option = options[directive];
                if (typeof option === 'object' && option.descriptionFormat) {
                    descriptionFormats.set(directive, new RegExp(option.descriptionFormat));
                }
            }
            return {
                Program() {
                    const comments = sourceCode.getAllComments();
                    comments.forEach(comment => {
                        const regExp = comment.type === utils_1.AST_TOKEN_TYPES.Line
                            ? commentDirectiveRegExSingleLine
                            : commentDirectiveRegExMultiLine;
                        const match = regExp.exec(comment.value);
                        if (!match) {
                            return;
                        }
                        const { directive, description } = match.groups;
                        const fullDirective = `ts-${directive}`;
                        const option = options[fullDirective];
                        if (option === true) {
                            context.report({
                                data: { directive },
                                node: comment,
                                messageId: 'tsDirectiveComment',
                            });
                        }
                        if (option === 'allow-with-description' ||
                            (typeof option === 'object' && option.descriptionFormat)) {
                            const { minimumDescriptionLength = exports.defaultMinimumDescriptionLength, } = options;
                            const format = descriptionFormats.get(fullDirective);
                            if (util.getStringLength(description.trim()) <
                                minimumDescriptionLength) {
                                context.report({
                                    data: { directive, minimumDescriptionLength },
                                    node: comment,
                                    messageId: 'tsDirectiveCommentRequiresDescription',
                                });
                            }
                            else if (format && !format.test(description)) {
                                context.report({
                                    data: { directive, format: format.source },
                                    node: comment,
                                    messageId: 'tsDirectiveCommentDescriptionNotMatchPattern',
                                });
                            }
                        }
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/ban-tslint-comment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    // tslint regex
    // https://github.com/palantir/tslint/blob/95d9d958833fd9dc0002d18cbe34db20d0fbf437/src/enableDisableRules.ts#L32
    const ENABLE_DISABLE_REGEX = /^\s*tslint:(enable|disable)(?:-(line|next-line))?(:|\s|$)/;
    const toText = (text, type) => type === utils_1.AST_TOKEN_TYPES.Line
        ? ['//', text.trim()].join(' ')
        : ['/*', text.trim(), '*/'].join(' ');
    exports.default = util.createRule({
        name: 'ban-tslint-comment',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow `// tslint:<rule-flag>` comments',
                recommended: 'strict',
            },
            messages: {
                commentDetected: 'tslint comment detected: "{{ text }}"',
            },
            schema: [],
            fixable: 'code',
        },
        defaultOptions: [],
        create: context => {
            const sourceCode = context.getSourceCode();
            return {
                Program() {
                    const comments = sourceCode.getAllComments();
                    comments.forEach(c => {
                        if (ENABLE_DISABLE_REGEX.test(c.value)) {
                            context.report({
                                data: { text: toText(c.value, c.type) },
                                node: c,
                                messageId: 'commentDetected',
                                fix(fixer) {
                                    const rangeStart = sourceCode.getIndexFromLoc({
                                        column: c.loc.start.column > 0 ? c.loc.start.column - 1 : 0,
                                        line: c.loc.start.line,
                                    });
                                    const rangeEnd = sourceCode.getIndexFromLoc({
                                        column: c.loc.end.column,
                                        line: c.loc.end.line,
                                    });
                                    return fixer.removeRange([rangeStart, rangeEnd + 1]);
                                },
                            });
                        }
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/ban-types.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TYPE_KEYWORDS = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    function removeSpaces(str) {
        return str.replace(/\s/g, '');
    }
    function stringifyNode(node, sourceCode) {
        return removeSpaces(sourceCode.getText(node));
    }
    function getCustomMessage(bannedType) {
        if (bannedType == null) {
            return '';
        }
        if (typeof bannedType === 'string') {
            return ` ${bannedType}`;
        }
        if (bannedType.message) {
            return ` ${bannedType.message}`;
        }
        return '';
    }
    const defaultTypes = {
        String: {
            message: 'Use string instead',
            fixWith: 'string',
        },
        Boolean: {
            message: 'Use boolean instead',
            fixWith: 'boolean',
        },
        Number: {
            message: 'Use number instead',
            fixWith: 'number',
        },
        Symbol: {
            message: 'Use symbol instead',
            fixWith: 'symbol',
        },
        BigInt: {
            message: 'Use bigint instead',
            fixWith: 'bigint',
        },
        Function: {
            message: [
                'The `Function` type accepts any function-like value.',
                'It provides no type safety when calling the function, which can be a common source of bugs.',
                'It also accepts things like class declarations, which will throw at runtime as they will not be called with `new`.',
                'If you are expecting the function to accept certain arguments, you should explicitly define the function shape.',
            ].join('\n'),
        },
        // object typing
        Object: {
            message: [
                'The `Object` type actually means "any non-nullish value", so it is marginally better than `unknown`.',
                '- If you want a type meaning "any object", you probably want `object` instead.',
                '- If you want a type meaning "any value", you probably want `unknown` instead.',
            ].join('\n'),
        },
        '{}': {
            message: [
                '`{}` actually means "any non-nullish value".',
                '- If you want a type meaning "any object", you probably want `object` instead.',
                '- If you want a type meaning "any value", you probably want `unknown` instead.',
                '- If you want a type meaning "empty object", you probably want `Record<string, never>` instead.',
            ].join('\n'),
        },
    };
    exports.TYPE_KEYWORDS = {
        bigint: utils_1.AST_NODE_TYPES.TSBigIntKeyword,
        boolean: utils_1.AST_NODE_TYPES.TSBooleanKeyword,
        never: utils_1.AST_NODE_TYPES.TSNeverKeyword,
        null: utils_1.AST_NODE_TYPES.TSNullKeyword,
        number: utils_1.AST_NODE_TYPES.TSNumberKeyword,
        object: utils_1.AST_NODE_TYPES.TSObjectKeyword,
        string: utils_1.AST_NODE_TYPES.TSStringKeyword,
        symbol: utils_1.AST_NODE_TYPES.TSSymbolKeyword,
        undefined: utils_1.AST_NODE_TYPES.TSUndefinedKeyword,
        unknown: utils_1.AST_NODE_TYPES.TSUnknownKeyword,
        void: utils_1.AST_NODE_TYPES.TSVoidKeyword,
    };
    exports.default = util.createRule({
        name: 'ban-types',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow certain types',
                recommended: 'error',
            },
            fixable: 'code',
            messages: {
                bannedTypeMessage: "Don't use `{{name}}` as a type.{{customMessage}}",
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        types: {
                            type: 'object',
                            additionalProperties: {
                                oneOf: [
                                    { type: 'null' },
                                    { type: 'boolean' },
                                    { type: 'string' },
                                    {
                                        type: 'object',
                                        properties: {
                                            message: { type: 'string' },
                                            fixWith: { type: 'string' },
                                        },
                                        additionalProperties: false,
                                    },
                                ],
                            },
                        },
                        extendDefaults: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [{}],
        create(context, [options]) {
            var _a, _b;
            const extendDefaults = (_a = options.extendDefaults) !== null && _a !== void 0 ? _a : true;
            const customTypes = (_b = options.types) !== null && _b !== void 0 ? _b : {};
            const types = Object.assign({}, extendDefaults ? defaultTypes : {}, customTypes);
            const bannedTypes = new Map(Object.entries(types).map(([type, data]) => [removeSpaces(type), data]));
            function checkBannedTypes(typeNode, name = stringifyNode(typeNode, context.getSourceCode())) {
                const bannedType = bannedTypes.get(name);
                if (bannedType === undefined || bannedType === false) {
                    return;
                }
                const customMessage = getCustomMessage(bannedType);
                const fixWith = bannedType && typeof bannedType === 'object' && bannedType.fixWith;
                context.report({
                    node: typeNode,
                    messageId: 'bannedTypeMessage',
                    data: {
                        name,
                        customMessage,
                    },
                    fix: fixWith
                        ? (fixer) => fixer.replaceText(typeNode, fixWith)
                        : null,
                });
            }
            const keywordSelectors = util.objectReduceKey(exports.TYPE_KEYWORDS, (acc, keyword) => {
                if (bannedTypes.has(keyword)) {
                    acc[exports.TYPE_KEYWORDS[keyword]] = (node) => checkBannedTypes(node, keyword);
                }
                return acc;
            }, {});
            return Object.assign(Object.assign({}, keywordSelectors), { TSTypeLiteral(node) {
                    if (node.members.length) {
                        return;
                    }
                    checkBannedTypes(node);
                },
                TSTupleType(node) {
                    if (node.elementTypes.length === 0) {
                        checkBannedTypes(node);
                    }
                },
                TSTypeReference(node) {
                    checkBannedTypes(node.typeName);
                    if (node.typeParameters) {
                        checkBannedTypes(node);
                    }
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/block-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('block-spacing');
    exports.default = util.createRule({
        name: 'block-spacing',
        meta: {
            type: 'layout',
            docs: {
                description: 'Disallow or enforce spaces inside of blocks after opening block and before closing block',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'whitespace',
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            messages: baseRule.meta.messages,
        },
        defaultOptions: ['always'],
        create(context, [whenToApplyOption]) {
            const sourceCode = context.getSourceCode();
            const baseRules = baseRule.create(context);
            const always = whenToApplyOption !== 'never';
            const messageId = always ? 'missing' : 'extra';
            /**
             * Gets the open brace token from a given node.
             * @returns The token of the open brace.
             */
            function getOpenBrace(node) {
                // guaranteed for enums
                // This is the only change made here from the base rule
                return sourceCode.getFirstToken(node, {
                    filter: token => token.type === utils_1.AST_TOKEN_TYPES.Punctuator && token.value === '{',
                });
            }
            /**
             * Checks whether or not:
             *   - given tokens are on same line.
             *   - there is/isn't a space between given tokens.
             * @param left A token to check.
             * @param right The token which is next to `left`.
             * @returns
             *    When the option is `"always"`, `true` if there are one or more spaces between given tokens.
             *    When the option is `"never"`, `true` if there are not any spaces between given tokens.
             *    If given tokens are not on same line, it's always `true`.
             */
            function isValid(left, right) {
                return (!util.isTokenOnSameLine(left, right) ||
                    sourceCode.isSpaceBetween(left, right) === always);
            }
            /**
             * Checks and reports invalid spacing style inside braces.
             */
            function checkSpacingInsideBraces(node) {
                // Gets braces and the first/last token of content.
                const openBrace = getOpenBrace(node);
                const closeBrace = sourceCode.getLastToken(node);
                const firstToken = sourceCode.getTokenAfter(openBrace, {
                    includeComments: true,
                });
                const lastToken = sourceCode.getTokenBefore(closeBrace, {
                    includeComments: true,
                });
                // Skip if the node is invalid or empty.
                if (openBrace.type !== utils_1.AST_TOKEN_TYPES.Punctuator ||
                    openBrace.value !== '{' ||
                    closeBrace.type !== utils_1.AST_TOKEN_TYPES.Punctuator ||
                    closeBrace.value !== '}' ||
                    firstToken === closeBrace) {
                    return;
                }
                // Skip line comments for option never
                if (!always && firstToken.type === utils_1.AST_TOKEN_TYPES.Line) {
                    return;
                }
                if (!isValid(openBrace, firstToken)) {
                    let loc = openBrace.loc;
                    if (messageId === 'extra') {
                        loc = {
                            start: openBrace.loc.end,
                            end: firstToken.loc.start,
                        };
                    }
                    context.report({
                        node,
                        loc,
                        messageId,
                        data: {
                            location: 'after',
                            token: openBrace.value,
                        },
                        fix(fixer) {
                            if (always) {
                                return fixer.insertTextBefore(firstToken, ' ');
                            }
                            return fixer.removeRange([openBrace.range[1], firstToken.range[0]]);
                        },
                    });
                }
                if (!isValid(lastToken, closeBrace)) {
                    let loc = closeBrace.loc;
                    if (messageId === 'extra') {
                        loc = {
                            start: lastToken.loc.end,
                            end: closeBrace.loc.start,
                        };
                    }
                    context.report({
                        node,
                        loc,
                        messageId,
                        data: {
                            location: 'before',
                            token: closeBrace.value,
                        },
                        fix(fixer) {
                            if (always) {
                                return fixer.insertTextAfter(lastToken, ' ');
                            }
                            return fixer.removeRange([lastToken.range[1], closeBrace.range[0]]);
                        },
                    });
                }
            }
            return Object.assign(Object.assign({}, baseRules), {
                // This code worked "out of the box" for interface and type literal
                // Enums were very close to match as well, the only reason they are not is that was that enums don't have a body node in the parser
                // So the opening brace punctuator starts in the middle of the node - `getFirstToken` in
                // the base rule did not filter for the first opening brace punctuator
                TSInterfaceBody: baseRules.BlockStatement, TSTypeLiteral: baseRules.BlockStatement, TSEnumDeclaration: checkSpacingInsideBraces
            });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/util/getESLintCoreRule.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.maybeGetESLintCoreRule = exports.getESLintCoreRule = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const package_json_1 = require(221) /* eslint/package.json */;
    const semver = __importStar(require(802) /* semver */);
    const isESLintV8 = semver.major(package_json_1.version) >= 8;
    exports.getESLintCoreRule = isESLintV8
        ? (ruleId) => utils_1.ESLintUtils.nullThrows(
        // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access, @typescript-eslint/no-unsafe-call
        require(1156) /* eslint/use-at-your-own-risk */.builtinRules.get(ruleId), `ESLint's core rule '${ruleId}' not found.`)
        : (ruleId) => require(`eslint/lib/rules/${ruleId}`);
    function maybeGetESLintCoreRule(ruleId) {
        try {
            return (0, exports.getESLintCoreRule)(ruleId);
        }
        catch (_a) {
            return null;
        }
    }
    exports.maybeGetESLintCoreRule = maybeGetESLintCoreRule;
    
},
/* eslint/lib/unsupported-api.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * @fileoverview APIs that are not officially supported by ESLint.
     *      These APIs may change or be removed at any time. Use at your
     *      own risk.
     * @author Nicholas C. Zakas
     */
    "use strict";
    //-----------------------------------------------------------------------------
    // Requirements
    //-----------------------------------------------------------------------------
    const { FileEnumerator } = require(281) /* ./cli-engine/file-enumerator */;
    const { FlatESLint } = require(727) /* ./eslint/flat-eslint */;
    const FlatRuleTester = require(1157) /* ./rule-tester/flat-rule-tester */;
    //-----------------------------------------------------------------------------
    // Exports
    //-----------------------------------------------------------------------------
    module.exports = {
        builtinRules: require(357) /* ./rules */,
        FlatESLint,
        FlatRuleTester,
        FileEnumerator
    };
},
/* eslint/lib/rule-tester/flat-rule-tester.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * @fileoverview Mocha/Jest test wrapper
     * @author Ilya Volodin
     */
    "use strict";
    /* globals describe, it -- Mocha globals */
    //------------------------------------------------------------------------------
    // Requirements
    //------------------------------------------------------------------------------
    const assert = require("assert"), util = require("util"), equal = require(237) /* fast-deep-equal */, Traverser = require(313) /* ../shared/traverser */, { getRuleOptionsSchema } = require(694) /* ../config/flat-config-helpers */, { Linter, SourceCodeFixer, interpolate } = require(289) /* ../linter */;
    const { FlatConfigArray } = require(695) /* ../config/flat-config-array */;
    const { defaultConfig } = require(705) /* ../config/default-config */;
    const ajv = require(703) /* ../shared/ajv */({ strictDefaults: true });
    const parserSymbol = Symbol.for("eslint.RuleTester.parser");
    const { SourceCode } = require(314) /* ../source-code */;
    const { ConfigArraySymbol } = require(696) /* @humanwhocodes/config-array */;
    //------------------------------------------------------------------------------
    // Typedefs
    //------------------------------------------------------------------------------
    /** @typedef {import("../shared/types").Parser} Parser */
    /** @typedef {import("../shared/types").LanguageOptions} LanguageOptions */
    /* eslint-disable jsdoc/valid-types -- https://github.com/jsdoc-type-pratt-parser/jsdoc-type-pratt-parser/issues/4#issuecomment-778805577 */
    /**
     * A test case that is expected to pass lint.
     * @typedef {Object} ValidTestCase
     * @property {string} [name] Name for the test case.
     * @property {string} code Code for the test case.
     * @property {any[]} [options] Options for the test case.
     * @property {LanguageOptions} [languageOptions] The language options to use in the test case.
     * @property {{ [name: string]: any }} [settings] Settings for the test case.
     * @property {string} [filename] The fake filename for the test case. Useful for rules that make assertion about filenames.
     * @property {boolean} [only] Run only this test case or the subset of test cases with this property.
     */
    /**
     * A test case that is expected to fail lint.
     * @typedef {Object} InvalidTestCase
     * @property {string} [name] Name for the test case.
     * @property {string} code Code for the test case.
     * @property {number | Array<TestCaseError | string | RegExp>} errors Expected errors.
     * @property {string | null} [output] The expected code after autofixes are applied. If set to `null`, the test runner will assert that no autofix is suggested.
     * @property {any[]} [options] Options for the test case.
     * @property {{ [name: string]: any }} [settings] Settings for the test case.
     * @property {string} [filename] The fake filename for the test case. Useful for rules that make assertion about filenames.
     * @property {LanguageOptions} [languageOptions] The language options to use in the test case.
     * @property {boolean} [only] Run only this test case or the subset of test cases with this property.
     */
    /**
     * A description of a reported error used in a rule tester test.
     * @typedef {Object} TestCaseError
     * @property {string | RegExp} [message] Message.
     * @property {string} [messageId] Message ID.
     * @property {string} [type] The type of the reported AST node.
     * @property {{ [name: string]: string }} [data] The data used to fill the message template.
     * @property {number} [line] The 1-based line number of the reported start location.
     * @property {number} [column] The 1-based column number of the reported start location.
     * @property {number} [endLine] The 1-based line number of the reported end location.
     * @property {number} [endColumn] The 1-based column number of the reported end location.
     */
    /* eslint-enable jsdoc/valid-types -- https://github.com/jsdoc-type-pratt-parser/jsdoc-type-pratt-parser/issues/4#issuecomment-778805577 */
    //------------------------------------------------------------------------------
    // Private Members
    //------------------------------------------------------------------------------
    /*
     * testerDefaultConfig must not be modified as it allows to reset the tester to
     * the initial default configuration
     */
    const testerDefaultConfig = { rules: {} };
    /*
     * RuleTester uses this config as its default. This can be overwritten via
     * setDefaultConfig().
     */
    let sharedDefaultConfig = { rules: {} };
    /*
     * List every parameters possible on a test case that are not related to eslint
     * configuration
     */
    const RuleTesterParameters = [
        "name",
        "code",
        "filename",
        "options",
        "errors",
        "output",
        "only"
    ];
    /*
     * All allowed property names in error objects.
     */
    const errorObjectParameters = new Set([
        "message",
        "messageId",
        "data",
        "type",
        "line",
        "column",
        "endLine",
        "endColumn",
        "suggestions"
    ]);
    const friendlyErrorObjectParameterList = `[${[...errorObjectParameters].map(key => `'${key}'`).join(", ")}]`;
    /*
     * All allowed property names in suggestion objects.
     */
    const suggestionObjectParameters = new Set([
        "desc",
        "messageId",
        "data",
        "output"
    ]);
    const friendlySuggestionObjectParameterList = `[${[...suggestionObjectParameters].map(key => `'${key}'`).join(", ")}]`;
    const hasOwnProperty = Function.call.bind(Object.hasOwnProperty);
    /**
     * Clones a given value deeply.
     * Note: This ignores `parent` property.
     * @param {any} x A value to clone.
     * @returns {any} A cloned value.
     */
    function cloneDeeplyExcludesParent(x) {
        if (typeof x === "object" && x !== null) {
            if (Array.isArray(x)) {
                return x.map(cloneDeeplyExcludesParent);
            }
            const retv = {};
            for (const key in x) {
                if (key !== "parent" && hasOwnProperty(x, key)) {
                    retv[key] = cloneDeeplyExcludesParent(x[key]);
                }
            }
            return retv;
        }
        return x;
    }
    /**
     * Freezes a given value deeply.
     * @param {any} x A value to freeze.
     * @returns {void}
     */
    function freezeDeeply(x) {
        if (typeof x === "object" && x !== null) {
            if (Array.isArray(x)) {
                x.forEach(freezeDeeply);
            }
            else {
                for (const key in x) {
                    if (key !== "parent" && hasOwnProperty(x, key)) {
                        freezeDeeply(x[key]);
                    }
                }
            }
            Object.freeze(x);
        }
    }
    /**
     * Replace control characters by `\u00xx` form.
     * @param {string} text The text to sanitize.
     * @returns {string} The sanitized text.
     */
    function sanitize(text) {
        if (typeof text !== "string") {
            return "";
        }
        return text.replace(/[\u0000-\u0009\u000b-\u001a]/gu, // eslint-disable-line no-control-regex -- Escaping controls
        // eslint-disable-line no-control-regex -- Escaping controls
        c => `\\u${c.codePointAt(0).toString(16).padStart(4, "0")}`);
    }
    /**
     * Define `start`/`end` properties as throwing error.
     * @param {string} objName Object name used for error messages.
     * @param {ASTNode} node The node to define.
     * @returns {void}
     */
    function defineStartEndAsError(objName, node) {
        Object.defineProperties(node, {
            start: {
                get() {
                    throw new Error(`Use ${objName}.range[0] instead of ${objName}.start`);
                },
                configurable: true,
                enumerable: false
            },
            end: {
                get() {
                    throw new Error(`Use ${objName}.range[1] instead of ${objName}.end`);
                },
                configurable: true,
                enumerable: false
            }
        });
    }
    /**
     * Define `start`/`end` properties of all nodes of the given AST as throwing error.
     * @param {ASTNode} ast The root node to errorize `start`/`end` properties.
     * @param {Object} [visitorKeys] Visitor keys to be used for traversing the given ast.
     * @returns {void}
     */
    function defineStartEndAsErrorInTree(ast, visitorKeys) {
        Traverser.traverse(ast, { visitorKeys, enter: defineStartEndAsError.bind(null, "node") });
        ast.tokens.forEach(defineStartEndAsError.bind(null, "token"));
        ast.comments.forEach(defineStartEndAsError.bind(null, "token"));
    }
    /**
     * Wraps the given parser in order to intercept and modify return values from the `parse` and `parseForESLint` methods, for test purposes.
     * In particular, to modify ast nodes, tokens and comments to throw on access to their `start` and `end` properties.
     * @param {Parser} parser Parser object.
     * @returns {Parser} Wrapped parser object.
     */
    function wrapParser(parser) {
        if (typeof parser.parseForESLint === "function") {
            return {
                [parserSymbol]: parser,
                parseForESLint(...args) {
                    const ret = parser.parseForESLint(...args);
                    defineStartEndAsErrorInTree(ret.ast, ret.visitorKeys);
                    return ret;
                }
            };
        }
        return {
            [parserSymbol]: parser,
            parse(...args) {
                const ast = parser.parse(...args);
                defineStartEndAsErrorInTree(ast);
                return ast;
            }
        };
    }
    /**
     * Function to replace `SourceCode.prototype.getComments`.
     * @returns {void}
     * @throws {Error} Deprecation message.
     */
    function getCommentsDeprecation() {
        throw new Error("`SourceCode#getComments()` is deprecated and will be removed in a future major version. Use `getCommentsBefore()`, `getCommentsAfter()`, and `getCommentsInside()` instead.");
    }
    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------
    // default separators for testing
    const DESCRIBE = Symbol("describe");
    const IT = Symbol("it");
    const IT_ONLY = Symbol("itOnly");
    /**
     * This is `it` default handler if `it` don't exist.
     * @this {Mocha}
     * @param {string} text The description of the test case.
     * @param {Function} method The logic of the test case.
     * @throws {Error} Any error upon execution of `method`.
     * @returns {any} Returned value of `method`.
     */
    function itDefaultHandler(text, method) {
        try {
            return method.call(this);
        }
        catch (err) {
            if (err instanceof assert.AssertionError) {
                err.message += ` (${util.inspect(err.actual)} ${err.operator} ${util.inspect(err.expected)})`;
            }
            throw err;
        }
    }
    /**
     * This is `describe` default handler if `describe` don't exist.
     * @this {Mocha}
     * @param {string} text The description of the test case.
     * @param {Function} method The logic of the test case.
     * @returns {any} Returned value of `method`.
     */
    function describeDefaultHandler(text, method) {
        return method.call(this);
    }
    /**
     * Mocha test wrapper.
     */
    class FlatRuleTester {
        /**
         * Creates a new instance of RuleTester.
         * @param {Object} [testerConfig] Optional, extra configuration for the tester
         */
        constructor(testerConfig = {}) {
            /**
             * The configuration to use for this tester. Combination of the tester
             * configuration and the default configuration.
             * @type {Object}
             */
            this.testerConfig = [
                sharedDefaultConfig,
                testerConfig,
                { rules: { "rule-tester/validate-ast": "error" } }
            ];
            this.linter = new Linter({ configType: "flat" });
        }
        /**
         * Set the configuration to use for all future tests
         * @param {Object} config the configuration to use.
         * @throws {TypeError} If non-object config.
         * @returns {void}
         */
        static setDefaultConfig(config) {
            if (typeof config !== "object") {
                throw new TypeError("FlatRuleTester.setDefaultConfig: config must be an object");
            }
            sharedDefaultConfig = config;
            // Make sure the rules object exists since it is assumed to exist later
            sharedDefaultConfig.rules = sharedDefaultConfig.rules || {};
        }
        /**
         * Get the current configuration used for all tests
         * @returns {Object} the current configuration
         */
        static getDefaultConfig() {
            return sharedDefaultConfig;
        }
        /**
         * Reset the configuration to the initial configuration of the tester removing
         * any changes made until now.
         * @returns {void}
         */
        static resetDefaultConfig() {
            sharedDefaultConfig = {
                rules: {
                    ...testerDefaultConfig.rules
                }
            };
        }
        /*
         * If people use `mocha test.js --watch` command, `describe` and `it` function
         * instances are different for each execution. So `describe` and `it` should get fresh instance
         * always.
         */
        static get describe() {
            return (this[DESCRIBE] ||
                (typeof describe === "function" ? describe : describeDefaultHandler));
        }
        static set describe(value) {
            this[DESCRIBE] = value;
        }
        static get it() {
            return (this[IT] ||
                (typeof it === "function" ? it : itDefaultHandler));
        }
        static set it(value) {
            this[IT] = value;
        }
        /**
         * Adds the `only` property to a test to run it in isolation.
         * @param {string | ValidTestCase | InvalidTestCase} item A single test to run by itself.
         * @returns {ValidTestCase | InvalidTestCase} The test with `only` set.
         */
        static only(item) {
            if (typeof item === "string") {
                return { code: item, only: true };
            }
            return { ...item, only: true };
        }
        static get itOnly() {
            if (typeof this[IT_ONLY] === "function") {
                return this[IT_ONLY];
            }
            if (typeof this[IT] === "function" && typeof this[IT].only === "function") {
                return Function.bind.call(this[IT].only, this[IT]);
            }
            if (typeof it === "function" && typeof it.only === "function") {
                return Function.bind.call(it.only, it);
            }
            if (typeof this[DESCRIBE] === "function" || typeof this[IT] === "function") {
                throw new Error("Set `RuleTester.itOnly` to use `only` with a custom test framework.\n" +
                    "See https://eslint.org/docs/latest/integrate/nodejs-api#customizing-ruletester for more.");
            }
            if (typeof it === "function") {
                throw new Error("The current test framework does not support exclusive tests with `only`.");
            }
            throw new Error("To use `only`, use RuleTester with a test framework that provides `it.only()` like Mocha.");
        }
        static set itOnly(value) {
            this[IT_ONLY] = value;
        }
        /**
         * Adds a new rule test to execute.
         * @param {string} ruleName The name of the rule to run.
         * @param {Function} rule The rule to test.
         * @param {{
         *   valid: (ValidTestCase | string)[],
         *   invalid: InvalidTestCase[]
         * }} test The collection of tests to run.
         * @throws {TypeError|Error} If non-object `test`, or if a required
         * scenario of the given type is missing.
         * @returns {void}
         */
        run(ruleName, rule, test) {
            const testerConfig = this.testerConfig, requiredScenarios = ["valid", "invalid"], scenarioErrors = [], linter = this.linter, ruleId = `rule-to-test/${ruleName}`;
            if (!test || typeof test !== "object") {
                throw new TypeError(`Test Scenarios for rule ${ruleName} : Could not find test scenario object`);
            }
            requiredScenarios.forEach(scenarioType => {
                if (!test[scenarioType]) {
                    scenarioErrors.push(`Could not find any ${scenarioType} test scenarios`);
                }
            });
            if (scenarioErrors.length > 0) {
                throw new Error([
                    `Test Scenarios for rule ${ruleName} is invalid:`
                ].concat(scenarioErrors).join("\n"));
            }
            const baseConfig = [
                {
                    plugins: {
                        // copy root plugin over
                        "@": {
                            /*
                             * Parsers are wrapped to detect more errors, so this needs
                             * to be a new object for each call to run(), otherwise the
                             * parsers will be wrapped multiple times.
                             */
                            parsers: {
                                ...defaultConfig[0].plugins["@"].parsers
                            },
                            /*
                             * The rules key on the default plugin is a proxy to lazy-load
                             * just the rules that are needed. So, don't create a new object
                             * here, just use the default one to keep that performance
                             * enhancement.
                             */
                            rules: defaultConfig[0].plugins["@"].rules
                        },
                        "rule-to-test": {
                            rules: {
                                [ruleName]: Object.assign({}, rule, {
                                    // Create a wrapper rule that freezes the `context` properties.
                                    create(context) {
                                        freezeDeeply(context.options);
                                        freezeDeeply(context.settings);
                                        freezeDeeply(context.parserOptions);
                                        // freezeDeeply(context.languageOptions);
                                        return (typeof rule === "function" ? rule : rule.create)(context);
                                    }
                                })
                            }
                        }
                    },
                    languageOptions: {
                        ...defaultConfig[0].languageOptions
                    }
                },
                ...defaultConfig.slice(1)
            ];
            /**
             * Run the rule for the given item
             * @param {string|Object} item Item to run the rule against
             * @throws {Error} If an invalid schema.
             * @returns {Object} Eslint run result
             * @private
             */
            function runRuleForItem(item) {
                const configs = new FlatConfigArray(testerConfig, { baseConfig });
                /*
                 * Modify the returned config so that the parser is wrapped to catch
                 * access of the start/end properties. This method is called just
                 * once per code snippet being tested, so each test case gets a clean
                 * parser.
                 */
                configs[ConfigArraySymbol.finalizeConfig] = function (...args) {
                    // can't do super here :(
                    const proto = Object.getPrototypeOf(this);
                    const calculatedConfig = proto[ConfigArraySymbol.finalizeConfig].apply(this, args);
                    // wrap the parser to catch start/end property access
                    calculatedConfig.languageOptions.parser = wrapParser(calculatedConfig.languageOptions.parser);
                    return calculatedConfig;
                };
                let code, filename, output, beforeAST, afterAST;
                if (typeof item === "string") {
                    code = item;
                }
                else {
                    code = item.code;
                    /*
                     * Assumes everything on the item is a config except for the
                     * parameters used by this tester
                     */
                    const itemConfig = { ...item };
                    for (const parameter of RuleTesterParameters) {
                        delete itemConfig[parameter];
                    }
                    // wrap any parsers
                    if (itemConfig.languageOptions && itemConfig.languageOptions.parser) {
                        const parser = itemConfig.languageOptions.parser;
                        if (parser && typeof parser !== "object") {
                            throw new Error("Parser must be an object with a parse() or parseForESLint() method.");
                        }
                    }
                    /*
                     * Create the config object from the tester config and this item
                     * specific configurations.
                     */
                    configs.push(itemConfig);
                }
                if (item.filename) {
                    filename = item.filename;
                }
                let ruleConfig = 1;
                if (hasOwnProperty(item, "options")) {
                    assert(Array.isArray(item.options), "options must be an array");
                    ruleConfig = [1, ...item.options];
                }
                configs.push({
                    rules: {
                        [ruleId]: ruleConfig
                    }
                });
                const schema = getRuleOptionsSchema(rule);
                /*
                 * Setup AST getters.
                 * The goal is to check whether or not AST was modified when
                 * running the rule under test.
                 */
                configs.push({
                    plugins: {
                        "rule-tester": {
                            rules: {
                                "validate-ast": {
                                    create() {
                                        return {
                                            Program(node) {
                                                beforeAST = cloneDeeplyExcludesParent(node);
                                            },
                                            "Program:exit"(node) {
                                                afterAST = node;
                                            }
                                        };
                                    }
                                }
                            }
                        }
                    }
                });
                if (schema) {
                    ajv.validateSchema(schema);
                    if (ajv.errors) {
                        const errors = ajv.errors.map(error => {
                            const field = error.dataPath[0] === "." ? error.dataPath.slice(1) : error.dataPath;
                            return `\t${field}: ${error.message}`;
                        }).join("\n");
                        throw new Error([`Schema for rule ${ruleName} is invalid:`, errors]);
                    }
                    /*
                     * `ajv.validateSchema` checks for errors in the structure of the schema (by comparing the schema against a "meta-schema"),
                     * and it reports those errors individually. However, there are other types of schema errors that only occur when compiling
                     * the schema (e.g. using invalid defaults in a schema), and only one of these errors can be reported at a time. As a result,
                     * the schema is compiled here separately from checking for `validateSchema` errors.
                     */
                    try {
                        ajv.compile(schema);
                    }
                    catch (err) {
                        throw new Error(`Schema for rule ${ruleName} is invalid: ${err.message}`);
                    }
                }
                // Verify the code.
                const { getComments } = SourceCode.prototype;
                let messages;
                // check for validation errors
                try {
                    configs.normalizeSync();
                    configs.getConfig("test.js");
                }
                catch (error) {
                    error.message = `ESLint configuration in rule-tester is invalid: ${error.message}`;
                    throw error;
                }
                try {
                    SourceCode.prototype.getComments = getCommentsDeprecation;
                    messages = linter.verify(code, configs, filename);
                }
                finally {
                    SourceCode.prototype.getComments = getComments;
                }
                const fatalErrorMessage = messages.find(m => m.fatal);
                assert(!fatalErrorMessage, `A fatal parsing error occurred: ${fatalErrorMessage && fatalErrorMessage.message}`);
                // Verify if autofix makes a syntax error or not.
                if (messages.some(m => m.fix)) {
                    output = SourceCodeFixer.applyFixes(code, messages).output;
                    const errorMessageInFix = linter.verify(output, configs, filename).find(m => m.fatal);
                    assert(!errorMessageInFix, [
                        "A fatal parsing error occurred in autofix.",
                        `Error: ${errorMessageInFix && errorMessageInFix.message}`,
                        "Autofix output:",
                        output
                    ].join("\n"));
                }
                else {
                    output = code;
                }
                return {
                    messages,
                    output,
                    beforeAST,
                    afterAST: cloneDeeplyExcludesParent(afterAST)
                };
            }
            /**
             * Check if the AST was changed
             * @param {ASTNode} beforeAST AST node before running
             * @param {ASTNode} afterAST AST node after running
             * @returns {void}
             * @private
             */
            function assertASTDidntChange(beforeAST, afterAST) {
                if (!equal(beforeAST, afterAST)) {
                    assert.fail("Rule should not modify AST.");
                }
            }
            /**
             * Check if the template is valid or not
             * all valid cases go through this
             * @param {string|Object} item Item to run the rule against
             * @returns {void}
             * @private
             */
            function testValidTemplate(item) {
                const code = typeof item === "object" ? item.code : item;
                assert.ok(typeof code === "string", "Test case must specify a string value for 'code'");
                if (item.name) {
                    assert.ok(typeof item.name === "string", "Optional test case property 'name' must be a string");
                }
                const result = runRuleForItem(item);
                const messages = result.messages;
                assert.strictEqual(messages.length, 0, util.format("Should have no errors but had %d: %s", messages.length, util.inspect(messages)));
                assertASTDidntChange(result.beforeAST, result.afterAST);
            }
            /**
             * Asserts that the message matches its expected value. If the expected
             * value is a regular expression, it is checked against the actual
             * value.
             * @param {string} actual Actual value
             * @param {string|RegExp} expected Expected value
             * @returns {void}
             * @private
             */
            function assertMessageMatches(actual, expected) {
                if (expected instanceof RegExp) {
                    // assert.js doesn't have a built-in RegExp match function
                    assert.ok(expected.test(actual), `Expected '${actual}' to match ${expected}`);
                }
                else {
                    assert.strictEqual(actual, expected);
                }
            }
            /**
             * Check if the template is invalid or not
             * all invalid cases go through this.
             * @param {string|Object} item Item to run the rule against
             * @returns {void}
             * @private
             */
            function testInvalidTemplate(item) {
                assert.ok(typeof item.code === "string", "Test case must specify a string value for 'code'");
                if (item.name) {
                    assert.ok(typeof item.name === "string", "Optional test case property 'name' must be a string");
                }
                assert.ok(item.errors || item.errors === 0, `Did not specify errors for an invalid test of ${ruleName}`);
                if (Array.isArray(item.errors) && item.errors.length === 0) {
                    assert.fail("Invalid cases must have at least one error");
                }
                const ruleHasMetaMessages = hasOwnProperty(rule, "meta") && hasOwnProperty(rule.meta, "messages");
                const friendlyIDList = ruleHasMetaMessages ? `[${Object.keys(rule.meta.messages).map(key => `'${key}'`).join(", ")}]` : null;
                const result = runRuleForItem(item);
                const messages = result.messages;
                if (typeof item.errors === "number") {
                    if (item.errors === 0) {
                        assert.fail("Invalid cases must have 'error' value greater than 0");
                    }
                    assert.strictEqual(messages.length, item.errors, util.format("Should have %d error%s but had %d: %s", item.errors, item.errors === 1 ? "" : "s", messages.length, util.inspect(messages)));
                }
                else {
                    assert.strictEqual(messages.length, item.errors.length, util.format("Should have %d error%s but had %d: %s", item.errors.length, item.errors.length === 1 ? "" : "s", messages.length, util.inspect(messages)));
                    const hasMessageOfThisRule = messages.some(m => m.ruleId === ruleId);
                    for (let i = 0, l = item.errors.length; i < l; i++) {
                        const error = item.errors[i];
                        const message = messages[i];
                        assert(hasMessageOfThisRule, "Error rule name should be the same as the name of the rule being tested");
                        if (typeof error === "string" || error instanceof RegExp) {
                            // Just an error message.
                            assertMessageMatches(message.message, error);
                        }
                        else if (typeof error === "object" && error !== null) {
                            /*
                             * Error object.
                             * This may have a message, messageId, data, node type, line, and/or
                             * column.
                             */
                            Object.keys(error).forEach(propertyName => {
                                assert.ok(errorObjectParameters.has(propertyName), `Invalid error property name '${propertyName}'. Expected one of ${friendlyErrorObjectParameterList}.`);
                            });
                            if (hasOwnProperty(error, "message")) {
                                assert.ok(!hasOwnProperty(error, "messageId"), "Error should not specify both 'message' and a 'messageId'.");
                                assert.ok(!hasOwnProperty(error, "data"), "Error should not specify both 'data' and 'message'.");
                                assertMessageMatches(message.message, error.message);
                            }
                            else if (hasOwnProperty(error, "messageId")) {
                                assert.ok(ruleHasMetaMessages, "Error can not use 'messageId' if rule under test doesn't define 'meta.messages'.");
                                if (!hasOwnProperty(rule.meta.messages, error.messageId)) {
                                    assert(false, `Invalid messageId '${error.messageId}'. Expected one of ${friendlyIDList}.`);
                                }
                                assert.strictEqual(message.messageId, error.messageId, `messageId '${message.messageId}' does not match expected messageId '${error.messageId}'.`);
                                if (hasOwnProperty(error, "data")) {
                                    /*
                                     *  if data was provided, then directly compare the returned message to a synthetic
                                     *  interpolated message using the same message ID and data provided in the test.
                                     *  See https://github.com/eslint/eslint/issues/9890 for context.
                                     */
                                    const unformattedOriginalMessage = rule.meta.messages[error.messageId];
                                    const rehydratedMessage = interpolate(unformattedOriginalMessage, error.data);
                                    assert.strictEqual(message.message, rehydratedMessage, `Hydrated message "${rehydratedMessage}" does not match "${message.message}"`);
                                }
                            }
                            assert.ok(hasOwnProperty(error, "data") ? hasOwnProperty(error, "messageId") : true, "Error must specify 'messageId' if 'data' is used.");
                            if (error.type) {
                                assert.strictEqual(message.nodeType, error.type, `Error type should be ${error.type}, found ${message.nodeType}`);
                            }
                            if (hasOwnProperty(error, "line")) {
                                assert.strictEqual(message.line, error.line, `Error line should be ${error.line}`);
                            }
                            if (hasOwnProperty(error, "column")) {
                                assert.strictEqual(message.column, error.column, `Error column should be ${error.column}`);
                            }
                            if (hasOwnProperty(error, "endLine")) {
                                assert.strictEqual(message.endLine, error.endLine, `Error endLine should be ${error.endLine}`);
                            }
                            if (hasOwnProperty(error, "endColumn")) {
                                assert.strictEqual(message.endColumn, error.endColumn, `Error endColumn should be ${error.endColumn}`);
                            }
                            if (hasOwnProperty(error, "suggestions")) {
                                // Support asserting there are no suggestions
                                if (!error.suggestions || (Array.isArray(error.suggestions) && error.suggestions.length === 0)) {
                                    if (Array.isArray(message.suggestions) && message.suggestions.length > 0) {
                                        assert.fail(`Error should have no suggestions on error with message: "${message.message}"`);
                                    }
                                }
                                else {
                                    assert.strictEqual(Array.isArray(message.suggestions), true, `Error should have an array of suggestions. Instead received "${message.suggestions}" on error with message: "${message.message}"`);
                                    assert.strictEqual(message.suggestions.length, error.suggestions.length, `Error should have ${error.suggestions.length} suggestions. Instead found ${message.suggestions.length} suggestions`);
                                    error.suggestions.forEach((expectedSuggestion, index) => {
                                        assert.ok(typeof expectedSuggestion === "object" && expectedSuggestion !== null, "Test suggestion in 'suggestions' array must be an object.");
                                        Object.keys(expectedSuggestion).forEach(propertyName => {
                                            assert.ok(suggestionObjectParameters.has(propertyName), `Invalid suggestion property name '${propertyName}'. Expected one of ${friendlySuggestionObjectParameterList}.`);
                                        });
                                        const actualSuggestion = message.suggestions[index];
                                        const suggestionPrefix = `Error Suggestion at index ${index} :`;
                                        if (hasOwnProperty(expectedSuggestion, "desc")) {
                                            assert.ok(!hasOwnProperty(expectedSuggestion, "data"), `${suggestionPrefix} Test should not specify both 'desc' and 'data'.`);
                                            assert.strictEqual(actualSuggestion.desc, expectedSuggestion.desc, `${suggestionPrefix} desc should be "${expectedSuggestion.desc}" but got "${actualSuggestion.desc}" instead.`);
                                        }
                                        if (hasOwnProperty(expectedSuggestion, "messageId")) {
                                            assert.ok(ruleHasMetaMessages, `${suggestionPrefix} Test can not use 'messageId' if rule under test doesn't define 'meta.messages'.`);
                                            assert.ok(hasOwnProperty(rule.meta.messages, expectedSuggestion.messageId), `${suggestionPrefix} Test has invalid messageId '${expectedSuggestion.messageId}', the rule under test allows only one of ${friendlyIDList}.`);
                                            assert.strictEqual(actualSuggestion.messageId, expectedSuggestion.messageId, `${suggestionPrefix} messageId should be '${expectedSuggestion.messageId}' but got '${actualSuggestion.messageId}' instead.`);
                                            if (hasOwnProperty(expectedSuggestion, "data")) {
                                                const unformattedMetaMessage = rule.meta.messages[expectedSuggestion.messageId];
                                                const rehydratedDesc = interpolate(unformattedMetaMessage, expectedSuggestion.data);
                                                assert.strictEqual(actualSuggestion.desc, rehydratedDesc, `${suggestionPrefix} Hydrated test desc "${rehydratedDesc}" does not match received desc "${actualSuggestion.desc}".`);
                                            }
                                        }
                                        else {
                                            assert.ok(!hasOwnProperty(expectedSuggestion, "data"), `${suggestionPrefix} Test must specify 'messageId' if 'data' is used.`);
                                        }
                                        if (hasOwnProperty(expectedSuggestion, "output")) {
                                            const codeWithAppliedSuggestion = SourceCodeFixer.applyFixes(item.code, [actualSuggestion]).output;
                                            assert.strictEqual(codeWithAppliedSuggestion, expectedSuggestion.output, `Expected the applied suggestion fix to match the test suggestion output for suggestion at index: ${index} on error with message: "${message.message}"`);
                                        }
                                    });
                                }
                            }
                        }
                        else {
                            // Message was an unexpected type
                            assert.fail(`Error should be a string, object, or RegExp, but found (${util.inspect(message)})`);
                        }
                    }
                }
                if (hasOwnProperty(item, "output")) {
                    if (item.output === null) {
                        assert.strictEqual(result.output, item.code, "Expected no autofixes to be suggested");
                    }
                    else {
                        assert.strictEqual(result.output, item.output, "Output is incorrect.");
                    }
                }
                else {
                    assert.strictEqual(result.output, item.code, "The rule fixed the code. Please add 'output' property.");
                }
                assertASTDidntChange(result.beforeAST, result.afterAST);
            }
            /*
             * This creates a mocha test suite and pipes all supplied info through
             * one of the templates above.
             */
            this.constructor.describe(ruleName, () => {
                this.constructor.describe("valid", () => {
                    test.valid.forEach(valid => {
                        this.constructor[valid.only ? "itOnly" : "it"](sanitize(typeof valid === "object" ? valid.name || valid.code : valid), () => {
                            testValidTemplate(valid);
                        });
                    });
                });
                this.constructor.describe("invalid", () => {
                    test.invalid.forEach(invalid => {
                        this.constructor[invalid.only ? "itOnly" : "it"](sanitize(invalid.name || invalid.code), () => {
                            testInvalidTemplate(invalid);
                        });
                    });
                });
            });
        }
    }
    FlatRuleTester[DESCRIBE] = FlatRuleTester[IT] = FlatRuleTester[IT_ONLY] = null;
    module.exports = FlatRuleTester;
},
/* @typescript-eslint/eslint-plugin/dist/rules/brace-style.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const util_1 = require(1018) /* ../util */;
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('brace-style');
    exports.default = (0, util_1.createRule)({
        name: 'brace-style',
        meta: {
            type: 'layout',
            docs: {
                description: 'Enforce consistent brace style for blocks',
                recommended: false,
                extendsBaseRule: true,
            },
            messages: baseRule.meta.messages,
            fixable: baseRule.meta.fixable,
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
        },
        defaultOptions: ['1tbs'],
        create(context) {
            const [style, { allowSingleLine } = { allowSingleLine: false }] = 
            // eslint-disable-next-line no-restricted-syntax -- Use raw options for extended rules.
            context.options;
            const isAllmanStyle = style === 'allman';
            const sourceCode = context.getSourceCode();
            const rules = baseRule.create(context);
            /**
             * Checks a pair of curly brackets based on the user's config
             */
            function validateCurlyPair(openingCurlyToken, closingCurlyToken) {
                if (allowSingleLine &&
                    (0, util_1.isTokenOnSameLine)(openingCurlyToken, closingCurlyToken)) {
                    return;
                }
                const tokenBeforeOpeningCurly = sourceCode.getTokenBefore(openingCurlyToken);
                const tokenBeforeClosingCurly = sourceCode.getTokenBefore(closingCurlyToken);
                const tokenAfterOpeningCurly = sourceCode.getTokenAfter(openingCurlyToken);
                if (!isAllmanStyle &&
                    !(0, util_1.isTokenOnSameLine)(tokenBeforeOpeningCurly, openingCurlyToken)) {
                    context.report({
                        node: openingCurlyToken,
                        messageId: 'nextLineOpen',
                        fix: fixer => {
                            const textRange = [
                                tokenBeforeOpeningCurly.range[1],
                                openingCurlyToken.range[0],
                            ];
                            const textBetween = sourceCode.text.slice(textRange[0], textRange[1]);
                            if (textBetween.trim()) {
                                return null;
                            }
                            return fixer.replaceTextRange(textRange, ' ');
                        },
                    });
                }
                if (isAllmanStyle &&
                    (0, util_1.isTokenOnSameLine)(tokenBeforeOpeningCurly, openingCurlyToken)) {
                    context.report({
                        node: openingCurlyToken,
                        messageId: 'sameLineOpen',
                        fix: fixer => fixer.insertTextBefore(openingCurlyToken, '\n'),
                    });
                }
                if ((0, util_1.isTokenOnSameLine)(openingCurlyToken, tokenAfterOpeningCurly) &&
                    tokenAfterOpeningCurly !== closingCurlyToken) {
                    context.report({
                        node: openingCurlyToken,
                        messageId: 'blockSameLine',
                        fix: fixer => fixer.insertTextAfter(openingCurlyToken, '\n'),
                    });
                }
                if ((0, util_1.isTokenOnSameLine)(tokenBeforeClosingCurly, closingCurlyToken) &&
                    tokenBeforeClosingCurly !== openingCurlyToken) {
                    context.report({
                        node: closingCurlyToken,
                        messageId: 'singleLineClose',
                        fix: fixer => fixer.insertTextBefore(closingCurlyToken, '\n'),
                    });
                }
            }
            return Object.assign(Object.assign({}, rules), { 'TSInterfaceBody, TSModuleBlock'(node) {
                    const openingCurly = sourceCode.getFirstToken(node);
                    const closingCurly = sourceCode.getLastToken(node);
                    validateCurlyPair(openingCurly, closingCurly);
                },
                TSEnumDeclaration(node) {
                    const closingCurly = sourceCode.getLastToken(node);
                    const openingCurly = sourceCode.getTokenBefore(node.members.length ? node.members[0] : closingCurly);
                    validateCurlyPair(openingCurly, closingCurly);
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/class-literal-property-style.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const printNodeModifiers = (node, final) => {
        var _a;
        return `${(_a = node.accessibility) !== null && _a !== void 0 ? _a : ''}${node.static ? ' static' : ''} ${final} `.trimStart();
    };
    const isSupportedLiteral = (node) => {
        if (node.type === utils_1.AST_NODE_TYPES.Literal) {
            return true;
        }
        if (node.type === utils_1.AST_NODE_TYPES.TaggedTemplateExpression ||
            node.type === utils_1.AST_NODE_TYPES.TemplateLiteral) {
            return ('quasi' in node ? node.quasi.quasis : node.quasis).length === 1;
        }
        return false;
    };
    exports.default = util.createRule({
        name: 'class-literal-property-style',
        meta: {
            type: 'problem',
            docs: {
                description: 'Enforce that literals on classes are exposed in a consistent style',
                recommended: 'strict',
            },
            fixable: 'code',
            messages: {
                preferFieldStyle: 'Literals should be exposed using readonly fields.',
                preferGetterStyle: 'Literals should be exposed using getters.',
            },
            schema: [{ enum: ['fields', 'getters'] }],
        },
        defaultOptions: ['fields'],
        create(context, [style]) {
            return Object.assign(Object.assign({}, (style === 'fields' && {
                MethodDefinition(node) {
                    if (node.kind !== 'get' ||
                        !node.value.body ||
                        !node.value.body.body.length) {
                        return;
                    }
                    const [statement] = node.value.body.body;
                    if (statement.type !== utils_1.AST_NODE_TYPES.ReturnStatement) {
                        return;
                    }
                    const { argument } = statement;
                    if (!argument || !isSupportedLiteral(argument)) {
                        return;
                    }
                    context.report({
                        node: node.key,
                        messageId: 'preferFieldStyle',
                        fix(fixer) {
                            const sourceCode = context.getSourceCode();
                            const name = sourceCode.getText(node.key);
                            let text = '';
                            text += printNodeModifiers(node, 'readonly');
                            text += node.computed ? `[${name}]` : name;
                            text += ` = ${sourceCode.getText(argument)};`;
                            return fixer.replaceText(node, text);
                        },
                    });
                },
            })), (style === 'getters' && {
                PropertyDefinition(node) {
                    if (!node.readonly || node.declare) {
                        return;
                    }
                    const { value } = node;
                    if (!value || !isSupportedLiteral(value)) {
                        return;
                    }
                    context.report({
                        node: node.key,
                        messageId: 'preferGetterStyle',
                        fix(fixer) {
                            const sourceCode = context.getSourceCode();
                            const name = sourceCode.getText(node.key);
                            let text = '';
                            text += printNodeModifiers(node, 'get');
                            text += node.computed ? `[${name}]` : name;
                            text += `() { return ${sourceCode.getText(value)}; }`;
                            return fixer.replaceText(node, text);
                        },
                    });
                },
            }));
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/comma-dangle.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('comma-dangle');
    const OPTION_VALUE_SCHEME = [
        'always-multiline',
        'always',
        'never',
        'only-multiline',
    ];
    const DEFAULT_OPTION_VALUE = 'never';
    function normalizeOptions(options) {
        var _a, _b, _c;
        if (typeof options === 'string') {
            return {
                enums: options,
                generics: options,
                tuples: options,
            };
        }
        return {
            enums: (_a = options.enums) !== null && _a !== void 0 ? _a : DEFAULT_OPTION_VALUE,
            generics: (_b = options.generics) !== null && _b !== void 0 ? _b : DEFAULT_OPTION_VALUE,
            tuples: (_c = options.tuples) !== null && _c !== void 0 ? _c : DEFAULT_OPTION_VALUE,
        };
    }
    exports.default = util.createRule({
        name: 'comma-dangle',
        meta: {
            type: 'layout',
            docs: {
                description: 'Require or disallow trailing commas',
                recommended: false,
                extendsBaseRule: true,
            },
            schema: {
                $defs: {
                    value: {
                        enum: OPTION_VALUE_SCHEME,
                    },
                    valueWithIgnore: {
                        enum: [...OPTION_VALUE_SCHEME, 'ignore'],
                    },
                },
                type: 'array',
                items: [
                    {
                        oneOf: [
                            {
                                $ref: '#/$defs/value',
                            },
                            {
                                type: 'object',
                                properties: {
                                    arrays: { $ref: '#/$defs/valueWithIgnore' },
                                    objects: { $ref: '#/$defs/valueWithIgnore' },
                                    imports: { $ref: '#/$defs/valueWithIgnore' },
                                    exports: { $ref: '#/$defs/valueWithIgnore' },
                                    functions: { $ref: '#/$defs/valueWithIgnore' },
                                    enums: { $ref: '#/$defs/valueWithIgnore' },
                                    generics: { $ref: '#/$defs/valueWithIgnore' },
                                    tuples: { $ref: '#/$defs/valueWithIgnore' },
                                },
                                additionalProperties: false,
                            },
                        ],
                    },
                ],
                additionalProperties: false,
            },
            fixable: 'code',
            hasSuggestions: baseRule.meta.hasSuggestions,
            messages: baseRule.meta.messages,
        },
        defaultOptions: ['never'],
        create(context, [options]) {
            const rules = baseRule.create(context);
            const sourceCode = context.getSourceCode();
            const normalizedOptions = normalizeOptions(options);
            const predicate = {
                always: forceComma,
                'always-multiline': forceCommaIfMultiline,
                'only-multiline': allowCommaIfMultiline,
                never: forbidComma,
                ignore: () => { },
            };
            function last(nodes) {
                var _a;
                return (_a = nodes[nodes.length - 1]) !== null && _a !== void 0 ? _a : null;
            }
            function getLastItem(node) {
                switch (node.type) {
                    case utils_1.AST_NODE_TYPES.TSEnumDeclaration:
                        return last(node.members);
                    case utils_1.AST_NODE_TYPES.TSTypeParameterDeclaration:
                        return last(node.params);
                    case utils_1.AST_NODE_TYPES.TSTupleType:
                        return last(node.elementTypes);
                    default:
                        return null;
                }
            }
            function getTrailingToken(node) {
                const last = getLastItem(node);
                const trailing = last && sourceCode.getTokenAfter(last);
                return trailing;
            }
            function isMultiline(node) {
                const last = getLastItem(node);
                const lastToken = sourceCode.getLastToken(node);
                return (last === null || last === void 0 ? void 0 : last.loc.end.line) !== (lastToken === null || lastToken === void 0 ? void 0 : lastToken.loc.end.line);
            }
            function forbidComma(node) {
                const last = getLastItem(node);
                const trailing = getTrailingToken(node);
                if (last && trailing && util.isCommaToken(trailing)) {
                    context.report({
                        node,
                        messageId: 'unexpected',
                        fix(fixer) {
                            return fixer.remove(trailing);
                        },
                    });
                }
            }
            function forceComma(node) {
                const last = getLastItem(node);
                const trailing = getTrailingToken(node);
                if (last && trailing && !util.isCommaToken(trailing)) {
                    context.report({
                        node,
                        messageId: 'missing',
                        fix(fixer) {
                            return fixer.insertTextAfter(last, ',');
                        },
                    });
                }
            }
            function allowCommaIfMultiline(node) {
                if (!isMultiline(node)) {
                    forbidComma(node);
                }
            }
            function forceCommaIfMultiline(node) {
                if (isMultiline(node)) {
                    forceComma(node);
                }
                else {
                    forbidComma(node);
                }
            }
            return Object.assign(Object.assign({}, rules), { TSEnumDeclaration: predicate[normalizedOptions.enums], TSTypeParameterDeclaration: predicate[normalizedOptions.generics], TSTupleType: predicate[normalizedOptions.tuples] });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/comma-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util_1 = require(1018) /* ../util */;
    exports.default = (0, util_1.createRule)({
        name: 'comma-spacing',
        meta: {
            type: 'layout',
            docs: {
                description: 'Enforce consistent spacing before and after commas',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'whitespace',
            schema: [
                {
                    type: 'object',
                    properties: {
                        before: {
                            type: 'boolean',
                            default: false,
                        },
                        after: {
                            type: 'boolean',
                            default: true,
                        },
                    },
                    additionalProperties: false,
                },
            ],
            messages: {
                unexpected: `There should be no space {{loc}} ','.`,
                missing: `A space is required {{loc}} ','.`,
            },
        },
        defaultOptions: [
            {
                before: false,
                after: true,
            },
        ],
        create(context, [{ before: spaceBefore, after: spaceAfter }]) {
            const sourceCode = context.getSourceCode();
            const tokensAndComments = sourceCode.tokensAndComments;
            const ignoredTokens = new Set();
            /**
             * Adds null elements of the ArrayExpression or ArrayPattern node to the ignore list
             * @param node node to evaluate
             */
            function addNullElementsToIgnoreList(node) {
                let previousToken = sourceCode.getFirstToken(node);
                for (const element of node.elements) {
                    let token;
                    if (element == null) {
                        token = sourceCode.getTokenAfter(previousToken);
                        if (token && (0, util_1.isCommaToken)(token)) {
                            ignoredTokens.add(token);
                        }
                    }
                    else {
                        token = sourceCode.getTokenAfter(element);
                    }
                    previousToken = token;
                }
            }
            /**
             * Adds type parameters trailing comma token to the ignore list
             * @param node node to evaluate
             */
            function addTypeParametersTrailingCommaToIgnoreList(node) {
                const paramLength = node.params.length;
                if (paramLength) {
                    const param = node.params[paramLength - 1];
                    const afterToken = sourceCode.getTokenAfter(param);
                    if (afterToken && (0, util_1.isCommaToken)(afterToken)) {
                        ignoredTokens.add(afterToken);
                    }
                }
            }
            /**
             * Validates the spacing around a comma token.
             * @param commaToken The token representing the comma
             * @param prevToken The last token before the comma
             * @param nextToken The first token after the comma
             */
            function validateCommaSpacing(commaToken, prevToken, nextToken) {
                if (prevToken &&
                    (0, util_1.isTokenOnSameLine)(prevToken, commaToken) &&
                    // eslint-disable-next-line deprecation/deprecation -- TODO - switch once our min ESLint version is 6.7.0
                    spaceBefore !== sourceCode.isSpaceBetweenTokens(prevToken, commaToken)) {
                    context.report({
                        node: commaToken,
                        data: {
                            loc: 'before',
                        },
                        messageId: spaceBefore ? 'missing' : 'unexpected',
                        fix: fixer => spaceBefore
                            ? fixer.insertTextBefore(commaToken, ' ')
                            : fixer.replaceTextRange([prevToken.range[1], commaToken.range[0]], ''),
                    });
                }
                if (nextToken && (0, util_1.isClosingParenToken)(nextToken)) {
                    return;
                }
                if (!spaceAfter && nextToken && nextToken.type === utils_1.AST_TOKEN_TYPES.Line) {
                    return;
                }
                if (nextToken &&
                    (0, util_1.isTokenOnSameLine)(commaToken, nextToken) &&
                    // eslint-disable-next-line deprecation/deprecation -- TODO - switch once our min ESLint version is 6.7.0
                    spaceAfter !== sourceCode.isSpaceBetweenTokens(commaToken, nextToken)) {
                    context.report({
                        node: commaToken,
                        data: {
                            loc: 'after',
                        },
                        messageId: spaceAfter ? 'missing' : 'unexpected',
                        fix: fixer => spaceAfter
                            ? fixer.insertTextAfter(commaToken, ' ')
                            : fixer.replaceTextRange([commaToken.range[1], nextToken.range[0]], ''),
                    });
                }
            }
            return {
                TSTypeParameterDeclaration: addTypeParametersTrailingCommaToIgnoreList,
                ArrayExpression: addNullElementsToIgnoreList,
                ArrayPattern: addNullElementsToIgnoreList,
                'Program:exit'() {
                    tokensAndComments.forEach((token, i) => {
                        if (!(0, util_1.isCommaToken)(token)) {
                            return;
                        }
                        const prevToken = tokensAndComments[i - 1];
                        const nextToken = tokensAndComments[i + 1];
                        validateCommaSpacing(token, (0, util_1.isCommaToken)(prevToken) || ignoredTokens.has(token)
                            ? null
                            : prevToken, (nextToken && (0, util_1.isCommaToken)(nextToken)) || ignoredTokens.has(token)
                            ? null
                            : nextToken);
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/consistent-generic-constructors.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util_1 = require(1018) /* ../util */;
    exports.default = (0, util_1.createRule)({
        name: 'consistent-generic-constructors',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce specifying generic type arguments on type annotation or constructor name of a constructor call',
                recommended: 'strict',
            },
            messages: {
                preferTypeAnnotation: 'The generic type arguments should be specified as part of the type annotation.',
                preferConstructor: 'The generic type arguments should be specified as part of the constructor type arguments.',
            },
            fixable: 'code',
            schema: [
                {
                    enum: ['type-annotation', 'constructor'],
                },
            ],
        },
        defaultOptions: ['constructor'],
        create(context, [mode]) {
            const sourceCode = context.getSourceCode();
            return {
                'VariableDeclarator,PropertyDefinition,:matches(FunctionDeclaration,FunctionExpression) > AssignmentPattern'(node) {
                    var _a, _b;
                    function getLHSRHS() {
                        switch (node.type) {
                            case utils_1.AST_NODE_TYPES.VariableDeclarator:
                                return [node.id, node.init];
                            case utils_1.AST_NODE_TYPES.PropertyDefinition:
                                return [node, node.value];
                            case utils_1.AST_NODE_TYPES.AssignmentPattern:
                                return [node.left, node.right];
                            default:
                                throw new Error(`Unhandled node type: ${node.type}`);
                        }
                    }
                    const [lhsName, rhs] = getLHSRHS();
                    const lhs = (_a = lhsName.typeAnnotation) === null || _a === void 0 ? void 0 : _a.typeAnnotation;
                    if (!rhs ||
                        rhs.type !== utils_1.AST_NODE_TYPES.NewExpression ||
                        rhs.callee.type !== utils_1.AST_NODE_TYPES.Identifier) {
                        return;
                    }
                    if (lhs &&
                        (lhs.type !== utils_1.AST_NODE_TYPES.TSTypeReference ||
                            lhs.typeName.type !== utils_1.AST_NODE_TYPES.Identifier ||
                            lhs.typeName.name !== rhs.callee.name)) {
                        return;
                    }
                    if (mode === 'type-annotation') {
                        if (!lhs && rhs.typeParameters) {
                            const { typeParameters, callee } = rhs;
                            const typeAnnotation = sourceCode.getText(callee) + sourceCode.getText(typeParameters);
                            context.report({
                                node,
                                messageId: 'preferTypeAnnotation',
                                fix(fixer) {
                                    function getIDToAttachAnnotation() {
                                        if (node.type !== utils_1.AST_NODE_TYPES.PropertyDefinition) {
                                            return lhsName;
                                        }
                                        if (!node.computed) {
                                            return node.key;
                                        }
                                        // If the property's computed, we have to attach the
                                        // annotation after the square bracket, not the enclosed expression
                                        return sourceCode.getTokenAfter(node.key);
                                    }
                                    return [
                                        fixer.remove(typeParameters),
                                        fixer.insertTextAfter(getIDToAttachAnnotation(), ': ' + typeAnnotation),
                                    ];
                                },
                            });
                        }
                        return;
                    }
                    if (mode === 'constructor') {
                        if ((lhs === null || lhs === void 0 ? void 0 : lhs.typeParameters) && !rhs.typeParameters) {
                            const hasParens = ((_b = sourceCode.getTokenAfter(rhs.callee)) === null || _b === void 0 ? void 0 : _b.value) === '(';
                            const extraComments = new Set(sourceCode.getCommentsInside(lhs.parent));
                            sourceCode
                                .getCommentsInside(lhs.typeParameters)
                                .forEach(c => extraComments.delete(c));
                            context.report({
                                node,
                                messageId: 'preferConstructor',
                                *fix(fixer) {
                                    yield fixer.remove(lhs.parent);
                                    for (const comment of extraComments) {
                                        yield fixer.insertTextAfter(rhs.callee, sourceCode.getText(comment));
                                    }
                                    yield fixer.insertTextAfter(rhs.callee, sourceCode.getText(lhs.typeParameters));
                                    if (!hasParens) {
                                        yield fixer.insertTextAfter(rhs.callee, '()');
                                    }
                                },
                            });
                        }
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/consistent-indexed-object-style.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util_1 = require(1018) /* ../util */;
    exports.default = (0, util_1.createRule)({
        name: 'consistent-indexed-object-style',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require or disallow the `Record` type',
                recommended: 'strict',
            },
            messages: {
                preferRecord: 'A record is preferred over an index signature.',
                preferIndexSignature: 'An index signature is preferred over a record.',
            },
            fixable: 'code',
            schema: [
                {
                    enum: ['record', 'index-signature'],
                },
            ],
        },
        defaultOptions: ['record'],
        create(context, [mode]) {
            const sourceCode = context.getSourceCode();
            function checkMembers(members, node, parentId, prefix, postfix, safeFix = true) {
                if (members.length !== 1) {
                    return;
                }
                const [member] = members;
                if (member.type !== utils_1.AST_NODE_TYPES.TSIndexSignature) {
                    return;
                }
                const [parameter] = member.parameters;
                if (!parameter) {
                    return;
                }
                if (parameter.type !== utils_1.AST_NODE_TYPES.Identifier) {
                    return;
                }
                const keyType = parameter.typeAnnotation;
                if (!keyType) {
                    return;
                }
                const valueType = member.typeAnnotation;
                if (!valueType) {
                    return;
                }
                if (parentId) {
                    const scope = context.getScope();
                    const superVar = utils_1.ASTUtils.findVariable(scope, parentId.name);
                    if (superVar) {
                        const isCircular = superVar.references.some(item => item.isTypeReference &&
                            node.range[0] <= item.identifier.range[0] &&
                            node.range[1] >= item.identifier.range[1]);
                        if (isCircular) {
                            return;
                        }
                    }
                }
                context.report({
                    node,
                    messageId: 'preferRecord',
                    fix: safeFix
                        ? (fixer) => {
                            const key = sourceCode.getText(keyType.typeAnnotation);
                            const value = sourceCode.getText(valueType.typeAnnotation);
                            const record = member.readonly
                                ? `Readonly<Record<${key}, ${value}>>`
                                : `Record<${key}, ${value}>`;
                            return fixer.replaceText(node, `${prefix}${record}${postfix}`);
                        }
                        : null,
                });
            }
            return Object.assign(Object.assign({}, (mode === 'index-signature' && {
                TSTypeReference(node) {
                    var _a;
                    const typeName = node.typeName;
                    if (typeName.type !== utils_1.AST_NODE_TYPES.Identifier) {
                        return;
                    }
                    if (typeName.name !== 'Record') {
                        return;
                    }
                    const params = (_a = node.typeParameters) === null || _a === void 0 ? void 0 : _a.params;
                    if ((params === null || params === void 0 ? void 0 : params.length) !== 2) {
                        return;
                    }
                    context.report({
                        node,
                        messageId: 'preferIndexSignature',
                        fix(fixer) {
                            const key = sourceCode.getText(params[0]);
                            const type = sourceCode.getText(params[1]);
                            return fixer.replaceText(node, `{ [key: ${key}]: ${type} }`);
                        },
                    });
                },
            })), (mode === 'record' && {
                TSTypeLiteral(node) {
                    const parent = findParentDeclaration(node);
                    checkMembers(node.members, node, parent === null || parent === void 0 ? void 0 : parent.id, '', '');
                },
                TSInterfaceDeclaration(node) {
                    var _a, _b, _c, _d;
                    let genericTypes = '';
                    if (((_b = (_a = node.typeParameters) === null || _a === void 0 ? void 0 : _a.params) !== null && _b !== void 0 ? _b : []).length > 0) {
                        genericTypes = `<${(_c = node.typeParameters) === null || _c === void 0 ? void 0 : _c.params.map(p => sourceCode.getText(p)).join(', ')}>`;
                    }
                    checkMembers(node.body.body, node, node.id, `type ${node.id.name}${genericTypes} = `, ';', !((_d = node.extends) === null || _d === void 0 ? void 0 : _d.length));
                },
            }));
        },
    });
    function findParentDeclaration(node) {
        if (node.parent && node.parent.type !== utils_1.AST_NODE_TYPES.TSTypeAnnotation) {
            if (node.parent.type === utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration) {
                return node.parent;
            }
            return findParentDeclaration(node.parent);
        }
        return undefined;
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/consistent-type-assertions.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'consistent-type-assertions',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce consistent usage of type assertions',
                recommended: 'strict',
            },
            messages: {
                as: "Use 'as {{cast}}' instead of '<{{cast}}>'.",
                'angle-bracket': "Use '<{{cast}}>' instead of 'as {{cast}}'.",
                never: 'Do not use any type assertions.',
                unexpectedObjectTypeAssertion: 'Always prefer const x: T = { ... }.',
            },
            schema: [
                {
                    oneOf: [
                        {
                            type: 'object',
                            properties: {
                                assertionStyle: {
                                    enum: ['never'],
                                },
                            },
                            additionalProperties: false,
                            required: ['assertionStyle'],
                        },
                        {
                            type: 'object',
                            properties: {
                                assertionStyle: {
                                    enum: ['as', 'angle-bracket'],
                                },
                                objectLiteralTypeAssertions: {
                                    enum: ['allow', 'allow-as-parameter', 'never'],
                                },
                            },
                            additionalProperties: false,
                            required: ['assertionStyle'],
                        },
                    ],
                },
            ],
        },
        defaultOptions: [
            {
                assertionStyle: 'as',
                objectLiteralTypeAssertions: 'allow',
            },
        ],
        create(context, [options]) {
            const sourceCode = context.getSourceCode();
            function isConst(node) {
                if (node.type !== utils_1.AST_NODE_TYPES.TSTypeReference) {
                    return false;
                }
                return (node.typeName.type === utils_1.AST_NODE_TYPES.Identifier &&
                    node.typeName.name === 'const');
            }
            function reportIncorrectAssertionType(node) {
                const messageId = options.assertionStyle;
                // If this node is `as const`, then don't report an error.
                if (isConst(node.typeAnnotation) && messageId === 'never') {
                    return;
                }
                context.report({
                    node,
                    messageId,
                    data: messageId !== 'never'
                        ? { cast: sourceCode.getText(node.typeAnnotation) }
                        : {},
                });
            }
            function checkType(node) {
                switch (node.type) {
                    case utils_1.AST_NODE_TYPES.TSAnyKeyword:
                    case utils_1.AST_NODE_TYPES.TSUnknownKeyword:
                        return false;
                    case utils_1.AST_NODE_TYPES.TSTypeReference:
                        return (
                        // Ignore `as const` and `<const>`
                        !isConst(node) ||
                            // Allow qualified names which have dots between identifiers, `Foo.Bar`
                            node.typeName.type === utils_1.AST_NODE_TYPES.TSQualifiedName);
                    default:
                        return true;
                }
            }
            function checkExpression(node) {
                if (options.assertionStyle === 'never' ||
                    options.objectLiteralTypeAssertions === 'allow' ||
                    node.expression.type !== utils_1.AST_NODE_TYPES.ObjectExpression) {
                    return;
                }
                if (options.objectLiteralTypeAssertions === 'allow-as-parameter' &&
                    node.parent &&
                    (node.parent.type === utils_1.AST_NODE_TYPES.NewExpression ||
                        node.parent.type === utils_1.AST_NODE_TYPES.CallExpression ||
                        node.parent.type === utils_1.AST_NODE_TYPES.ThrowStatement ||
                        node.parent.type === utils_1.AST_NODE_TYPES.AssignmentPattern ||
                        node.parent.type === utils_1.AST_NODE_TYPES.JSXExpressionContainer)) {
                    return;
                }
                if (checkType(node.typeAnnotation) &&
                    node.expression.type === utils_1.AST_NODE_TYPES.ObjectExpression) {
                    context.report({
                        node,
                        messageId: 'unexpectedObjectTypeAssertion',
                    });
                }
            }
            return {
                TSTypeAssertion(node) {
                    if (options.assertionStyle !== 'angle-bracket') {
                        reportIncorrectAssertionType(node);
                        return;
                    }
                    checkExpression(node);
                },
                TSAsExpression(node) {
                    if (options.assertionStyle !== 'as') {
                        reportIncorrectAssertionType(node);
                        return;
                    }
                    checkExpression(node);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/consistent-type-definitions.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'consistent-type-definitions',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce type definitions to consistently use either `interface` or `type`',
                recommended: 'strict',
            },
            messages: {
                interfaceOverType: 'Use an `interface` instead of a `type`.',
                typeOverInterface: 'Use a `type` instead of an `interface`.',
            },
            schema: [
                {
                    enum: ['interface', 'type'],
                },
            ],
            fixable: 'code',
        },
        defaultOptions: ['interface'],
        create(context, [option]) {
            const sourceCode = context.getSourceCode();
            /**
             * Iterates from the highest parent to the currently traversed node
             * to determine whether any node in tree is globally declared module declaration
             */
            function isCurrentlyTraversedNodeWithinModuleDeclaration() {
                return context
                    .getAncestors()
                    .some(node => node.type === utils_1.AST_NODE_TYPES.TSModuleDeclaration &&
                    node.declare &&
                    node.global);
            }
            return Object.assign(Object.assign({}, (option === 'interface' && {
                "TSTypeAliasDeclaration[typeAnnotation.type='TSTypeLiteral']"(node) {
                    context.report({
                        node: node.id,
                        messageId: 'interfaceOverType',
                        fix(fixer) {
                            var _a;
                            const typeNode = (_a = node.typeParameters) !== null && _a !== void 0 ? _a : node.id;
                            const fixes = [];
                            const firstToken = sourceCode.getTokenBefore(node.id);
                            if (firstToken) {
                                fixes.push(fixer.replaceText(firstToken, 'interface'));
                                fixes.push(fixer.replaceTextRange([typeNode.range[1], node.typeAnnotation.range[0]], ' '));
                            }
                            const afterToken = sourceCode.getTokenAfter(node.typeAnnotation);
                            if (afterToken &&
                                afterToken.type === utils_1.AST_TOKEN_TYPES.Punctuator &&
                                afterToken.value === ';') {
                                fixes.push(fixer.remove(afterToken));
                            }
                            return fixes;
                        },
                    });
                },
            })), (option === 'type' && {
                TSInterfaceDeclaration(node) {
                    const fix = isCurrentlyTraversedNodeWithinModuleDeclaration()
                        ? null
                        : (fixer) => {
                            var _a, _b;
                            const typeNode = (_a = node.typeParameters) !== null && _a !== void 0 ? _a : node.id;
                            const fixes = [];
                            const firstToken = sourceCode.getTokenBefore(node.id);
                            if (firstToken) {
                                fixes.push(fixer.replaceText(firstToken, 'type'));
                                fixes.push(fixer.replaceTextRange([typeNode.range[1], node.body.range[0]], ' = '));
                            }
                            if (node.extends) {
                                node.extends.forEach(heritage => {
                                    const typeIdentifier = sourceCode.getText(heritage);
                                    fixes.push(fixer.insertTextAfter(node.body, ` & ${typeIdentifier}`));
                                });
                            }
                            if (((_b = node.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.ExportDefaultDeclaration) {
                                fixes.push(fixer.removeRange([node.parent.range[0], node.range[0]]), fixer.insertTextAfter(node.body, `\nexport default ${node.id.name}`));
                            }
                            return fixes;
                        };
                    context.report({
                        node: node.id,
                        messageId: 'typeOverInterface',
                        /**
                         * remove automatically fix when the interface is within a declare global
                         * @see {@link https://github.com/typescript-eslint/typescript-eslint/issues/2707}
                         */
                        fix,
                    });
                },
            }));
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/consistent-type-exports.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const typescript_1 = require(21) /* typescript */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'consistent-type-exports',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce consistent usage of type exports',
                recommended: false,
                requiresTypeChecking: true,
            },
            messages: {
                typeOverValue: 'All exports in the declaration are only used as types. Use `export type`.',
                singleExportIsType: 'Type export {{exportNames}} is not a value and should be exported using `export type`.',
                multipleExportsAreTypes: 'Type exports {{exportNames}} are not values and should be exported using `export type`.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        fixMixedExportsWithInlineTypeSpecifier: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
            fixable: 'code',
        },
        defaultOptions: [
            {
                fixMixedExportsWithInlineTypeSpecifier: false,
            },
        ],
        create(context, [{ fixMixedExportsWithInlineTypeSpecifier }]) {
            const sourceCode = context.getSourceCode();
            const sourceExportsMap = {};
            const parserServices = util.getParserServices(context);
            return {
                ExportNamedDeclaration(node) {
                    var _a;
                    // Coerce the source into a string for use as a lookup entry.
                    const source = (_a = getSourceFromExport(node)) !== null && _a !== void 0 ? _a : 'undefined';
                    const sourceExports = (sourceExportsMap[source] || (sourceExportsMap[source] = {
                        source,
                        reportValueExports: [],
                        typeOnlyNamedExport: null,
                        valueOnlyNamedExport: null,
                    }));
                    // Cache the first encountered exports for the package. We will need to come
                    // back to these later when fixing the problems.
                    if (node.exportKind === 'type') {
                        if (sourceExports.typeOnlyNamedExport == null) {
                            // The export is a type export
                            sourceExports.typeOnlyNamedExport = node;
                        }
                    }
                    else if (sourceExports.valueOnlyNamedExport == null) {
                        // The export is a value export
                        sourceExports.valueOnlyNamedExport = node;
                    }
                    // Next for the current export, we will separate type/value specifiers.
                    const typeBasedSpecifiers = [];
                    const inlineTypeSpecifiers = [];
                    const valueSpecifiers = [];
                    // Note: it is valid to export values as types. We will avoid reporting errors
                    // when this is encountered.
                    if (node.exportKind !== 'type') {
                        for (const specifier of node.specifiers) {
                            if (specifier.exportKind === 'type') {
                                inlineTypeSpecifiers.push(specifier);
                                continue;
                            }
                            const isTypeBased = isSpecifierTypeBased(parserServices, specifier);
                            if (isTypeBased === true) {
                                typeBasedSpecifiers.push(specifier);
                            }
                            else if (isTypeBased === false) {
                                // When isTypeBased is undefined, we should avoid reporting them.
                                valueSpecifiers.push(specifier);
                            }
                        }
                    }
                    if ((node.exportKind === 'value' && typeBasedSpecifiers.length) ||
                        (node.exportKind === 'type' && valueSpecifiers.length)) {
                        sourceExports.reportValueExports.push({
                            node,
                            typeBasedSpecifiers,
                            valueSpecifiers,
                            inlineTypeSpecifiers,
                        });
                    }
                },
                'Program:exit'() {
                    for (const sourceExports of Object.values(sourceExportsMap)) {
                        // If this export has no issues, move on.
                        if (sourceExports.reportValueExports.length === 0) {
                            continue;
                        }
                        for (const report of sourceExports.reportValueExports) {
                            if (report.valueSpecifiers.length === 0) {
                                // Export is all type-only with no type specifiers; convert the entire export to `export type`.
                                context.report({
                                    node: report.node,
                                    messageId: 'typeOverValue',
                                    *fix(fixer) {
                                        yield* fixExportInsertType(fixer, sourceCode, report.node);
                                    },
                                });
                                continue;
                            }
                            // We have both type and value violations.
                            const allExportNames = report.typeBasedSpecifiers.map(specifier => `${specifier.local.name}`);
                            if (allExportNames.length === 1) {
                                const exportNames = allExportNames[0];
                                context.report({
                                    node: report.node,
                                    messageId: 'singleExportIsType',
                                    data: { exportNames },
                                    *fix(fixer) {
                                        if (fixMixedExportsWithInlineTypeSpecifier) {
                                            yield* fixAddTypeSpecifierToNamedExports(fixer, report);
                                        }
                                        else {
                                            yield* fixSeparateNamedExports(fixer, sourceCode, report);
                                        }
                                    },
                                });
                            }
                            else {
                                const exportNames = util.formatWordList(allExportNames);
                                context.report({
                                    node: report.node,
                                    messageId: 'multipleExportsAreTypes',
                                    data: { exportNames },
                                    *fix(fixer) {
                                        if (fixMixedExportsWithInlineTypeSpecifier) {
                                            yield* fixAddTypeSpecifierToNamedExports(fixer, report);
                                        }
                                        else {
                                            yield* fixSeparateNamedExports(fixer, sourceCode, report);
                                        }
                                    },
                                });
                            }
                        }
                    }
                },
            };
        },
    });
    /**
     * Helper for identifying if an export specifier resolves to a
     * JavaScript value or a TypeScript type.
     *
     * @returns True/false if is a type or not, or undefined if the specifier
     * can't be resolved.
     */
    function isSpecifierTypeBased(parserServices, specifier) {
        const checker = parserServices.program.getTypeChecker();
        const node = parserServices.esTreeNodeToTSNodeMap.get(specifier.exported);
        const symbol = checker.getSymbolAtLocation(node);
        const aliasedSymbol = checker.getAliasedSymbol(symbol);
        if (!aliasedSymbol || aliasedSymbol.escapedName === 'unknown') {
            return undefined;
        }
        return !(aliasedSymbol.flags & typescript_1.SymbolFlags.Value);
    }
    /**
     * Inserts "type" into an export.
     *
     * Example:
     *
     * export type { Foo } from 'foo';
     *        ^^^^
     */
    function* fixExportInsertType(fixer, sourceCode, node) {
        const exportToken = util.nullThrows(sourceCode.getFirstToken(node), util.NullThrowsReasons.MissingToken('export', node.type));
        yield fixer.insertTextAfter(exportToken, ' type');
        for (const specifier of node.specifiers) {
            if (specifier.exportKind === 'type') {
                const kindToken = util.nullThrows(sourceCode.getFirstToken(specifier), util.NullThrowsReasons.MissingToken('export', specifier.type));
                const firstTokenAfter = util.nullThrows(sourceCode.getTokenAfter(kindToken, {
                    includeComments: true,
                }), 'Missing token following the export kind.');
                yield fixer.removeRange([kindToken.range[0], firstTokenAfter.range[0]]);
            }
        }
    }
    /**
     * Separates the exports which mismatch the kind of export the given
     * node represents. For example, a type export's named specifiers which
     * represent values will be inserted in a separate `export` statement.
     */
    function* fixSeparateNamedExports(fixer, sourceCode, report) {
        const { node, typeBasedSpecifiers, inlineTypeSpecifiers, valueSpecifiers } = report;
        const typeSpecifiers = typeBasedSpecifiers.concat(inlineTypeSpecifiers);
        const source = getSourceFromExport(node);
        const specifierNames = typeSpecifiers.map(getSpecifierText).join(', ');
        const exportToken = util.nullThrows(sourceCode.getFirstToken(node), util.NullThrowsReasons.MissingToken('export', node.type));
        // Filter the bad exports from the current line.
        const filteredSpecifierNames = valueSpecifiers
            .map(getSpecifierText)
            .join(', ');
        const openToken = util.nullThrows(sourceCode.getFirstToken(node, util.isOpeningBraceToken), util.NullThrowsReasons.MissingToken('{', node.type));
        const closeToken = util.nullThrows(sourceCode.getLastToken(node, util.isClosingBraceToken), util.NullThrowsReasons.MissingToken('}', node.type));
        // Remove exports from the current line which we're going to re-insert.
        yield fixer.replaceTextRange([openToken.range[1], closeToken.range[0]], ` ${filteredSpecifierNames} `);
        // Insert the bad exports into a new export line above.
        yield fixer.insertTextBefore(exportToken, `export type { ${specifierNames} }${source ? ` from '${source}'` : ''};\n`);
    }
    function* fixAddTypeSpecifierToNamedExports(fixer, report) {
        if (report.node.exportKind === 'type') {
            return;
        }
        for (const specifier of report.typeBasedSpecifiers) {
            yield fixer.insertTextBefore(specifier, 'type ');
        }
    }
    /**
     * Returns the source of the export, or undefined if the named export has no source.
     */
    function getSourceFromExport(node) {
        var _a;
        if (((_a = node.source) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.Literal &&
            typeof node.source.value === 'string') {
            return node.source.value;
        }
        return undefined;
    }
    /**
     * Returns the specifier text for the export. If it is aliased, we take care to return
     * the proper formatting.
     */
    function getSpecifierText(specifier) {
        return `${specifier.local.name}${specifier.exported.name !== specifier.local.name
            ? ` as ${specifier.exported.name}`
            : ''}`;
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/consistent-type-imports.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'consistent-type-imports',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce consistent usage of type imports',
                recommended: false,
            },
            messages: {
                typeOverValue: 'All imports in the declaration are only used as types. Use `import type`.',
                someImportsAreOnlyTypes: 'Imports {{typeImports}} are only used as types.',
                aImportIsOnlyTypes: 'Import {{typeImports}} is only used as types.',
                someImportsInDecoMeta: 'Type imports {{typeImports}} are used by decorator metadata.',
                aImportInDecoMeta: 'Type import {{typeImports}} is used by decorator metadata.',
                valueOverType: 'Use an `import` instead of an `import type`.',
                noImportTypeAnnotations: '`import()` type annotations are forbidden.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        prefer: {
                            enum: ['type-imports', 'no-type-imports'],
                        },
                        disallowTypeAnnotations: {
                            type: 'boolean',
                        },
                        fixStyle: {
                            enum: ['separate-type-imports', 'inline-type-imports'],
                        },
                    },
                    additionalProperties: false,
                },
            ],
            fixable: 'code',
        },
        defaultOptions: [
            {
                prefer: 'type-imports',
                disallowTypeAnnotations: true,
                fixStyle: 'separate-type-imports',
            },
        ],
        create(context, [option]) {
            var _a, _b;
            const prefer = (_a = option.prefer) !== null && _a !== void 0 ? _a : 'type-imports';
            const disallowTypeAnnotations = option.disallowTypeAnnotations !== false;
            const fixStyle = (_b = option.fixStyle) !== null && _b !== void 0 ? _b : 'separate-type-imports';
            const sourceCode = context.getSourceCode();
            const sourceImportsMap = {};
            return Object.assign(Object.assign({}, (prefer === 'type-imports'
                ? {
                    // prefer type imports
                    ImportDeclaration(node) {
                        var _a;
                        const source = node.source.value;
                        // sourceImports is the object containing all the specifics for a particular import source, type or value
                        const sourceImports = (_a = sourceImportsMap[source]) !== null && _a !== void 0 ? _a : (sourceImportsMap[source] = {
                            source,
                            reportValueImports: [],
                            typeOnlyNamedImport: null,
                            valueOnlyNamedImport: null,
                            valueImport: null, // if only value imports
                        });
                        if (node.importKind === 'type') {
                            if (!sourceImports.typeOnlyNamedImport &&
                                node.specifiers.every(specifier => specifier.type === utils_1.AST_NODE_TYPES.ImportSpecifier)) {
                                // definitely import type { TypeX }
                                sourceImports.typeOnlyNamedImport = node;
                            }
                        }
                        else {
                            if (!sourceImports.valueOnlyNamedImport &&
                                node.specifiers.every(specifier => specifier.type === utils_1.AST_NODE_TYPES.ImportSpecifier)) {
                                sourceImports.valueOnlyNamedImport = node;
                                sourceImports.valueImport = node;
                            }
                            else if (!sourceImports.valueImport &&
                                node.specifiers.some(specifier => specifier.type === utils_1.AST_NODE_TYPES.ImportDefaultSpecifier)) {
                                sourceImports.valueImport = node;
                            }
                        }
                        const typeSpecifiers = [];
                        const inlineTypeSpecifiers = [];
                        const valueSpecifiers = [];
                        const unusedSpecifiers = [];
                        for (const specifier of node.specifiers) {
                            if (specifier.type === utils_1.AST_NODE_TYPES.ImportSpecifier &&
                                specifier.importKind === 'type') {
                                inlineTypeSpecifiers.push(specifier);
                                continue;
                            }
                            const [variable] = context.getDeclaredVariables(specifier);
                            if (variable.references.length === 0) {
                                unusedSpecifiers.push(specifier);
                            }
                            else {
                                const onlyHasTypeReferences = variable.references.every(ref => {
                                    var _a, _b;
                                    /**
                                     * keep origin import kind when export
                                     * export { Type }
                                     * export default Type;
                                     */
                                    if (((_a = ref.identifier.parent) === null || _a === void 0 ? void 0 : _a.type) ===
                                        utils_1.AST_NODE_TYPES.ExportSpecifier ||
                                        ((_b = ref.identifier.parent) === null || _b === void 0 ? void 0 : _b.type) ===
                                            utils_1.AST_NODE_TYPES.ExportDefaultDeclaration) {
                                        if (ref.isValueReference && ref.isTypeReference) {
                                            return node.importKind === 'type';
                                        }
                                    }
                                    if (ref.isValueReference) {
                                        let parent = ref.identifier.parent;
                                        let child = ref.identifier;
                                        while (parent) {
                                            switch (parent.type) {
                                                // CASE 1:
                                                // `type T = typeof foo` will create a value reference because "foo" must be a value type
                                                // however this value reference is safe to use with type-only imports
                                                case utils_1.AST_NODE_TYPES.TSTypeQuery:
                                                    return true;
                                                case utils_1.AST_NODE_TYPES.TSQualifiedName:
                                                    // TSTypeQuery must have a TSESTree.EntityName as its child, so we can filter here and break early
                                                    if (parent.left !== child) {
                                                        return false;
                                                    }
                                                    child = parent;
                                                    parent = parent.parent;
                                                    continue;
                                                // END CASE 1
                                                //////////////
                                                // CASE 2:
                                                // `type T = { [foo]: string }` will create a value reference because "foo" must be a value type
                                                // however this value reference is safe to use with type-only imports.
                                                // Also this is represented as a non-type AST - hence it uses MemberExpression
                                                case utils_1.AST_NODE_TYPES.TSPropertySignature:
                                                    return parent.key === child;
                                                case utils_1.AST_NODE_TYPES.MemberExpression:
                                                    if (parent.object !== child) {
                                                        return false;
                                                    }
                                                    child = parent;
                                                    parent = parent.parent;
                                                    continue;
                                                // END CASE 2
                                                default:
                                                    return false;
                                            }
                                        }
                                    }
                                    return ref.isTypeReference;
                                });
                                if (onlyHasTypeReferences) {
                                    typeSpecifiers.push(specifier);
                                }
                                else {
                                    valueSpecifiers.push(specifier);
                                }
                            }
                        }
                        if ((node.importKind === 'value' && typeSpecifiers.length) ||
                            (node.importKind === 'type' && valueSpecifiers.length)) {
                            sourceImports.reportValueImports.push({
                                node,
                                typeSpecifiers,
                                valueSpecifiers,
                                unusedSpecifiers,
                                inlineTypeSpecifiers,
                            });
                        }
                    },
                    'Program:exit'() {
                        for (const sourceImports of Object.values(sourceImportsMap)) {
                            if (sourceImports.reportValueImports.length === 0) {
                                // nothing to fix. value specifiers and type specifiers are correctly written
                                continue;
                            }
                            for (const report of sourceImports.reportValueImports) {
                                if (report.valueSpecifiers.length === 0 &&
                                    report.unusedSpecifiers.length === 0 &&
                                    report.node.importKind !== 'type') {
                                    context.report({
                                        node: report.node,
                                        messageId: 'typeOverValue',
                                        *fix(fixer) {
                                            yield* fixToTypeImportDeclaration(fixer, report, sourceImports);
                                        },
                                    });
                                }
                                else {
                                    const isTypeImport = report.node.importKind === 'type';
                                    // we have a mixed type/value import or just value imports, so we need to split them out into multiple imports if separate-type-imports is configured
                                    const importNames = (isTypeImport
                                        ? report.valueSpecifiers // import type { A } from 'roo'; // WHERE A is used in value position
                                        : report.typeSpecifiers) // import { A, B } from 'roo'; // WHERE A is used in type position and B is in value position
                                        .map(specifier => `"${specifier.local.name}"`);
                                    const message = (() => {
                                        const typeImports = util.formatWordList(importNames);
                                        if (importNames.length === 1) {
                                            if (isTypeImport) {
                                                return {
                                                    messageId: 'aImportInDecoMeta',
                                                    data: { typeImports },
                                                };
                                            }
                                            else {
                                                return {
                                                    messageId: 'aImportIsOnlyTypes',
                                                    data: { typeImports },
                                                };
                                            }
                                        }
                                        else {
                                            if (isTypeImport) {
                                                return {
                                                    messageId: 'someImportsInDecoMeta',
                                                    data: { typeImports }, // typeImports are all the value specifiers that are in the type position
                                                };
                                            }
                                            else {
                                                return {
                                                    messageId: 'someImportsAreOnlyTypes',
                                                    data: { typeImports }, // typeImports are all the type specifiers in the value position
                                                };
                                            }
                                        }
                                    })();
                                    context.report(Object.assign(Object.assign({ node: report.node }, message), { *fix(fixer) {
                                            if (isTypeImport) {
                                                // take all the valueSpecifiers and put them on a new line
                                                yield* fixToValueImportDeclaration(fixer, report, sourceImports);
                                            }
                                            else {
                                                // take all the typeSpecifiers and put them on a new line
                                                yield* fixToTypeImportDeclaration(fixer, report, sourceImports);
                                            }
                                        } }));
                                }
                            }
                        }
                    },
                }
                : {
                    // prefer no type imports
                    'ImportDeclaration[importKind = "type"]'(node) {
                        context.report({
                            node,
                            messageId: 'valueOverType',
                            fix(fixer) {
                                return fixRemoveTypeSpecifierFromImportDeclaration(fixer, node);
                            },
                        });
                    },
                    'ImportSpecifier[importKind = "type"]'(node) {
                        context.report({
                            node,
                            messageId: 'valueOverType',
                            fix(fixer) {
                                return fixRemoveTypeSpecifierFromImportSpecifier(fixer, node);
                            },
                        });
                    },
                })), (disallowTypeAnnotations
                ? {
                    // disallow `import()` type
                    TSImportType(node) {
                        context.report({
                            node,
                            messageId: 'noImportTypeAnnotations',
                        });
                    },
                }
                : {}));
            function classifySpecifier(node) {
                var _a;
                const defaultSpecifier = node.specifiers[0].type === utils_1.AST_NODE_TYPES.ImportDefaultSpecifier
                    ? node.specifiers[0]
                    : null;
                const namespaceSpecifier = (_a = node.specifiers.find((specifier) => specifier.type === utils_1.AST_NODE_TYPES.ImportNamespaceSpecifier)) !== null && _a !== void 0 ? _a : null;
                const namedSpecifiers = node.specifiers.filter((specifier) => specifier.type === utils_1.AST_NODE_TYPES.ImportSpecifier);
                return {
                    defaultSpecifier,
                    namespaceSpecifier,
                    namedSpecifiers,
                };
            }
            /**
             * Returns information for fixing named specifiers, type or value
             */
            function getFixesNamedSpecifiers(fixer, node, subsetNamedSpecifiers, allNamedSpecifiers) {
                if (allNamedSpecifiers.length === 0) {
                    return {
                        typeNamedSpecifiersText: '',
                        removeTypeNamedSpecifiers: [],
                    };
                }
                const typeNamedSpecifiersTexts = [];
                const removeTypeNamedSpecifiers = [];
                if (subsetNamedSpecifiers.length === allNamedSpecifiers.length) {
                    // import Foo, {Type1, Type2} from 'foo'
                    // import DefType, {Type1, Type2} from 'foo'
                    const openingBraceToken = util.nullThrows(sourceCode.getTokenBefore(subsetNamedSpecifiers[0], util.isOpeningBraceToken), util.NullThrowsReasons.MissingToken('{', node.type));
                    const commaToken = util.nullThrows(sourceCode.getTokenBefore(openingBraceToken, util.isCommaToken), util.NullThrowsReasons.MissingToken(',', node.type));
                    const closingBraceToken = util.nullThrows(sourceCode.getFirstTokenBetween(openingBraceToken, node.source, util.isClosingBraceToken), util.NullThrowsReasons.MissingToken('}', node.type));
                    // import DefType, {...} from 'foo'
                    //               ^^^^^^^ remove
                    removeTypeNamedSpecifiers.push(fixer.removeRange([commaToken.range[0], closingBraceToken.range[1]]));
                    typeNamedSpecifiersTexts.push(sourceCode.text.slice(openingBraceToken.range[1], closingBraceToken.range[0]));
                }
                else {
                    const namedSpecifierGroups = [];
                    let group = [];
                    for (const namedSpecifier of allNamedSpecifiers) {
                        if (subsetNamedSpecifiers.includes(namedSpecifier)) {
                            group.push(namedSpecifier);
                        }
                        else if (group.length) {
                            namedSpecifierGroups.push(group);
                            group = [];
                        }
                    }
                    if (group.length) {
                        namedSpecifierGroups.push(group);
                    }
                    for (const namedSpecifiers of namedSpecifierGroups) {
                        const { removeRange, textRange } = getNamedSpecifierRanges(namedSpecifiers, allNamedSpecifiers);
                        removeTypeNamedSpecifiers.push(fixer.removeRange(removeRange));
                        typeNamedSpecifiersTexts.push(sourceCode.text.slice(...textRange));
                    }
                }
                return {
                    typeNamedSpecifiersText: typeNamedSpecifiersTexts.join(','),
                    removeTypeNamedSpecifiers,
                };
            }
            /**
             * Returns ranges for fixing named specifier.
             */
            function getNamedSpecifierRanges(namedSpecifierGroup, allNamedSpecifiers) {
                const first = namedSpecifierGroup[0];
                const last = namedSpecifierGroup[namedSpecifierGroup.length - 1];
                const removeRange = [first.range[0], last.range[1]];
                const textRange = [...removeRange];
                const before = sourceCode.getTokenBefore(first);
                textRange[0] = before.range[1];
                if (util.isCommaToken(before)) {
                    removeRange[0] = before.range[0];
                }
                else {
                    removeRange[0] = before.range[1];
                }
                const isFirst = allNamedSpecifiers[0] === first;
                const isLast = allNamedSpecifiers[allNamedSpecifiers.length - 1] === last;
                const after = sourceCode.getTokenAfter(last);
                textRange[1] = after.range[0];
                if (isFirst || isLast) {
                    if (util.isCommaToken(after)) {
                        removeRange[1] = after.range[1];
                    }
                }
                return {
                    textRange,
                    removeRange,
                };
            }
            /**
             * insert specifiers to named import node.
             * e.g.
             * import type { Already, Type1, Type2 } from 'foo'
             *                        ^^^^^^^^^^^^^ insert
             */
            function fixInsertNamedSpecifiersInNamedSpecifierList(fixer, target, insertText) {
                const closingBraceToken = util.nullThrows(sourceCode.getFirstTokenBetween(sourceCode.getFirstToken(target), target.source, util.isClosingBraceToken), util.NullThrowsReasons.MissingToken('}', target.type));
                const before = sourceCode.getTokenBefore(closingBraceToken);
                if (!util.isCommaToken(before) && !util.isOpeningBraceToken(before)) {
                    insertText = `,${insertText}`;
                }
                return fixer.insertTextBefore(closingBraceToken, insertText);
            }
            /**
             * insert type keyword to named import node.
             * e.g.
             * import ADefault, { Already, type Type1, type Type2 } from 'foo'
             *                             ^^^^ insert
             */
            function* fixInsertTypeKeywordInNamedSpecifierList(fixer, typeSpecifiers) {
                for (const spec of typeSpecifiers) {
                    const insertText = sourceCode.text.slice(...spec.range);
                    yield fixer.replaceTextRange(spec.range, `type ${insertText}`);
                }
            }
            function* fixInlineTypeImportDeclaration(fixer, report, sourceImports) {
                const { node } = report;
                // For a value import, will only add an inline type to named specifiers
                const { namedSpecifiers } = classifySpecifier(node);
                const typeNamedSpecifiers = namedSpecifiers.filter(specifier => report.typeSpecifiers.includes(specifier));
                if (sourceImports.valueImport) {
                    // add import named type specifiers to its value import
                    // import ValueA, { type A }
                    //                  ^^^^ insert
                    const { namedSpecifiers: valueImportNamedSpecifiers } = classifySpecifier(sourceImports.valueImport);
                    if (sourceImports.valueOnlyNamedImport ||
                        valueImportNamedSpecifiers.length) {
                        yield* fixInsertTypeKeywordInNamedSpecifierList(fixer, typeNamedSpecifiers);
                    }
                }
            }
            function* fixToTypeImportDeclaration(fixer, report, sourceImports) {
                const { node } = report;
                const { defaultSpecifier, namespaceSpecifier, namedSpecifiers } = classifySpecifier(node);
                if (namespaceSpecifier && !defaultSpecifier) {
                    // import * as types from 'foo'
                    yield* fixInsertTypeSpecifierForImportDeclaration(fixer, node, false);
                    return;
                }
                else if (defaultSpecifier) {
                    if (report.typeSpecifiers.includes(defaultSpecifier) &&
                        namedSpecifiers.length === 0 &&
                        !namespaceSpecifier) {
                        // import Type from 'foo'
                        yield* fixInsertTypeSpecifierForImportDeclaration(fixer, node, true);
                        return;
                    }
                    else if (fixStyle === 'inline-type-imports' &&
                        !report.typeSpecifiers.includes(defaultSpecifier) &&
                        namedSpecifiers.length > 0 &&
                        !namespaceSpecifier) {
                        // if there is a default specifier but it isn't a type specifier, then just add the inline type modifier to the named specifiers
                        // import AValue, {BValue, Type1, Type2} from 'foo'
                        yield* fixInlineTypeImportDeclaration(fixer, report, sourceImports);
                        return;
                    }
                }
                else if (!namespaceSpecifier) {
                    if (fixStyle === 'inline-type-imports' &&
                        namedSpecifiers.some(specifier => report.typeSpecifiers.includes(specifier))) {
                        // import {AValue, Type1, Type2} from 'foo'
                        yield* fixInlineTypeImportDeclaration(fixer, report, sourceImports);
                        return;
                    }
                    else if (namedSpecifiers.every(specifier => report.typeSpecifiers.includes(specifier))) {
                        // import {Type1, Type2} from 'foo'
                        yield* fixInsertTypeSpecifierForImportDeclaration(fixer, node, false);
                        return;
                    }
                }
                const typeNamedSpecifiers = namedSpecifiers.filter(specifier => report.typeSpecifiers.includes(specifier));
                const fixesNamedSpecifiers = getFixesNamedSpecifiers(fixer, node, typeNamedSpecifiers, namedSpecifiers);
                const afterFixes = [];
                if (typeNamedSpecifiers.length) {
                    if (sourceImports.typeOnlyNamedImport) {
                        const insertTypeNamedSpecifiers = fixInsertNamedSpecifiersInNamedSpecifierList(fixer, sourceImports.typeOnlyNamedImport, fixesNamedSpecifiers.typeNamedSpecifiersText);
                        if (sourceImports.typeOnlyNamedImport.range[1] <= node.range[0]) {
                            yield insertTypeNamedSpecifiers;
                        }
                        else {
                            afterFixes.push(insertTypeNamedSpecifiers);
                        }
                    }
                    else {
                        // The import is both default and named.  Insert named on new line because can't mix default type import and named type imports
                        if (fixStyle === 'inline-type-imports') {
                            yield fixer.insertTextBefore(node, `import {${typeNamedSpecifiers
                                .map(spec => {
                                const insertText = sourceCode.text.slice(...spec.range);
                                return `type ${insertText}`;
                            })
                                .join(', ')}} from ${sourceCode.getText(node.source)};\n`);
                        }
                        else {
                            yield fixer.insertTextBefore(node, `import type {${fixesNamedSpecifiers.typeNamedSpecifiersText}} from ${sourceCode.getText(node.source)};\n`);
                        }
                    }
                }
                const fixesRemoveTypeNamespaceSpecifier = [];
                if (namespaceSpecifier &&
                    report.typeSpecifiers.includes(namespaceSpecifier)) {
                    // import Foo, * as Type from 'foo'
                    // import DefType, * as Type from 'foo'
                    // import DefType, * as Type from 'foo'
                    const commaToken = util.nullThrows(sourceCode.getTokenBefore(namespaceSpecifier, util.isCommaToken), util.NullThrowsReasons.MissingToken(',', node.type));
                    // import Def, * as Ns from 'foo'
                    //           ^^^^^^^^^ remove
                    fixesRemoveTypeNamespaceSpecifier.push(fixer.removeRange([commaToken.range[0], namespaceSpecifier.range[1]]));
                    // import type * as Ns from 'foo'
                    // ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ insert
                    yield fixer.insertTextBefore(node, `import type ${sourceCode.getText(namespaceSpecifier)} from ${sourceCode.getText(node.source)};\n`);
                }
                if (defaultSpecifier &&
                    report.typeSpecifiers.includes(defaultSpecifier)) {
                    if (report.typeSpecifiers.length === node.specifiers.length) {
                        const importToken = util.nullThrows(sourceCode.getFirstToken(node, util.isImportKeyword), util.NullThrowsReasons.MissingToken('import', node.type));
                        // import type Type from 'foo'
                        //        ^^^^ insert
                        yield fixer.insertTextAfter(importToken, ' type');
                    }
                    else {
                        const commaToken = util.nullThrows(sourceCode.getTokenAfter(defaultSpecifier, util.isCommaToken), util.NullThrowsReasons.MissingToken(',', defaultSpecifier.type));
                        // import Type , {...} from 'foo'
                        //        ^^^^^ pick
                        const defaultText = sourceCode.text
                            .slice(defaultSpecifier.range[0], commaToken.range[0])
                            .trim();
                        yield fixer.insertTextBefore(node, `import type ${defaultText} from ${sourceCode.getText(node.source)};\n`);
                        const afterToken = util.nullThrows(sourceCode.getTokenAfter(commaToken, { includeComments: true }), util.NullThrowsReasons.MissingToken('any token', node.type));
                        // import Type , {...} from 'foo'
                        //        ^^^^^^^ remove
                        yield fixer.removeRange([
                            defaultSpecifier.range[0],
                            afterToken.range[0],
                        ]);
                    }
                }
                yield* fixesNamedSpecifiers.removeTypeNamedSpecifiers;
                yield* fixesRemoveTypeNamespaceSpecifier;
                yield* afterFixes;
            }
            function* fixInsertTypeSpecifierForImportDeclaration(fixer, node, isDefaultImport) {
                // import type Foo from 'foo'
                //       ^^^^^ insert
                const importToken = util.nullThrows(sourceCode.getFirstToken(node, util.isImportKeyword), util.NullThrowsReasons.MissingToken('import', node.type));
                yield fixer.insertTextAfter(importToken, ' type');
                if (isDefaultImport) {
                    // Has default import
                    const openingBraceToken = sourceCode.getFirstTokenBetween(importToken, node.source, util.isOpeningBraceToken);
                    if (openingBraceToken) {
                        // Only braces. e.g. import Foo, {} from 'foo'
                        const commaToken = util.nullThrows(sourceCode.getTokenBefore(openingBraceToken, util.isCommaToken), util.NullThrowsReasons.MissingToken(',', node.type));
                        const closingBraceToken = util.nullThrows(sourceCode.getFirstTokenBetween(openingBraceToken, node.source, util.isClosingBraceToken), util.NullThrowsReasons.MissingToken('}', node.type));
                        // import type Foo, {} from 'foo'
                        //                  ^^ remove
                        yield fixer.removeRange([
                            commaToken.range[0],
                            closingBraceToken.range[1],
                        ]);
                        const specifiersText = sourceCode.text.slice(commaToken.range[1], closingBraceToken.range[1]);
                        if (node.specifiers.length > 1) {
                            yield fixer.insertTextAfter(node, `\nimport type${specifiersText} from ${sourceCode.getText(node.source)};`);
                        }
                    }
                }
                // make sure we don't do anything like `import type {type T} from 'foo';`
                for (const specifier of node.specifiers) {
                    if (specifier.type === utils_1.AST_NODE_TYPES.ImportSpecifier &&
                        specifier.importKind === 'type') {
                        yield* fixRemoveTypeSpecifierFromImportSpecifier(fixer, specifier);
                    }
                }
            }
            function* fixToValueImportDeclaration(fixer, report, sourceImports) {
                const { node } = report;
                const { defaultSpecifier, namespaceSpecifier, namedSpecifiers } = classifySpecifier(node);
                if (namespaceSpecifier) {
                    // import type * as types from 'foo'
                    yield* fixRemoveTypeSpecifierFromImportDeclaration(fixer, node);
                    return;
                }
                else if (defaultSpecifier) {
                    if (report.valueSpecifiers.includes(defaultSpecifier) &&
                        namedSpecifiers.length === 0) {
                        // import type Type from 'foo'
                        yield* fixRemoveTypeSpecifierFromImportDeclaration(fixer, node);
                        return;
                    }
                }
                else {
                    if (namedSpecifiers.every(specifier => report.valueSpecifiers.includes(specifier))) {
                        // import type {Type1, Type2} from 'foo'
                        yield* fixRemoveTypeSpecifierFromImportDeclaration(fixer, node);
                        return;
                    }
                }
                // we have some valueSpecifiers intermixed in types that need to be put on their own line
                // import type { Type1, A } from 'foo'
                // import type { A } from 'foo'
                const valueNamedSpecifiers = namedSpecifiers.filter(specifier => report.valueSpecifiers.includes(specifier));
                const fixesNamedSpecifiers = getFixesNamedSpecifiers(fixer, node, valueNamedSpecifiers, namedSpecifiers);
                const afterFixes = [];
                if (valueNamedSpecifiers.length) {
                    if (sourceImports.valueOnlyNamedImport) {
                        const insertTypeNamedSpecifiers = fixInsertNamedSpecifiersInNamedSpecifierList(fixer, sourceImports.valueOnlyNamedImport, fixesNamedSpecifiers.typeNamedSpecifiersText);
                        if (sourceImports.valueOnlyNamedImport.range[1] <= node.range[0]) {
                            yield insertTypeNamedSpecifiers;
                        }
                        else {
                            afterFixes.push(insertTypeNamedSpecifiers);
                        }
                    }
                    else {
                        // some are types.
                        // Add new value import and later remove those value specifiers from import type
                        yield fixer.insertTextBefore(node, `import {${fixesNamedSpecifiers.typeNamedSpecifiersText}} from ${sourceCode.getText(node.source)};\n`);
                    }
                }
                yield* fixesNamedSpecifiers.removeTypeNamedSpecifiers;
                yield* afterFixes;
            }
            function* fixRemoveTypeSpecifierFromImportDeclaration(fixer, node) {
                var _a, _b;
                // import type Foo from 'foo'
                //        ^^^^ remove
                const importToken = util.nullThrows(sourceCode.getFirstToken(node, util.isImportKeyword), util.NullThrowsReasons.MissingToken('import', node.type));
                const typeToken = util.nullThrows(sourceCode.getFirstTokenBetween(importToken, (_b = (_a = node.specifiers[0]) === null || _a === void 0 ? void 0 : _a.local) !== null && _b !== void 0 ? _b : node.source, util.isTypeKeyword), util.NullThrowsReasons.MissingToken('type', node.type));
                const afterToken = util.nullThrows(sourceCode.getTokenAfter(typeToken, { includeComments: true }), util.NullThrowsReasons.MissingToken('any token', node.type));
                yield fixer.removeRange([typeToken.range[0], afterToken.range[0]]);
            }
            function* fixRemoveTypeSpecifierFromImportSpecifier(fixer, node) {
                // import { type Foo } from 'foo'
                //          ^^^^ remove
                const typeToken = util.nullThrows(sourceCode.getFirstToken(node, util.isTypeKeyword), util.NullThrowsReasons.MissingToken('type', node.type));
                const afterToken = util.nullThrows(sourceCode.getTokenAfter(typeToken, { includeComments: true }), util.NullThrowsReasons.MissingToken('any token', node.type));
                yield fixer.removeRange([typeToken.range[0], afterToken.range[0]]);
            }
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/default-param-last.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util_1 = require(1018) /* ../util */;
    exports.default = (0, util_1.createRule)({
        name: 'default-param-last',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce default parameters to be last',
                recommended: false,
                extendsBaseRule: true,
            },
            schema: [],
            messages: {
                shouldBeLast: 'Default parameters should be last.',
            },
        },
        defaultOptions: [],
        create(context) {
            /**
             * checks if node is optional parameter
             * @param node the node to be evaluated
             * @private
             */
            function isOptionalParam(node) {
                return 'optional' in node && node.optional === true;
            }
            /**
             * checks if node is plain parameter
             * @param node the node to be evaluated
             * @private
             */
            function isPlainParam(node) {
                return !(node.type === utils_1.AST_NODE_TYPES.AssignmentPattern ||
                    node.type === utils_1.AST_NODE_TYPES.RestElement ||
                    isOptionalParam(node));
            }
            function checkDefaultParamLast(node) {
                let hasSeenPlainParam = false;
                for (let i = node.params.length - 1; i >= 0; i--) {
                    const current = node.params[i];
                    const param = current.type === utils_1.AST_NODE_TYPES.TSParameterProperty
                        ? current.parameter
                        : current;
                    if (isPlainParam(param)) {
                        hasSeenPlainParam = true;
                        continue;
                    }
                    if (hasSeenPlainParam &&
                        (isOptionalParam(param) ||
                            param.type === utils_1.AST_NODE_TYPES.AssignmentPattern)) {
                        context.report({ node: current, messageId: 'shouldBeLast' });
                    }
                }
            }
            return {
                ArrowFunctionExpression: checkDefaultParamLast,
                FunctionDeclaration: checkDefaultParamLast,
                FunctionExpression: checkDefaultParamLast,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/dot-notation.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util_1 = require(1018) /* ../util */;
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('dot-notation');
    exports.default = (0, util_1.createRule)({
        name: 'dot-notation',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce dot notation whenever possible',
                recommended: 'strict',
                extendsBaseRule: true,
                requiresTypeChecking: true,
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowKeywords: {
                            type: 'boolean',
                            default: true,
                        },
                        allowPattern: {
                            type: 'string',
                            default: '',
                        },
                        allowPrivateClassPropertyAccess: {
                            type: 'boolean',
                            default: false,
                        },
                        allowProtectedClassPropertyAccess: {
                            type: 'boolean',
                            default: false,
                        },
                        allowIndexSignaturePropertyAccess: {
                            type: 'boolean',
                            default: false,
                        },
                    },
                    additionalProperties: false,
                },
            ],
            fixable: baseRule.meta.fixable,
            hasSuggestions: baseRule.meta.hasSuggestions,
            messages: baseRule.meta.messages,
        },
        defaultOptions: [
            {
                allowPrivateClassPropertyAccess: false,
                allowProtectedClassPropertyAccess: false,
                allowIndexSignaturePropertyAccess: false,
                allowKeywords: true,
                allowPattern: '',
            },
        ],
        create(context, [options]) {
            var _a;
            const rules = baseRule.create(context);
            const { program, esTreeNodeToTSNodeMap } = (0, util_1.getParserServices)(context);
            const typeChecker = program.getTypeChecker();
            const allowPrivateClassPropertyAccess = options.allowPrivateClassPropertyAccess;
            const allowProtectedClassPropertyAccess = options.allowProtectedClassPropertyAccess;
            const allowIndexSignaturePropertyAccess = ((_a = options.allowIndexSignaturePropertyAccess) !== null && _a !== void 0 ? _a : false) ||
                tsutils.isCompilerOptionEnabled(program.getCompilerOptions(), 
                // @ts-expect-error - TS is refining the type to never for some reason
                'noPropertyAccessFromIndexSignature');
            return {
                MemberExpression(node) {
                    var _a, _b;
                    if ((allowPrivateClassPropertyAccess ||
                        allowProtectedClassPropertyAccess ||
                        allowIndexSignaturePropertyAccess) &&
                        node.computed) {
                        // for perf reasons - only fetch symbols if we have to
                        const propertySymbol = typeChecker.getSymbolAtLocation(esTreeNodeToTSNodeMap.get(node.property));
                        const modifierKind = (_b = (0, util_1.getModifiers)((_a = propertySymbol === null || propertySymbol === void 0 ? void 0 : propertySymbol.getDeclarations()) === null || _a === void 0 ? void 0 : _a[0])) === null || _b === void 0 ? void 0 : _b[0].kind;
                        if ((allowPrivateClassPropertyAccess &&
                            modifierKind === ts.SyntaxKind.PrivateKeyword) ||
                            (allowProtectedClassPropertyAccess &&
                                modifierKind === ts.SyntaxKind.ProtectedKeyword)) {
                            return;
                        }
                        if (propertySymbol === undefined &&
                            allowIndexSignaturePropertyAccess) {
                            const objectType = typeChecker.getTypeAtLocation(esTreeNodeToTSNodeMap.get(node.object));
                            const indexType = objectType
                                .getNonNullableType()
                                .getStringIndexType();
                            if (indexType !== undefined) {
                                return;
                            }
                        }
                    }
                    rules.MemberExpression(node);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/explicit-function-return-type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const explicitReturnTypeUtils_1 = require(1171) /* ../util/explicitReturnTypeUtils */;
    exports.default = util.createRule({
        name: 'explicit-function-return-type',
        meta: {
            type: 'problem',
            docs: {
                description: 'Require explicit return types on functions and class methods',
                recommended: false,
            },
            messages: {
                missingReturnType: 'Missing return type on function.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowConciseArrowFunctionExpressionsStartingWithVoid: {
                            description: 'Whether to allow arrow functions that start with the `void` keyword.',
                            type: 'boolean',
                        },
                        allowExpressions: {
                            description: 'Whether to ignore function expressions (functions which are not part of a declaration).',
                            type: 'boolean',
                        },
                        allowHigherOrderFunctions: {
                            description: 'Whether to ignore functions immediately returning another function expression.',
                            type: 'boolean',
                        },
                        allowTypedFunctionExpressions: {
                            description: 'Whether to ignore type annotations on the variable of function expressions.',
                            type: 'boolean',
                        },
                        allowDirectConstAssertionInArrowFunctions: {
                            description: 'Whether to ignore arrow functions immediately returning a `as const` value.',
                            type: 'boolean',
                        },
                        allowFunctionsWithoutTypeParameters: {
                            description: "Whether to ignore functions that don't have generic type parameters.",
                            type: 'boolean',
                        },
                        allowedNames: {
                            description: 'An array of function/method names that will not have their arguments or return values checked.',
                            items: {
                                type: 'string',
                            },
                            type: 'array',
                        },
                        allowIIFEs: {
                            description: 'Whether to ignore immediately invoked function expressions (IIFEs).',
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                allowExpressions: false,
                allowTypedFunctionExpressions: true,
                allowHigherOrderFunctions: true,
                allowDirectConstAssertionInArrowFunctions: true,
                allowConciseArrowFunctionExpressionsStartingWithVoid: false,
                allowFunctionsWithoutTypeParameters: false,
                allowedNames: [],
                allowIIFEs: false,
            },
        ],
        create(context, [options]) {
            const sourceCode = context.getSourceCode();
            function isAllowedFunction(node) {
                var _a, _b;
                if (options.allowFunctionsWithoutTypeParameters && !node.typeParameters) {
                    return true;
                }
                if (options.allowIIFEs && isIIFE(node)) {
                    return true;
                }
                if (!((_a = options.allowedNames) === null || _a === void 0 ? void 0 : _a.length)) {
                    return false;
                }
                if (node.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression ||
                    node.type === utils_1.AST_NODE_TYPES.FunctionExpression) {
                    const parent = node.parent;
                    let funcName;
                    if ((_b = node.id) === null || _b === void 0 ? void 0 : _b.name) {
                        funcName = node.id.name;
                    }
                    else if (parent) {
                        switch (parent.type) {
                            case utils_1.AST_NODE_TYPES.VariableDeclarator: {
                                if (parent.id.type === utils_1.AST_NODE_TYPES.Identifier) {
                                    funcName = parent.id.name;
                                }
                                break;
                            }
                            case utils_1.AST_NODE_TYPES.MethodDefinition:
                            case utils_1.AST_NODE_TYPES.PropertyDefinition:
                            case utils_1.AST_NODE_TYPES.Property: {
                                if (parent.key.type === utils_1.AST_NODE_TYPES.Identifier &&
                                    parent.computed === false) {
                                    funcName = parent.key.name;
                                }
                                break;
                            }
                        }
                    }
                    if (!!funcName && !!options.allowedNames.includes(funcName)) {
                        return true;
                    }
                }
                if (node.type === utils_1.AST_NODE_TYPES.FunctionDeclaration &&
                    node.id &&
                    node.id.type === utils_1.AST_NODE_TYPES.Identifier &&
                    !!options.allowedNames.includes(node.id.name)) {
                    return true;
                }
                return false;
            }
            function isIIFE(node) {
                return node.parent.type === utils_1.AST_NODE_TYPES.CallExpression;
            }
            return {
                'ArrowFunctionExpression, FunctionExpression'(node) {
                    if (options.allowConciseArrowFunctionExpressionsStartingWithVoid &&
                        node.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression &&
                        node.expression &&
                        node.body.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                        node.body.operator === 'void') {
                        return;
                    }
                    if (isAllowedFunction(node)) {
                        return;
                    }
                    if (options.allowTypedFunctionExpressions &&
                        ((0, explicitReturnTypeUtils_1.isValidFunctionExpressionReturnType)(node, options) ||
                            (0, explicitReturnTypeUtils_1.ancestorHasReturnType)(node))) {
                        return;
                    }
                    (0, explicitReturnTypeUtils_1.checkFunctionReturnType)(node, options, sourceCode, loc => context.report({
                        node,
                        loc,
                        messageId: 'missingReturnType',
                    }));
                },
                FunctionDeclaration(node) {
                    if (isAllowedFunction(node)) {
                        return;
                    }
                    if (options.allowTypedFunctionExpressions && node.returnType) {
                        return;
                    }
                    (0, explicitReturnTypeUtils_1.checkFunctionReturnType)(node, options, sourceCode, loc => context.report({
                        node,
                        loc,
                        messageId: 'missingReturnType',
                    }));
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/util/explicitReturnTypeUtils.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ancestorHasReturnType = exports.isValidFunctionExpressionReturnType = exports.isTypedFunctionExpression = exports.doesImmediatelyReturnFunctionExpression = exports.checkFunctionReturnType = exports.checkFunctionExpressionReturnType = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const astUtils_1 = require(1019) /* ./astUtils */;
    const getFunctionHeadLoc_1 = require(1023) /* ./getFunctionHeadLoc */;
    /**
     * Checks if a node is a variable declarator with a type annotation.
     * ```
     * const x: Foo = ...
     * ```
     */
    function isVariableDeclaratorWithTypeAnnotation(node) {
        return (node.type === utils_1.AST_NODE_TYPES.VariableDeclarator && !!node.id.typeAnnotation);
    }
    /**
     * Checks if a node is a class property with a type annotation.
     * ```
     * public x: Foo = ...
     * ```
     */
    function isPropertyDefinitionWithTypeAnnotation(node) {
        return (node.type === utils_1.AST_NODE_TYPES.PropertyDefinition && !!node.typeAnnotation);
    }
    /**
     * Checks if a node belongs to:
     * ```
     * new Foo(() => {})
     *         ^^^^^^^^
     * ```
     */
    function isConstructorArgument(node) {
        return node.type === utils_1.AST_NODE_TYPES.NewExpression;
    }
    /**
     * Checks if a node is a property or a nested property of a typed object:
     * ```
     * const x: Foo = { prop: () => {} }
     * const x = { prop: () => {} } as Foo
     * const x = <Foo>{ prop: () => {} }
     * const x: Foo = { bar: { prop: () => {} } }
     * ```
     */
    function isPropertyOfObjectWithType(property) {
        if (!property || property.type !== utils_1.AST_NODE_TYPES.Property) {
            return false;
        }
        const objectExpr = property.parent; // this shouldn't happen, checking just in case
        /* istanbul ignore if */ if (!objectExpr ||
            objectExpr.type !== utils_1.AST_NODE_TYPES.ObjectExpression) {
            return false;
        }
        const parent = objectExpr.parent; // this shouldn't happen, checking just in case
        /* istanbul ignore if */ if (!parent) {
            return false;
        }
        return ((0, astUtils_1.isTypeAssertion)(parent) ||
            isPropertyDefinitionWithTypeAnnotation(parent) ||
            isVariableDeclaratorWithTypeAnnotation(parent) ||
            isFunctionArgument(parent) ||
            isPropertyOfObjectWithType(parent));
    }
    /**
     * Checks if a function belongs to:
     * ```
     * () => () => ...
     * () => function () { ... }
     * () => { return () => ... }
     * () => { return function () { ... } }
     * function fn() { return () => ... }
     * function fn() { return function() { ... } }
     * ```
     */
    function doesImmediatelyReturnFunctionExpression({ body, }) {
        // Should always have a body; really checking just in case
        /* istanbul ignore if */ if (!body) {
            return false;
        }
        // Check if body is a block with a single statement
        if (body.type === utils_1.AST_NODE_TYPES.BlockStatement && body.body.length === 1) {
            const [statement] = body.body;
            // Check if that statement is a return statement with an argument
            if (statement.type === utils_1.AST_NODE_TYPES.ReturnStatement &&
                !!statement.argument) {
                // If so, check that returned argument as body
                body = statement.argument;
            }
        }
        // Check if the body being returned is a function expression
        return (body.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression ||
            body.type === utils_1.AST_NODE_TYPES.FunctionExpression);
    }
    exports.doesImmediatelyReturnFunctionExpression = doesImmediatelyReturnFunctionExpression;
    /**
     * Checks if a node belongs to:
     * ```
     * foo(() => 1)
     * ```
     */
    function isFunctionArgument(parent, callee) {
        return (parent.type === utils_1.AST_NODE_TYPES.CallExpression &&
            // make sure this isn't an IIFE
            parent.callee !== callee);
    }
    /**
     * Checks if a function belongs to:
     * ```
     * () => ({ action: 'xxx' } as const)
     * ```
     */
    function returnsConstAssertionDirectly(node) {
        const { body } = node;
        if ((0, astUtils_1.isTypeAssertion)(body)) {
            const { typeAnnotation } = body;
            if (typeAnnotation.type === utils_1.AST_NODE_TYPES.TSTypeReference) {
                const { typeName } = typeAnnotation;
                if (typeName.type === utils_1.AST_NODE_TYPES.Identifier &&
                    typeName.name === 'const') {
                    return true;
                }
            }
        }
        return false;
    }
    /**
     * True when the provided function expression is typed.
     */
    function isTypedFunctionExpression(node, options) {
        const parent = utils_1.ESLintUtils.nullThrows(node.parent, utils_1.ESLintUtils.NullThrowsReasons.MissingParent);
        if (!options.allowTypedFunctionExpressions) {
            return false;
        }
        return ((0, astUtils_1.isTypeAssertion)(parent) ||
            isVariableDeclaratorWithTypeAnnotation(parent) ||
            isPropertyDefinitionWithTypeAnnotation(parent) ||
            isPropertyOfObjectWithType(parent) ||
            isFunctionArgument(parent, node) ||
            isConstructorArgument(parent));
    }
    exports.isTypedFunctionExpression = isTypedFunctionExpression;
    /**
     * Check whether the function expression return type is either typed or valid
     * with the provided options.
     */
    function isValidFunctionExpressionReturnType(node, options) {
        if (isTypedFunctionExpression(node, options)) {
            return true;
        }
        const parent = utils_1.ESLintUtils.nullThrows(node.parent, utils_1.ESLintUtils.NullThrowsReasons.MissingParent);
        if (options.allowExpressions &&
            parent.type !== utils_1.AST_NODE_TYPES.VariableDeclarator &&
            parent.type !== utils_1.AST_NODE_TYPES.MethodDefinition &&
            parent.type !== utils_1.AST_NODE_TYPES.ExportDefaultDeclaration &&
            parent.type !== utils_1.AST_NODE_TYPES.PropertyDefinition) {
            return true;
        }
        // https://github.com/typescript-eslint/typescript-eslint/issues/653
        return (options.allowDirectConstAssertionInArrowFunctions === true &&
            node.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression &&
            returnsConstAssertionDirectly(node));
    }
    exports.isValidFunctionExpressionReturnType = isValidFunctionExpressionReturnType;
    /**
     * Check that the function expression or declaration is valid.
     */
    function isValidFunctionReturnType(node, options) {
        if (options.allowHigherOrderFunctions &&
            doesImmediatelyReturnFunctionExpression(node)) {
            return true;
        }
        return (node.returnType != null ||
            (0, astUtils_1.isConstructor)(node.parent) ||
            (0, astUtils_1.isSetter)(node.parent));
    }
    /**
     * Checks if a function declaration/expression has a return type.
     */
    function checkFunctionReturnType(node, options, sourceCode, report) {
        if (isValidFunctionReturnType(node, options)) {
            return;
        }
        report((0, getFunctionHeadLoc_1.getFunctionHeadLoc)(node, sourceCode));
    }
    exports.checkFunctionReturnType = checkFunctionReturnType;
    /**
     * Checks if a function declaration/expression has a return type.
     */
    function checkFunctionExpressionReturnType(node, options, sourceCode, report) {
        if (isValidFunctionExpressionReturnType(node, options)) {
            return;
        }
        checkFunctionReturnType(node, options, sourceCode, report);
    }
    exports.checkFunctionExpressionReturnType = checkFunctionExpressionReturnType;
    /**
     * Check whether any ancestor of the provided function has a valid return type.
     */
    function ancestorHasReturnType(node) {
        let ancestor = node.parent;
        if ((ancestor === null || ancestor === void 0 ? void 0 : ancestor.type) === utils_1.AST_NODE_TYPES.Property) {
            ancestor = ancestor.value;
        }
        // if the ancestor is not a return, then this function was not returned at all, so we can exit early
        const isReturnStatement = (ancestor === null || ancestor === void 0 ? void 0 : ancestor.type) === utils_1.AST_NODE_TYPES.ReturnStatement;
        const isBodylessArrow = (ancestor === null || ancestor === void 0 ? void 0 : ancestor.type) === utils_1.AST_NODE_TYPES.ArrowFunctionExpression &&
            ancestor.body.type !== utils_1.AST_NODE_TYPES.BlockStatement;
        if (!isReturnStatement && !isBodylessArrow) {
            return false;
        }
        while (ancestor) {
            switch (ancestor.type) {
                case utils_1.AST_NODE_TYPES.ArrowFunctionExpression:
                case utils_1.AST_NODE_TYPES.FunctionExpression:
                case utils_1.AST_NODE_TYPES.FunctionDeclaration:
                    if (ancestor.returnType) {
                        return true;
                    }
                    break;
                // const x: Foo = () => {};
                // Assume that a typed variable types the function expression
                case utils_1.AST_NODE_TYPES.VariableDeclarator:
                    if (ancestor.id.typeAnnotation) {
                        return true;
                    }
                    break;
            }
            ancestor = ancestor.parent;
        }
        return false;
    }
    exports.ancestorHasReturnType = ancestorHasReturnType;
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/explicit-member-accessibility.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const accessibilityLevel = {
        oneOf: [
            {
                const: 'explicit',
                description: 'Always require an accessor.',
            },
            {
                const: 'no-public',
                description: 'Require an accessor except when public.',
            },
            {
                const: 'off',
                description: 'Never check whether there is an accessor.',
            },
        ],
    };
    exports.default = util.createRule({
        name: 'explicit-member-accessibility',
        meta: {
            hasSuggestions: true,
            type: 'problem',
            docs: {
                description: 'Require explicit accessibility modifiers on class properties and methods',
                // too opinionated to be recommended
                recommended: false,
            },
            fixable: 'code',
            messages: {
                missingAccessibility: 'Missing accessibility modifier on {{type}} {{name}}.',
                unwantedPublicAccessibility: 'Public accessibility modifier on {{type}} {{name}}.',
                addExplicitAccessibility: "Add '{{ type }}' accessibility modifier",
            },
            schema: {
                $defs: {
                    accessibilityLevel,
                },
                prefixItems: [
                    {
                        type: 'object',
                        properties: {
                            accessibility: { $ref: '#/$defs/accessibilityLevel' },
                            overrides: {
                                type: 'object',
                                properties: {
                                    accessors: { $ref: '#/$defs/accessibilityLevel' },
                                    constructors: { $ref: '#/$defs/accessibilityLevel' },
                                    methods: { $ref: '#/$defs/accessibilityLevel' },
                                    properties: { $ref: '#/$defs/accessibilityLevel' },
                                    parameterProperties: {
                                        $ref: '#/$defs/accessibilityLevel',
                                    },
                                },
                                additionalProperties: false,
                            },
                            ignoredMethodNames: {
                                type: 'array',
                                items: {
                                    type: 'string',
                                },
                            },
                        },
                        additionalProperties: false,
                    },
                ],
                type: 'array',
            },
        },
        defaultOptions: [{ accessibility: 'explicit' }],
        create(context, [option]) {
            var _a, _b, _c, _d, _e, _f, _g, _h;
            const sourceCode = context.getSourceCode();
            const baseCheck = (_a = option.accessibility) !== null && _a !== void 0 ? _a : 'explicit';
            const overrides = (_b = option.overrides) !== null && _b !== void 0 ? _b : {};
            const ctorCheck = (_c = overrides.constructors) !== null && _c !== void 0 ? _c : baseCheck;
            const accessorCheck = (_d = overrides.accessors) !== null && _d !== void 0 ? _d : baseCheck;
            const methodCheck = (_e = overrides.methods) !== null && _e !== void 0 ? _e : baseCheck;
            const propCheck = (_f = overrides.properties) !== null && _f !== void 0 ? _f : baseCheck;
            const paramPropCheck = (_g = overrides.parameterProperties) !== null && _g !== void 0 ? _g : baseCheck;
            const ignoredMethodNames = new Set((_h = option.ignoredMethodNames) !== null && _h !== void 0 ? _h : []);
            /**
             * Checks if a method declaration has an accessibility modifier.
             * @param methodDefinition The node representing a MethodDefinition.
             */
            function checkMethodAccessibilityModifier(methodDefinition) {
                if (methodDefinition.key.type === utils_1.AST_NODE_TYPES.PrivateIdentifier) {
                    return;
                }
                let nodeType = 'method definition';
                let check = baseCheck;
                switch (methodDefinition.kind) {
                    case 'method':
                        check = methodCheck;
                        break;
                    case 'constructor':
                        check = ctorCheck;
                        break;
                    case 'get':
                    case 'set':
                        check = accessorCheck;
                        nodeType = `${methodDefinition.kind} property accessor`;
                        break;
                }
                const { name: methodName } = util.getNameFromMember(methodDefinition, sourceCode);
                if (check === 'off' || ignoredMethodNames.has(methodName)) {
                    return;
                }
                if (check === 'no-public' &&
                    methodDefinition.accessibility === 'public') {
                    context.report({
                        node: methodDefinition,
                        messageId: 'unwantedPublicAccessibility',
                        data: {
                            type: nodeType,
                            name: methodName,
                        },
                        fix: getUnwantedPublicAccessibilityFixer(methodDefinition),
                    });
                }
                else if (check === 'explicit' && !methodDefinition.accessibility) {
                    context.report({
                        node: methodDefinition,
                        messageId: 'missingAccessibility',
                        data: {
                            type: nodeType,
                            name: methodName,
                        },
                        suggest: getMissingAccessibilitySuggestions(methodDefinition),
                    });
                }
            }
            /**
             * Creates a fixer that removes a "public" keyword with following spaces
             */
            function getUnwantedPublicAccessibilityFixer(node) {
                return function (fixer) {
                    const tokens = sourceCode.getTokens(node);
                    let rangeToRemove;
                    for (let i = 0; i < tokens.length; i++) {
                        const token = tokens[i];
                        if (token.type === utils_1.AST_TOKEN_TYPES.Keyword &&
                            token.value === 'public') {
                            const commensAfterPublicKeyword = sourceCode.getCommentsAfter(token);
                            if (commensAfterPublicKeyword.length) {
                                // public /* Hi there! */ static foo()
                                // ^^^^^^^
                                rangeToRemove = [
                                    token.range[0],
                                    commensAfterPublicKeyword[0].range[0],
                                ];
                                break;
                            }
                            else {
                                // public static foo()
                                // ^^^^^^^
                                rangeToRemove = [token.range[0], tokens[i + 1].range[0]];
                                break;
                            }
                        }
                    }
                    return fixer.removeRange(rangeToRemove);
                };
            }
            /**
             * Creates a fixer that adds a "public" keyword with following spaces
             */
            function getMissingAccessibilitySuggestions(node) {
                function fix(accessibility, fixer) {
                    var _a;
                    if ((_a = node === null || node === void 0 ? void 0 : node.decorators) === null || _a === void 0 ? void 0 : _a.length) {
                        const lastDecorator = node.decorators[node.decorators.length - 1];
                        const nextToken = sourceCode.getTokenAfter(lastDecorator);
                        return fixer.insertTextBefore(nextToken, `${accessibility} `);
                    }
                    return fixer.insertTextBefore(node, `${accessibility} `);
                }
                return [
                    {
                        messageId: 'addExplicitAccessibility',
                        data: { type: 'public' },
                        fix: fixer => fix('public', fixer),
                    },
                    {
                        messageId: 'addExplicitAccessibility',
                        data: { type: 'private' },
                        fix: fixer => fix('private', fixer),
                    },
                    {
                        messageId: 'addExplicitAccessibility',
                        data: { type: 'protected' },
                        fix: fixer => fix('protected', fixer),
                    },
                ];
            }
            /**
             * Checks if property has an accessibility modifier.
             * @param propertyDefinition The node representing a PropertyDefinition.
             */
            function checkPropertyAccessibilityModifier(propertyDefinition) {
                if (propertyDefinition.key.type === utils_1.AST_NODE_TYPES.PrivateIdentifier) {
                    return;
                }
                const nodeType = 'class property';
                const { name: propertyName } = util.getNameFromMember(propertyDefinition, sourceCode);
                if (propCheck === 'no-public' &&
                    propertyDefinition.accessibility === 'public') {
                    context.report({
                        node: propertyDefinition,
                        messageId: 'unwantedPublicAccessibility',
                        data: {
                            type: nodeType,
                            name: propertyName,
                        },
                        fix: getUnwantedPublicAccessibilityFixer(propertyDefinition),
                    });
                }
                else if (propCheck === 'explicit' &&
                    !propertyDefinition.accessibility) {
                    context.report({
                        node: propertyDefinition,
                        messageId: 'missingAccessibility',
                        data: {
                            type: nodeType,
                            name: propertyName,
                        },
                        suggest: getMissingAccessibilitySuggestions(propertyDefinition),
                    });
                }
            }
            /**
             * Checks that the parameter property has the desired accessibility modifiers set.
             * @param node The node representing a Parameter Property
             */
            function checkParameterPropertyAccessibilityModifier(node) {
                const nodeType = 'parameter property';
                // HAS to be an identifier or assignment or TSC will throw
                if (node.parameter.type !== utils_1.AST_NODE_TYPES.Identifier &&
                    node.parameter.type !== utils_1.AST_NODE_TYPES.AssignmentPattern) {
                    return;
                }
                const nodeName = node.parameter.type === utils_1.AST_NODE_TYPES.Identifier
                    ? node.parameter.name
                    : // has to be an Identifier or TSC will throw an error
                        node.parameter.left.name;
                switch (paramPropCheck) {
                    case 'explicit': {
                        if (!node.accessibility) {
                            context.report({
                                node,
                                messageId: 'missingAccessibility',
                                data: {
                                    type: nodeType,
                                    name: nodeName,
                                },
                                suggest: getMissingAccessibilitySuggestions(node),
                            });
                        }
                        break;
                    }
                    case 'no-public': {
                        if (node.accessibility === 'public' && node.readonly) {
                            context.report({
                                node,
                                messageId: 'unwantedPublicAccessibility',
                                data: {
                                    type: nodeType,
                                    name: nodeName,
                                },
                                fix: getUnwantedPublicAccessibilityFixer(node),
                            });
                        }
                        break;
                    }
                }
            }
            return {
                'MethodDefinition, TSAbstractMethodDefinition': checkMethodAccessibilityModifier,
                'PropertyDefinition, TSAbstractPropertyDefinition': checkPropertyAccessibilityModifier,
                TSParameterProperty: checkParameterPropertyAccessibilityModifier,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/explicit-module-boundary-types.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const scope_manager_1 = require(861) /* @typescript-eslint/scope-manager */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const explicitReturnTypeUtils_1 = require(1171) /* ../util/explicitReturnTypeUtils */;
    exports.default = util.createRule({
        name: 'explicit-module-boundary-types',
        meta: {
            type: 'problem',
            docs: {
                description: "Require explicit return and argument types on exported functions' and classes' public class methods",
                recommended: false,
            },
            messages: {
                missingReturnType: 'Missing return type on function.',
                missingArgType: "Argument '{{name}}' should be typed.",
                missingArgTypeUnnamed: '{{type}} argument should be typed.',
                anyTypedArg: "Argument '{{name}}' should be typed with a non-any type.",
                anyTypedArgUnnamed: '{{type}} argument should be typed with a non-any type.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowArgumentsExplicitlyTypedAsAny: {
                            description: 'Whether to ignore arguments that are explicitly typed as `any`.',
                            type: 'boolean',
                        },
                        allowDirectConstAssertionInArrowFunctions: {
                            description: [
                                'Whether to ignore return type annotations on body-less arrow functions that return an `as const` type assertion.',
                                'You must still type the parameters of the function.',
                            ].join('\n'),
                            type: 'boolean',
                        },
                        allowedNames: {
                            description: 'An array of function/method names that will not have their arguments or return values checked.',
                            items: {
                                type: 'string',
                            },
                            type: 'array',
                        },
                        allowHigherOrderFunctions: {
                            description: [
                                'Whether to ignore return type annotations on functions immediately returning another function expression.',
                                'You must still type the parameters of the function.',
                            ].join('\n'),
                            type: 'boolean',
                        },
                        allowTypedFunctionExpressions: {
                            description: 'Whether to ignore type annotations on the variable of a function expresion.',
                            type: 'boolean',
                        },
                        // DEPRECATED - To be removed in next major
                        shouldTrackReferences: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                allowArgumentsExplicitlyTypedAsAny: false,
                allowDirectConstAssertionInArrowFunctions: true,
                allowedNames: [],
                allowHigherOrderFunctions: true,
                allowTypedFunctionExpressions: true,
            },
        ],
        create(context, [options]) {
            const sourceCode = context.getSourceCode();
            // tracks all of the functions we've already checked
            const checkedFunctions = new Set();
            // tracks functions that were found whilst traversing
            const foundFunctions = [];
            // all nodes visited, avoids infinite recursion for cyclic references
            // (such as class member referring to itself)
            const alreadyVisited = new Set();
            /*
            # How the rule works:
        
            As the rule traverses the AST, it immediately checks every single function that it finds is exported.
            "exported" means that it is either directly exported, or that its name is exported.
        
            It also collects a list of every single function it finds on the way, but does not check them.
            After it's finished traversing the AST, it then iterates through the list of found functions, and checks to see if
            any of them are part of a higher-order function
            */
            return {
                ExportDefaultDeclaration(node) {
                    checkNode(node.declaration);
                },
                'ExportNamedDeclaration:not([source])'(node) {
                    if (node.declaration) {
                        checkNode(node.declaration);
                    }
                    else {
                        for (const specifier of node.specifiers) {
                            followReference(specifier.local);
                        }
                    }
                },
                TSExportAssignment(node) {
                    checkNode(node.expression);
                },
                'ArrowFunctionExpression, FunctionDeclaration, FunctionExpression'(node) {
                    foundFunctions.push(node);
                },
                'Program:exit'() {
                    for (const func of foundFunctions) {
                        if (isExportedHigherOrderFunction(func)) {
                            checkNode(func);
                        }
                    }
                },
            };
            function checkParameters(node) {
                function checkParameter(param) {
                    function report(namedMessageId, unnamedMessageId) {
                        if (param.type === utils_1.AST_NODE_TYPES.Identifier) {
                            context.report({
                                node: param,
                                messageId: namedMessageId,
                                data: { name: param.name },
                            });
                        }
                        else if (param.type === utils_1.AST_NODE_TYPES.ArrayPattern) {
                            context.report({
                                node: param,
                                messageId: unnamedMessageId,
                                data: { type: 'Array pattern' },
                            });
                        }
                        else if (param.type === utils_1.AST_NODE_TYPES.ObjectPattern) {
                            context.report({
                                node: param,
                                messageId: unnamedMessageId,
                                data: { type: 'Object pattern' },
                            });
                        }
                        else if (param.type === utils_1.AST_NODE_TYPES.RestElement) {
                            if (param.argument.type === utils_1.AST_NODE_TYPES.Identifier) {
                                context.report({
                                    node: param,
                                    messageId: namedMessageId,
                                    data: { name: param.argument.name },
                                });
                            }
                            else {
                                context.report({
                                    node: param,
                                    messageId: unnamedMessageId,
                                    data: { type: 'Rest' },
                                });
                            }
                        }
                    }
                    switch (param.type) {
                        case utils_1.AST_NODE_TYPES.ArrayPattern:
                        case utils_1.AST_NODE_TYPES.Identifier:
                        case utils_1.AST_NODE_TYPES.ObjectPattern:
                        case utils_1.AST_NODE_TYPES.RestElement:
                            if (!param.typeAnnotation) {
                                report('missingArgType', 'missingArgTypeUnnamed');
                            }
                            else if (options.allowArgumentsExplicitlyTypedAsAny !== true &&
                                param.typeAnnotation.typeAnnotation.type ===
                                    utils_1.AST_NODE_TYPES.TSAnyKeyword) {
                                report('anyTypedArg', 'anyTypedArgUnnamed');
                            }
                            return;
                        case utils_1.AST_NODE_TYPES.TSParameterProperty:
                            return checkParameter(param.parameter);
                        case utils_1.AST_NODE_TYPES.AssignmentPattern: // ignored as it has a type via its assignment
                            return;
                    }
                }
                for (const arg of node.params) {
                    checkParameter(arg);
                }
            }
            /**
             * Checks if a function name is allowed and should not be checked.
             */
            function isAllowedName(node) {
                var _a;
                if (!node || !options.allowedNames || !options.allowedNames.length) {
                    return false;
                }
                if (node.type === utils_1.AST_NODE_TYPES.VariableDeclarator ||
                    node.type === utils_1.AST_NODE_TYPES.FunctionDeclaration) {
                    return (((_a = node.id) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.Identifier &&
                        options.allowedNames.includes(node.id.name));
                }
                else if (node.type === utils_1.AST_NODE_TYPES.MethodDefinition ||
                    node.type === utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition ||
                    (node.type === utils_1.AST_NODE_TYPES.Property && node.method) ||
                    node.type === utils_1.AST_NODE_TYPES.PropertyDefinition) {
                    if (node.key.type === utils_1.AST_NODE_TYPES.Literal &&
                        typeof node.key.value === 'string') {
                        return options.allowedNames.includes(node.key.value);
                    }
                    if (node.key.type === utils_1.AST_NODE_TYPES.TemplateLiteral &&
                        node.key.expressions.length === 0) {
                        return options.allowedNames.includes(node.key.quasis[0].value.raw);
                    }
                    if (!node.computed && node.key.type === utils_1.AST_NODE_TYPES.Identifier) {
                        return options.allowedNames.includes(node.key.name);
                    }
                }
                return false;
            }
            function isExportedHigherOrderFunction(node) {
                var _a;
                let current = node.parent;
                while (current) {
                    if (current.type === utils_1.AST_NODE_TYPES.ReturnStatement) {
                        // the parent of a return will always be a block statement, so we can skip over it
                        current = (_a = current.parent) === null || _a === void 0 ? void 0 : _a.parent;
                        continue;
                    }
                    if (!util.isFunction(current) ||
                        !(0, explicitReturnTypeUtils_1.doesImmediatelyReturnFunctionExpression)(current)) {
                        return false;
                    }
                    if (checkedFunctions.has(current)) {
                        return true;
                    }
                    current = current.parent;
                }
                return false;
            }
            function followReference(node) {
                const scope = context.getScope();
                const variable = scope.set.get(node.name);
                /* istanbul ignore if */ if (!variable) {
                    return;
                }
                // check all of the definitions
                for (const definition of variable.defs) {
                    // cases we don't care about in this rule
                    if ([
                        scope_manager_1.DefinitionType.ImplicitGlobalVariable,
                        scope_manager_1.DefinitionType.ImportBinding,
                        scope_manager_1.DefinitionType.CatchClause,
                        scope_manager_1.DefinitionType.Parameter,
                    ].includes(definition.type)) {
                        continue;
                    }
                    checkNode(definition.node);
                }
                // follow references to find writes to the variable
                for (const reference of variable.references) {
                    if (
                    // we don't want to check the initialization ref, as this is handled by the declaration check
                    !reference.init &&
                        reference.writeExpr) {
                        checkNode(reference.writeExpr);
                    }
                }
            }
            function checkNode(node) {
                if (node == null || alreadyVisited.has(node)) {
                    return;
                }
                alreadyVisited.add(node);
                switch (node.type) {
                    case utils_1.AST_NODE_TYPES.ArrowFunctionExpression:
                    case utils_1.AST_NODE_TYPES.FunctionExpression:
                        return checkFunctionExpression(node);
                    case utils_1.AST_NODE_TYPES.ArrayExpression:
                        for (const element of node.elements) {
                            checkNode(element);
                        }
                        return;
                    case utils_1.AST_NODE_TYPES.PropertyDefinition:
                        if (node.accessibility === 'private' ||
                            node.key.type === utils_1.AST_NODE_TYPES.PrivateIdentifier) {
                            return;
                        }
                        return checkNode(node.value);
                    case utils_1.AST_NODE_TYPES.ClassDeclaration:
                    case utils_1.AST_NODE_TYPES.ClassExpression:
                        for (const element of node.body.body) {
                            checkNode(element);
                        }
                        return;
                    case utils_1.AST_NODE_TYPES.FunctionDeclaration:
                        return checkFunction(node);
                    case utils_1.AST_NODE_TYPES.MethodDefinition:
                    case utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition:
                        if (node.accessibility === 'private' ||
                            node.key.type === utils_1.AST_NODE_TYPES.PrivateIdentifier) {
                            return;
                        }
                        return checkNode(node.value);
                    case utils_1.AST_NODE_TYPES.Identifier:
                        return followReference(node);
                    case utils_1.AST_NODE_TYPES.ObjectExpression:
                        for (const property of node.properties) {
                            checkNode(property);
                        }
                        return;
                    case utils_1.AST_NODE_TYPES.Property:
                        return checkNode(node.value);
                    case utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression:
                        return checkEmptyBodyFunctionExpression(node);
                    case utils_1.AST_NODE_TYPES.VariableDeclaration:
                        for (const declaration of node.declarations) {
                            checkNode(declaration);
                        }
                        return;
                    case utils_1.AST_NODE_TYPES.VariableDeclarator:
                        return checkNode(node.init);
                }
            }
            function checkEmptyBodyFunctionExpression(node) {
                var _a, _b, _c;
                const isConstructor = ((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.MethodDefinition &&
                    node.parent.kind === 'constructor';
                const isSetAccessor = (((_b = node.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition ||
                    ((_c = node.parent) === null || _c === void 0 ? void 0 : _c.type) === utils_1.AST_NODE_TYPES.MethodDefinition) &&
                    node.parent.kind === 'set';
                if (!isConstructor && !isSetAccessor && !node.returnType) {
                    context.report({
                        node,
                        messageId: 'missingReturnType',
                    });
                }
                checkParameters(node);
            }
            function checkFunctionExpression(node) {
                if (checkedFunctions.has(node)) {
                    return;
                }
                checkedFunctions.add(node);
                if (isAllowedName(node.parent) ||
                    (0, explicitReturnTypeUtils_1.isTypedFunctionExpression)(node, options) ||
                    (0, explicitReturnTypeUtils_1.ancestorHasReturnType)(node)) {
                    return;
                }
                (0, explicitReturnTypeUtils_1.checkFunctionExpressionReturnType)(node, options, sourceCode, loc => {
                    context.report({
                        node,
                        loc,
                        messageId: 'missingReturnType',
                    });
                });
                checkParameters(node);
            }
            function checkFunction(node) {
                if (checkedFunctions.has(node)) {
                    return;
                }
                checkedFunctions.add(node);
                if (isAllowedName(node) || (0, explicitReturnTypeUtils_1.ancestorHasReturnType)(node)) {
                    return;
                }
                (0, explicitReturnTypeUtils_1.checkFunctionReturnType)(node, options, sourceCode, loc => {
                    context.report({
                        node,
                        loc,
                        messageId: 'missingReturnType',
                    });
                });
                checkParameters(node);
            }
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/func-call-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'func-call-spacing',
        meta: {
            type: 'layout',
            docs: {
                description: 'Require or disallow spacing between function identifiers and their invocations',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'whitespace',
            schema: {
                anyOf: [
                    {
                        type: 'array',
                        items: [
                            {
                                enum: ['never'],
                            },
                        ],
                        minItems: 0,
                        maxItems: 1,
                    },
                    {
                        type: 'array',
                        items: [
                            {
                                enum: ['always'],
                            },
                            {
                                type: 'object',
                                properties: {
                                    allowNewlines: {
                                        type: 'boolean',
                                    },
                                },
                                additionalProperties: false,
                            },
                        ],
                        minItems: 0,
                        maxItems: 2,
                    },
                ],
            },
            messages: {
                unexpectedWhitespace: 'Unexpected whitespace between function name and paren.',
                unexpectedNewline: 'Unexpected newline between function name and paren.',
                missing: 'Missing space between function name and paren.',
            },
        },
        defaultOptions: ['never', {}],
        create(context, [option, config]) {
            const sourceCode = context.getSourceCode();
            const text = sourceCode.getText();
            /**
             * Check if open space is present in a function name
             * @param {ASTNode} node node to evaluate
             * @returns {void}
             * @private
             */
            function checkSpacing(node) {
                var _a;
                const isOptionalCall = util.isOptionalCallExpression(node);
                const closingParenToken = sourceCode.getLastToken(node);
                const lastCalleeTokenWithoutPossibleParens = sourceCode.getLastToken((_a = node.typeParameters) !== null && _a !== void 0 ? _a : node.callee);
                const openingParenToken = sourceCode.getFirstTokenBetween(lastCalleeTokenWithoutPossibleParens, closingParenToken, util.isOpeningParenToken);
                if (!openingParenToken || openingParenToken.range[1] >= node.range[1]) {
                    // new expression with no parens...
                    return;
                }
                const lastCalleeToken = sourceCode.getTokenBefore(openingParenToken, util.isNotOptionalChainPunctuator);
                const textBetweenTokens = text
                    .slice(lastCalleeToken.range[1], openingParenToken.range[0])
                    .replace(/\/\*.*?\*\//gu, '');
                const hasWhitespace = /\s/u.test(textBetweenTokens);
                const hasNewline = hasWhitespace && util.LINEBREAK_MATCHER.test(textBetweenTokens);
                if (option === 'never') {
                    if (hasWhitespace) {
                        return context.report({
                            node,
                            loc: lastCalleeToken.loc.start,
                            messageId: 'unexpectedWhitespace',
                            fix(fixer) {
                                /*
                                 * Only autofix if there is no newline
                                 * https://github.com/eslint/eslint/issues/7787
                                 */
                                if (!hasNewline &&
                                    // don't fix optional calls
                                    !isOptionalCall) {
                                    return fixer.removeRange([
                                        lastCalleeToken.range[1],
                                        openingParenToken.range[0],
                                    ]);
                                }
                                return null;
                            },
                        });
                    }
                }
                else if (isOptionalCall) {
                    // disallow:
                    // foo?. ();
                    // foo ?.();
                    // foo ?. ();
                    if (hasWhitespace || hasNewline) {
                        context.report({
                            node,
                            loc: lastCalleeToken.loc.start,
                            messageId: 'unexpectedWhitespace',
                        });
                    }
                }
                else {
                    if (!hasWhitespace) {
                        context.report({
                            node,
                            loc: lastCalleeToken.loc.start,
                            messageId: 'missing',
                            fix(fixer) {
                                return fixer.insertTextBefore(openingParenToken, ' ');
                            },
                        });
                    }
                    else if (!config.allowNewlines && hasNewline) {
                        context.report({
                            node,
                            loc: lastCalleeToken.loc.start,
                            messageId: 'unexpectedNewline',
                            fix(fixer) {
                                return fixer.replaceTextRange([lastCalleeToken.range[1], openingParenToken.range[0]], ' ');
                            },
                        });
                    }
                }
            }
            return {
                CallExpression: checkSpacing,
                NewExpression: checkSpacing,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/indent.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /**
     * Note this file is rather type-unsafe in its current state.
     * This is due to some really funky type conversions between different node types.
     * This is done intentionally based on the internal implementation of the base indent rule.
     */
    /* eslint-disable @typescript-eslint/no-explicit-any, @typescript-eslint/no-unsafe-assignment  */
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('indent');
    const KNOWN_NODES = new Set([
        // Class properties aren't yet supported by eslint...
        utils_1.AST_NODE_TYPES.PropertyDefinition,
        // ts keywords
        utils_1.AST_NODE_TYPES.TSAbstractKeyword,
        utils_1.AST_NODE_TYPES.TSAnyKeyword,
        utils_1.AST_NODE_TYPES.TSBooleanKeyword,
        utils_1.AST_NODE_TYPES.TSNeverKeyword,
        utils_1.AST_NODE_TYPES.TSNumberKeyword,
        utils_1.AST_NODE_TYPES.TSStringKeyword,
        utils_1.AST_NODE_TYPES.TSSymbolKeyword,
        utils_1.AST_NODE_TYPES.TSUndefinedKeyword,
        utils_1.AST_NODE_TYPES.TSUnknownKeyword,
        utils_1.AST_NODE_TYPES.TSVoidKeyword,
        utils_1.AST_NODE_TYPES.TSNullKeyword,
        // ts specific nodes we want to support
        utils_1.AST_NODE_TYPES.TSAbstractPropertyDefinition,
        utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition,
        utils_1.AST_NODE_TYPES.TSArrayType,
        utils_1.AST_NODE_TYPES.TSAsExpression,
        utils_1.AST_NODE_TYPES.TSCallSignatureDeclaration,
        utils_1.AST_NODE_TYPES.TSConditionalType,
        utils_1.AST_NODE_TYPES.TSConstructorType,
        utils_1.AST_NODE_TYPES.TSConstructSignatureDeclaration,
        utils_1.AST_NODE_TYPES.TSDeclareFunction,
        utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression,
        utils_1.AST_NODE_TYPES.TSEnumDeclaration,
        utils_1.AST_NODE_TYPES.TSEnumMember,
        utils_1.AST_NODE_TYPES.TSExportAssignment,
        utils_1.AST_NODE_TYPES.TSExternalModuleReference,
        utils_1.AST_NODE_TYPES.TSFunctionType,
        utils_1.AST_NODE_TYPES.TSImportType,
        utils_1.AST_NODE_TYPES.TSIndexedAccessType,
        utils_1.AST_NODE_TYPES.TSIndexSignature,
        utils_1.AST_NODE_TYPES.TSInferType,
        utils_1.AST_NODE_TYPES.TSInterfaceBody,
        utils_1.AST_NODE_TYPES.TSInterfaceDeclaration,
        utils_1.AST_NODE_TYPES.TSInterfaceHeritage,
        utils_1.AST_NODE_TYPES.TSIntersectionType,
        utils_1.AST_NODE_TYPES.TSImportEqualsDeclaration,
        utils_1.AST_NODE_TYPES.TSLiteralType,
        utils_1.AST_NODE_TYPES.TSMappedType,
        utils_1.AST_NODE_TYPES.TSMethodSignature,
        'TSMinusToken',
        utils_1.AST_NODE_TYPES.TSModuleBlock,
        utils_1.AST_NODE_TYPES.TSModuleDeclaration,
        utils_1.AST_NODE_TYPES.TSNonNullExpression,
        utils_1.AST_NODE_TYPES.TSParameterProperty,
        'TSPlusToken',
        utils_1.AST_NODE_TYPES.TSPropertySignature,
        utils_1.AST_NODE_TYPES.TSQualifiedName,
        'TSQuestionToken',
        utils_1.AST_NODE_TYPES.TSRestType,
        utils_1.AST_NODE_TYPES.TSThisType,
        utils_1.AST_NODE_TYPES.TSTupleType,
        utils_1.AST_NODE_TYPES.TSTypeAnnotation,
        utils_1.AST_NODE_TYPES.TSTypeLiteral,
        utils_1.AST_NODE_TYPES.TSTypeOperator,
        utils_1.AST_NODE_TYPES.TSTypeParameter,
        utils_1.AST_NODE_TYPES.TSTypeParameterDeclaration,
        utils_1.AST_NODE_TYPES.TSTypeParameterInstantiation,
        utils_1.AST_NODE_TYPES.TSTypeReference,
        utils_1.AST_NODE_TYPES.TSUnionType,
        utils_1.AST_NODE_TYPES.Decorator,
    ]);
    exports.default = util.createRule({
        name: 'indent',
        meta: {
            type: 'layout',
            docs: {
                description: 'Enforce consistent indentation',
                // too opinionated to be recommended
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'whitespace',
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            messages: baseRule.meta.messages,
        },
        defaultOptions: [
            // typescript docs and playground use 4 space indent
            4,
            {
                // typescript docs indent the case from the switch
                // https://www.typescriptlang.org/docs/handbook/release-notes/typescript-1-8.html#example-4
                SwitchCase: 1,
                flatTernaryExpressions: false,
                ignoredNodes: [],
            },
        ],
        create(context, optionsWithDefaults) {
            // because we extend the base rule, have to update opts on the context
            // the context defines options as readonly though...
            const contextWithDefaults = Object.create(context, {
                options: {
                    writable: false,
                    configurable: false,
                    value: optionsWithDefaults,
                },
            });
            const rules = baseRule.create(contextWithDefaults);
            /**
             * Converts from a TSPropertySignature to a Property
             * @param node a TSPropertySignature node
             * @param [type] the type to give the new node
             * @returns a Property node
             */
            function TSPropertySignatureToProperty(node, type = utils_1.AST_NODE_TYPES.Property) {
                const base = {
                    // indent doesn't actually use these
                    key: null,
                    value: null,
                    // Property flags
                    computed: false,
                    method: false,
                    kind: 'init',
                    // this will stop eslint from interrogating the type literal
                    shorthand: true,
                    // location data
                    parent: node.parent,
                    range: node.range,
                    loc: node.loc,
                };
                if (type === utils_1.AST_NODE_TYPES.Property) {
                    return Object.assign({ type }, base);
                }
                else {
                    return Object.assign({ type, static: false, readonly: false, declare: false }, base);
                }
            }
            return Object.assign({}, rules, {
                // overwrite the base rule here so we can use our KNOWN_NODES list instead
                '*:exit'(node) {
                    // For nodes we care about, skip the default handling, because it just marks the node as ignored...
                    if (!KNOWN_NODES.has(node.type)) {
                        rules['*:exit'](node);
                    }
                },
                VariableDeclaration(node) {
                    // https://github.com/typescript-eslint/typescript-eslint/issues/441
                    if (node.declarations.length === 0) {
                        return;
                    }
                    return rules.VariableDeclaration(node);
                },
                TSAsExpression(node) {
                    // transform it to a BinaryExpression
                    return rules['BinaryExpression, LogicalExpression']({
                        type: utils_1.AST_NODE_TYPES.BinaryExpression,
                        operator: 'as',
                        left: node.expression,
                        // the first typeAnnotation includes the as token
                        right: node.typeAnnotation,
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
                TSConditionalType(node) {
                    // transform it to a ConditionalExpression
                    return rules.ConditionalExpression({
                        type: utils_1.AST_NODE_TYPES.ConditionalExpression,
                        test: {
                            type: utils_1.AST_NODE_TYPES.BinaryExpression,
                            operator: 'extends',
                            left: node.checkType,
                            right: node.extendsType,
                            // location data
                            range: [node.checkType.range[0], node.extendsType.range[1]],
                            loc: {
                                start: node.checkType.loc.start,
                                end: node.extendsType.loc.end,
                            },
                        },
                        consequent: node.trueType,
                        alternate: node.falseType,
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
                'TSEnumDeclaration, TSTypeLiteral'(node) {
                    // transform it to an ObjectExpression
                    return rules['ObjectExpression, ObjectPattern']({
                        type: utils_1.AST_NODE_TYPES.ObjectExpression,
                        properties: node.members.map(member => TSPropertySignatureToProperty(member)),
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
                TSImportEqualsDeclaration(node) {
                    // transform it to an VariableDeclaration
                    // use VariableDeclaration instead of ImportDeclaration because it's essentially the same thing
                    const { id, moduleReference } = node;
                    return rules.VariableDeclaration({
                        type: utils_1.AST_NODE_TYPES.VariableDeclaration,
                        kind: 'const',
                        declarations: [
                            {
                                type: utils_1.AST_NODE_TYPES.VariableDeclarator,
                                range: [id.range[0], moduleReference.range[1]],
                                loc: {
                                    start: id.loc.start,
                                    end: moduleReference.loc.end,
                                },
                                id: id,
                                init: {
                                    type: utils_1.AST_NODE_TYPES.CallExpression,
                                    callee: {
                                        type: utils_1.AST_NODE_TYPES.Identifier,
                                        name: 'require',
                                        range: [
                                            moduleReference.range[0],
                                            moduleReference.range[0] + 'require'.length,
                                        ],
                                        loc: {
                                            start: moduleReference.loc.start,
                                            end: {
                                                line: moduleReference.loc.end.line,
                                                column: moduleReference.loc.start.line + 'require'.length,
                                            },
                                        },
                                    },
                                    arguments: 'expression' in moduleReference
                                        ? [moduleReference.expression]
                                        : [],
                                    // location data
                                    range: moduleReference.range,
                                    loc: moduleReference.loc,
                                },
                            },
                        ],
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
                TSIndexedAccessType(node) {
                    // convert to a MemberExpression
                    return rules['MemberExpression, JSXMemberExpression, MetaProperty']({
                        type: utils_1.AST_NODE_TYPES.MemberExpression,
                        object: node.objectType,
                        property: node.indexType,
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                        optional: false,
                        computed: true,
                    });
                },
                TSInterfaceBody(node) {
                    // transform it to an ClassBody
                    return rules['BlockStatement, ClassBody']({
                        type: utils_1.AST_NODE_TYPES.ClassBody,
                        body: node.body.map(p => TSPropertySignatureToProperty(p, utils_1.AST_NODE_TYPES.PropertyDefinition)),
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
                'TSInterfaceDeclaration[extends.length > 0]'(node) {
                    // transform it to a ClassDeclaration
                    return rules['ClassDeclaration[superClass], ClassExpression[superClass]']({
                        type: utils_1.AST_NODE_TYPES.ClassDeclaration,
                        body: node.body,
                        id: null,
                        // TODO: This is invalid, there can be more than one extends in interface
                        superClass: node.extends[0].expression,
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
                TSMappedType(node) {
                    const sourceCode = context.getSourceCode();
                    const squareBracketStart = sourceCode.getTokenBefore(node.typeParameter);
                    // transform it to an ObjectExpression
                    return rules['ObjectExpression, ObjectPattern']({
                        type: utils_1.AST_NODE_TYPES.ObjectExpression,
                        properties: [
                            {
                                type: utils_1.AST_NODE_TYPES.Property,
                                key: node.typeParameter,
                                value: node.typeAnnotation,
                                // location data
                                range: [
                                    squareBracketStart.range[0],
                                    node.typeAnnotation
                                        ? node.typeAnnotation.range[1]
                                        : squareBracketStart.range[0],
                                ],
                                loc: {
                                    start: squareBracketStart.loc.start,
                                    end: node.typeAnnotation
                                        ? node.typeAnnotation.loc.end
                                        : squareBracketStart.loc.end,
                                },
                                kind: 'init',
                                computed: false,
                                method: false,
                                shorthand: false,
                            },
                        ],
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
                TSModuleBlock(node) {
                    // transform it to a BlockStatement
                    return rules['BlockStatement, ClassBody']({
                        type: utils_1.AST_NODE_TYPES.BlockStatement,
                        body: node.body,
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
                TSQualifiedName(node) {
                    return rules['MemberExpression, JSXMemberExpression, MetaProperty']({
                        type: utils_1.AST_NODE_TYPES.MemberExpression,
                        object: node.left,
                        property: node.right,
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                        optional: false,
                        computed: false,
                    });
                },
                TSTupleType(node) {
                    // transform it to an ArrayExpression
                    return rules['ArrayExpression, ArrayPattern']({
                        type: utils_1.AST_NODE_TYPES.ArrayExpression,
                        elements: node.elementTypes,
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
                TSTypeParameterDeclaration(node) {
                    if (!node.params.length) {
                        return;
                    }
                    const [name, ...attributes] = node.params;
                    // JSX is about the closest we can get because the angle brackets
                    // it's not perfect but it works!
                    return rules.JSXOpeningElement({
                        type: utils_1.AST_NODE_TYPES.JSXOpeningElement,
                        selfClosing: false,
                        name: name,
                        attributes: attributes,
                        // location data
                        parent: node.parent,
                        range: node.range,
                        loc: node.loc,
                    });
                },
            });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/init-declarations.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util_1 = require(1018) /* ../util */;
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('init-declarations');
    exports.default = (0, util_1.createRule)({
        name: 'init-declarations',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require or disallow initialization in variable declarations',
                recommended: false,
                extendsBaseRule: true,
            },
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            messages: baseRule.meta.messages,
        },
        defaultOptions: ['always'],
        create(context, [mode]) {
            const rules = baseRule.create(context);
            return {
                'VariableDeclaration:exit'(node) {
                    if (mode === 'always') {
                        if (node.declare) {
                            return;
                        }
                        if (isAncestorNamespaceDeclared(node)) {
                            return;
                        }
                    }
                    rules['VariableDeclaration:exit'](node);
                },
            };
            function isAncestorNamespaceDeclared(node) {
                let ancestor = node.parent;
                while (ancestor) {
                    if (ancestor.type === utils_1.AST_NODE_TYPES.TSModuleDeclaration &&
                        ancestor.declare) {
                        return true;
                    }
                    ancestor = ancestor.parent;
                }
                return false;
            }
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/key-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('key-spacing');
    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    const baseSchema = Array.isArray(baseRule.meta.schema)
        ? baseRule.meta.schema[0]
        : baseRule.meta.schema;
    /**
     * TODO: replace with native .at() once Node 14 stops being supported
     */
    function at(arr, position) {
        if (position < 0) {
            return arr[arr.length + position];
        }
        return arr[position];
    }
    exports.default = util.createRule({
        name: 'key-spacing',
        meta: {
            type: 'layout',
            docs: {
                description: 'Enforce consistent spacing between property names and type annotations in types and interfaces',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'whitespace',
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: [baseSchema],
            messages: baseRule.meta.messages,
        },
        defaultOptions: [{}],
        create(context, [options]) {
            const sourceCode = context.getSourceCode();
            const baseRules = baseRule.create(context);
            /**
             * @returns the column of the position after converting all unicode characters in the line to 1 char length
             */
            function adjustedColumn(position) {
                const line = position.line - 1; // position.line is 1-indexed
                return util.getStringLength(at(sourceCode.lines, line).slice(0, position.column));
            }
            /**
             * Starting from the given a node (a property.key node here) looks forward
             * until it finds the last token before a colon punctuator and returns it.
             */
            function getLastTokenBeforeColon(node) {
                const colonToken = sourceCode.getTokenAfter(node, util.isColonToken);
                return sourceCode.getTokenBefore(colonToken);
            }
            function isKeyTypeNode(node) {
                return ((node.type === utils_1.AST_NODE_TYPES.TSPropertySignature ||
                    node.type === utils_1.AST_NODE_TYPES.TSIndexSignature ||
                    node.type === utils_1.AST_NODE_TYPES.PropertyDefinition) &&
                    !!node.typeAnnotation);
            }
            function isApplicable(node) {
                return (isKeyTypeNode(node) &&
                    node.typeAnnotation.loc.start.line === node.loc.end.line);
            }
            /**
             * To handle index signatures, to get the whole text for the parameters
             */
            function getKeyText(node) {
                if (node.type !== utils_1.AST_NODE_TYPES.TSIndexSignature) {
                    return sourceCode.getText(node.key);
                }
                const code = sourceCode.getText(node);
                return code.slice(0, sourceCode.getTokenAfter(at(node.parameters, -1), util.isClosingBracketToken).range[1] - node.range[0]);
            }
            /**
             * To handle index signatures, be able to get the end position of the parameters
             */
            function getKeyLocEnd(node) {
                return getLastTokenBeforeColon(node.type !== utils_1.AST_NODE_TYPES.TSIndexSignature
                    ? node.key
                    : at(node.parameters, -1)).loc.end;
            }
            function checkBeforeColon(node, expectedWhitespaceBeforeColon, mode) {
                const { typeAnnotation } = node;
                const colon = typeAnnotation.loc.start.column;
                const keyEnd = getKeyLocEnd(node);
                const difference = colon - keyEnd.column - expectedWhitespaceBeforeColon;
                if (mode === 'strict' ? difference : difference < 0) {
                    context.report({
                        node,
                        messageId: difference > 0 ? 'extraKey' : 'missingKey',
                        fix: fixer => {
                            if (difference > 0) {
                                return fixer.removeRange([
                                    typeAnnotation.range[0] - difference,
                                    typeAnnotation.range[0],
                                ]);
                            }
                            else {
                                return fixer.insertTextBefore(typeAnnotation, ' '.repeat(-difference));
                            }
                        },
                        data: {
                            computed: '',
                            key: getKeyText(node),
                        },
                    });
                }
            }
            function checkAfterColon(node, expectedWhitespaceAfterColon, mode) {
                const { typeAnnotation } = node;
                const colon = typeAnnotation.loc.start.column;
                const typeStart = typeAnnotation.typeAnnotation.loc.start.column;
                const difference = typeStart - colon - 1 - expectedWhitespaceAfterColon;
                if (mode === 'strict' ? difference : difference < 0) {
                    context.report({
                        node,
                        messageId: difference > 0 ? 'extraValue' : 'missingValue',
                        fix: fixer => {
                            if (difference > 0) {
                                return fixer.removeRange([
                                    typeAnnotation.typeAnnotation.range[0] - difference,
                                    typeAnnotation.typeAnnotation.range[0],
                                ]);
                            }
                            else {
                                return fixer.insertTextBefore(typeAnnotation.typeAnnotation, ' '.repeat(-difference));
                            }
                        },
                        data: {
                            computed: '',
                            key: getKeyText(node),
                        },
                    });
                }
            }
            // adapted from  https://github.com/eslint/eslint/blob/ba74253e8bd63e9e163bbee0540031be77e39253/lib/rules/key-spacing.js#L356
            function continuesAlignGroup(lastMember, candidate) {
                const groupEndLine = lastMember.loc.start.line;
                const candidateValueStartLine = (isKeyTypeNode(candidate) ? candidate.typeAnnotation : candidate).loc.start.line;
                if (candidateValueStartLine === groupEndLine) {
                    return false;
                }
                if (candidateValueStartLine - groupEndLine === 1) {
                    return true;
                }
                /*
                 * Check that the first comment is adjacent to the end of the group, the
                 * last comment is adjacent to the candidate property, and that successive
                 * comments are adjacent to each other.
                 */
                const leadingComments = sourceCode.getCommentsBefore(candidate);
                if (leadingComments.length &&
                    leadingComments[0].loc.start.line - groupEndLine <= 1 &&
                    candidateValueStartLine - at(leadingComments, -1).loc.end.line <= 1) {
                    for (let i = 1; i < leadingComments.length; i++) {
                        if (leadingComments[i].loc.start.line -
                            leadingComments[i - 1].loc.end.line >
                            1) {
                            return false;
                        }
                    }
                    return true;
                }
                return false;
            }
            function checkAlignGroup(group) {
                var _a, _b, _c, _d, _e, _f, _g, _h;
                let alignColumn = 0;
                const align = (_d = (typeof options.align === 'object'
                    ? options.align.on
                    : typeof ((_a = options.multiLine) === null || _a === void 0 ? void 0 : _a.align) === 'object'
                        ? options.multiLine.align.on
                        : (_c = (_b = options.multiLine) === null || _b === void 0 ? void 0 : _b.align) !== null && _c !== void 0 ? _c : options.align)) !== null && _d !== void 0 ? _d : 'colon';
                const beforeColon = (_e = (typeof options.align === 'object'
                    ? options.align.beforeColon
                    : options.multiLine
                        ? typeof options.multiLine.align === 'object'
                            ? options.multiLine.align.beforeColon
                            : options.multiLine.beforeColon
                        : options.beforeColon)) !== null && _e !== void 0 ? _e : false;
                const expectedWhitespaceBeforeColon = beforeColon ? 1 : 0;
                const afterColon = (_f = (typeof options.align === 'object'
                    ? options.align.afterColon
                    : options.multiLine
                        ? typeof options.multiLine.align === 'object'
                            ? options.multiLine.align.afterColon
                            : options.multiLine.afterColon
                        : options.afterColon)) !== null && _f !== void 0 ? _f : true;
                const expectedWhitespaceAfterColon = afterColon ? 1 : 0;
                const mode = (_h = (typeof options.align === 'object'
                    ? options.align.mode
                    : options.multiLine
                        ? typeof options.multiLine.align === 'object'
                            ? // same behavior as in original rule
                                (_g = options.multiLine.align.mode) !== null && _g !== void 0 ? _g : options.multiLine.mode
                            : options.multiLine.mode
                        : options.mode)) !== null && _h !== void 0 ? _h : 'strict';
                for (const node of group) {
                    if (isKeyTypeNode(node)) {
                        const keyEnd = adjustedColumn(getKeyLocEnd(node));
                        alignColumn = Math.max(alignColumn, align === 'colon'
                            ? keyEnd + expectedWhitespaceBeforeColon
                            : keyEnd +
                                ':'.length +
                                expectedWhitespaceAfterColon +
                                expectedWhitespaceBeforeColon);
                    }
                }
                for (const node of group) {
                    if (!isApplicable(node)) {
                        continue;
                    }
                    const { typeAnnotation } = node;
                    const toCheck = align === 'colon' ? typeAnnotation : typeAnnotation.typeAnnotation;
                    const difference = adjustedColumn(toCheck.loc.start) - alignColumn;
                    if (difference) {
                        context.report({
                            node,
                            messageId: difference > 0
                                ? align === 'colon'
                                    ? 'extraKey'
                                    : 'extraValue'
                                : align === 'colon'
                                    ? 'missingKey'
                                    : 'missingValue',
                            fix: fixer => {
                                if (difference > 0) {
                                    return fixer.removeRange([
                                        toCheck.range[0] - difference,
                                        toCheck.range[0],
                                    ]);
                                }
                                else {
                                    return fixer.insertTextBefore(toCheck, ' '.repeat(-difference));
                                }
                            },
                            data: {
                                computed: '',
                                key: getKeyText(node),
                            },
                        });
                    }
                    if (align === 'colon') {
                        checkAfterColon(node, expectedWhitespaceAfterColon, mode);
                    }
                    else {
                        checkBeforeColon(node, expectedWhitespaceBeforeColon, mode);
                    }
                }
            }
            function checkIndividualNode(node, { singleLine }) {
                var _a, _b, _c;
                const beforeColon = (_a = (singleLine
                    ? options.singleLine
                        ? options.singleLine.beforeColon
                        : options.beforeColon
                    : options.multiLine
                        ? options.multiLine.beforeColon
                        : options.beforeColon)) !== null && _a !== void 0 ? _a : false;
                const expectedWhitespaceBeforeColon = beforeColon ? 1 : 0;
                const afterColon = (_b = (singleLine
                    ? options.singleLine
                        ? options.singleLine.afterColon
                        : options.afterColon
                    : options.multiLine
                        ? options.multiLine.afterColon
                        : options.afterColon)) !== null && _b !== void 0 ? _b : true;
                const expectedWhitespaceAfterColon = afterColon ? 1 : 0;
                const mode = (_c = (singleLine
                    ? options.singleLine
                        ? options.singleLine.mode
                        : options.mode
                    : options.multiLine
                        ? options.multiLine.mode
                        : options.mode)) !== null && _c !== void 0 ? _c : 'strict';
                if (isApplicable(node)) {
                    checkBeforeColon(node, expectedWhitespaceBeforeColon, mode);
                    checkAfterColon(node, expectedWhitespaceAfterColon, mode);
                }
            }
            function validateBody(body) {
                var _a;
                const isSingleLine = body.loc.start.line === body.loc.end.line;
                const members = body.type === utils_1.AST_NODE_TYPES.TSTypeLiteral ? body.members : body.body;
                let alignGroups = [];
                let unalignedElements = [];
                if (options.align || ((_a = options.multiLine) === null || _a === void 0 ? void 0 : _a.align)) {
                    let currentAlignGroup = [];
                    alignGroups.push(currentAlignGroup);
                    let prevNode = undefined;
                    for (const node of members) {
                        let prevAlignedNode = at(currentAlignGroup, -1);
                        if (prevAlignedNode !== prevNode) {
                            prevAlignedNode = undefined;
                        }
                        if (prevAlignedNode && continuesAlignGroup(prevAlignedNode, node)) {
                            currentAlignGroup.push(node);
                        }
                        else if ((prevNode === null || prevNode === void 0 ? void 0 : prevNode.loc.start.line) === node.loc.start.line) {
                            if (prevAlignedNode) {
                                // Here, prevNode === prevAlignedNode === currentAlignGroup.at(-1)
                                unalignedElements.push(prevAlignedNode);
                                currentAlignGroup.pop();
                            }
                            unalignedElements.push(node);
                        }
                        else {
                            currentAlignGroup = [node];
                            alignGroups.push(currentAlignGroup);
                        }
                        prevNode = node;
                    }
                    unalignedElements = unalignedElements.concat(...alignGroups.filter(group => group.length === 1));
                    alignGroups = alignGroups.filter(group => group.length >= 2);
                }
                else {
                    unalignedElements = members;
                }
                for (const group of alignGroups) {
                    checkAlignGroup(group);
                }
                for (const node of unalignedElements) {
                    checkIndividualNode(node, { singleLine: isSingleLine });
                }
            }
            return Object.assign(Object.assign({}, baseRules), { TSTypeLiteral: validateBody, TSInterfaceBody: validateBody, ClassBody: validateBody });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/keyword-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('keyword-spacing');
    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    const baseSchema = Array.isArray(baseRule.meta.schema)
        ? baseRule.meta.schema[0]
        : baseRule.meta.schema;
    const schema = util.deepMerge(
    // eslint-disable-next-line @typescript-eslint/no-unsafe-argument -- https://github.com/microsoft/TypeScript/issues/17002
    baseSchema, {
        properties: {
            overrides: {
                properties: {
                    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment, @typescript-eslint/no-unsafe-member-access
                    type: baseSchema.properties.overrides.properties.import,
                },
            },
        },
    });
    exports.default = util.createRule({
        name: 'keyword-spacing',
        meta: {
            type: 'layout',
            docs: {
                description: 'Enforce consistent spacing before and after keywords',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'whitespace',
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: [schema],
            messages: baseRule.meta.messages,
        },
        defaultOptions: [{}],
        create(context, [{ after, overrides }]) {
            const sourceCode = context.getSourceCode();
            const baseRules = baseRule.create(context);
            return Object.assign(Object.assign({}, baseRules), { TSAsExpression(node) {
                    const asToken = util.nullThrows(sourceCode.getTokenAfter(node.expression, token => token.value === 'as'), util.NullThrowsReasons.MissingToken('as', node.type));
                    const oldTokenType = asToken.type;
                    // as is a contextual keyword, so it's always reported as an Identifier
                    // the rule looks for keyword tokens, so we temporarily override it
                    // we mutate it at the token level because the rule calls sourceCode.getFirstToken,
                    // so mutating a copy would not change the underlying copy returned by that method
                    asToken.type = utils_1.AST_TOKEN_TYPES.Keyword;
                    // use this selector just because it is just a call to `checkSpacingAroundFirstToken`
                    baseRules.DebuggerStatement(asToken);
                    // make sure to reset the type afterward so we don't permanently mutate the AST
                    asToken.type = oldTokenType;
                },
                'ImportDeclaration[importKind=type]'(node) {
                    var _a, _b, _c, _d;
                    const { type: typeOptionOverride = {} } = overrides !== null && overrides !== void 0 ? overrides : {};
                    const typeToken = sourceCode.getFirstToken(node, { skip: 1 });
                    const punctuatorToken = sourceCode.getTokenAfter(typeToken);
                    if (((_b = (_a = node.specifiers) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.ImportDefaultSpecifier) {
                        return;
                    }
                    const spacesBetweenTypeAndPunctuator = punctuatorToken.range[0] - typeToken.range[1];
                    if (((_c = typeOptionOverride.after) !== null && _c !== void 0 ? _c : after) === true &&
                        spacesBetweenTypeAndPunctuator === 0) {
                        context.report({
                            loc: typeToken.loc,
                            messageId: 'expectedAfter',
                            data: { value: 'type' },
                            fix(fixer) {
                                return fixer.insertTextAfter(typeToken, ' ');
                            },
                        });
                    }
                    if (((_d = typeOptionOverride.after) !== null && _d !== void 0 ? _d : after) === false &&
                        spacesBetweenTypeAndPunctuator > 0) {
                        context.report({
                            loc: typeToken.loc,
                            messageId: 'unexpectedAfter',
                            data: { value: 'type' },
                            fix(fixer) {
                                return fixer.removeRange([
                                    typeToken.range[1],
                                    typeToken.range[1] + spacesBetweenTypeAndPunctuator,
                                ]);
                            },
                        });
                    }
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/lines-around-comment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('lines-around-comment');
    const COMMENTS_IGNORE_PATTERN = /^\s*(?:eslint|jshint\s+|jslint\s+|istanbul\s+|globals?\s+|exported\s+|jscs)/u;
    /**
     * @returns an array with with any line numbers that are empty.
     */
    function getEmptyLineNums(lines) {
        const emptyLines = lines
            .map((line, i) => ({
            code: line.trim(),
            num: i + 1,
        }))
            .filter(line => !line.code)
            .map(line => line.num);
        return emptyLines;
    }
    /**
     * @returns an array with with any line numbers that contain comments.
     */
    function getCommentLineNums(comments) {
        const lines = [];
        comments.forEach(token => {
            const start = token.loc.start.line;
            const end = token.loc.end.line;
            lines.push(start, end);
        });
        return lines;
    }
    exports.default = util.createRule({
        name: 'lines-around-comment',
        meta: {
            type: 'layout',
            docs: {
                description: 'Require empty lines around comments',
                recommended: false,
                extendsBaseRule: true,
            },
            schema: {
                type: 'array',
                items: [
                    {
                        type: 'object',
                        properties: {
                            beforeBlockComment: {
                                type: 'boolean',
                                default: true,
                            },
                            afterBlockComment: {
                                type: 'boolean',
                                default: false,
                            },
                            beforeLineComment: {
                                type: 'boolean',
                                default: false,
                            },
                            afterLineComment: {
                                type: 'boolean',
                                default: false,
                            },
                            allowBlockStart: {
                                type: 'boolean',
                                default: false,
                            },
                            allowBlockEnd: {
                                type: 'boolean',
                                default: false,
                            },
                            allowClassStart: {
                                type: 'boolean',
                            },
                            allowClassEnd: {
                                type: 'boolean',
                            },
                            allowObjectStart: {
                                type: 'boolean',
                            },
                            allowObjectEnd: {
                                type: 'boolean',
                            },
                            allowArrayStart: {
                                type: 'boolean',
                            },
                            allowArrayEnd: {
                                type: 'boolean',
                            },
                            allowInterfaceStart: {
                                type: 'boolean',
                            },
                            allowInterfaceEnd: {
                                type: 'boolean',
                            },
                            allowTypeStart: {
                                type: 'boolean',
                            },
                            allowTypeEnd: {
                                type: 'boolean',
                            },
                            allowEnumStart: {
                                type: 'boolean',
                            },
                            allowEnumEnd: {
                                type: 'boolean',
                            },
                            allowModuleStart: {
                                type: 'boolean',
                            },
                            allowModuleEnd: {
                                type: 'boolean',
                            },
                            ignorePattern: {
                                type: 'string',
                            },
                            applyDefaultIgnorePatterns: {
                                type: 'boolean',
                            },
                        },
                        additionalProperties: false,
                    },
                ],
            },
            fixable: baseRule.meta.fixable,
            hasSuggestions: baseRule.meta.hasSuggestions,
            messages: baseRule.meta.messages,
        },
        defaultOptions: [
            {
                beforeBlockComment: true,
            },
        ],
        create(context, [_options]) {
            var _a;
            const options = _options;
            const defaultIgnoreRegExp = COMMENTS_IGNORE_PATTERN;
            const customIgnoreRegExp = new RegExp((_a = options.ignorePattern) !== null && _a !== void 0 ? _a : '', 'u');
            const sourceCode = context.getSourceCode();
            const comments = sourceCode.getAllComments();
            const lines = sourceCode.lines;
            const commentLines = getCommentLineNums(comments);
            const emptyLines = getEmptyLineNums(lines);
            const commentAndEmptyLines = new Set(commentLines.concat(emptyLines));
            /**
             * @returns whether comments are on lines starting with or ending with code.
             */
            function codeAroundComment(token) {
                let currentToken = token;
                do {
                    currentToken = sourceCode.getTokenBefore(currentToken, {
                        includeComments: true,
                    });
                } while (currentToken && util.isCommentToken(currentToken));
                if (currentToken && util.isTokenOnSameLine(currentToken, token)) {
                    return true;
                }
                currentToken = token;
                do {
                    currentToken = sourceCode.getTokenAfter(currentToken, {
                        includeComments: true,
                    });
                } while (currentToken && util.isCommentToken(currentToken));
                if (currentToken && util.isTokenOnSameLine(token, currentToken)) {
                    return true;
                }
                return false;
            }
            /**
             * @returns whether comments are inside a node type.
             */
            function isParentNodeType(parent, nodeType) {
                return parent.type === nodeType;
            }
            /**
             * @returns the parent node that contains the given token.
             */
            function getParentNodeOfToken(token) {
                const node = sourceCode.getNodeByRangeIndex(token.range[0]);
                return node;
            }
            /**
             * @returns whether comments are at the parent start.
             */
            function isCommentAtParentStart(token, nodeType) {
                const parent = getParentNodeOfToken(token);
                if (parent && isParentNodeType(parent, nodeType)) {
                    const parentStartNodeOrToken = parent;
                    return (token.loc.start.line - parentStartNodeOrToken.loc.start.line === 1);
                }
                return false;
            }
            /**
             * @returns whether comments are at the parent end.
             */
            function isCommentAtParentEnd(token, nodeType) {
                const parent = getParentNodeOfToken(token);
                return (!!parent &&
                    isParentNodeType(parent, nodeType) &&
                    parent.loc.end.line - token.loc.end.line === 1);
            }
            function isCommentAtInterfaceStart(token) {
                return isCommentAtParentStart(token, utils_1.AST_NODE_TYPES.TSInterfaceBody);
            }
            function isCommentAtInterfaceEnd(token) {
                return isCommentAtParentEnd(token, utils_1.AST_NODE_TYPES.TSInterfaceBody);
            }
            function isCommentAtTypeStart(token) {
                return isCommentAtParentStart(token, utils_1.AST_NODE_TYPES.TSTypeLiteral);
            }
            function isCommentAtTypeEnd(token) {
                return isCommentAtParentEnd(token, utils_1.AST_NODE_TYPES.TSTypeLiteral);
            }
            function isCommentAtEnumStart(token) {
                return isCommentAtParentStart(token, utils_1.AST_NODE_TYPES.TSEnumDeclaration);
            }
            function isCommentAtEnumEnd(token) {
                return isCommentAtParentEnd(token, utils_1.AST_NODE_TYPES.TSEnumDeclaration);
            }
            function isCommentAtModuleStart(token) {
                return isCommentAtParentStart(token, utils_1.AST_NODE_TYPES.TSModuleBlock);
            }
            function isCommentAtModuleEnd(token) {
                return isCommentAtParentEnd(token, utils_1.AST_NODE_TYPES.TSModuleBlock);
            }
            function isCommentNearTSConstruct(token) {
                return (isCommentAtInterfaceStart(token) ||
                    isCommentAtInterfaceEnd(token) ||
                    isCommentAtTypeStart(token) ||
                    isCommentAtTypeEnd(token) ||
                    isCommentAtEnumStart(token) ||
                    isCommentAtEnumEnd(token) ||
                    isCommentAtModuleStart(token) ||
                    isCommentAtModuleEnd(token));
            }
            function checkForEmptyLine(token, { before, after }) {
                // the base rule handles comments away from TS constructs blocks correctly, we skip those
                if (!isCommentNearTSConstruct(token)) {
                    return;
                }
                if (options.applyDefaultIgnorePatterns !== false &&
                    defaultIgnoreRegExp.test(token.value)) {
                    return;
                }
                if (options.ignorePattern && customIgnoreRegExp.test(token.value)) {
                    return;
                }
                const prevLineNum = token.loc.start.line - 1;
                const nextLineNum = token.loc.end.line + 1;
                // we ignore all inline comments
                if (codeAroundComment(token)) {
                    return;
                }
                const interfaceStartAllowed = Boolean(options.allowInterfaceStart) &&
                    isCommentAtInterfaceStart(token);
                const interfaceEndAllowed = Boolean(options.allowInterfaceEnd) && isCommentAtInterfaceEnd(token);
                const typeStartAllowed = Boolean(options.allowTypeStart) && isCommentAtTypeStart(token);
                const typeEndAllowed = Boolean(options.allowTypeEnd) && isCommentAtTypeEnd(token);
                const enumStartAllowed = Boolean(options.allowEnumStart) && isCommentAtEnumStart(token);
                const enumEndAllowed = Boolean(options.allowEnumEnd) && isCommentAtEnumEnd(token);
                const moduleStartAllowed = Boolean(options.allowModuleStart) && isCommentAtModuleStart(token);
                const moduleEndAllowed = Boolean(options.allowModuleEnd) && isCommentAtModuleEnd(token);
                const exceptionStartAllowed = interfaceStartAllowed ||
                    typeStartAllowed ||
                    enumStartAllowed ||
                    moduleStartAllowed;
                const exceptionEndAllowed = interfaceEndAllowed ||
                    typeEndAllowed ||
                    enumEndAllowed ||
                    moduleEndAllowed;
                const previousTokenOrComment = sourceCode.getTokenBefore(token, {
                    includeComments: true,
                });
                const nextTokenOrComment = sourceCode.getTokenAfter(token, {
                    includeComments: true,
                });
                // check for newline before
                if (!exceptionStartAllowed &&
                    before &&
                    !commentAndEmptyLines.has(prevLineNum) &&
                    !(util.isCommentToken(previousTokenOrComment) &&
                        util.isTokenOnSameLine(previousTokenOrComment, token))) {
                    const lineStart = token.range[0] - token.loc.start.column;
                    const range = [lineStart, lineStart];
                    context.report({
                        node: token,
                        messageId: 'before',
                        fix(fixer) {
                            return fixer.insertTextBeforeRange(range, '\n');
                        },
                    });
                }
                // check for newline after
                if (!exceptionEndAllowed &&
                    after &&
                    !commentAndEmptyLines.has(nextLineNum) &&
                    !(util.isCommentToken(nextTokenOrComment) &&
                        util.isTokenOnSameLine(token, nextTokenOrComment))) {
                    context.report({
                        node: token,
                        messageId: 'after',
                        fix(fixer) {
                            return fixer.insertTextAfter(token, '\n');
                        },
                    });
                }
            }
            /**
             * A custom report function for the baseRule to ignore false positive errors
             * caused by TS-specific codes
             */
            const customReport = descriptor => {
                if ('node' in descriptor) {
                    if (descriptor.node.type === utils_1.AST_TOKEN_TYPES.Line ||
                        descriptor.node.type === utils_1.AST_TOKEN_TYPES.Block) {
                        if (isCommentNearTSConstruct(descriptor.node)) {
                            return;
                        }
                    }
                }
                return context.report(descriptor);
            };
            const customContext = { report: customReport };
            // we can't directly proxy `context` because its `report` property is non-configurable
            // and non-writable. So we proxy `customContext` and redirect all
            // property access to the original context except for `report`
            const proxiedContext = new Proxy(customContext, {
                get(target, path, receiver) {
                    if (path !== 'report') {
                        return Reflect.get(context, path, receiver);
                    }
                    return Reflect.get(target, path, receiver);
                },
            });
            const rules = baseRule.create(proxiedContext);
            return {
                Program() {
                    rules.Program();
                    comments.forEach(token => {
                        if (token.type === utils_1.AST_TOKEN_TYPES.Line) {
                            if (options.beforeLineComment || options.afterLineComment) {
                                checkForEmptyLine(token, {
                                    after: options.afterLineComment,
                                    before: options.beforeLineComment,
                                });
                            }
                        }
                        else if (token.type === utils_1.AST_TOKEN_TYPES.Block) {
                            if (options.beforeBlockComment || options.afterBlockComment) {
                                checkForEmptyLine(token, {
                                    after: options.afterBlockComment,
                                    before: options.beforeBlockComment,
                                });
                            }
                        }
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/lines-between-class-members.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('lines-between-class-members');
    const schema = util.deepMerge(Object.assign({}, baseRule.meta.schema), {
        1: {
            exceptAfterOverload: {
                type: 'boolean',
                default: true,
            },
        },
    });
    exports.default = util.createRule({
        name: 'lines-between-class-members',
        meta: {
            type: 'layout',
            docs: {
                description: 'Require or disallow an empty line between class members',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'whitespace',
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema,
            messages: baseRule.meta.messages,
        },
        defaultOptions: [
            'always',
            {
                exceptAfterOverload: true,
                exceptAfterSingleLine: false,
            },
        ],
        create(context, [firstOption, secondOption]) {
            const rules = baseRule.create(context);
            const exceptAfterOverload = (secondOption === null || secondOption === void 0 ? void 0 : secondOption.exceptAfterOverload) && firstOption === 'always';
            function isOverload(node) {
                return ((node.type === utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition ||
                    node.type === utils_1.AST_NODE_TYPES.MethodDefinition) &&
                    node.value.type === utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression);
            }
            return {
                ClassBody(node) {
                    const body = exceptAfterOverload
                        ? node.body.filter(node => !isOverload(node))
                        : node.body;
                    rules.ClassBody(Object.assign(Object.assign({}, node), { body }));
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/member-delimiter-style.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const definition = {
        type: 'object',
        properties: {
            multiline: {
                type: 'object',
                properties: {
                    delimiter: { enum: ['none', 'semi', 'comma'] },
                    requireLast: { type: 'boolean' },
                },
                additionalProperties: false,
            },
            singleline: {
                type: 'object',
                properties: {
                    // note can't have "none" for single line delimiter as it's invalid syntax
                    delimiter: { enum: ['semi', 'comma'] },
                    requireLast: { type: 'boolean' },
                },
                additionalProperties: false,
            },
        },
        additionalProperties: false,
    };
    const isLastTokenEndOfLine = (token, line) => {
        const positionInLine = token.loc.start.column;
        return positionInLine === line.length - 1;
    };
    const isCommentsEndOfLine = (token, comments, line) => {
        if (!comments) {
            return false;
        }
        if (comments.loc.end.line > token.loc.end.line) {
            return true;
        }
        const positionInLine = comments.loc.end.column;
        return positionInLine === line.length;
    };
    const makeFixFunction = ({ optsNone, optsSemi, lastToken, commentsAfterLastToken, missingDelimiter, lastTokenLine, isSingleLine, }) => {
        // if removing is the action but last token is not the end of the line
        if (optsNone &&
            !isLastTokenEndOfLine(lastToken, lastTokenLine) &&
            !isCommentsEndOfLine(lastToken, commentsAfterLastToken, lastTokenLine) &&
            !isSingleLine) {
            return null;
        }
        return (fixer) => {
            if (optsNone) {
                // remove the unneeded token
                return fixer.remove(lastToken);
            }
            const token = optsSemi ? ';' : ',';
            if (missingDelimiter) {
                // add the missing delimiter
                return fixer.insertTextAfter(lastToken, token);
            }
            // correct the current delimiter
            return fixer.replaceText(lastToken, token);
        };
    };
    exports.default = util.createRule({
        name: 'member-delimiter-style',
        meta: {
            type: 'layout',
            docs: {
                description: 'Require a specific member delimiter style for interfaces and type literals',
                recommended: false,
            },
            fixable: 'whitespace',
            messages: {
                unexpectedComma: 'Unexpected separator (,).',
                unexpectedSemi: 'Unexpected separator (;).',
                expectedComma: 'Expected a comma.',
                expectedSemi: 'Expected a semicolon.',
            },
            schema: [
                {
                    type: 'object',
                    properties: Object.assign({}, definition.properties, {
                        overrides: {
                            type: 'object',
                            properties: {
                                interface: definition,
                                typeLiteral: definition,
                            },
                            additionalProperties: false,
                        },
                        multilineDetection: {
                            enum: ['brackets', 'last-member'],
                        },
                    }),
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                multiline: {
                    delimiter: 'semi',
                    requireLast: true,
                },
                singleline: {
                    delimiter: 'semi',
                    requireLast: false,
                },
                multilineDetection: 'brackets',
            },
        ],
        create(context, [options]) {
            var _a;
            const sourceCode = context.getSourceCode();
            // use the base options as the defaults for the cases
            const baseOptions = options;
            const overrides = (_a = baseOptions.overrides) !== null && _a !== void 0 ? _a : {};
            const interfaceOptions = util.deepMerge(baseOptions, overrides.interface);
            const typeLiteralOptions = util.deepMerge(baseOptions, overrides.typeLiteral);
            /**
             * Check the last token in the given member.
             * @param member the member to be evaluated.
             * @param opts the options to be validated.
             * @param isLast a flag indicating `member` is the last in the interface or type literal.
             */
            function checkLastToken(member, opts, isLast) {
                /**
                 * Resolves the boolean value for the given setting enum value
                 * @param type the option name
                 */
                function getOption(type) {
                    if (isLast && !opts.requireLast) {
                        // only turn the option on if its expecting no delimiter for the last member
                        return type === 'none';
                    }
                    return opts.delimiter === type;
                }
                let messageId = null;
                let missingDelimiter = false;
                const lastToken = sourceCode.getLastToken(member, {
                    includeComments: false,
                });
                if (!lastToken) {
                    return;
                }
                const commentsAfterLastToken = sourceCode
                    .getCommentsAfter(lastToken)
                    .pop();
                const sourceCodeLines = sourceCode.getLines();
                const lastTokenLine = sourceCodeLines[(lastToken === null || lastToken === void 0 ? void 0 : lastToken.loc.start.line) - 1];
                const optsSemi = getOption('semi');
                const optsComma = getOption('comma');
                const optsNone = getOption('none');
                if (lastToken.value === ';') {
                    if (optsComma) {
                        messageId = 'expectedComma';
                    }
                    else if (optsNone) {
                        missingDelimiter = true;
                        messageId = 'unexpectedSemi';
                    }
                }
                else if (lastToken.value === ',') {
                    if (optsSemi) {
                        messageId = 'expectedSemi';
                    }
                    else if (optsNone) {
                        missingDelimiter = true;
                        messageId = 'unexpectedComma';
                    }
                }
                else {
                    if (optsSemi) {
                        missingDelimiter = true;
                        messageId = 'expectedSemi';
                    }
                    else if (optsComma) {
                        missingDelimiter = true;
                        messageId = 'expectedComma';
                    }
                }
                if (messageId) {
                    context.report({
                        node: lastToken,
                        loc: {
                            start: {
                                line: lastToken.loc.end.line,
                                column: lastToken.loc.end.column,
                            },
                            end: {
                                line: lastToken.loc.end.line,
                                column: lastToken.loc.end.column,
                            },
                        },
                        messageId,
                        fix: makeFixFunction({
                            optsNone,
                            optsSemi,
                            lastToken,
                            commentsAfterLastToken,
                            missingDelimiter,
                            lastTokenLine,
                            isSingleLine: opts.type === 'single-line',
                        }),
                    });
                }
            }
            /**
             * Check the member separator being used matches the delimiter.
             * @param {ASTNode} node the node to be evaluated.
             */
            function checkMemberSeparatorStyle(node) {
                const members = node.type === utils_1.AST_NODE_TYPES.TSInterfaceBody ? node.body : node.members;
                let isSingleLine = node.loc.start.line === node.loc.end.line;
                if (options.multilineDetection === 'last-member' &&
                    !isSingleLine &&
                    members.length > 0) {
                    const lastMember = members[members.length - 1];
                    if (lastMember.loc.end.line === node.loc.end.line) {
                        isSingleLine = true;
                    }
                }
                const typeOpts = node.type === utils_1.AST_NODE_TYPES.TSInterfaceBody
                    ? interfaceOptions
                    : typeLiteralOptions;
                const opts = isSingleLine
                    ? Object.assign(Object.assign({}, typeOpts.singleline), { type: 'single-line' }) : Object.assign(Object.assign({}, typeOpts.multiline), { type: 'multi-line' });
                members.forEach((member, index) => {
                    checkLastToken(member, opts !== null && opts !== void 0 ? opts : {}, index === members.length - 1);
                });
            }
            return {
                TSInterfaceBody: checkMemberSeparatorStyle,
                TSTypeLiteral: checkMemberSeparatorStyle,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/member-ordering.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.defaultOrder = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const natural_compare_lite_1 = __importDefault(require(1183) /* natural-compare-lite */);
    const util = __importStar(require(1018) /* ../util */);
    const neverConfig = {
        type: 'string',
        enum: ['never'],
    };
    const arrayConfig = (memberTypes) => ({
        type: 'array',
        items: {
            oneOf: [
                {
                    enum: memberTypes,
                },
                {
                    type: 'array',
                    items: {
                        enum: memberTypes,
                    },
                },
            ],
        },
    });
    const objectConfig = (memberTypes) => ({
        type: 'object',
        properties: {
            memberTypes: {
                oneOf: [arrayConfig(memberTypes), neverConfig],
            },
            order: {
                type: 'string',
                enum: [
                    'alphabetically',
                    'alphabetically-case-insensitive',
                    'as-written',
                    'natural',
                    'natural-case-insensitive',
                ],
            },
            optionalityOrder: {
                type: 'string',
                enum: ['optional-first', 'required-first'],
            },
        },
        additionalProperties: false,
    });
    exports.defaultOrder = [
        // Index signature
        'signature',
        'call-signature',
        // Fields
        'public-static-field',
        'protected-static-field',
        'private-static-field',
        '#private-static-field',
        'public-decorated-field',
        'protected-decorated-field',
        'private-decorated-field',
        'public-instance-field',
        'protected-instance-field',
        'private-instance-field',
        '#private-instance-field',
        'public-abstract-field',
        'protected-abstract-field',
        'public-field',
        'protected-field',
        'private-field',
        '#private-field',
        'static-field',
        'instance-field',
        'abstract-field',
        'decorated-field',
        'field',
        // Static initialization
        'static-initialization',
        // Constructors
        'public-constructor',
        'protected-constructor',
        'private-constructor',
        'constructor',
        // Getters
        'public-static-get',
        'protected-static-get',
        'private-static-get',
        '#private-static-get',
        'public-decorated-get',
        'protected-decorated-get',
        'private-decorated-get',
        'public-instance-get',
        'protected-instance-get',
        'private-instance-get',
        '#private-instance-get',
        'public-abstract-get',
        'protected-abstract-get',
        'public-get',
        'protected-get',
        'private-get',
        '#private-get',
        'static-get',
        'instance-get',
        'abstract-get',
        'decorated-get',
        'get',
        // Setters
        'public-static-set',
        'protected-static-set',
        'private-static-set',
        '#private-static-set',
        'public-decorated-set',
        'protected-decorated-set',
        'private-decorated-set',
        'public-instance-set',
        'protected-instance-set',
        'private-instance-set',
        '#private-instance-set',
        'public-abstract-set',
        'protected-abstract-set',
        'public-set',
        'protected-set',
        'private-set',
        '#private-set',
        'static-set',
        'instance-set',
        'abstract-set',
        'decorated-set',
        'set',
        // Methods
        'public-static-method',
        'protected-static-method',
        'private-static-method',
        '#private-static-method',
        'public-decorated-method',
        'protected-decorated-method',
        'private-decorated-method',
        'public-instance-method',
        'protected-instance-method',
        'private-instance-method',
        '#private-instance-method',
        'public-abstract-method',
        'protected-abstract-method',
        'public-method',
        'protected-method',
        'private-method',
        '#private-method',
        'static-method',
        'instance-method',
        'abstract-method',
        'decorated-method',
        'method',
    ];
    const allMemberTypes = Array.from([
        'readonly-signature',
        'signature',
        'readonly-field',
        'field',
        'method',
        'call-signature',
        'constructor',
        'get',
        'set',
        'static-initialization',
    ].reduce((all, type) => {
        all.add(type);
        ['public', 'protected', 'private', '#private'].forEach(accessibility => {
            if (type !== 'readonly-signature' &&
                type !== 'signature' &&
                type !== 'static-initialization' &&
                type !== 'call-signature' &&
                !(type === 'constructor' && accessibility === '#private')) {
                all.add(`${accessibility}-${type}`); // e.g. `public-field`
            }
            // Only class instance fields, methods, get and set can have decorators attached to them
            if (accessibility !== '#private' &&
                (type === 'readonly-field' ||
                    type === 'field' ||
                    type === 'method' ||
                    type === 'get' ||
                    type === 'set')) {
                all.add(`${accessibility}-decorated-${type}`);
                all.add(`decorated-${type}`);
            }
            if (type !== 'constructor' &&
                type !== 'readonly-signature' &&
                type !== 'signature' &&
                type !== 'call-signature') {
                // There is no `static-constructor` or `instance-constructor` or `abstract-constructor`
                if (accessibility === '#private' || accessibility === 'private') {
                    ['static', 'instance'].forEach(scope => {
                        all.add(`${scope}-${type}`);
                        all.add(`${accessibility}-${scope}-${type}`);
                    });
                }
                else {
                    ['static', 'instance', 'abstract'].forEach(scope => {
                        all.add(`${scope}-${type}`);
                        all.add(`${accessibility}-${scope}-${type}`);
                    });
                }
            }
        });
        return all;
    }, new Set()));
    const functionExpressions = [
        utils_1.AST_NODE_TYPES.FunctionExpression,
        utils_1.AST_NODE_TYPES.ArrowFunctionExpression,
    ];
    /**
     * Gets the node type.
     *
     * @param node the node to be evaluated.
     */
    function getNodeType(node) {
        switch (node.type) {
            case utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition:
            case utils_1.AST_NODE_TYPES.MethodDefinition:
                return node.kind;
            case utils_1.AST_NODE_TYPES.TSMethodSignature:
                return 'method';
            case utils_1.AST_NODE_TYPES.TSCallSignatureDeclaration:
                return 'call-signature';
            case utils_1.AST_NODE_TYPES.TSConstructSignatureDeclaration:
                return 'constructor';
            case utils_1.AST_NODE_TYPES.TSAbstractPropertyDefinition:
                return node.readonly ? 'readonly-field' : 'field';
            case utils_1.AST_NODE_TYPES.PropertyDefinition:
                return node.value && functionExpressions.includes(node.value.type)
                    ? 'method'
                    : node.readonly
                        ? 'readonly-field'
                        : 'field';
            case utils_1.AST_NODE_TYPES.TSPropertySignature:
                return node.readonly ? 'readonly-field' : 'field';
            case utils_1.AST_NODE_TYPES.TSIndexSignature:
                return node.readonly ? 'readonly-signature' : 'signature';
            case utils_1.AST_NODE_TYPES.StaticBlock:
                return 'static-initialization';
            default:
                return null;
        }
    }
    /**
     * Gets the raw string value of a member's name
     */
    function getMemberRawName(member, sourceCode) {
        const { name, type } = util.getNameFromMember(member, sourceCode);
        if (type === util.MemberNameType.Quoted) {
            return name.slice(1, -1);
        }
        if (type === util.MemberNameType.Private) {
            return name.slice(1);
        }
        return name;
    }
    /**
     * Gets the member name based on the member type.
     *
     * @param node the node to be evaluated.
     * @param sourceCode
     */
    function getMemberName(node, sourceCode) {
        switch (node.type) {
            case utils_1.AST_NODE_TYPES.TSPropertySignature:
            case utils_1.AST_NODE_TYPES.TSMethodSignature:
            case utils_1.AST_NODE_TYPES.TSAbstractPropertyDefinition:
            case utils_1.AST_NODE_TYPES.PropertyDefinition:
                return getMemberRawName(node, sourceCode);
            case utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition:
            case utils_1.AST_NODE_TYPES.MethodDefinition:
                return node.kind === 'constructor'
                    ? 'constructor'
                    : getMemberRawName(node, sourceCode);
            case utils_1.AST_NODE_TYPES.TSConstructSignatureDeclaration:
                return 'new';
            case utils_1.AST_NODE_TYPES.TSCallSignatureDeclaration:
                return 'call';
            case utils_1.AST_NODE_TYPES.TSIndexSignature:
                return util.getNameFromIndexSignature(node);
            case utils_1.AST_NODE_TYPES.StaticBlock:
                return 'static block';
            default:
                return null;
        }
    }
    /**
     * Returns true if the member is optional based on the member type.
     *
     * @param node the node to be evaluated.
     *
     * @returns Whether the member is optional, or false if it cannot be optional at all.
     */
    function isMemberOptional(node) {
        switch (node.type) {
            case utils_1.AST_NODE_TYPES.TSPropertySignature:
            case utils_1.AST_NODE_TYPES.TSMethodSignature:
            case utils_1.AST_NODE_TYPES.TSAbstractPropertyDefinition:
            case utils_1.AST_NODE_TYPES.PropertyDefinition:
            case utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition:
            case utils_1.AST_NODE_TYPES.MethodDefinition:
                return !!node.optional;
        }
        return false;
    }
    /**
     * Gets the calculated rank using the provided method definition.
     * The algorithm is as follows:
     * - Get the rank based on the accessibility-scope-type name, e.g. public-instance-field
     * - If there is no order for accessibility-scope-type, then strip out the accessibility.
     * - If there is no order for scope-type, then strip out the scope.
     * - If there is no order for type, then return -1
     * @param memberGroups the valid names to be validated.
     * @param orderConfig the current order to be validated.
     *
     * @return Index of the matching member type in the order configuration.
     */
    function getRankOrder(memberGroups, orderConfig) {
        let rank = -1;
        const stack = memberGroups.slice(); // Get a copy of the member groups
        while (stack.length > 0 && rank === -1) {
            const memberGroup = stack.shift();
            rank = orderConfig.findIndex(memberType => Array.isArray(memberType)
                ? memberType.includes(memberGroup)
                : memberType === memberGroup);
        }
        return rank;
    }
    function getAccessibility(node) {
        var _a;
        if ('accessibility' in node && node.accessibility) {
            return node.accessibility;
        }
        if ('key' in node && ((_a = node.key) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.PrivateIdentifier) {
            return '#private';
        }
        return 'public';
    }
    /**
     * Gets the rank of the node given the order.
     * @param node the node to be evaluated.
     * @param orderConfig the current order to be validated.
     * @param supportsModifiers a flag indicating whether the type supports modifiers (scope or accessibility) or not.
     */
    function getRank(node, orderConfig, supportsModifiers) {
        const type = getNodeType(node);
        if (type == null) {
            // shouldn't happen but just in case, put it on the end
            return orderConfig.length - 1;
        }
        const abstract = node.type === utils_1.AST_NODE_TYPES.TSAbstractPropertyDefinition ||
            node.type === utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition;
        const scope = 'static' in node && node.static
            ? 'static'
            : abstract
                ? 'abstract'
                : 'instance';
        const accessibility = getAccessibility(node);
        // Collect all existing member groups that apply to this node...
        // (e.g. 'public-instance-field', 'instance-field', 'public-field', 'constructor' etc.)
        const memberGroups = [];
        if (supportsModifiers) {
            const decorated = 'decorators' in node && node.decorators.length > 0;
            if (decorated &&
                (type === 'readonly-field' ||
                    type === 'field' ||
                    type === 'method' ||
                    type === 'get' ||
                    type === 'set')) {
                memberGroups.push(`${accessibility}-decorated-${type}`);
                memberGroups.push(`decorated-${type}`);
                if (type === 'readonly-field') {
                    memberGroups.push(`${accessibility}-decorated-field`);
                    memberGroups.push(`decorated-field`);
                }
            }
            if (type !== 'readonly-signature' &&
                type !== 'signature' &&
                type !== 'static-initialization') {
                if (type !== 'constructor') {
                    // Constructors have no scope
                    memberGroups.push(`${accessibility}-${scope}-${type}`);
                    memberGroups.push(`${scope}-${type}`);
                    if (type === 'readonly-field') {
                        memberGroups.push(`${accessibility}-${scope}-field`);
                        memberGroups.push(`${scope}-field`);
                    }
                }
                memberGroups.push(`${accessibility}-${type}`);
                if (type === 'readonly-field') {
                    memberGroups.push(`${accessibility}-field`);
                }
            }
        }
        memberGroups.push(type);
        if (type === 'readonly-signature') {
            memberGroups.push('signature');
        }
        else if (type === 'readonly-field') {
            memberGroups.push('field');
        }
        // ...then get the rank order for those member groups based on the node
        return getRankOrder(memberGroups, orderConfig);
    }
    /**
     * Gets the lowest possible rank(s) higher than target.
     * e.g. given the following order:
     *   ...
     *   public-static-method
     *   protected-static-method
     *   private-static-method
     *   public-instance-method
     *   protected-instance-method
     *   private-instance-method
     *   ...
     * and considering that a public-instance-method has already been declared, so ranks contains
     * public-instance-method, then the lowest possible rank for public-static-method is
     * public-instance-method.
     * If a lowest possible rank is a member group, a comma separated list of ranks is returned.
     * @param ranks the existing ranks in the object.
     * @param target the target rank.
     * @param order the current order to be validated.
     * @returns the name(s) of the lowest possible rank without dashes (-).
     */
    function getLowestRank(ranks, target, order) {
        let lowest = ranks[ranks.length - 1];
        ranks.forEach(rank => {
            if (rank > target) {
                lowest = Math.min(lowest, rank);
            }
        });
        const lowestRank = order[lowest];
        const lowestRanks = Array.isArray(lowestRank) ? lowestRank : [lowestRank];
        return lowestRanks.map(rank => rank.replace(/-/g, ' ')).join(', ');
    }
    exports.default = util.createRule({
        name: 'member-ordering',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require a consistent member declaration order',
                recommended: false,
            },
            messages: {
                incorrectOrder: 'Member {{member}} should be declared before member {{beforeMember}}.',
                incorrectGroupOrder: 'Member {{name}} should be declared before all {{rank}} definitions.',
                incorrectRequiredMembersOrder: `Member {{member}} should be declared after all {{optionalOrRequired}} members.`,
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        default: {
                            oneOf: [
                                neverConfig,
                                arrayConfig(allMemberTypes),
                                objectConfig(allMemberTypes),
                            ],
                        },
                        classes: {
                            oneOf: [
                                neverConfig,
                                arrayConfig(allMemberTypes),
                                objectConfig(allMemberTypes),
                            ],
                        },
                        classExpressions: {
                            oneOf: [
                                neverConfig,
                                arrayConfig(allMemberTypes),
                                objectConfig(allMemberTypes),
                            ],
                        },
                        interfaces: {
                            oneOf: [
                                neverConfig,
                                arrayConfig([
                                    'readonly-signature',
                                    'signature',
                                    'readonly-field',
                                    'field',
                                    'method',
                                    'constructor',
                                ]),
                                objectConfig([
                                    'readonly-signature',
                                    'signature',
                                    'readonly-field',
                                    'field',
                                    'method',
                                    'constructor',
                                ]),
                            ],
                        },
                        typeLiterals: {
                            oneOf: [
                                neverConfig,
                                arrayConfig([
                                    'readonly-signature',
                                    'signature',
                                    'readonly-field',
                                    'field',
                                    'method',
                                    'constructor',
                                ]),
                                objectConfig([
                                    'readonly-signature',
                                    'signature',
                                    'readonly-field',
                                    'field',
                                    'method',
                                    'constructor',
                                ]),
                            ],
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                default: exports.defaultOrder,
            },
        ],
        create(context, [options]) {
            /**
             * Checks if the member groups are correctly sorted.
             *
             * @param members Members to be validated.
             * @param groupOrder Group order to be validated.
             * @param supportsModifiers A flag indicating whether the type supports modifiers (scope or accessibility) or not.
             *
             * @return Array of member groups or null if one of the groups is not correctly sorted.
             */
            function checkGroupSort(members, groupOrder, supportsModifiers) {
                const previousRanks = [];
                const memberGroups = [];
                let isCorrectlySorted = true;
                // Find first member which isn't correctly sorted
                members.forEach(member => {
                    const rank = getRank(member, groupOrder, supportsModifiers);
                    const name = getMemberName(member, context.getSourceCode());
                    const rankLastMember = previousRanks[previousRanks.length - 1];
                    if (rank === -1) {
                        return;
                    }
                    // Works for 1st item because x < undefined === false for any x (typeof string)
                    if (rank < rankLastMember) {
                        context.report({
                            node: member,
                            messageId: 'incorrectGroupOrder',
                            data: {
                                name,
                                rank: getLowestRank(previousRanks, rank, groupOrder),
                            },
                        });
                        isCorrectlySorted = false;
                    }
                    else if (rank === rankLastMember) {
                        // Same member group --> Push to existing member group array
                        memberGroups[memberGroups.length - 1].push(member);
                    }
                    else {
                        // New member group --> Create new member group array
                        previousRanks.push(rank);
                        memberGroups.push([member]);
                    }
                });
                return isCorrectlySorted ? memberGroups : null;
            }
            /**
             * Checks if the members are alphabetically sorted.
             *
             * @param members Members to be validated.
             * @param caseSensitive indicates if the alpha ordering is case sensitive or not.
             *
             * @return True if all members are correctly sorted.
             */
            function checkAlphaSort(members, order) {
                let previousName = '';
                let isCorrectlySorted = true;
                // Find first member which isn't correctly sorted
                members.forEach(member => {
                    const name = getMemberName(member, context.getSourceCode());
                    // Note: Not all members have names
                    if (name) {
                        if (naturalOutOfOrder(name, previousName, order)) {
                            context.report({
                                node: member,
                                messageId: 'incorrectOrder',
                                data: {
                                    member: name,
                                    beforeMember: previousName,
                                },
                            });
                            isCorrectlySorted = false;
                        }
                        previousName = name;
                    }
                });
                return isCorrectlySorted;
            }
            function naturalOutOfOrder(name, previousName, order) {
                switch (order) {
                    case 'alphabetically':
                        return name < previousName;
                    case 'alphabetically-case-insensitive':
                        return name.toLowerCase() < previousName.toLowerCase();
                    case 'natural':
                        return (0, natural_compare_lite_1.default)(name, previousName) !== 1;
                    case 'natural-case-insensitive':
                        return ((0, natural_compare_lite_1.default)(name.toLowerCase(), previousName.toLowerCase()) !== 1);
                }
            }
            /**
             * Checks if the order of optional and required members is correct based
             * on the given 'required' parameter.
             *
             * @param members Members to be validated.
             * @param optionalityOrder Where to place optional members, if not intermixed.
             *
             * @return True if all required and optional members are correctly sorted.
             */
            function checkRequiredOrder(members, optionalityOrder) {
                const switchIndex = members.findIndex((member, i) => i && isMemberOptional(member) !== isMemberOptional(members[i - 1]));
                const report = (member) => context.report({
                    messageId: 'incorrectRequiredMembersOrder',
                    loc: member.loc,
                    data: {
                        member: getMemberName(member, context.getSourceCode()),
                        optionalOrRequired: optionalityOrder === 'required-first' ? 'required' : 'optional',
                    },
                });
                // if the optionality of the first item is correct (based on optionalityOrder)
                // then the first 0 inclusive to switchIndex exclusive members all
                // have the correct optionality
                if (isMemberOptional(members[0]) !==
                    (optionalityOrder === 'optional-first')) {
                    report(members[0]);
                    return false;
                }
                for (let i = switchIndex + 1; i < members.length; i++) {
                    if (isMemberOptional(members[i]) !==
                        isMemberOptional(members[switchIndex])) {
                        report(members[switchIndex]);
                        return false;
                    }
                }
                return true;
            }
            /**
             * Validates if all members are correctly sorted.
             *
             * @param members Members to be validated.
             * @param orderConfig Order config to be validated.
             * @param supportsModifiers A flag indicating whether the type supports modifiers (scope or accessibility) or not.
             */
            function validateMembersOrder(members, orderConfig, supportsModifiers) {
                if (orderConfig === 'never') {
                    return;
                }
                // Standardize config
                let order;
                let memberTypes;
                let optionalityOrder;
                // returns true if everything is good and false if an error was reported
                const checkOrder = (memberSet) => {
                    const hasAlphaSort = !!(order && order !== 'as-written');
                    // Check order
                    if (Array.isArray(memberTypes)) {
                        const grouped = checkGroupSort(memberSet, memberTypes, supportsModifiers);
                        if (grouped == null) {
                            return false;
                        }
                        if (hasAlphaSort) {
                            return !grouped.some(groupMember => !checkAlphaSort(groupMember, order));
                        }
                    }
                    else if (hasAlphaSort) {
                        return checkAlphaSort(memberSet, order);
                    }
                    return true;
                };
                if (Array.isArray(orderConfig)) {
                    memberTypes = orderConfig;
                }
                else {
                    order = orderConfig.order;
                    memberTypes = orderConfig.memberTypes;
                    optionalityOrder = orderConfig.optionalityOrder;
                }
                if (!optionalityOrder) {
                    checkOrder(members);
                    return;
                }
                const switchIndex = members.findIndex((member, i) => i && isMemberOptional(member) !== isMemberOptional(members[i - 1]));
                if (switchIndex !== -1) {
                    if (!checkRequiredOrder(members, optionalityOrder)) {
                        return;
                    }
                    checkOrder(members.slice(0, switchIndex));
                    checkOrder(members.slice(switchIndex));
                }
            }
            return {
                ClassDeclaration(node) {
                    var _a;
                    validateMembersOrder(node.body.body, (_a = options.classes) !== null && _a !== void 0 ? _a : options.default, true);
                },
                ClassExpression(node) {
                    var _a;
                    validateMembersOrder(node.body.body, (_a = options.classExpressions) !== null && _a !== void 0 ? _a : options.default, true);
                },
                TSInterfaceDeclaration(node) {
                    var _a;
                    validateMembersOrder(node.body.body, (_a = options.interfaces) !== null && _a !== void 0 ? _a : options.default, false);
                },
                TSTypeLiteral(node) {
                    var _a;
                    validateMembersOrder(node.members, (_a = options.typeLiterals) !== null && _a !== void 0 ? _a : options.default, false);
                },
            };
        },
    });
    
},
/* natural-compare-lite/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
     * @version    1.4.0
     * @date       2015-10-26
     * @stability  3 - Stable
     * @author     Lauri Rooden (https://github.com/litejs/natural-compare-lite)
     * @license    MIT License
     */
    var naturalCompare = function (a, b) {
        var i, codeA, codeB = 1, posA = 0, posB = 0, alphabet = String.alphabet;
        function getCode(str, pos, code) {
            if (code) {
                for (i = pos; code = getCode(str, i), code < 76 && code > 65;)
                    ++i;
                return +str.slice(pos - 1, i);
            }
            code = alphabet && alphabet.indexOf(str.charAt(pos));
            return code > -1 ? code + 76 : ((code = str.charCodeAt(pos) || 0), code < 45 || code > 127) ? code
                : code < 46 ? 65 // -
                    : code < 48 ? code - 1
                        : code < 58 ? code + 18 // 0-9
                            : code < 65 ? code - 11
                                : code < 91 ? code + 11 // A-Z
                                    : code < 97 ? code - 37
                                        : code < 123 ? code + 5 // a-z
                                            : code - 63;
        }
        if ((a += "") != (b += ""))
            for (; codeB;) {
                codeA = getCode(a, posA++);
                codeB = getCode(b, posB++);
                if (codeA < 76 && codeB < 76 && codeA > 66 && codeB > 66) {
                    codeA = getCode(a, posA, posA);
                    codeB = getCode(b, posB, posA = i);
                    posB = i;
                }
                if (codeA != codeB)
                    return (codeA < codeB) ? -1 : 1;
            }
        return 0;
    };
    try {
        module.exports = naturalCompare;
    }
    catch (e) {
        String.naturalCompare = naturalCompare;
    }
},
/* @typescript-eslint/eslint-plugin/dist/rules/method-signature-style.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'method-signature-style',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce using a particular method signature syntax',
                recommended: false,
            },
            fixable: 'code',
            messages: {
                errorMethod: 'Shorthand method signature is forbidden. Use a function property instead.',
                errorProperty: 'Function property signature is forbidden. Use a method shorthand instead.',
            },
            schema: [
                {
                    enum: ['property', 'method'],
                },
            ],
        },
        defaultOptions: ['property'],
        create(context, [mode]) {
            const sourceCode = context.getSourceCode();
            function getMethodKey(node) {
                let key = sourceCode.getText(node.key);
                if (node.computed) {
                    key = `[${key}]`;
                }
                if (node.optional) {
                    key = `${key}?`;
                }
                if (node.readonly) {
                    key = `readonly ${key}`;
                }
                return key;
            }
            function getMethodParams(node) {
                let params = '()';
                if (node.params.length > 0) {
                    const openingParen = util.nullThrows(sourceCode.getTokenBefore(node.params[0], util.isOpeningParenToken), 'Missing opening paren before first parameter');
                    const closingParen = util.nullThrows(sourceCode.getTokenAfter(node.params[node.params.length - 1], util.isClosingParenToken), 'Missing closing paren after last parameter');
                    params = sourceCode.text.substring(openingParen.range[0], closingParen.range[1]);
                }
                if (node.typeParameters != null) {
                    const typeParams = sourceCode.getText(node.typeParameters);
                    params = `${typeParams}${params}`;
                }
                return params;
            }
            function getMethodReturnType(node) {
                return node.returnType == null
                    ? // if the method has no return type, it implicitly has an `any` return type
                        // we just make it explicit here so we can do the fix
                        'any'
                    : sourceCode.getText(node.returnType.typeAnnotation);
            }
            function getDelimiter(node) {
                const lastToken = sourceCode.getLastToken(node);
                if (lastToken &&
                    (util.isSemicolonToken(lastToken) || util.isCommaToken(lastToken))) {
                    return lastToken.value;
                }
                return '';
            }
            function isNodeParentModuleDeclaration(node) {
                if (!node.parent) {
                    return false;
                }
                if (node.parent.type === utils_1.AST_NODE_TYPES.TSModuleDeclaration) {
                    return true;
                }
                if (node.parent.type === utils_1.AST_NODE_TYPES.Program) {
                    return false;
                }
                return isNodeParentModuleDeclaration(node.parent);
            }
            return Object.assign(Object.assign({}, (mode === 'property' && {
                TSMethodSignature(methodNode) {
                    if (methodNode.kind !== 'method') {
                        return;
                    }
                    const parent = methodNode.parent;
                    const members = (parent === null || parent === void 0 ? void 0 : parent.type) === utils_1.AST_NODE_TYPES.TSInterfaceBody
                        ? parent.body
                        : (parent === null || parent === void 0 ? void 0 : parent.type) === utils_1.AST_NODE_TYPES.TSTypeLiteral
                            ? parent.members
                            : [];
                    const duplicatedKeyMethodNodes = members.filter((element) => element.type === utils_1.AST_NODE_TYPES.TSMethodSignature &&
                        element !== methodNode &&
                        getMethodKey(element) === getMethodKey(methodNode));
                    const isParentModule = isNodeParentModuleDeclaration(methodNode);
                    if (duplicatedKeyMethodNodes.length > 0) {
                        if (isParentModule) {
                            context.report({
                                node: methodNode,
                                messageId: 'errorMethod',
                            });
                        }
                        else {
                            context.report({
                                node: methodNode,
                                messageId: 'errorMethod',
                                *fix(fixer) {
                                    const methodNodes = [
                                        methodNode,
                                        ...duplicatedKeyMethodNodes,
                                    ].sort((a, b) => (a.range[0] < b.range[0] ? -1 : 1));
                                    const typeString = methodNodes
                                        .map(node => {
                                        const params = getMethodParams(node);
                                        const returnType = getMethodReturnType(node);
                                        return `(${params} => ${returnType})`;
                                    })
                                        .join(' & ');
                                    const key = getMethodKey(methodNode);
                                    const delimiter = getDelimiter(methodNode);
                                    yield fixer.replaceText(methodNode, `${key}: ${typeString}${delimiter}`);
                                    for (const node of duplicatedKeyMethodNodes) {
                                        const lastToken = sourceCode.getLastToken(node);
                                        if (lastToken) {
                                            const nextToken = sourceCode.getTokenAfter(lastToken);
                                            if (nextToken) {
                                                yield fixer.remove(node);
                                                yield fixer.replaceTextRange([lastToken.range[1], nextToken.range[0]], '');
                                            }
                                        }
                                    }
                                },
                            });
                        }
                        return;
                    }
                    if (isParentModule) {
                        context.report({
                            node: methodNode,
                            messageId: 'errorMethod',
                        });
                    }
                    else {
                        context.report({
                            node: methodNode,
                            messageId: 'errorMethod',
                            fix: fixer => {
                                const key = getMethodKey(methodNode);
                                const params = getMethodParams(methodNode);
                                const returnType = getMethodReturnType(methodNode);
                                const delimiter = getDelimiter(methodNode);
                                return fixer.replaceText(methodNode, `${key}: ${params} => ${returnType}${delimiter}`);
                            },
                        });
                    }
                },
            })), (mode === 'method' && {
                TSPropertySignature(propertyNode) {
                    var _a;
                    const typeNode = (_a = propertyNode.typeAnnotation) === null || _a === void 0 ? void 0 : _a.typeAnnotation;
                    if ((typeNode === null || typeNode === void 0 ? void 0 : typeNode.type) !== utils_1.AST_NODE_TYPES.TSFunctionType) {
                        return;
                    }
                    context.report({
                        node: propertyNode,
                        messageId: 'errorProperty',
                        fix: fixer => {
                            const key = getMethodKey(propertyNode);
                            const params = getMethodParams(typeNode);
                            const returnType = getMethodReturnType(typeNode);
                            const delimiter = getDelimiter(propertyNode);
                            return fixer.replaceText(propertyNode, `${key}${params}: ${returnType}${delimiter}`);
                        },
                    });
                },
            }));
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/naming-convention.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const scope_manager_1 = require(861) /* @typescript-eslint/scope-manager */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const naming_convention_utils_1 = require(1186) /* ./naming-convention-utils */;
    // This essentially mirrors ESLint's `camelcase` rule
    // note that that rule ignores leading and trailing underscores and only checks those in the middle of a variable name
    const defaultCamelCaseAllTheThingsConfig = [
        {
            selector: 'default',
            format: ['camelCase'],
            leadingUnderscore: 'allow',
            trailingUnderscore: 'allow',
        },
        {
            selector: 'variable',
            format: ['camelCase', 'UPPER_CASE'],
            leadingUnderscore: 'allow',
            trailingUnderscore: 'allow',
        },
        {
            selector: 'typeLike',
            format: ['PascalCase'],
        },
    ];
    exports.default = util.createRule({
        name: 'naming-convention',
        meta: {
            docs: {
                description: 'Enforce naming conventions for everything across a codebase',
                recommended: false,
                // technically only requires type checking if the user uses "type" modifiers
                requiresTypeChecking: true,
            },
            type: 'suggestion',
            messages: {
                unexpectedUnderscore: '{{type}} name `{{name}}` must not have a {{position}} underscore.',
                missingUnderscore: '{{type}} name `{{name}}` must have {{count}} {{position}} underscore(s).',
                missingAffix: '{{type}} name `{{name}}` must have one of the following {{position}}es: {{affixes}}',
                satisfyCustom: '{{type}} name `{{name}}` must {{regexMatch}} the RegExp: {{regex}}',
                doesNotMatchFormat: '{{type}} name `{{name}}` must match one of the following formats: {{formats}}',
                doesNotMatchFormatTrimmed: '{{type}} name `{{name}}` trimmed as `{{processedName}}` must match one of the following formats: {{formats}}',
            },
            schema: naming_convention_utils_1.SCHEMA,
        },
        defaultOptions: defaultCamelCaseAllTheThingsConfig,
        create(contextWithoutDefaults) {
            const context = contextWithoutDefaults.options &&
                contextWithoutDefaults.options.length > 0
                ? contextWithoutDefaults
                : // only apply the defaults when the user provides no config
                    Object.setPrototypeOf({
                        options: defaultCamelCaseAllTheThingsConfig,
                    }, contextWithoutDefaults);
            const validators = (0, naming_convention_utils_1.parseOptions)(context);
            // getParserServices(context, false) -- dirty hack to work around the docs checker test...
            const compilerOptions = util
                .getParserServices(context, true)
                .program.getCompilerOptions();
            function handleMember(validator, node, modifiers) {
                if (!validator) {
                    return;
                }
                const key = node.key;
                if (requiresQuoting(key, compilerOptions.target)) {
                    modifiers.add(naming_convention_utils_1.Modifiers.requiresQuotes);
                }
                validator(key, modifiers);
            }
            function getMemberModifiers(node) {
                const modifiers = new Set();
                if ('key' in node && node.key.type === utils_1.AST_NODE_TYPES.PrivateIdentifier) {
                    modifiers.add(naming_convention_utils_1.Modifiers['#private']);
                }
                else if (node.accessibility) {
                    modifiers.add(naming_convention_utils_1.Modifiers[node.accessibility]);
                }
                else {
                    modifiers.add(naming_convention_utils_1.Modifiers.public);
                }
                if (node.static) {
                    modifiers.add(naming_convention_utils_1.Modifiers.static);
                }
                if ('readonly' in node && node.readonly) {
                    modifiers.add(naming_convention_utils_1.Modifiers.readonly);
                }
                if ('override' in node && node.override) {
                    modifiers.add(naming_convention_utils_1.Modifiers.override);
                }
                if (node.type === utils_1.AST_NODE_TYPES.TSAbstractPropertyDefinition ||
                    node.type === utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition) {
                    modifiers.add(naming_convention_utils_1.Modifiers.abstract);
                }
                return modifiers;
            }
            const unusedVariables = util.collectUnusedVariables(context);
            function isUnused(name, initialScope = context.getScope()) {
                var _a;
                let variable = null;
                let scope = initialScope;
                while (scope) {
                    variable = (_a = scope.set.get(name)) !== null && _a !== void 0 ? _a : null;
                    if (variable) {
                        break;
                    }
                    scope = scope.upper;
                }
                if (!variable) {
                    return false;
                }
                return unusedVariables.has(variable);
            }
            function isDestructured(id) {
                var _a, _b, _c;
                return (
                // `const { x }`
                // does not match `const { x: y }`
                (((_a = id.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.Property && id.parent.shorthand) ||
                    // `const { x = 2 }`
                    // does not match const `{ x: y = 2 }`
                    (((_b = id.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.AssignmentPattern &&
                        ((_c = id.parent.parent) === null || _c === void 0 ? void 0 : _c.type) === utils_1.AST_NODE_TYPES.Property &&
                        id.parent.parent.shorthand));
            }
            function isAsyncMemberOrProperty(propertyOrMemberNode) {
                return Boolean('value' in propertyOrMemberNode &&
                    propertyOrMemberNode.value &&
                    'async' in propertyOrMemberNode.value &&
                    propertyOrMemberNode.value.async);
            }
            function isAsyncVariableIdentifier(id) {
                return Boolean(id.parent &&
                    (('async' in id.parent && id.parent.async) ||
                        ('init' in id.parent &&
                            id.parent.init &&
                            'async' in id.parent.init &&
                            id.parent.init.async)));
            }
            const selectors = {
                // #region variable
                VariableDeclarator: {
                    validator: validators.variable,
                    handler: (node, validator) => {
                        const identifiers = getIdentifiersFromPattern(node.id);
                        const baseModifiers = new Set();
                        const parent = node.parent;
                        if ((parent === null || parent === void 0 ? void 0 : parent.type) === utils_1.AST_NODE_TYPES.VariableDeclaration) {
                            if (parent.kind === 'const') {
                                baseModifiers.add(naming_convention_utils_1.Modifiers.const);
                            }
                            if (isGlobal(context.getScope())) {
                                baseModifiers.add(naming_convention_utils_1.Modifiers.global);
                            }
                        }
                        identifiers.forEach(id => {
                            const modifiers = new Set(baseModifiers);
                            if (isDestructured(id)) {
                                modifiers.add(naming_convention_utils_1.Modifiers.destructured);
                            }
                            if (isExported(parent, id.name, context.getScope())) {
                                modifiers.add(naming_convention_utils_1.Modifiers.exported);
                            }
                            if (isUnused(id.name)) {
                                modifiers.add(naming_convention_utils_1.Modifiers.unused);
                            }
                            if (isAsyncVariableIdentifier(id)) {
                                modifiers.add(naming_convention_utils_1.Modifiers.async);
                            }
                            validator(id, modifiers);
                        });
                    },
                },
                // #endregion
                // #region function
                'FunctionDeclaration, TSDeclareFunction, FunctionExpression': {
                    validator: validators.function,
                    handler: (node, validator) => {
                        if (node.id == null) {
                            return;
                        }
                        const modifiers = new Set();
                        // functions create their own nested scope
                        const scope = context.getScope().upper;
                        if (isGlobal(scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.global);
                        }
                        if (isExported(node, node.id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.exported);
                        }
                        if (isUnused(node.id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.unused);
                        }
                        if (node.async) {
                            modifiers.add(naming_convention_utils_1.Modifiers.async);
                        }
                        validator(node.id, modifiers);
                    },
                },
                // #endregion function
                // #region parameter
                'FunctionDeclaration, TSDeclareFunction, TSEmptyBodyFunctionExpression, FunctionExpression, ArrowFunctionExpression': {
                    validator: validators.parameter,
                    handler: (node, validator) => {
                        node.params.forEach(param => {
                            if (param.type === utils_1.AST_NODE_TYPES.TSParameterProperty) {
                                return;
                            }
                            const identifiers = getIdentifiersFromPattern(param);
                            identifiers.forEach(i => {
                                const modifiers = new Set();
                                if (isDestructured(i)) {
                                    modifiers.add(naming_convention_utils_1.Modifiers.destructured);
                                }
                                if (isUnused(i.name)) {
                                    modifiers.add(naming_convention_utils_1.Modifiers.unused);
                                }
                                validator(i, modifiers);
                            });
                        });
                    },
                },
                // #endregion parameter
                // #region parameterProperty
                TSParameterProperty: {
                    validator: validators.parameterProperty,
                    handler: (node, validator) => {
                        const modifiers = getMemberModifiers(node);
                        const identifiers = getIdentifiersFromPattern(node.parameter);
                        identifiers.forEach(i => {
                            validator(i, modifiers);
                        });
                    },
                },
                // #endregion parameterProperty
                // #region property
                ':not(ObjectPattern) > Property[computed = false][kind = "init"][value.type != "ArrowFunctionExpression"][value.type != "FunctionExpression"][value.type != "TSEmptyBodyFunctionExpression"]': {
                    validator: validators.objectLiteralProperty,
                    handler: (node, validator) => {
                        const modifiers = new Set([naming_convention_utils_1.Modifiers.public]);
                        handleMember(validator, node, modifiers);
                    },
                },
                ':matches(PropertyDefinition, TSAbstractPropertyDefinition)[computed = false][value.type != "ArrowFunctionExpression"][value.type != "FunctionExpression"][value.type != "TSEmptyBodyFunctionExpression"]': {
                    validator: validators.classProperty,
                    handler: (node, validator) => {
                        const modifiers = getMemberModifiers(node);
                        handleMember(validator, node, modifiers);
                    },
                },
                'TSPropertySignature[computed = false]': {
                    validator: validators.typeProperty,
                    handler: (node, validator) => {
                        const modifiers = new Set([naming_convention_utils_1.Modifiers.public]);
                        if (node.readonly) {
                            modifiers.add(naming_convention_utils_1.Modifiers.readonly);
                        }
                        handleMember(validator, node, modifiers);
                    },
                },
                // #endregion property
                // #region method
                [[
                    'Property[computed = false][kind = "init"][value.type = "ArrowFunctionExpression"]',
                    'Property[computed = false][kind = "init"][value.type = "FunctionExpression"]',
                    'Property[computed = false][kind = "init"][value.type = "TSEmptyBodyFunctionExpression"]',
                ].join(', ')]: {
                    validator: validators.objectLiteralMethod,
                    handler: (node, validator) => {
                        const modifiers = new Set([naming_convention_utils_1.Modifiers.public]);
                        if (isAsyncMemberOrProperty(node)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.async);
                        }
                        handleMember(validator, node, modifiers);
                    },
                },
                [[
                    ':matches(PropertyDefinition, TSAbstractPropertyDefinition)[computed = false][value.type = "ArrowFunctionExpression"]',
                    ':matches(PropertyDefinition, TSAbstractPropertyDefinition)[computed = false][value.type = "FunctionExpression"]',
                    ':matches(PropertyDefinition, TSAbstractPropertyDefinition)[computed = false][value.type = "TSEmptyBodyFunctionExpression"]',
                    ':matches(MethodDefinition, TSAbstractMethodDefinition)[computed = false][kind = "method"]',
                ].join(', ')]: {
                    validator: validators.classMethod,
                    handler: (node, validator) => {
                        const modifiers = getMemberModifiers(node);
                        if (isAsyncMemberOrProperty(node)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.async);
                        }
                        handleMember(validator, node, modifiers);
                    },
                },
                'TSMethodSignature[computed = false]': {
                    validator: validators.typeMethod,
                    handler: (node, validator) => {
                        const modifiers = new Set([naming_convention_utils_1.Modifiers.public]);
                        handleMember(validator, node, modifiers);
                    },
                },
                // #endregion method
                // #region accessor
                'Property[computed = false]:matches([kind = "get"], [kind = "set"])': {
                    validator: validators.accessor,
                    handler: (node, validator) => {
                        const modifiers = new Set([naming_convention_utils_1.Modifiers.public]);
                        handleMember(validator, node, modifiers);
                    },
                },
                'MethodDefinition[computed = false]:matches([kind = "get"], [kind = "set"])': {
                    validator: validators.accessor,
                    handler: (node, validator) => {
                        const modifiers = getMemberModifiers(node);
                        handleMember(validator, node, modifiers);
                    },
                },
                // #endregion accessor
                // #region enumMember
                // computed is optional, so can't do [computed = false]
                'TSEnumMember[computed != true]': {
                    validator: validators.enumMember,
                    handler: (node, validator) => {
                        const id = node.id;
                        const modifiers = new Set();
                        if (requiresQuoting(id, compilerOptions.target)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.requiresQuotes);
                        }
                        validator(id, modifiers);
                    },
                },
                // #endregion enumMember
                // #region class
                'ClassDeclaration, ClassExpression': {
                    validator: validators.class,
                    handler: (node, validator) => {
                        const id = node.id;
                        if (id == null) {
                            return;
                        }
                        const modifiers = new Set();
                        // classes create their own nested scope
                        const scope = context.getScope().upper;
                        if (node.abstract) {
                            modifiers.add(naming_convention_utils_1.Modifiers.abstract);
                        }
                        if (isExported(node, id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.exported);
                        }
                        if (isUnused(id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.unused);
                        }
                        validator(id, modifiers);
                    },
                },
                // #endregion class
                // #region interface
                TSInterfaceDeclaration: {
                    validator: validators.interface,
                    handler: (node, validator) => {
                        const modifiers = new Set();
                        const scope = context.getScope();
                        if (isExported(node, node.id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.exported);
                        }
                        if (isUnused(node.id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.unused);
                        }
                        validator(node.id, modifiers);
                    },
                },
                // #endregion interface
                // #region typeAlias
                TSTypeAliasDeclaration: {
                    validator: validators.typeAlias,
                    handler: (node, validator) => {
                        const modifiers = new Set();
                        const scope = context.getScope();
                        if (isExported(node, node.id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.exported);
                        }
                        if (isUnused(node.id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.unused);
                        }
                        validator(node.id, modifiers);
                    },
                },
                // #endregion typeAlias
                // #region enum
                TSEnumDeclaration: {
                    validator: validators.enum,
                    handler: (node, validator) => {
                        const modifiers = new Set();
                        // enums create their own nested scope
                        const scope = context.getScope().upper;
                        if (isExported(node, node.id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.exported);
                        }
                        if (isUnused(node.id.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.unused);
                        }
                        validator(node.id, modifiers);
                    },
                },
                // #endregion enum
                // #region typeParameter
                'TSTypeParameterDeclaration > TSTypeParameter': {
                    validator: validators.typeParameter,
                    handler: (node, validator) => {
                        const modifiers = new Set();
                        const scope = context.getScope();
                        if (isUnused(node.name.name, scope)) {
                            modifiers.add(naming_convention_utils_1.Modifiers.unused);
                        }
                        validator(node.name, modifiers);
                    },
                },
                // #endregion typeParameter
            };
            return Object.fromEntries(Object.entries(selectors)
                .map(([selector, { validator, handler }]) => {
                return [
                    selector,
                    (node) => {
                        handler(node, validator);
                    },
                ];
            })
                .filter((s) => s != null));
        },
    });
    function getIdentifiersFromPattern(pattern) {
        const identifiers = [];
        const visitor = new scope_manager_1.PatternVisitor({}, pattern, id => identifiers.push(id));
        visitor.visit(pattern);
        return identifiers;
    }
    function isExported(node, name, scope) {
        var _a, _b;
        if (((_a = node === null || node === void 0 ? void 0 : node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ExportDefaultDeclaration ||
            ((_b = node === null || node === void 0 ? void 0 : node.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.ExportNamedDeclaration) {
            return true;
        }
        if (scope == null) {
            return false;
        }
        const variable = scope.set.get(name);
        if (variable) {
            for (const ref of variable.references) {
                const refParent = ref.identifier.parent;
                if ((refParent === null || refParent === void 0 ? void 0 : refParent.type) === utils_1.AST_NODE_TYPES.ExportDefaultDeclaration ||
                    (refParent === null || refParent === void 0 ? void 0 : refParent.type) === utils_1.AST_NODE_TYPES.ExportSpecifier) {
                    return true;
                }
            }
        }
        return false;
    }
    function isGlobal(scope) {
        if (scope == null) {
            return false;
        }
        return (scope.type === utils_1.TSESLint.Scope.ScopeType.global ||
            scope.type === utils_1.TSESLint.Scope.ScopeType.module);
    }
    function requiresQuoting(node, target) {
        const name = node.type === utils_1.AST_NODE_TYPES.Identifier ||
            node.type === utils_1.AST_NODE_TYPES.PrivateIdentifier
            ? node.name
            : `${node.value}`;
        return util.requiresQuoting(name, target);
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/naming-convention-utils/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.parseOptions = exports.selectorTypeToMessageString = exports.SCHEMA = exports.Modifiers = void 0;
    var enums_1 = require(1187) /* ./enums */;
    Object.defineProperty(exports, "Modifiers", { enumerable: true, get: function () { return enums_1.Modifiers; } });
    var schema_1 = require(1188) /* ./schema */;
    Object.defineProperty(exports, "SCHEMA", { enumerable: true, get: function () { return schema_1.SCHEMA; } });
    var shared_1 = require(1189) /* ./shared */;
    Object.defineProperty(exports, "selectorTypeToMessageString", { enumerable: true, get: function () { return shared_1.selectorTypeToMessageString; } });
    var parse_options_1 = require(1190) /* ./parse-options */;
    Object.defineProperty(exports, "parseOptions", { enumerable: true, get: function () { return parse_options_1.parseOptions; } });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/naming-convention-utils/enums.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.UnderscoreOptions = exports.TypeModifiers = exports.Selectors = exports.PredefinedFormats = exports.Modifiers = exports.MetaSelectors = void 0;
    var PredefinedFormats;
    (function (PredefinedFormats) {
        PredefinedFormats[PredefinedFormats["camelCase"] = 1] = "camelCase";
        PredefinedFormats[PredefinedFormats["strictCamelCase"] = 2] = "strictCamelCase";
        PredefinedFormats[PredefinedFormats["PascalCase"] = 3] = "PascalCase";
        PredefinedFormats[PredefinedFormats["StrictPascalCase"] = 4] = "StrictPascalCase";
        PredefinedFormats[PredefinedFormats["snake_case"] = 5] = "snake_case";
        PredefinedFormats[PredefinedFormats["UPPER_CASE"] = 6] = "UPPER_CASE";
    })(PredefinedFormats || (PredefinedFormats = {}));
    exports.PredefinedFormats = PredefinedFormats;
    var UnderscoreOptions;
    (function (UnderscoreOptions) {
        UnderscoreOptions[UnderscoreOptions["forbid"] = 1] = "forbid";
        UnderscoreOptions[UnderscoreOptions["allow"] = 2] = "allow";
        UnderscoreOptions[UnderscoreOptions["require"] = 3] = "require";
        // special cases as it's common practice to use double underscore
        UnderscoreOptions[UnderscoreOptions["requireDouble"] = 4] = "requireDouble";
        UnderscoreOptions[UnderscoreOptions["allowDouble"] = 5] = "allowDouble";
        UnderscoreOptions[UnderscoreOptions["allowSingleOrDouble"] = 6] = "allowSingleOrDouble";
    })(UnderscoreOptions || (UnderscoreOptions = {}));
    exports.UnderscoreOptions = UnderscoreOptions;
    var Selectors;
    (function (Selectors) {
        // variableLike
        Selectors[Selectors["variable"] = 1] = "variable";
        Selectors[Selectors["function"] = 2] = "function";
        Selectors[Selectors["parameter"] = 4] = "parameter";
        // memberLike
        Selectors[Selectors["parameterProperty"] = 8] = "parameterProperty";
        Selectors[Selectors["accessor"] = 16] = "accessor";
        Selectors[Selectors["enumMember"] = 32] = "enumMember";
        Selectors[Selectors["classMethod"] = 64] = "classMethod";
        Selectors[Selectors["objectLiteralMethod"] = 128] = "objectLiteralMethod";
        Selectors[Selectors["typeMethod"] = 256] = "typeMethod";
        Selectors[Selectors["classProperty"] = 512] = "classProperty";
        Selectors[Selectors["objectLiteralProperty"] = 1024] = "objectLiteralProperty";
        Selectors[Selectors["typeProperty"] = 2048] = "typeProperty";
        // typeLike
        Selectors[Selectors["class"] = 4096] = "class";
        Selectors[Selectors["interface"] = 8192] = "interface";
        Selectors[Selectors["typeAlias"] = 16384] = "typeAlias";
        Selectors[Selectors["enum"] = 32768] = "enum";
        Selectors[Selectors["typeParameter"] = 131072] = "typeParameter";
    })(Selectors || (Selectors = {}));
    exports.Selectors = Selectors;
    var MetaSelectors;
    (function (MetaSelectors) {
        MetaSelectors[MetaSelectors["default"] = -1] = "default";
        MetaSelectors[MetaSelectors["variableLike"] = 7] = "variableLike";
        MetaSelectors[MetaSelectors["memberLike"] = 4088] = "memberLike";
        MetaSelectors[MetaSelectors["typeLike"] = 192512] = "typeLike";
        MetaSelectors[MetaSelectors["method"] = 448] = "method";
        MetaSelectors[MetaSelectors["property"] = 3584] = "property";
    })(MetaSelectors || (MetaSelectors = {}));
    exports.MetaSelectors = MetaSelectors;
    var Modifiers;
    (function (Modifiers) {
        // const variable
        Modifiers[Modifiers["const"] = 1] = "const";
        // readonly members
        Modifiers[Modifiers["readonly"] = 2] = "readonly";
        // static members
        Modifiers[Modifiers["static"] = 4] = "static";
        // member accessibility
        Modifiers[Modifiers["public"] = 8] = "public";
        Modifiers[Modifiers["protected"] = 16] = "protected";
        Modifiers[Modifiers["private"] = 32] = "private";
        Modifiers[Modifiers["#private"] = 64] = "#private";
        Modifiers[Modifiers["abstract"] = 128] = "abstract";
        // destructured variable
        Modifiers[Modifiers["destructured"] = 256] = "destructured";
        // variables declared in the top-level scope
        Modifiers[Modifiers["global"] = 512] = "global";
        // things that are exported
        Modifiers[Modifiers["exported"] = 1024] = "exported";
        // things that are unused
        Modifiers[Modifiers["unused"] = 2048] = "unused";
        // properties that require quoting
        Modifiers[Modifiers["requiresQuotes"] = 4096] = "requiresQuotes";
        // class members that are overridden
        Modifiers[Modifiers["override"] = 8192] = "override";
        // class methods, object function properties, or functions that are async via the `async` keyword
        Modifiers[Modifiers["async"] = 16384] = "async";
        // make sure TypeModifiers starts at Modifiers + 1 or else sorting won't work
    })(Modifiers || (Modifiers = {}));
    exports.Modifiers = Modifiers;
    var TypeModifiers;
    (function (TypeModifiers) {
        TypeModifiers[TypeModifiers["boolean"] = 32768] = "boolean";
        TypeModifiers[TypeModifiers["string"] = 65536] = "string";
        TypeModifiers[TypeModifiers["number"] = 131072] = "number";
        TypeModifiers[TypeModifiers["function"] = 262144] = "function";
        TypeModifiers[TypeModifiers["array"] = 524288] = "array";
    })(TypeModifiers || (TypeModifiers = {}));
    exports.TypeModifiers = TypeModifiers;
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/naming-convention-utils/schema.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.SCHEMA = void 0;
    const util = __importStar(require(1018) /* ../../util */);
    const enums_1 = require(1187) /* ./enums */;
    const UNDERSCORE_SCHEMA = {
        type: 'string',
        enum: util.getEnumNames(enums_1.UnderscoreOptions),
    };
    const PREFIX_SUFFIX_SCHEMA = {
        type: 'array',
        items: {
            type: 'string',
            minLength: 1,
        },
        additionalItems: false,
    };
    const MATCH_REGEX_SCHEMA = {
        type: 'object',
        properties: {
            match: { type: 'boolean' },
            regex: { type: 'string' },
        },
        required: ['match', 'regex'],
    };
    const FORMAT_OPTIONS_PROPERTIES = {
        format: {
            oneOf: [
                {
                    type: 'array',
                    items: {
                        type: 'string',
                        enum: util.getEnumNames(enums_1.PredefinedFormats),
                    },
                    additionalItems: false,
                },
                {
                    type: 'null',
                },
            ],
        },
        custom: MATCH_REGEX_SCHEMA,
        leadingUnderscore: UNDERSCORE_SCHEMA,
        trailingUnderscore: UNDERSCORE_SCHEMA,
        prefix: PREFIX_SUFFIX_SCHEMA,
        suffix: PREFIX_SUFFIX_SCHEMA,
        failureMessage: {
            type: 'string',
        },
    };
    function selectorSchema(selectorString, allowType, modifiers) {
        const selector = {
            filter: {
                oneOf: [
                    {
                        type: 'string',
                        minLength: 1,
                    },
                    MATCH_REGEX_SCHEMA,
                ],
            },
            selector: {
                type: 'string',
                enum: [selectorString],
            },
        };
        if (modifiers && modifiers.length > 0) {
            selector.modifiers = {
                type: 'array',
                items: {
                    type: 'string',
                    enum: modifiers,
                },
                additionalItems: false,
            };
        }
        if (allowType) {
            selector.types = {
                type: 'array',
                items: {
                    type: 'string',
                    enum: util.getEnumNames(enums_1.TypeModifiers),
                },
                additionalItems: false,
            };
        }
        return [
            {
                type: 'object',
                properties: Object.assign(Object.assign({}, FORMAT_OPTIONS_PROPERTIES), selector),
                required: ['selector', 'format'],
                additionalProperties: false,
            },
        ];
    }
    function selectorsSchema() {
        return {
            type: 'object',
            properties: Object.assign(Object.assign({}, FORMAT_OPTIONS_PROPERTIES), {
                filter: {
                    oneOf: [
                        {
                            type: 'string',
                            minLength: 1,
                        },
                        MATCH_REGEX_SCHEMA,
                    ],
                },
                selector: {
                    type: 'array',
                    items: {
                        type: 'string',
                        enum: [
                            ...util.getEnumNames(enums_1.MetaSelectors),
                            ...util.getEnumNames(enums_1.Selectors),
                        ],
                    },
                    additionalItems: false,
                },
                modifiers: {
                    type: 'array',
                    items: {
                        type: 'string',
                        enum: util.getEnumNames(enums_1.Modifiers),
                    },
                    additionalItems: false,
                },
                types: {
                    type: 'array',
                    items: {
                        type: 'string',
                        enum: util.getEnumNames(enums_1.TypeModifiers),
                    },
                    additionalItems: false,
                },
            }),
            required: ['selector', 'format'],
            additionalProperties: false,
        };
    }
    const SCHEMA = {
        type: 'array',
        items: {
            oneOf: [
                selectorsSchema(),
                ...selectorSchema('default', false, util.getEnumNames(enums_1.Modifiers)),
                ...selectorSchema('variableLike', false, ['unused', 'async']),
                ...selectorSchema('variable', true, [
                    'const',
                    'destructured',
                    'exported',
                    'global',
                    'unused',
                    'async',
                ]),
                ...selectorSchema('function', false, [
                    'exported',
                    'global',
                    'unused',
                    'async',
                ]),
                ...selectorSchema('parameter', true, ['destructured', 'unused']),
                ...selectorSchema('memberLike', false, [
                    'abstract',
                    'private',
                    '#private',
                    'protected',
                    'public',
                    'readonly',
                    'requiresQuotes',
                    'static',
                    'override',
                    'async',
                ]),
                ...selectorSchema('classProperty', true, [
                    'abstract',
                    'private',
                    '#private',
                    'protected',
                    'public',
                    'readonly',
                    'requiresQuotes',
                    'static',
                    'override',
                ]),
                ...selectorSchema('objectLiteralProperty', true, [
                    'public',
                    'requiresQuotes',
                ]),
                ...selectorSchema('typeProperty', true, [
                    'public',
                    'readonly',
                    'requiresQuotes',
                ]),
                ...selectorSchema('parameterProperty', true, [
                    'private',
                    'protected',
                    'public',
                    'readonly',
                ]),
                ...selectorSchema('property', true, [
                    'abstract',
                    'private',
                    '#private',
                    'protected',
                    'public',
                    'readonly',
                    'requiresQuotes',
                    'static',
                    'override',
                    'async',
                ]),
                ...selectorSchema('classMethod', false, [
                    'abstract',
                    'private',
                    '#private',
                    'protected',
                    'public',
                    'requiresQuotes',
                    'static',
                    'override',
                    'async',
                ]),
                ...selectorSchema('objectLiteralMethod', false, [
                    'public',
                    'requiresQuotes',
                    'async',
                ]),
                ...selectorSchema('typeMethod', false, ['public', 'requiresQuotes']),
                ...selectorSchema('method', false, [
                    'abstract',
                    'private',
                    '#private',
                    'protected',
                    'public',
                    'requiresQuotes',
                    'static',
                    'override',
                    'async',
                ]),
                ...selectorSchema('accessor', true, [
                    'abstract',
                    'private',
                    'protected',
                    'public',
                    'requiresQuotes',
                    'static',
                    'override',
                ]),
                ...selectorSchema('enumMember', false, ['requiresQuotes']),
                ...selectorSchema('typeLike', false, ['abstract', 'exported', 'unused']),
                ...selectorSchema('class', false, ['abstract', 'exported', 'unused']),
                ...selectorSchema('interface', false, ['exported', 'unused']),
                ...selectorSchema('typeAlias', false, ['exported', 'unused']),
                ...selectorSchema('enum', false, ['exported', 'unused']),
                ...selectorSchema('typeParameter', false, ['unused']),
            ],
        },
        additionalItems: false,
    };
    exports.SCHEMA = SCHEMA;
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/naming-convention-utils/shared.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isMethodOrPropertySelector = exports.isMetaSelector = exports.selectorTypeToMessageString = void 0;
    const enums_1 = require(1187) /* ./enums */;
    function selectorTypeToMessageString(selectorType) {
        const notCamelCase = selectorType.replace(/([A-Z])/g, ' $1');
        return notCamelCase.charAt(0).toUpperCase() + notCamelCase.slice(1);
    }
    exports.selectorTypeToMessageString = selectorTypeToMessageString;
    function isMetaSelector(selector) {
        return selector in enums_1.MetaSelectors;
    }
    exports.isMetaSelector = isMetaSelector;
    function isMethodOrPropertySelector(selector) {
        return (selector === enums_1.MetaSelectors.method || selector === enums_1.MetaSelectors.property);
    }
    exports.isMethodOrPropertySelector = isMethodOrPropertySelector;
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/naming-convention-utils/parse-options.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.parseOptions = void 0;
    const util = __importStar(require(1018) /* ../../util */);
    const enums_1 = require(1187) /* ./enums */;
    const shared_1 = require(1189) /* ./shared */;
    const validator_1 = require(1191) /* ./validator */;
    function normalizeOption(option) {
        var _a, _b, _c, _d, _e, _f;
        let weight = 0;
        (_a = option.modifiers) === null || _a === void 0 ? void 0 : _a.forEach(mod => {
            weight |= enums_1.Modifiers[mod];
        });
        (_b = option.types) === null || _b === void 0 ? void 0 : _b.forEach(mod => {
            weight |= enums_1.TypeModifiers[mod];
        });
        // give selectors with a filter the _highest_ priority
        if (option.filter) {
            weight |= 1 << 30;
        }
        const normalizedOption = {
            // format options
            format: option.format ? option.format.map(f => enums_1.PredefinedFormats[f]) : null,
            custom: option.custom
                ? {
                    regex: new RegExp(option.custom.regex, 'u'),
                    match: option.custom.match,
                }
                : null,
            leadingUnderscore: option.leadingUnderscore !== undefined
                ? enums_1.UnderscoreOptions[option.leadingUnderscore]
                : null,
            trailingUnderscore: option.trailingUnderscore !== undefined
                ? enums_1.UnderscoreOptions[option.trailingUnderscore]
                : null,
            prefix: option.prefix && option.prefix.length > 0 ? option.prefix : null,
            suffix: option.suffix && option.suffix.length > 0 ? option.suffix : null,
            modifiers: (_d = (_c = option.modifiers) === null || _c === void 0 ? void 0 : _c.map(m => enums_1.Modifiers[m])) !== null && _d !== void 0 ? _d : null,
            types: (_f = (_e = option.types) === null || _e === void 0 ? void 0 : _e.map(m => enums_1.TypeModifiers[m])) !== null && _f !== void 0 ? _f : null,
            filter: option.filter !== undefined
                ? typeof option.filter === 'string'
                    ? {
                        regex: new RegExp(option.filter, 'u'),
                        match: true,
                    }
                    : {
                        regex: new RegExp(option.filter.regex, 'u'),
                        match: option.filter.match,
                    }
                : null,
            // calculated ordering weight based on modifiers
            modifierWeight: weight,
        };
        const selectors = Array.isArray(option.selector)
            ? option.selector
            : [option.selector];
        return selectors.map(selector => (Object.assign({ selector: (0, shared_1.isMetaSelector)(selector)
                ? enums_1.MetaSelectors[selector]
                : enums_1.Selectors[selector] }, normalizedOption)));
    }
    function parseOptions(context) {
        const normalizedOptions = context.options
            .map(opt => normalizeOption(opt))
            .reduce((acc, val) => acc.concat(val), []);
        return util.getEnumNames(enums_1.Selectors).reduce((acc, k) => {
            acc[k] = (0, validator_1.createValidator)(k, context, normalizedOptions);
            return acc;
        }, {});
    }
    exports.parseOptions = parseOptions;
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/naming-convention-utils/validator.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createValidator = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../../util */);
    const enums_1 = require(1187) /* ./enums */;
    const format_1 = require(1192) /* ./format */;
    const shared_1 = require(1189) /* ./shared */;
    function createValidator(type, context, allConfigs) {
        // make sure the "highest priority" configs are checked first
        const selectorType = enums_1.Selectors[type];
        const configs = allConfigs
            // gather all of the applicable selectors
            .filter(c => (c.selector & selectorType) !== 0 ||
            c.selector === enums_1.MetaSelectors.default)
            .sort((a, b) => {
            if (a.selector === b.selector) {
                // in the event of the same selector, order by modifier weight
                // sort descending - the type modifiers are "more important"
                return b.modifierWeight - a.modifierWeight;
            }
            const aIsMeta = (0, shared_1.isMetaSelector)(a.selector);
            const bIsMeta = (0, shared_1.isMetaSelector)(b.selector);
            // non-meta selectors should go ahead of meta selectors
            if (aIsMeta && !bIsMeta) {
                return 1;
            }
            if (!aIsMeta && bIsMeta) {
                return -1;
            }
            const aIsMethodOrProperty = (0, shared_1.isMethodOrPropertySelector)(a.selector);
            const bIsMethodOrProperty = (0, shared_1.isMethodOrPropertySelector)(b.selector);
            // for backward compatibility, method and property have higher precedence than other meta selectors
            if (aIsMethodOrProperty && !bIsMethodOrProperty) {
                return -1;
            }
            if (!aIsMethodOrProperty && bIsMethodOrProperty) {
                return 1;
            }
            // both aren't meta selectors
            // sort descending - the meta selectors are "least important"
            return b.selector - a.selector;
        });
        return (node, modifiers = new Set()) => {
            var _a, _b, _c;
            const originalName = node.type === utils_1.AST_NODE_TYPES.Identifier ||
                node.type === utils_1.AST_NODE_TYPES.PrivateIdentifier
                ? node.name
                : `${node.value}`;
            // return will break the loop and stop checking configs
            // it is only used when the name is known to have failed or succeeded a config.
            for (const config of configs) {
                if (((_a = config.filter) === null || _a === void 0 ? void 0 : _a.regex.test(originalName)) !== ((_b = config.filter) === null || _b === void 0 ? void 0 : _b.match)) {
                    // name does not match the filter
                    continue;
                }
                if ((_c = config.modifiers) === null || _c === void 0 ? void 0 : _c.some(modifier => !modifiers.has(modifier))) {
                    // does not have the required modifiers
                    continue;
                }
                if (!isCorrectType(node, config, context, selectorType)) {
                    // is not the correct type
                    continue;
                }
                let name = originalName;
                name = validateUnderscore('leading', config, name, node, originalName);
                if (name == null) {
                    // fail
                    return;
                }
                name = validateUnderscore('trailing', config, name, node, originalName);
                if (name == null) {
                    // fail
                    return;
                }
                name = validateAffix('prefix', config, name, node, originalName);
                if (name == null) {
                    // fail
                    return;
                }
                name = validateAffix('suffix', config, name, node, originalName);
                if (name == null) {
                    // fail
                    return;
                }
                if (!validateCustom(config, name, node, originalName)) {
                    // fail
                    return;
                }
                if (!validatePredefinedFormat(config, name, node, originalName, modifiers)) {
                    // fail
                    return;
                }
                // it's valid for this config, so we don't need to check any more configs
                return;
            }
        };
        // centralizes the logic for formatting the report data
        function formatReportData({ affixes, formats, originalName, processedName, position, custom, count, }) {
            var _a;
            return {
                type: (0, shared_1.selectorTypeToMessageString)(type),
                name: originalName,
                processedName,
                position,
                count,
                affixes: affixes === null || affixes === void 0 ? void 0 : affixes.join(', '),
                formats: formats === null || formats === void 0 ? void 0 : formats.map(f => enums_1.PredefinedFormats[f]).join(', '),
                regex: (_a = custom === null || custom === void 0 ? void 0 : custom.regex) === null || _a === void 0 ? void 0 : _a.toString(),
                regexMatch: (custom === null || custom === void 0 ? void 0 : custom.match) === true
                    ? 'match'
                    : (custom === null || custom === void 0 ? void 0 : custom.match) === false
                        ? 'not match'
                        : null,
            };
        }
        /**
         * @returns the name with the underscore removed, if it is valid according to the specified underscore option, null otherwise
         */
        function validateUnderscore(position, config, name, node, originalName) {
            const option = position === 'leading'
                ? config.leadingUnderscore
                : config.trailingUnderscore;
            if (!option) {
                return name;
            }
            const hasSingleUnderscore = position === 'leading'
                ? () => name.startsWith('_')
                : () => name.endsWith('_');
            const trimSingleUnderscore = position === 'leading'
                ? () => name.slice(1)
                : () => name.slice(0, -1);
            const hasDoubleUnderscore = position === 'leading'
                ? () => name.startsWith('__')
                : () => name.endsWith('__');
            const trimDoubleUnderscore = position === 'leading'
                ? () => name.slice(2)
                : () => name.slice(0, -2);
            switch (option) {
                // ALLOW - no conditions as the user doesn't care if it's there or not
                case enums_1.UnderscoreOptions.allow: {
                    if (hasSingleUnderscore()) {
                        return trimSingleUnderscore();
                    }
                    return name;
                }
                case enums_1.UnderscoreOptions.allowDouble: {
                    if (hasDoubleUnderscore()) {
                        return trimDoubleUnderscore();
                    }
                    return name;
                }
                case enums_1.UnderscoreOptions.allowSingleOrDouble: {
                    if (hasDoubleUnderscore()) {
                        return trimDoubleUnderscore();
                    }
                    if (hasSingleUnderscore()) {
                        return trimSingleUnderscore();
                    }
                    return name;
                }
                // FORBID
                case enums_1.UnderscoreOptions.forbid: {
                    if (hasSingleUnderscore()) {
                        context.report({
                            node,
                            messageId: 'unexpectedUnderscore',
                            data: formatReportData({
                                originalName,
                                position,
                                count: 'one',
                            }),
                        });
                        return null;
                    }
                    return name;
                }
                // REQUIRE
                case enums_1.UnderscoreOptions.require: {
                    if (!hasSingleUnderscore()) {
                        context.report({
                            node,
                            messageId: 'missingUnderscore',
                            data: formatReportData({
                                originalName,
                                position,
                                count: 'one',
                            }),
                        });
                        return null;
                    }
                    return trimSingleUnderscore();
                }
                case enums_1.UnderscoreOptions.requireDouble: {
                    if (!hasDoubleUnderscore()) {
                        context.report({
                            node,
                            messageId: 'missingUnderscore',
                            data: formatReportData({
                                originalName,
                                position,
                                count: 'two',
                            }),
                        });
                        return null;
                    }
                    return trimDoubleUnderscore();
                }
            }
        }
        /**
         * @returns the name with the affix removed, if it is valid according to the specified affix option, null otherwise
         */
        function validateAffix(position, config, name, node, originalName) {
            const affixes = config[position];
            if (!affixes || affixes.length === 0) {
                return name;
            }
            for (const affix of affixes) {
                const hasAffix = position === 'prefix' ? name.startsWith(affix) : name.endsWith(affix);
                const trimAffix = position === 'prefix'
                    ? () => name.slice(affix.length)
                    : () => name.slice(0, -affix.length);
                if (hasAffix) {
                    // matches, so trim it and return
                    return trimAffix();
                }
            }
            context.report({
                node,
                messageId: 'missingAffix',
                data: formatReportData({
                    originalName,
                    position,
                    affixes,
                }),
            });
            return null;
        }
        /**
         * @returns true if the name is valid according to the `regex` option, false otherwise
         */
        function validateCustom(config, name, node, originalName) {
            const custom = config.custom;
            if (!custom) {
                return true;
            }
            const result = custom.regex.test(name);
            if (custom.match && result) {
                return true;
            }
            if (!custom.match && !result) {
                return true;
            }
            context.report({
                node,
                messageId: 'satisfyCustom',
                data: formatReportData({
                    originalName,
                    custom,
                }),
            });
            return false;
        }
        /**
         * @returns true if the name is valid according to the `format` option, false otherwise
         */
        function validatePredefinedFormat(config, name, node, originalName, modifiers) {
            const formats = config.format;
            if (!(formats === null || formats === void 0 ? void 0 : formats.length)) {
                return true;
            }
            if (!modifiers.has(enums_1.Modifiers.requiresQuotes)) {
                for (const format of formats) {
                    const checker = format_1.PredefinedFormatToCheckFunction[format];
                    if (checker(name)) {
                        return true;
                    }
                }
            }
            context.report({
                node,
                messageId: originalName === name
                    ? 'doesNotMatchFormat'
                    : 'doesNotMatchFormatTrimmed',
                data: formatReportData({
                    originalName,
                    processedName: name,
                    formats,
                }),
            });
            return false;
        }
    }
    exports.createValidator = createValidator;
    const SelectorsAllowedToHaveTypes = enums_1.Selectors.variable |
        enums_1.Selectors.parameter |
        enums_1.Selectors.classProperty |
        enums_1.Selectors.objectLiteralProperty |
        enums_1.Selectors.typeProperty |
        enums_1.Selectors.parameterProperty |
        enums_1.Selectors.accessor;
    function isCorrectType(node, config, context, selector) {
        if (config.types == null) {
            return true;
        }
        if ((SelectorsAllowedToHaveTypes & selector) === 0) {
            return true;
        }
        const { esTreeNodeToTSNodeMap, program } = util.getParserServices(context);
        const checker = program.getTypeChecker();
        const tsNode = esTreeNodeToTSNodeMap.get(node);
        const type = checker
            .getTypeAtLocation(tsNode)
            // remove null and undefined from the type, as we don't care about it here
            .getNonNullableType();
        for (const allowedType of config.types) {
            switch (allowedType) {
                case enums_1.TypeModifiers.array:
                    if (isAllTypesMatch(type, t => checker.isArrayType(t) || checker.isTupleType(t))) {
                        return true;
                    }
                    break;
                case enums_1.TypeModifiers.function:
                    if (isAllTypesMatch(type, t => t.getCallSignatures().length > 0)) {
                        return true;
                    }
                    break;
                case enums_1.TypeModifiers.boolean:
                case enums_1.TypeModifiers.number:
                case enums_1.TypeModifiers.string: {
                    const typeString = checker.typeToString(
                    // this will resolve things like true => boolean, 'a' => string and 1 => number
                    checker.getWidenedType(checker.getBaseTypeOfLiteralType(type)));
                    const allowedTypeString = enums_1.TypeModifiers[allowedType];
                    if (typeString === allowedTypeString) {
                        return true;
                    }
                    break;
                }
            }
        }
        return false;
    }
    /**
     * @returns `true` if the type (or all union types) in the given type return true for the callback
     */
    function isAllTypesMatch(type, cb) {
        if (type.isUnion()) {
            return type.types.every(t => cb(t));
        }
        return cb(type);
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/naming-convention-utils/format.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.PredefinedFormatToCheckFunction = void 0;
    const enums_1 = require(1187) /* ./enums */;
    /*
    These format functions are taken from `tslint-consistent-codestyle/naming-convention`:
    https://github.com/ajafff/tslint-consistent-codestyle/blob/ab156cc8881bcc401236d999f4ce034b59039e81/rules/namingConventionRule.ts#L603-L645
    
    The license for the code can be viewed here:
    https://github.com/ajafff/tslint-consistent-codestyle/blob/ab156cc8881bcc401236d999f4ce034b59039e81/LICENSE
    */
    /*
    Why not regex here? Because it's actually really, really difficult to create a regex to handle
    all of the unicode cases, and we have many non-english users that use non-english characters.
    https://gist.github.com/mathiasbynens/6334847
    */
    function isPascalCase(name) {
        return (name.length === 0 ||
            (name[0] === name[0].toUpperCase() && !name.includes('_')));
    }
    function isStrictPascalCase(name) {
        return (name.length === 0 ||
            (name[0] === name[0].toUpperCase() && hasStrictCamelHumps(name, true)));
    }
    function isCamelCase(name) {
        return (name.length === 0 ||
            (name[0] === name[0].toLowerCase() && !name.includes('_')));
    }
    function isStrictCamelCase(name) {
        return (name.length === 0 ||
            (name[0] === name[0].toLowerCase() && hasStrictCamelHumps(name, false)));
    }
    function hasStrictCamelHumps(name, isUpper) {
        function isUppercaseChar(char) {
            return char === char.toUpperCase() && char !== char.toLowerCase();
        }
        if (name.startsWith('_')) {
            return false;
        }
        for (let i = 1; i < name.length; ++i) {
            if (name[i] === '_') {
                return false;
            }
            if (isUpper === isUppercaseChar(name[i])) {
                if (isUpper) {
                    return false;
                }
            }
            else {
                isUpper = !isUpper;
            }
        }
        return true;
    }
    function isSnakeCase(name) {
        return (name.length === 0 ||
            (name === name.toLowerCase() && validateUnderscores(name)));
    }
    function isUpperCase(name) {
        return (name.length === 0 ||
            (name === name.toUpperCase() && validateUnderscores(name)));
    }
    /** Check for leading trailing and adjacent underscores */
    function validateUnderscores(name) {
        if (name.startsWith('_')) {
            return false;
        }
        let wasUnderscore = false;
        for (let i = 1; i < name.length; ++i) {
            if (name[i] === '_') {
                if (wasUnderscore) {
                    return false;
                }
                wasUnderscore = true;
            }
            else {
                wasUnderscore = false;
            }
        }
        return !wasUnderscore;
    }
    const PredefinedFormatToCheckFunction = {
        [enums_1.PredefinedFormats.PascalCase]: isPascalCase,
        [enums_1.PredefinedFormats.StrictPascalCase]: isStrictPascalCase,
        [enums_1.PredefinedFormats.camelCase]: isCamelCase,
        [enums_1.PredefinedFormats.strictCamelCase]: isStrictCamelCase,
        [enums_1.PredefinedFormats.UPPER_CASE]: isUpperCase,
        [enums_1.PredefinedFormats.snake_case]: isSnakeCase,
    };
    exports.PredefinedFormatToCheckFunction = PredefinedFormatToCheckFunction;
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-array-constructor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-array-constructor',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow generic `Array` constructors',
                recommended: 'error',
                extendsBaseRule: true,
            },
            fixable: 'code',
            messages: {
                useLiteral: 'The array literal notation [] is preferable.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            /**
             * Disallow construction of dense arrays using the Array constructor
             * @param node node to evaluate
             */
            function check(node) {
                if (node.arguments.length !== 1 &&
                    node.callee.type === utils_1.AST_NODE_TYPES.Identifier &&
                    node.callee.name === 'Array' &&
                    !node.typeParameters &&
                    !util.isOptionalCallExpression(node)) {
                    context.report({
                        node,
                        messageId: 'useLiteral',
                        fix(fixer) {
                            if (node.arguments.length === 0) {
                                return fixer.replaceText(node, '[]');
                            }
                            const fullText = context.getSourceCode().getText(node);
                            const preambleLength = node.callee.range[1] - node.range[0];
                            return fixer.replaceText(node, `[${fullText.slice(preambleLength + 1, -1)}]`);
                        },
                    });
                }
            }
            return {
                CallExpression: check,
                NewExpression: check,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-base-to-string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    var Usefulness;
    (function (Usefulness) {
        Usefulness[Usefulness["Always"] = 0] = "Always";
        Usefulness["Never"] = "will";
        Usefulness["Sometimes"] = "may";
    })(Usefulness || (Usefulness = {}));
    exports.default = util.createRule({
        name: 'no-base-to-string',
        meta: {
            docs: {
                description: 'Require `.toString()` to only be called on objects which provide useful information when stringified',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            messages: {
                baseToString: "'{{name}}' {{certainty}} evaluate to '[object Object]' when stringified.",
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        ignoredTypeNames: {
                            type: 'array',
                            items: {
                                type: 'string',
                            },
                        },
                    },
                    additionalProperties: false,
                },
            ],
            type: 'suggestion',
        },
        defaultOptions: [
            {
                ignoredTypeNames: ['Error', 'RegExp', 'URL', 'URLSearchParams'],
            },
        ],
        create(context, [option]) {
            var _a;
            const parserServices = util.getParserServices(context);
            const typeChecker = parserServices.program.getTypeChecker();
            const ignoredTypeNames = (_a = option.ignoredTypeNames) !== null && _a !== void 0 ? _a : [];
            function checkExpression(node, type) {
                if (node.type === utils_1.AST_NODE_TYPES.Literal) {
                    return;
                }
                const certainty = collectToStringCertainty(type !== null && type !== void 0 ? type : typeChecker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(node)));
                if (certainty === Usefulness.Always) {
                    return;
                }
                context.report({
                    data: {
                        certainty,
                        name: context.getSourceCode().getText(node),
                    },
                    messageId: 'baseToString',
                    node,
                });
            }
            function collectToStringCertainty(type) {
                const toString = typeChecker.getPropertyOfType(type, 'toString');
                const declarations = toString === null || toString === void 0 ? void 0 : toString.getDeclarations();
                if (!toString || !declarations || declarations.length === 0) {
                    return Usefulness.Always;
                }
                // Patch for old version TypeScript, the Boolean type definition missing toString()
                if (type.flags & ts.TypeFlags.Boolean ||
                    type.flags & ts.TypeFlags.BooleanLiteral) {
                    return Usefulness.Always;
                }
                if (ignoredTypeNames.includes(util.getTypeName(typeChecker, type))) {
                    return Usefulness.Always;
                }
                if (declarations.every(({ parent }) => !ts.isInterfaceDeclaration(parent) || parent.name.text !== 'Object')) {
                    return Usefulness.Always;
                }
                if (type.isIntersection()) {
                    for (const subType of type.types) {
                        const subtypeUsefulness = collectToStringCertainty(subType);
                        if (subtypeUsefulness === Usefulness.Always) {
                            return Usefulness.Always;
                        }
                    }
                    return Usefulness.Never;
                }
                if (!type.isUnion()) {
                    return Usefulness.Never;
                }
                let allSubtypesUseful = true;
                let someSubtypeUseful = false;
                for (const subType of type.types) {
                    const subtypeUsefulness = collectToStringCertainty(subType);
                    if (subtypeUsefulness !== Usefulness.Always && allSubtypesUseful) {
                        allSubtypesUseful = false;
                    }
                    if (subtypeUsefulness !== Usefulness.Never && !someSubtypeUseful) {
                        someSubtypeUseful = true;
                    }
                }
                if (allSubtypesUseful && someSubtypeUseful) {
                    return Usefulness.Always;
                }
                if (someSubtypeUseful) {
                    return Usefulness.Sometimes;
                }
                return Usefulness.Never;
            }
            return {
                'AssignmentExpression[operator = "+="], BinaryExpression[operator = "+"]'(node) {
                    const leftType = typeChecker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(node.left));
                    const rightType = typeChecker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(node.right));
                    if (util.getTypeName(typeChecker, leftType) === 'string') {
                        checkExpression(node.right, rightType);
                    }
                    else if (util.getTypeName(typeChecker, rightType) === 'string' &&
                        node.left.type !== utils_1.AST_NODE_TYPES.PrivateIdentifier) {
                        checkExpression(node.left, leftType);
                    }
                },
                'CallExpression > MemberExpression.callee > Identifier[name = "toString"].property'(node) {
                    const memberExpr = node.parent;
                    checkExpression(memberExpr.object);
                },
                TemplateLiteral(node) {
                    if (node.parent &&
                        node.parent.type === utils_1.AST_NODE_TYPES.TaggedTemplateExpression) {
                        return;
                    }
                    for (const expression of node.expressions) {
                        checkExpression(expression);
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-confusing-non-null-assertion.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-confusing-non-null-assertion',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow non-null assertion in locations that may be confusing',
                recommended: 'strict',
            },
            fixable: 'code',
            hasSuggestions: true,
            messages: {
                confusingEqual: 'Confusing combinations of non-null assertion and equal test like "a! == b", which looks very similar to not equal "a !== b".',
                confusingAssign: 'Confusing combinations of non-null assertion and equal test like "a! = b", which looks very similar to not equal "a != b".',
                notNeedInEqualTest: 'Unnecessary non-null assertion (!) in equal test.',
                notNeedInAssign: 'Unnecessary non-null assertion (!) in assignment left hand.',
                wrapUpLeft: 'Wrap up left hand to avoid putting non-null assertion "!" and "=" together.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                'BinaryExpression, AssignmentExpression'(node) {
                    function isLeftHandPrimaryExpression(node) {
                        return node.type === utils_1.AST_NODE_TYPES.TSNonNullExpression;
                    }
                    if (node.operator === '==' ||
                        node.operator === '===' ||
                        node.operator === '=') {
                        const isAssign = node.operator === '=';
                        const leftHandFinalToken = sourceCode.getLastToken(node.left);
                        const tokenAfterLeft = sourceCode.getTokenAfter(node.left);
                        if ((leftHandFinalToken === null || leftHandFinalToken === void 0 ? void 0 : leftHandFinalToken.type) === utils_1.AST_TOKEN_TYPES.Punctuator &&
                            (leftHandFinalToken === null || leftHandFinalToken === void 0 ? void 0 : leftHandFinalToken.value) === '!' &&
                            (tokenAfterLeft === null || tokenAfterLeft === void 0 ? void 0 : tokenAfterLeft.value) !== ')') {
                            if (isLeftHandPrimaryExpression(node.left)) {
                                context.report({
                                    node,
                                    messageId: isAssign ? 'confusingAssign' : 'confusingEqual',
                                    suggest: [
                                        {
                                            messageId: isAssign
                                                ? 'notNeedInAssign'
                                                : 'notNeedInEqualTest',
                                            fix: (fixer) => [
                                                fixer.remove(leftHandFinalToken),
                                            ],
                                        },
                                    ],
                                });
                            }
                            else {
                                context.report({
                                    node,
                                    messageId: isAssign ? 'confusingAssign' : 'confusingEqual',
                                    suggest: [
                                        {
                                            messageId: 'wrapUpLeft',
                                            fix: (fixer) => [
                                                fixer.insertTextBefore(node.left, '('),
                                                fixer.insertTextAfter(node.left, ')'),
                                            ],
                                        },
                                    ],
                                });
                            }
                        }
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-confusing-void-expression.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-confusing-void-expression',
        meta: {
            docs: {
                description: 'Require expressions of type void to appear in statement position',
                recommended: false,
                requiresTypeChecking: true,
            },
            messages: {
                invalidVoidExpr: 'Placing a void expression inside another expression is forbidden. ' +
                    'Move it to its own statement instead.',
                invalidVoidExprWrapVoid: 'Void expressions used inside another expression ' +
                    'must be moved to its own statement ' +
                    'or marked explicitly with the `void` operator.',
                invalidVoidExprArrow: 'Returning a void expression from an arrow function shorthand is forbidden. ' +
                    'Please add braces to the arrow function.',
                invalidVoidExprArrowWrapVoid: 'Void expressions returned from an arrow function shorthand ' +
                    'must be marked explicitly with the `void` operator.',
                invalidVoidExprReturn: 'Returning a void expression from a function is forbidden. ' +
                    'Please move it before the `return` statement.',
                invalidVoidExprReturnLast: 'Returning a void expression from a function is forbidden. ' +
                    'Please remove the `return` statement.',
                invalidVoidExprReturnWrapVoid: 'Void expressions returned from a function ' +
                    'must be marked explicitly with the `void` operator.',
                voidExprWrapVoid: 'Mark with an explicit `void` operator.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        ignoreArrowShorthand: { type: 'boolean' },
                        ignoreVoidOperator: { type: 'boolean' },
                    },
                    additionalProperties: false,
                },
            ],
            type: 'problem',
            fixable: 'code',
            hasSuggestions: true,
        },
        defaultOptions: [{}],
        create(context, [options]) {
            return {
                'AwaitExpression, CallExpression, TaggedTemplateExpression'(node) {
                    const parserServices = util.getParserServices(context);
                    const checker = parserServices.program.getTypeChecker();
                    const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                    const type = util.getConstrainedTypeAtLocation(checker, tsNode);
                    if (!tsutils.isTypeFlagSet(type, ts.TypeFlags.VoidLike)) {
                        // not a void expression
                        return;
                    }
                    const invalidAncestor = findInvalidAncestor(node);
                    if (invalidAncestor == null) {
                        // void expression is in valid position
                        return;
                    }
                    const sourceCode = context.getSourceCode();
                    const wrapVoidFix = (fixer) => {
                        const nodeText = sourceCode.getText(node);
                        const newNodeText = `void ${nodeText}`;
                        return fixer.replaceText(node, newNodeText);
                    };
                    if (invalidAncestor.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression) {
                        // handle arrow function shorthand
                        if (options.ignoreVoidOperator) {
                            // handle wrapping with `void`
                            return context.report({
                                node,
                                messageId: 'invalidVoidExprArrowWrapVoid',
                                fix: wrapVoidFix,
                            });
                        }
                        // handle wrapping with braces
                        const arrowFunction = invalidAncestor;
                        return context.report({
                            node,
                            messageId: 'invalidVoidExprArrow',
                            fix(fixer) {
                                const arrowBody = arrowFunction.body;
                                const arrowBodyText = sourceCode.getText(arrowBody);
                                const newArrowBodyText = `{ ${arrowBodyText}; }`;
                                if (util.isParenthesized(arrowBody, sourceCode)) {
                                    const bodyOpeningParen = sourceCode.getTokenBefore(arrowBody, util.isOpeningParenToken);
                                    const bodyClosingParen = sourceCode.getTokenAfter(arrowBody, util.isClosingParenToken);
                                    return fixer.replaceTextRange([bodyOpeningParen.range[0], bodyClosingParen.range[1]], newArrowBodyText);
                                }
                                return fixer.replaceText(arrowBody, newArrowBodyText);
                            },
                        });
                    }
                    if (invalidAncestor.type === utils_1.AST_NODE_TYPES.ReturnStatement) {
                        // handle return statement
                        if (options.ignoreVoidOperator) {
                            // handle wrapping with `void`
                            return context.report({
                                node,
                                messageId: 'invalidVoidExprReturnWrapVoid',
                                fix: wrapVoidFix,
                            });
                        }
                        const returnStmt = invalidAncestor;
                        if (isFinalReturn(returnStmt)) {
                            // remove the `return` keyword
                            return context.report({
                                node,
                                messageId: 'invalidVoidExprReturnLast',
                                fix(fixer) {
                                    const returnValue = returnStmt.argument;
                                    const returnValueText = sourceCode.getText(returnValue);
                                    let newReturnStmtText = `${returnValueText};`;
                                    if (isPreventingASI(returnValue, sourceCode)) {
                                        // put a semicolon at the beginning of the line
                                        newReturnStmtText = `;${newReturnStmtText}`;
                                    }
                                    return fixer.replaceText(returnStmt, newReturnStmtText);
                                },
                            });
                        }
                        // move before the `return` keyword
                        return context.report({
                            node,
                            messageId: 'invalidVoidExprReturn',
                            fix(fixer) {
                                var _a;
                                const returnValue = returnStmt.argument;
                                const returnValueText = sourceCode.getText(returnValue);
                                let newReturnStmtText = `${returnValueText}; return;`;
                                if (isPreventingASI(returnValue, sourceCode)) {
                                    // put a semicolon at the beginning of the line
                                    newReturnStmtText = `;${newReturnStmtText}`;
                                }
                                if (((_a = returnStmt.parent) === null || _a === void 0 ? void 0 : _a.type) !== utils_1.AST_NODE_TYPES.BlockStatement) {
                                    // e.g. `if (cond) return console.error();`
                                    // add braces if not inside a block
                                    newReturnStmtText = `{ ${newReturnStmtText} }`;
                                }
                                return fixer.replaceText(returnStmt, newReturnStmtText);
                            },
                        });
                    }
                    // handle generic case
                    if (options.ignoreVoidOperator) {
                        // this would be reported by this rule btw. such irony
                        return context.report({
                            node,
                            messageId: 'invalidVoidExprWrapVoid',
                            suggest: [{ messageId: 'voidExprWrapVoid', fix: wrapVoidFix }],
                        });
                    }
                    context.report({
                        node,
                        messageId: 'invalidVoidExpr',
                    });
                },
            };
            /**
             * Inspects the void expression's ancestors and finds closest invalid one.
             * By default anything other than an ExpressionStatement is invalid.
             * Parent expressions which can be used for their short-circuiting behavior
             * are ignored and their parents are checked instead.
             * @param node The void expression node to check.
             * @returns Invalid ancestor node if it was found. `null` otherwise.
             */
            function findInvalidAncestor(node) {
                const parent = util.nullThrows(node.parent, util.NullThrowsReasons.MissingParent);
                if (parent.type === utils_1.AST_NODE_TYPES.SequenceExpression) {
                    if (node !== parent.expressions[parent.expressions.length - 1]) {
                        return null;
                    }
                }
                if (parent.type === utils_1.AST_NODE_TYPES.ExpressionStatement) {
                    // e.g. `{ console.log("foo"); }`
                    // this is always valid
                    return null;
                }
                if (parent.type === utils_1.AST_NODE_TYPES.LogicalExpression) {
                    if (parent.right === node) {
                        // e.g. `x && console.log(x)`
                        // this is valid only if the next ancestor is valid
                        return findInvalidAncestor(parent);
                    }
                }
                if (parent.type === utils_1.AST_NODE_TYPES.ConditionalExpression) {
                    if (parent.consequent === node || parent.alternate === node) {
                        // e.g. `cond ? console.log(true) : console.log(false)`
                        // this is valid only if the next ancestor is valid
                        return findInvalidAncestor(parent);
                    }
                }
                if (parent.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression) {
                    // e.g. `() => console.log("foo")`
                    // this is valid with an appropriate option
                    if (options.ignoreArrowShorthand) {
                        return null;
                    }
                }
                if (parent.type === utils_1.AST_NODE_TYPES.UnaryExpression) {
                    if (parent.operator === 'void') {
                        // e.g. `void console.log("foo")`
                        // this is valid with an appropriate option
                        if (options.ignoreVoidOperator) {
                            return null;
                        }
                    }
                }
                if (parent.type === utils_1.AST_NODE_TYPES.ChainExpression) {
                    // e.g. `console?.log('foo')`
                    return findInvalidAncestor(parent);
                }
                // any other parent is invalid
                return parent;
            }
            /** Checks whether the return statement is the last statement in a function body. */
            function isFinalReturn(node) {
                // the parent must be a block
                const block = util.nullThrows(node.parent, util.NullThrowsReasons.MissingParent);
                if (block.type !== utils_1.AST_NODE_TYPES.BlockStatement) {
                    // e.g. `if (cond) return;` (not in a block)
                    return false;
                }
                // the block's parent must be a function
                const blockParent = util.nullThrows(block.parent, util.NullThrowsReasons.MissingParent);
                if (![
                    utils_1.AST_NODE_TYPES.FunctionDeclaration,
                    utils_1.AST_NODE_TYPES.FunctionExpression,
                    utils_1.AST_NODE_TYPES.ArrowFunctionExpression,
                ].includes(blockParent.type)) {
                    // e.g. `if (cond) { return; }`
                    // not in a top-level function block
                    return false;
                }
                // must be the last child of the block
                if (block.body.indexOf(node) < block.body.length - 1) {
                    // not the last statement in the block
                    return false;
                }
                return true;
            }
            /**
             * Checks whether the given node, if placed on its own line,
             * would prevent automatic semicolon insertion on the line before.
             *
             * This happens if the line begins with `(`, `[` or `` ` ``
             */
            function isPreventingASI(node, sourceCode) {
                const startToken = util.nullThrows(sourceCode.getFirstToken(node), util.NullThrowsReasons.MissingToken('first token', node.type));
                return ['(', '[', '`'].includes(startToken.value);
            }
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-dupe-class-members.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-dupe-class-members');
    exports.default = util.createRule({
        name: 'no-dupe-class-members',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow duplicate class members',
                recommended: false,
                extendsBaseRule: true,
            },
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            messages: baseRule.meta.messages,
        },
        defaultOptions: [],
        create(context) {
            const rules = baseRule.create(context);
            function wrapMemberDefinitionListener(coreListener) {
                return (node) => {
                    if (node.computed) {
                        return;
                    }
                    if (node.value &&
                        node.value.type === utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression) {
                        return;
                    }
                    return coreListener(node);
                };
            }
            return Object.assign(Object.assign(Object.assign({}, rules), (rules.MethodDefinition
                ? {
                    MethodDefinition: wrapMemberDefinitionListener(rules.MethodDefinition),
                }
                : {})), (rules['MethodDefinition, PropertyDefinition']
                ? {
                    'MethodDefinition, PropertyDefinition': wrapMemberDefinitionListener(rules['MethodDefinition, PropertyDefinition']),
                }
                : {}));
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-duplicate-enum-values.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-duplicate-enum-values',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow duplicate enum member values',
                recommended: 'strict',
            },
            hasSuggestions: false,
            messages: {
                duplicateValue: 'Duplicate enum member value {{value}}.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            function isStringLiteral(node) {
                return (node.type === utils_1.AST_NODE_TYPES.Literal && typeof node.value === 'string');
            }
            function isNumberLiteral(node) {
                return (node.type === utils_1.AST_NODE_TYPES.Literal && typeof node.value === 'number');
            }
            return {
                TSEnumDeclaration(node) {
                    const enumMembers = node.members;
                    const seenValues = new Set();
                    enumMembers.forEach(member => {
                        if (member.initializer === undefined) {
                            return;
                        }
                        let value;
                        if (isStringLiteral(member.initializer)) {
                            value = String(member.initializer.value);
                        }
                        else if (isNumberLiteral(member.initializer)) {
                            value = Number(member.initializer.value);
                        }
                        if (value === undefined) {
                            return;
                        }
                        if (seenValues.has(value)) {
                            context.report({
                                node: member,
                                messageId: 'duplicateValue',
                                data: {
                                    value,
                                },
                            });
                        }
                        else {
                            seenValues.add(value);
                        }
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-duplicate-imports.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-duplicate-imports');
    exports.default = util.createRule({
        name: 'no-duplicate-imports',
        meta: {
            deprecated: true,
            replacedBy: ['import/no-duplicates'],
            type: 'problem',
            docs: {
                description: 'Disallow duplicate imports',
                recommended: false,
                extendsBaseRule: true,
            },
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            messages: Object.assign(Object.assign({}, baseRule.meta.messages), { importType: '{{module}} type import is duplicated.', importTypeAs: '{{module}} type import is duplicated as type export.', exportType: '{{module}} type export is duplicated.', exportTypeAs: '{{module}} type export is duplicated as type import.' }),
        },
        defaultOptions: [
            {
                includeExports: false,
            },
        ],
        create(context, [{ includeExports }]) {
            const rules = baseRule.create(context);
            const typeMemberImports = new Set();
            const typeDefaultImports = new Set();
            const typeExports = new Set();
            function report(messageId, node, module) {
                context.report({
                    messageId,
                    node,
                    data: {
                        module,
                    },
                });
            }
            function isAllMemberImport(node) {
                return node.specifiers.every(specifier => specifier.type === utils_1.AST_NODE_TYPES.ImportSpecifier);
            }
            function checkTypeImport(node) {
                if (node.source) {
                    const value = node.source.value;
                    const isMemberImport = isAllMemberImport(node);
                    if (isMemberImport
                        ? typeMemberImports.has(value)
                        : typeDefaultImports.has(value)) {
                        report('importType', node, value);
                    }
                    if (includeExports && typeExports.has(value)) {
                        report('importTypeAs', node, value);
                    }
                    if (isMemberImport) {
                        typeMemberImports.add(value);
                    }
                    else {
                        typeDefaultImports.add(value);
                    }
                }
            }
            function checkTypeExport(node) {
                if (node.source) {
                    const value = node.source.value;
                    if (typeExports.has(value)) {
                        report('exportType', node, value);
                    }
                    if (typeMemberImports.has(value) || typeDefaultImports.has(value)) {
                        report('exportTypeAs', node, value);
                    }
                    typeExports.add(value);
                }
            }
            return Object.assign(Object.assign({}, rules), { ImportDeclaration(node) {
                    if (node.importKind === 'type') {
                        checkTypeImport(node);
                        return;
                    }
                    rules.ImportDeclaration(node);
                },
                ExportNamedDeclaration(node) {
                    var _a;
                    if (includeExports && node.exportKind === 'type') {
                        checkTypeExport(node);
                        return;
                    }
                    (_a = rules.ExportNamedDeclaration) === null || _a === void 0 ? void 0 : _a.call(rules, node);
                },
                ExportAllDeclaration(node) {
                    var _a;
                    if (includeExports && node.exportKind === 'type') {
                        checkTypeExport(node);
                        return;
                    }
                    (_a = rules.ExportAllDeclaration) === null || _a === void 0 ? void 0 : _a.call(rules, node);
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-dynamic-delete.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-dynamic-delete',
        meta: {
            docs: {
                description: 'Disallow using the `delete` operator on computed key expressions',
                recommended: 'strict',
            },
            fixable: 'code',
            messages: {
                dynamicDelete: 'Do not delete dynamically computed property keys.',
            },
            schema: [],
            type: 'suggestion',
        },
        defaultOptions: [],
        create(context) {
            function createFixer(member) {
                if (member.property.type === utils_1.AST_NODE_TYPES.Literal &&
                    typeof member.property.value === 'string') {
                    return createPropertyReplacement(member.property, `.${member.property.value}`);
                }
                return undefined;
            }
            return {
                'UnaryExpression[operator=delete]'(node) {
                    if (node.argument.type !== utils_1.AST_NODE_TYPES.MemberExpression ||
                        !node.argument.computed ||
                        isNecessaryDynamicAccess(diveIntoWrapperExpressions(node.argument.property))) {
                        return;
                    }
                    context.report({
                        fix: createFixer(node.argument),
                        messageId: 'dynamicDelete',
                        node: node.argument.property,
                    });
                },
            };
            function createPropertyReplacement(property, replacement) {
                return (fixer) => fixer.replaceTextRange(getTokenRange(property), replacement);
            }
            function getTokenRange(property) {
                const sourceCode = context.getSourceCode();
                return [
                    sourceCode.getTokenBefore(property).range[0],
                    sourceCode.getTokenAfter(property).range[1],
                ];
            }
        },
    });
    function diveIntoWrapperExpressions(node) {
        if (node.type === utils_1.AST_NODE_TYPES.UnaryExpression) {
            return diveIntoWrapperExpressions(node.argument);
        }
        return node;
    }
    function isNecessaryDynamicAccess(property) {
        if (property.type !== utils_1.AST_NODE_TYPES.Literal) {
            return false;
        }
        if (typeof property.value === 'number') {
            return true;
        }
        return (typeof property.value === 'string' &&
            !tsutils.isValidPropertyAccess(property.value));
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-empty-function.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-empty-function');
    const schema = util.deepMerge(
    // eslint-disable-next-line @typescript-eslint/no-unsafe-argument -- https://github.com/microsoft/TypeScript/issues/17002
    Array.isArray(baseRule.meta.schema)
        ? baseRule.meta.schema[0]
        : baseRule.meta.schema, {
        properties: {
            allow: {
                items: {
                    enum: [
                        'functions',
                        'arrowFunctions',
                        'generatorFunctions',
                        'methods',
                        'generatorMethods',
                        'getters',
                        'setters',
                        'constructors',
                        'private-constructors',
                        'protected-constructors',
                        'asyncFunctions',
                        'asyncMethods',
                        'decoratedFunctions',
                        'overrideMethods',
                    ],
                },
            },
        },
    });
    exports.default = util.createRule({
        name: 'no-empty-function',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow empty functions',
                recommended: 'error',
                extendsBaseRule: true,
            },
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: [schema],
            messages: baseRule.meta.messages,
        },
        defaultOptions: [
            {
                allow: [],
            },
        ],
        create(context, [{ allow = [] }]) {
            const rules = baseRule.create(context);
            const isAllowedProtectedConstructors = allow.includes('protected-constructors');
            const isAllowedPrivateConstructors = allow.includes('private-constructors');
            const isAllowedDecoratedFunctions = allow.includes('decoratedFunctions');
            const isAllowedOverrideMethods = allow.includes('overrideMethods');
            /**
             * Check if the method body is empty
             * @param node the node to be validated
             * @returns true if the body is empty
             * @private
             */
            function isBodyEmpty(node) {
                return !node.body || node.body.body.length === 0;
            }
            /**
             * Check if method has parameter properties
             * @param node the node to be validated
             * @returns true if the body has parameter properties
             * @private
             */
            function hasParameterProperties(node) {
                var _a;
                return (_a = node.params) === null || _a === void 0 ? void 0 : _a.some(param => param.type === utils_1.AST_NODE_TYPES.TSParameterProperty);
            }
            /**
             * @param node the node to be validated
             * @returns true if the constructor is allowed to be empty
             * @private
             */
            function isAllowedEmptyConstructor(node) {
                const parent = node.parent;
                if (isBodyEmpty(node) &&
                    (parent === null || parent === void 0 ? void 0 : parent.type) === utils_1.AST_NODE_TYPES.MethodDefinition &&
                    parent.kind === 'constructor') {
                    const { accessibility } = parent;
                    return (
                    // allow protected constructors
                    (accessibility === 'protected' && isAllowedProtectedConstructors) ||
                        // allow private constructors
                        (accessibility === 'private' && isAllowedPrivateConstructors) ||
                        // allow constructors which have parameter properties
                        hasParameterProperties(node));
                }
                return false;
            }
            /**
             * @param node the node to be validated
             * @returns true if a function has decorators
             * @private
             */
            function isAllowedEmptyDecoratedFunctions(node) {
                var _a;
                if (isAllowedDecoratedFunctions && isBodyEmpty(node)) {
                    const decorators = ((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.MethodDefinition
                        ? node.parent.decorators
                        : undefined;
                    return !!decorators && !!decorators.length;
                }
                return false;
            }
            function isAllowedEmptyOverrideMethod(node) {
                var _a;
                return (isAllowedOverrideMethods &&
                    isBodyEmpty(node) &&
                    ((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.MethodDefinition &&
                    node.parent.override === true);
            }
            return Object.assign(Object.assign({}, rules), { FunctionExpression(node) {
                    if (isAllowedEmptyConstructor(node) ||
                        isAllowedEmptyDecoratedFunctions(node) ||
                        isAllowedEmptyOverrideMethod(node)) {
                        return;
                    }
                    rules.FunctionExpression(node);
                },
                FunctionDeclaration(node) {
                    if (isAllowedEmptyDecoratedFunctions(node)) {
                        return;
                    }
                    rules.FunctionDeclaration(node);
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-empty-interface.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-empty-interface',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow the declaration of empty interfaces',
                recommended: 'error',
            },
            fixable: 'code',
            hasSuggestions: true,
            messages: {
                noEmpty: 'An empty interface is equivalent to `{}`.',
                noEmptyWithSuper: 'An interface declaring no members is equivalent to its supertype.',
            },
            schema: [
                {
                    type: 'object',
                    additionalProperties: false,
                    properties: {
                        allowSingleExtends: {
                            type: 'boolean',
                        },
                    },
                },
            ],
        },
        defaultOptions: [
            {
                allowSingleExtends: false,
            },
        ],
        create(context, [{ allowSingleExtends }]) {
            return {
                TSInterfaceDeclaration(node) {
                    var _a, _b;
                    const sourceCode = context.getSourceCode();
                    const filename = context.getFilename();
                    if (node.body.body.length !== 0) {
                        // interface contains members --> Nothing to report
                        return;
                    }
                    const extend = node.extends;
                    if (!extend || extend.length === 0) {
                        context.report({
                            node: node.id,
                            messageId: 'noEmpty',
                        });
                    }
                    else if (extend.length === 1) {
                        // interface extends exactly 1 interface --> Report depending on rule setting
                        if (!allowSingleExtends) {
                            const fix = (fixer) => {
                                let typeParam = '';
                                if (node.typeParameters) {
                                    typeParam = sourceCode.getText(node.typeParameters);
                                }
                                return fixer.replaceText(node, `type ${sourceCode.getText(node.id)}${typeParam} = ${sourceCode.getText(extend[0])}`);
                            };
                            const scope = context.getScope();
                            const mergedWithClassDeclaration = (_b = (_a = scope.set
                                .get(node.id.name)) === null || _a === void 0 ? void 0 : _a.defs) === null || _b === void 0 ? void 0 : _b.some(def => def.node.type === utils_1.AST_NODE_TYPES.ClassDeclaration);
                            const isInAmbientDeclaration = !!(util.isDefinitionFile(filename) &&
                                scope.type === 'tsModule' &&
                                scope.block.declare);
                            const useAutoFix = !(isInAmbientDeclaration || mergedWithClassDeclaration);
                            context.report(Object.assign({ node: node.id, messageId: 'noEmptyWithSuper' }, (useAutoFix
                                ? { fix }
                                : !mergedWithClassDeclaration
                                    ? {
                                        suggest: [
                                            {
                                                messageId: 'noEmptyWithSuper',
                                                fix,
                                            },
                                        ],
                                    }
                                    : null)));
                        }
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-explicit-any.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-explicit-any',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow the `any` type',
                recommended: 'warn',
            },
            fixable: 'code',
            hasSuggestions: true,
            messages: {
                unexpectedAny: 'Unexpected any. Specify a different type.',
                suggestUnknown: 'Use `unknown` instead, this will force you to explicitly, and safely assert the type is correct.',
                suggestNever: "Use `never` instead, this is useful when instantiating generic type parameters that you don't need to know the type of.",
            },
            schema: [
                {
                    type: 'object',
                    additionalProperties: false,
                    properties: {
                        fixToUnknown: {
                            description: 'Whether to enable auto-fixing in which the `any` type is converted to the `unknown` type.',
                            type: 'boolean',
                        },
                        ignoreRestArgs: {
                            description: 'Whether to ignore rest parameter arrays.',
                            type: 'boolean',
                        },
                    },
                },
            ],
        },
        defaultOptions: [
            {
                fixToUnknown: false,
                ignoreRestArgs: false,
            },
        ],
        create(context, [{ ignoreRestArgs, fixToUnknown }]) {
            /**
             * Checks if the node is an arrow function, function/constructor declaration or function expression
             * @param node the node to be validated.
             * @returns true if the node is any kind of function declaration or expression
             * @private
             */
            function isNodeValidFunction(node) {
                return [
                    utils_1.AST_NODE_TYPES.ArrowFunctionExpression,
                    utils_1.AST_NODE_TYPES.FunctionDeclaration,
                    utils_1.AST_NODE_TYPES.FunctionExpression,
                    utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression,
                    utils_1.AST_NODE_TYPES.TSFunctionType,
                    utils_1.AST_NODE_TYPES.TSConstructorType,
                    utils_1.AST_NODE_TYPES.TSCallSignatureDeclaration,
                    utils_1.AST_NODE_TYPES.TSConstructSignatureDeclaration,
                    utils_1.AST_NODE_TYPES.TSMethodSignature,
                    utils_1.AST_NODE_TYPES.TSDeclareFunction, // declare function _8(...args: any[]): unknown;
                ].includes(node.type);
            }
            /**
             * Checks if the node is a rest element child node of a function
             * @param node the node to be validated.
             * @returns true if the node is a rest element child node of a function
             * @private
             */
            function isNodeRestElementInFunction(node) {
                return (node.type === utils_1.AST_NODE_TYPES.RestElement &&
                    node.parent !== undefined &&
                    isNodeValidFunction(node.parent));
            }
            /**
             * Checks if the node is a TSTypeOperator node with a readonly operator
             * @param node the node to be validated.
             * @returns true if the node is a TSTypeOperator node with a readonly operator
             * @private
             */
            function isNodeReadonlyTSTypeOperator(node) {
                return (node.type === utils_1.AST_NODE_TYPES.TSTypeOperator &&
                    node.operator === 'readonly');
            }
            /**
             * Checks if the node is a TSTypeReference node with an Array identifier
             * @param node the node to be validated.
             * @returns true if the node is a TSTypeReference node with an Array identifier
             * @private
             */
            function isNodeValidArrayTSTypeReference(node) {
                return (node.type === utils_1.AST_NODE_TYPES.TSTypeReference &&
                    node.typeName !== undefined &&
                    node.typeName.type === utils_1.AST_NODE_TYPES.Identifier &&
                    ['Array', 'ReadonlyArray'].includes(node.typeName.name));
            }
            /**
             * Checks if the node is a valid TSTypeOperator or TSTypeReference node
             * @param node the node to be validated.
             * @returns true if the node is a valid TSTypeOperator or TSTypeReference node
             * @private
             */
            function isNodeValidTSType(node) {
                return (isNodeReadonlyTSTypeOperator(node) ||
                    isNodeValidArrayTSTypeReference(node));
            }
            /**
             * Checks if the great grand-parent node is a RestElement node in a function
             * @param node the node to be validated.
             * @returns true if the great grand-parent node is a RestElement node in a function
             * @private
             */
            function isGreatGrandparentRestElement(node) {
                var _a, _b;
                return (((_b = (_a = node === null || node === void 0 ? void 0 : node.parent) === null || _a === void 0 ? void 0 : _a.parent) === null || _b === void 0 ? void 0 : _b.parent) != null &&
                    isNodeRestElementInFunction(node.parent.parent.parent));
            }
            /**
             * Checks if the great great grand-parent node is a valid RestElement node in a function
             * @param node the node to be validated.
             * @returns true if the great great grand-parent node is a valid RestElement node in a function
             * @private
             */
            function isGreatGreatGrandparentRestElement(node) {
                var _a, _b, _c;
                return (((_c = (_b = (_a = node.parent) === null || _a === void 0 ? void 0 : _a.parent) === null || _b === void 0 ? void 0 : _b.parent) === null || _c === void 0 ? void 0 : _c.parent) != null &&
                    isNodeValidTSType(node.parent.parent) &&
                    isNodeRestElementInFunction(node.parent.parent.parent.parent));
            }
            /**
             * Checks if the great grand-parent or the great great grand-parent node is a RestElement node
             * @param node the node to be validated.
             * @returns true if the great grand-parent or the great great grand-parent node is a RestElement node
             * @private
             */
            function isNodeDescendantOfRestElementInFunction(node) {
                return (isGreatGrandparentRestElement(node) ||
                    isGreatGreatGrandparentRestElement(node));
            }
            return {
                TSAnyKeyword(node) {
                    if (ignoreRestArgs && isNodeDescendantOfRestElementInFunction(node)) {
                        return;
                    }
                    const fixOrSuggest = {
                        fix: null,
                        suggest: [
                            {
                                messageId: 'suggestUnknown',
                                fix(fixer) {
                                    return fixer.replaceText(node, 'unknown');
                                },
                            },
                            {
                                messageId: 'suggestNever',
                                fix(fixer) {
                                    return fixer.replaceText(node, 'never');
                                },
                            },
                        ],
                    };
                    if (fixToUnknown) {
                        fixOrSuggest.fix = (fixer) => fixer.replaceText(node, 'unknown');
                    }
                    context.report(Object.assign({ node, messageId: 'unexpectedAny' }, fixOrSuggest));
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-extra-non-null-assertion.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-extra-non-null-assertion',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow extra non-null assertions',
                recommended: 'error',
            },
            fixable: 'code',
            schema: [],
            messages: {
                noExtraNonNullAssertion: 'Forbidden extra non-null assertion.',
            },
        },
        defaultOptions: [],
        create(context) {
            function checkExtraNonNullAssertion(node) {
                context.report({
                    node,
                    messageId: 'noExtraNonNullAssertion',
                    fix(fixer) {
                        return fixer.removeRange([node.range[1] - 1, node.range[1]]);
                    },
                });
            }
            return {
                'TSNonNullExpression > TSNonNullExpression': checkExtraNonNullAssertion,
                'MemberExpression[optional = true] > TSNonNullExpression.object': checkExtraNonNullAssertion,
                'CallExpression[optional = true] > TSNonNullExpression.callee': checkExtraNonNullAssertion,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-extra-parens.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // any is required to work around manipulating the AST in weird ways
    /* eslint-disable @typescript-eslint/no-explicit-any, @typescript-eslint/no-unsafe-assignment */
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-extra-parens');
    exports.default = util.createRule({
        name: 'no-extra-parens',
        meta: {
            type: 'layout',
            docs: {
                description: 'Disallow unnecessary parentheses',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'code',
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            messages: baseRule.meta.messages,
        },
        defaultOptions: ['all'],
        create(context) {
            const rules = baseRule.create(context);
            function binaryExp(node) {
                const rule = rules.BinaryExpression;
                // makes the rule think it should skip the left or right
                const isLeftTypeAssertion = util.isTypeAssertion(node.left);
                const isRightTypeAssertion = util.isTypeAssertion(node.right);
                if (isLeftTypeAssertion && isRightTypeAssertion) {
                    return; // ignore
                }
                if (isLeftTypeAssertion) {
                    return rule(Object.assign(Object.assign({}, node), { left: Object.assign(Object.assign({}, node.left), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                }
                if (isRightTypeAssertion) {
                    return rule(Object.assign(Object.assign({}, node), { right: Object.assign(Object.assign({}, node.right), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                }
                return rule(node);
            }
            function callExp(node) {
                var _a;
                const rule = rules.CallExpression;
                if (util.isTypeAssertion(node.callee)) {
                    // reduces the precedence of the node so the rule thinks it needs to be wrapped
                    return rule(Object.assign(Object.assign({}, node), { callee: Object.assign(Object.assign({}, node.callee), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                }
                if (node.arguments.length === 1 &&
                    ((_a = node.typeParameters) === null || _a === void 0 ? void 0 : _a.params.some(param => param.type === utils_1.AST_NODE_TYPES.TSImportType ||
                        param.type === utils_1.AST_NODE_TYPES.TSArrayType))) {
                    return rule(Object.assign(Object.assign({}, node), { arguments: [
                            Object.assign(Object.assign({}, node.arguments[0]), { type: utils_1.AST_NODE_TYPES.SequenceExpression }),
                        ] }));
                }
                return rule(node);
            }
            function unaryUpdateExpression(node) {
                const rule = rules.UnaryExpression;
                if (util.isTypeAssertion(node.argument)) {
                    // reduces the precedence of the node so the rule thinks it needs to be wrapped
                    return rule(Object.assign(Object.assign({}, node), { argument: Object.assign(Object.assign({}, node.argument), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                }
                return rule(node);
            }
            const overrides = {
                // ArrayExpression
                ArrowFunctionExpression(node) {
                    if (!util.isTypeAssertion(node.body)) {
                        return rules.ArrowFunctionExpression(node);
                    }
                },
                // AssignmentExpression
                AwaitExpression(node) {
                    if (util.isTypeAssertion(node.argument)) {
                        // reduces the precedence of the node so the rule thinks it needs to be wrapped
                        return rules.AwaitExpression(Object.assign(Object.assign({}, node), { argument: Object.assign(Object.assign({}, node.argument), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                    }
                    return rules.AwaitExpression(node);
                },
                BinaryExpression: binaryExp,
                CallExpression: callExp,
                ClassDeclaration(node) {
                    var _a;
                    if (((_a = node.superClass) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.TSAsExpression) {
                        return rules.ClassDeclaration(Object.assign(Object.assign({}, node), { superClass: Object.assign(Object.assign({}, node.superClass), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                    }
                    return rules.ClassDeclaration(node);
                },
                ClassExpression(node) {
                    var _a;
                    if (((_a = node.superClass) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.TSAsExpression) {
                        return rules.ClassExpression(Object.assign(Object.assign({}, node), { superClass: Object.assign(Object.assign({}, node.superClass), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                    }
                    return rules.ClassExpression(node);
                },
                ConditionalExpression(node) {
                    // reduces the precedence of the node so the rule thinks it needs to be wrapped
                    if (util.isTypeAssertion(node.test)) {
                        return rules.ConditionalExpression(Object.assign(Object.assign({}, node), { test: Object.assign(Object.assign({}, node.test), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                    }
                    if (util.isTypeAssertion(node.consequent)) {
                        return rules.ConditionalExpression(Object.assign(Object.assign({}, node), { consequent: Object.assign(Object.assign({}, node.consequent), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                    }
                    if (util.isTypeAssertion(node.alternate)) {
                        // reduces the precedence of the node so the rule thinks it needs to be wrapped
                        return rules.ConditionalExpression(Object.assign(Object.assign({}, node), { alternate: Object.assign(Object.assign({}, node.alternate), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                    }
                    return rules.ConditionalExpression(node);
                },
                // DoWhileStatement
                // ForIn and ForOf are guarded by eslint version
                ForStatement(node) {
                    // make the rule skip the piece by removing it entirely
                    if (node.init && util.isTypeAssertion(node.init)) {
                        return rules.ForStatement(Object.assign(Object.assign({}, node), { init: null }));
                    }
                    if (node.test && util.isTypeAssertion(node.test)) {
                        return rules.ForStatement(Object.assign(Object.assign({}, node), { test: null }));
                    }
                    if (node.update && util.isTypeAssertion(node.update)) {
                        return rules.ForStatement(Object.assign(Object.assign({}, node), { update: null }));
                    }
                    return rules.ForStatement(node);
                },
                'ForStatement > *.init:exit'(node) {
                    if (!util.isTypeAssertion(node)) {
                        return rules['ForStatement > *.init:exit'](node);
                    }
                },
                // IfStatement
                LogicalExpression: binaryExp,
                MemberExpression(node) {
                    if (util.isTypeAssertion(node.object)) {
                        // reduces the precedence of the node so the rule thinks it needs to be wrapped
                        return rules.MemberExpression(Object.assign(Object.assign({}, node), { object: Object.assign(Object.assign({}, node.object), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                    }
                    return rules.MemberExpression(node);
                },
                NewExpression: callExp,
                // ObjectExpression
                // ReturnStatement
                // SequenceExpression
                SpreadElement(node) {
                    if (!util.isTypeAssertion(node.argument)) {
                        return rules.SpreadElement(node);
                    }
                },
                SwitchCase(node) {
                    if (node.test && !util.isTypeAssertion(node.test)) {
                        return rules.SwitchCase(node);
                    }
                },
                // SwitchStatement
                ThrowStatement(node) {
                    if (node.argument && !util.isTypeAssertion(node.argument)) {
                        return rules.ThrowStatement(node);
                    }
                },
                UnaryExpression: unaryUpdateExpression,
                UpdateExpression: unaryUpdateExpression,
                // VariableDeclarator
                // WhileStatement
                // WithStatement - i'm not going to even bother implementing this terrible and never used feature
                YieldExpression(node) {
                    if (node.argument && !util.isTypeAssertion(node.argument)) {
                        return rules.YieldExpression(node);
                    }
                },
            };
            if (rules.ForInStatement && rules.ForOfStatement) {
                overrides.ForInStatement = function (node) {
                    if (util.isTypeAssertion(node.right)) {
                        // as of 7.20.0 there's no way to skip checking the right of the ForIn
                        // so just don't validate it at all
                        return;
                    }
                    return rules.ForInStatement(node);
                };
                overrides.ForOfStatement = function (node) {
                    if (util.isTypeAssertion(node.right)) {
                        // makes the rule skip checking of the right
                        return rules.ForOfStatement(Object.assign(Object.assign({}, node), { type: utils_1.AST_NODE_TYPES.ForOfStatement, right: Object.assign(Object.assign({}, node.right), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                    }
                    return rules.ForOfStatement(node);
                };
            }
            else {
                overrides['ForInStatement, ForOfStatement'] = function (node) {
                    if (util.isTypeAssertion(node.right)) {
                        // makes the rule skip checking of the right
                        return rules['ForInStatement, ForOfStatement'](Object.assign(Object.assign({}, node), { type: utils_1.AST_NODE_TYPES.ForOfStatement, right: Object.assign(Object.assign({}, node.right), { type: utils_1.AST_NODE_TYPES.SequenceExpression }) }));
                    }
                    return rules['ForInStatement, ForOfStatement'](node);
                };
            }
            return Object.assign({}, rules, overrides);
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-extra-semi.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-extra-semi');
    exports.default = util.createRule({
        name: 'no-extra-semi',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow unnecessary semicolons',
                recommended: 'error',
                extendsBaseRule: true,
            },
            fixable: 'code',
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            messages: baseRule.meta.messages,
        },
        defaultOptions: [],
        create(context) {
            const rules = baseRule.create(context);
            return Object.assign(Object.assign({}, rules), { 'TSAbstractMethodDefinition, TSAbstractPropertyDefinition'(node) {
                    var _a;
                    if (rules.MethodDefinition) {
                        // for ESLint <= v7
                        rules.MethodDefinition(node);
                    }
                    else if (rules['MethodDefinition, PropertyDefinition']) {
                        // for ESLint >= v8 < v8.3.0
                        rules['MethodDefinition, PropertyDefinition'](node);
                    }
                    else {
                        // for ESLint >= v8.3.0
                        (_a = rules['MethodDefinition, PropertyDefinition, StaticBlock']) === null || _a === void 0 ? void 0 : _a.call(rules, node);
                    }
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-extraneous-class.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-extraneous-class',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow classes used as namespaces',
                recommended: 'strict',
            },
            schema: [
                {
                    type: 'object',
                    additionalProperties: false,
                    properties: {
                        allowConstructorOnly: {
                            description: 'Whether to allow extraneous classes that contain only a constructor.',
                            type: 'boolean',
                        },
                        allowEmpty: {
                            description: 'Whether to allow extraneous classes that have no body (i.e. are empty).',
                            type: 'boolean',
                        },
                        allowStaticOnly: {
                            description: 'Whether to allow extraneous classes that only contain static members.',
                            type: 'boolean',
                        },
                        allowWithDecorator: {
                            description: 'Whether to allow extraneous classes that include a decorator.',
                            type: 'boolean',
                        },
                    },
                },
            ],
            messages: {
                empty: 'Unexpected empty class.',
                onlyStatic: 'Unexpected class with only static properties.',
                onlyConstructor: 'Unexpected class with only a constructor.',
            },
        },
        defaultOptions: [
            {
                allowConstructorOnly: false,
                allowEmpty: false,
                allowStaticOnly: false,
                allowWithDecorator: false,
            },
        ],
        create(context, [{ allowConstructorOnly, allowEmpty, allowStaticOnly, allowWithDecorator }]) {
            const isAllowWithDecorator = (node) => {
                return !!(allowWithDecorator &&
                    node &&
                    node.decorators &&
                    node.decorators.length);
            };
            return {
                ClassBody(node) {
                    const parent = node.parent;
                    if (!parent || parent.superClass || isAllowWithDecorator(parent)) {
                        return;
                    }
                    const reportNode = 'id' in parent && parent.id ? parent.id : parent;
                    if (node.body.length === 0) {
                        if (allowEmpty) {
                            return;
                        }
                        context.report({
                            node: reportNode,
                            messageId: 'empty',
                        });
                        return;
                    }
                    let onlyStatic = true;
                    let onlyConstructor = true;
                    for (const prop of node.body) {
                        if ('kind' in prop && prop.kind === 'constructor') {
                            if (prop.value.params.some(param => param.type === utils_1.AST_NODE_TYPES.TSParameterProperty)) {
                                onlyConstructor = false;
                                onlyStatic = false;
                            }
                        }
                        else {
                            onlyConstructor = false;
                            if ('static' in prop && !prop.static) {
                                onlyStatic = false;
                            }
                        }
                        if (!(onlyStatic || onlyConstructor)) {
                            break;
                        }
                    }
                    if (onlyConstructor) {
                        if (!allowConstructorOnly) {
                            context.report({
                                node: reportNode,
                                messageId: 'onlyConstructor',
                            });
                        }
                        return;
                    }
                    if (onlyStatic && !allowStaticOnly) {
                        context.report({
                            node: reportNode,
                            messageId: 'onlyStatic',
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-floating-promises.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    exports.default = util.createRule({
        name: 'no-floating-promises',
        meta: {
            docs: {
                description: 'Require Promise-like statements to be handled appropriately',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            hasSuggestions: true,
            messages: {
                floating: 'Promises must be awaited, end with a call to .catch, or end with a call to .then with a rejection handler.',
                floatingFixAwait: 'Add await operator.',
                floatingVoid: 'Promises must be awaited, end with a call to .catch, end with a call to .then with a rejection handler' +
                    ' or be explicitly marked as ignored with the `void` operator.',
                floatingFixVoid: 'Add void operator to ignore.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        ignoreVoid: {
                            description: 'Whether to ignore `void` expressions.',
                            type: 'boolean',
                        },
                        ignoreIIFE: {
                            description: 'Whether to ignore async IIFEs (Immediately Invocated Function Expressions).',
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
            type: 'problem',
        },
        defaultOptions: [
            {
                ignoreVoid: true,
                ignoreIIFE: false,
            },
        ],
        create(context, [options]) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            return {
                ExpressionStatement(node) {
                    if (options.ignoreIIFE && isAsyncIife(node)) {
                        return;
                    }
                    let expression = node.expression;
                    if (expression.type === utils_1.AST_NODE_TYPES.ChainExpression) {
                        expression = expression.expression;
                    }
                    if (isUnhandledPromise(checker, expression)) {
                        if (options.ignoreVoid) {
                            context.report({
                                node,
                                messageId: 'floatingVoid',
                                suggest: [
                                    {
                                        messageId: 'floatingFixVoid',
                                        fix(fixer) {
                                            const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node.expression);
                                            if (isHigherPrecedenceThanUnary(tsNode)) {
                                                return fixer.insertTextBefore(node, 'void ');
                                            }
                                            else {
                                                return [
                                                    fixer.insertTextBefore(node, 'void ('),
                                                    fixer.insertTextAfterRange([expression.range[1], expression.range[1]], ')'),
                                                ];
                                            }
                                        },
                                    },
                                ],
                            });
                        }
                        else {
                            context.report({
                                node,
                                messageId: 'floating',
                                suggest: [
                                    {
                                        messageId: 'floatingFixAwait',
                                        fix(fixer) {
                                            if (expression.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                                                expression.operator === 'void') {
                                                return fixer.replaceTextRange([expression.range[0], expression.range[0] + 4], 'await');
                                            }
                                            const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node.expression);
                                            if (isHigherPrecedenceThanUnary(tsNode)) {
                                                return fixer.insertTextBefore(node, 'await ');
                                            }
                                            else {
                                                return [
                                                    fixer.insertTextBefore(node, 'await ('),
                                                    fixer.insertTextAfterRange([expression.range[1], expression.range[1]], ')'),
                                                ];
                                            }
                                        },
                                    },
                                ],
                            });
                        }
                    }
                },
            };
            function isHigherPrecedenceThanUnary(node) {
                const operator = tsutils.isBinaryExpression(node)
                    ? node.operatorToken.kind
                    : ts.SyntaxKind.Unknown;
                const nodePrecedence = util.getOperatorPrecedence(node.kind, operator);
                return nodePrecedence > util_1.OperatorPrecedence.Unary;
            }
            function isAsyncIife(node) {
                if (node.expression.type !== utils_1.AST_NODE_TYPES.CallExpression) {
                    return false;
                }
                return (node.expression.type === utils_1.AST_NODE_TYPES.CallExpression &&
                    (node.expression.callee.type ===
                        utils_1.AST_NODE_TYPES.ArrowFunctionExpression ||
                        node.expression.callee.type === utils_1.AST_NODE_TYPES.FunctionExpression));
            }
            function isUnhandledPromise(checker, node) {
                // First, check expressions whose resulting types may not be promise-like
                if (node.type === utils_1.AST_NODE_TYPES.SequenceExpression) {
                    // Any child in a comma expression could return a potentially unhandled
                    // promise, so we check them all regardless of whether the final returned
                    // value is promise-like.
                    return node.expressions.some(item => isUnhandledPromise(checker, item));
                }
                if (!options.ignoreVoid &&
                    node.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                    node.operator === 'void') {
                    // Similarly, a `void` expression always returns undefined, so we need to
                    // see what's inside it without checking the type of the overall expression.
                    return isUnhandledPromise(checker, node.argument);
                }
                // Check the type. At this point it can't be unhandled if it isn't a promise
                if (!isPromiseLike(checker, parserServices.esTreeNodeToTSNodeMap.get(node))) {
                    return false;
                }
                if (node.type === utils_1.AST_NODE_TYPES.CallExpression) {
                    // If the outer expression is a call, it must be either a `.then()` or
                    // `.catch()` that handles the promise.
                    return (!isPromiseCatchCallWithHandler(node) &&
                        !isPromiseThenCallWithRejectionHandler(node) &&
                        !isPromiseFinallyCallWithHandler(node));
                }
                else if (node.type === utils_1.AST_NODE_TYPES.ConditionalExpression) {
                    // We must be getting the promise-like value from one of the branches of the
                    // ternary. Check them directly.
                    return (isUnhandledPromise(checker, node.alternate) ||
                        isUnhandledPromise(checker, node.consequent));
                }
                else if (node.type === utils_1.AST_NODE_TYPES.MemberExpression ||
                    node.type === utils_1.AST_NODE_TYPES.Identifier ||
                    node.type === utils_1.AST_NODE_TYPES.NewExpression) {
                    // If it is just a property access chain or a `new` call (e.g. `foo.bar` or
                    // `new Promise()`), the promise is not handled because it doesn't have the
                    // necessary then/catch call at the end of the chain.
                    return true;
                }
                else if (node.type === utils_1.AST_NODE_TYPES.LogicalExpression) {
                    return (isUnhandledPromise(checker, node.left) ||
                        isUnhandledPromise(checker, node.right));
                }
                // We conservatively return false for all other types of expressions because
                // we don't want to accidentally fail if the promise is handled internally but
                // we just can't tell.
                return false;
            }
        },
    });
    // Modified from tsutils.isThenable() to only consider thenables which can be
    // rejected/caught via a second parameter. Original source (MIT licensed):
    //
    //   https://github.com/ajafff/tsutils/blob/49d0d31050b44b81e918eae4fbaf1dfe7b7286af/util/type.ts#L95-L125
    function isPromiseLike(checker, node) {
        const type = checker.getTypeAtLocation(node);
        for (const ty of tsutils.unionTypeParts(checker.getApparentType(type))) {
            const then = ty.getProperty('then');
            if (then === undefined) {
                continue;
            }
            const thenType = checker.getTypeOfSymbolAtLocation(then, node);
            if (hasMatchingSignature(thenType, signature => signature.parameters.length >= 2 &&
                isFunctionParam(checker, signature.parameters[0], node) &&
                isFunctionParam(checker, signature.parameters[1], node))) {
                return true;
            }
        }
        return false;
    }
    function hasMatchingSignature(type, matcher) {
        for (const t of tsutils.unionTypeParts(type)) {
            if (t.getCallSignatures().some(matcher)) {
                return true;
            }
        }
        return false;
    }
    function isFunctionParam(checker, param, node) {
        const type = checker.getApparentType(checker.getTypeOfSymbolAtLocation(param, node));
        for (const t of tsutils.unionTypeParts(type)) {
            if (t.getCallSignatures().length !== 0) {
                return true;
            }
        }
        return false;
    }
    function isPromiseCatchCallWithHandler(expression) {
        return (expression.callee.type === utils_1.AST_NODE_TYPES.MemberExpression &&
            expression.callee.property.type === utils_1.AST_NODE_TYPES.Identifier &&
            expression.callee.property.name === 'catch' &&
            expression.arguments.length >= 1);
    }
    function isPromiseThenCallWithRejectionHandler(expression) {
        return (expression.callee.type === utils_1.AST_NODE_TYPES.MemberExpression &&
            expression.callee.property.type === utils_1.AST_NODE_TYPES.Identifier &&
            expression.callee.property.name === 'then' &&
            expression.arguments.length >= 2);
    }
    function isPromiseFinallyCallWithHandler(expression) {
        return (expression.callee.type === utils_1.AST_NODE_TYPES.MemberExpression &&
            expression.callee.property.type === utils_1.AST_NODE_TYPES.Identifier &&
            expression.callee.property.name === 'finally' &&
            expression.arguments.length >= 1);
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-for-in-array.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-for-in-array',
        meta: {
            docs: {
                description: 'Disallow iterating over an array with a for-in loop',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                forInViolation: 'For-in loops over arrays are forbidden. Use for-of or array.forEach instead.',
            },
            schema: [],
            type: 'problem',
        },
        defaultOptions: [],
        create(context) {
            return {
                ForInStatement(node) {
                    const parserServices = util.getParserServices(context);
                    const checker = parserServices.program.getTypeChecker();
                    const originalNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                    const type = util.getConstrainedTypeAtLocation(checker, originalNode.expression);
                    if (util.isTypeArrayTypeOrUnionOfArrayTypes(type, checker) ||
                        (type.flags & ts.TypeFlags.StringLike) !== 0) {
                        context.report({
                            node,
                            messageId: 'forInViolation',
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-implicit-any-catch.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-implicit-any-catch',
        meta: {
            deprecated: true,
            type: 'suggestion',
            docs: {
                description: 'Disallow usage of the implicit `any` type in catch clauses',
                recommended: false,
            },
            fixable: 'code',
            hasSuggestions: true,
            messages: {
                implicitAnyInCatch: 'Implicit any in catch clause.',
                explicitAnyInCatch: 'Explicit any in catch clause.',
                suggestExplicitUnknown: 'Use `unknown` instead, this will force you to explicitly, and safely assert the type is correct.',
            },
            schema: [
                {
                    type: 'object',
                    additionalProperties: false,
                    properties: {
                        allowExplicitAny: {
                            description: 'Whether to disallow specifying `: any` as the error type as well. See also `no-explicit-any`.',
                            type: 'boolean',
                        },
                    },
                },
            ],
        },
        defaultOptions: [
            {
                allowExplicitAny: false,
            },
        ],
        create(context, [{ allowExplicitAny }]) {
            return {
                CatchClause(node) {
                    if (!node.param) {
                        return; // ignore catch without variable
                    }
                    if (!node.param.typeAnnotation) {
                        context.report({
                            node,
                            messageId: 'implicitAnyInCatch',
                            suggest: [
                                {
                                    messageId: 'suggestExplicitUnknown',
                                    fix(fixer) {
                                        return fixer.insertTextAfter(node.param, ': unknown');
                                    },
                                },
                            ],
                        });
                    }
                    else if (!allowExplicitAny &&
                        node.param.typeAnnotation.typeAnnotation.type ===
                            utils_1.AST_NODE_TYPES.TSAnyKeyword) {
                        context.report({
                            node,
                            messageId: 'explicitAnyInCatch',
                            suggest: [
                                {
                                    messageId: 'suggestExplicitUnknown',
                                    fix(fixer) {
                                        return fixer.replaceText(node.param.typeAnnotation, ': unknown');
                                    },
                                },
                            ],
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-implied-eval.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    const FUNCTION_CONSTRUCTOR = 'Function';
    const GLOBAL_CANDIDATES = new Set(['global', 'window', 'globalThis']);
    const EVAL_LIKE_METHODS = new Set([
        'setImmediate',
        'setInterval',
        'setTimeout',
        'execScript',
    ]);
    exports.default = util.createRule({
        name: 'no-implied-eval',
        meta: {
            docs: {
                description: 'Disallow the use of `eval()`-like methods',
                recommended: 'error',
                extendsBaseRule: true,
                requiresTypeChecking: true,
            },
            messages: {
                noImpliedEvalError: 'Implied eval. Consider passing a function.',
                noFunctionConstructor: 'Implied eval. Do not use the Function constructor to create functions.',
            },
            schema: [],
            type: 'suggestion',
        },
        defaultOptions: [],
        create(context) {
            const parserServices = util.getParserServices(context);
            const program = parserServices.program;
            const checker = parserServices.program.getTypeChecker();
            function getCalleeName(node) {
                if (node.type === utils_1.AST_NODE_TYPES.Identifier) {
                    return node.name;
                }
                if (node.type === utils_1.AST_NODE_TYPES.MemberExpression &&
                    node.object.type === utils_1.AST_NODE_TYPES.Identifier &&
                    GLOBAL_CANDIDATES.has(node.object.name)) {
                    if (node.property.type === utils_1.AST_NODE_TYPES.Identifier) {
                        return node.property.name;
                    }
                    if (node.property.type === utils_1.AST_NODE_TYPES.Literal &&
                        typeof node.property.value === 'string') {
                        return node.property.value;
                    }
                }
                return null;
            }
            function isFunctionType(node) {
                var _a;
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                const type = checker.getTypeAtLocation(tsNode);
                const symbol = type.getSymbol();
                if (symbol &&
                    tsutils.isSymbolFlagSet(symbol, ts.SymbolFlags.Function | ts.SymbolFlags.Method)) {
                    return true;
                }
                if (symbol && symbol.escapedName === FUNCTION_CONSTRUCTOR) {
                    const declarations = (_a = symbol.getDeclarations()) !== null && _a !== void 0 ? _a : [];
                    for (const declaration of declarations) {
                        const sourceFile = declaration.getSourceFile();
                        if (program.isSourceFileDefaultLibrary(sourceFile)) {
                            return true;
                        }
                    }
                }
                const signatures = checker.getSignaturesOfType(type, ts.SignatureKind.Call);
                return signatures.length > 0;
            }
            function isBind(node) {
                return node.type === utils_1.AST_NODE_TYPES.MemberExpression
                    ? isBind(node.property)
                    : node.type === utils_1.AST_NODE_TYPES.Identifier && node.name === 'bind';
            }
            function isFunction(node) {
                switch (node.type) {
                    case utils_1.AST_NODE_TYPES.ArrowFunctionExpression:
                    case utils_1.AST_NODE_TYPES.FunctionDeclaration:
                    case utils_1.AST_NODE_TYPES.FunctionExpression:
                        return true;
                    case utils_1.AST_NODE_TYPES.Literal:
                    case utils_1.AST_NODE_TYPES.TemplateLiteral:
                        return false;
                    case utils_1.AST_NODE_TYPES.CallExpression:
                        return isBind(node.callee) || isFunctionType(node);
                    default:
                        return isFunctionType(node);
                }
            }
            function isReferenceToGlobalFunction(calleeName) {
                const ref = context
                    .getScope()
                    .references.find(ref => ref.identifier.name === calleeName);
                // ensure it's the "global" version
                return !(ref === null || ref === void 0 ? void 0 : ref.resolved) || ref.resolved.defs.length === 0;
            }
            function checkImpliedEval(node) {
                var _a;
                const calleeName = getCalleeName(node.callee);
                if (calleeName == null) {
                    return;
                }
                if (calleeName === FUNCTION_CONSTRUCTOR) {
                    const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node.callee);
                    const type = checker.getTypeAtLocation(tsNode);
                    const symbol = type.getSymbol();
                    if (symbol) {
                        const declarations = (_a = symbol.getDeclarations()) !== null && _a !== void 0 ? _a : [];
                        for (const declaration of declarations) {
                            const sourceFile = declaration.getSourceFile();
                            if (program.isSourceFileDefaultLibrary(sourceFile)) {
                                context.report({ node, messageId: 'noFunctionConstructor' });
                                return;
                            }
                        }
                    }
                    else {
                        context.report({ node, messageId: 'noFunctionConstructor' });
                        return;
                    }
                }
                if (node.arguments.length === 0) {
                    return;
                }
                const [handler] = node.arguments;
                if (EVAL_LIKE_METHODS.has(calleeName) &&
                    !isFunction(handler) &&
                    isReferenceToGlobalFunction(calleeName)) {
                    context.report({ node: handler, messageId: 'noImpliedEvalError' });
                }
            }
            return {
                NewExpression: checkImpliedEval,
                CallExpression: checkImpliedEval,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-import-type-side-effects.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-import-type-side-effects',
        meta: {
            type: 'problem',
            docs: {
                description: 'Enforce the use of top-level import type qualifier when an import only has specifiers with inline type qualifiers',
                recommended: false,
            },
            fixable: 'code',
            messages: {
                useTopLevelQualifier: 'TypeScript will only remove the inline type specifiers which will leave behind a side effect import at runtime. Convert this to a top-level type qualifier to properly remove the entire import.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                'ImportDeclaration[importKind!="type"]'(node) {
                    if (node.specifiers.length === 0) {
                        return;
                    }
                    const specifiers = [];
                    for (const specifier of node.specifiers) {
                        if (specifier.type !== utils_1.AST_NODE_TYPES.ImportSpecifier ||
                            specifier.importKind !== 'type') {
                            return;
                        }
                        specifiers.push(specifier);
                    }
                    context.report({
                        node,
                        messageId: 'useTopLevelQualifier',
                        fix(fixer) {
                            const fixes = [];
                            for (const specifier of specifiers) {
                                const qualifier = util.nullThrows(sourceCode.getFirstToken(specifier, util.isTypeKeyword), util.NullThrowsReasons.MissingToken('type keyword', 'import specifier'));
                                fixes.push(fixer.removeRange([
                                    qualifier.range[0],
                                    specifier.imported.range[0],
                                ]));
                            }
                            const importKeyword = util.nullThrows(sourceCode.getFirstToken(node, util.isImportKeyword), util.NullThrowsReasons.MissingToken('import keyword', 'import'));
                            fixes.push(fixer.insertTextAfter(importKeyword, ' type'));
                            return fixes;
                        },
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-inferrable-types.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-inferrable-types',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow explicit type declarations for variables or parameters initialized to a number, string, or boolean',
                recommended: 'error',
            },
            fixable: 'code',
            messages: {
                noInferrableType: 'Type {{type}} trivially inferred from a {{type}} literal, remove type annotation.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        ignoreParameters: {
                            type: 'boolean',
                        },
                        ignoreProperties: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                ignoreParameters: false,
                ignoreProperties: false,
            },
        ],
        create(context, [{ ignoreParameters, ignoreProperties }]) {
            const sourceCode = context.getSourceCode();
            function isFunctionCall(init, callName) {
                if (init.type === utils_1.AST_NODE_TYPES.ChainExpression) {
                    return isFunctionCall(init.expression, callName);
                }
                return (init.type === utils_1.AST_NODE_TYPES.CallExpression &&
                    init.callee.type === utils_1.AST_NODE_TYPES.Identifier &&
                    init.callee.name === callName);
            }
            function isLiteral(init, typeName) {
                return (init.type === utils_1.AST_NODE_TYPES.Literal && typeof init.value === typeName);
            }
            function isIdentifier(init, ...names) {
                return (init.type === utils_1.AST_NODE_TYPES.Identifier && names.includes(init.name));
            }
            function hasUnaryPrefix(init, ...operators) {
                return (init.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                    operators.includes(init.operator));
            }
            const keywordMap = {
                [utils_1.AST_NODE_TYPES.TSBigIntKeyword]: 'bigint',
                [utils_1.AST_NODE_TYPES.TSBooleanKeyword]: 'boolean',
                [utils_1.AST_NODE_TYPES.TSNumberKeyword]: 'number',
                [utils_1.AST_NODE_TYPES.TSNullKeyword]: 'null',
                [utils_1.AST_NODE_TYPES.TSStringKeyword]: 'string',
                [utils_1.AST_NODE_TYPES.TSSymbolKeyword]: 'symbol',
                [utils_1.AST_NODE_TYPES.TSUndefinedKeyword]: 'undefined',
            };
            /**
             * Returns whether a node has an inferrable value or not
             */
            function isInferrable(annotation, init) {
                switch (annotation.type) {
                    case utils_1.AST_NODE_TYPES.TSBigIntKeyword: {
                        // note that bigint cannot have + prefixed to it
                        const unwrappedInit = hasUnaryPrefix(init, '-')
                            ? init.argument
                            : init;
                        return (isFunctionCall(unwrappedInit, 'BigInt') ||
                            (unwrappedInit.type === utils_1.AST_NODE_TYPES.Literal &&
                                'bigint' in unwrappedInit));
                    }
                    case utils_1.AST_NODE_TYPES.TSBooleanKeyword:
                        return (hasUnaryPrefix(init, '!') ||
                            isFunctionCall(init, 'Boolean') ||
                            isLiteral(init, 'boolean'));
                    case utils_1.AST_NODE_TYPES.TSNumberKeyword: {
                        const unwrappedInit = hasUnaryPrefix(init, '+', '-')
                            ? init.argument
                            : init;
                        return (isIdentifier(unwrappedInit, 'Infinity', 'NaN') ||
                            isFunctionCall(unwrappedInit, 'Number') ||
                            isLiteral(unwrappedInit, 'number'));
                    }
                    case utils_1.AST_NODE_TYPES.TSNullKeyword:
                        return init.type === utils_1.AST_NODE_TYPES.Literal && init.value == null;
                    case utils_1.AST_NODE_TYPES.TSStringKeyword:
                        return (isFunctionCall(init, 'String') ||
                            isLiteral(init, 'string') ||
                            init.type === utils_1.AST_NODE_TYPES.TemplateLiteral);
                    case utils_1.AST_NODE_TYPES.TSSymbolKeyword:
                        return isFunctionCall(init, 'Symbol');
                    case utils_1.AST_NODE_TYPES.TSTypeReference: {
                        if (annotation.typeName.type === utils_1.AST_NODE_TYPES.Identifier &&
                            annotation.typeName.name === 'RegExp') {
                            const isRegExpLiteral = init.type === utils_1.AST_NODE_TYPES.Literal &&
                                init.value instanceof RegExp;
                            const isRegExpNewCall = init.type === utils_1.AST_NODE_TYPES.NewExpression &&
                                init.callee.type === utils_1.AST_NODE_TYPES.Identifier &&
                                init.callee.name === 'RegExp';
                            const isRegExpCall = isFunctionCall(init, 'RegExp');
                            return isRegExpLiteral || isRegExpCall || isRegExpNewCall;
                        }
                        return false;
                    }
                    case utils_1.AST_NODE_TYPES.TSUndefinedKeyword:
                        return (hasUnaryPrefix(init, 'void') || isIdentifier(init, 'undefined'));
                }
                return false;
            }
            /**
             * Reports an inferrable type declaration, if any
             */
            function reportInferrableType(node, typeNode, initNode) {
                if (!typeNode || !initNode || !typeNode.typeAnnotation) {
                    return;
                }
                if (!isInferrable(typeNode.typeAnnotation, initNode)) {
                    return;
                }
                const type = typeNode.typeAnnotation.type === utils_1.AST_NODE_TYPES.TSTypeReference
                    ? // TODO - if we add more references
                        'RegExp'
                    : keywordMap[typeNode.typeAnnotation.type];
                context.report({
                    node,
                    messageId: 'noInferrableType',
                    data: {
                        type,
                    },
                    *fix(fixer) {
                        if ((node.type === utils_1.AST_NODE_TYPES.AssignmentPattern &&
                            node.left.optional) ||
                            (node.type === utils_1.AST_NODE_TYPES.PropertyDefinition && node.definite)) {
                            yield fixer.remove(sourceCode.getTokenBefore(typeNode));
                        }
                        yield fixer.remove(typeNode);
                    },
                });
            }
            function inferrableVariableVisitor(node) {
                if (!node.id) {
                    return;
                }
                reportInferrableType(node, node.id.typeAnnotation, node.init);
            }
            function inferrableParameterVisitor(node) {
                if (ignoreParameters || !node.params) {
                    return;
                }
                node.params.filter(param => param.type === utils_1.AST_NODE_TYPES.AssignmentPattern &&
                    param.left &&
                    param.right).forEach(param => {
                    reportInferrableType(param, param.left.typeAnnotation, param.right);
                });
            }
            function inferrablePropertyVisitor(node) {
                // We ignore `readonly` because of Microsoft/TypeScript#14416
                // Essentially a readonly property without a type
                // will result in its value being the type, leading to
                // compile errors if the type is stripped.
                if (ignoreProperties || node.readonly || node.optional) {
                    return;
                }
                reportInferrableType(node, node.typeAnnotation, node.value);
            }
            return {
                VariableDeclarator: inferrableVariableVisitor,
                FunctionExpression: inferrableParameterVisitor,
                FunctionDeclaration: inferrableParameterVisitor,
                ArrowFunctionExpression: inferrableParameterVisitor,
                PropertyDefinition: inferrablePropertyVisitor,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-invalid-this.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var _a;
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util_1 = require(1018) /* ../util */;
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-invalid-this');
    exports.default = (0, util_1.createRule)({
        name: 'no-invalid-this',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow `this` keywords outside of classes or class-like objects',
                recommended: false,
                extendsBaseRule: true,
            },
            // TODO: this rule has only had messages since v7.0 - remove this when we remove support for v6
            messages: (_a = baseRule.meta.messages) !== null && _a !== void 0 ? _a : {
                unexpectedThis: "Unexpected 'this'.",
            },
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
        },
        defaultOptions: [{ capIsConstructor: true }],
        create(context) {
            const rules = baseRule.create(context);
            /**
             * Since function definitions can be nested we use a stack storing if "this" is valid in the current context.
             *
             * Example:
             *
             * function a(this: number) { // valid "this"
             *     function b() {
             *         console.log(this); // invalid "this"
             *     }
             * }
             *
             * When parsing the function declaration of "a" the stack will be: [true]
             * When parsing the function declaration of "b" the stack will be: [true, false]
             */
            const thisIsValidStack = [];
            return Object.assign(Object.assign({}, rules), { PropertyDefinition() {
                    thisIsValidStack.push(true);
                },
                'PropertyDefinition:exit'() {
                    thisIsValidStack.pop();
                },
                FunctionDeclaration(node) {
                    var _a;
                    thisIsValidStack.push(node.params.some(param => param.type === utils_1.AST_NODE_TYPES.Identifier && param.name === 'this'));
                    // baseRule's work
                    (_a = rules.FunctionDeclaration) === null || _a === void 0 ? void 0 : _a.call(rules, node);
                },
                'FunctionDeclaration:exit'(node) {
                    var _a;
                    thisIsValidStack.pop();
                    // baseRule's work
                    (_a = rules['FunctionDeclaration:exit']) === null || _a === void 0 ? void 0 : _a.call(rules, node);
                },
                FunctionExpression(node) {
                    var _a;
                    thisIsValidStack.push(node.params.some(param => param.type === utils_1.AST_NODE_TYPES.Identifier && param.name === 'this'));
                    // baseRule's work
                    (_a = rules.FunctionExpression) === null || _a === void 0 ? void 0 : _a.call(rules, node);
                },
                'FunctionExpression:exit'(node) {
                    var _a;
                    thisIsValidStack.pop();
                    // baseRule's work
                    (_a = rules['FunctionExpression:exit']) === null || _a === void 0 ? void 0 : _a.call(rules, node);
                },
                ThisExpression(node) {
                    const thisIsValidHere = thisIsValidStack[thisIsValidStack.length - 1];
                    if (thisIsValidHere) {
                        return;
                    }
                    // baseRule's work
                    rules.ThisExpression(node);
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-invalid-void-type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-invalid-void-type',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow `void` type outside of generic or return types',
                recommended: 'strict',
            },
            messages: {
                invalidVoidForGeneric: '{{ generic }} may not have void as a type argument.',
                invalidVoidNotReturnOrGeneric: 'void is only valid as a return type or generic type argument.',
                invalidVoidNotReturn: 'void is only valid as a return type.',
                invalidVoidNotReturnOrThisParam: 'void is only valid as return type or type of `this` parameter.',
                invalidVoidNotReturnOrThisParamOrGeneric: 'void is only valid as a return type or generic type argument or the type of a `this` parameter.',
                invalidVoidUnionConstituent: 'void is not valid as a constituent in a union type',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowInGenericTypeArguments: {
                            oneOf: [
                                { type: 'boolean' },
                                {
                                    type: 'array',
                                    items: { type: 'string' },
                                    minLength: 1,
                                },
                            ],
                        },
                        allowAsThisParameter: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            { allowInGenericTypeArguments: true, allowAsThisParameter: false },
        ],
        create(context, [{ allowInGenericTypeArguments, allowAsThisParameter }]) {
            const validParents = [
                utils_1.AST_NODE_TYPES.TSTypeAnnotation, //
            ];
            const invalidGrandParents = [
                utils_1.AST_NODE_TYPES.TSPropertySignature,
                utils_1.AST_NODE_TYPES.CallExpression,
                utils_1.AST_NODE_TYPES.PropertyDefinition,
                utils_1.AST_NODE_TYPES.Identifier,
            ];
            const validUnionMembers = [
                utils_1.AST_NODE_TYPES.TSVoidKeyword,
                utils_1.AST_NODE_TYPES.TSNeverKeyword,
            ];
            if (allowInGenericTypeArguments === true) {
                validParents.push(utils_1.AST_NODE_TYPES.TSTypeParameterInstantiation);
            }
            /**
             * @brief check if the given void keyword is used as a valid generic type
             *
             * reports if the type parametrized by void is not in the whitelist, or
             * allowInGenericTypeArguments is false.
             * no-op if the given void keyword is not used as generic type
             */
            function checkGenericTypeArgument(node) {
                var _a, _b;
                // only matches T<..., void, ...>
                // extra check for precaution
                /* istanbul ignore next */
                if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) !== utils_1.AST_NODE_TYPES.TSTypeParameterInstantiation ||
                    ((_b = node.parent.parent) === null || _b === void 0 ? void 0 : _b.type) !== utils_1.AST_NODE_TYPES.TSTypeReference) {
                    return;
                }
                // check whitelist
                if (Array.isArray(allowInGenericTypeArguments)) {
                    const sourceCode = context.getSourceCode();
                    const fullyQualifiedName = sourceCode
                        .getText(node.parent.parent.typeName)
                        .replace(/ /gu, '');
                    if (!allowInGenericTypeArguments
                        .map(s => s.replace(/ /gu, ''))
                        .includes(fullyQualifiedName)) {
                        context.report({
                            messageId: 'invalidVoidForGeneric',
                            data: { generic: fullyQualifiedName },
                            node,
                        });
                    }
                    return;
                }
                if (!allowInGenericTypeArguments) {
                    context.report({
                        messageId: allowAsThisParameter
                            ? 'invalidVoidNotReturnOrThisParam'
                            : 'invalidVoidNotReturn',
                        node,
                    });
                }
            }
            /**
             * @brief checks if the generic type parameter defaults to void
             */
            function checkDefaultVoid(node, parentNode) {
                if (parentNode.default !== node) {
                    context.report({
                        messageId: getNotReturnOrGenericMessageId(node),
                        node,
                    });
                }
            }
            /**
             * @brief checks that a union containing void is valid
             * @return true if every member of the union is specified as a valid type in
             * validUnionMembers, or is a valid generic type parametrized by void
             */
            function isValidUnionType(node) {
                return node.types.every(member => {
                    var _a, _b;
                    return validUnionMembers.includes(member.type) ||
                        // allows any T<..., void, ...> here, checked by checkGenericTypeArgument
                        (member.type === utils_1.AST_NODE_TYPES.TSTypeReference &&
                            ((_a = member.typeParameters) === null || _a === void 0 ? void 0 : _a.type) ===
                                utils_1.AST_NODE_TYPES.TSTypeParameterInstantiation &&
                            ((_b = member.typeParameters) === null || _b === void 0 ? void 0 : _b.params.map(param => param.type).includes(utils_1.AST_NODE_TYPES.TSVoidKeyword)));
                });
            }
            return {
                TSVoidKeyword(node) {
                    var _a, _b;
                    /* istanbul ignore next */
                    if (!((_a = node.parent) === null || _a === void 0 ? void 0 : _a.parent)) {
                        return;
                    }
                    // checks T<..., void, ...> against specification of allowInGenericArguments option
                    if (node.parent.type === utils_1.AST_NODE_TYPES.TSTypeParameterInstantiation &&
                        node.parent.parent.type === utils_1.AST_NODE_TYPES.TSTypeReference) {
                        checkGenericTypeArgument(node);
                        return;
                    }
                    // allow <T = void> if allowInGenericTypeArguments is specified, and report if the generic type parameter extends void
                    if (allowInGenericTypeArguments &&
                        node.parent.type === utils_1.AST_NODE_TYPES.TSTypeParameter &&
                        ((_b = node.parent.default) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.TSVoidKeyword) {
                        checkDefaultVoid(node, node.parent);
                        return;
                    }
                    // union w/ void must contain types from validUnionMembers, or a valid generic void type
                    if (node.parent.type === utils_1.AST_NODE_TYPES.TSUnionType &&
                        isValidUnionType(node.parent)) {
                        return;
                    }
                    // this parameter is ok to be void.
                    if (allowAsThisParameter &&
                        node.parent.type === utils_1.AST_NODE_TYPES.TSTypeAnnotation &&
                        node.parent.parent.type === utils_1.AST_NODE_TYPES.Identifier &&
                        node.parent.parent.name === 'this') {
                        return;
                    }
                    // default cases
                    if (validParents.includes(node.parent.type) &&
                        !invalidGrandParents.includes(node.parent.parent.type)) {
                        return;
                    }
                    context.report({
                        messageId: allowInGenericTypeArguments && allowAsThisParameter
                            ? 'invalidVoidNotReturnOrThisParamOrGeneric'
                            : allowInGenericTypeArguments
                                ? getNotReturnOrGenericMessageId(node)
                                : allowAsThisParameter
                                    ? 'invalidVoidNotReturnOrThisParam'
                                    : 'invalidVoidNotReturn',
                        node,
                    });
                },
            };
        },
    });
    function getNotReturnOrGenericMessageId(node) {
        return node.parent.type === utils_1.AST_NODE_TYPES.TSUnionType
            ? 'invalidVoidUnionConstituent'
            : 'invalidVoidNotReturnOrGeneric';
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-loop-func.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-loop-func');
    exports.default = util.createRule({
        name: 'no-loop-func',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow function declarations that contain unsafe references inside loop statements',
                recommended: false,
                extendsBaseRule: true,
            },
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: [],
            messages: baseRule.meta.messages,
        },
        defaultOptions: [],
        create(context) {
            /**
             * Reports functions which match the following condition:
             * - has a loop node in ancestors.
             * - has any references which refers to an unsafe variable.
             *
             * @param node The AST node to check.
             * @returns Whether or not the node is within a loop.
             */
            function checkForLoops(node) {
                const loopNode = getContainingLoopNode(node);
                if (!loopNode) {
                    return;
                }
                const references = context.getScope().through;
                const unsafeRefs = references
                    .filter(r => !isSafe(loopNode, r))
                    .map(r => r.identifier.name);
                if (unsafeRefs.length > 0) {
                    context.report({
                        node,
                        messageId: 'unsafeRefs',
                        data: { varNames: `'${unsafeRefs.join("', '")}'` },
                    });
                }
            }
            return {
                ArrowFunctionExpression: checkForLoops,
                FunctionExpression: checkForLoops,
                FunctionDeclaration: checkForLoops,
            };
        },
    });
    /**
     * Gets the containing loop node of a specified node.
     *
     * We don't need to check nested functions, so this ignores those.
     * `Scope.through` contains references of nested functions.
     *
     * @param node An AST node to get.
     * @returns The containing loop node of the specified node, or `null`.
     */
    function getContainingLoopNode(node) {
        for (let currentNode = node; currentNode.parent; currentNode = currentNode.parent) {
            const parent = currentNode.parent;
            switch (parent.type) {
                case utils_1.AST_NODE_TYPES.WhileStatement:
                case utils_1.AST_NODE_TYPES.DoWhileStatement:
                    return parent;
                case utils_1.AST_NODE_TYPES.ForStatement:
                    // `init` is outside of the loop.
                    if (parent.init !== currentNode) {
                        return parent;
                    }
                    break;
                case utils_1.AST_NODE_TYPES.ForInStatement:
                case utils_1.AST_NODE_TYPES.ForOfStatement:
                    // `right` is outside of the loop.
                    if (parent.right !== currentNode) {
                        return parent;
                    }
                    break;
                case utils_1.AST_NODE_TYPES.ArrowFunctionExpression:
                case utils_1.AST_NODE_TYPES.FunctionExpression:
                case utils_1.AST_NODE_TYPES.FunctionDeclaration:
                    // We don't need to check nested functions.
                    return null;
                default:
                    break;
            }
        }
        return null;
    }
    /**
     * Gets the containing loop node of a given node.
     * If the loop was nested, this returns the most outer loop.
     * @param node A node to get. This is a loop node.
     * @param excludedNode A node that the result node should not include.
     * @returns The most outer loop node.
     */
    function getTopLoopNode(node, excludedNode) {
        const border = excludedNode ? excludedNode.range[1] : 0;
        let retv = node;
        let containingLoopNode = node;
        while (containingLoopNode && containingLoopNode.range[0] >= border) {
            retv = containingLoopNode;
            containingLoopNode = getContainingLoopNode(containingLoopNode);
        }
        return retv;
    }
    /**
     * Checks whether a given reference which refers to an upper scope's variable is
     * safe or not.
     * @param loopNode A containing loop node.
     * @param reference A reference to check.
     * @returns `true` if the reference is safe or not.
     */
    function isSafe(loopNode, reference) {
        var _a;
        const variable = reference.resolved;
        const definition = variable === null || variable === void 0 ? void 0 : variable.defs[0];
        const declaration = definition === null || definition === void 0 ? void 0 : definition.parent;
        const kind = (declaration === null || declaration === void 0 ? void 0 : declaration.type) === utils_1.AST_NODE_TYPES.VariableDeclaration
            ? declaration.kind
            : '';
        // type references are all safe
        // this only really matters for global types that haven't been configured
        if (reference.isTypeReference) {
            return true;
        }
        // Variables which are declared by `const` is safe.
        if (kind === 'const') {
            return true;
        }
        /*
         * Variables which are declared by `let` in the loop is safe.
         * It's a different instance from the next loop step's.
         */
        if (kind === 'let' &&
            declaration &&
            declaration.range[0] > loopNode.range[0] &&
            declaration.range[1] < loopNode.range[1]) {
            return true;
        }
        /*
         * WriteReferences which exist after this border are unsafe because those
         * can modify the variable.
         */
        const border = getTopLoopNode(loopNode, kind === 'let' ? declaration : null)
            .range[0];
        /**
         * Checks whether a given reference is safe or not.
         * The reference is every reference of the upper scope's variable we are
         * looking now.
         *
         * It's safe if the reference matches one of the following condition.
         * - is readonly.
         * - doesn't exist inside a local function and after the border.
         *
         * @param upperRef A reference to check.
         * @returns `true` if the reference is safe.
         */
        function isSafeReference(upperRef) {
            var _a;
            const id = upperRef.identifier;
            return (!upperRef.isWrite() ||
                (((_a = variable === null || variable === void 0 ? void 0 : variable.scope) === null || _a === void 0 ? void 0 : _a.variableScope) === upperRef.from.variableScope &&
                    id.range[0] < border));
        }
        return (_a = variable === null || variable === void 0 ? void 0 : variable.references.every(isSafeReference)) !== null && _a !== void 0 ? _a : false;
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-loss-of-precision.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var _a;
    Object.defineProperty(exports, "__esModule", { value: true });
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.maybeGetESLintCoreRule)('no-loss-of-precision');
    exports.default = util.createRule({
        name: 'no-loss-of-precision',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow literal numbers that lose precision',
                recommended: 'error',
                extendsBaseRule: true,
            },
            hasSuggestions: baseRule === null || baseRule === void 0 ? void 0 : baseRule.meta.hasSuggestions,
            schema: [],
            messages: (_a = baseRule === null || baseRule === void 0 ? void 0 : baseRule.meta.messages) !== null && _a !== void 0 ? _a : { noLossOfPrecision: '' },
        },
        defaultOptions: [],
        create(context) {
            /* istanbul ignore if */ if (baseRule == null) {
                throw new Error('@typescript-eslint/no-loss-of-precision requires at least ESLint v7.1.0');
            }
            // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion
            const rules = baseRule.create(context);
            function isSeparatedNumeric(node) {
                return typeof node.value === 'number' && node.raw.includes('_');
            }
            return {
                Literal(node) {
                    rules.Literal(Object.assign(Object.assign({}, node), { raw: isSeparatedNumeric(node) ? node.raw.replace(/_/g, '') : node.raw }));
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-magic-numbers.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-magic-numbers');
    // Extend base schema with additional property to ignore TS numeric literal types
    const schema = util.deepMerge(
    // eslint-disable-next-line @typescript-eslint/no-unsafe-argument -- https://github.com/microsoft/TypeScript/issues/17002
    Array.isArray(baseRule.meta.schema)
        ? baseRule.meta.schema[0]
        : baseRule.meta.schema, {
        properties: {
            ignoreNumericLiteralTypes: {
                type: 'boolean',
            },
            ignoreEnums: {
                type: 'boolean',
            },
            ignoreReadonlyClassProperties: {
                type: 'boolean',
            },
            ignoreTypeIndexes: {
                type: 'boolean',
            },
        },
    });
    exports.default = util.createRule({
        name: 'no-magic-numbers',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow magic numbers',
                recommended: false,
                extendsBaseRule: true,
            },
            schema: [schema],
            messages: baseRule.meta.messages,
        },
        defaultOptions: [
            {
                ignore: [],
                ignoreArrayIndexes: false,
                enforceConst: false,
                detectObjects: false,
                ignoreNumericLiteralTypes: false,
                ignoreEnums: false,
                ignoreReadonlyClassProperties: false,
            },
        ],
        create(context, [options]) {
            const rules = baseRule.create(context);
            return {
                Literal(node) {
                    var _a;
                    // If it’s not a numeric literal we’re not interested
                    if (typeof node.value !== 'number' && typeof node.value !== 'bigint') {
                        return;
                    }
                    // This will be `true` if we’re configured to ignore this case (eg. it’s
                    // an enum and `ignoreEnums` is `true`). It will be `false` if we’re not
                    // configured to ignore this case. It will remain `undefined` if this is
                    // not one of our exception cases, and we’ll fall back to the base rule.
                    let isAllowed;
                    // Check if the node is a TypeScript enum declaration
                    if (isParentTSEnumDeclaration(node)) {
                        isAllowed = options.ignoreEnums === true;
                    }
                    // Check TypeScript specific nodes for Numeric Literal
                    else if (isTSNumericLiteralType(node)) {
                        isAllowed = options.ignoreNumericLiteralTypes === true;
                    }
                    // Check if the node is a type index
                    else if (isAncestorTSIndexedAccessType(node)) {
                        isAllowed = options.ignoreTypeIndexes === true;
                    }
                    // Check if the node is a readonly class property
                    else if (isParentTSReadonlyPropertyDefinition(node)) {
                        isAllowed = options.ignoreReadonlyClassProperties === true;
                    }
                    // If we’ve hit a case where the ignore option is true we can return now
                    if (isAllowed === true) {
                        return;
                    }
                    // If the ignore option is *not* set we can report it now
                    else if (isAllowed === false) {
                        let fullNumberNode = node;
                        let raw = node.raw;
                        if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.UnaryExpression &&
                            // the base rule only shows the operator for negative numbers
                            // https://github.com/eslint/eslint/blob/9dfc8501fb1956c90dc11e6377b4cb38a6bea65d/lib/rules/no-magic-numbers.js#L126
                            node.parent.operator === '-') {
                            fullNumberNode = node.parent;
                            raw = `${node.parent.operator}${node.raw}`;
                        }
                        context.report({
                            messageId: 'noMagic',
                            node: fullNumberNode,
                            data: { raw },
                        });
                        return;
                    }
                    // Let the base rule deal with the rest
                    rules.Literal(node);
                },
            };
        },
    });
    /**
     * Gets the true parent of the literal, handling prefixed numbers (-1 / +1)
     */
    function getLiteralParent(node) {
        var _a;
        if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.UnaryExpression &&
            ['-', '+'].includes(node.parent.operator)) {
            return node.parent.parent;
        }
        return node.parent;
    }
    /**
     * Checks if the node grandparent is a Typescript type alias declaration
     * @param node the node to be validated.
     * @returns true if the node grandparent is a Typescript type alias declaration
     * @private
     */
    function isGrandparentTSTypeAliasDeclaration(node) {
        var _a, _b;
        return ((_b = (_a = node.parent) === null || _a === void 0 ? void 0 : _a.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration;
    }
    /**
     * Checks if the node grandparent is a Typescript union type and its parent is a type alias declaration
     * @param node the node to be validated.
     * @returns true if the node grandparent is a Typescript union type and its parent is a type alias declaration
     * @private
     */
    function isGrandparentTSUnionType(node) {
        var _a, _b;
        if (((_b = (_a = node.parent) === null || _a === void 0 ? void 0 : _a.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.TSUnionType) {
            return isGrandparentTSTypeAliasDeclaration(node.parent);
        }
        return false;
    }
    /**
     * Checks if the node parent is a Typescript enum member
     * @param node the node to be validated.
     * @returns true if the node parent is a Typescript enum member
     * @private
     */
    function isParentTSEnumDeclaration(node) {
        const parent = getLiteralParent(node);
        return (parent === null || parent === void 0 ? void 0 : parent.type) === utils_1.AST_NODE_TYPES.TSEnumMember;
    }
    /**
     * Checks if the node parent is a Typescript literal type
     * @param node the node to be validated.
     * @returns true if the node parent is a Typescript literal type
     * @private
     */
    function isParentTSLiteralType(node) {
        var _a;
        return ((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.TSLiteralType;
    }
    /**
     * Checks if the node is a valid TypeScript numeric literal type.
     * @param node the node to be validated.
     * @returns true if the node is a TypeScript numeric literal type.
     * @private
     */
    function isTSNumericLiteralType(node) {
        var _a;
        // For negative numbers, use the parent node
        if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.UnaryExpression &&
            node.parent.operator === '-') {
            node = node.parent;
        }
        // If the parent node is not a TSLiteralType, early return
        if (!isParentTSLiteralType(node)) {
            return false;
        }
        // If the grandparent is a TSTypeAliasDeclaration, ignore
        if (isGrandparentTSTypeAliasDeclaration(node)) {
            return true;
        }
        // If the grandparent is a TSUnionType and it's parent is a TSTypeAliasDeclaration, ignore
        if (isGrandparentTSUnionType(node)) {
            return true;
        }
        return false;
    }
    /**
     * Checks if the node parent is a readonly class property
     * @param node the node to be validated.
     * @returns true if the node parent is a readonly class property
     * @private
     */
    function isParentTSReadonlyPropertyDefinition(node) {
        const parent = getLiteralParent(node);
        if ((parent === null || parent === void 0 ? void 0 : parent.type) === utils_1.AST_NODE_TYPES.PropertyDefinition && parent.readonly) {
            return true;
        }
        return false;
    }
    /**
     * Checks if the node is part of a type indexed access (eg. Foo[4])
     * @param node the node to be validated.
     * @returns true if the node is part of an indexed access
     * @private
     */
    function isAncestorTSIndexedAccessType(node) {
        var _a, _b, _c;
        // Handle unary expressions (eg. -4)
        let ancestor = getLiteralParent(node);
        // Go up another level while we’re part of a type union (eg. 1 | 2) or
        // intersection (eg. 1 & 2)
        while (((_a = ancestor === null || ancestor === void 0 ? void 0 : ancestor.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.TSUnionType ||
            ((_b = ancestor === null || ancestor === void 0 ? void 0 : ancestor.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.TSIntersectionType) {
            ancestor = ancestor.parent;
        }
        return ((_c = ancestor === null || ancestor === void 0 ? void 0 : ancestor.parent) === null || _c === void 0 ? void 0 : _c.type) === utils_1.AST_NODE_TYPES.TSIndexedAccessType;
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-meaningless-void-operator.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-meaningless-void-operator',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow the `void` operator except when used to discard a value',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            fixable: 'code',
            hasSuggestions: true,
            messages: {
                meaninglessVoidOperator: "void operator shouldn't be used on {{type}}; it should convey that a return value is being ignored",
                removeVoid: "Remove 'void'",
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        checkNever: {
                            type: 'boolean',
                            default: false,
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [{ checkNever: false }],
        create(context, [{ checkNever }]) {
            const parserServices = utils_1.ESLintUtils.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const sourceCode = context.getSourceCode();
            return {
                'UnaryExpression[operator="void"]'(node) {
                    const fix = (fixer) => {
                        return fixer.removeRange([
                            sourceCode.getTokens(node)[0].range[0],
                            sourceCode.getTokens(node)[1].range[0],
                        ]);
                    };
                    const argTsNode = parserServices.esTreeNodeToTSNodeMap.get(node.argument);
                    const argType = checker.getTypeAtLocation(argTsNode);
                    const unionParts = tsutils.unionTypeParts(argType);
                    if (unionParts.every(part => part.flags & (ts.TypeFlags.Void | ts.TypeFlags.Undefined))) {
                        context.report({
                            node,
                            messageId: 'meaninglessVoidOperator',
                            data: { type: checker.typeToString(argType) },
                            fix,
                        });
                    }
                    else if (checkNever &&
                        unionParts.every(part => part.flags &
                            (ts.TypeFlags.Void | ts.TypeFlags.Undefined | ts.TypeFlags.Never))) {
                        context.report({
                            node,
                            messageId: 'meaninglessVoidOperator',
                            data: { type: checker.typeToString(argType) },
                            suggest: [{ messageId: 'removeVoid', fix }],
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-misused-new.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-misused-new',
        meta: {
            type: 'problem',
            docs: {
                description: 'Enforce valid definition of `new` and `constructor`',
                recommended: 'error',
            },
            schema: [],
            messages: {
                errorMessageInterface: 'Interfaces cannot be constructed, only classes.',
                errorMessageClass: 'Class cannot have method named `new`.',
            },
        },
        defaultOptions: [],
        create(context) {
            /**
             * @param node type to be inspected.
             * @returns name of simple type or null
             */
            function getTypeReferenceName(node) {
                if (node) {
                    switch (node.type) {
                        case utils_1.AST_NODE_TYPES.TSTypeAnnotation:
                            return getTypeReferenceName(node.typeAnnotation);
                        case utils_1.AST_NODE_TYPES.TSTypeReference:
                            return getTypeReferenceName(node.typeName);
                        case utils_1.AST_NODE_TYPES.Identifier:
                            return node.name;
                        default:
                            break;
                    }
                }
                return null;
            }
            /**
             * @param parent parent node.
             * @param returnType type to be compared
             */
            function isMatchingParentType(parent, returnType) {
                if (parent &&
                    'id' in parent &&
                    parent.id &&
                    parent.id.type === utils_1.AST_NODE_TYPES.Identifier) {
                    return getTypeReferenceName(returnType) === parent.id.name;
                }
                return false;
            }
            return {
                'TSInterfaceBody > TSConstructSignatureDeclaration'(node) {
                    if (isMatchingParentType(node.parent.parent, node.returnType)) {
                        // constructor
                        context.report({
                            node,
                            messageId: 'errorMessageInterface',
                        });
                    }
                },
                "TSMethodSignature[key.name='constructor']"(node) {
                    context.report({
                        node,
                        messageId: 'errorMessageInterface',
                    });
                },
                "ClassBody > MethodDefinition[key.name='new']"(node) {
                    if (node.value.type === utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression) {
                        if (node.parent &&
                            isMatchingParentType(node.parent.parent, node.value.returnType)) {
                            context.report({
                                node,
                                messageId: 'errorMessageClass',
                            });
                        }
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-misused-promises.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    function parseChecksVoidReturn(checksVoidReturn) {
        var _a, _b, _c, _d, _e;
        switch (checksVoidReturn) {
            case false:
                return false;
            case true:
            case undefined:
                return {
                    arguments: true,
                    attributes: true,
                    properties: true,
                    returns: true,
                    variables: true,
                };
            default:
                return {
                    arguments: (_a = checksVoidReturn.arguments) !== null && _a !== void 0 ? _a : true,
                    attributes: (_b = checksVoidReturn.attributes) !== null && _b !== void 0 ? _b : true,
                    properties: (_c = checksVoidReturn.properties) !== null && _c !== void 0 ? _c : true,
                    returns: (_d = checksVoidReturn.returns) !== null && _d !== void 0 ? _d : true,
                    variables: (_e = checksVoidReturn.variables) !== null && _e !== void 0 ? _e : true,
                };
        }
    }
    exports.default = util.createRule({
        name: 'no-misused-promises',
        meta: {
            docs: {
                description: 'Disallow Promises in places not designed to handle them',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                voidReturnArgument: 'Promise returned in function argument where a void return was expected.',
                voidReturnVariable: 'Promise-returning function provided to variable where a void return was expected.',
                voidReturnProperty: 'Promise-returning function provided to property where a void return was expected.',
                voidReturnReturnValue: 'Promise-returning function provided to return value where a void return was expected.',
                voidReturnAttribute: 'Promise-returning function provided to attribute where a void return was expected.',
                conditional: 'Expected non-Promise value in a boolean conditional.',
                spread: 'Expected a non-Promise value to be spreaded in an object.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        checksConditionals: {
                            type: 'boolean',
                        },
                        checksVoidReturn: {
                            oneOf: [
                                { type: 'boolean' },
                                {
                                    additionalProperties: false,
                                    properties: {
                                        arguments: { type: 'boolean' },
                                        attributes: { type: 'boolean' },
                                        properties: { type: 'boolean' },
                                        returns: { type: 'boolean' },
                                        variables: { type: 'boolean' },
                                    },
                                    type: 'object',
                                },
                            ],
                        },
                        checksSpreads: {
                            type: 'boolean',
                        },
                    },
                },
            ],
            type: 'problem',
        },
        defaultOptions: [
            {
                checksConditionals: true,
                checksVoidReturn: true,
                checksSpreads: true,
            },
        ],
        create(context, [{ checksConditionals, checksVoidReturn, checksSpreads }]) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const checkedNodes = new Set();
            const conditionalChecks = {
                ConditionalExpression: checkTestConditional,
                DoWhileStatement: checkTestConditional,
                ForStatement: checkTestConditional,
                IfStatement: checkTestConditional,
                LogicalExpression: checkConditional,
                'UnaryExpression[operator="!"]'(node) {
                    checkConditional(node.argument, true);
                },
                WhileStatement: checkTestConditional,
            };
            checksVoidReturn = parseChecksVoidReturn(checksVoidReturn);
            const voidReturnChecks = checksVoidReturn
                ? Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, (checksVoidReturn.arguments && {
                    CallExpression: checkArguments,
                    NewExpression: checkArguments,
                })), (checksVoidReturn.attributes && {
                    JSXAttribute: checkJSXAttribute,
                })), (checksVoidReturn.properties && {
                    Property: checkProperty,
                })), (checksVoidReturn.returns && {
                    ReturnStatement: checkReturnStatement,
                })), (checksVoidReturn.variables && {
                    AssignmentExpression: checkAssignment,
                    VariableDeclarator: checkVariableDeclaration,
                })) : {};
            const spreadChecks = {
                SpreadElement: checkSpread,
            };
            function checkTestConditional(node) {
                if (node.test) {
                    checkConditional(node.test, true);
                }
            }
            /**
             * This function analyzes the type of a node and checks if it is a Promise in a boolean conditional.
             * It uses recursion when checking nested logical operators.
             * @param node The AST node to check.
             * @param isTestExpr Whether the node is a descendant of a test expression.
             */
            function checkConditional(node, isTestExpr = false) {
                // prevent checking the same node multiple times
                if (checkedNodes.has(node)) {
                    return;
                }
                checkedNodes.add(node);
                if (node.type === utils_1.AST_NODE_TYPES.LogicalExpression) {
                    // ignore the left operand for nullish coalescing expressions not in a context of a test expression
                    if (node.operator !== '??' || isTestExpr) {
                        checkConditional(node.left, isTestExpr);
                    }
                    // we ignore the right operand when not in a context of a test expression
                    if (isTestExpr) {
                        checkConditional(node.right, isTestExpr);
                    }
                    return;
                }
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                if (isAlwaysThenable(checker, tsNode)) {
                    context.report({
                        messageId: 'conditional',
                        node,
                    });
                }
            }
            function checkArguments(node) {
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                const voidArgs = voidFunctionArguments(checker, tsNode);
                if (voidArgs.size === 0) {
                    return;
                }
                for (const [index, argument] of node.arguments.entries()) {
                    if (!voidArgs.has(index)) {
                        continue;
                    }
                    const tsNode = parserServices.esTreeNodeToTSNodeMap.get(argument);
                    if (returnsThenable(checker, tsNode)) {
                        context.report({
                            messageId: 'voidReturnArgument',
                            node: argument,
                        });
                    }
                }
            }
            function checkAssignment(node) {
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                const varType = checker.getTypeAtLocation(tsNode.left);
                if (!isVoidReturningFunctionType(checker, tsNode.left, varType)) {
                    return;
                }
                if (returnsThenable(checker, tsNode.right)) {
                    context.report({
                        messageId: 'voidReturnVariable',
                        node: node.right,
                    });
                }
            }
            function checkVariableDeclaration(node) {
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                if (tsNode.initializer === undefined || node.init == null) {
                    return;
                }
                const varType = checker.getTypeAtLocation(tsNode.name);
                if (!isVoidReturningFunctionType(checker, tsNode.initializer, varType)) {
                    return;
                }
                if (returnsThenable(checker, tsNode.initializer)) {
                    context.report({
                        messageId: 'voidReturnVariable',
                        node: node.init,
                    });
                }
            }
            function checkProperty(node) {
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                if (ts.isPropertyAssignment(tsNode)) {
                    const contextualType = checker.getContextualType(tsNode.initializer);
                    if (contextualType !== undefined &&
                        isVoidReturningFunctionType(checker, tsNode.initializer, contextualType) &&
                        returnsThenable(checker, tsNode.initializer)) {
                        context.report({
                            messageId: 'voidReturnProperty',
                            node: node.value,
                        });
                    }
                }
                else if (ts.isShorthandPropertyAssignment(tsNode)) {
                    const contextualType = checker.getContextualType(tsNode.name);
                    if (contextualType !== undefined &&
                        isVoidReturningFunctionType(checker, tsNode.name, contextualType) &&
                        returnsThenable(checker, tsNode.name)) {
                        context.report({
                            messageId: 'voidReturnProperty',
                            node: node.value,
                        });
                    }
                }
                else if (ts.isMethodDeclaration(tsNode)) {
                    if (ts.isComputedPropertyName(tsNode.name)) {
                        return;
                    }
                    const obj = tsNode.parent;
                    // Below condition isn't satisfied unless something goes wrong,
                    // but is needed for type checking.
                    // 'node' does not include class method declaration so 'obj' is
                    // always an object literal expression, but after converting 'node'
                    // to TypeScript AST, its type includes MethodDeclaration which
                    // does include the case of class method declaration.
                    if (!ts.isObjectLiteralExpression(obj)) {
                        return;
                    }
                    const objType = checker.getContextualType(obj);
                    if (objType === undefined) {
                        return;
                    }
                    const propertySymbol = checker.getPropertyOfType(objType, tsNode.name.text);
                    if (propertySymbol === undefined) {
                        return;
                    }
                    const contextualType = checker.getTypeOfSymbolAtLocation(propertySymbol, tsNode.name);
                    if (isVoidReturningFunctionType(checker, tsNode.name, contextualType) &&
                        returnsThenable(checker, tsNode)) {
                        context.report({
                            messageId: 'voidReturnProperty',
                            node: node.value,
                        });
                    }
                    return;
                }
            }
            function checkReturnStatement(node) {
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                if (tsNode.expression === undefined || node.argument == null) {
                    return;
                }
                const contextualType = checker.getContextualType(tsNode.expression);
                if (contextualType !== undefined &&
                    isVoidReturningFunctionType(checker, tsNode.expression, contextualType) &&
                    returnsThenable(checker, tsNode.expression)) {
                    context.report({
                        messageId: 'voidReturnReturnValue',
                        node: node.argument,
                    });
                }
            }
            function checkJSXAttribute(node) {
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                const value = tsNode.initializer;
                if (node.value == null ||
                    value === undefined ||
                    !ts.isJsxExpression(value) ||
                    value.expression === undefined) {
                    return;
                }
                const contextualType = checker.getContextualType(value);
                if (contextualType !== undefined &&
                    isVoidReturningFunctionType(checker, value, contextualType) &&
                    returnsThenable(checker, value.expression)) {
                    context.report({
                        messageId: 'voidReturnAttribute',
                        node: node.value,
                    });
                }
            }
            function checkSpread(node) {
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                if (isSometimesThenable(checker, tsNode.expression)) {
                    context.report({
                        messageId: 'spread',
                        node: node.argument,
                    });
                }
            }
            return Object.assign(Object.assign(Object.assign({}, (checksConditionals ? conditionalChecks : {})), (checksVoidReturn ? voidReturnChecks : {})), (checksSpreads ? spreadChecks : {}));
        },
    });
    function isSometimesThenable(checker, node) {
        const type = checker.getTypeAtLocation(node);
        for (const subType of tsutils.unionTypeParts(checker.getApparentType(type))) {
            if (tsutils.isThenableType(checker, node, subType)) {
                return true;
            }
        }
        return false;
    }
    // Variation on the thenable check which requires all forms of the type (read:
    // alternates in a union) to be thenable. Otherwise, you might be trying to
    // check if something is defined or undefined and get caught because one of the
    // branches is thenable.
    function isAlwaysThenable(checker, node) {
        const type = checker.getTypeAtLocation(node);
        for (const subType of tsutils.unionTypeParts(checker.getApparentType(type))) {
            const thenProp = subType.getProperty('then');
            // If one of the alternates has no then property, it is not thenable in all
            // cases.
            if (thenProp === undefined) {
                return false;
            }
            // We walk through each variation of the then property. Since we know it
            // exists at this point, we just need at least one of the alternates to
            // be of the right form to consider it thenable.
            const thenType = checker.getTypeOfSymbolAtLocation(thenProp, node);
            let hasThenableSignature = false;
            for (const subType of tsutils.unionTypeParts(thenType)) {
                for (const signature of subType.getCallSignatures()) {
                    if (signature.parameters.length !== 0 &&
                        isFunctionParam(checker, signature.parameters[0], node)) {
                        hasThenableSignature = true;
                        break;
                    }
                }
                // We only need to find one variant of the then property that has a
                // function signature for it to be thenable.
                if (hasThenableSignature) {
                    break;
                }
            }
            // If no flavors of the then property are thenable, we don't consider the
            // overall type to be thenable
            if (!hasThenableSignature) {
                return false;
            }
        }
        // If all variants are considered thenable (i.e. haven't returned false), we
        // consider the overall type thenable
        return true;
    }
    function isFunctionParam(checker, param, node) {
        const type = checker.getApparentType(checker.getTypeOfSymbolAtLocation(param, node));
        for (const subType of tsutils.unionTypeParts(type)) {
            if (subType.getCallSignatures().length !== 0) {
                return true;
            }
        }
        return false;
    }
    function checkThenableOrVoidArgument(checker, node, type, index, thenableReturnIndices, voidReturnIndices) {
        if (isThenableReturningFunctionType(checker, node.expression, type)) {
            thenableReturnIndices.add(index);
        }
        else if (isVoidReturningFunctionType(checker, node.expression, type)) {
            // If a certain argument accepts both thenable and void returns,
            // a promise-returning function is valid
            if (!thenableReturnIndices.has(index)) {
                voidReturnIndices.add(index);
            }
        }
    }
    // Get the positions of arguments which are void functions (and not also
    // thenable functions). These are the candidates for the void-return check at
    // the current call site.
    // If the function parameters end with a 'rest' parameter, then we consider
    // the array type parameter (e.g. '...args:Array<SomeType>') when determining
    // if trailing arguments are candidates.
    function voidFunctionArguments(checker, node) {
        // 'new' can be used without any arguments, as in 'let b = new Object;'
        // In this case, there are no argument positions to check, so return early.
        if (!node.arguments) {
            return new Set();
        }
        const thenableReturnIndices = new Set();
        const voidReturnIndices = new Set();
        const type = checker.getTypeAtLocation(node.expression);
        // We can't use checker.getResolvedSignature because it prefers an early '() => void' over a later '() => Promise<void>'
        // See https://github.com/microsoft/TypeScript/issues/48077
        for (const subType of tsutils.unionTypeParts(type)) {
            // Standard function calls and `new` have two different types of signatures
            const signatures = ts.isCallExpression(node)
                ? subType.getCallSignatures()
                : subType.getConstructSignatures();
            for (const signature of signatures) {
                for (const [index, parameter] of signature.parameters.entries()) {
                    const decl = parameter.valueDeclaration;
                    let type = checker.getTypeOfSymbolAtLocation(parameter, node.expression);
                    // If this is a array 'rest' parameter, check all of the argument indices
                    // from the current argument to the end.
                    // Note - we currently do not support 'spread' arguments - adding support for them
                    // is tracked in https://github.com/typescript-eslint/typescript-eslint/issues/5744
                    if (decl && ts.isParameter(decl) && decl.dotDotDotToken) {
                        if (checker.isArrayType(type)) {
                            // Unwrap 'Array<MaybeVoidFunction>' to 'MaybeVoidFunction',
                            // so that we'll handle it in the same way as a non-rest
                            // 'param: MaybeVoidFunction'
                            type = checker.getTypeArguments(type)[0];
                            for (let i = index; i < node.arguments.length; i++) {
                                checkThenableOrVoidArgument(checker, node, type, i, thenableReturnIndices, voidReturnIndices);
                            }
                        }
                        else if (checker.isTupleType(type)) {
                            // Check each type in the tuple - for example, [boolean, () => void] would
                            // add the index of the second tuple parameter to 'voidReturnIndices'
                            const typeArgs = checker.getTypeArguments(type);
                            for (let i = index; i < node.arguments.length && i - index < typeArgs.length; i++) {
                                checkThenableOrVoidArgument(checker, node, typeArgs[i - index], i, thenableReturnIndices, voidReturnIndices);
                            }
                        }
                    }
                    else {
                        checkThenableOrVoidArgument(checker, node, type, index, thenableReturnIndices, voidReturnIndices);
                    }
                }
            }
        }
        for (const index of thenableReturnIndices) {
            voidReturnIndices.delete(index);
        }
        return voidReturnIndices;
    }
    /**
     * @returns Whether any call signature of the type has a thenable return type.
     */
    function anySignatureIsThenableType(checker, node, type) {
        for (const signature of type.getCallSignatures()) {
            const returnType = signature.getReturnType();
            if (tsutils.isThenableType(checker, node, returnType)) {
                return true;
            }
        }
        return false;
    }
    /**
     * @returns Whether type is a thenable-returning function.
     */
    function isThenableReturningFunctionType(checker, node, type) {
        for (const subType of tsutils.unionTypeParts(type)) {
            if (anySignatureIsThenableType(checker, node, subType)) {
                return true;
            }
        }
        return false;
    }
    /**
     * @returns Whether type is a void-returning function.
     */
    function isVoidReturningFunctionType(checker, node, type) {
        let hadVoidReturn = false;
        for (const subType of tsutils.unionTypeParts(type)) {
            for (const signature of subType.getCallSignatures()) {
                const returnType = signature.getReturnType();
                // If a certain positional argument accepts both thenable and void returns,
                // a promise-returning function is valid
                if (tsutils.isThenableType(checker, node, returnType)) {
                    return false;
                }
                hadVoidReturn || (hadVoidReturn = tsutils.isTypeFlagSet(returnType, ts.TypeFlags.Void));
            }
        }
        return hadVoidReturn;
    }
    /**
     * @returns Whether expression is a function that returns a thenable.
     */
    function returnsThenable(checker, node) {
        const type = checker.getApparentType(checker.getTypeAtLocation(node));
        if (anySignatureIsThenableType(checker, node, type)) {
            return true;
        }
        return false;
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-mixed-enums.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const scope_manager_1 = require(861) /* @typescript-eslint/scope-manager */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    var AllowedType;
    (function (AllowedType) {
        AllowedType[AllowedType["Number"] = 0] = "Number";
        AllowedType[AllowedType["String"] = 1] = "String";
        AllowedType[AllowedType["Unknown"] = 2] = "Unknown";
    })(AllowedType || (AllowedType = {}));
    exports.default = util.createRule({
        name: 'no-mixed-enums',
        meta: {
            docs: {
                description: 'Disallow enums from having both number and string members',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            messages: {
                mixed: `Mixing number and string enums can be confusing.`,
            },
            schema: [],
            type: 'problem',
        },
        defaultOptions: [],
        create(context) {
            const parserServices = util.getParserServices(context);
            const typeChecker = parserServices.program.getTypeChecker();
            function collectNodeDefinitions(node) {
                var _a, _b, _c, _d, _e;
                const { name } = node.id;
                const found = {
                    imports: [],
                    previousSibling: undefined,
                };
                let scope = context.getScope();
                for (const definition of (_c = (_b = (_a = scope.upper) === null || _a === void 0 ? void 0 : _a.set.get(name)) === null || _b === void 0 ? void 0 : _b.defs) !== null && _c !== void 0 ? _c : []) {
                    if (definition.node.type === utils_1.AST_NODE_TYPES.TSEnumDeclaration &&
                        definition.node.range[0] < node.range[0] &&
                        definition.node.members.length > 0) {
                        found.previousSibling = definition.node;
                        break;
                    }
                }
                while (scope) {
                    (_e = (_d = scope.set.get(name)) === null || _d === void 0 ? void 0 : _d.defs) === null || _e === void 0 ? void 0 : _e.forEach(definition => {
                        if (definition.type === scope_manager_1.DefinitionType.ImportBinding) {
                            found.imports.push(definition.node);
                        }
                    });
                    scope = scope.upper;
                }
                return found;
            }
            function getAllowedTypeForNode(node) {
                return tsutils.isTypeFlagSet(typeChecker.getTypeAtLocation(node), ts.TypeFlags.StringLike)
                    ? AllowedType.String
                    : AllowedType.Number;
            }
            function getTypeFromImported(imported) {
                var _a;
                const type = typeChecker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(imported));
                const valueDeclaration = (_a = type.getSymbol()) === null || _a === void 0 ? void 0 : _a.valueDeclaration;
                if (!valueDeclaration ||
                    !ts.isEnumDeclaration(valueDeclaration) ||
                    valueDeclaration.members.length === 0) {
                    return undefined;
                }
                return getAllowedTypeForNode(valueDeclaration.members[0]);
            }
            function getMemberType(member) {
                if (!member.initializer) {
                    return AllowedType.Number;
                }
                switch (member.initializer.type) {
                    case utils_1.AST_NODE_TYPES.Literal:
                        switch (typeof member.initializer.value) {
                            case 'number':
                                return AllowedType.Number;
                            case 'string':
                                return AllowedType.String;
                            default:
                                return AllowedType.Unknown;
                        }
                    case utils_1.AST_NODE_TYPES.TemplateLiteral:
                        return AllowedType.String;
                    default:
                        return getAllowedTypeForNode(parserServices.esTreeNodeToTSNodeMap.get(member.initializer));
                }
            }
            function getDesiredTypeForDefinition(node) {
                const { imports, previousSibling } = collectNodeDefinitions(node);
                // Case: Merged ambiently via module augmentation
                // import { MyEnum } from 'other-module';
                // declare module 'other-module' {
                //   enum MyEnum { A }
                // }
                for (const imported of imports) {
                    const typeFromImported = getTypeFromImported(imported);
                    if (typeFromImported !== undefined) {
                        return typeFromImported;
                    }
                }
                // Case: Multiple enum declarations in the same file
                // enum MyEnum { A }
                // enum MyEnum { B }
                if (previousSibling) {
                    return getMemberType(previousSibling.members[0]);
                }
                // Case: Namespace declaration merging
                // namespace MyNamespace {
                //   export enum MyEnum { A }
                // }
                // namespace MyNamespace {
                //   export enum MyEnum { B }
                // }
                if (node.parent.type === utils_1.AST_NODE_TYPES.ExportNamedDeclaration &&
                    node.parent.parent.type === utils_1.AST_NODE_TYPES.TSModuleBlock) {
                    // TODO: We don't need to dip into the TypeScript type checker here!
                    // Merged namespaces must all exist in the same file.
                    // We could instead compare this file's nodes to find the merges.
                    const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node.id);
                    const declarations = typeChecker
                        .getSymbolAtLocation(tsNode)
                        .getDeclarations();
                    for (const declaration of declarations) {
                        for (const member of declaration.members) {
                            return member.initializer
                                ? tsutils.isTypeFlagSet(typeChecker.getTypeAtLocation(member.initializer), ts.TypeFlags.StringLike)
                                    ? AllowedType.String
                                    : AllowedType.Number
                                : AllowedType.Number;
                        }
                    }
                }
                // Finally, we default to the type of the first enum member
                return getMemberType(node.members[0]);
            }
            return {
                TSEnumDeclaration(node) {
                    var _a;
                    if (!node.members.length) {
                        return;
                    }
                    let desiredType = getDesiredTypeForDefinition(node);
                    if (desiredType === ts.TypeFlags.Unknown) {
                        return;
                    }
                    for (const member of node.members) {
                        const currentType = getMemberType(member);
                        if (currentType === AllowedType.Unknown) {
                            return;
                        }
                        if (currentType === AllowedType.Number) {
                            desiredType !== null && desiredType !== void 0 ? desiredType : (desiredType = currentType);
                        }
                        if (currentType !== desiredType &&
                            (currentType !== undefined || desiredType === AllowedType.String)) {
                            context.report({
                                messageId: 'mixed',
                                node: (_a = member.initializer) !== null && _a !== void 0 ? _a : member,
                            });
                            return;
                        }
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-namespace.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-namespace',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow TypeScript namespaces',
                recommended: 'error',
            },
            messages: {
                moduleSyntaxIsPreferred: 'ES2015 module syntax is preferred over namespaces.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowDeclarations: {
                            description: 'Whether to allow `declare` with custom TypeScript namespaces.',
                            type: 'boolean',
                        },
                        allowDefinitionFiles: {
                            description: 'Whether to allow `declare` with custom TypeScript namespaces inside definition files.',
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                allowDeclarations: false,
                allowDefinitionFiles: true,
            },
        ],
        create(context, [{ allowDeclarations, allowDefinitionFiles }]) {
            const filename = context.getFilename();
            function isDeclaration(node) {
                if (node.type === utils_1.AST_NODE_TYPES.TSModuleDeclaration &&
                    node.declare === true) {
                    return true;
                }
                return node.parent != null && isDeclaration(node.parent);
            }
            return {
                "TSModuleDeclaration[global!=true][id.type='Identifier']"(node) {
                    if ((node.parent &&
                        node.parent.type === utils_1.AST_NODE_TYPES.TSModuleDeclaration) ||
                        (allowDefinitionFiles && util.isDefinitionFile(filename)) ||
                        (allowDeclarations && isDeclaration(node))) {
                        return;
                    }
                    context.report({
                        node,
                        messageId: 'moduleSyntaxIsPreferred',
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-non-null-asserted-nullish-coalescing.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const scope_manager_1 = require(861) /* @typescript-eslint/scope-manager */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    function hasAssignmentBeforeNode(variable, node) {
        return (variable.references.some(ref => ref.isWrite() && ref.identifier.range[1] < node.range[1]) ||
            variable.defs.some(def => isDefinitionWithAssignment(def) && def.node.range[1] < node.range[1]));
    }
    function isDefinitionWithAssignment(definition) {
        if (definition.type !== scope_manager_1.DefinitionType.Variable) {
            return false;
        }
        const variableDeclarator = definition.node;
        return (variableDeclarator.definite === true || variableDeclarator.init != null);
    }
    exports.default = util.createRule({
        name: 'no-non-null-asserted-nullish-coalescing',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow non-null assertions in the left operand of a nullish coalescing operator',
                recommended: 'strict',
            },
            messages: {
                noNonNullAssertedNullishCoalescing: 'The nullish coalescing operator is designed to handle undefined and null - using a non-null assertion is not needed.',
                suggestRemovingNonNull: 'Remove the non-null assertion.',
            },
            schema: [],
            hasSuggestions: true,
        },
        defaultOptions: [],
        create(context) {
            return {
                'LogicalExpression[operator = "??"] > TSNonNullExpression.left'(node) {
                    if (node.expression.type === utils_1.TSESTree.AST_NODE_TYPES.Identifier) {
                        const scope = context.getScope();
                        const identifier = node.expression;
                        const variable = utils_1.ASTUtils.findVariable(scope, identifier.name);
                        if (variable && !hasAssignmentBeforeNode(variable, node)) {
                            return;
                        }
                    }
                    const sourceCode = context.getSourceCode();
                    context.report({
                        node,
                        messageId: 'noNonNullAssertedNullishCoalescing',
                        /*
                        Use a suggestion instead of a fixer, because this can break type checks.
                        The resulting type of the nullish coalesce is only influenced by the right operand if the left operand can be `null` or `undefined`.
                        After removing the non-null assertion the type of the left operand might contain `null` or `undefined` and then the type of the right operand
                        might change the resulting type of the nullish coalesce.
                        See the following example:
              
                        function test(x?: string): string {
                          const bar = x! ?? false; // type analysis reports `bar` has type `string`
                          //          x  ?? false; // type analysis reports `bar` has type `string | false`
                          return bar;
                        }
                        */
                        suggest: [
                            {
                                messageId: 'suggestRemovingNonNull',
                                fix(fixer) {
                                    const exclamationMark = util.nullThrows(sourceCode.getLastToken(node, utils_1.ASTUtils.isNonNullAssertionPunctuator), util.NullThrowsReasons.MissingToken('!', 'Non-null Assertion'));
                                    return fixer.remove(exclamationMark);
                                },
                            },
                        ],
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-non-null-asserted-optional-chain.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const semver = __importStar(require(802) /* semver */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    const is3dot9 = semver.satisfies(ts.version, `>= 3.9.0 || >= 3.9.1-rc || >= 3.9.0-beta`, {
        includePrerelease: true,
    });
    exports.default = util.createRule({
        name: 'no-non-null-asserted-optional-chain',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow non-null assertions after an optional chain expression',
                recommended: 'error',
            },
            hasSuggestions: true,
            messages: {
                noNonNullOptionalChain: 'Optional chain expressions can return undefined by design - using a non-null assertion is unsafe and wrong.',
                suggestRemovingNonNull: 'You should remove the non-null assertion.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            // TS3.9 made a breaking change to how non-null works with optional chains.
            // Pre-3.9,  `x?.y!.z` means `(x?.y).z` - i.e. it essentially scrubbed the optionality from the chain
            // Post-3.9, `x?.y!.z` means `x?.y!.z`  - i.e. it just asserts that the property `y` is non-null, not the result of `x?.y`.
            // This means that for > 3.9, x?.y!.z is valid!
            //
            // NOTE: these cases are still invalid for 3.9:
            // - x?.y.z!
            // - (x?.y)!.z
            const baseSelectors = {
                // non-nulling a wrapped chain will scrub all nulls introduced by the chain
                // (x?.y)!
                // (x?.())!
                'TSNonNullExpression > ChainExpression'(node) {
                    // selector guarantees this assertion
                    const parent = node.parent;
                    context.report({
                        node,
                        messageId: 'noNonNullOptionalChain',
                        // use a suggestion instead of a fixer, because this can obviously break type checks
                        suggest: [
                            {
                                messageId: 'suggestRemovingNonNull',
                                fix(fixer) {
                                    return fixer.removeRange([
                                        parent.range[1] - 1,
                                        parent.range[1],
                                    ]);
                                },
                            },
                        ],
                    });
                },
                // non-nulling at the end of a chain will scrub all nulls introduced by the chain
                // x?.y!
                // x?.()!
                'ChainExpression > TSNonNullExpression'(node) {
                    context.report({
                        node,
                        messageId: 'noNonNullOptionalChain',
                        // use a suggestion instead of a fixer, because this can obviously break type checks
                        suggest: [
                            {
                                messageId: 'suggestRemovingNonNull',
                                fix(fixer) {
                                    return fixer.removeRange([node.range[1] - 1, node.range[1]]);
                                },
                            },
                        ],
                    });
                },
            };
            if (is3dot9) {
                return baseSelectors;
            }
            return Object.assign(Object.assign({}, baseSelectors), { [[
                    // > :not(ChainExpression) because that case is handled by a previous selector
                    'MemberExpression > TSNonNullExpression.object > :not(ChainExpression)',
                    'CallExpression > TSNonNullExpression.callee > :not(ChainExpression)',
                ].join(', ')](child) {
                    // selector guarantees this assertion
                    const node = child.parent;
                    let current = child;
                    while (current) {
                        switch (current.type) {
                            case utils_1.AST_NODE_TYPES.MemberExpression:
                                if (current.optional) {
                                    // found an optional chain! stop traversing
                                    break;
                                }
                                current = current.object;
                                continue;
                            case utils_1.AST_NODE_TYPES.CallExpression:
                                if (current.optional) {
                                    // found an optional chain! stop traversing
                                    break;
                                }
                                current = current.callee;
                                continue;
                            default:
                                // something that's not a ChainElement, which means this is not an optional chain we want to check
                                return;
                        }
                    }
                    context.report({
                        node,
                        messageId: 'noNonNullOptionalChain',
                        // use a suggestion instead of a fixer, because this can obviously break type checks
                        suggest: [
                            {
                                messageId: 'suggestRemovingNonNull',
                                fix(fixer) {
                                    return fixer.removeRange([node.range[1] - 1, node.range[1]]);
                                },
                            },
                        ],
                    });
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-non-null-assertion.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-non-null-assertion',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow non-null assertions using the `!` postfix operator',
                recommended: 'warn',
            },
            hasSuggestions: true,
            messages: {
                noNonNull: 'Forbidden non-null assertion.',
                suggestOptionalChain: 'Consider using the optional chain operator `?.` instead. This operator includes runtime checks, so it is safer than the compile-only non-null assertion operator.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                TSNonNullExpression(node) {
                    var _a, _b;
                    const suggest = [];
                    function convertTokenToOptional(replacement) {
                        return (fixer) => {
                            const operator = sourceCode.getTokenAfter(node.expression, util.isNonNullAssertionPunctuator);
                            if (operator) {
                                return fixer.replaceText(operator, replacement);
                            }
                            return null;
                        };
                    }
                    function removeToken() {
                        return (fixer) => {
                            const operator = sourceCode.getTokenAfter(node.expression, util.isNonNullAssertionPunctuator);
                            if (operator) {
                                return fixer.remove(operator);
                            }
                            return null;
                        };
                    }
                    if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.MemberExpression &&
                        node.parent.object === node) {
                        if (!node.parent.optional) {
                            if (node.parent.computed) {
                                // it is x![y]?.z
                                suggest.push({
                                    messageId: 'suggestOptionalChain',
                                    fix: convertTokenToOptional('?.'),
                                });
                            }
                            else {
                                // it is x!.y?.z
                                suggest.push({
                                    messageId: 'suggestOptionalChain',
                                    fix: convertTokenToOptional('?'),
                                });
                            }
                        }
                        else {
                            if (node.parent.computed) {
                                // it is x!?.[y].z
                                suggest.push({
                                    messageId: 'suggestOptionalChain',
                                    fix: removeToken(),
                                });
                            }
                            else {
                                // it is x!?.y.z
                                suggest.push({
                                    messageId: 'suggestOptionalChain',
                                    fix: removeToken(),
                                });
                            }
                        }
                    }
                    else if (((_b = node.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.CallExpression &&
                        node.parent.callee === node) {
                        if (!node.parent.optional) {
                            // it is x.y?.z!()
                            suggest.push({
                                messageId: 'suggestOptionalChain',
                                fix: convertTokenToOptional('?.'),
                            });
                        }
                        else {
                            // it is x.y.z!?.()
                            suggest.push({
                                messageId: 'suggestOptionalChain',
                                fix: removeToken(),
                            });
                        }
                    }
                    context.report({
                        node,
                        messageId: 'noNonNull',
                        suggest,
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-parameter-properties.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-parameter-properties',
        meta: {
            deprecated: true,
            replacedBy: ['@typescript-eslint/parameter-properties'],
            type: 'problem',
            docs: {
                description: 'Disallow the use of parameter properties in class constructors',
                // too opinionated to be recommended
                recommended: false,
            },
            messages: {
                noParamProp: 'Property {{parameter}} cannot be declared in the constructor.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allows: {
                            type: 'array',
                            items: {
                                enum: [
                                    'readonly',
                                    'private',
                                    'protected',
                                    'public',
                                    'private readonly',
                                    'protected readonly',
                                    'public readonly',
                                ],
                            },
                            minItems: 1,
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                allows: [],
            },
        ],
        create(context, [{ allows }]) {
            /**
             * Gets the modifiers of `node`.
             * @param node the node to be inspected.
             */
            function getModifiers(node) {
                const modifiers = [];
                if (node.accessibility) {
                    modifiers.push(node.accessibility);
                }
                if (node.readonly) {
                    modifiers.push('readonly');
                }
                return modifiers.filter(Boolean).join(' ');
            }
            return {
                TSParameterProperty(node) {
                    const modifiers = getModifiers(node);
                    if (!allows.includes(modifiers)) {
                        // HAS to be an identifier or assignment or TSC will throw
                        if (node.parameter.type !== utils_1.AST_NODE_TYPES.Identifier &&
                            node.parameter.type !== utils_1.AST_NODE_TYPES.AssignmentPattern) {
                            return;
                        }
                        const name = node.parameter.type === utils_1.AST_NODE_TYPES.Identifier
                            ? node.parameter.name
                            : // has to be an Identifier or TSC will throw an error
                                node.parameter.left.name;
                        context.report({
                            node,
                            messageId: 'noParamProp',
                            data: {
                                parameter: name,
                            },
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-redeclare.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-redeclare',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow variable redeclaration',
                recommended: false,
                extendsBaseRule: true,
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        builtinGlobals: {
                            type: 'boolean',
                        },
                        ignoreDeclarationMerge: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
            messages: {
                redeclared: "'{{id}}' is already defined.",
                redeclaredAsBuiltin: "'{{id}}' is already defined as a built-in global variable.",
                redeclaredBySyntax: "'{{id}}' is already defined by a variable declaration.",
            },
        },
        defaultOptions: [
            {
                builtinGlobals: true,
                ignoreDeclarationMerge: true,
            },
        ],
        create(context, [options]) {
            const sourceCode = context.getSourceCode();
            const CLASS_DECLARATION_MERGE_NODES = new Set([
                utils_1.AST_NODE_TYPES.TSInterfaceDeclaration,
                utils_1.AST_NODE_TYPES.TSModuleDeclaration,
                utils_1.AST_NODE_TYPES.ClassDeclaration,
            ]);
            const FUNCTION_DECLARATION_MERGE_NODES = new Set([
                utils_1.AST_NODE_TYPES.TSModuleDeclaration,
                utils_1.AST_NODE_TYPES.FunctionDeclaration,
            ]);
            const ENUM_DECLARATION_MERGE_NODES = new Set([
                utils_1.AST_NODE_TYPES.TSEnumDeclaration,
                utils_1.AST_NODE_TYPES.TSModuleDeclaration,
            ]);
            function* iterateDeclarations(variable) {
                if ((options === null || options === void 0 ? void 0 : options.builtinGlobals) &&
                    'eslintImplicitGlobalSetting' in variable &&
                    (variable.eslintImplicitGlobalSetting === 'readonly' ||
                        variable.eslintImplicitGlobalSetting === 'writable')) {
                    yield { type: 'builtin' };
                }
                if ('eslintExplicitGlobalComments' in variable &&
                    variable.eslintExplicitGlobalComments) {
                    for (const comment of variable.eslintExplicitGlobalComments) {
                        yield {
                            type: 'comment',
                            node: comment,
                            loc: util.getNameLocationInGlobalDirectiveComment(sourceCode, comment, variable.name),
                        };
                    }
                }
                const identifiers = variable.identifiers
                    .map(id => ({
                    identifier: id,
                    parent: id.parent,
                }))
                    // ignore function declarations because TS will treat them as an overload
                    .filter(({ parent }) => parent.type !== utils_1.AST_NODE_TYPES.TSDeclareFunction);
                if (options.ignoreDeclarationMerge && identifiers.length > 1) {
                    if (
                    // interfaces merging
                    identifiers.every(({ parent }) => parent.type === utils_1.AST_NODE_TYPES.TSInterfaceDeclaration)) {
                        return;
                    }
                    if (
                    // namespace/module merging
                    identifiers.every(({ parent }) => parent.type === utils_1.AST_NODE_TYPES.TSModuleDeclaration)) {
                        return;
                    }
                    if (
                    // class + interface/namespace merging
                    identifiers.every(({ parent }) => CLASS_DECLARATION_MERGE_NODES.has(parent.type))) {
                        const classDecls = identifiers.filter(({ parent }) => parent.type === utils_1.AST_NODE_TYPES.ClassDeclaration);
                        if (classDecls.length === 1) {
                            // safe declaration merging
                            return;
                        }
                        // there's more than one class declaration, which needs to be reported
                        for (const { identifier } of classDecls) {
                            yield { type: 'syntax', node: identifier, loc: identifier.loc };
                        }
                        return;
                    }
                    if (
                    // class + interface/namespace merging
                    identifiers.every(({ parent }) => FUNCTION_DECLARATION_MERGE_NODES.has(parent.type))) {
                        const functionDecls = identifiers.filter(({ parent }) => parent.type === utils_1.AST_NODE_TYPES.FunctionDeclaration);
                        if (functionDecls.length === 1) {
                            // safe declaration merging
                            return;
                        }
                        // there's more than one function declaration, which needs to be reported
                        for (const { identifier } of functionDecls) {
                            yield { type: 'syntax', node: identifier, loc: identifier.loc };
                        }
                        return;
                    }
                    if (
                    // enum + namespace merging
                    identifiers.every(({ parent }) => ENUM_DECLARATION_MERGE_NODES.has(parent.type))) {
                        const enumDecls = identifiers.filter(({ parent }) => parent.type === utils_1.AST_NODE_TYPES.TSEnumDeclaration);
                        if (enumDecls.length === 1) {
                            // safe declaration merging
                            return;
                        }
                        // there's more than one enum declaration, which needs to be reported
                        for (const { identifier } of enumDecls) {
                            yield { type: 'syntax', node: identifier, loc: identifier.loc };
                        }
                        return;
                    }
                }
                for (const { identifier } of identifiers) {
                    yield { type: 'syntax', node: identifier, loc: identifier.loc };
                }
            }
            function findVariablesInScope(scope) {
                for (const variable of scope.variables) {
                    const [declaration, ...extraDeclarations] = iterateDeclarations(variable);
                    if (extraDeclarations.length === 0) {
                        continue;
                    }
                    /*
                     * If the type of a declaration is different from the type of
                     * the first declaration, it shows the location of the first
                     * declaration.
                     */
                    const detailMessageId = declaration.type === 'builtin'
                        ? 'redeclaredAsBuiltin'
                        : 'redeclaredBySyntax';
                    const data = { id: variable.name };
                    // Report extra declarations.
                    for (const { type, node, loc } of extraDeclarations) {
                        const messageId = type === declaration.type ? 'redeclared' : detailMessageId;
                        if (node) {
                            context.report({ node, loc, messageId, data });
                        }
                        else if (loc) {
                            context.report({ loc, messageId, data });
                        }
                    }
                }
            }
            /**
             * Find variables in the current scope.
             */
            function checkForBlock(node) {
                const scope = context.getScope();
                /*
                 * In ES5, some node type such as `BlockStatement` doesn't have that scope.
                 * `scope.block` is a different node in such a case.
                 */
                if (scope.block === node) {
                    findVariablesInScope(scope);
                }
            }
            return {
                Program() {
                    const scope = context.getScope();
                    findVariablesInScope(scope);
                    // Node.js or ES modules has a special scope.
                    if (scope.type === 'global' &&
                        scope.childScopes[0] &&
                        // The special scope's block is the Program node.
                        scope.block === scope.childScopes[0].block) {
                        findVariablesInScope(scope.childScopes[0]);
                    }
                },
                FunctionDeclaration: checkForBlock,
                FunctionExpression: checkForBlock,
                ArrowFunctionExpression: checkForBlock,
                BlockStatement: checkForBlock,
                ForStatement: checkForBlock,
                ForInStatement: checkForBlock,
                ForOfStatement: checkForBlock,
                SwitchStatement: checkForBlock,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-redundant-type-constituents.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    const literalToPrimitiveTypeFlags = {
        [ts.TypeFlags.BigIntLiteral]: ts.TypeFlags.BigInt,
        [ts.TypeFlags.BooleanLiteral]: ts.TypeFlags.Boolean,
        [ts.TypeFlags.NumberLiteral]: ts.TypeFlags.Number,
        [ts.TypeFlags.StringLiteral]: ts.TypeFlags.String,
        [ts.TypeFlags.TemplateLiteral]: ts.TypeFlags.String,
    };
    const literalTypeFlags = [
        ts.TypeFlags.BigIntLiteral,
        ts.TypeFlags.BooleanLiteral,
        ts.TypeFlags.NumberLiteral,
        ts.TypeFlags.StringLiteral,
        ts.TypeFlags.TemplateLiteral,
    ];
    const primitiveTypeFlags = [
        ts.TypeFlags.BigInt,
        ts.TypeFlags.Boolean,
        ts.TypeFlags.Number,
        ts.TypeFlags.String,
    ];
    const primitiveTypeFlagNames = {
        [ts.TypeFlags.BigInt]: 'bigint',
        [ts.TypeFlags.Boolean]: 'boolean',
        [ts.TypeFlags.Number]: 'number',
        [ts.TypeFlags.String]: 'string',
    };
    const primitiveTypeFlagTypes = {
        bigint: ts.TypeFlags.BigIntLiteral,
        boolean: ts.TypeFlags.BooleanLiteral,
        number: ts.TypeFlags.NumberLiteral,
        string: ts.TypeFlags.StringLiteral,
    };
    const keywordNodeTypesToTsTypes = new Map([
        [utils_1.TSESTree.AST_NODE_TYPES.TSAnyKeyword, ts.TypeFlags.Any],
        [utils_1.TSESTree.AST_NODE_TYPES.TSBigIntKeyword, ts.TypeFlags.BigInt],
        [utils_1.TSESTree.AST_NODE_TYPES.TSBooleanKeyword, ts.TypeFlags.Boolean],
        [utils_1.TSESTree.AST_NODE_TYPES.TSNeverKeyword, ts.TypeFlags.Never],
        [utils_1.TSESTree.AST_NODE_TYPES.TSUnknownKeyword, ts.TypeFlags.Unknown],
        [utils_1.TSESTree.AST_NODE_TYPES.TSNumberKeyword, ts.TypeFlags.Number],
        [utils_1.TSESTree.AST_NODE_TYPES.TSStringKeyword, ts.TypeFlags.String],
    ]);
    function addToMapGroup(map, key, value) {
        const existing = map.get(key);
        if (existing) {
            existing.push(value);
        }
        else {
            map.set(key, [value]);
        }
    }
    function describeLiteralType(type) {
        if (type.isStringLiteral()) {
            return JSON.stringify(type.value);
        }
        if (util.isTypeBigIntLiteralType(type)) {
            return `${type.value.negative ? '-' : ''}${type.value.base10Value}n`;
        }
        if (type.isLiteral()) {
            return type.value.toString();
        }
        if (util.isTypeAnyType(type)) {
            return 'any';
        }
        if (util.isTypeNeverType(type)) {
            return 'never';
        }
        if (util.isTypeUnknownType(type)) {
            return 'unknown';
        }
        if (util.isTypeTemplateLiteralType(type)) {
            return 'template literal type';
        }
        if (tsutils.isBooleanLiteralType(type, true)) {
            return 'true';
        }
        if (tsutils.isBooleanLiteralType(type, false)) {
            return 'false';
        }
        return 'literal type';
    }
    function describeLiteralTypeNode(typeNode) {
        switch (typeNode.type) {
            case utils_1.AST_NODE_TYPES.TSAnyKeyword:
                return 'any';
            case utils_1.AST_NODE_TYPES.TSBooleanKeyword:
                return 'boolean';
            case utils_1.AST_NODE_TYPES.TSNeverKeyword:
                return 'never';
            case utils_1.AST_NODE_TYPES.TSNumberKeyword:
                return 'number';
            case utils_1.AST_NODE_TYPES.TSStringKeyword:
                return 'string';
            case utils_1.AST_NODE_TYPES.TSUnknownKeyword:
                return 'unknown';
            case utils_1.AST_NODE_TYPES.TSLiteralType:
                switch (typeNode.literal.type) {
                    case utils_1.TSESTree.AST_NODE_TYPES.Literal:
                        switch (typeof typeNode.literal.value) {
                            case 'bigint':
                                return `${typeNode.literal.value < 0 ? '-' : ''}${typeNode.literal.value}n`;
                            case 'string':
                                return JSON.stringify(typeNode.literal.value);
                            default:
                                return `${typeNode.literal.value}`;
                        }
                    case utils_1.TSESTree.AST_NODE_TYPES.TemplateLiteral:
                        return 'template literal type';
                }
        }
        return 'literal type';
    }
    function isNodeInsideReturnType(node) {
        var _a;
        return !!(((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.TSTypeAnnotation &&
            node.parent.parent &&
            (util.isFunctionType(node.parent.parent) ||
                util.isFunction(node.parent.parent)));
    }
    /**
     * @remarks TypeScript stores boolean types as the union false | true, always.
     */
    function unionTypePartsUnlessBoolean(type) {
        return type.isUnion() &&
            type.types.length === 2 &&
            tsutils.isBooleanLiteralType(type.types[0], false) &&
            tsutils.isBooleanLiteralType(type.types[1], true)
            ? [type]
            : tsutils.unionTypeParts(type);
    }
    exports.default = util.createRule({
        name: 'no-redundant-type-constituents',
        meta: {
            docs: {
                description: 'Disallow members of unions and intersections that do nothing or override type information',
                recommended: false,
                requiresTypeChecking: true,
            },
            messages: {
                literalOverridden: `{{literal}} is overridden by {{primitive}} in this union type.`,
                primitiveOverridden: `{{primitive}} is overridden by the {{literal}} in this intersection type.`,
                overridden: `'{{typeName}}' is overridden by other types in this {{container}} type.`,
                overrides: `'{{typeName}}' overrides all other types in this {{container}} type.`,
            },
            schema: [],
            type: 'suggestion',
        },
        defaultOptions: [],
        create(context) {
            const parserServices = util.getParserServices(context);
            const typesCache = new Map();
            function getTypeNodeTypePartFlags(typeNode) {
                const keywordTypeFlags = keywordNodeTypesToTsTypes.get(typeNode.type);
                if (keywordTypeFlags) {
                    return [
                        {
                            typeFlags: keywordTypeFlags,
                            typeName: describeLiteralTypeNode(typeNode),
                        },
                    ];
                }
                if (typeNode.type === utils_1.AST_NODE_TYPES.TSLiteralType &&
                    typeNode.literal.type === utils_1.AST_NODE_TYPES.Literal) {
                    return [
                        {
                            typeFlags: primitiveTypeFlagTypes[typeof typeNode.literal
                                .value],
                            typeName: describeLiteralTypeNode(typeNode),
                        },
                    ];
                }
                if (typeNode.type === utils_1.AST_NODE_TYPES.TSUnionType) {
                    return typeNode.types.flatMap(getTypeNodeTypePartFlags);
                }
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(typeNode);
                const checker = parserServices.program.getTypeChecker();
                const nodeType = checker.getTypeAtLocation(tsNode);
                const typeParts = unionTypePartsUnlessBoolean(nodeType);
                return typeParts.map(typePart => ({
                    typeFlags: typePart.flags,
                    typeName: describeLiteralType(typePart),
                }));
            }
            function getTypeNodeTypePartFlagsCached(typeNode) {
                const existing = typesCache.get(typeNode);
                if (existing) {
                    return existing;
                }
                const created = getTypeNodeTypePartFlags(typeNode);
                typesCache.set(typeNode, created);
                return created;
            }
            return {
                'TSIntersectionType:exit'(node) {
                    const seenLiteralTypes = new Map();
                    const seenPrimitiveTypes = new Map();
                    function checkIntersectionBottomAndTopTypes({ typeFlags, typeName }, typeNode) {
                        for (const [messageId, checkFlag] of [
                            ['overrides', ts.TypeFlags.Any],
                            ['overrides', ts.TypeFlags.Never],
                            ['overridden', ts.TypeFlags.Unknown],
                        ]) {
                            if (typeFlags === checkFlag) {
                                context.report({
                                    data: {
                                        container: 'intersection',
                                        typeName,
                                    },
                                    messageId,
                                    node: typeNode,
                                });
                                return true;
                            }
                        }
                        return false;
                    }
                    for (const typeNode of node.types) {
                        const typePartFlags = getTypeNodeTypePartFlagsCached(typeNode);
                        for (const typePart of typePartFlags) {
                            if (checkIntersectionBottomAndTopTypes(typePart, typeNode)) {
                                continue;
                            }
                            for (const literalTypeFlag of literalTypeFlags) {
                                if (typePart.typeFlags === literalTypeFlag) {
                                    addToMapGroup(seenLiteralTypes, literalToPrimitiveTypeFlags[literalTypeFlag], typePart.typeName);
                                    break;
                                }
                            }
                            for (const primitiveTypeFlag of primitiveTypeFlags) {
                                if (typePart.typeFlags === primitiveTypeFlag) {
                                    addToMapGroup(seenPrimitiveTypes, primitiveTypeFlag, typeNode);
                                }
                            }
                        }
                    }
                    // For each primitive type of all the seen primitive types,
                    // if there was a literal type seen that overrides it,
                    // report each of the primitive type's type nodes
                    for (const [primitiveTypeFlag, typeNodes] of seenPrimitiveTypes) {
                        const matchedLiteralTypes = seenLiteralTypes.get(primitiveTypeFlag);
                        if (matchedLiteralTypes) {
                            for (const typeNode of typeNodes) {
                                context.report({
                                    data: {
                                        literal: matchedLiteralTypes.join(' | '),
                                        primitive: primitiveTypeFlagNames[primitiveTypeFlag],
                                    },
                                    messageId: 'primitiveOverridden',
                                    node: typeNode,
                                });
                            }
                        }
                    }
                },
                'TSUnionType:exit'(node) {
                    const seenLiteralTypes = new Map();
                    const seenPrimitiveTypes = new Set();
                    function checkUnionBottomAndTopTypes({ typeFlags, typeName }, typeNode) {
                        for (const checkFlag of [
                            ts.TypeFlags.Any,
                            ts.TypeFlags.Unknown,
                        ]) {
                            if (typeFlags === checkFlag) {
                                context.report({
                                    data: {
                                        container: 'union',
                                        typeName,
                                    },
                                    messageId: 'overrides',
                                    node: typeNode,
                                });
                                return true;
                            }
                        }
                        if (typeFlags === ts.TypeFlags.Never &&
                            !isNodeInsideReturnType(node)) {
                            context.report({
                                data: {
                                    container: 'union',
                                    typeName: 'never',
                                },
                                messageId: 'overridden',
                                node: typeNode,
                            });
                            return true;
                        }
                        return false;
                    }
                    for (const typeNode of node.types) {
                        const typePartFlags = getTypeNodeTypePartFlagsCached(typeNode);
                        for (const typePart of typePartFlags) {
                            if (checkUnionBottomAndTopTypes(typePart, typeNode)) {
                                continue;
                            }
                            for (const literalTypeFlag of literalTypeFlags) {
                                if (typePart.typeFlags === literalTypeFlag) {
                                    addToMapGroup(seenLiteralTypes, literalToPrimitiveTypeFlags[literalTypeFlag], {
                                        literalValue: typePart.typeName,
                                        typeNode,
                                    });
                                    break;
                                }
                            }
                            for (const primitiveTypeFlag of primitiveTypeFlags) {
                                if ((typePart.typeFlags & primitiveTypeFlag) !== 0) {
                                    seenPrimitiveTypes.add(primitiveTypeFlag);
                                }
                            }
                        }
                    }
                    const overriddenTypeNodes = new Map();
                    // For each primitive type of all the seen literal types,
                    // if there was a primitive type seen that overrides it,
                    // upsert the literal text and primitive type under the backing type node
                    for (const [primitiveTypeFlag, typeNodesWithText] of seenLiteralTypes) {
                        if (seenPrimitiveTypes.has(primitiveTypeFlag)) {
                            for (const { literalValue, typeNode } of typeNodesWithText) {
                                addToMapGroup(overriddenTypeNodes, typeNode, {
                                    literalValue,
                                    primitiveTypeFlag,
                                });
                            }
                        }
                    }
                    // For each type node that had at least one overridden literal,
                    // group those literals by their primitive type,
                    // then report each primitive type with all its literals
                    for (const [typeNode, typeFlagsWithText] of overriddenTypeNodes) {
                        const grouped = util.arrayGroupByToMap(typeFlagsWithText, pair => pair.primitiveTypeFlag);
                        for (const [primitiveTypeFlag, pairs] of grouped) {
                            context.report({
                                data: {
                                    literal: pairs.map(pair => pair.literalValue).join(' | '),
                                    primitive: primitiveTypeFlagNames[primitiveTypeFlag],
                                },
                                messageId: 'literalOverridden',
                                node: typeNode,
                            });
                        }
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-require-imports.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-require-imports',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow invocation of `require()`',
                recommended: false,
            },
            schema: [],
            messages: {
                noRequireImports: 'A `require()` style import is forbidden.',
            },
        },
        defaultOptions: [],
        create(context) {
            return {
                'CallExpression[callee.name="require"]'(node) {
                    const variable = utils_1.ASTUtils.findVariable(context.getScope(), 'require');
                    // ignore non-global require usage as it's something user-land custom instead
                    // of the commonjs standard
                    if (!(variable === null || variable === void 0 ? void 0 : variable.identifiers.length)) {
                        context.report({
                            node,
                            messageId: 'noRequireImports',
                        });
                    }
                },
                TSExternalModuleReference(node) {
                    context.report({
                        node,
                        messageId: 'noRequireImports',
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-restricted-imports.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const ignore_1 = __importDefault(require(228) /* ignore */);
    const util_1 = require(1018) /* ../util */;
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-restricted-imports');
    const allowTypeImportsOptionSchema = {
        allowTypeImports: {
            type: 'boolean',
            default: false,
        },
    };
    const schemaForMergeArrayOfStringsOrObjects = {
        items: {
            anyOf: [
                {},
                {
                    properties: allowTypeImportsOptionSchema,
                },
            ],
        },
    };
    const schemaForMergeArrayOfStringsOrObjectPatterns = {
        anyOf: [
            {},
            {
                items: {
                    properties: allowTypeImportsOptionSchema,
                },
            },
        ],
    };
    const schema = (0, util_1.deepMerge)(Object.assign({}, baseRule.meta.schema), {
        anyOf: [
            schemaForMergeArrayOfStringsOrObjects,
            {
                items: {
                    properties: {
                        paths: schemaForMergeArrayOfStringsOrObjects,
                        patterns: schemaForMergeArrayOfStringsOrObjectPatterns,
                    },
                },
            },
        ],
    });
    function isObjectOfPaths(obj) {
        return Object.prototype.hasOwnProperty.call(obj, 'paths');
    }
    function isObjectOfPatterns(obj) {
        return Object.prototype.hasOwnProperty.call(obj, 'patterns');
    }
    function isOptionsArrayOfStringOrObject(options) {
        if (isObjectOfPaths(options[0])) {
            return false;
        }
        if (isObjectOfPatterns(options[0])) {
            return false;
        }
        return true;
    }
    function getRestrictedPaths(options) {
        if (isOptionsArrayOfStringOrObject(options)) {
            return options;
        }
        if (isObjectOfPaths(options[0])) {
            return options[0].paths;
        }
        return [];
    }
    function getRestrictedPatterns(options) {
        if (isObjectOfPatterns(options[0])) {
            return options[0].patterns;
        }
        return [];
    }
    exports.default = (0, util_1.createRule)({
        name: 'no-restricted-imports',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow specified modules when loaded by `import`',
                recommended: false,
                extendsBaseRule: true,
            },
            messages: baseRule.meta.messages,
            fixable: baseRule.meta.fixable,
            schema,
        },
        defaultOptions: [],
        create(context) {
            const rules = baseRule.create(context);
            const { options } = context;
            if (options.length === 0) {
                return {};
            }
            const restrictedPaths = getRestrictedPaths(options);
            const allowedTypeImportPathNameSet = new Set();
            for (const restrictedPath of restrictedPaths) {
                if (typeof restrictedPath === 'object' &&
                    restrictedPath.allowTypeImports) {
                    allowedTypeImportPathNameSet.add(restrictedPath.name);
                }
            }
            function isAllowedTypeImportPath(importSource) {
                return allowedTypeImportPathNameSet.has(importSource);
            }
            const restrictedPatterns = getRestrictedPatterns(options);
            const allowedImportTypeMatchers = [];
            for (const restrictedPattern of restrictedPatterns) {
                if (typeof restrictedPattern === 'object' &&
                    restrictedPattern.allowTypeImports) {
                    // Following how ignore is configured in the base rule
                    allowedImportTypeMatchers.push((0, ignore_1.default)({
                        allowRelativePaths: true,
                        ignoreCase: !restrictedPattern.caseSensitive,
                    }).add(restrictedPattern.group));
                }
            }
            function isAllowedTypeImportPattern(importSource) {
                return (
                // As long as there's one matching pattern that allows type import
                allowedImportTypeMatchers.some(matcher => matcher.ignores(importSource)));
            }
            return {
                ImportDeclaration(node) {
                    if (node.importKind === 'type') {
                        const importSource = node.source.value.trim();
                        if (!isAllowedTypeImportPath(importSource) &&
                            !isAllowedTypeImportPattern(importSource)) {
                            return rules.ImportDeclaration(node);
                        }
                    }
                    else {
                        return rules.ImportDeclaration(node);
                    }
                },
                'ExportNamedDeclaration[source]'(node) {
                    if (node.exportKind === 'type') {
                        const importSource = node.source.value.trim();
                        if (!isAllowedTypeImportPath(importSource) &&
                            !isAllowedTypeImportPattern(importSource)) {
                            return rules.ExportNamedDeclaration(node);
                        }
                    }
                    else {
                        return rules.ExportNamedDeclaration(node);
                    }
                },
                ExportAllDeclaration: rules.ExportAllDeclaration,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-shadow.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const scope_manager_1 = require(861) /* @typescript-eslint/scope-manager */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const allowedFunctionVariableDefTypes = new Set([
        utils_1.AST_NODE_TYPES.TSCallSignatureDeclaration,
        utils_1.AST_NODE_TYPES.TSFunctionType,
        utils_1.AST_NODE_TYPES.TSMethodSignature,
    ]);
    exports.default = util.createRule({
        name: 'no-shadow',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow variable declarations from shadowing variables declared in the outer scope',
                recommended: false,
                extendsBaseRule: true,
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        builtinGlobals: {
                            type: 'boolean',
                        },
                        hoist: {
                            enum: ['all', 'functions', 'never'],
                        },
                        allow: {
                            type: 'array',
                            items: {
                                type: 'string',
                            },
                        },
                        ignoreOnInitialization: {
                            type: 'boolean',
                        },
                        ignoreTypeValueShadow: {
                            type: 'boolean',
                        },
                        ignoreFunctionTypeParameterNameValueShadow: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
            messages: {
                noShadow: "'{{name}}' is already declared in the upper scope on line {{shadowedLine}} column {{shadowedColumn}}.",
                noShadowGlobal: "'{{name}}' is already a global variable.",
            },
        },
        defaultOptions: [
            {
                allow: [],
                builtinGlobals: false,
                hoist: 'functions',
                ignoreOnInitialization: false,
                ignoreTypeValueShadow: true,
                ignoreFunctionTypeParameterNameValueShadow: true,
            },
        ],
        create(context, [options]) {
            /**
             * Check if a scope is a TypeScript module augmenting the global namespace.
             */
            function isGlobalAugmentation(scope) {
                return ((scope.type === scope_manager_1.ScopeType.tsModule && !!scope.block.global) ||
                    (!!scope.upper && isGlobalAugmentation(scope.upper)));
            }
            /**
             * Check if variable is a `this` parameter.
             */
            function isThisParam(variable) {
                return (variable.defs[0].type === scope_manager_1.DefinitionType.Parameter &&
                    variable.name === 'this');
            }
            function isTypeImport(definition) {
                return ((definition === null || definition === void 0 ? void 0 : definition.type) === scope_manager_1.DefinitionType.ImportBinding &&
                    (definition.parent.importKind === 'type' ||
                        (definition.node.type === utils_1.AST_NODE_TYPES.ImportSpecifier &&
                            definition.node.importKind === 'type')));
            }
            function isTypeValueShadow(variable, shadowed) {
                if (options.ignoreTypeValueShadow !== true) {
                    return false;
                }
                if (!('isValueVariable' in variable)) {
                    // this shouldn't happen...
                    return false;
                }
                const [firstDefinition] = shadowed.defs;
                const isShadowedValue = !('isValueVariable' in shadowed) ||
                    !firstDefinition ||
                    (!isTypeImport(firstDefinition) && shadowed.isValueVariable);
                return variable.isValueVariable !== isShadowedValue;
            }
            function isFunctionTypeParameterNameValueShadow(variable, shadowed) {
                if (options.ignoreFunctionTypeParameterNameValueShadow !== true) {
                    return false;
                }
                if (!('isValueVariable' in variable)) {
                    // this shouldn't happen...
                    return false;
                }
                const isShadowedValue = 'isValueVariable' in shadowed ? shadowed.isValueVariable : true;
                if (!isShadowedValue) {
                    return false;
                }
                return variable.defs.every(def => allowedFunctionVariableDefTypes.has(def.node.type));
            }
            function isGenericOfStaticMethod(variable) {
                if (!('isTypeVariable' in variable)) {
                    // this shouldn't happen...
                    return false;
                }
                if (!variable.isTypeVariable) {
                    return false;
                }
                if (variable.identifiers.length === 0) {
                    return false;
                }
                const typeParameter = variable.identifiers[0].parent;
                if ((typeParameter === null || typeParameter === void 0 ? void 0 : typeParameter.type) !== utils_1.AST_NODE_TYPES.TSTypeParameter) {
                    return false;
                }
                const typeParameterDecl = typeParameter.parent;
                if ((typeParameterDecl === null || typeParameterDecl === void 0 ? void 0 : typeParameterDecl.type) !== utils_1.AST_NODE_TYPES.TSTypeParameterDeclaration) {
                    return false;
                }
                const functionExpr = typeParameterDecl.parent;
                if (!functionExpr ||
                    (functionExpr.type !== utils_1.AST_NODE_TYPES.FunctionExpression &&
                        functionExpr.type !== utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression)) {
                    return false;
                }
                const methodDefinition = functionExpr.parent;
                if ((methodDefinition === null || methodDefinition === void 0 ? void 0 : methodDefinition.type) !== utils_1.AST_NODE_TYPES.MethodDefinition) {
                    return false;
                }
                return methodDefinition.static;
            }
            function isGenericOfClassDecl(variable) {
                if (!('isTypeVariable' in variable)) {
                    // this shouldn't happen...
                    return false;
                }
                if (!variable.isTypeVariable) {
                    return false;
                }
                if (variable.identifiers.length === 0) {
                    return false;
                }
                const typeParameter = variable.identifiers[0].parent;
                if ((typeParameter === null || typeParameter === void 0 ? void 0 : typeParameter.type) !== utils_1.AST_NODE_TYPES.TSTypeParameter) {
                    return false;
                }
                const typeParameterDecl = typeParameter.parent;
                if ((typeParameterDecl === null || typeParameterDecl === void 0 ? void 0 : typeParameterDecl.type) !== utils_1.AST_NODE_TYPES.TSTypeParameterDeclaration) {
                    return false;
                }
                const classDecl = typeParameterDecl.parent;
                return (classDecl === null || classDecl === void 0 ? void 0 : classDecl.type) === utils_1.AST_NODE_TYPES.ClassDeclaration;
            }
            function isGenericOfAStaticMethodShadow(variable, shadowed) {
                return (isGenericOfStaticMethod(variable) && isGenericOfClassDecl(shadowed));
            }
            function isImportDeclaration(definition) {
                return definition.type === utils_1.AST_NODE_TYPES.ImportDeclaration;
            }
            function isExternalModuleDeclarationWithName(scope, name) {
                return (scope.type === scope_manager_1.ScopeType.tsModule &&
                    scope.block.type === utils_1.AST_NODE_TYPES.TSModuleDeclaration &&
                    scope.block.id.type === utils_1.AST_NODE_TYPES.Literal &&
                    scope.block.id.value === name);
            }
            function isExternalDeclarationMerging(scope, variable, shadowed) {
                var _a;
                const [firstDefinition] = shadowed.defs;
                const [secondDefinition] = variable.defs;
                return (isTypeImport(firstDefinition) &&
                    isImportDeclaration(firstDefinition.parent) &&
                    isExternalModuleDeclarationWithName(scope, firstDefinition.parent.source.value) &&
                    secondDefinition.node.type === utils_1.AST_NODE_TYPES.TSInterfaceDeclaration &&
                    ((_a = secondDefinition.node.parent) === null || _a === void 0 ? void 0 : _a.type) ===
                        utils_1.AST_NODE_TYPES.ExportNamedDeclaration);
            }
            /**
             * Check if variable name is allowed.
             * @param variable The variable to check.
             * @returns Whether or not the variable name is allowed.
             */
            function isAllowed(variable) {
                return options.allow.indexOf(variable.name) !== -1;
            }
            /**
             * Checks if a variable of the class name in the class scope of ClassDeclaration.
             *
             * ClassDeclaration creates two variables of its name into its outer scope and its class scope.
             * So we should ignore the variable in the class scope.
             * @param variable The variable to check.
             * @returns Whether or not the variable of the class name in the class scope of ClassDeclaration.
             */
            function isDuplicatedClassNameVariable(variable) {
                const block = variable.scope.block;
                return (block.type === utils_1.AST_NODE_TYPES.ClassDeclaration &&
                    block.id === variable.identifiers[0]);
            }
            /**
             * Checks if a variable of the class name in the class scope of TSEnumDeclaration.
             *
             * TSEnumDeclaration creates two variables of its name into its outer scope and its class scope.
             * So we should ignore the variable in the class scope.
             * @param variable The variable to check.
             * @returns Whether or not the variable of the class name in the class scope of TSEnumDeclaration.
             */
            function isDuplicatedEnumNameVariable(variable) {
                const block = variable.scope.block;
                return (block.type === utils_1.AST_NODE_TYPES.TSEnumDeclaration &&
                    block.id === variable.identifiers[0]);
            }
            /**
             * Checks whether or not a given location is inside of the range of a given node.
             * @param node An node to check.
             * @param location A location to check.
             * @returns `true` if the location is inside of the range of the node.
             */
            function isInRange(node, location) {
                return node && node.range[0] <= location && location <= node.range[1];
            }
            /**
             * Searches from the current node through its ancestry to find a matching node.
             * @param node a node to get.
             * @param match a callback that checks whether or not the node verifies its condition or not.
             * @returns the matching node.
             */
            function findSelfOrAncestor(node, match) {
                let currentNode = node;
                while (currentNode && !match(currentNode)) {
                    currentNode = currentNode.parent;
                }
                return currentNode;
            }
            /**
             * Finds function's outer scope.
             * @param scope Function's own scope.
             * @returns Function's outer scope.
             */
            function getOuterScope(scope) {
                const upper = scope.upper;
                if ((upper === null || upper === void 0 ? void 0 : upper.type) === 'function-expression-name') {
                    return upper.upper;
                }
                return upper;
            }
            /**
             * Checks if a variable and a shadowedVariable have the same init pattern ancestor.
             * @param variable a variable to check.
             * @param shadowedVariable a shadowedVariable to check.
             * @returns Whether or not the variable and the shadowedVariable have the same init pattern ancestor.
             */
            function isInitPatternNode(variable, shadowedVariable) {
                var _a, _b, _c, _d;
                const outerDef = shadowedVariable.defs[0];
                if (!outerDef) {
                    return false;
                }
                const { variableScope } = variable.scope;
                if (!((variableScope.block.type ===
                    utils_1.AST_NODE_TYPES.ArrowFunctionExpression ||
                    variableScope.block.type === utils_1.AST_NODE_TYPES.FunctionExpression) &&
                    getOuterScope(variableScope) === shadowedVariable.scope)) {
                    return false;
                }
                const fun = variableScope.block;
                const { parent } = fun;
                const callExpression = findSelfOrAncestor(parent, node => node.type === utils_1.AST_NODE_TYPES.CallExpression);
                if (!callExpression) {
                    return false;
                }
                let node = outerDef.name;
                const location = callExpression.range[1];
                while (node) {
                    if (node.type === utils_1.AST_NODE_TYPES.VariableDeclarator) {
                        if (isInRange(node.init, location)) {
                            return true;
                        }
                        if ((((_b = (_a = node.parent) === null || _a === void 0 ? void 0 : _a.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.ForInStatement ||
                            ((_d = (_c = node.parent) === null || _c === void 0 ? void 0 : _c.parent) === null || _d === void 0 ? void 0 : _d.type) === utils_1.AST_NODE_TYPES.ForOfStatement) &&
                            isInRange(node.parent.parent.right, location)) {
                            return true;
                        }
                        break;
                    }
                    else if (node.type === utils_1.AST_NODE_TYPES.AssignmentPattern) {
                        if (isInRange(node.right, location)) {
                            return true;
                        }
                    }
                    else if ([
                        utils_1.AST_NODE_TYPES.FunctionDeclaration,
                        utils_1.AST_NODE_TYPES.ClassDeclaration,
                        utils_1.AST_NODE_TYPES.FunctionExpression,
                        utils_1.AST_NODE_TYPES.ClassExpression,
                        utils_1.AST_NODE_TYPES.ArrowFunctionExpression,
                        utils_1.AST_NODE_TYPES.CatchClause,
                        utils_1.AST_NODE_TYPES.ImportDeclaration,
                        utils_1.AST_NODE_TYPES.ExportNamedDeclaration,
                    ].includes(node.type)) {
                        break;
                    }
                    node = node.parent;
                }
                return false;
            }
            /**
             * Checks if a variable is inside the initializer of scopeVar.
             *
             * To avoid reporting at declarations such as `var a = function a() {};`.
             * But it should report `var a = function(a) {};` or `var a = function() { function a() {} };`.
             * @param variable The variable to check.
             * @param scopeVar The scope variable to look for.
             * @returns Whether or not the variable is inside initializer of scopeVar.
             */
            function isOnInitializer(variable, scopeVar) {
                var _a;
                const outerScope = scopeVar.scope;
                const outerDef = scopeVar.defs[0];
                const outer = (_a = outerDef === null || outerDef === void 0 ? void 0 : outerDef.parent) === null || _a === void 0 ? void 0 : _a.range;
                const innerScope = variable.scope;
                const innerDef = variable.defs[0];
                const inner = innerDef === null || innerDef === void 0 ? void 0 : innerDef.name.range;
                return !!(outer &&
                    inner &&
                    outer[0] < inner[0] &&
                    inner[1] < outer[1] &&
                    ((innerDef.type === scope_manager_1.DefinitionType.FunctionName &&
                        innerDef.node.type === utils_1.AST_NODE_TYPES.FunctionExpression) ||
                        innerDef.node.type === utils_1.AST_NODE_TYPES.ClassExpression) &&
                    outerScope === innerScope.upper);
            }
            /**
             * Get a range of a variable's identifier node.
             * @param variable The variable to get.
             * @returns The range of the variable's identifier node.
             */
            function getNameRange(variable) {
                const def = variable.defs[0];
                return def === null || def === void 0 ? void 0 : def.name.range;
            }
            /**
             * Checks if a variable is in TDZ of scopeVar.
             * @param variable The variable to check.
             * @param scopeVar The variable of TDZ.
             * @returns Whether or not the variable is in TDZ of scopeVar.
             */
            function isInTdz(variable, scopeVar) {
                const outerDef = scopeVar.defs[0];
                const inner = getNameRange(variable);
                const outer = getNameRange(scopeVar);
                return !!(inner &&
                    outer &&
                    inner[1] < outer[0] &&
                    // Excepts FunctionDeclaration if is {"hoist":"function"}.
                    (options.hoist !== 'functions' ||
                        !outerDef ||
                        outerDef.node.type !== utils_1.AST_NODE_TYPES.FunctionDeclaration));
            }
            /**
             * Get declared line and column of a variable.
             * @param  variable The variable to get.
             * @returns The declared line and column of the variable.
             */
            function getDeclaredLocation(variable) {
                const identifier = variable.identifiers[0];
                if (identifier) {
                    return {
                        global: false,
                        line: identifier.loc.start.line,
                        column: identifier.loc.start.column + 1,
                    };
                }
                else {
                    return {
                        global: true,
                    };
                }
            }
            /**
             * Checks the current context for shadowed variables.
             * @param {Scope} scope Fixme
             */
            function checkForShadows(scope) {
                // ignore global augmentation
                if (isGlobalAugmentation(scope)) {
                    return;
                }
                const variables = scope.variables;
                for (const variable of variables) {
                    // ignore "arguments"
                    if (variable.identifiers.length === 0) {
                        continue;
                    }
                    // this params are pseudo-params that cannot be shadowed
                    if (isThisParam(variable)) {
                        continue;
                    }
                    // ignore variables of a class name in the class scope of ClassDeclaration
                    if (isDuplicatedClassNameVariable(variable)) {
                        continue;
                    }
                    // ignore variables of a class name in the class scope of ClassDeclaration
                    if (isDuplicatedEnumNameVariable(variable)) {
                        continue;
                    }
                    // ignore configured allowed names
                    if (isAllowed(variable)) {
                        continue;
                    }
                    // Gets shadowed variable.
                    const shadowed = scope.upper
                        ? utils_1.ASTUtils.findVariable(scope.upper, variable.name)
                        : null;
                    if (!shadowed) {
                        continue;
                    }
                    // ignore type value variable shadowing if configured
                    if (isTypeValueShadow(variable, shadowed)) {
                        continue;
                    }
                    // ignore function type parameter name shadowing if configured
                    if (isFunctionTypeParameterNameValueShadow(variable, shadowed)) {
                        continue;
                    }
                    // ignore static class method generic shadowing class generic
                    // this is impossible for the scope analyser to understand
                    // so we have to handle this manually in this rule
                    if (isGenericOfAStaticMethodShadow(variable, shadowed)) {
                        continue;
                    }
                    if (isExternalDeclarationMerging(scope, variable, shadowed)) {
                        continue;
                    }
                    const isESLintGlobal = 'writeable' in shadowed;
                    if ((shadowed.identifiers.length > 0 ||
                        (options.builtinGlobals && isESLintGlobal)) &&
                        !isOnInitializer(variable, shadowed) &&
                        !(options.ignoreOnInitialization &&
                            isInitPatternNode(variable, shadowed)) &&
                        !(options.hoist !== 'all' && isInTdz(variable, shadowed))) {
                        const location = getDeclaredLocation(shadowed);
                        context.report(Object.assign({ node: variable.identifiers[0] }, (location.global
                            ? {
                                messageId: 'noShadowGlobal',
                                data: {
                                    name: variable.name,
                                },
                            }
                            : {
                                messageId: 'noShadow',
                                data: {
                                    name: variable.name,
                                    shadowedLine: location.line,
                                    shadowedColumn: location.column,
                                },
                            })));
                    }
                }
            }
            return {
                'Program:exit'() {
                    const globalScope = context.getScope();
                    const stack = globalScope.childScopes.slice();
                    while (stack.length) {
                        const scope = stack.pop();
                        stack.push(...scope.childScopes);
                        checkForShadows(scope);
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-this-alias.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-this-alias',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow aliasing `this`',
                recommended: 'error',
            },
            schema: [
                {
                    type: 'object',
                    additionalProperties: false,
                    properties: {
                        allowDestructuring: {
                            description: 'Whether to ignore destructurings, such as `const { props, state } = this`.',
                            type: 'boolean',
                        },
                        allowedNames: {
                            description: 'Names to ignore, such as ["self"] for `const self = this;`.',
                            type: 'array',
                            items: {
                                type: 'string',
                            },
                        },
                    },
                },
            ],
            messages: {
                thisAssignment: "Unexpected aliasing of 'this' to local variable.",
                thisDestructure: "Unexpected aliasing of members of 'this' to local variables.",
            },
        },
        defaultOptions: [
            {
                allowDestructuring: true,
                allowedNames: [],
            },
        ],
        create(context, [{ allowDestructuring, allowedNames }]) {
            return {
                "VariableDeclarator[init.type='ThisExpression'], AssignmentExpression[right.type='ThisExpression']"(node) {
                    const id = node.type === utils_1.AST_NODE_TYPES.VariableDeclarator ? node.id : node.left;
                    if (allowDestructuring && id.type !== utils_1.AST_NODE_TYPES.Identifier) {
                        return;
                    }
                    const hasAllowedName = id.type === utils_1.AST_NODE_TYPES.Identifier
                        ? allowedNames.includes(id.name)
                        : false;
                    if (!hasAllowedName) {
                        context.report({
                            node: id,
                            messageId: id.type === utils_1.AST_NODE_TYPES.Identifier
                                ? 'thisAssignment'
                                : 'thisDestructure',
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-throw-literal.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-throw-literal',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow throwing literals as exceptions',
                recommended: 'strict',
                extendsBaseRule: true,
                requiresTypeChecking: true,
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowThrowingAny: {
                            type: 'boolean',
                        },
                        allowThrowingUnknown: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
            messages: {
                object: 'Expected an error object to be thrown.',
                undef: 'Do not throw undefined.',
            },
        },
        defaultOptions: [
            {
                allowThrowingAny: true,
                allowThrowingUnknown: true,
            },
        ],
        create(context, [options]) {
            const parserServices = util.getParserServices(context);
            const program = parserServices.program;
            const checker = program.getTypeChecker();
            function isErrorLike(type) {
                var _a;
                if (type.isIntersection()) {
                    return type.types.some(isErrorLike);
                }
                if (type.isUnion()) {
                    return type.types.every(isErrorLike);
                }
                const symbol = type.getSymbol();
                if (!symbol) {
                    return false;
                }
                if (symbol.getName() === 'Error') {
                    const declarations = (_a = symbol.getDeclarations()) !== null && _a !== void 0 ? _a : [];
                    for (const declaration of declarations) {
                        const sourceFile = declaration.getSourceFile();
                        if (program.isSourceFileDefaultLibrary(sourceFile)) {
                            return true;
                        }
                    }
                }
                if (symbol.flags & (ts.SymbolFlags.Class | ts.SymbolFlags.Interface)) {
                    for (const baseType of checker.getBaseTypes(type)) {
                        if (isErrorLike(baseType)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function checkThrowArgument(node) {
                if (node.type === utils_1.AST_NODE_TYPES.AwaitExpression ||
                    node.type === utils_1.AST_NODE_TYPES.YieldExpression) {
                    return;
                }
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                const type = checker.getTypeAtLocation(tsNode);
                if (type.flags & ts.TypeFlags.Undefined) {
                    context.report({ node, messageId: 'undef' });
                    return;
                }
                if (options.allowThrowingAny && util.isTypeAnyType(type)) {
                    return;
                }
                if (options.allowThrowingUnknown && util.isTypeUnknownType(type)) {
                    return;
                }
                if (isErrorLike(type)) {
                    return;
                }
                context.report({ node, messageId: 'object' });
            }
            return {
                ThrowStatement(node) {
                    if (node.argument) {
                        checkThrowArgument(node.argument);
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-type-alias.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const enumValues = [
        'always',
        'never',
        'in-unions',
        'in-intersections',
        'in-unions-and-intersections',
    ];
    exports.default = util.createRule({
        name: 'no-type-alias',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow type aliases',
                // too opinionated to be recommended
                recommended: false,
            },
            messages: {
                noTypeAlias: 'Type {{alias}} are not allowed.',
                noCompositionAlias: '{{typeName}} in {{compositionType}} types are not allowed.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowAliases: {
                            description: 'Whether to allow direct one-to-one type aliases.',
                            enum: enumValues,
                        },
                        allowCallbacks: {
                            description: 'Whether to allow type aliases for callbacks.',
                            enum: ['always', 'never'],
                        },
                        allowConditionalTypes: {
                            description: 'Whether to allow type aliases for conditional types.',
                            enum: ['always', 'never'],
                        },
                        allowConstructors: {
                            description: 'Whether to allow type aliases with constructors.',
                            enum: ['always', 'never'],
                        },
                        allowLiterals: {
                            description: 'Whether to allow type aliases with object literal types.',
                            enum: enumValues,
                        },
                        allowMappedTypes: {
                            description: 'Whether to allow type aliases with mapped types.',
                            enum: enumValues,
                        },
                        allowTupleTypes: {
                            description: 'Whether to allow type aliases with tuple types.',
                            enum: enumValues,
                        },
                        allowGenerics: {
                            description: 'Whether to allow type aliases with generic types.',
                            enum: ['always', 'never'],
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                allowAliases: 'never',
                allowCallbacks: 'never',
                allowConditionalTypes: 'never',
                allowConstructors: 'never',
                allowLiterals: 'never',
                allowMappedTypes: 'never',
                allowTupleTypes: 'never',
                allowGenerics: 'never',
            },
        ],
        create(context, [{ allowAliases, allowCallbacks, allowConditionalTypes, allowConstructors, allowLiterals, allowMappedTypes, allowTupleTypes, allowGenerics, },]) {
            const unions = ['always', 'in-unions', 'in-unions-and-intersections'];
            const intersections = [
                'always',
                'in-intersections',
                'in-unions-and-intersections',
            ];
            const compositions = [
                'in-unions',
                'in-intersections',
                'in-unions-and-intersections',
            ];
            const aliasTypes = new Set([
                utils_1.AST_NODE_TYPES.TSArrayType,
                utils_1.AST_NODE_TYPES.TSImportType,
                utils_1.AST_NODE_TYPES.TSTypeReference,
                utils_1.AST_NODE_TYPES.TSLiteralType,
                utils_1.AST_NODE_TYPES.TSTypeQuery,
                utils_1.AST_NODE_TYPES.TSIndexedAccessType,
                utils_1.AST_NODE_TYPES.TSTemplateLiteralType,
            ]);
            /**
             * Determines if the composition type is supported by the allowed flags.
             * @param isTopLevel a flag indicating this is the top level node.
             * @param compositionType the composition type (either TSUnionType or TSIntersectionType)
             * @param allowed the currently allowed flags.
             */
            function isSupportedComposition(isTopLevel, compositionType, allowed) {
                return (!compositions.includes(allowed) ||
                    (!isTopLevel &&
                        ((compositionType === utils_1.AST_NODE_TYPES.TSUnionType &&
                            unions.includes(allowed)) ||
                            (compositionType === utils_1.AST_NODE_TYPES.TSIntersectionType &&
                                intersections.includes(allowed)))));
            }
            /**
             * Gets the message to be displayed based on the node type and whether the node is a top level declaration.
             * @param node the location
             * @param compositionType the type of composition this alias is part of (undefined if not
             *                                  part of a composition)
             * @param isRoot a flag indicating we are dealing with the top level declaration.
             * @param type the kind of type alias being validated.
             */
            function reportError(node, compositionType, isRoot, type) {
                if (isRoot) {
                    return context.report({
                        node,
                        messageId: 'noTypeAlias',
                        data: {
                            alias: type.toLowerCase(),
                        },
                    });
                }
                return context.report({
                    node,
                    messageId: 'noCompositionAlias',
                    data: {
                        compositionType: compositionType === utils_1.AST_NODE_TYPES.TSUnionType
                            ? 'union'
                            : 'intersection',
                        typeName: type,
                    },
                });
            }
            const isValidTupleType = (type) => {
                if (type.node.type === utils_1.AST_NODE_TYPES.TSTupleType) {
                    return true;
                }
                if (type.node.type === utils_1.AST_NODE_TYPES.TSTypeOperator) {
                    if (['keyof', 'readonly'].includes(type.node.operator) &&
                        type.node.typeAnnotation &&
                        type.node.typeAnnotation.type === utils_1.AST_NODE_TYPES.TSTupleType) {
                        return true;
                    }
                }
                return false;
            };
            const isValidGeneric = (type) => {
                return (type.node.type === utils_1.AST_NODE_TYPES.TSTypeReference &&
                    type.node.typeParameters !== undefined);
            };
            const checkAndReport = (optionValue, isTopLevel, type, label) => {
                if (optionValue === 'never' ||
                    !isSupportedComposition(isTopLevel, type.compositionType, optionValue)) {
                    reportError(type.node, type.compositionType, isTopLevel, label);
                }
            };
            /**
             * Validates the node looking for aliases, callbacks and literals.
             * @param type the type of composition this alias is part of (null if not
             *                                  part of a composition)
             * @param isTopLevel a flag indicating this is the top level node.
             */
            function validateTypeAliases(type, isTopLevel = false) {
                if (type.node.type === utils_1.AST_NODE_TYPES.TSFunctionType) {
                    // callback
                    if (allowCallbacks === 'never') {
                        reportError(type.node, type.compositionType, isTopLevel, 'Callbacks');
                    }
                }
                else if (type.node.type === utils_1.AST_NODE_TYPES.TSConditionalType) {
                    // conditional type
                    if (allowConditionalTypes === 'never') {
                        reportError(type.node, type.compositionType, isTopLevel, 'Conditional types');
                    }
                }
                else if (type.node.type === utils_1.AST_NODE_TYPES.TSConstructorType) {
                    if (allowConstructors === 'never') {
                        reportError(type.node, type.compositionType, isTopLevel, 'Constructors');
                    }
                }
                else if (type.node.type === utils_1.AST_NODE_TYPES.TSTypeLiteral) {
                    // literal object type
                    checkAndReport(allowLiterals, isTopLevel, type, 'Literals');
                }
                else if (type.node.type === utils_1.AST_NODE_TYPES.TSMappedType) {
                    // mapped type
                    checkAndReport(allowMappedTypes, isTopLevel, type, 'Mapped types');
                }
                else if (isValidTupleType(type)) {
                    // tuple types
                    checkAndReport(allowTupleTypes, isTopLevel, type, 'Tuple Types');
                }
                else if (isValidGeneric(type)) {
                    if (allowGenerics === 'never') {
                        reportError(type.node, type.compositionType, isTopLevel, 'Generics');
                    }
                }
                else if (type.node.type.endsWith(utils_1.AST_TOKEN_TYPES.Keyword) ||
                    aliasTypes.has(type.node.type) ||
                    (type.node.type === utils_1.AST_NODE_TYPES.TSTypeOperator &&
                        (type.node.operator === 'keyof' ||
                            (type.node.operator === 'readonly' &&
                                type.node.typeAnnotation &&
                                aliasTypes.has(type.node.typeAnnotation.type))))) {
                    // alias / keyword
                    checkAndReport(allowAliases, isTopLevel, type, 'Aliases');
                }
                else {
                    // unhandled type - shouldn't happen
                    reportError(type.node, type.compositionType, isTopLevel, 'Unhandled');
                }
            }
            /**
             * Flatten the given type into an array of its dependencies
             */
            function getTypes(node, compositionType = null) {
                if (node.type === utils_1.AST_NODE_TYPES.TSUnionType ||
                    node.type === utils_1.AST_NODE_TYPES.TSIntersectionType) {
                    return node.types.reduce((acc, type) => {
                        acc.push(...getTypes(type, node.type));
                        return acc;
                    }, []);
                }
                return [{ node, compositionType }];
            }
            return {
                TSTypeAliasDeclaration(node) {
                    const types = getTypes(node.typeAnnotation);
                    if (types.length === 1) {
                        // is a top level type annotation
                        validateTypeAliases(types[0], true);
                    }
                    else {
                        // is a composition type
                        types.forEach(type => {
                            validateTypeAliases(type);
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unnecessary-boolean-literal-compare.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-unnecessary-boolean-literal-compare',
        meta: {
            docs: {
                description: 'Disallow unnecessary equality comparisons against boolean literals',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            fixable: 'code',
            messages: {
                direct: 'This expression unnecessarily compares a boolean value to a boolean instead of using it directly.',
                negated: 'This expression unnecessarily compares a boolean value to a boolean instead of negating it.',
                comparingNullableToTrueDirect: 'This expression unnecessarily compares a nullable boolean value to true instead of using it directly.',
                comparingNullableToTrueNegated: 'This expression unnecessarily compares a nullable boolean value to true instead of negating it.',
                comparingNullableToFalse: 'This expression unnecessarily compares a nullable boolean value to false instead of using the ?? operator to provide a default.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowComparingNullableBooleansToTrue: {
                            description: 'Whether to allow comparisons between nullable boolean variables and `true`.',
                            type: 'boolean',
                        },
                        allowComparingNullableBooleansToFalse: {
                            description: 'Whether to allow comparisons between nullable boolean variables and `false`.',
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
            type: 'suggestion',
        },
        defaultOptions: [
            {
                allowComparingNullableBooleansToTrue: true,
                allowComparingNullableBooleansToFalse: true,
            },
        ],
        create(context, [options]) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const sourceCode = context.getSourceCode();
            function getBooleanComparison(node) {
                const comparison = deconstructComparison(node);
                if (!comparison) {
                    return undefined;
                }
                const expressionType = checker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(comparison.expression));
                if (isBooleanType(expressionType)) {
                    return Object.assign(Object.assign({}, comparison), { expressionIsNullableBoolean: false });
                }
                if (isNullableBoolean(expressionType)) {
                    return Object.assign(Object.assign({}, comparison), { expressionIsNullableBoolean: true });
                }
                return undefined;
            }
            function isBooleanType(expressionType) {
                return tsutils.isTypeFlagSet(expressionType, ts.TypeFlags.Boolean | ts.TypeFlags.BooleanLiteral);
            }
            /**
             * checks if the expressionType is a union that
             *   1) contains at least one nullish type (null or undefined)
             *   2) contains at least once boolean type (true or false or boolean)
             *   3) does not contain any types besides nullish and boolean types
             */
            function isNullableBoolean(expressionType) {
                if (!expressionType.isUnion()) {
                    return false;
                }
                const { types } = expressionType;
                const nonNullishTypes = types.filter(type => !tsutils.isTypeFlagSet(type, ts.TypeFlags.Undefined | ts.TypeFlags.Null));
                const hasNonNullishType = nonNullishTypes.length > 0;
                if (!hasNonNullishType) {
                    return false;
                }
                const hasNullableType = nonNullishTypes.length < types.length;
                if (!hasNullableType) {
                    return false;
                }
                const allNonNullishTypesAreBoolean = nonNullishTypes.every(isBooleanType);
                if (!allNonNullishTypesAreBoolean) {
                    return false;
                }
                return true;
            }
            function deconstructComparison(node) {
                const comparisonType = getEqualsKind(node.operator);
                if (!comparisonType) {
                    return undefined;
                }
                for (const [against, expression] of [
                    [node.right, node.left],
                    [node.left, node.right],
                ]) {
                    if (against.type !== utils_1.AST_NODE_TYPES.Literal ||
                        typeof against.value !== 'boolean') {
                        continue;
                    }
                    const { value: literalBooleanInComparison } = against;
                    const negated = !comparisonType.isPositive;
                    return {
                        literalBooleanInComparison,
                        forTruthy: literalBooleanInComparison ? !negated : negated,
                        expression,
                        negated,
                    };
                }
                return undefined;
            }
            function nodeIsUnaryNegation(node) {
                return (node.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                    node.prefix &&
                    node.operator === '!');
            }
            return {
                BinaryExpression(node) {
                    const comparison = getBooleanComparison(node);
                    if (comparison === undefined) {
                        return;
                    }
                    if (comparison.expressionIsNullableBoolean) {
                        if (comparison.literalBooleanInComparison &&
                            options.allowComparingNullableBooleansToTrue) {
                            return;
                        }
                        if (!comparison.literalBooleanInComparison &&
                            options.allowComparingNullableBooleansToFalse) {
                            return;
                        }
                    }
                    context.report({
                        fix: function* (fixer) {
                            yield fixer.replaceText(node, sourceCode.getText(comparison.expression));
                            // if the expression `exp` isn't nullable, or we're comparing to `true`,
                            // we can just replace the entire comparison with `exp` or `!exp`
                            if (!comparison.expressionIsNullableBoolean ||
                                comparison.literalBooleanInComparison) {
                                if (!comparison.forTruthy) {
                                    yield fixer.insertTextBefore(node, '!');
                                    if (!util.isStrongPrecedenceNode(comparison.expression)) {
                                        yield fixer.insertTextBefore(node, '(');
                                        yield fixer.insertTextAfter(node, ')');
                                    }
                                }
                                return;
                            }
                            // if we're here, then the expression is a nullable boolean and we're
                            // comparing to a literal `false`
                            // if we're doing `== false` or `=== false`, then we need to negate the expression
                            if (!comparison.negated) {
                                const { parent } = node;
                                // if the parent is a negation, we can instead just get rid of the parent's negation.
                                // i.e. instead of resulting in `!(!(exp))`, we can just result in `exp`
                                if (parent != null && nodeIsUnaryNegation(parent)) {
                                    // remove from the beginning of the parent to the beginning of this node
                                    yield fixer.removeRange([parent.range[0], node.range[0]]);
                                    // remove from the end of the node to the end of the parent
                                    yield fixer.removeRange([node.range[1], parent.range[1]]);
                                }
                                else {
                                    yield fixer.insertTextBefore(node, '!');
                                }
                            }
                            // provide the default `true`
                            yield fixer.insertTextBefore(node, '(');
                            yield fixer.insertTextAfter(node, ' ?? true)');
                        },
                        messageId: comparison.expressionIsNullableBoolean
                            ? comparison.literalBooleanInComparison
                                ? comparison.negated
                                    ? 'comparingNullableToTrueNegated'
                                    : 'comparingNullableToTrueDirect'
                                : 'comparingNullableToFalse'
                            : comparison.negated
                                ? 'negated'
                                : 'direct',
                        node,
                    });
                },
            };
        },
    });
    function getEqualsKind(operator) {
        switch (operator) {
            case '==':
                return {
                    isPositive: true,
                    isStrict: false,
                };
            case '===':
                return {
                    isPositive: true,
                    isStrict: true,
                };
            case '!=':
                return {
                    isPositive: false,
                    isStrict: false,
                };
            case '!==':
                return {
                    isPositive: false,
                    isStrict: true,
                };
            default:
                return undefined;
        }
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unnecessary-condition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    const util_1 = require(1018) /* ../util */;
    // Truthiness utilities
    // #region
    const isTruthyLiteral = (type) => (0, tsutils_1.isBooleanLiteralType)(type, true) || ((0, tsutils_1.isLiteralType)(type) && !!type.value);
    const isPossiblyFalsy = (type) => (0, tsutils_1.unionTypeParts)(type)
        // PossiblyFalsy flag includes literal values, so exclude ones that
        // are definitely truthy
        .filter(t => !isTruthyLiteral(t))
        .some(type => (0, util_1.isTypeFlagSet)(type, ts.TypeFlags.PossiblyFalsy));
    const isPossiblyTruthy = (type) => (0, tsutils_1.unionTypeParts)(type).some(type => !(0, tsutils_1.isFalsyType)(type));
    // Nullish utilities
    const nullishFlag = ts.TypeFlags.Undefined | ts.TypeFlags.Null;
    const isNullishType = (type) => (0, util_1.isTypeFlagSet)(type, nullishFlag);
    const isPossiblyNullish = (type) => (0, tsutils_1.unionTypeParts)(type).some(isNullishType);
    const isAlwaysNullish = (type) => (0, tsutils_1.unionTypeParts)(type).every(isNullishType);
    // isLiteralType only covers numbers and strings, this is a more exhaustive check.
    const isLiteral = (type) => (0, tsutils_1.isBooleanLiteralType)(type, true) ||
        (0, tsutils_1.isBooleanLiteralType)(type, false) ||
        type.flags === ts.TypeFlags.Undefined ||
        type.flags === ts.TypeFlags.Null ||
        type.flags === ts.TypeFlags.Void ||
        (0, tsutils_1.isLiteralType)(type);
    exports.default = (0, util_1.createRule)({
        name: 'no-unnecessary-condition',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow conditionals where the type is always truthy or always falsy',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowConstantLoopConditions: {
                            description: 'Whether to ignore constant loop conditions, such as `while (true)`.',
                            type: 'boolean',
                        },
                        allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing: {
                            description: 'Whether to not error when running with a tsconfig that has strictNullChecks turned.',
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
            fixable: 'code',
            messages: {
                alwaysTruthy: 'Unnecessary conditional, value is always truthy.',
                alwaysFalsy: 'Unnecessary conditional, value is always falsy.',
                alwaysTruthyFunc: 'This callback should return a conditional, but return is always truthy.',
                alwaysFalsyFunc: 'This callback should return a conditional, but return is always falsy.',
                neverNullish: 'Unnecessary conditional, expected left-hand side of `??` operator to be possibly null or undefined.',
                alwaysNullish: 'Unnecessary conditional, left-hand side of `??` operator is always `null` or `undefined`.',
                literalBooleanExpression: 'Unnecessary conditional, both sides of the expression are literal values.',
                noOverlapBooleanExpression: 'Unnecessary conditional, the types have no overlap.',
                never: 'Unnecessary conditional, value is `never`.',
                neverOptionalChain: 'Unnecessary optional chain on a non-nullish value.',
                noStrictNullCheck: 'This rule requires the `strictNullChecks` compiler option to be turned on to function correctly.',
            },
        },
        defaultOptions: [
            {
                allowConstantLoopConditions: false,
                allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing: false,
            },
        ],
        create(context, [{ allowConstantLoopConditions, allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing, },]) {
            const service = (0, util_1.getParserServices)(context);
            const checker = service.program.getTypeChecker();
            const sourceCode = context.getSourceCode();
            const compilerOptions = service.program.getCompilerOptions();
            const isStrictNullChecks = (0, tsutils_1.isStrictCompilerOptionEnabled)(compilerOptions, 'strictNullChecks');
            if (!isStrictNullChecks &&
                allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing !== true) {
                context.report({
                    loc: {
                        start: { line: 0, column: 0 },
                        end: { line: 0, column: 0 },
                    },
                    messageId: 'noStrictNullCheck',
                });
            }
            function getNodeType(node) {
                const tsNode = service.esTreeNodeToTSNodeMap.get(node);
                return (0, util_1.getConstrainedTypeAtLocation)(checker, tsNode);
            }
            function nodeIsArrayType(node) {
                const nodeType = getNodeType(node);
                return checker.isArrayType(nodeType);
            }
            function nodeIsTupleType(node) {
                const nodeType = getNodeType(node);
                return checker.isTupleType(nodeType);
            }
            function isArrayIndexExpression(node) {
                return (
                // Is an index signature
                node.type === utils_1.AST_NODE_TYPES.MemberExpression &&
                    node.computed &&
                    // ...into an array type
                    (nodeIsArrayType(node.object) ||
                        // ... or a tuple type
                        (nodeIsTupleType(node.object) &&
                            // Exception: literal index into a tuple - will have a sound type
                            node.property.type !== utils_1.AST_NODE_TYPES.Literal)));
            }
            /**
             * Checks if a conditional node is necessary:
             * if the type of the node is always true or always false, it's not necessary.
             */
            function checkNode(node, isUnaryNotArgument = false) {
                // Check if the node is Unary Negation expression and handle it
                if (node.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                    node.operator === '!') {
                    return checkNode(node.argument, true);
                }
                // Since typescript array index signature types don't represent the
                //  possibility of out-of-bounds access, if we're indexing into an array
                //  just skip the check, to avoid false positives
                if (isArrayIndexExpression(node)) {
                    return;
                }
                // When checking logical expressions, only check the right side
                //  as the left side has been checked by checkLogicalExpressionForUnnecessaryConditionals
                //
                // Unless the node is nullish coalescing, as it's common to use patterns like `nullBool ?? true` to to strict
                //  boolean checks if we inspect the right here, it'll usually be a constant condition on purpose.
                // In this case it's better to inspect the type of the expression as a whole.
                if (node.type === utils_1.AST_NODE_TYPES.LogicalExpression &&
                    node.operator !== '??') {
                    return checkNode(node.right);
                }
                const type = getNodeType(node);
                // Conditional is always necessary if it involves:
                //    `any` or `unknown` or a naked type variable
                if ((0, tsutils_1.unionTypeParts)(type).some(part => (0, util_1.isTypeAnyType)(part) ||
                    (0, util_1.isTypeUnknownType)(part) ||
                    (0, util_1.isTypeFlagSet)(part, ts.TypeFlags.TypeVariable))) {
                    return;
                }
                let messageId = null;
                if ((0, util_1.isTypeFlagSet)(type, ts.TypeFlags.Never)) {
                    messageId = 'never';
                }
                else if (!isPossiblyTruthy(type)) {
                    messageId = !isUnaryNotArgument ? 'alwaysFalsy' : 'alwaysTruthy';
                }
                else if (!isPossiblyFalsy(type)) {
                    messageId = !isUnaryNotArgument ? 'alwaysTruthy' : 'alwaysFalsy';
                }
                if (messageId) {
                    context.report({ node, messageId });
                }
            }
            function checkNodeForNullish(node) {
                const type = getNodeType(node);
                // Conditional is always necessary if it involves `any` or `unknown`
                if ((0, util_1.isTypeAnyType)(type) || (0, util_1.isTypeUnknownType)(type)) {
                    return;
                }
                let messageId = null;
                if ((0, util_1.isTypeFlagSet)(type, ts.TypeFlags.Never)) {
                    messageId = 'never';
                }
                else if (!isPossiblyNullish(type)) {
                    // Since typescript array index signature types don't represent the
                    //  possibility of out-of-bounds access, if we're indexing into an array
                    //  just skip the check, to avoid false positives
                    if (!isArrayIndexExpression(node) &&
                        !(node.type === utils_1.AST_NODE_TYPES.ChainExpression &&
                            node.expression.type !== utils_1.AST_NODE_TYPES.TSNonNullExpression &&
                            optionChainContainsOptionArrayIndex(node.expression))) {
                        messageId = 'neverNullish';
                    }
                }
                else if (isAlwaysNullish(type)) {
                    messageId = 'alwaysNullish';
                }
                if (messageId) {
                    context.report({ node, messageId });
                }
            }
            /**
             * Checks that a binary expression is necessarily conditional, reports otherwise.
             * If both sides of the binary expression are literal values, it's not a necessary condition.
             *
             * NOTE: It's also unnecessary if the types that don't overlap at all
             *    but that case is handled by the Typescript compiler itself.
             *    Known exceptions:
             *      * https://github.com/microsoft/TypeScript/issues/32627
             *      * https://github.com/microsoft/TypeScript/issues/37160 (handled)
             */
            const BOOL_OPERATORS = new Set([
                '<',
                '>',
                '<=',
                '>=',
                '==',
                '===',
                '!=',
                '!==',
            ]);
            function checkIfBinaryExpressionIsNecessaryConditional(node) {
                if (!BOOL_OPERATORS.has(node.operator)) {
                    return;
                }
                const leftType = getNodeType(node.left);
                const rightType = getNodeType(node.right);
                if (isLiteral(leftType) && isLiteral(rightType)) {
                    context.report({ node, messageId: 'literalBooleanExpression' });
                    return;
                }
                // Workaround for https://github.com/microsoft/TypeScript/issues/37160
                if (isStrictNullChecks) {
                    const UNDEFINED = ts.TypeFlags.Undefined;
                    const NULL = ts.TypeFlags.Null;
                    const VOID = ts.TypeFlags.Void;
                    const isComparable = (type, flag) => {
                        // Allow comparison to `any`, `unknown` or a naked type parameter.
                        flag |=
                            ts.TypeFlags.Any |
                                ts.TypeFlags.Unknown |
                                ts.TypeFlags.TypeParameter;
                        // Allow loose comparison to nullish values.
                        if (node.operator === '==' || node.operator === '!=') {
                            flag |= NULL | UNDEFINED | VOID;
                        }
                        return (0, util_1.isTypeFlagSet)(type, flag);
                    };
                    if ((leftType.flags === UNDEFINED &&
                        !isComparable(rightType, UNDEFINED | VOID)) ||
                        (rightType.flags === UNDEFINED &&
                            !isComparable(leftType, UNDEFINED | VOID)) ||
                        (leftType.flags === NULL && !isComparable(rightType, NULL)) ||
                        (rightType.flags === NULL && !isComparable(leftType, NULL))) {
                        context.report({ node, messageId: 'noOverlapBooleanExpression' });
                        return;
                    }
                }
            }
            /**
             * Checks that a logical expression contains a boolean, reports otherwise.
             */
            function checkLogicalExpressionForUnnecessaryConditionals(node) {
                if (node.operator === '??') {
                    checkNodeForNullish(node.left);
                    return;
                }
                // Only checks the left side, since the right side might not be "conditional" at all.
                // The right side will be checked if the LogicalExpression is used in a conditional context
                checkNode(node.left);
            }
            /**
             * Checks that a testable expression of a loop is necessarily conditional, reports otherwise.
             */
            function checkIfLoopIsNecessaryConditional(node) {
                if (node.test == null) {
                    // e.g. `for(;;)`
                    return;
                }
                /**
                 * Allow:
                 *   while (true) {}
                 *   for (;true;) {}
                 *   do {} while (true)
                 */
                if (allowConstantLoopConditions &&
                    (0, tsutils_1.isBooleanLiteralType)(getNodeType(node.test), true)) {
                    return;
                }
                checkNode(node.test);
            }
            const ARRAY_PREDICATE_FUNCTIONS = new Set([
                'filter',
                'find',
                'some',
                'every',
            ]);
            function isArrayPredicateFunction(node) {
                const { callee } = node;
                return (
                // looks like `something.filter` or `something.find`
                callee.type === utils_1.AST_NODE_TYPES.MemberExpression &&
                    callee.property.type === utils_1.AST_NODE_TYPES.Identifier &&
                    ARRAY_PREDICATE_FUNCTIONS.has(callee.property.name) &&
                    // and the left-hand side is an array, according to the types
                    (nodeIsArrayType(callee.object) || nodeIsTupleType(callee.object)));
            }
            function checkCallExpression(node) {
                // If this is something like arr.filter(x => /*condition*/), check `condition`
                if (isArrayPredicateFunction(node) && node.arguments.length) {
                    const callback = node.arguments[0];
                    // Inline defined functions
                    if ((callback.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression ||
                        callback.type === utils_1.AST_NODE_TYPES.FunctionExpression) &&
                        callback.body) {
                        // Two special cases, where we can directly check the node that's returned:
                        // () => something
                        if (callback.body.type !== utils_1.AST_NODE_TYPES.BlockStatement) {
                            return checkNode(callback.body);
                        }
                        // () => { return something; }
                        const callbackBody = callback.body.body;
                        if (callbackBody.length === 1 &&
                            callbackBody[0].type === utils_1.AST_NODE_TYPES.ReturnStatement &&
                            callbackBody[0].argument) {
                            return checkNode(callbackBody[0].argument);
                        }
                        // Potential enhancement: could use code-path analysis to check
                        //   any function with a single return statement
                        // (Value to complexity ratio is dubious however)
                    }
                    // Otherwise just do type analysis on the function as a whole.
                    const returnTypes = (0, tsutils_1.getCallSignaturesOfType)(getNodeType(callback)).map(sig => sig.getReturnType());
                    /* istanbul ignore if */ if (returnTypes.length === 0) {
                        // Not a callable function
                        return;
                    }
                    // Predicate is always necessary if it involves `any` or `unknown`
                    if (returnTypes.some(t => (0, util_1.isTypeAnyType)(t) || (0, util_1.isTypeUnknownType)(t))) {
                        return;
                    }
                    if (!returnTypes.some(isPossiblyFalsy)) {
                        return context.report({
                            node: callback,
                            messageId: 'alwaysTruthyFunc',
                        });
                    }
                    if (!returnTypes.some(isPossiblyTruthy)) {
                        return context.report({
                            node: callback,
                            messageId: 'alwaysFalsyFunc',
                        });
                    }
                }
            }
            // Recursively searches an optional chain for an array index expression
            //  Has to search the entire chain, because an array index will "infect" the rest of the types
            //  Example:
            //  ```
            //  [{x: {y: "z"} }][n] // type is {x: {y: "z"}}
            //    ?.x // type is {y: "z"}
            //    ?.y // This access is considered "unnecessary" according to the types
            //  ```
            function optionChainContainsOptionArrayIndex(node) {
                const lhsNode = node.type === utils_1.AST_NODE_TYPES.CallExpression ? node.callee : node.object;
                if (node.optional && isArrayIndexExpression(lhsNode)) {
                    return true;
                }
                if (lhsNode.type === utils_1.AST_NODE_TYPES.MemberExpression ||
                    lhsNode.type === utils_1.AST_NODE_TYPES.CallExpression) {
                    return optionChainContainsOptionArrayIndex(lhsNode);
                }
                return false;
            }
            function isNullablePropertyType(objType, propertyType) {
                if (propertyType.isUnion()) {
                    return propertyType.types.some(type => isNullablePropertyType(objType, type));
                }
                if (propertyType.isNumberLiteral() || propertyType.isStringLiteral()) {
                    const propType = (0, util_1.getTypeOfPropertyOfName)(checker, objType, propertyType.value.toString());
                    if (propType) {
                        return (0, util_1.isNullableType)(propType, { allowUndefined: true });
                    }
                }
                const typeName = (0, util_1.getTypeName)(checker, propertyType);
                return !!((typeName === 'string' &&
                    checker.getIndexInfoOfType(objType, ts.IndexKind.String)) ||
                    (typeName === 'number' &&
                        checker.getIndexInfoOfType(objType, ts.IndexKind.Number)));
            }
            // Checks whether a member expression is nullable or not regardless of it's previous node.
            //  Example:
            //  ```
            //  // 'bar' is nullable if 'foo' is null.
            //  // but this function checks regardless of 'foo' type, so returns 'true'.
            //  declare const foo: { bar : { baz: string } } | null
            //  foo?.bar;
            //  ```
            function isNullableOriginFromPrev(node) {
                const prevType = getNodeType(node.object);
                const property = node.property;
                if (prevType.isUnion() && (0, util_1.isIdentifier)(property)) {
                    const isOwnNullable = prevType.types.some(type => {
                        if (node.computed) {
                            const propertyType = getNodeType(node.property);
                            return isNullablePropertyType(type, propertyType);
                        }
                        const propType = (0, util_1.getTypeOfPropertyOfName)(checker, type, property.name);
                        if (propType) {
                            return (0, util_1.isNullableType)(propType, { allowUndefined: true });
                        }
                        return !!checker.getIndexInfoOfType(type, ts.IndexKind.String);
                    });
                    return (!isOwnNullable && (0, util_1.isNullableType)(prevType, { allowUndefined: true }));
                }
                return false;
            }
            function isOptionableExpression(node) {
                const type = getNodeType(node);
                const isOwnNullable = node.type === utils_1.AST_NODE_TYPES.MemberExpression
                    ? !isNullableOriginFromPrev(node)
                    : true;
                const possiblyVoid = (0, util_1.isTypeFlagSet)(type, ts.TypeFlags.Void);
                return ((0, util_1.isTypeFlagSet)(type, ts.TypeFlags.Any | ts.TypeFlags.Unknown) ||
                    (isOwnNullable &&
                        ((0, util_1.isNullableType)(type, { allowUndefined: true }) || possiblyVoid)));
            }
            function checkOptionalChain(node, beforeOperator, fix) {
                // We only care if this step in the chain is optional. If just descend
                // from an optional chain, then that's fine.
                if (!node.optional) {
                    return;
                }
                // Since typescript array index signature types don't represent the
                //  possibility of out-of-bounds access, if we're indexing into an array
                //  just skip the check, to avoid false positives
                if (optionChainContainsOptionArrayIndex(node)) {
                    return;
                }
                const nodeToCheck = node.type === utils_1.AST_NODE_TYPES.CallExpression ? node.callee : node.object;
                if (isOptionableExpression(nodeToCheck)) {
                    return;
                }
                const questionDotOperator = (0, util_1.nullThrows)(sourceCode.getTokenAfter(beforeOperator, token => token.type === utils_1.AST_TOKEN_TYPES.Punctuator && token.value === '?.'), util_1.NullThrowsReasons.MissingToken('operator', node.type));
                context.report({
                    node,
                    loc: questionDotOperator.loc,
                    messageId: 'neverOptionalChain',
                    fix(fixer) {
                        return fixer.replaceText(questionDotOperator, fix);
                    },
                });
            }
            function checkOptionalMemberExpression(node) {
                checkOptionalChain(node, node.object, node.computed ? '' : '.');
            }
            function checkOptionalCallExpression(node) {
                checkOptionalChain(node, node.callee, '');
            }
            function checkAssignmentExpression(node) {
                // Similar to checkLogicalExpressionForUnnecessaryConditionals, since
                // a ||= b is equivalent to a || (a = b)
                if (['||=', '&&='].includes(node.operator)) {
                    checkNode(node.left);
                }
                else if (node.operator === '??=') {
                    checkNodeForNullish(node.left);
                }
            }
            return {
                AssignmentExpression: checkAssignmentExpression,
                BinaryExpression: checkIfBinaryExpressionIsNecessaryConditional,
                CallExpression: checkCallExpression,
                ConditionalExpression: (node) => checkNode(node.test),
                DoWhileStatement: checkIfLoopIsNecessaryConditional,
                ForStatement: checkIfLoopIsNecessaryConditional,
                IfStatement: (node) => checkNode(node.test),
                LogicalExpression: checkLogicalExpressionForUnnecessaryConditionals,
                WhileStatement: checkIfLoopIsNecessaryConditional,
                'MemberExpression[optional = true]': checkOptionalMemberExpression,
                'CallExpression[optional = true]': checkOptionalCallExpression,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unnecessary-qualifier.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-unnecessary-qualifier',
        meta: {
            docs: {
                description: 'Disallow unnecessary namespace qualifiers',
                recommended: false,
                requiresTypeChecking: true,
            },
            fixable: 'code',
            messages: {
                unnecessaryQualifier: "Qualifier is unnecessary since '{{ name }}' is in scope.",
            },
            schema: [],
            type: 'suggestion',
        },
        defaultOptions: [],
        create(context) {
            const namespacesInScope = [];
            let currentFailedNamespaceExpression = null;
            const parserServices = util.getParserServices(context);
            const esTreeNodeToTSNodeMap = parserServices.esTreeNodeToTSNodeMap;
            const program = parserServices.program;
            const checker = program.getTypeChecker();
            const sourceCode = context.getSourceCode();
            function tryGetAliasedSymbol(symbol, checker) {
                return tsutils.isSymbolFlagSet(symbol, ts.SymbolFlags.Alias)
                    ? checker.getAliasedSymbol(symbol)
                    : null;
            }
            function symbolIsNamespaceInScope(symbol) {
                var _a;
                const symbolDeclarations = (_a = symbol.getDeclarations()) !== null && _a !== void 0 ? _a : [];
                if (symbolDeclarations.some(decl => namespacesInScope.some(ns => ns === decl))) {
                    return true;
                }
                const alias = tryGetAliasedSymbol(symbol, checker);
                return alias != null && symbolIsNamespaceInScope(alias);
            }
            function getSymbolInScope(node, flags, name) {
                // TODO:PERF `getSymbolsInScope` gets a long list. Is there a better way?
                const scope = checker.getSymbolsInScope(node, flags);
                return scope.find(scopeSymbol => scopeSymbol.name === name);
            }
            function symbolsAreEqual(accessed, inScope) {
                return accessed === checker.getExportSymbolOfSymbol(inScope);
            }
            function qualifierIsUnnecessary(qualifier, name) {
                const tsQualifier = esTreeNodeToTSNodeMap.get(qualifier);
                const tsName = esTreeNodeToTSNodeMap.get(name);
                const namespaceSymbol = checker.getSymbolAtLocation(tsQualifier);
                if (namespaceSymbol === undefined ||
                    !symbolIsNamespaceInScope(namespaceSymbol)) {
                    return false;
                }
                const accessedSymbol = checker.getSymbolAtLocation(tsName);
                if (accessedSymbol === undefined) {
                    return false;
                }
                // If the symbol in scope is different, the qualifier is necessary.
                const fromScope = getSymbolInScope(tsQualifier, accessedSymbol.flags, sourceCode.getText(name));
                return (fromScope === undefined || symbolsAreEqual(accessedSymbol, fromScope));
            }
            function visitNamespaceAccess(node, qualifier, name) {
                // Only look for nested qualifier errors if we didn't already fail on the outer qualifier.
                if (!currentFailedNamespaceExpression &&
                    qualifierIsUnnecessary(qualifier, name)) {
                    currentFailedNamespaceExpression = node;
                    context.report({
                        node: qualifier,
                        messageId: 'unnecessaryQualifier',
                        data: {
                            name: sourceCode.getText(name),
                        },
                        fix(fixer) {
                            return fixer.removeRange([qualifier.range[0], name.range[0]]);
                        },
                    });
                }
            }
            function enterDeclaration(node) {
                namespacesInScope.push(esTreeNodeToTSNodeMap.get(node));
            }
            function exitDeclaration() {
                namespacesInScope.pop();
            }
            function resetCurrentNamespaceExpression(node) {
                if (node === currentFailedNamespaceExpression) {
                    currentFailedNamespaceExpression = null;
                }
            }
            function isPropertyAccessExpression(node) {
                return node.type === utils_1.AST_NODE_TYPES.MemberExpression && !node.computed;
            }
            function isEntityNameExpression(node) {
                return (node.type === utils_1.AST_NODE_TYPES.Identifier ||
                    (isPropertyAccessExpression(node) &&
                        isEntityNameExpression(node.object)));
            }
            return {
                TSModuleDeclaration: enterDeclaration,
                TSEnumDeclaration: enterDeclaration,
                'ExportNamedDeclaration[declaration.type="TSModuleDeclaration"]': enterDeclaration,
                'ExportNamedDeclaration[declaration.type="TSEnumDeclaration"]': enterDeclaration,
                'TSModuleDeclaration:exit': exitDeclaration,
                'TSEnumDeclaration:exit': exitDeclaration,
                'ExportNamedDeclaration[declaration.type="TSModuleDeclaration"]:exit': exitDeclaration,
                'ExportNamedDeclaration[declaration.type="TSEnumDeclaration"]:exit': exitDeclaration,
                TSQualifiedName(node) {
                    visitNamespaceAccess(node, node.left, node.right);
                },
                'MemberExpression[computed=false]': function (node) {
                    const property = node.property;
                    if (isEntityNameExpression(node.object)) {
                        visitNamespaceAccess(node, node.object, property);
                    }
                },
                'TSQualifiedName:exit': resetCurrentNamespaceExpression,
                'MemberExpression:exit': resetCurrentNamespaceExpression,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unnecessary-type-arguments.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    exports.default = util.createRule({
        name: 'no-unnecessary-type-arguments',
        meta: {
            docs: {
                description: 'Disallow type arguments that are equal to the default',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            fixable: 'code',
            messages: {
                unnecessaryTypeParameter: 'This is the default value for this type parameter, so it can be omitted.',
            },
            schema: [],
            type: 'suggestion',
        },
        defaultOptions: [],
        create(context) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            function getTypeForComparison(type) {
                if (util.isTypeReferenceType(type)) {
                    return {
                        type: type.target,
                        typeArguments: util.getTypeArguments(type, checker),
                    };
                }
                return {
                    type,
                    typeArguments: [],
                };
            }
            function checkTSArgsAndParameters(esParameters, typeParameters) {
                // Just check the last one. Must specify previous type parameters if the last one is specified.
                const i = esParameters.params.length - 1;
                const arg = esParameters.params[i];
                const param = typeParameters[i];
                if (!(param === null || param === void 0 ? void 0 : param.default)) {
                    return;
                }
                // TODO: would like checker.areTypesEquivalent. https://github.com/Microsoft/TypeScript/issues/13502
                const defaultType = checker.getTypeAtLocation(param.default);
                const argTsNode = parserServices.esTreeNodeToTSNodeMap.get(arg);
                const argType = checker.getTypeAtLocation(argTsNode);
                // this check should handle some of the most simple cases of like strings, numbers, etc
                if (defaultType !== argType) {
                    // For more complex types (like aliases to generic object types) - TS won't always create a
                    // global shared type object for the type - so we need to resort to manually comparing the
                    // reference type and the passed type arguments.
                    // Also - in case there are aliases - we need to resolve them before we do checks
                    const defaultTypeResolved = getTypeForComparison(defaultType);
                    const argTypeResolved = getTypeForComparison(argType);
                    if (
                    // ensure the resolved type AND all the parameters are the same
                    defaultTypeResolved.type !== argTypeResolved.type ||
                        defaultTypeResolved.typeArguments.length !==
                            argTypeResolved.typeArguments.length ||
                        defaultTypeResolved.typeArguments.some((t, i) => t !== argTypeResolved.typeArguments[i])) {
                        return;
                    }
                }
                context.report({
                    node: arg,
                    messageId: 'unnecessaryTypeParameter',
                    fix: fixer => fixer.removeRange(i === 0
                        ? esParameters.range
                        : [esParameters.params[i - 1].range[1], arg.range[1]]),
                });
            }
            return {
                TSTypeParameterInstantiation(node) {
                    const expression = parserServices.esTreeNodeToTSNodeMap.get(node);
                    const typeParameters = getTypeParametersFromNode(expression, checker);
                    if (typeParameters) {
                        checkTSArgsAndParameters(node, typeParameters);
                    }
                },
            };
        },
    });
    function getTypeParametersFromNode(node, checker) {
        if (ts.isExpressionWithTypeArguments(node)) {
            return getTypeParametersFromType(node.expression, checker);
        }
        if (ts.isTypeReferenceNode(node)) {
            return getTypeParametersFromType(node.typeName, checker);
        }
        if (ts.isCallExpression(node) || ts.isNewExpression(node)) {
            return getTypeParametersFromCall(node, checker);
        }
        return undefined;
    }
    function getTypeParametersFromType(type, checker) {
        const symAtLocation = checker.getSymbolAtLocation(type);
        if (!symAtLocation) {
            return undefined;
        }
        const sym = getAliasedSymbol(symAtLocation, checker);
        const declarations = sym.getDeclarations();
        if (!declarations) {
            return undefined;
        }
        return (0, util_1.findFirstResult)(declarations, decl => ts.isClassLike(decl) ||
            ts.isTypeAliasDeclaration(decl) ||
            ts.isInterfaceDeclaration(decl)
            ? decl.typeParameters
            : undefined);
    }
    function getTypeParametersFromCall(node, checker) {
        const sig = checker.getResolvedSignature(node);
        const sigDecl = sig === null || sig === void 0 ? void 0 : sig.getDeclaration();
        if (!sigDecl) {
            return ts.isNewExpression(node)
                ? getTypeParametersFromType(node.expression, checker)
                : undefined;
        }
        return sigDecl.typeParameters;
    }
    function getAliasedSymbol(symbol, checker) {
        return tsutils.isSymbolFlagSet(symbol, ts.SymbolFlags.Alias)
            ? checker.getAliasedSymbol(symbol)
            : symbol;
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unnecessary-type-assertion.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-unnecessary-type-assertion',
        meta: {
            docs: {
                description: 'Disallow type assertions that do not change the type of an expression',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            fixable: 'code',
            messages: {
                unnecessaryAssertion: 'This assertion is unnecessary since it does not change the type of the expression.',
                contextuallyUnnecessary: 'This assertion is unnecessary since the receiver accepts the original type of the expression.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        typesToIgnore: {
                            description: 'A list of type names to ignore.',
                            type: 'array',
                            items: {
                                type: 'string',
                            },
                        },
                    },
                },
            ],
            type: 'suggestion',
        },
        defaultOptions: [{}],
        create(context, [options]) {
            const sourceCode = context.getSourceCode();
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const compilerOptions = parserServices.program.getCompilerOptions();
            /**
             * Sometimes tuple types don't have ObjectFlags.Tuple set, like when they're being matched against an inferred type.
             * So, in addition, check if there are integer properties 0..n and no other numeric keys
             */
            function couldBeTupleType(type) {
                const properties = type.getProperties();
                if (properties.length === 0) {
                    return false;
                }
                let i = 0;
                for (; i < properties.length; ++i) {
                    const name = properties[i].name;
                    if (String(i) !== name) {
                        if (i === 0) {
                            // if there are no integer properties, this is not a tuple
                            return false;
                        }
                        break;
                    }
                }
                for (; i < properties.length; ++i) {
                    if (String(+properties[i].name) === properties[i].name) {
                        return false; // if there are any other numeric properties, this is not a tuple
                    }
                }
                return true;
            }
            /**
             * Returns true if there's a chance the variable has been used before a value has been assigned to it
             */
            function isPossiblyUsedBeforeAssigned(node) {
                const declaration = util.getDeclaration(checker, node);
                if (!declaration) {
                    // don't know what the declaration is for some reason, so just assume the worst
                    return true;
                }
                if (
                // non-strict mode doesn't care about used before assigned errors
                (0, tsutils_1.isStrictCompilerOptionEnabled)(compilerOptions, 'strictNullChecks') &&
                    // ignore class properties as they are compile time guarded
                    // also ignore function arguments as they can't be used before defined
                    (0, tsutils_1.isVariableDeclaration)(declaration) &&
                    // is it `const x!: number`
                    declaration.initializer === undefined &&
                    declaration.exclamationToken === undefined &&
                    declaration.type !== undefined) {
                    // check if the defined variable type has changed since assignment
                    const declarationType = checker.getTypeFromTypeNode(declaration.type);
                    const type = util.getConstrainedTypeAtLocation(checker, node);
                    if (declarationType === type) {
                        // possibly used before assigned, so just skip it
                        // better to false negative and skip it, than false positive and fix to compile erroring code
                        //
                        // no better way to figure this out right now
                        // https://github.com/Microsoft/TypeScript/issues/31124
                        return true;
                    }
                }
                return false;
            }
            function isConstAssertion(node) {
                return (node.type === utils_1.AST_NODE_TYPES.TSTypeReference &&
                    node.typeName.type === utils_1.AST_NODE_TYPES.Identifier &&
                    node.typeName.name === 'const');
            }
            return {
                TSNonNullExpression(node) {
                    var _a;
                    if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.AssignmentExpression &&
                        node.parent.operator === '=') {
                        if (node.parent.left === node) {
                            context.report({
                                node,
                                messageId: 'contextuallyUnnecessary',
                                fix(fixer) {
                                    return fixer.removeRange([
                                        node.expression.range[1],
                                        node.range[1],
                                    ]);
                                },
                            });
                        }
                        // for all other = assignments we ignore non-null checks
                        // this is because non-null assertions can change the type-flow of the code
                        // so whilst they might be unnecessary for the assignment - they are necessary
                        // for following code
                        return;
                    }
                    const originalNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                    const type = util.getConstrainedTypeAtLocation(checker, originalNode.expression);
                    if (!util.isNullableType(type)) {
                        if (isPossiblyUsedBeforeAssigned(originalNode.expression)) {
                            return;
                        }
                        context.report({
                            node,
                            messageId: 'unnecessaryAssertion',
                            fix(fixer) {
                                return fixer.removeRange([
                                    node.expression.range[1],
                                    node.range[1],
                                ]);
                            },
                        });
                    }
                    else {
                        // we know it's a nullable type
                        // so figure out if the variable is used in a place that accepts nullable types
                        const contextualType = util.getContextualType(checker, originalNode);
                        if (contextualType) {
                            // in strict mode you can't assign null to undefined, so we have to make sure that
                            // the two types share a nullable type
                            const typeIncludesUndefined = util.isTypeFlagSet(type, ts.TypeFlags.Undefined);
                            const typeIncludesNull = util.isTypeFlagSet(type, ts.TypeFlags.Null);
                            const contextualTypeIncludesUndefined = util.isTypeFlagSet(contextualType, ts.TypeFlags.Undefined);
                            const contextualTypeIncludesNull = util.isTypeFlagSet(contextualType, ts.TypeFlags.Null);
                            // make sure that the parent accepts the same types
                            // i.e. assigning `string | null | undefined` to `string | undefined` is invalid
                            const isValidUndefined = typeIncludesUndefined
                                ? contextualTypeIncludesUndefined
                                : true;
                            const isValidNull = typeIncludesNull
                                ? contextualTypeIncludesNull
                                : true;
                            if (isValidUndefined && isValidNull) {
                                context.report({
                                    node,
                                    messageId: 'contextuallyUnnecessary',
                                    fix(fixer) {
                                        return fixer.removeRange([
                                            node.expression.range[1],
                                            node.range[1],
                                        ]);
                                    },
                                });
                            }
                        }
                    }
                },
                'TSAsExpression, TSTypeAssertion'(node) {
                    var _a;
                    if (((_a = options.typesToIgnore) === null || _a === void 0 ? void 0 : _a.includes(sourceCode.getText(node.typeAnnotation))) ||
                        isConstAssertion(node.typeAnnotation)) {
                        return;
                    }
                    const originalNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                    const castType = checker.getTypeAtLocation(originalNode);
                    if ((0, tsutils_1.isTypeFlagSet)(castType, ts.TypeFlags.Literal) ||
                        ((0, tsutils_1.isObjectType)(castType) &&
                            ((0, tsutils_1.isObjectFlagSet)(castType, ts.ObjectFlags.Tuple) ||
                                couldBeTupleType(castType)))) {
                        // It's not always safe to remove a cast to a literal type or tuple
                        // type, as those types are sometimes widened without the cast.
                        return;
                    }
                    const uncastType = checker.getTypeAtLocation(originalNode.expression);
                    if (uncastType === castType) {
                        context.report({
                            node,
                            messageId: 'unnecessaryAssertion',
                            fix(fixer) {
                                if (originalNode.kind === ts.SyntaxKind.TypeAssertionExpression) {
                                    const closingAngleBracket = sourceCode.getTokenAfter(node.typeAnnotation);
                                    return (closingAngleBracket === null || closingAngleBracket === void 0 ? void 0 : closingAngleBracket.value) === '>'
                                        ? fixer.removeRange([
                                            node.range[0],
                                            closingAngleBracket.range[1],
                                        ])
                                        : null;
                                }
                                return fixer.removeRange([
                                    node.expression.range[1] + 1,
                                    node.range[1],
                                ]);
                            },
                        });
                    }
                    // TODO - add contextually unnecessary check for this
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unnecessary-type-constraint.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const semver = __importStar(require(802) /* semver */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    const is3dot5 = semver.satisfies(ts.version, `>= 3.5.0 || >= 3.5.1-rc || >= 3.5.0-beta`, {
        includePrerelease: true,
    });
    const is3dot9 = is3dot5 &&
        semver.satisfies(ts.version, `>= 3.9.0 || >= 3.9.1-rc || >= 3.9.0-beta`, {
            includePrerelease: true,
        });
    exports.default = util.createRule({
        name: 'no-unnecessary-type-constraint',
        meta: {
            docs: {
                description: 'Disallow unnecessary constraints on generic types',
                recommended: 'error',
            },
            hasSuggestions: true,
            messages: {
                unnecessaryConstraint: 'Constraining the generic type `{{name}}` to `{{constraint}}` does nothing and is unnecessary.',
                removeUnnecessaryConstraint: 'Remove the unnecessary `{{constraint}}` constraint.',
            },
            schema: [],
            type: 'suggestion',
        },
        defaultOptions: [],
        create(context) {
            if (!is3dot5) {
                return {};
            }
            // In theory, we could use the type checker for more advanced constraint types...
            // ...but in practice, these types are rare, and likely not worth requiring type info.
            // https://github.com/typescript-eslint/typescript-eslint/pull/2516#discussion_r495731858
            const unnecessaryConstraints = is3dot9
                ? new Map([
                    [utils_1.AST_NODE_TYPES.TSAnyKeyword, 'any'],
                    [utils_1.AST_NODE_TYPES.TSUnknownKeyword, 'unknown'],
                ])
                : new Map([[utils_1.AST_NODE_TYPES.TSUnknownKeyword, 'unknown']]);
            const inJsx = context.getFilename().toLowerCase().endsWith('tsx');
            const source = context.getSourceCode();
            const checkNode = (node, inArrowFunction) => {
                const constraint = unnecessaryConstraints.get(node.constraint.type);
                function shouldAddTrailingComma() {
                    if (!inArrowFunction || !inJsx) {
                        return false;
                    }
                    // Only <T>() => {} would need trailing comma
                    return (node.parent.params.length ===
                        1 &&
                        source.getTokensAfter(node)[0].value !== ',' &&
                        !node.default);
                }
                if (constraint) {
                    context.report({
                        data: {
                            constraint,
                            name: node.name.name,
                        },
                        suggest: [
                            {
                                messageId: 'removeUnnecessaryConstraint',
                                data: {
                                    constraint,
                                },
                                fix(fixer) {
                                    return fixer.replaceTextRange([node.name.range[1], node.constraint.range[1]], shouldAddTrailingComma() ? ',' : '');
                                },
                            },
                        ],
                        messageId: 'unnecessaryConstraint',
                        node,
                    });
                }
            };
            return {
                ':not(ArrowFunctionExpression) > TSTypeParameterDeclaration > TSTypeParameter[constraint]'(node) {
                    checkNode(node, false);
                },
                'ArrowFunctionExpression > TSTypeParameterDeclaration > TSTypeParameter[constraint]'(node) {
                    checkNode(node, true);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unsafe-argument.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    class FunctionSignature {
        static create(checker, tsNode) {
            var _a;
            const signature = checker.getResolvedSignature(tsNode);
            if (!signature) {
                return null;
            }
            const paramTypes = [];
            let restType = null;
            const parameters = signature.getParameters();
            for (let i = 0; i < parameters.length; i += 1) {
                const param = parameters[i];
                const type = checker.getTypeOfSymbolAtLocation(param, tsNode);
                const decl = (_a = param.getDeclarations()) === null || _a === void 0 ? void 0 : _a[0];
                if (decl && ts.isParameter(decl) && decl.dotDotDotToken) {
                    // is a rest param
                    if (checker.isArrayType(type)) {
                        restType = {
                            type: checker.getTypeArguments(type)[0],
                            kind: 0 /* RestTypeKind.Array */,
                            index: i,
                        };
                    }
                    else if (checker.isTupleType(type)) {
                        restType = {
                            typeArguments: checker.getTypeArguments(type),
                            kind: 1 /* RestTypeKind.Tuple */,
                            index: i,
                        };
                    }
                    else {
                        restType = {
                            type,
                            kind: 2 /* RestTypeKind.Other */,
                            index: i,
                        };
                    }
                    break;
                }
                paramTypes.push(type);
            }
            return new this(paramTypes, restType);
        }
        constructor(paramTypes, restType) {
            this.paramTypes = paramTypes;
            this.restType = restType;
            this.parameterTypeIndex = 0;
            this.hasConsumedArguments = false;
        }
        getNextParameterType() {
            const index = this.parameterTypeIndex;
            this.parameterTypeIndex += 1;
            if (index >= this.paramTypes.length || this.hasConsumedArguments) {
                if (this.restType == null) {
                    return null;
                }
                switch (this.restType.kind) {
                    case 1 /* RestTypeKind.Tuple */: {
                        const typeArguments = this.restType.typeArguments;
                        if (this.hasConsumedArguments) {
                            // all types consumed by a rest - just assume it's the last type
                            // there is one edge case where this is wrong, but we ignore it because
                            // it's rare and really complicated to handle
                            // eg: function foo(...a: [number, ...string[], number])
                            return typeArguments[typeArguments.length - 1];
                        }
                        const typeIndex = index - this.restType.index;
                        if (typeIndex >= typeArguments.length) {
                            return typeArguments[typeArguments.length - 1];
                        }
                        return typeArguments[typeIndex];
                    }
                    case 0 /* RestTypeKind.Array */:
                    case 2 /* RestTypeKind.Other */:
                        return this.restType.type;
                }
            }
            return this.paramTypes[index];
        }
        consumeRemainingArguments() {
            this.hasConsumedArguments = true;
        }
    }
    exports.default = util.createRule({
        name: 'no-unsafe-argument',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow calling a function with a value with type `any`',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                unsafeArgument: 'Unsafe argument of type `{{sender}}` assigned to a parameter of type `{{receiver}}`.',
                unsafeTupleSpread: 'Unsafe spread of a tuple type. The argument is of type `{{sender}}` and is assigned to a parameter of type `{{receiver}}`.',
                unsafeArraySpread: 'Unsafe spread of an `any` array type.',
                unsafeSpread: 'Unsafe spread of an `any` type.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const { program, esTreeNodeToTSNodeMap } = util.getParserServices(context);
            const checker = program.getTypeChecker();
            return {
                'CallExpression, NewExpression'(node) {
                    if (node.arguments.length === 0) {
                        return;
                    }
                    // ignore any-typed calls as these are caught by no-unsafe-call
                    if (util.isTypeAnyType(checker.getTypeAtLocation(esTreeNodeToTSNodeMap.get(node.callee)))) {
                        return;
                    }
                    const tsNode = esTreeNodeToTSNodeMap.get(node);
                    const signature = FunctionSignature.create(checker, tsNode);
                    if (!signature) {
                        return;
                    }
                    for (const argument of node.arguments) {
                        switch (argument.type) {
                            // spreads consume
                            case utils_1.AST_NODE_TYPES.SpreadElement: {
                                const spreadArgType = checker.getTypeAtLocation(esTreeNodeToTSNodeMap.get(argument.argument));
                                if (util.isTypeAnyType(spreadArgType)) {
                                    // foo(...any)
                                    context.report({
                                        node: argument,
                                        messageId: 'unsafeSpread',
                                    });
                                }
                                else if (util.isTypeAnyArrayType(spreadArgType, checker)) {
                                    // foo(...any[])
                                    // TODO - we could break down the spread and compare the array type against each argument
                                    context.report({
                                        node: argument,
                                        messageId: 'unsafeArraySpread',
                                    });
                                }
                                else if (checker.isTupleType(spreadArgType)) {
                                    // foo(...[tuple1, tuple2])
                                    const spreadTypeArguments = checker.getTypeArguments(spreadArgType);
                                    for (const tupleType of spreadTypeArguments) {
                                        const parameterType = signature.getNextParameterType();
                                        if (parameterType == null) {
                                            continue;
                                        }
                                        const result = util.isUnsafeAssignment(tupleType, parameterType, checker, 
                                        // we can't pass the individual tuple members in here as this will most likely be a spread variable
                                        // not a spread array
                                        null);
                                        if (result) {
                                            context.report({
                                                node: argument,
                                                messageId: 'unsafeTupleSpread',
                                                data: {
                                                    sender: checker.typeToString(tupleType),
                                                    receiver: checker.typeToString(parameterType),
                                                },
                                            });
                                        }
                                    }
                                    if (spreadArgType.target.hasRestElement) {
                                        // the last element was a rest - so all remaining defined arguments can be considered "consumed"
                                        // all remaining arguments should be compared against the rest type (if one exists)
                                        signature.consumeRemainingArguments();
                                    }
                                }
                                else {
                                    // something that's iterable
                                    // handling this will be pretty complex - so we ignore it for now
                                    // TODO - handle generic iterable case
                                }
                                break;
                            }
                            default: {
                                const parameterType = signature.getNextParameterType();
                                if (parameterType == null) {
                                    continue;
                                }
                                const argumentType = checker.getTypeAtLocation(esTreeNodeToTSNodeMap.get(argument));
                                const result = util.isUnsafeAssignment(argumentType, parameterType, checker, argument);
                                if (result) {
                                    context.report({
                                        node: argument,
                                        messageId: 'unsafeArgument',
                                        data: {
                                            sender: checker.typeToString(argumentType),
                                            receiver: checker.typeToString(parameterType),
                                        },
                                    });
                                }
                            }
                        }
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unsafe-assignment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    exports.default = util.createRule({
        name: 'no-unsafe-assignment',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow assigning a value with type `any` to variables and properties',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                anyAssignment: 'Unsafe assignment of an `any` value.',
                anyAssignmentThis: [
                    'Unsafe assignment of an `any` value. `this` is typed as `any`.',
                    'You can try to fix this by turning on the `noImplicitThis` compiler option, or adding a `this` parameter to the function.',
                ].join('\n'),
                unsafeArrayPattern: 'Unsafe array destructuring of an `any` array value.',
                unsafeArrayPatternFromTuple: 'Unsafe array destructuring of a tuple element with an `any` value.',
                unsafeAssignment: 'Unsafe assignment of type {{sender}} to a variable of type {{receiver}}.',
                unsafeArraySpread: 'Unsafe spread of an `any` value in an array.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const { program, esTreeNodeToTSNodeMap } = util.getParserServices(context);
            const checker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            const isNoImplicitThis = tsutils.isStrictCompilerOptionEnabled(compilerOptions, 'noImplicitThis');
            // returns true if the assignment reported
            function checkArrayDestructureHelper(receiverNode, senderNode) {
                if (receiverNode.type !== utils_1.AST_NODE_TYPES.ArrayPattern) {
                    return false;
                }
                const senderTsNode = esTreeNodeToTSNodeMap.get(senderNode);
                const senderType = checker.getTypeAtLocation(senderTsNode);
                return checkArrayDestructure(receiverNode, senderType, senderTsNode);
            }
            // returns true if the assignment reported
            function checkArrayDestructure(receiverNode, senderType, senderNode) {
                // any array
                // const [x] = ([] as any[]);
                if (util.isTypeAnyArrayType(senderType, checker)) {
                    context.report({
                        node: receiverNode,
                        messageId: 'unsafeArrayPattern',
                    });
                    return false;
                }
                if (!checker.isTupleType(senderType)) {
                    return true;
                }
                const tupleElements = util.getTypeArguments(senderType, checker);
                // tuple with any
                // const [x] = [1 as any];
                let didReport = false;
                for (let receiverIndex = 0; receiverIndex < receiverNode.elements.length; receiverIndex += 1) {
                    const receiverElement = receiverNode.elements[receiverIndex];
                    if (!receiverElement) {
                        continue;
                    }
                    if (receiverElement.type === utils_1.AST_NODE_TYPES.RestElement) {
                        // don't handle rests as they're not a 1:1 assignment
                        continue;
                    }
                    const senderType = tupleElements[receiverIndex];
                    if (!senderType) {
                        continue;
                    }
                    // check for the any type first so we can handle [[[x]]] = [any]
                    if (util.isTypeAnyType(senderType)) {
                        context.report({
                            node: receiverElement,
                            messageId: 'unsafeArrayPatternFromTuple',
                        });
                        // we want to report on every invalid element in the tuple
                        didReport = true;
                    }
                    else if (receiverElement.type === utils_1.AST_NODE_TYPES.ArrayPattern) {
                        didReport = checkArrayDestructure(receiverElement, senderType, senderNode);
                    }
                    else if (receiverElement.type === utils_1.AST_NODE_TYPES.ObjectPattern) {
                        didReport = checkObjectDestructure(receiverElement, senderType, senderNode);
                    }
                }
                return didReport;
            }
            // returns true if the assignment reported
            function checkObjectDestructureHelper(receiverNode, senderNode) {
                if (receiverNode.type !== utils_1.AST_NODE_TYPES.ObjectPattern) {
                    return false;
                }
                const senderTsNode = esTreeNodeToTSNodeMap.get(senderNode);
                const senderType = checker.getTypeAtLocation(senderTsNode);
                return checkObjectDestructure(receiverNode, senderType, senderTsNode);
            }
            // returns true if the assignment reported
            function checkObjectDestructure(receiverNode, senderType, senderNode) {
                const properties = new Map(senderType
                    .getProperties()
                    .map(property => [
                    property.getName(),
                    checker.getTypeOfSymbolAtLocation(property, senderNode),
                ]));
                let didReport = false;
                for (const receiverProperty of receiverNode.properties) {
                    if (receiverProperty.type === utils_1.AST_NODE_TYPES.RestElement) {
                        // don't bother checking rest
                        continue;
                    }
                    let key;
                    if (receiverProperty.computed === false) {
                        key =
                            receiverProperty.key.type === utils_1.AST_NODE_TYPES.Identifier
                                ? receiverProperty.key.name
                                : String(receiverProperty.key.value);
                    }
                    else if (receiverProperty.key.type === utils_1.AST_NODE_TYPES.Literal) {
                        key = String(receiverProperty.key.value);
                    }
                    else if (receiverProperty.key.type === utils_1.AST_NODE_TYPES.TemplateLiteral &&
                        receiverProperty.key.quasis.length === 1) {
                        key = String(receiverProperty.key.quasis[0].value.cooked);
                    }
                    else {
                        // can't figure out the name, so skip it
                        continue;
                    }
                    const senderType = properties.get(key);
                    if (!senderType) {
                        continue;
                    }
                    // check for the any type first so we can handle {x: {y: z}} = {x: any}
                    if (util.isTypeAnyType(senderType)) {
                        context.report({
                            node: receiverProperty.value,
                            messageId: 'unsafeArrayPatternFromTuple',
                        });
                        didReport = true;
                    }
                    else if (receiverProperty.value.type === utils_1.AST_NODE_TYPES.ArrayPattern) {
                        didReport = checkArrayDestructure(receiverProperty.value, senderType, senderNode);
                    }
                    else if (receiverProperty.value.type === utils_1.AST_NODE_TYPES.ObjectPattern) {
                        didReport = checkObjectDestructure(receiverProperty.value, senderType, senderNode);
                    }
                }
                return didReport;
            }
            // returns true if the assignment reported
            function checkAssignment(receiverNode, senderNode, reportingNode, comparisonType) {
                var _a;
                const receiverTsNode = esTreeNodeToTSNodeMap.get(receiverNode);
                const receiverType = comparisonType === 2 /* ComparisonType.Contextual */
                    ? (_a = util.getContextualType(checker, receiverTsNode)) !== null && _a !== void 0 ? _a : checker.getTypeAtLocation(receiverTsNode)
                    : checker.getTypeAtLocation(receiverTsNode);
                const senderType = checker.getTypeAtLocation(esTreeNodeToTSNodeMap.get(senderNode));
                if (util.isTypeAnyType(senderType)) {
                    // handle cases when we assign any ==> unknown.
                    if (util.isTypeUnknownType(receiverType)) {
                        return false;
                    }
                    let messageId = 'anyAssignment';
                    if (!isNoImplicitThis) {
                        // `var foo = this`
                        const thisExpression = (0, util_1.getThisExpression)(senderNode);
                        if (thisExpression &&
                            util.isTypeAnyType(util.getConstrainedTypeAtLocation(checker, esTreeNodeToTSNodeMap.get(thisExpression)))) {
                            messageId = 'anyAssignmentThis';
                        }
                    }
                    context.report({
                        node: reportingNode,
                        messageId,
                    });
                    return true;
                }
                if (comparisonType === 0 /* ComparisonType.None */) {
                    return false;
                }
                const result = util.isUnsafeAssignment(senderType, receiverType, checker, senderNode);
                if (!result) {
                    return false;
                }
                const { sender, receiver } = result;
                context.report({
                    node: reportingNode,
                    messageId: 'unsafeAssignment',
                    data: {
                        sender: checker.typeToString(sender),
                        receiver: checker.typeToString(receiver),
                    },
                });
                return true;
            }
            function getComparisonType(typeAnnotation) {
                return typeAnnotation
                    ? // if there's a type annotation, we can do a comparison
                        1 /* ComparisonType.Basic */
                    : // no type annotation means the variable's type will just be inferred, thus equal
                        0 /* ComparisonType.None */;
            }
            return {
                'VariableDeclarator[init != null]'(node) {
                    const init = util.nullThrows(node.init, util.NullThrowsReasons.MissingToken(node.type, 'init'));
                    let didReport = checkAssignment(node.id, init, node, getComparisonType(node.id.typeAnnotation));
                    if (!didReport) {
                        didReport = checkArrayDestructureHelper(node.id, init);
                    }
                    if (!didReport) {
                        checkObjectDestructureHelper(node.id, init);
                    }
                },
                'PropertyDefinition[value != null]'(node) {
                    checkAssignment(node.key, node.value, node, getComparisonType(node.typeAnnotation));
                },
                'AssignmentExpression[operator = "="], AssignmentPattern'(node) {
                    let didReport = checkAssignment(node.left, node.right, node, 1 /* ComparisonType.Basic */);
                    if (!didReport) {
                        didReport = checkArrayDestructureHelper(node.left, node.right);
                    }
                    if (!didReport) {
                        checkObjectDestructureHelper(node.left, node.right);
                    }
                },
                // object pattern props are checked via assignments
                ':not(ObjectPattern) > Property'(node) {
                    if (node.value.type === utils_1.AST_NODE_TYPES.AssignmentPattern ||
                        node.value.type === utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression) {
                        // handled by other selector
                        return;
                    }
                    checkAssignment(node.key, node.value, node, 2 /* ComparisonType.Contextual */);
                },
                'ArrayExpression > SpreadElement'(node) {
                    const resetNode = esTreeNodeToTSNodeMap.get(node.argument);
                    const restType = checker.getTypeAtLocation(resetNode);
                    if (util.isTypeAnyType(restType) ||
                        util.isTypeAnyArrayType(restType, checker)) {
                        context.report({
                            node: node,
                            messageId: 'unsafeArraySpread',
                        });
                    }
                },
                'JSXAttribute[value != null]'(node) {
                    const value = util.nullThrows(node.value, util.NullThrowsReasons.MissingToken(node.type, 'value'));
                    if (value.type !== utils_1.AST_NODE_TYPES.JSXExpressionContainer ||
                        value.expression.type === utils_1.AST_NODE_TYPES.JSXEmptyExpression) {
                        return;
                    }
                    checkAssignment(node.name, value.expression, value.expression, 2 /* ComparisonType.Contextual */);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unsafe-call.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const tsutils = __importStar(require(1034) /* tsutils */);
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    exports.default = util.createRule({
        name: 'no-unsafe-call',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow calling a value with type `any`',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                unsafeCall: 'Unsafe call of an `any` typed value.',
                unsafeCallThis: [
                    'Unsafe call of an `any` typed value. `this` is typed as `any`.',
                    'You can try to fix this by turning on the `noImplicitThis` compiler option, or adding a `this` parameter to the function.',
                ].join('\n'),
                unsafeNew: 'Unsafe construction of an any type value.',
                unsafeTemplateTag: 'Unsafe any typed template tag.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const { program, esTreeNodeToTSNodeMap } = util.getParserServices(context);
            const checker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            const isNoImplicitThis = tsutils.isStrictCompilerOptionEnabled(compilerOptions, 'noImplicitThis');
            function checkCall(node, reportingNode, messageId) {
                const tsNode = esTreeNodeToTSNodeMap.get(node);
                const type = util.getConstrainedTypeAtLocation(checker, tsNode);
                if (util.isTypeAnyType(type)) {
                    if (!isNoImplicitThis) {
                        // `this()` or `this.foo()` or `this.foo[bar]()`
                        const thisExpression = (0, util_1.getThisExpression)(node);
                        if (thisExpression &&
                            util.isTypeAnyType(util.getConstrainedTypeAtLocation(checker, esTreeNodeToTSNodeMap.get(thisExpression)))) {
                            messageId = 'unsafeCallThis';
                        }
                    }
                    context.report({
                        node: reportingNode,
                        messageId: messageId,
                    });
                }
            }
            return {
                'CallExpression > *.callee'(node) {
                    checkCall(node, node, 'unsafeCall');
                },
                NewExpression(node) {
                    checkCall(node.callee, node, 'unsafeNew');
                },
                'TaggedTemplateExpression > *.tag'(node) {
                    checkCall(node, node, 'unsafeTemplateTag');
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unsafe-declaration-merging.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-unsafe-declaration-merging',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow unsafe declaration merging',
                recommended: 'strict',
                requiresTypeChecking: false,
            },
            messages: {
                unsafeMerging: 'Unsafe declaration merging between classes and interfaces.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            function checkUnsafeDeclaration(scope, node, unsafeKind) {
                const variable = scope.set.get(node.name);
                if (!variable) {
                    return;
                }
                const defs = variable.defs;
                if (defs.length <= 1) {
                    return;
                }
                if (defs.some(def => def.node.type === unsafeKind)) {
                    context.report({
                        node,
                        messageId: 'unsafeMerging',
                    });
                }
            }
            return {
                ClassDeclaration(node) {
                    if (node.id) {
                        // by default eslint returns the inner class scope for the ClassDeclaration node
                        // but we want the outer scope within which merged variables will sit
                        const currentScope = context.getScope().upper;
                        if (currentScope == null) {
                            return;
                        }
                        checkUnsafeDeclaration(currentScope, node.id, utils_1.AST_NODE_TYPES.TSInterfaceDeclaration);
                    }
                },
                TSInterfaceDeclaration(node) {
                    checkUnsafeDeclaration(context.getScope(), node.id, utils_1.AST_NODE_TYPES.ClassDeclaration);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unsafe-member-access.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    exports.default = util.createRule({
        name: 'no-unsafe-member-access',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow member access on a value with type `any`',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                unsafeMemberExpression: 'Unsafe member access {{property}} on an `any` value.',
                unsafeThisMemberExpression: [
                    'Unsafe member access {{property}} on an `any` value. `this` is typed as `any`.',
                    'You can try to fix this by turning on the `noImplicitThis` compiler option, or adding a `this` parameter to the function.',
                ].join('\n'),
                unsafeComputedMemberAccess: 'Computed name {{property}} resolves to an any value.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const { program, esTreeNodeToTSNodeMap } = util.getParserServices(context);
            const checker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            const isNoImplicitThis = tsutils.isStrictCompilerOptionEnabled(compilerOptions, 'noImplicitThis');
            const sourceCode = context.getSourceCode();
            const stateCache = new Map();
            function checkMemberExpression(node) {
                const cachedState = stateCache.get(node);
                if (cachedState) {
                    return cachedState;
                }
                if (node.object.type === utils_1.AST_NODE_TYPES.MemberExpression) {
                    const objectState = checkMemberExpression(node.object);
                    if (objectState === 1 /* State.Unsafe */) {
                        // if the object is unsafe, we know this will be unsafe as well
                        // we don't need to report, as we have already reported on the inner member expr
                        stateCache.set(node, objectState);
                        return objectState;
                    }
                }
                const tsNode = esTreeNodeToTSNodeMap.get(node.object);
                const type = checker.getTypeAtLocation(tsNode);
                const state = util.isTypeAnyType(type) ? 1 /* State.Unsafe */ : 2 /* State.Safe */;
                stateCache.set(node, state);
                if (state === 1 /* State.Unsafe */) {
                    const propertyName = sourceCode.getText(node.property);
                    let messageId = 'unsafeMemberExpression';
                    if (!isNoImplicitThis) {
                        // `this.foo` or `this.foo[bar]`
                        const thisExpression = (0, util_1.getThisExpression)(node);
                        if (thisExpression &&
                            util.isTypeAnyType(util.getConstrainedTypeAtLocation(checker, esTreeNodeToTSNodeMap.get(thisExpression)))) {
                            messageId = 'unsafeThisMemberExpression';
                        }
                    }
                    context.report({
                        node,
                        messageId,
                        data: {
                            property: node.computed ? `[${propertyName}]` : `.${propertyName}`,
                        },
                    });
                }
                return state;
            }
            return {
                // ignore MemberExpression if it's parent is TSClassImplements or TSInterfaceHeritage
                ':not(TSClassImplements, TSInterfaceHeritage) > MemberExpression': checkMemberExpression,
                'MemberExpression[computed = true] > *.property'(node) {
                    if (
                    // x[1]
                    node.type === utils_1.AST_NODE_TYPES.Literal ||
                        // x[1++] x[++x] etc
                        // FUN FACT - **all** update expressions return type number, regardless of the argument's type,
                        // because JS engines return NaN if there the argument is not a number.
                        node.type === utils_1.AST_NODE_TYPES.UpdateExpression) {
                        // perf optimizations - literals can obviously never be `any`
                        return;
                    }
                    const tsNode = esTreeNodeToTSNodeMap.get(node);
                    const type = checker.getTypeAtLocation(tsNode);
                    if (util.isTypeAnyType(type)) {
                        const propertyName = sourceCode.getText(node);
                        context.report({
                            node,
                            messageId: 'unsafeComputedMemberAccess',
                            data: {
                                property: `[${propertyName}]`,
                            },
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unsafe-return.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    exports.default = util.createRule({
        name: 'no-unsafe-return',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow returning a value with type `any` from a function',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                unsafeReturn: 'Unsafe return of an `{{type}}` typed value.',
                unsafeReturnThis: [
                    'Unsafe return of an `{{type}}` typed value. `this` is typed as `any`.',
                    'You can try to fix this by turning on the `noImplicitThis` compiler option, or adding a `this` parameter to the function.',
                ].join('\n'),
                unsafeReturnAssignment: 'Unsafe return of type `{{sender}}` from function with return type `{{receiver}}`.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const { program, esTreeNodeToTSNodeMap } = util.getParserServices(context);
            const checker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            const isNoImplicitThis = tsutils.isStrictCompilerOptionEnabled(compilerOptions, 'noImplicitThis');
            function getParentFunctionNode(node) {
                let current = node.parent;
                while (current) {
                    if (current.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression ||
                        current.type === utils_1.AST_NODE_TYPES.FunctionDeclaration ||
                        current.type === utils_1.AST_NODE_TYPES.FunctionExpression) {
                        return current;
                    }
                    current = current.parent;
                }
                // this shouldn't happen in correct code, but someone may attempt to parse bad code
                // the parser won't error, so we shouldn't throw here
                /* istanbul ignore next */ return null;
            }
            function checkReturn(returnNode, reportingNode = returnNode) {
                const tsNode = esTreeNodeToTSNodeMap.get(returnNode);
                const anyType = util.isAnyOrAnyArrayTypeDiscriminated(tsNode, checker);
                const functionNode = getParentFunctionNode(returnNode);
                /* istanbul ignore if */ if (!functionNode) {
                    return;
                }
                // function has an explicit return type, so ensure it's a safe return
                const returnNodeType = util.getConstrainedTypeAtLocation(checker, esTreeNodeToTSNodeMap.get(returnNode));
                const functionTSNode = esTreeNodeToTSNodeMap.get(functionNode);
                // function expressions will not have their return type modified based on receiver typing
                // so we have to use the contextual typing in these cases, i.e.
                // const foo1: () => Set<string> = () => new Set<any>();
                // the return type of the arrow function is Set<any> even though the variable is typed as Set<string>
                let functionType = tsutils.isExpression(functionTSNode)
                    ? util.getContextualType(checker, functionTSNode)
                    : checker.getTypeAtLocation(functionTSNode);
                if (!functionType) {
                    functionType = checker.getTypeAtLocation(functionTSNode);
                }
                // If there is an explicit type annotation *and* that type matches the actual
                // function return type, we shouldn't complain (it's intentional, even if unsafe)
                if (functionTSNode.type) {
                    for (const signature of functionType.getCallSignatures()) {
                        if (returnNodeType === signature.getReturnType()) {
                            return;
                        }
                    }
                }
                if (anyType !== util.AnyType.Safe) {
                    // Allow cases when the declared return type of the function is either unknown or unknown[]
                    // and the function is returning any or any[].
                    for (const signature of functionType.getCallSignatures()) {
                        const functionReturnType = signature.getReturnType();
                        if (anyType === util.AnyType.Any &&
                            util.isTypeUnknownType(functionReturnType)) {
                            return;
                        }
                        if (anyType === util.AnyType.AnyArray &&
                            util.isTypeUnknownArrayType(functionReturnType, checker)) {
                            return;
                        }
                    }
                    let messageId = 'unsafeReturn';
                    if (!isNoImplicitThis) {
                        // `return this`
                        const thisExpression = (0, util_1.getThisExpression)(returnNode);
                        if (thisExpression &&
                            util.isTypeAnyType(util.getConstrainedTypeAtLocation(checker, esTreeNodeToTSNodeMap.get(thisExpression)))) {
                            messageId = 'unsafeReturnThis';
                        }
                    }
                    // If the function return type was not unknown/unknown[], mark usage as unsafeReturn.
                    return context.report({
                        node: reportingNode,
                        messageId,
                        data: {
                            type: anyType === util.AnyType.Any ? 'any' : 'any[]',
                        },
                    });
                }
                for (const signature of functionType.getCallSignatures()) {
                    const functionReturnType = signature.getReturnType();
                    const result = util.isUnsafeAssignment(returnNodeType, functionReturnType, checker, returnNode);
                    if (!result) {
                        return;
                    }
                    const { sender, receiver } = result;
                    return context.report({
                        node: reportingNode,
                        messageId: 'unsafeReturnAssignment',
                        data: {
                            sender: checker.typeToString(sender),
                            receiver: checker.typeToString(receiver),
                        },
                    });
                }
            }
            return {
                ReturnStatement(node) {
                    const argument = node.argument;
                    if (!argument) {
                        return;
                    }
                    checkReturn(argument, node);
                },
                'ArrowFunctionExpression > :not(BlockStatement).body': checkReturn,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unused-expressions.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var _a;
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-unused-expressions');
    exports.default = util.createRule({
        name: 'no-unused-expressions',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow unused expressions',
                recommended: false,
                extendsBaseRule: true,
            },
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            // TODO: this rule has only had messages since v7.0 - remove this when we remove support for v6
            messages: (_a = baseRule.meta.messages) !== null && _a !== void 0 ? _a : {
                unusedExpression: 'Expected an assignment or function call and instead saw an expression.',
            },
        },
        defaultOptions: [
            {
                allowShortCircuit: false,
                allowTernary: false,
                allowTaggedTemplates: false,
            },
        ],
        create(context, [{ allowShortCircuit = false, allowTernary = false }]) {
            const rules = baseRule.create(context);
            function isValidExpression(node) {
                if (allowShortCircuit && node.type === utils_1.AST_NODE_TYPES.LogicalExpression) {
                    return isValidExpression(node.right);
                }
                if (allowTernary && node.type === utils_1.AST_NODE_TYPES.ConditionalExpression) {
                    return (isValidExpression(node.alternate) &&
                        isValidExpression(node.consequent));
                }
                return ((node.type === utils_1.AST_NODE_TYPES.ChainExpression &&
                    node.expression.type === utils_1.AST_NODE_TYPES.CallExpression) ||
                    node.type === utils_1.AST_NODE_TYPES.ImportExpression);
            }
            return {
                ExpressionStatement(node) {
                    if (node.directive || isValidExpression(node.expression)) {
                        return;
                    }
                    rules.ExpressionStatement(node);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-unused-vars.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const scope_manager_1 = require(861) /* @typescript-eslint/scope-manager */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-unused-vars',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow unused variables',
                recommended: 'warn',
                extendsBaseRule: true,
            },
            schema: [
                {
                    oneOf: [
                        {
                            enum: ['all', 'local'],
                        },
                        {
                            type: 'object',
                            properties: {
                                vars: {
                                    enum: ['all', 'local'],
                                },
                                varsIgnorePattern: {
                                    type: 'string',
                                },
                                args: {
                                    enum: ['all', 'after-used', 'none'],
                                },
                                ignoreRestSiblings: {
                                    type: 'boolean',
                                },
                                argsIgnorePattern: {
                                    type: 'string',
                                },
                                caughtErrors: {
                                    enum: ['all', 'none'],
                                },
                                caughtErrorsIgnorePattern: {
                                    type: 'string',
                                },
                                destructuredArrayIgnorePattern: {
                                    type: 'string',
                                },
                            },
                            additionalProperties: false,
                        },
                    ],
                },
            ],
            messages: {
                unusedVar: "'{{varName}}' is {{action}} but never used{{additional}}.",
            },
        },
        defaultOptions: [{}],
        create(context, [firstOption]) {
            const filename = context.getFilename();
            const sourceCode = context.getSourceCode();
            const MODULE_DECL_CACHE = new Map();
            const options = (() => {
                var _a, _b, _c, _d;
                const options = {
                    vars: 'all',
                    args: 'after-used',
                    ignoreRestSiblings: false,
                    caughtErrors: 'none',
                };
                if (firstOption) {
                    if (typeof firstOption === 'string') {
                        options.vars = firstOption;
                    }
                    else {
                        options.vars = (_a = firstOption.vars) !== null && _a !== void 0 ? _a : options.vars;
                        options.args = (_b = firstOption.args) !== null && _b !== void 0 ? _b : options.args;
                        options.ignoreRestSiblings =
                            (_c = firstOption.ignoreRestSiblings) !== null && _c !== void 0 ? _c : options.ignoreRestSiblings;
                        options.caughtErrors =
                            (_d = firstOption.caughtErrors) !== null && _d !== void 0 ? _d : options.caughtErrors;
                        if (firstOption.varsIgnorePattern) {
                            options.varsIgnorePattern = new RegExp(firstOption.varsIgnorePattern, 'u');
                        }
                        if (firstOption.argsIgnorePattern) {
                            options.argsIgnorePattern = new RegExp(firstOption.argsIgnorePattern, 'u');
                        }
                        if (firstOption.caughtErrorsIgnorePattern) {
                            options.caughtErrorsIgnorePattern = new RegExp(firstOption.caughtErrorsIgnorePattern, 'u');
                        }
                        if (firstOption.destructuredArrayIgnorePattern) {
                            options.destructuredArrayIgnorePattern = new RegExp(firstOption.destructuredArrayIgnorePattern, 'u');
                        }
                    }
                }
                return options;
            })();
            function collectUnusedVariables() {
                var _a, _b, _c, _d, _e;
                /**
                 * Checks whether a node is a sibling of the rest property or not.
                 * @param {ASTNode} node a node to check
                 * @returns {boolean} True if the node is a sibling of the rest property, otherwise false.
                 */
                function hasRestSibling(node) {
                    var _a;
                    return (node.type === utils_1.AST_NODE_TYPES.Property &&
                        ((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ObjectPattern &&
                        node.parent.properties[node.parent.properties.length - 1].type ===
                            utils_1.AST_NODE_TYPES.RestElement);
                }
                /**
                 * Determines if a variable has a sibling rest property
                 * @param variable eslint-scope variable object.
                 * @returns True if the variable is exported, false if not.
                 */
                function hasRestSpreadSibling(variable) {
                    if (options.ignoreRestSiblings) {
                        const hasRestSiblingDefinition = variable.defs.some(def => hasRestSibling(def.name.parent));
                        const hasRestSiblingReference = variable.references.some(ref => hasRestSibling(ref.identifier.parent));
                        return hasRestSiblingDefinition || hasRestSiblingReference;
                    }
                    return false;
                }
                /**
                 * Checks whether the given variable is after the last used parameter.
                 * @param variable The variable to check.
                 * @returns `true` if the variable is defined after the last used parameter.
                 */
                function isAfterLastUsedArg(variable) {
                    const def = variable.defs[0];
                    const params = context.getDeclaredVariables(def.node);
                    const posteriorParams = params.slice(params.indexOf(variable) + 1);
                    // If any used parameters occur after this parameter, do not report.
                    return !posteriorParams.some(v => v.references.length > 0 || v.eslintUsed);
                }
                const unusedVariablesOriginal = util.collectUnusedVariables(context);
                const unusedVariablesReturn = [];
                for (const variable of unusedVariablesOriginal) {
                    // explicit global variables don't have definitions.
                    if (variable.defs.length === 0) {
                        unusedVariablesReturn.push(variable);
                        continue;
                    }
                    const def = variable.defs[0];
                    if (variable.scope.type === utils_1.TSESLint.Scope.ScopeType.global &&
                        options.vars === 'local') {
                        // skip variables in the global scope if configured to
                        continue;
                    }
                    const refUsedInArrayPatterns = variable.references.some(ref => { var _a; return ((_a = ref.identifier.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ArrayPattern; });
                    // skip elements of array destructuring patterns
                    if ((((_a = def.name.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ArrayPattern ||
                        refUsedInArrayPatterns) &&
                        'name' in def.name &&
                        ((_b = options.destructuredArrayIgnorePattern) === null || _b === void 0 ? void 0 : _b.test(def.name.name))) {
                        continue;
                    }
                    // skip catch variables
                    if (def.type === utils_1.TSESLint.Scope.DefinitionType.CatchClause) {
                        if (options.caughtErrors === 'none') {
                            continue;
                        }
                        // skip ignored parameters
                        if ('name' in def.name &&
                            ((_c = options.caughtErrorsIgnorePattern) === null || _c === void 0 ? void 0 : _c.test(def.name.name))) {
                            continue;
                        }
                    }
                    if (def.type === utils_1.TSESLint.Scope.DefinitionType.Parameter) {
                        // if "args" option is "none", skip any parameter
                        if (options.args === 'none') {
                            continue;
                        }
                        // skip ignored parameters
                        if ('name' in def.name &&
                            ((_d = options.argsIgnorePattern) === null || _d === void 0 ? void 0 : _d.test(def.name.name))) {
                            continue;
                        }
                        // if "args" option is "after-used", skip used variables
                        if (options.args === 'after-used' &&
                            util.isFunction(def.name.parent) &&
                            !isAfterLastUsedArg(variable)) {
                            continue;
                        }
                    }
                    else {
                        // skip ignored variables
                        if ('name' in def.name &&
                            ((_e = options.varsIgnorePattern) === null || _e === void 0 ? void 0 : _e.test(def.name.name))) {
                            continue;
                        }
                    }
                    if (hasRestSpreadSibling(variable)) {
                        continue;
                    }
                    // in case another rule has run and used the collectUnusedVariables,
                    // we want to ensure our selectors that marked variables as used are respected
                    if (variable.eslintUsed) {
                        continue;
                    }
                    unusedVariablesReturn.push(variable);
                }
                return unusedVariablesReturn;
            }
            return {
                // declaration file handling
                [ambientDeclarationSelector(utils_1.AST_NODE_TYPES.Program, true)](node) {
                    if (!util.isDefinitionFile(filename)) {
                        return;
                    }
                    markDeclarationChildAsUsed(node);
                },
                // module declaration in module declaration should not report unused vars error
                // this is workaround as this change should be done in better way
                'TSModuleDeclaration > TSModuleDeclaration'(node) {
                    if (node.id.type === utils_1.AST_NODE_TYPES.Identifier) {
                        let scope = context.getScope();
                        if (scope.upper) {
                            scope = scope.upper;
                        }
                        const superVar = scope.set.get(node.id.name);
                        if (superVar) {
                            superVar.eslintUsed = true;
                        }
                    }
                },
                // children of a namespace that is a child of a declared namespace are auto-exported
                [ambientDeclarationSelector('TSModuleDeclaration[declare = true] > TSModuleBlock TSModuleDeclaration > TSModuleBlock', false)](node) {
                    markDeclarationChildAsUsed(node);
                },
                // declared namespace handling
                [ambientDeclarationSelector('TSModuleDeclaration[declare = true] > TSModuleBlock', false)](node) {
                    var _a;
                    const moduleDecl = util.nullThrows((_a = node.parent) === null || _a === void 0 ? void 0 : _a.parent, util.NullThrowsReasons.MissingParent);
                    // declared ambient modules with an `export =` statement will only export that one thing
                    // all other statements are not automatically exported in this case
                    if (moduleDecl.id.type === utils_1.AST_NODE_TYPES.Literal &&
                        checkModuleDeclForExportEquals(moduleDecl)) {
                        return;
                    }
                    markDeclarationChildAsUsed(node);
                },
                // collect
                'Program:exit'(programNode) {
                    /**
                     * Generates the message data about the variable being defined and unused,
                     * including the ignore pattern if configured.
                     * @param unusedVar eslint-scope variable object.
                     * @returns The message data to be used with this unused variable.
                     */
                    function getDefinedMessageData(unusedVar) {
                        var _a;
                        const defType = (_a = unusedVar === null || unusedVar === void 0 ? void 0 : unusedVar.defs[0]) === null || _a === void 0 ? void 0 : _a.type;
                        let type;
                        let pattern;
                        if (defType === utils_1.TSESLint.Scope.DefinitionType.CatchClause &&
                            options.caughtErrorsIgnorePattern) {
                            type = 'args';
                            pattern = options.caughtErrorsIgnorePattern.toString();
                        }
                        else if (defType === utils_1.TSESLint.Scope.DefinitionType.Parameter &&
                            options.argsIgnorePattern) {
                            type = 'args';
                            pattern = options.argsIgnorePattern.toString();
                        }
                        else if (defType !== utils_1.TSESLint.Scope.DefinitionType.Parameter &&
                            options.varsIgnorePattern) {
                            type = 'vars';
                            pattern = options.varsIgnorePattern.toString();
                        }
                        const additional = type
                            ? `. Allowed unused ${type} must match ${pattern}`
                            : '';
                        return {
                            varName: unusedVar.name,
                            action: 'defined',
                            additional,
                        };
                    }
                    /**
                     * Generate the warning message about the variable being
                     * assigned and unused, including the ignore pattern if configured.
                     * @param unusedVar eslint-scope variable object.
                     * @returns The message data to be used with this unused variable.
                     */
                    function getAssignedMessageData(unusedVar) {
                        var _a;
                        const def = unusedVar.defs[0];
                        let additional = '';
                        if (options.destructuredArrayIgnorePattern &&
                            ((_a = def === null || def === void 0 ? void 0 : def.name.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ArrayPattern) {
                            additional = `. Allowed unused elements of array destructuring patterns must match ${options.destructuredArrayIgnorePattern.toString()}`;
                        }
                        else if (options.varsIgnorePattern) {
                            additional = `. Allowed unused vars must match ${options.varsIgnorePattern.toString()}`;
                        }
                        return {
                            varName: unusedVar.name,
                            action: 'assigned a value',
                            additional,
                        };
                    }
                    const unusedVars = collectUnusedVariables();
                    for (const unusedVar of unusedVars) {
                        // Report the first declaration.
                        if (unusedVar.defs.length > 0) {
                            const writeReferences = unusedVar.references.filter(ref => ref.isWrite() &&
                                ref.from.variableScope === unusedVar.scope.variableScope);
                            context.report({
                                node: writeReferences.length
                                    ? writeReferences[writeReferences.length - 1].identifier
                                    : unusedVar.identifiers[0],
                                messageId: 'unusedVar',
                                data: unusedVar.references.some(ref => ref.isWrite())
                                    ? getAssignedMessageData(unusedVar)
                                    : getDefinedMessageData(unusedVar),
                            });
                            // If there are no regular declaration, report the first `/*globals*/` comment directive.
                        }
                        else if ('eslintExplicitGlobalComments' in unusedVar &&
                            unusedVar.eslintExplicitGlobalComments) {
                            const directiveComment = unusedVar.eslintExplicitGlobalComments[0];
                            context.report({
                                node: programNode,
                                loc: util.getNameLocationInGlobalDirectiveComment(sourceCode, directiveComment, unusedVar.name),
                                messageId: 'unusedVar',
                                data: getDefinedMessageData(unusedVar),
                            });
                        }
                    }
                },
            };
            function checkModuleDeclForExportEquals(node) {
                const cached = MODULE_DECL_CACHE.get(node);
                if (cached != null) {
                    return cached;
                }
                if (node.body && node.body.type === utils_1.AST_NODE_TYPES.TSModuleBlock) {
                    for (const statement of node.body.body) {
                        if (statement.type === utils_1.AST_NODE_TYPES.TSExportAssignment) {
                            MODULE_DECL_CACHE.set(node, true);
                            return true;
                        }
                    }
                }
                MODULE_DECL_CACHE.set(node, false);
                return false;
            }
            function ambientDeclarationSelector(parent, childDeclare) {
                return [
                    // Types are ambiently exported
                    `${parent} > :matches(${[
                        utils_1.AST_NODE_TYPES.TSInterfaceDeclaration,
                        utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration,
                    ].join(', ')})`,
                    // Value things are ambiently exported if they are "declare"d
                    `${parent} > :matches(${[
                        utils_1.AST_NODE_TYPES.ClassDeclaration,
                        utils_1.AST_NODE_TYPES.TSDeclareFunction,
                        utils_1.AST_NODE_TYPES.TSEnumDeclaration,
                        utils_1.AST_NODE_TYPES.TSModuleDeclaration,
                        utils_1.AST_NODE_TYPES.VariableDeclaration,
                    ].join(', ')})${childDeclare ? '[declare = true]' : ''}`,
                ].join(', ');
            }
            function markDeclarationChildAsUsed(node) {
                var _a;
                const identifiers = [];
                switch (node.type) {
                    case utils_1.AST_NODE_TYPES.TSInterfaceDeclaration:
                    case utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration:
                    case utils_1.AST_NODE_TYPES.ClassDeclaration:
                    case utils_1.AST_NODE_TYPES.FunctionDeclaration:
                    case utils_1.AST_NODE_TYPES.TSDeclareFunction:
                    case utils_1.AST_NODE_TYPES.TSEnumDeclaration:
                    case utils_1.AST_NODE_TYPES.TSModuleDeclaration:
                        if (((_a = node.id) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.Identifier) {
                            identifiers.push(node.id);
                        }
                        break;
                    case utils_1.AST_NODE_TYPES.VariableDeclaration:
                        for (const declaration of node.declarations) {
                            visitPattern(declaration, pattern => {
                                identifiers.push(pattern);
                            });
                        }
                        break;
                }
                let scope = context.getScope();
                const shouldUseUpperScope = [
                    utils_1.AST_NODE_TYPES.TSModuleDeclaration,
                    utils_1.AST_NODE_TYPES.TSDeclareFunction,
                ].includes(node.type);
                if (scope.variableScope !== scope) {
                    scope = scope.variableScope;
                }
                else if (shouldUseUpperScope && scope.upper) {
                    scope = scope.upper;
                }
                for (const id of identifiers) {
                    const superVar = scope.set.get(id.name);
                    if (superVar) {
                        superVar.eslintUsed = true;
                    }
                }
            }
            function visitPattern(node, cb) {
                const visitor = new scope_manager_1.PatternVisitor({}, node, cb);
                visitor.visit(node);
            }
        },
    });
    /*
    
    ###### TODO ######
    
    Edge cases that aren't currently handled due to laziness and them being super edgy edge cases
    
    
    --- function params referenced in typeof type refs in the function declaration ---
    --- NOTE - TS gets these cases wrong
    
    function _foo(
      arg: number // arg should be unused
    ): typeof arg {
      return 1 as any;
    }
    
    function _bar(
      arg: number, // arg should be unused
      _arg2: typeof arg,
    ) {}
    
    
    --- function names referenced in typeof type refs in the function declaration ---
    --- NOTE - TS gets these cases right
    
    function foo( // foo should be unused
    ): typeof foo {
        return 1 as any;
    }
    
    function bar( // bar should be unused
      _arg: typeof bar
    ) {}
    
    
    --- if an interface is merged into a namespace  ---
    --- NOTE - TS gets these cases wrong
    
    namespace Test {
        interface Foo { // Foo should be unused here
            a: string;
        }
        export namespace Foo {
           export type T = 'b';
        }
    }
    type T = Test.Foo; // Error: Namespace 'Test' has no exported member 'Foo'.
    
    
    namespace Test {
        export interface Foo {
            a: string;
        }
        namespace Foo { // Foo should be unused here
           export type T = 'b';
        }
    }
    type T = Test.Foo.T; // Error: Namespace 'Test' has no exported member 'Foo'.
    
    */
    /*
    
    ###### TODO ######
    
    We currently extend base `no-unused-vars` implementation because it's easier and lighter-weight.
    
    Because of this, there are a few false-negatives which won't get caught.
    We could fix these if we fork the base rule; but that's a lot of code (~650 lines) to add in.
    I didn't want to do that just yet without some real-world issues, considering these are pretty rare edge-cases.
    
    These cases are mishandled because the base rule assumes that each variable has one def, but type-value shadowing
    creates a variable with two defs
    
    --- type-only or value-only references to type/value shadowed variables ---
    --- NOTE - TS gets these cases wrong
    
    type T = 1;
    const T = 2; // this T should be unused
    
    type U = T; // this U should be unused
    const U = 3;
    
    const _V = U;
    
    
    --- partially exported type/value shadowed variables ---
    --- NOTE - TS gets these cases wrong
    
    export interface Foo {}
    const Foo = 1; // this Foo should be unused
    
    interface Bar {} // this Bar should be unused
    export const Bar = 1;
    
    */
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-use-before-define.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const scope_manager_1 = require(861) /* @typescript-eslint/scope-manager */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const SENTINEL_TYPE = /^(?:(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression|CatchClause|ImportDeclaration|ExportNamedDeclaration)$/;
    /**
     * Parses a given value as options.
     */
    function parseOptions(options) {
        let functions = true;
        let classes = true;
        let enums = true;
        let variables = true;
        let typedefs = true;
        let ignoreTypeReferences = true;
        let allowNamedExports = false;
        if (typeof options === 'string') {
            functions = options !== 'nofunc';
        }
        else if (typeof options === 'object' && options != null) {
            functions = options.functions !== false;
            classes = options.classes !== false;
            enums = options.enums !== false;
            variables = options.variables !== false;
            typedefs = options.typedefs !== false;
            ignoreTypeReferences = options.ignoreTypeReferences !== false;
            allowNamedExports = options.allowNamedExports !== false;
        }
        return {
            functions,
            classes,
            enums,
            variables,
            typedefs,
            ignoreTypeReferences,
            allowNamedExports,
        };
    }
    /**
     * Checks whether or not a given variable is a function declaration.
     */
    function isFunction(variable) {
        return variable.defs[0].type === scope_manager_1.DefinitionType.FunctionName;
    }
    /**
     * Checks whether or not a given variable is a type declaration.
     */
    function isTypedef(variable) {
        return variable.defs[0].type === scope_manager_1.DefinitionType.Type;
    }
    /**
     * Checks whether or not a given variable is a enum declaration.
     */
    function isOuterEnum(variable, reference) {
        return (variable.defs[0].type === scope_manager_1.DefinitionType.TSEnumName &&
            variable.scope.variableScope !== reference.from.variableScope);
    }
    /**
     * Checks whether or not a given variable is a class declaration in an upper function scope.
     */
    function isOuterClass(variable, reference) {
        return (variable.defs[0].type === scope_manager_1.DefinitionType.ClassName &&
            variable.scope.variableScope !== reference.from.variableScope);
    }
    /**
     * Checks whether or not a given variable is a variable declaration in an upper function scope.
     */
    function isOuterVariable(variable, reference) {
        return (variable.defs[0].type === scope_manager_1.DefinitionType.Variable &&
            variable.scope.variableScope !== reference.from.variableScope);
    }
    /**
     * Checks whether or not a given reference is a export reference.
     */
    function isNamedExports(reference) {
        var _a;
        const { identifier } = reference;
        return (((_a = identifier.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ExportSpecifier &&
            identifier.parent.local === identifier);
    }
    /**
     * Recursively checks whether or not a given reference has a type query declaration among it's parents
     */
    function referenceContainsTypeQuery(node) {
        switch (node.type) {
            case utils_1.AST_NODE_TYPES.TSTypeQuery:
                return true;
            case utils_1.AST_NODE_TYPES.TSQualifiedName:
            case utils_1.AST_NODE_TYPES.Identifier:
                if (!node.parent) {
                    return false;
                }
                return referenceContainsTypeQuery(node.parent);
            default:
                // if we find a different node, there's no chance that we're in a TSTypeQuery
                return false;
        }
    }
    /**
     * Checks whether or not a given reference is a type reference.
     */
    function isTypeReference(reference) {
        return (reference.isTypeReference ||
            referenceContainsTypeQuery(reference.identifier));
    }
    /**
     * Checks whether or not a given location is inside of the range of a given node.
     */
    function isInRange(node, location) {
        return !!node && node.range[0] <= location && location <= node.range[1];
    }
    /**
     * Decorators are transpiled such that the decorator is placed after the class declaration
     * So it is considered safe
     */
    function isClassRefInClassDecorator(variable, reference) {
        if (variable.defs[0].type !== scope_manager_1.DefinitionType.ClassName) {
            return false;
        }
        if (!variable.defs[0].node.decorators ||
            variable.defs[0].node.decorators.length === 0) {
            return false;
        }
        for (const deco of variable.defs[0].node.decorators) {
            if (reference.identifier.range[0] >= deco.range[0] &&
                reference.identifier.range[1] <= deco.range[1]) {
                return true;
            }
        }
        return false;
    }
    /**
     * Checks whether or not a given reference is inside of the initializers of a given variable.
     *
     * @returns `true` in the following cases:
     * - var a = a
     * - var [a = a] = list
     * - var {a = a} = obj
     * - for (var a in a) {}
     * - for (var a of a) {}
     */
    function isInInitializer(variable, reference) {
        var _a;
        if (variable.scope !== reference.from) {
            return false;
        }
        let node = variable.identifiers[0].parent;
        const location = reference.identifier.range[1];
        while (node) {
            if (node.type === utils_1.AST_NODE_TYPES.VariableDeclarator) {
                if (isInRange(node.init, location)) {
                    return true;
                }
                if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.parent) &&
                    (node.parent.parent.type === utils_1.AST_NODE_TYPES.ForInStatement ||
                        node.parent.parent.type === utils_1.AST_NODE_TYPES.ForOfStatement) &&
                    isInRange(node.parent.parent.right, location)) {
                    return true;
                }
                break;
            }
            else if (node.type === utils_1.AST_NODE_TYPES.AssignmentPattern) {
                if (isInRange(node.right, location)) {
                    return true;
                }
            }
            else if (SENTINEL_TYPE.test(node.type)) {
                break;
            }
            node = node.parent;
        }
        return false;
    }
    exports.default = util.createRule({
        name: 'no-use-before-define',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow the use of variables before they are defined',
                recommended: false,
                extendsBaseRule: true,
            },
            messages: {
                noUseBeforeDefine: "'{{name}}' was used before it was defined.",
            },
            schema: [
                {
                    oneOf: [
                        {
                            enum: ['nofunc'],
                        },
                        {
                            type: 'object',
                            properties: {
                                functions: { type: 'boolean' },
                                classes: { type: 'boolean' },
                                enums: { type: 'boolean' },
                                variables: { type: 'boolean' },
                                typedefs: { type: 'boolean' },
                                ignoreTypeReferences: { type: 'boolean' },
                                allowNamedExports: { type: 'boolean' },
                            },
                            additionalProperties: false,
                        },
                    ],
                },
            ],
        },
        defaultOptions: [
            {
                functions: true,
                classes: true,
                enums: true,
                variables: true,
                typedefs: true,
                ignoreTypeReferences: true,
                allowNamedExports: false,
            },
        ],
        create(context, optionsWithDefault) {
            const options = parseOptions(optionsWithDefault[0]);
            /**
             * Determines whether a given use-before-define case should be reported according to the options.
             * @param variable The variable that gets used before being defined
             * @param reference The reference to the variable
             */
            function isForbidden(variable, reference) {
                if (options.ignoreTypeReferences && isTypeReference(reference)) {
                    return false;
                }
                if (isFunction(variable)) {
                    return options.functions;
                }
                if (isOuterClass(variable, reference)) {
                    return options.classes;
                }
                if (isOuterVariable(variable, reference)) {
                    return options.variables;
                }
                if (isOuterEnum(variable, reference)) {
                    return options.enums;
                }
                if (isTypedef(variable)) {
                    return options.typedefs;
                }
                return true;
            }
            function isDefinedBeforeUse(variable, reference) {
                return (variable.identifiers[0].range[1] <= reference.identifier.range[1] &&
                    !isInInitializer(variable, reference));
            }
            /**
             * Finds and validates all variables in a given scope.
             */
            function findVariablesInScope(scope) {
                scope.references.forEach(reference => {
                    const variable = reference.resolved;
                    function report() {
                        context.report({
                            node: reference.identifier,
                            messageId: 'noUseBeforeDefine',
                            data: {
                                name: reference.identifier.name,
                            },
                        });
                    }
                    // Skips when the reference is:
                    // - initializations.
                    // - referring to an undefined variable.
                    // - referring to a global environment variable (there're no identifiers).
                    // - located preceded by the variable (except in initializers).
                    // - allowed by options.
                    if (reference.init) {
                        return;
                    }
                    if (!options.allowNamedExports && isNamedExports(reference)) {
                        if (!variable || !isDefinedBeforeUse(variable, reference)) {
                            report();
                        }
                        return;
                    }
                    if (!variable) {
                        return;
                    }
                    if (variable.identifiers.length === 0 ||
                        isDefinedBeforeUse(variable, reference) ||
                        !isForbidden(variable, reference) ||
                        isClassRefInClassDecorator(variable, reference) ||
                        reference.from.type === utils_1.TSESLint.Scope.ScopeType.functionType) {
                        return;
                    }
                    // Reports.
                    report();
                });
                scope.childScopes.forEach(findVariablesInScope);
            }
            return {
                Program() {
                    findVariablesInScope(context.getScope());
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-useless-constructor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var _a;
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('no-useless-constructor');
    /**
     * Check if method with accessibility is not useless
     */
    function checkAccessibility(node) {
        switch (node.accessibility) {
            case 'protected':
            case 'private':
                return false;
            case 'public':
                if (node.parent &&
                    node.parent.type === utils_1.AST_NODE_TYPES.ClassBody &&
                    node.parent.parent &&
                    'superClass' in node.parent.parent &&
                    node.parent.parent.superClass) {
                    return false;
                }
                break;
        }
        return true;
    }
    /**
     * Check if method is not useless due to typescript parameter properties and decorators
     */
    function checkParams(node) {
        return !node.value.params.some(param => {
            var _a;
            return param.type === utils_1.AST_NODE_TYPES.TSParameterProperty ||
                ((_a = param.decorators) === null || _a === void 0 ? void 0 : _a.length);
        });
    }
    exports.default = util.createRule({
        name: 'no-useless-constructor',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow unnecessary constructors',
                recommended: 'strict',
                extendsBaseRule: true,
            },
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            // TODO: this rule has only had messages since v7.0 - remove this when we remove support for v6
            messages: (_a = baseRule.meta.messages) !== null && _a !== void 0 ? _a : {
                noUselessConstructor: 'Useless constructor.',
            },
        },
        defaultOptions: [],
        create(context) {
            const rules = baseRule.create(context);
            return {
                MethodDefinition(node) {
                    if (node.value &&
                        node.value.type === utils_1.AST_NODE_TYPES.FunctionExpression &&
                        node.value.body &&
                        checkAccessibility(node) &&
                        checkParams(node)) {
                        rules.MethodDefinition(node);
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-useless-empty-export.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    function isEmptyExport(node) {
        return (node.type === utils_1.AST_NODE_TYPES.ExportNamedDeclaration &&
            node.specifiers.length === 0 &&
            !node.declaration);
    }
    const exportOrImportNodeTypes = new Set([
        utils_1.AST_NODE_TYPES.ExportAllDeclaration,
        utils_1.AST_NODE_TYPES.ExportDefaultDeclaration,
        utils_1.AST_NODE_TYPES.ExportNamedDeclaration,
        utils_1.AST_NODE_TYPES.ExportSpecifier,
        utils_1.AST_NODE_TYPES.ImportDeclaration,
        utils_1.AST_NODE_TYPES.TSExportAssignment,
        utils_1.AST_NODE_TYPES.TSImportEqualsDeclaration,
    ]);
    exports.default = util.createRule({
        name: 'no-useless-empty-export',
        meta: {
            docs: {
                description: "Disallow empty exports that don't change anything in a module file",
                recommended: false,
            },
            fixable: 'code',
            hasSuggestions: false,
            messages: {
                uselessExport: 'Empty export does nothing and can be removed.',
            },
            schema: [],
            type: 'suggestion',
        },
        defaultOptions: [],
        create(context) {
            function checkNode(node) {
                if (!Array.isArray(node.body)) {
                    return;
                }
                let emptyExport;
                let foundOtherExport = false;
                for (const statement of node.body) {
                    if (isEmptyExport(statement)) {
                        emptyExport = statement;
                        if (foundOtherExport) {
                            break;
                        }
                    }
                    else if (exportOrImportNodeTypes.has(statement.type)) {
                        foundOtherExport = true;
                    }
                }
                if (emptyExport && foundOtherExport) {
                    context.report({
                        fix: fixer => fixer.remove(emptyExport),
                        messageId: 'uselessExport',
                        node: emptyExport,
                    });
                }
            }
            return {
                Program: checkNode,
                TSModuleDeclaration: checkNode,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/no-var-requires.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'no-var-requires',
        meta: {
            type: 'problem',
            docs: {
                description: 'Disallow `require` statements except in import statements',
                recommended: 'error',
            },
            messages: {
                noVarReqs: 'Require statement not part of import statement.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            return {
                'CallExpression[callee.name="require"]'(node) {
                    var _a;
                    const parent = ((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ChainExpression
                        ? node.parent.parent
                        : node.parent;
                    if (parent &&
                        [
                            utils_1.AST_NODE_TYPES.CallExpression,
                            utils_1.AST_NODE_TYPES.MemberExpression,
                            utils_1.AST_NODE_TYPES.NewExpression,
                            utils_1.AST_NODE_TYPES.TSAsExpression,
                            utils_1.AST_NODE_TYPES.TSTypeAssertion,
                            utils_1.AST_NODE_TYPES.VariableDeclarator,
                        ].includes(parent.type)) {
                        const variable = utils_1.ASTUtils.findVariable(context.getScope(), 'require');
                        if (!(variable === null || variable === void 0 ? void 0 : variable.identifiers.length)) {
                            context.report({
                                node,
                                messageId: 'noVarReqs',
                            });
                        }
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/non-nullable-type-assertion-style.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'non-nullable-type-assertion-style',
        meta: {
            docs: {
                description: 'Enforce non-null assertions over explicit type casts',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            fixable: 'code',
            messages: {
                preferNonNullAssertion: 'Use a ! assertion to more succinctly remove null and undefined from the type.',
            },
            schema: [],
            type: 'suggestion',
        },
        defaultOptions: [],
        create(context) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const sourceCode = context.getSourceCode();
            const getTypesIfNotLoose = (node) => {
                const type = checker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(node));
                if (tsutils.isTypeFlagSet(type, ts.TypeFlags.Any | ts.TypeFlags.Unknown)) {
                    return undefined;
                }
                return tsutils.unionTypeParts(type);
            };
            const couldBeNullish = (type) => {
                if (type.flags & ts.TypeFlags.TypeParameter) {
                    const constraint = type.getConstraint();
                    return constraint == null || couldBeNullish(constraint);
                }
                else if (tsutils.isUnionType(type)) {
                    for (const part of type.types) {
                        if (couldBeNullish(part)) {
                            return true;
                        }
                    }
                    return false;
                }
                else {
                    return ((type.flags & (ts.TypeFlags.Null | ts.TypeFlags.Undefined)) !== 0);
                }
            };
            const sameTypeWithoutNullish = (assertedTypes, originalTypes) => {
                const nonNullishOriginalTypes = originalTypes.filter(type => (type.flags & (ts.TypeFlags.Null | ts.TypeFlags.Undefined)) === 0);
                if (nonNullishOriginalTypes.length === originalTypes.length) {
                    return false;
                }
                for (const assertedType of assertedTypes) {
                    if (couldBeNullish(assertedType) ||
                        !nonNullishOriginalTypes.includes(assertedType)) {
                        return false;
                    }
                }
                for (const originalType of nonNullishOriginalTypes) {
                    if (!assertedTypes.includes(originalType)) {
                        return false;
                    }
                }
                return true;
            };
            const isConstAssertion = (node) => {
                return (node.typeAnnotation.type === utils_1.AST_NODE_TYPES.TSTypeReference &&
                    node.typeAnnotation.typeName.type === utils_1.AST_NODE_TYPES.Identifier &&
                    node.typeAnnotation.typeName.name === 'const');
            };
            return {
                'TSAsExpression, TSTypeAssertion'(node) {
                    if (isConstAssertion(node)) {
                        return;
                    }
                    const originalTypes = getTypesIfNotLoose(node.expression);
                    if (!originalTypes) {
                        return;
                    }
                    const assertedTypes = getTypesIfNotLoose(node.typeAnnotation);
                    if (!assertedTypes) {
                        return;
                    }
                    if (sameTypeWithoutNullish(assertedTypes, originalTypes)) {
                        context.report({
                            fix(fixer) {
                                return fixer.replaceText(node, `${sourceCode.getText(node.expression)}!`);
                            },
                            messageId: 'preferNonNullAssertion',
                            node,
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/object-curly-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util_1 = require(1018) /* ../util */;
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('object-curly-spacing');
    exports.default = (0, util_1.createRule)({
        name: 'object-curly-spacing',
        // eslint-disable-next-line eslint-plugin/prefer-message-ids,eslint-plugin/require-meta-type,eslint-plugin/require-meta-schema,eslint-plugin/require-meta-fixable -- all in base rule - https://github.com/not-an-aardvark/eslint-plugin-eslint-plugin/issues/274
        meta: Object.assign(Object.assign({}, baseRule.meta), { docs: {
                description: 'Enforce consistent spacing inside braces',
                recommended: false,
                extendsBaseRule: true,
            } }),
        defaultOptions: ['never'],
        create(context) {
            // eslint-disable-next-line no-restricted-syntax -- Use raw options for extended rules.
            const [firstOption, secondOption] = context.options;
            const spaced = firstOption === 'always';
            const sourceCode = context.getSourceCode();
            /**
             * Determines whether an option is set, relative to the spacing option.
             * If spaced is "always", then check whether option is set to false.
             * If spaced is "never", then check whether option is set to true.
             * @param option The option to exclude.
             * @returns Whether or not the property is excluded.
             */
            function isOptionSet(option) {
                return secondOption ? secondOption[option] === !spaced : false;
            }
            const options = {
                spaced,
                arraysInObjectsException: isOptionSet('arraysInObjects'),
                objectsInObjectsException: isOptionSet('objectsInObjects'),
            };
            //--------------------------------------------------------------------------
            // Helpers
            //--------------------------------------------------------------------------
            /**
             * Reports that there shouldn't be a space after the first token
             * @param node The node to report in the event of an error.
             * @param token The token to use for the report.
             */
            function reportNoBeginningSpace(node, token) {
                const nextToken = context
                    .getSourceCode()
                    .getTokenAfter(token, { includeComments: true });
                context.report({
                    node,
                    loc: { start: token.loc.end, end: nextToken.loc.start },
                    messageId: 'unexpectedSpaceAfter',
                    data: {
                        token: token.value,
                    },
                    fix(fixer) {
                        return fixer.removeRange([token.range[1], nextToken.range[0]]);
                    },
                });
            }
            /**
             * Reports that there shouldn't be a space before the last token
             * @param node The node to report in the event of an error.
             * @param token The token to use for the report.
             */
            function reportNoEndingSpace(node, token) {
                const previousToken = context
                    .getSourceCode()
                    .getTokenBefore(token, { includeComments: true });
                context.report({
                    node,
                    loc: { start: previousToken.loc.end, end: token.loc.start },
                    messageId: 'unexpectedSpaceBefore',
                    data: {
                        token: token.value,
                    },
                    fix(fixer) {
                        return fixer.removeRange([previousToken.range[1], token.range[0]]);
                    },
                });
            }
            /**
             * Reports that there should be a space after the first token
             * @param node The node to report in the event of an error.
             * @param token The token to use for the report.
             */
            function reportRequiredBeginningSpace(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: 'requireSpaceAfter',
                    data: {
                        token: token.value,
                    },
                    fix(fixer) {
                        return fixer.insertTextAfter(token, ' ');
                    },
                });
            }
            /**
             * Reports that there should be a space before the last token
             * @param node The node to report in the event of an error.
             * @param token The token to use for the report.
             */
            function reportRequiredEndingSpace(node, token) {
                context.report({
                    node,
                    loc: token.loc,
                    messageId: 'requireSpaceBefore',
                    data: {
                        token: token.value,
                    },
                    fix(fixer) {
                        return fixer.insertTextBefore(token, ' ');
                    },
                });
            }
            /**
             * Determines if spacing in curly braces is valid.
             * @param node The AST node to check.
             * @param first The first token to check (should be the opening brace)
             * @param second The second token to check (should be first after the opening brace)
             * @param penultimate The penultimate token to check (should be last before closing brace)
             * @param last The last token to check (should be closing brace)
             */
            function validateBraceSpacing(node, first, second, penultimate, last) {
                if ((0, util_1.isTokenOnSameLine)(first, second)) {
                    const firstSpaced = sourceCode.isSpaceBetween(first, second);
                    const secondType = sourceCode.getNodeByRangeIndex(second.range[0]).type;
                    const openingCurlyBraceMustBeSpaced = options.arraysInObjectsException &&
                        [
                            utils_1.AST_NODE_TYPES.TSMappedType,
                            utils_1.AST_NODE_TYPES.TSIndexSignature,
                        ].includes(secondType)
                        ? !options.spaced
                        : options.spaced;
                    if (openingCurlyBraceMustBeSpaced && !firstSpaced) {
                        reportRequiredBeginningSpace(node, first);
                    }
                    if (!openingCurlyBraceMustBeSpaced &&
                        firstSpaced &&
                        second.type !== utils_1.AST_TOKEN_TYPES.Line) {
                        reportNoBeginningSpace(node, first);
                    }
                }
                if ((0, util_1.isTokenOnSameLine)(penultimate, last)) {
                    const shouldCheckPenultimate = (options.arraysInObjectsException &&
                        (0, util_1.isClosingBracketToken)(penultimate)) ||
                        (options.objectsInObjectsException &&
                            (0, util_1.isClosingBraceToken)(penultimate));
                    const penultimateType = shouldCheckPenultimate
                        ? sourceCode.getNodeByRangeIndex(penultimate.range[0]).type
                        : undefined;
                    const closingCurlyBraceMustBeSpaced = (options.arraysInObjectsException &&
                        penultimateType === utils_1.AST_NODE_TYPES.TSTupleType) ||
                        (options.objectsInObjectsException &&
                            penultimateType !== undefined &&
                            [
                                utils_1.AST_NODE_TYPES.TSMappedType,
                                utils_1.AST_NODE_TYPES.TSTypeLiteral,
                            ].includes(penultimateType))
                        ? !options.spaced
                        : options.spaced;
                    const lastSpaced = sourceCode.isSpaceBetween(penultimate, last);
                    if (closingCurlyBraceMustBeSpaced && !lastSpaced) {
                        reportRequiredEndingSpace(node, last);
                    }
                    if (!closingCurlyBraceMustBeSpaced && lastSpaced) {
                        reportNoEndingSpace(node, last);
                    }
                }
            }
            /**
             * Gets '}' token of an object node.
             *
             * Because the last token of object patterns might be a type annotation,
             * this traverses tokens preceded by the last property, then returns the
             * first '}' token.
             * @param node The node to get. This node is an
             *      ObjectExpression or an ObjectPattern. And this node has one or
             *      more properties.
             * @returns '}' token.
             */
            function getClosingBraceOfObject(node) {
                const lastProperty = node.members[node.members.length - 1];
                return sourceCode.getTokenAfter(lastProperty, util_1.isClosingBraceToken);
            }
            //--------------------------------------------------------------------------
            // Public
            //--------------------------------------------------------------------------
            const rules = baseRule.create(context);
            return Object.assign(Object.assign({}, rules), { TSMappedType(node) {
                    const first = sourceCode.getFirstToken(node);
                    const last = sourceCode.getLastToken(node);
                    const second = sourceCode.getTokenAfter(first, {
                        includeComments: true,
                    });
                    const penultimate = sourceCode.getTokenBefore(last, {
                        includeComments: true,
                    });
                    validateBraceSpacing(node, first, second, penultimate, last);
                },
                TSTypeLiteral(node) {
                    if (node.members.length === 0) {
                        return;
                    }
                    const first = sourceCode.getFirstToken(node);
                    const last = getClosingBraceOfObject(node);
                    const second = sourceCode.getTokenAfter(first, {
                        includeComments: true,
                    });
                    const penultimate = sourceCode.getTokenBefore(last, {
                        includeComments: true,
                    });
                    validateBraceSpacing(node, first, second, penultimate, last);
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/padding-line-between-statements.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const LT = `[${Array.from(new Set(['\r\n', '\r', '\n', '\u2028', '\u2029'])).join('')}]`;
    const PADDING_LINE_SEQUENCE = new RegExp(String.raw `^(\s*?${LT})\s*${LT}(\s*;?)$`, 'u');
    /**
     * Creates tester which check if a node starts with specific keyword with the
     * appropriate AST_NODE_TYPES.
     * @param keyword The keyword to test.
     * @returns the created tester.
     * @private
     */
    function newKeywordTester(type, keyword) {
        return {
            test(node, sourceCode) {
                var _a;
                const isSameKeyword = ((_a = sourceCode.getFirstToken(node)) === null || _a === void 0 ? void 0 : _a.value) === keyword;
                const isSameType = Array.isArray(type)
                    ? type.some(val => val === node.type)
                    : type === node.type;
                return isSameKeyword && isSameType;
            },
        };
    }
    /**
     * Creates tester which check if a node starts with specific keyword and spans a single line.
     * @param keyword The keyword to test.
     * @returns the created tester.
     * @private
     */
    function newSinglelineKeywordTester(keyword) {
        return {
            test(node, sourceCode) {
                return (node.loc.start.line === node.loc.end.line &&
                    sourceCode.getFirstToken(node).value === keyword);
            },
        };
    }
    /**
     * Creates tester which check if a node starts with specific keyword and spans multiple lines.
     * @param keyword The keyword to test.
     * @returns the created tester.
     * @private
     */
    function newMultilineKeywordTester(keyword) {
        return {
            test(node, sourceCode) {
                return (node.loc.start.line !== node.loc.end.line &&
                    sourceCode.getFirstToken(node).value === keyword);
            },
        };
    }
    /**
     * Creates tester which check if a node is specific type.
     * @param type The node type to test.
     * @returns the created tester.
     * @private
     */
    function newNodeTypeTester(type) {
        return {
            test: (node) => node.type === type,
        };
    }
    /**
     * Skips a chain expression node
     * @param node The node to test
     * @returnsA non-chain expression
     * @private
     */
    function skipChainExpression(node) {
        return node && node.type === utils_1.AST_NODE_TYPES.ChainExpression
            ? node.expression
            : node;
    }
    /**
     * Checks the given node is an expression statement of IIFE.
     * @param node The node to check.
     * @returns `true` if the node is an expression statement of IIFE.
     * @private
     */
    function isIIFEStatement(node) {
        if (node.type === utils_1.AST_NODE_TYPES.ExpressionStatement) {
            let expression = skipChainExpression(node.expression);
            if (expression.type === utils_1.AST_NODE_TYPES.UnaryExpression) {
                expression = skipChainExpression(expression.argument);
            }
            if (expression.type === utils_1.AST_NODE_TYPES.CallExpression) {
                let node = expression.callee;
                while (node.type === utils_1.AST_NODE_TYPES.SequenceExpression) {
                    node = node.expressions[node.expressions.length - 1];
                }
                return util.isFunction(node);
            }
        }
        return false;
    }
    /**
     * Checks the given node is a CommonJS require statement
     * @param node The node to check.
     * @returns `true` if the node is a CommonJS require statement.
     * @private
     */
    function isCJSRequire(node) {
        if (node.type === utils_1.AST_NODE_TYPES.VariableDeclaration) {
            const declaration = node.declarations[0];
            if (declaration === null || declaration === void 0 ? void 0 : declaration.init) {
                let call = declaration === null || declaration === void 0 ? void 0 : declaration.init;
                while (call.type === utils_1.AST_NODE_TYPES.MemberExpression) {
                    call = call.object;
                }
                if (call.type === utils_1.AST_NODE_TYPES.CallExpression &&
                    call.callee.type === utils_1.AST_NODE_TYPES.Identifier) {
                    return call.callee.name === 'require';
                }
            }
        }
        return false;
    }
    /**
     * Checks whether the given node is a block-like statement.
     * This checks the last token of the node is the closing brace of a block.
     * @param sourceCode The source code to get tokens.
     * @param node The node to check.
     * @returns `true` if the node is a block-like statement.
     * @private
     */
    function isBlockLikeStatement(node, sourceCode) {
        // do-while with a block is a block-like statement.
        if (node.type === utils_1.AST_NODE_TYPES.DoWhileStatement &&
            node.body.type === utils_1.AST_NODE_TYPES.BlockStatement) {
            return true;
        }
        /**
         * IIFE is a block-like statement specially from
         * JSCS#disallowPaddingNewLinesAfterBlocks.
         */
        if (isIIFEStatement(node)) {
            return true;
        }
        // Checks the last token is a closing brace of blocks.
        const lastToken = sourceCode.getLastToken(node, util.isNotSemicolonToken);
        const belongingNode = lastToken && util.isClosingBraceToken(lastToken)
            ? sourceCode.getNodeByRangeIndex(lastToken.range[0])
            : null;
        return (!!belongingNode &&
            (belongingNode.type === utils_1.AST_NODE_TYPES.BlockStatement ||
                belongingNode.type === utils_1.AST_NODE_TYPES.SwitchStatement));
    }
    /**
     * Check whether the given node is a directive or not.
     * @param node The node to check.
     * @param sourceCode The source code object to get tokens.
     * @returns `true` if the node is a directive.
     */
    function isDirective(node, sourceCode) {
        var _a, _b;
        return (node.type === utils_1.AST_NODE_TYPES.ExpressionStatement &&
            (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.Program ||
                (((_b = node.parent) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.BlockStatement &&
                    util.isFunction(node.parent.parent))) &&
            node.expression.type === utils_1.AST_NODE_TYPES.Literal &&
            typeof node.expression.value === 'string' &&
            !util.isParenthesized(node.expression, sourceCode));
    }
    /**
     * Check whether the given node is a part of directive prologue or not.
     * @param node The node to check.
     * @param sourceCode The source code object to get tokens.
     * @returns `true` if the node is a part of directive prologue.
     */
    function isDirectivePrologue(node, sourceCode) {
        if (isDirective(node, sourceCode) &&
            node.parent &&
            'body' in node.parent &&
            Array.isArray(node.parent.body)) {
            for (const sibling of node.parent.body) {
                if (sibling === node) {
                    break;
                }
                if (!isDirective(sibling, sourceCode)) {
                    return false;
                }
            }
            return true;
        }
        return false;
    }
    /**
     * Checks the given node is a CommonJS export statement
     * @param node The node to check.
     * @returns `true` if the node is a CommonJS export statement.
     * @private
     */
    function isCJSExport(node) {
        if (node.type === utils_1.AST_NODE_TYPES.ExpressionStatement) {
            const expression = node.expression;
            if (expression.type === utils_1.AST_NODE_TYPES.AssignmentExpression) {
                let left = expression.left;
                if (left.type === utils_1.AST_NODE_TYPES.MemberExpression) {
                    while (left.object.type === utils_1.AST_NODE_TYPES.MemberExpression) {
                        left = left.object;
                    }
                    return (left.object.type === utils_1.AST_NODE_TYPES.Identifier &&
                        (left.object.name === 'exports' ||
                            (left.object.name === 'module' &&
                                left.property.type === utils_1.AST_NODE_TYPES.Identifier &&
                                left.property.name === 'exports')));
                }
            }
        }
        return false;
    }
    /**
     * Check whether the given node is an expression
     * @param node The node to check.
     * @param sourceCode The source code object to get tokens.
     * @returns `true` if the node is an expression
     */
    function isExpression(node, sourceCode) {
        return (node.type === utils_1.AST_NODE_TYPES.ExpressionStatement &&
            !isDirectivePrologue(node, sourceCode));
    }
    /**
     * Gets the actual last token.
     *
     * If a semicolon is semicolon-less style's semicolon, this ignores it.
     * For example:
     *
     *     foo()
     *     ;[1, 2, 3].forEach(bar)
     * @param sourceCode The source code to get tokens.
     * @param node The node to get.
     * @returns The actual last token.
     * @private
     */
    function getActualLastToken(node, sourceCode) {
        const semiToken = sourceCode.getLastToken(node);
        const prevToken = sourceCode.getTokenBefore(semiToken);
        const nextToken = sourceCode.getTokenAfter(semiToken);
        const isSemicolonLessStyle = prevToken &&
            nextToken &&
            prevToken.range[0] >= node.range[0] &&
            util.isSemicolonToken(semiToken) &&
            semiToken.loc.start.line !== prevToken.loc.end.line &&
            semiToken.loc.end.line === nextToken.loc.start.line;
        return isSemicolonLessStyle ? prevToken : semiToken;
    }
    /**
     * This returns the concatenation of the first 2 captured strings.
     * @param _ Unused. Whole matched string.
     * @param trailingSpaces The trailing spaces of the first line.
     * @param indentSpaces The indentation spaces of the last line.
     * @returns The concatenation of trailingSpaces and indentSpaces.
     * @private
     */
    function replacerToRemovePaddingLines(_, trailingSpaces, indentSpaces) {
        return trailingSpaces + indentSpaces;
    }
    /**
     * Check and report statements for `any` configuration.
     * It does nothing.
     *
     * @private
     */
    function verifyForAny() {
        // Empty
    }
    /**
     * Check and report statements for `never` configuration.
     * This autofix removes blank lines between the given 2 statements.
     * However, if comments exist between 2 blank lines, it does not remove those
     * blank lines automatically.
     * @param context The rule context to report.
     * @param _ Unused. The previous node to check.
     * @param nextNode The next node to check.
     * @param paddingLines The array of token pairs that blank
     * lines exist between the pair.
     *
     * @private
     */
    function verifyForNever(context, _, nextNode, paddingLines) {
        if (paddingLines.length === 0) {
            return;
        }
        context.report({
            node: nextNode,
            messageId: 'unexpectedBlankLine',
            fix(fixer) {
                if (paddingLines.length >= 2) {
                    return null;
                }
                const prevToken = paddingLines[0][0];
                const nextToken = paddingLines[0][1];
                const start = prevToken.range[1];
                const end = nextToken.range[0];
                const text = context
                    .getSourceCode()
                    .text.slice(start, end)
                    .replace(PADDING_LINE_SEQUENCE, replacerToRemovePaddingLines);
                return fixer.replaceTextRange([start, end], text);
            },
        });
    }
    /**
     * Check and report statements for `always` configuration.
     * This autofix inserts a blank line between the given 2 statements.
     * If the `prevNode` has trailing comments, it inserts a blank line after the
     * trailing comments.
     * @param context The rule context to report.
     * @param prevNode The previous node to check.
     * @param nextNode The next node to check.
     * @param paddingLines The array of token pairs that blank
     * lines exist between the pair.
     *
     * @private
     */
    function verifyForAlways(context, prevNode, nextNode, paddingLines) {
        if (paddingLines.length > 0) {
            return;
        }
        context.report({
            node: nextNode,
            messageId: 'expectedBlankLine',
            fix(fixer) {
                const sourceCode = context.getSourceCode();
                let prevToken = getActualLastToken(prevNode, sourceCode);
                const nextToken = sourceCode.getFirstTokenBetween(prevToken, nextNode, {
                    includeComments: true,
                    /**
                     * Skip the trailing comments of the previous node.
                     * This inserts a blank line after the last trailing comment.
                     *
                     * For example:
                     *
                     *     foo(); // trailing comment.
                     *     // comment.
                     *     bar();
                     *
                     * Get fixed to:
                     *
                     *     foo(); // trailing comment.
                     *
                     *     // comment.
                     *     bar();
                     * @param token The token to check.
                     * @returns `true` if the token is not a trailing comment.
                     * @private
                     */
                    filter(token) {
                        if (util.isTokenOnSameLine(prevToken, token)) {
                            prevToken = token;
                            return false;
                        }
                        return true;
                    },
                }) || nextNode;
                const insertText = util.isTokenOnSameLine(prevToken, nextToken)
                    ? '\n\n'
                    : '\n';
                return fixer.insertTextAfter(prevToken, insertText);
            },
        });
    }
    /**
     * Types of blank lines.
     * `any`, `never`, and `always` are defined.
     * Those have `verify` method to check and report statements.
     * @private
     */
    const PaddingTypes = {
        any: { verify: verifyForAny },
        never: { verify: verifyForNever },
        always: { verify: verifyForAlways },
    };
    /**
     * Types of statements.
     * Those have `test` method to check it matches to the given statement.
     * @private
     */
    const StatementTypes = {
        '*': { test: () => true },
        'block-like': { test: isBlockLikeStatement },
        exports: { test: isCJSExport },
        require: { test: isCJSRequire },
        directive: { test: isDirectivePrologue },
        expression: { test: isExpression },
        iife: { test: isIIFEStatement },
        'multiline-block-like': {
            test: (node, sourceCode) => node.loc.start.line !== node.loc.end.line &&
                isBlockLikeStatement(node, sourceCode),
        },
        'multiline-expression': {
            test: (node, sourceCode) => node.loc.start.line !== node.loc.end.line &&
                node.type === utils_1.AST_NODE_TYPES.ExpressionStatement &&
                !isDirectivePrologue(node, sourceCode),
        },
        'multiline-const': newMultilineKeywordTester('const'),
        'multiline-let': newMultilineKeywordTester('let'),
        'multiline-var': newMultilineKeywordTester('var'),
        'singleline-const': newSinglelineKeywordTester('const'),
        'singleline-let': newSinglelineKeywordTester('let'),
        'singleline-var': newSinglelineKeywordTester('var'),
        block: newNodeTypeTester(utils_1.AST_NODE_TYPES.BlockStatement),
        empty: newNodeTypeTester(utils_1.AST_NODE_TYPES.EmptyStatement),
        function: newNodeTypeTester(utils_1.AST_NODE_TYPES.FunctionDeclaration),
        break: newKeywordTester(utils_1.AST_NODE_TYPES.BreakStatement, 'break'),
        case: newKeywordTester(utils_1.AST_NODE_TYPES.SwitchCase, 'case'),
        class: newKeywordTester(utils_1.AST_NODE_TYPES.ClassDeclaration, 'class'),
        const: newKeywordTester(utils_1.AST_NODE_TYPES.VariableDeclaration, 'const'),
        continue: newKeywordTester(utils_1.AST_NODE_TYPES.ContinueStatement, 'continue'),
        debugger: newKeywordTester(utils_1.AST_NODE_TYPES.DebuggerStatement, 'debugger'),
        default: newKeywordTester([utils_1.AST_NODE_TYPES.SwitchCase, utils_1.AST_NODE_TYPES.ExportDefaultDeclaration], 'default'),
        do: newKeywordTester(utils_1.AST_NODE_TYPES.DoWhileStatement, 'do'),
        export: newKeywordTester([
            utils_1.AST_NODE_TYPES.ExportDefaultDeclaration,
            utils_1.AST_NODE_TYPES.ExportNamedDeclaration,
        ], 'export'),
        for: newKeywordTester([
            utils_1.AST_NODE_TYPES.ForStatement,
            utils_1.AST_NODE_TYPES.ForInStatement,
            utils_1.AST_NODE_TYPES.ForOfStatement,
        ], 'for'),
        if: newKeywordTester(utils_1.AST_NODE_TYPES.IfStatement, 'if'),
        import: newKeywordTester(utils_1.AST_NODE_TYPES.ImportDeclaration, 'import'),
        let: newKeywordTester(utils_1.AST_NODE_TYPES.VariableDeclaration, 'let'),
        return: newKeywordTester(utils_1.AST_NODE_TYPES.ReturnStatement, 'return'),
        switch: newKeywordTester(utils_1.AST_NODE_TYPES.SwitchStatement, 'switch'),
        throw: newKeywordTester(utils_1.AST_NODE_TYPES.ThrowStatement, 'throw'),
        try: newKeywordTester(utils_1.AST_NODE_TYPES.TryStatement, 'try'),
        var: newKeywordTester(utils_1.AST_NODE_TYPES.VariableDeclaration, 'var'),
        while: newKeywordTester([utils_1.AST_NODE_TYPES.WhileStatement, utils_1.AST_NODE_TYPES.DoWhileStatement], 'while'),
        with: newKeywordTester(utils_1.AST_NODE_TYPES.WithStatement, 'with'),
        // Additional Typescript constructs
        interface: newKeywordTester(utils_1.AST_NODE_TYPES.TSInterfaceDeclaration, 'interface'),
        type: newKeywordTester(utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration, 'type'),
    };
    //------------------------------------------------------------------------------
    // Rule Definition
    //------------------------------------------------------------------------------
    exports.default = util.createRule({
        name: 'padding-line-between-statements',
        meta: {
            type: 'layout',
            docs: {
                description: 'Require or disallow padding lines between statements',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'whitespace',
            hasSuggestions: false,
            schema: {
                $defs: {
                    paddingType: {
                        enum: Object.keys(PaddingTypes),
                    },
                    statementType: {
                        anyOf: [
                            { enum: Object.keys(StatementTypes) },
                            {
                                type: 'array',
                                items: { enum: Object.keys(StatementTypes) },
                                minItems: 1,
                                uniqueItems: true,
                                additionalItems: false,
                            },
                        ],
                    },
                },
                type: 'array',
                items: {
                    type: 'object',
                    properties: {
                        blankLine: { $ref: '#/$defs/paddingType' },
                        prev: { $ref: '#/$defs/statementType' },
                        next: { $ref: '#/$defs/statementType' },
                    },
                    additionalProperties: false,
                    required: ['blankLine', 'prev', 'next'],
                },
                additionalItems: false,
            },
            messages: {
                unexpectedBlankLine: 'Unexpected blank line before this statement.',
                expectedBlankLine: 'Expected blank line before this statement.',
            },
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            // eslint-disable-next-line no-restricted-syntax -- We need all raw options.
            const configureList = context.options || [];
            let scopeInfo = null;
            /**
             * Processes to enter to new scope.
             * This manages the current previous statement.
             *
             * @private
             */
            function enterScope() {
                scopeInfo = {
                    upper: scopeInfo,
                    prevNode: null,
                };
            }
            /**
             * Processes to exit from the current scope.
             *
             * @private
             */
            function exitScope() {
                if (scopeInfo) {
                    scopeInfo = scopeInfo.upper;
                }
            }
            /**
             * Checks whether the given node matches the given type.
             * @param node The statement node to check.
             * @param type The statement type to check.
             * @returns `true` if the statement node matched the type.
             * @private
             */
            function match(node, type) {
                let innerStatementNode = node;
                while (innerStatementNode.type === utils_1.AST_NODE_TYPES.LabeledStatement) {
                    innerStatementNode = innerStatementNode.body;
                }
                if (Array.isArray(type)) {
                    return type.some(match.bind(null, innerStatementNode));
                }
                return StatementTypes[type].test(innerStatementNode, sourceCode);
            }
            /**
             * Finds the last matched configure from configureList.
             * @paramprevNode The previous statement to match.
             * @paramnextNode The current statement to match.
             * @returns The tester of the last matched configure.
             * @private
             */
            function getPaddingType(prevNode, nextNode) {
                for (let i = configureList.length - 1; i >= 0; --i) {
                    const configure = configureList[i];
                    if (match(prevNode, configure.prev) &&
                        match(nextNode, configure.next)) {
                        return PaddingTypes[configure.blankLine];
                    }
                }
                return PaddingTypes.any;
            }
            /**
             * Gets padding line sequences between the given 2 statements.
             * Comments are separators of the padding line sequences.
             * @paramprevNode The previous statement to count.
             * @paramnextNode The current statement to count.
             * @returns The array of token pairs.
             * @private
             */
            function getPaddingLineSequences(prevNode, nextNode) {
                const pairs = [];
                let prevToken = getActualLastToken(prevNode, sourceCode);
                if (nextNode.loc.start.line - prevToken.loc.end.line >= 2) {
                    do {
                        const token = sourceCode.getTokenAfter(prevToken, {
                            includeComments: true,
                        });
                        if (token.loc.start.line - prevToken.loc.end.line >= 2) {
                            pairs.push([prevToken, token]);
                        }
                        prevToken = token;
                    } while (prevToken.range[0] < nextNode.range[0]);
                }
                return pairs;
            }
            /**
             * Verify padding lines between the given node and the previous node.
             * @param node The node to verify.
             *
             * @private
             */
            function verify(node) {
                if (!node.parent ||
                    ![
                        utils_1.AST_NODE_TYPES.BlockStatement,
                        utils_1.AST_NODE_TYPES.Program,
                        utils_1.AST_NODE_TYPES.SwitchCase,
                        utils_1.AST_NODE_TYPES.SwitchStatement,
                        utils_1.AST_NODE_TYPES.TSModuleBlock,
                    ].includes(node.parent.type)) {
                    return;
                }
                // Save this node as the current previous statement.
                const prevNode = scopeInfo.prevNode;
                // Verify.
                if (prevNode) {
                    const type = getPaddingType(prevNode, node);
                    const paddingLines = getPaddingLineSequences(prevNode, node);
                    type.verify(context, prevNode, node, paddingLines);
                }
                scopeInfo.prevNode = node;
            }
            /**
             * Verify padding lines between the given node and the previous node.
             * Then process to enter to new scope.
             * @param node The node to verify.
             *
             * @private
             */
            function verifyThenEnterScope(node) {
                verify(node);
                enterScope();
            }
            return {
                Program: enterScope,
                BlockStatement: enterScope,
                SwitchStatement: enterScope,
                TSModuleBlock: enterScope,
                'Program:exit': exitScope,
                'BlockStatement:exit': exitScope,
                'SwitchStatement:exit': exitScope,
                'TSModuleBlock:exit': exitScope,
                ':statement': verify,
                SwitchCase: verifyThenEnterScope,
                TSDeclareFunction: verifyThenEnterScope,
                'SwitchCase:exit': exitScope,
                'TSDeclareFunction:exit': exitScope,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/parameter-properties.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'parameter-properties',
        meta: {
            type: 'problem',
            docs: {
                description: 'Require or disallow parameter properties in class constructors',
                recommended: false,
            },
            messages: {
                preferClassProperty: 'Property {{parameter}} should be declared as a class property.',
                preferParameterProperty: 'Property {{parameter}} should be declared as a parameter property.',
            },
            schema: {
                $defs: {
                    modifier: {
                        enum: [
                            'readonly',
                            'private',
                            'protected',
                            'public',
                            'private readonly',
                            'protected readonly',
                            'public readonly',
                        ],
                    },
                },
                prefixItems: [
                    {
                        type: 'object',
                        properties: {
                            allow: {
                                type: 'array',
                                items: {
                                    $ref: '#/$defs/modifier',
                                },
                                minItems: 1,
                            },
                            prefer: {
                                enum: ['class-property', 'parameter-property'],
                            },
                        },
                        additionalProperties: false,
                    },
                ],
                type: 'array',
            },
        },
        defaultOptions: [
            {
                allow: [],
                prefer: 'class-property',
            },
        ],
        create(context, [{ allow = [], prefer = 'class-property' }]) {
            /**
             * Gets the modifiers of `node`.
             * @param node the node to be inspected.
             */
            function getModifiers(node) {
                const modifiers = [];
                if (node.accessibility) {
                    modifiers.push(node.accessibility);
                }
                if (node.readonly) {
                    modifiers.push('readonly');
                }
                return modifiers.filter(Boolean).join(' ');
            }
            if (prefer === 'class-property') {
                return {
                    TSParameterProperty(node) {
                        const modifiers = getModifiers(node);
                        if (!allow.includes(modifiers)) {
                            // HAS to be an identifier or assignment or TSC will throw
                            if (node.parameter.type !== utils_1.AST_NODE_TYPES.Identifier &&
                                node.parameter.type !== utils_1.AST_NODE_TYPES.AssignmentPattern) {
                                return;
                            }
                            const name = node.parameter.type === utils_1.AST_NODE_TYPES.Identifier
                                ? node.parameter.name
                                : // has to be an Identifier or TSC will throw an error
                                    node.parameter.left.name;
                            context.report({
                                node,
                                messageId: 'preferClassProperty',
                                data: {
                                    parameter: name,
                                },
                            });
                        }
                    },
                };
            }
            const propertyNodesByNameStack = [];
            function getNodesByName(name) {
                const propertyNodesByName = propertyNodesByNameStack[propertyNodesByNameStack.length - 1];
                const existing = propertyNodesByName.get(name);
                if (existing) {
                    return existing;
                }
                const created = {};
                propertyNodesByName.set(name, created);
                return created;
            }
            const sourceCode = context.getSourceCode();
            function typeAnnotationsMatch(classProperty, constructorParameter) {
                if (!classProperty.typeAnnotation ||
                    !constructorParameter.typeAnnotation) {
                    return (classProperty.typeAnnotation === constructorParameter.typeAnnotation);
                }
                return (sourceCode.getText(classProperty.typeAnnotation) ===
                    sourceCode.getText(constructorParameter.typeAnnotation));
            }
            return {
                'ClassDeclaration, ClassExpression'() {
                    propertyNodesByNameStack.push(new Map());
                },
                ':matches(ClassDeclaration, ClassExpression):exit'() {
                    const propertyNodesByName = propertyNodesByNameStack.pop();
                    for (const [name, nodes] of propertyNodesByName) {
                        if (nodes.classProperty &&
                            nodes.constructorAssignment &&
                            nodes.constructorParameter &&
                            typeAnnotationsMatch(nodes.classProperty, nodes.constructorParameter)) {
                            context.report({
                                data: {
                                    parameter: name,
                                },
                                messageId: 'preferParameterProperty',
                                node: nodes.classProperty,
                            });
                        }
                    }
                },
                ClassBody(node) {
                    for (const element of node.body) {
                        if (element.type === utils_1.AST_NODE_TYPES.PropertyDefinition &&
                            element.key.type === utils_1.AST_NODE_TYPES.Identifier &&
                            !element.value &&
                            !allow.includes(getModifiers(element))) {
                            getNodesByName(element.key.name).classProperty = element;
                        }
                    }
                },
                'MethodDefinition[kind="constructor"]'(node) {
                    var _a, _b;
                    for (const parameter of node.value.params) {
                        if (parameter.type === utils_1.AST_NODE_TYPES.Identifier) {
                            getNodesByName(parameter.name).constructorParameter = parameter;
                        }
                    }
                    for (const statement of (_b = (_a = node.value.body) === null || _a === void 0 ? void 0 : _a.body) !== null && _b !== void 0 ? _b : []) {
                        if (statement.type !== utils_1.AST_NODE_TYPES.ExpressionStatement ||
                            statement.expression.type !== utils_1.AST_NODE_TYPES.AssignmentExpression ||
                            statement.expression.left.type !==
                                utils_1.AST_NODE_TYPES.MemberExpression ||
                            statement.expression.left.object.type !==
                                utils_1.AST_NODE_TYPES.ThisExpression ||
                            statement.expression.left.property.type !==
                                utils_1.AST_NODE_TYPES.Identifier ||
                            statement.expression.right.type !== utils_1.AST_NODE_TYPES.Identifier) {
                            break;
                        }
                        getNodesByName(statement.expression.right.name).constructorAssignment = statement.expression;
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-as-const.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'prefer-as-const',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce the use of `as const` over literal type',
                recommended: 'error',
            },
            fixable: 'code',
            hasSuggestions: true,
            messages: {
                preferConstAssertion: 'Expected a `const` instead of a literal type assertion.',
                variableConstAssertion: 'Expected a `const` assertion instead of a literal type annotation.',
                variableSuggest: 'You should use `as const` instead of type annotation.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            function compareTypes(valueNode, typeNode, canFix) {
                if (valueNode.type === utils_1.AST_NODE_TYPES.Literal &&
                    typeNode.type === utils_1.AST_NODE_TYPES.TSLiteralType &&
                    'raw' in typeNode.literal &&
                    valueNode.raw === typeNode.literal.raw) {
                    if (canFix) {
                        context.report({
                            node: typeNode,
                            messageId: 'preferConstAssertion',
                            fix: fixer => fixer.replaceText(typeNode, 'const'),
                        });
                    }
                    else {
                        context.report({
                            node: typeNode,
                            messageId: 'variableConstAssertion',
                            suggest: [
                                {
                                    messageId: 'variableSuggest',
                                    fix: (fixer) => [
                                        fixer.remove(typeNode.parent),
                                        fixer.insertTextAfter(valueNode, ' as const'),
                                    ],
                                },
                            ],
                        });
                    }
                }
            }
            return {
                TSAsExpression(node) {
                    compareTypes(node.expression, node.typeAnnotation, true);
                },
                TSTypeAssertion(node) {
                    compareTypes(node.expression, node.typeAnnotation, true);
                },
                PropertyDefinition(node) {
                    if (node.value && node.typeAnnotation) {
                        compareTypes(node.value, node.typeAnnotation.typeAnnotation, false);
                    }
                },
                VariableDeclarator(node) {
                    if (node.init && node.id.typeAnnotation) {
                        compareTypes(node.init, node.id.typeAnnotation.typeAnnotation, false);
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-enum-initializers.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'prefer-enum-initializers',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require each enum member value to be explicitly initialized',
                recommended: false,
            },
            hasSuggestions: true,
            messages: {
                defineInitializer: "The value of the member '{{ name }}' should be explicitly defined.",
                defineInitializerSuggestion: 'Can be fixed to {{ name }} = {{ suggested }}',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            function TSEnumDeclaration(node) {
                const { members } = node;
                members.forEach((member, index) => {
                    if (member.initializer == null) {
                        const name = sourceCode.getText(member);
                        context.report({
                            node: member,
                            messageId: 'defineInitializer',
                            data: {
                                name,
                            },
                            suggest: [
                                {
                                    messageId: 'defineInitializerSuggestion',
                                    data: { name, suggested: index },
                                    fix: (fixer) => {
                                        return fixer.replaceText(member, `${name} = ${index}`);
                                    },
                                },
                                {
                                    messageId: 'defineInitializerSuggestion',
                                    data: { name, suggested: index + 1 },
                                    fix: (fixer) => {
                                        return fixer.replaceText(member, `${name} = ${index + 1}`);
                                    },
                                },
                                {
                                    messageId: 'defineInitializerSuggestion',
                                    data: { name, suggested: `'${name}'` },
                                    fix: (fixer) => {
                                        return fixer.replaceText(member, `${name} = '${name}'`);
                                    },
                                },
                            ],
                        });
                    }
                });
            }
            return {
                TSEnumDeclaration,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-for-of.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'prefer-for-of',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce the use of `for-of` loop over the standard `for` loop where possible',
                recommended: 'strict',
            },
            messages: {
                preferForOf: 'Expected a `for-of` loop instead of a `for` loop with this simple iteration.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            function isSingleVariableDeclaration(node) {
                return ((node === null || node === void 0 ? void 0 : node.type) === utils_1.AST_NODE_TYPES.VariableDeclaration &&
                    node.kind !== 'const' &&
                    node.declarations.length === 1);
            }
            function isLiteral(node, value) {
                return node.type === utils_1.AST_NODE_TYPES.Literal && node.value === value;
            }
            function isZeroInitialized(node) {
                return node.init != null && isLiteral(node.init, 0);
            }
            function isMatchingIdentifier(node, name) {
                return node.type === utils_1.AST_NODE_TYPES.Identifier && node.name === name;
            }
            function isLessThanLengthExpression(node, name) {
                if ((node === null || node === void 0 ? void 0 : node.type) === utils_1.AST_NODE_TYPES.BinaryExpression &&
                    node.operator === '<' &&
                    isMatchingIdentifier(node.left, name) &&
                    node.right.type === utils_1.AST_NODE_TYPES.MemberExpression &&
                    isMatchingIdentifier(node.right.property, 'length')) {
                    return node.right.object;
                }
                return null;
            }
            function isIncrement(node, name) {
                if (!node) {
                    return false;
                }
                switch (node.type) {
                    case utils_1.AST_NODE_TYPES.UpdateExpression:
                        // x++ or ++x
                        return (node.operator === '++' && isMatchingIdentifier(node.argument, name));
                    case utils_1.AST_NODE_TYPES.AssignmentExpression:
                        if (isMatchingIdentifier(node.left, name)) {
                            if (node.operator === '+=') {
                                // x += 1
                                return isLiteral(node.right, 1);
                            }
                            else if (node.operator === '=') {
                                // x = x + 1 or x = 1 + x
                                const expr = node.right;
                                return (expr.type === utils_1.AST_NODE_TYPES.BinaryExpression &&
                                    expr.operator === '+' &&
                                    ((isMatchingIdentifier(expr.left, name) &&
                                        isLiteral(expr.right, 1)) ||
                                        (isLiteral(expr.left, 1) &&
                                            isMatchingIdentifier(expr.right, name))));
                            }
                        }
                }
                return false;
            }
            function contains(outer, inner) {
                return (outer.range[0] <= inner.range[0] && outer.range[1] >= inner.range[1]);
            }
            function isAssignee(node) {
                var _a;
                const parent = node.parent;
                if (!parent) {
                    return false;
                }
                // a[i] = 1, a[i] += 1, etc.
                if (parent.type === utils_1.AST_NODE_TYPES.AssignmentExpression &&
                    parent.left === node) {
                    return true;
                }
                // delete a[i]
                if (parent.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                    parent.operator === 'delete' &&
                    parent.argument === node) {
                    return true;
                }
                // a[i]++, --a[i], etc.
                if (parent.type === utils_1.AST_NODE_TYPES.UpdateExpression &&
                    parent.argument === node) {
                    return true;
                }
                // [a[i]] = [0]
                if (parent.type === utils_1.AST_NODE_TYPES.ArrayPattern) {
                    return true;
                }
                // [...a[i]] = [0]
                if (parent.type === utils_1.AST_NODE_TYPES.RestElement) {
                    return true;
                }
                // ({ foo: a[i] }) = { foo: 0 }
                if (parent.type === utils_1.AST_NODE_TYPES.Property &&
                    parent.value === node &&
                    ((_a = parent.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ObjectExpression &&
                    isAssignee(parent.parent)) {
                    return true;
                }
                return false;
            }
            function isIndexOnlyUsedWithArray(body, indexVar, arrayExpression) {
                const sourceCode = context.getSourceCode();
                const arrayText = sourceCode.getText(arrayExpression);
                return indexVar.references.every(reference => {
                    const id = reference.identifier;
                    const node = id.parent;
                    return (!contains(body, id) ||
                        (node !== undefined &&
                            node.type === utils_1.AST_NODE_TYPES.MemberExpression &&
                            node.object.type !== utils_1.AST_NODE_TYPES.ThisExpression &&
                            node.property === id &&
                            sourceCode.getText(node.object) === arrayText &&
                            !isAssignee(node)));
                });
            }
            return {
                'ForStatement:exit'(node) {
                    if (!isSingleVariableDeclaration(node.init)) {
                        return;
                    }
                    const declarator = node.init.declarations[0];
                    if (!declarator ||
                        !isZeroInitialized(declarator) ||
                        declarator.id.type !== utils_1.AST_NODE_TYPES.Identifier) {
                        return;
                    }
                    const indexName = declarator.id.name;
                    const arrayExpression = isLessThanLengthExpression(node.test, indexName);
                    if (!arrayExpression) {
                        return;
                    }
                    const [indexVar] = context.getDeclaredVariables(node.init);
                    if (isIncrement(node.update, indexName) &&
                        isIndexOnlyUsedWithArray(node.body, indexVar, arrayExpression)) {
                        context.report({
                            node,
                            messageId: 'preferForOf',
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-function-type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.phrases = void 0;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.phrases = {
        [utils_1.AST_NODE_TYPES.TSTypeLiteral]: 'Type literal',
        [utils_1.AST_NODE_TYPES.TSInterfaceDeclaration]: 'Interface',
    };
    exports.default = util.createRule({
        name: 'prefer-function-type',
        meta: {
            docs: {
                description: 'Enforce using function types instead of interfaces with call signatures',
                recommended: 'strict',
            },
            fixable: 'code',
            messages: {
                functionTypeOverCallableType: '{{ literalOrInterface }} only has a call signature, you should use a function type instead.',
                unexpectedThisOnFunctionOnlyInterface: "`this` refers to the function type '{{ interfaceName }}', did you intend to use a generic `this` parameter like `<Self>(this: Self, ...) => Self` instead?",
            },
            schema: [],
            type: 'suggestion',
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            /**
             * Checks if there the interface has exactly one supertype that isn't named 'Function'
             * @param node The node being checked
             */
            function hasOneSupertype(node) {
                if (!node.extends || node.extends.length === 0) {
                    return false;
                }
                if (node.extends.length !== 1) {
                    return true;
                }
                const expr = node.extends[0].expression;
                return (expr.type !== utils_1.AST_NODE_TYPES.Identifier || expr.name !== 'Function');
            }
            /**
             * @param parent The parent of the call signature causing the diagnostic
             */
            function shouldWrapSuggestion(parent) {
                if (!parent) {
                    return false;
                }
                switch (parent.type) {
                    case utils_1.AST_NODE_TYPES.TSUnionType:
                    case utils_1.AST_NODE_TYPES.TSIntersectionType:
                    case utils_1.AST_NODE_TYPES.TSArrayType:
                        return true;
                    default:
                        return false;
                }
            }
            /**
             * @param member The TypeElement being checked
             * @param node The parent of member being checked
             * @param tsThisTypes
             */
            function checkMember(member, node, tsThisTypes = null) {
                if ((member.type === utils_1.AST_NODE_TYPES.TSCallSignatureDeclaration ||
                    member.type === utils_1.AST_NODE_TYPES.TSConstructSignatureDeclaration) &&
                    member.returnType !== undefined) {
                    if ((tsThisTypes === null || tsThisTypes === void 0 ? void 0 : tsThisTypes.length) &&
                        node.type === utils_1.AST_NODE_TYPES.TSInterfaceDeclaration) {
                        // the message can be confusing if we don't point directly to the `this` node instead of the whole member
                        // and in favour of generating at most one error we'll only report the first occurrence of `this` if there are multiple
                        context.report({
                            node: tsThisTypes[0],
                            messageId: 'unexpectedThisOnFunctionOnlyInterface',
                            data: {
                                interfaceName: node.id.name,
                            },
                        });
                        return;
                    }
                    const fixable = node.parent &&
                        node.parent.type === utils_1.AST_NODE_TYPES.ExportDefaultDeclaration;
                    const fix = fixable
                        ? null
                        : (fixer) => {
                            const fixes = [];
                            const start = member.range[0];
                            const colonPos = member.returnType.range[0] - start;
                            const text = sourceCode.getText().slice(start, member.range[1]);
                            const comments = sourceCode
                                .getCommentsBefore(member)
                                .concat(sourceCode.getCommentsAfter(member));
                            let suggestion = `${text.slice(0, colonPos)} =>${text.slice(colonPos + 1)}`;
                            const lastChar = suggestion.endsWith(';') ? ';' : '';
                            if (lastChar) {
                                suggestion = suggestion.slice(0, -1);
                            }
                            if (shouldWrapSuggestion(node.parent)) {
                                suggestion = `(${suggestion})`;
                            }
                            if (node.type === utils_1.AST_NODE_TYPES.TSInterfaceDeclaration) {
                                if (node.typeParameters !== undefined) {
                                    suggestion = `type ${sourceCode
                                        .getText()
                                        .slice(node.id.range[0], node.typeParameters.range[1])} = ${suggestion}${lastChar}`;
                                }
                                else {
                                    suggestion = `type ${node.id.name} = ${suggestion}${lastChar}`;
                                }
                            }
                            const isParentExported = node.parent &&
                                node.parent.type === utils_1.AST_NODE_TYPES.ExportNamedDeclaration;
                            if (node.type === utils_1.AST_NODE_TYPES.TSInterfaceDeclaration &&
                                isParentExported) {
                                const commentsText = comments.reduce((text, comment) => {
                                    return (text +
                                        (comment.type === utils_1.AST_TOKEN_TYPES.Line
                                            ? `//${comment.value}`
                                            : `/*${comment.value}*/`) +
                                        '\n');
                                }, '');
                                // comments should move before export and not between export and interface declaration
                                fixes.push(fixer.insertTextBefore(node.parent, commentsText));
                            }
                            else {
                                comments.forEach(comment => {
                                    let commentText = comment.type === utils_1.AST_TOKEN_TYPES.Line
                                        ? `//${comment.value}`
                                        : `/*${comment.value}*/`;
                                    const isCommentOnTheSameLine = comment.loc.start.line === member.loc.start.line;
                                    if (!isCommentOnTheSameLine) {
                                        commentText += '\n';
                                    }
                                    else {
                                        commentText += ' ';
                                    }
                                    suggestion = commentText + suggestion;
                                });
                            }
                            const fixStart = node.range[0];
                            fixes.push(fixer.replaceTextRange([fixStart, node.range[1]], suggestion));
                            return fixes;
                        };
                    context.report({
                        node: member,
                        messageId: 'functionTypeOverCallableType',
                        data: {
                            literalOrInterface: exports.phrases[node.type],
                        },
                        fix,
                    });
                }
            }
            let tsThisTypes = null;
            let literalNesting = 0;
            return {
                TSInterfaceDeclaration() {
                    // when entering an interface reset the count of `this`s to empty.
                    tsThisTypes = [];
                },
                'TSInterfaceDeclaration TSThisType'(node) {
                    // inside an interface keep track of all ThisType references.
                    // unless it's inside a nested type literal in which case it's invalid code anyway
                    // we don't want to incorrectly say "it refers to name" while typescript says it's completely invalid.
                    if (literalNesting === 0 && tsThisTypes != null) {
                        tsThisTypes.push(node);
                    }
                },
                'TSInterfaceDeclaration:exit'(node) {
                    if (!hasOneSupertype(node) && node.body.body.length === 1) {
                        checkMember(node.body.body[0], node, tsThisTypes);
                    }
                    // on exit check member and reset the array to nothing.
                    tsThisTypes = null;
                },
                // keep track of nested literals to avoid complaining about invalid `this` uses
                'TSInterfaceDeclaration TSTypeLiteral'() {
                    literalNesting += 1;
                },
                'TSInterfaceDeclaration TSTypeLiteral:exit'() {
                    literalNesting -= 1;
                },
                'TSTypeLiteral[members.length = 1]'(node) {
                    checkMember(node.members[0], node);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-includes.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const regexpp_1 = require(485) /* @eslint-community/regexpp */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const ts = __importStar(require(21) /* typescript */);
    const util_1 = require(1018) /* ../util */;
    exports.default = (0, util_1.createRule)({
        name: 'prefer-includes',
        defaultOptions: [],
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce `includes` method over `indexOf` method',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            fixable: 'code',
            messages: {
                preferIncludes: "Use 'includes()' method instead.",
                preferStringIncludes: 'Use `String#includes()` method with a string instead.',
            },
            schema: [],
        },
        create(context) {
            const globalScope = context.getScope();
            const services = (0, util_1.getParserServices)(context);
            const types = services.program.getTypeChecker();
            function isNumber(node, value) {
                const evaluated = (0, util_1.getStaticValue)(node, globalScope);
                return evaluated != null && evaluated.value === value;
            }
            function isPositiveCheck(node) {
                switch (node.operator) {
                    case '!==':
                    case '!=':
                    case '>':
                        return isNumber(node.right, -1);
                    case '>=':
                        return isNumber(node.right, 0);
                    default:
                        return false;
                }
            }
            function isNegativeCheck(node) {
                switch (node.operator) {
                    case '===':
                    case '==':
                    case '<=':
                        return isNumber(node.right, -1);
                    case '<':
                        return isNumber(node.right, 0);
                    default:
                        return false;
                }
            }
            function hasSameParameters(nodeA, nodeB) {
                if (!ts.isFunctionLike(nodeA) || !ts.isFunctionLike(nodeB)) {
                    return false;
                }
                const paramsA = nodeA.parameters;
                const paramsB = nodeB.parameters;
                if (paramsA.length !== paramsB.length) {
                    return false;
                }
                for (let i = 0; i < paramsA.length; ++i) {
                    const paramA = paramsA[i];
                    const paramB = paramsB[i];
                    // Check name, type, and question token once.
                    if (paramA.getText() !== paramB.getText()) {
                        return false;
                    }
                }
                return true;
            }
            /**
             * Parse a given node if it's a `RegExp` instance.
             * @param node The node to parse.
             */
            function parseRegExp(node) {
                const evaluated = (0, util_1.getStaticValue)(node, globalScope);
                if (evaluated == null || !(evaluated.value instanceof RegExp)) {
                    return null;
                }
                const { pattern, flags } = (0, regexpp_1.parseRegExpLiteral)(evaluated.value);
                if (pattern.alternatives.length !== 1 ||
                    flags.ignoreCase ||
                    flags.global) {
                    return null;
                }
                // Check if it can determine a unique string.
                const chars = pattern.alternatives[0].elements;
                if (!chars.every(c => c.type === 'Character')) {
                    return null;
                }
                // To string.
                return String.fromCodePoint(...chars.map(c => c.value));
            }
            function checkArrayIndexOf(node, allowFixing) {
                var _a, _b, _c;
                // Check if the comparison is equivalent to `includes()`.
                const callNode = node.parent;
                const compareNode = (((_a = callNode.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ChainExpression
                    ? callNode.parent.parent
                    : callNode.parent);
                const negative = isNegativeCheck(compareNode);
                if (!negative && !isPositiveCheck(compareNode)) {
                    return;
                }
                // Get the symbol of `indexOf` method.
                const tsNode = services.esTreeNodeToTSNodeMap.get(node.property);
                const indexofMethodDeclarations = (_b = types
                    .getSymbolAtLocation(tsNode)) === null || _b === void 0 ? void 0 : _b.getDeclarations();
                if (indexofMethodDeclarations == null ||
                    indexofMethodDeclarations.length === 0) {
                    return;
                }
                // Check if every declaration of `indexOf` method has `includes` method
                // and the two methods have the same parameters.
                for (const instanceofMethodDecl of indexofMethodDeclarations) {
                    const typeDecl = instanceofMethodDecl.parent;
                    const type = types.getTypeAtLocation(typeDecl);
                    const includesMethodDecl = (_c = type
                        .getProperty('includes')) === null || _c === void 0 ? void 0 : _c.getDeclarations();
                    if (includesMethodDecl == null ||
                        !includesMethodDecl.some(includesMethodDecl => hasSameParameters(includesMethodDecl, instanceofMethodDecl))) {
                        return;
                    }
                }
                // Report it.
                context.report(Object.assign({ node: compareNode, messageId: 'preferIncludes' }, (allowFixing && {
                    *fix(fixer) {
                        if (negative) {
                            yield fixer.insertTextBefore(callNode, '!');
                        }
                        yield fixer.replaceText(node.property, 'includes');
                        yield fixer.removeRange([callNode.range[1], compareNode.range[1]]);
                    },
                })));
            }
            return {
                // a.indexOf(b) !== 1
                "BinaryExpression > CallExpression.left > MemberExpression.callee[property.name='indexOf'][computed=false]"(node) {
                    checkArrayIndexOf(node, /* allowFixing */ true);
                },
                // a?.indexOf(b) !== 1
                "BinaryExpression > ChainExpression.left > CallExpression > MemberExpression.callee[property.name='indexOf'][computed=false]"(node) {
                    checkArrayIndexOf(node, /* allowFixing */ false);
                },
                // /bar/.test(foo)
                'CallExpression > MemberExpression.callee[property.name="test"][computed=false]'(node) {
                    var _a;
                    const callNode = node.parent;
                    const text = callNode.arguments.length === 1 ? parseRegExp(node.object) : null;
                    if (text == null) {
                        return;
                    }
                    //check the argument type of test methods
                    const argument = callNode.arguments[0];
                    const tsNode = services.esTreeNodeToTSNodeMap.get(argument);
                    const type = (0, util_1.getConstrainedTypeAtLocation)(types, tsNode);
                    const includesMethodDecl = (_a = type
                        .getProperty('includes')) === null || _a === void 0 ? void 0 : _a.getDeclarations();
                    if (includesMethodDecl == null) {
                        return;
                    }
                    context.report({
                        node: callNode,
                        messageId: 'preferStringIncludes',
                        *fix(fixer) {
                            const argNode = callNode.arguments[0];
                            const needsParen = argNode.type !== utils_1.AST_NODE_TYPES.Literal &&
                                argNode.type !== utils_1.AST_NODE_TYPES.TemplateLiteral &&
                                argNode.type !== utils_1.AST_NODE_TYPES.Identifier &&
                                argNode.type !== utils_1.AST_NODE_TYPES.MemberExpression &&
                                argNode.type !== utils_1.AST_NODE_TYPES.CallExpression;
                            yield fixer.removeRange([callNode.range[0], argNode.range[0]]);
                            if (needsParen) {
                                yield fixer.insertTextBefore(argNode, '(');
                                yield fixer.insertTextAfter(argNode, ')');
                            }
                            yield fixer.insertTextAfter(argNode, `${node.optional ? '?.' : '.'}includes('${text}'`);
                        },
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-literal-enum-member.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util_1 = require(1018) /* ../util */;
    exports.default = (0, util_1.createRule)({
        name: 'prefer-literal-enum-member',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require all enum members to be literal values',
                recommended: 'strict',
                requiresTypeChecking: false,
            },
            messages: {
                notLiteral: `Explicit enum value must only be a literal value (string, number, boolean, etc).`,
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowBitwiseExpressions: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                allowBitwiseExpressions: false,
            },
        ],
        create(context, [{ allowBitwiseExpressions }]) {
            return {
                TSEnumMember(node) {
                    // If there is no initializer, then this node is just the name of the member, so ignore.
                    if (node.initializer == null) {
                        return;
                    }
                    // any old literal
                    if (node.initializer.type === utils_1.AST_NODE_TYPES.Literal) {
                        return;
                    }
                    // TemplateLiteral without expressions
                    if (node.initializer.type === utils_1.AST_NODE_TYPES.TemplateLiteral &&
                        node.initializer.expressions.length === 0) {
                        return;
                    }
                    // -1 and +1
                    if (node.initializer.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                        node.initializer.argument.type === utils_1.AST_NODE_TYPES.Literal &&
                        (['+', '-'].includes(node.initializer.operator) ||
                            (allowBitwiseExpressions && node.initializer.operator === '~'))) {
                        return;
                    }
                    if (allowBitwiseExpressions &&
                        node.initializer.type === utils_1.AST_NODE_TYPES.BinaryExpression &&
                        ['|', '&', '^', '<<', '>>', '>>>'].includes(node.initializer.operator) &&
                        node.initializer.left.type === utils_1.AST_NODE_TYPES.Literal &&
                        node.initializer.right.type === utils_1.AST_NODE_TYPES.Literal) {
                        return;
                    }
                    context.report({
                        node: node.id,
                        messageId: 'notLiteral',
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-namespace-keyword.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'prefer-namespace-keyword',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require using `namespace` keyword over `module` keyword to declare custom TypeScript modules',
                recommended: 'error',
            },
            fixable: 'code',
            messages: {
                useNamespace: "Use 'namespace' instead of 'module' to declare custom TypeScript modules.",
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            return {
                TSModuleDeclaration(node) {
                    // Do nothing if the name is a string.
                    if (!node.id || node.id.type === utils_1.AST_NODE_TYPES.Literal) {
                        return;
                    }
                    // Get tokens of the declaration header.
                    const moduleType = sourceCode.getTokenBefore(node.id);
                    if (moduleType &&
                        moduleType.type === utils_1.AST_TOKEN_TYPES.Identifier &&
                        moduleType.value === 'module') {
                        context.report({
                            node,
                            messageId: 'useNamespace',
                            fix(fixer) {
                                return fixer.replaceText(moduleType, 'namespace');
                            },
                        });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-nullish-coalescing.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'prefer-nullish-coalescing',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce using the nullish coalescing operator instead of logical chaining',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            hasSuggestions: true,
            messages: {
                preferNullishOverOr: 'Prefer using nullish coalescing operator (`??`) instead of a logical or (`||`), as it is a safer operator.',
                preferNullishOverTernary: 'Prefer using nullish coalescing operator (`??`) instead of a ternary expression, as it is simpler to read.',
                suggestNullish: 'Fix to nullish coalescing operator (`??`).',
                noStrictNullCheck: 'This rule requires the `strictNullChecks` compiler option to be turned on to function correctly.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        ignoreConditionalTests: {
                            type: 'boolean',
                        },
                        ignoreTernaryTests: {
                            type: 'boolean',
                        },
                        ignoreMixedLogicalExpressions: {
                            type: 'boolean',
                        },
                        allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                ignoreConditionalTests: true,
                ignoreTernaryTests: true,
                ignoreMixedLogicalExpressions: true,
                allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing: false,
            },
        ],
        create(context, [{ ignoreConditionalTests, ignoreTernaryTests, ignoreMixedLogicalExpressions, allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing, },]) {
            const parserServices = util.getParserServices(context);
            const compilerOptions = parserServices.program.getCompilerOptions();
            const sourceCode = context.getSourceCode();
            const checker = parserServices.program.getTypeChecker();
            const isStrictNullChecks = tsutils.isStrictCompilerOptionEnabled(compilerOptions, 'strictNullChecks');
            if (!isStrictNullChecks &&
                allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing !== true) {
                context.report({
                    loc: {
                        start: { line: 0, column: 0 },
                        end: { line: 0, column: 0 },
                    },
                    messageId: 'noStrictNullCheck',
                });
            }
            return {
                ConditionalExpression(node) {
                    if (ignoreTernaryTests) {
                        return;
                    }
                    let operator;
                    let nodesInsideTestExpression = [];
                    if (node.test.type === utils_1.AST_NODE_TYPES.BinaryExpression) {
                        nodesInsideTestExpression = [node.test.left, node.test.right];
                        if (node.test.operator === '==' ||
                            node.test.operator === '!=' ||
                            node.test.operator === '===' ||
                            node.test.operator === '!==') {
                            operator = node.test.operator;
                        }
                    }
                    else if (node.test.type === utils_1.AST_NODE_TYPES.LogicalExpression &&
                        node.test.left.type === utils_1.AST_NODE_TYPES.BinaryExpression &&
                        node.test.right.type === utils_1.AST_NODE_TYPES.BinaryExpression) {
                        nodesInsideTestExpression = [
                            node.test.left.left,
                            node.test.left.right,
                            node.test.right.left,
                            node.test.right.right,
                        ];
                        if (node.test.operator === '||') {
                            if (node.test.left.operator === '===' &&
                                node.test.right.operator === '===') {
                                operator = '===';
                            }
                            else if (((node.test.left.operator === '===' ||
                                node.test.right.operator === '===') &&
                                (node.test.left.operator === '==' ||
                                    node.test.right.operator === '==')) ||
                                (node.test.left.operator === '==' &&
                                    node.test.right.operator === '==')) {
                                operator = '==';
                            }
                        }
                        else if (node.test.operator === '&&') {
                            if (node.test.left.operator === '!==' &&
                                node.test.right.operator === '!==') {
                                operator = '!==';
                            }
                            else if (((node.test.left.operator === '!==' ||
                                node.test.right.operator === '!==') &&
                                (node.test.left.operator === '!=' ||
                                    node.test.right.operator === '!=')) ||
                                (node.test.left.operator === '!=' &&
                                    node.test.right.operator === '!=')) {
                                operator = '!=';
                            }
                        }
                    }
                    if (!operator) {
                        return;
                    }
                    let identifier;
                    let hasUndefinedCheck = false;
                    let hasNullCheck = false;
                    // we check that the test only contains null, undefined and the identifier
                    for (const testNode of nodesInsideTestExpression) {
                        if (util.isNullLiteral(testNode)) {
                            hasNullCheck = true;
                        }
                        else if (util.isUndefinedIdentifier(testNode)) {
                            hasUndefinedCheck = true;
                        }
                        else if ((operator === '!==' || operator === '!=') &&
                            util.isNodeEqual(testNode, node.consequent)) {
                            identifier = testNode;
                        }
                        else if ((operator === '===' || operator === '==') &&
                            util.isNodeEqual(testNode, node.alternate)) {
                            identifier = testNode;
                        }
                        else {
                            return;
                        }
                    }
                    if (!identifier) {
                        return;
                    }
                    const isFixable = (() => {
                        // it is fixable if we check for both null and undefined, or not if neither
                        if (hasUndefinedCheck === hasNullCheck) {
                            return hasUndefinedCheck;
                        }
                        // it is fixable if we loosely check for either null or undefined
                        if (operator === '==' || operator === '!=') {
                            return true;
                        }
                        const tsNode = parserServices.esTreeNodeToTSNodeMap.get(identifier);
                        const type = checker.getTypeAtLocation(tsNode);
                        const flags = util.getTypeFlags(type);
                        if (flags & (ts.TypeFlags.Any | ts.TypeFlags.Unknown)) {
                            return false;
                        }
                        const hasNullType = (flags & ts.TypeFlags.Null) !== 0;
                        // it is fixable if we check for undefined and the type is not nullable
                        if (hasUndefinedCheck && !hasNullType) {
                            return true;
                        }
                        const hasUndefinedType = (flags & ts.TypeFlags.Undefined) !== 0;
                        // it is fixable if we check for null and the type can't be undefined
                        return hasNullCheck && !hasUndefinedType;
                    })();
                    if (isFixable) {
                        context.report({
                            node,
                            messageId: 'preferNullishOverTernary',
                            suggest: [
                                {
                                    messageId: 'suggestNullish',
                                    fix(fixer) {
                                        const [left, right] = operator === '===' || operator === '=='
                                            ? [node.alternate, node.consequent]
                                            : [node.consequent, node.alternate];
                                        return fixer.replaceText(node, `${sourceCode.text.slice(left.range[0], left.range[1])} ?? ${sourceCode.text.slice(right.range[0], right.range[1])}`);
                                    },
                                },
                            ],
                        });
                    }
                },
                'LogicalExpression[operator = "||"]'(node) {
                    const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                    const type = checker.getTypeAtLocation(tsNode.left);
                    const isNullish = util.isNullableType(type, { allowUndefined: true });
                    if (!isNullish) {
                        return;
                    }
                    if (ignoreConditionalTests === true && isConditionalTest(node)) {
                        return;
                    }
                    const isMixedLogical = isMixedLogicalExpression(node);
                    if (ignoreMixedLogicalExpressions === true && isMixedLogical) {
                        return;
                    }
                    const barBarOperator = util.nullThrows(sourceCode.getTokenAfter(node.left, token => token.type === utils_1.AST_TOKEN_TYPES.Punctuator &&
                        token.value === node.operator), util.NullThrowsReasons.MissingToken('operator', node.type));
                    function* fix(fixer) {
                        if (node.parent && util.isLogicalOrOperator(node.parent)) {
                            // '&&' and '??' operations cannot be mixed without parentheses (e.g. a && b ?? c)
                            if (node.left.type === utils_1.AST_NODE_TYPES.LogicalExpression &&
                                !util.isLogicalOrOperator(node.left.left)) {
                                yield fixer.insertTextBefore(node.left.right, '(');
                            }
                            else {
                                yield fixer.insertTextBefore(node.left, '(');
                            }
                            yield fixer.insertTextAfter(node.right, ')');
                        }
                        yield fixer.replaceText(barBarOperator, '??');
                    }
                    context.report({
                        node: barBarOperator,
                        messageId: 'preferNullishOverOr',
                        suggest: [
                            {
                                messageId: 'suggestNullish',
                                fix,
                            },
                        ],
                    });
                },
            };
        },
    });
    function isConditionalTest(node) {
        const parents = new Set([node]);
        let current = node.parent;
        while (current) {
            parents.add(current);
            if ((current.type === utils_1.AST_NODE_TYPES.ConditionalExpression ||
                current.type === utils_1.AST_NODE_TYPES.DoWhileStatement ||
                current.type === utils_1.AST_NODE_TYPES.IfStatement ||
                current.type === utils_1.AST_NODE_TYPES.ForStatement ||
                current.type === utils_1.AST_NODE_TYPES.WhileStatement) &&
                parents.has(current.test)) {
                return true;
            }
            if ([
                utils_1.AST_NODE_TYPES.ArrowFunctionExpression,
                utils_1.AST_NODE_TYPES.FunctionExpression,
            ].includes(current.type)) {
                /**
                 * This is a weird situation like:
                 * `if (() => a || b) {}`
                 * `if (function () { return a || b }) {}`
                 */
                return false;
            }
            current = current.parent;
        }
        return false;
    }
    function isMixedLogicalExpression(node) {
        const seen = new Set();
        const queue = [node.parent, node.left, node.right];
        for (const current of queue) {
            if (seen.has(current)) {
                continue;
            }
            seen.add(current);
            if (current && current.type === utils_1.AST_NODE_TYPES.LogicalExpression) {
                if (current.operator === '&&') {
                    return true;
                }
                else if (current.operator === '||') {
                    // check the pieces of the node to catch cases like `a || b || c && d`
                    queue.push(current.parent, current.left, current.right);
                }
            }
        }
        return false;
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-optional-chain.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    /*
    The AST is always constructed such the first element is always the deepest element.
    I.e. for this code: `foo && foo.bar && foo.bar.baz && foo.bar.baz.buzz`
    The AST will look like this:
    {
      left: {
        left: {
          left: foo
          right: foo.bar
        }
        right: foo.bar.baz
      }
      right: foo.bar.baz.buzz
    }
    */
    exports.default = util.createRule({
        name: 'prefer-optional-chain',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce using concise optional chain expressions instead of chained logical ands, negated logical ors, or empty objects',
                recommended: 'strict',
            },
            hasSuggestions: true,
            messages: {
                preferOptionalChain: "Prefer using an optional chain expression instead, as it's more concise and easier to read.",
                optionalChainSuggest: 'Change to an optional chain.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            const parserServices = util.getParserServices(context, true);
            return {
                'LogicalExpression[operator="||"], LogicalExpression[operator="??"]'(node) {
                    const leftNode = node.left;
                    const rightNode = node.right;
                    const parentNode = node.parent;
                    const isRightNodeAnEmptyObjectLiteral = rightNode.type === utils_1.AST_NODE_TYPES.ObjectExpression &&
                        rightNode.properties.length === 0;
                    if (!isRightNodeAnEmptyObjectLiteral ||
                        !parentNode ||
                        parentNode.type !== utils_1.AST_NODE_TYPES.MemberExpression ||
                        parentNode.optional) {
                        return;
                    }
                    function isLeftSideLowerPrecedence() {
                        const logicalTsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                        const leftTsNode = parserServices.esTreeNodeToTSNodeMap.get(leftNode);
                        const operator = (0, tsutils_1.isBinaryExpression)(logicalTsNode)
                            ? logicalTsNode.operatorToken.kind
                            : ts.SyntaxKind.Unknown;
                        const leftPrecedence = util.getOperatorPrecedence(leftTsNode.kind, operator);
                        return leftPrecedence < util.OperatorPrecedence.LeftHandSide;
                    }
                    context.report({
                        node: parentNode,
                        messageId: 'optionalChainSuggest',
                        suggest: [
                            {
                                messageId: 'optionalChainSuggest',
                                fix: (fixer) => {
                                    const leftNodeText = sourceCode.getText(leftNode);
                                    // Any node that is made of an operator with higher or equal precedence,
                                    const maybeWrappedLeftNode = isLeftSideLowerPrecedence()
                                        ? `(${leftNodeText})`
                                        : leftNodeText;
                                    const propertyToBeOptionalText = sourceCode.getText(parentNode.property);
                                    const maybeWrappedProperty = parentNode.computed
                                        ? `[${propertyToBeOptionalText}]`
                                        : propertyToBeOptionalText;
                                    return fixer.replaceTextRange(parentNode.range, `${maybeWrappedLeftNode}?.${maybeWrappedProperty}`);
                                },
                            },
                        ],
                    });
                },
                [[
                    'LogicalExpression[operator="||"] > UnaryExpression[operator="!"] > Identifier',
                    'LogicalExpression[operator="||"] > UnaryExpression[operator="!"] > MemberExpression',
                    'LogicalExpression[operator="||"] > UnaryExpression[operator="!"] > ChainExpression > MemberExpression',
                    'LogicalExpression[operator="||"] > UnaryExpression[operator="!"] > MetaProperty',
                ].join(',')](initialIdentifierOrNotEqualsExpr) {
                    // selector guarantees this cast
                    const initialExpression = (initialIdentifierOrNotEqualsExpr.parent.type ===
                        utils_1.AST_NODE_TYPES.ChainExpression
                        ? initialIdentifierOrNotEqualsExpr.parent.parent
                        : initialIdentifierOrNotEqualsExpr.parent).parent;
                    if (initialExpression.left.type !== utils_1.AST_NODE_TYPES.UnaryExpression ||
                        initialExpression.left.argument !== initialIdentifierOrNotEqualsExpr) {
                        // the node(identifier or member expression) is not the deepest left node
                        return;
                    }
                    // walk up the tree to figure out how many logical expressions we can include
                    let previous = initialExpression;
                    let current = initialExpression;
                    let previousLeftText = getText(initialIdentifierOrNotEqualsExpr);
                    let optionallyChainedCode = previousLeftText;
                    let expressionCount = 1;
                    while (current.type === utils_1.AST_NODE_TYPES.LogicalExpression) {
                        if (current.right.type !== utils_1.AST_NODE_TYPES.UnaryExpression ||
                            !isValidChainTarget(current.right.argument, 
                            // only allow unary '!' with identifiers for the first chain - !foo || !foo()
                            expressionCount === 1)) {
                            break;
                        }
                        const { rightText, shouldBreak } = breakIfInvalid({
                            rightNode: current.right.argument,
                            previousLeftText,
                        });
                        if (shouldBreak) {
                            break;
                        }
                        let invalidOptionallyChainedPrivateProperty;
                        ({
                            invalidOptionallyChainedPrivateProperty,
                            expressionCount,
                            previousLeftText,
                            optionallyChainedCode,
                            previous,
                            current,
                        } = normalizeRepeatingPatterns(rightText, expressionCount, previousLeftText, optionallyChainedCode, previous, current));
                        if (invalidOptionallyChainedPrivateProperty) {
                            return;
                        }
                    }
                    reportIfMoreThanOne({
                        expressionCount,
                        previous,
                        optionallyChainedCode,
                        sourceCode,
                        context,
                        shouldHandleChainedAnds: false,
                    });
                },
                [[
                    'LogicalExpression[operator="&&"] > Identifier',
                    'LogicalExpression[operator="&&"] > MemberExpression',
                    'LogicalExpression[operator="&&"] > ChainExpression > MemberExpression',
                    'LogicalExpression[operator="&&"] > MetaProperty',
                    'LogicalExpression[operator="&&"] > BinaryExpression[operator="!=="]',
                    'LogicalExpression[operator="&&"] > BinaryExpression[operator="!="]',
                ].join(',')](initialIdentifierOrNotEqualsExpr) {
                    var _a;
                    // selector guarantees this cast
                    const initialExpression = (((_a = initialIdentifierOrNotEqualsExpr.parent) === null || _a === void 0 ? void 0 : _a.type) ===
                        utils_1.AST_NODE_TYPES.ChainExpression
                        ? initialIdentifierOrNotEqualsExpr.parent.parent
                        : initialIdentifierOrNotEqualsExpr.parent);
                    if (initialExpression.left !== initialIdentifierOrNotEqualsExpr) {
                        // the node(identifier or member expression) is not the deepest left node
                        return;
                    }
                    if (!isValidChainTarget(initialIdentifierOrNotEqualsExpr, true)) {
                        return;
                    }
                    // walk up the tree to figure out how many logical expressions we can include
                    let previous = initialExpression;
                    let current = initialExpression;
                    let previousLeftText = getText(initialIdentifierOrNotEqualsExpr);
                    let optionallyChainedCode = previousLeftText;
                    let expressionCount = 1;
                    while (current.type === utils_1.AST_NODE_TYPES.LogicalExpression) {
                        if (!isValidChainTarget(current.right, 
                        // only allow identifiers for the first chain - foo && foo()
                        expressionCount === 1)) {
                            break;
                        }
                        const { rightText, shouldBreak } = breakIfInvalid({
                            rightNode: current.right,
                            previousLeftText,
                        });
                        if (shouldBreak) {
                            break;
                        }
                        let invalidOptionallyChainedPrivateProperty;
                        ({
                            invalidOptionallyChainedPrivateProperty,
                            expressionCount,
                            previousLeftText,
                            optionallyChainedCode,
                            previous,
                            current,
                        } = normalizeRepeatingPatterns(rightText, expressionCount, previousLeftText, optionallyChainedCode, previous, current));
                        if (invalidOptionallyChainedPrivateProperty) {
                            return;
                        }
                    }
                    reportIfMoreThanOne({
                        expressionCount,
                        previous,
                        optionallyChainedCode,
                        sourceCode,
                        context,
                        shouldHandleChainedAnds: true,
                    });
                },
            };
            function breakIfInvalid({ previousLeftText, rightNode, }) {
                let shouldBreak = false;
                const rightText = getText(rightNode);
                // can't just use startsWith because of cases like foo && fooBar.baz;
                const matchRegex = new RegExp(`^${
                // escape regex characters
                previousLeftText.replace(/[.*+?^${}()|[\]\\]/g, '\\$&')}[^a-zA-Z0-9_$]`);
                if (!matchRegex.test(rightText) &&
                    // handle redundant cases like foo.bar && foo.bar
                    previousLeftText !== rightText) {
                    shouldBreak = true;
                }
                return { shouldBreak, leftText: previousLeftText, rightText };
            }
            function getText(node) {
                if (node.type === utils_1.AST_NODE_TYPES.BinaryExpression) {
                    return getText(
                    // isValidChainTarget ensures this is type safe
                    node.left);
                }
                if (node.type === utils_1.AST_NODE_TYPES.CallExpression) {
                    const calleeText = getText(
                    // isValidChainTarget ensures this is type safe
                    node.callee);
                    // ensure that the call arguments are left untouched, or else we can break cases that _need_ whitespace:
                    // - JSX: <Foo Needs Space Between Attrs />
                    // - Unary Operators: typeof foo, await bar, delete baz
                    const closingParenToken = util.nullThrows(sourceCode.getLastToken(node), util.NullThrowsReasons.MissingToken('closing parenthesis', node.type));
                    const openingParenToken = util.nullThrows(sourceCode.getFirstTokenBetween(node.callee, closingParenToken, util.isOpeningParenToken), util.NullThrowsReasons.MissingToken('opening parenthesis', node.type));
                    const argumentsText = sourceCode.text.substring(openingParenToken.range[0], closingParenToken.range[1]);
                    return `${calleeText}${argumentsText}`;
                }
                if (node.type === utils_1.AST_NODE_TYPES.Identifier ||
                    node.type === utils_1.AST_NODE_TYPES.PrivateIdentifier) {
                    return node.name;
                }
                if (node.type === utils_1.AST_NODE_TYPES.MetaProperty) {
                    return `${node.meta.name}.${node.property.name}`;
                }
                if (node.type === utils_1.AST_NODE_TYPES.ThisExpression) {
                    return 'this';
                }
                if (node.type === utils_1.AST_NODE_TYPES.ChainExpression) {
                    /* istanbul ignore if */ if (node.expression.type === utils_1.AST_NODE_TYPES.TSNonNullExpression) {
                        // this shouldn't happen
                        return '';
                    }
                    return getText(node.expression);
                }
                if (node.object.type === utils_1.AST_NODE_TYPES.TSNonNullExpression) {
                    // Not supported mixing with TSNonNullExpression
                    return '';
                }
                return getMemberExpressionText(node);
            }
            /**
             * Gets a normalized representation of the given MemberExpression
             */
            function getMemberExpressionText(node) {
                let objectText;
                // cases should match the list in ALLOWED_MEMBER_OBJECT_TYPES
                switch (node.object.type) {
                    case utils_1.AST_NODE_TYPES.MemberExpression:
                        objectText = getMemberExpressionText(node.object);
                        break;
                    case utils_1.AST_NODE_TYPES.CallExpression:
                    case utils_1.AST_NODE_TYPES.Identifier:
                    case utils_1.AST_NODE_TYPES.MetaProperty:
                    case utils_1.AST_NODE_TYPES.ThisExpression:
                        objectText = getText(node.object);
                        break;
                    /* istanbul ignore next */
                    default:
                        return '';
                }
                let propertyText;
                if (node.computed) {
                    // cases should match the list in ALLOWED_COMPUTED_PROP_TYPES
                    switch (node.property.type) {
                        case utils_1.AST_NODE_TYPES.Identifier:
                            propertyText = getText(node.property);
                            break;
                        case utils_1.AST_NODE_TYPES.Literal:
                        case utils_1.AST_NODE_TYPES.TemplateLiteral:
                        case utils_1.AST_NODE_TYPES.BinaryExpression:
                            propertyText = sourceCode.getText(node.property);
                            break;
                        case utils_1.AST_NODE_TYPES.MemberExpression:
                            propertyText = getMemberExpressionText(node.property);
                            break;
                        /* istanbul ignore next */
                        default:
                            return '';
                    }
                    return `${objectText}${node.optional ? '?.' : ''}[${propertyText}]`;
                }
                else {
                    // cases should match the list in ALLOWED_NON_COMPUTED_PROP_TYPES
                    switch (node.property.type) {
                        case utils_1.AST_NODE_TYPES.Identifier:
                            propertyText = getText(node.property);
                            break;
                        case utils_1.AST_NODE_TYPES.PrivateIdentifier:
                            propertyText = '#' + getText(node.property);
                            break;
                        default:
                            propertyText = sourceCode.getText(node.property);
                    }
                    return `${objectText}${node.optional ? '?.' : '.'}${propertyText}`;
                }
            }
        },
    });
    const ALLOWED_MEMBER_OBJECT_TYPES = new Set([
        utils_1.AST_NODE_TYPES.CallExpression,
        utils_1.AST_NODE_TYPES.Identifier,
        utils_1.AST_NODE_TYPES.MemberExpression,
        utils_1.AST_NODE_TYPES.ThisExpression,
        utils_1.AST_NODE_TYPES.MetaProperty,
    ]);
    const ALLOWED_COMPUTED_PROP_TYPES = new Set([
        utils_1.AST_NODE_TYPES.Identifier,
        utils_1.AST_NODE_TYPES.Literal,
        utils_1.AST_NODE_TYPES.MemberExpression,
        utils_1.AST_NODE_TYPES.TemplateLiteral,
    ]);
    const ALLOWED_NON_COMPUTED_PROP_TYPES = new Set([
        utils_1.AST_NODE_TYPES.Identifier,
        utils_1.AST_NODE_TYPES.PrivateIdentifier,
    ]);
    function reportIfMoreThanOne({ expressionCount, previous, optionallyChainedCode, sourceCode, context, shouldHandleChainedAnds, }) {
        if (expressionCount > 1) {
            if (shouldHandleChainedAnds &&
                previous.right.type === utils_1.AST_NODE_TYPES.BinaryExpression) {
                let operator = previous.right.operator;
                if (previous.right.operator === '!==' &&
                    // TODO(#4820): Use the type checker to know whether this is `null`
                    previous.right.right.type === utils_1.AST_NODE_TYPES.Literal &&
                    previous.right.right.raw === 'null') {
                    // case like foo !== null && foo.bar !== null
                    operator = '!=';
                }
                // case like foo && foo.bar !== someValue
                optionallyChainedCode += ` ${operator} ${sourceCode.getText(previous.right.right)}`;
            }
            context.report({
                node: previous,
                messageId: 'preferOptionalChain',
                suggest: [
                    {
                        messageId: 'optionalChainSuggest',
                        fix: (fixer) => [
                            fixer.replaceText(previous, `${shouldHandleChainedAnds ? '' : '!'}${optionallyChainedCode}`),
                        ],
                    },
                ],
            });
        }
    }
    function normalizeRepeatingPatterns(rightText, expressionCount, previousLeftText, optionallyChainedCode, previous, current) {
        const leftText = previousLeftText;
        let invalidOptionallyChainedPrivateProperty = false;
        // omit weird doubled up expression that make no sense like foo.bar && foo.bar
        if (rightText !== previousLeftText) {
            expressionCount += 1;
            previousLeftText = rightText;
            /*
            Diff the left and right text to construct the fix string
            There are the following cases:
        
            1)
            rightText === 'foo.bar.baz.buzz'
            leftText === 'foo.bar.baz'
            diff === '.buzz'
        
            2)
            rightText === 'foo.bar.baz.buzz()'
            leftText === 'foo.bar.baz'
            diff === '.buzz()'
        
            3)
            rightText === 'foo.bar.baz.buzz()'
            leftText === 'foo.bar.baz.buzz'
            diff === '()'
        
            4)
            rightText === 'foo.bar.baz[buzz]'
            leftText === 'foo.bar.baz'
            diff === '[buzz]'
        
            5)
            rightText === 'foo.bar.baz?.buzz'
            leftText === 'foo.bar.baz'
            diff === '?.buzz'
            */
            const diff = rightText.replace(leftText, '');
            if (diff.startsWith('.#')) {
                // Do not handle direct optional chaining on private properties because of a typescript bug (https://github.com/microsoft/TypeScript/issues/42734)
                // We still allow in computed properties
                invalidOptionallyChainedPrivateProperty = true;
            }
            if (diff.startsWith('?')) {
                // item was "pre optional chained"
                optionallyChainedCode += diff;
            }
            else {
                const needsDot = diff.startsWith('(') || diff.startsWith('[');
                optionallyChainedCode += `?${needsDot ? '.' : ''}${diff}`;
            }
        }
        previous = current;
        current = util.nullThrows(current.parent, util.NullThrowsReasons.MissingParent);
        return {
            invalidOptionallyChainedPrivateProperty,
            expressionCount,
            previousLeftText,
            optionallyChainedCode,
            previous,
            current,
        };
    }
    function isValidChainTarget(node, allowIdentifier) {
        if (node.type === utils_1.AST_NODE_TYPES.ChainExpression) {
            return isValidChainTarget(node.expression, allowIdentifier);
        }
        if (node.type === utils_1.AST_NODE_TYPES.MemberExpression) {
            const isObjectValid = ALLOWED_MEMBER_OBJECT_TYPES.has(node.object.type) &&
                // make sure to validate the expression is of our expected structure
                isValidChainTarget(node.object, true);
            const isPropertyValid = node.computed
                ? ALLOWED_COMPUTED_PROP_TYPES.has(node.property.type) &&
                    // make sure to validate the member expression is of our expected structure
                    (node.property.type === utils_1.AST_NODE_TYPES.MemberExpression
                        ? isValidChainTarget(node.property, allowIdentifier)
                        : true)
                : ALLOWED_NON_COMPUTED_PROP_TYPES.has(node.property.type);
            return isObjectValid && isPropertyValid;
        }
        if (node.type === utils_1.AST_NODE_TYPES.CallExpression) {
            return isValidChainTarget(node.callee, allowIdentifier);
        }
        if (allowIdentifier &&
            (node.type === utils_1.AST_NODE_TYPES.Identifier ||
                node.type === utils_1.AST_NODE_TYPES.ThisExpression ||
                node.type === utils_1.AST_NODE_TYPES.MetaProperty)) {
            return true;
        }
        /*
        special case for the following, where we only want the left
        - foo !== null
        - foo != null
        - foo !== undefined
        - foo != undefined
        */
        return (node.type === utils_1.AST_NODE_TYPES.BinaryExpression &&
            ['!==', '!='].includes(node.operator) &&
            isValidChainTarget(node.left, allowIdentifier) &&
            (util.isUndefinedIdentifier(node.right) || util.isNullLiteral(node.right)));
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-readonly.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    const functionScopeBoundaries = [
        utils_1.AST_NODE_TYPES.ArrowFunctionExpression,
        utils_1.AST_NODE_TYPES.FunctionDeclaration,
        utils_1.AST_NODE_TYPES.FunctionExpression,
        utils_1.AST_NODE_TYPES.MethodDefinition,
    ].join(', ');
    exports.default = util.createRule({
        name: 'prefer-readonly',
        meta: {
            docs: {
                description: "Require private members to be marked as `readonly` if they're never modified outside of the constructor",
                recommended: false,
                requiresTypeChecking: true,
            },
            fixable: 'code',
            messages: {
                preferReadonly: "Member '{{name}}' is never reassigned; mark it as `readonly`.",
            },
            schema: [
                {
                    allowAdditionalProperties: false,
                    properties: {
                        onlyInlineLambdas: {
                            type: 'boolean',
                        },
                    },
                    type: 'object',
                },
            ],
            type: 'suggestion',
        },
        defaultOptions: [{ onlyInlineLambdas: false }],
        create(context, [{ onlyInlineLambdas }]) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const classScopeStack = [];
            function handlePropertyAccessExpression(node, parent, classScope) {
                if (ts.isBinaryExpression(parent)) {
                    handleParentBinaryExpression(node, parent, classScope);
                    return;
                }
                if (ts.isDeleteExpression(parent) || isDestructuringAssignment(node)) {
                    classScope.addVariableModification(node);
                    return;
                }
                if (ts.isPostfixUnaryExpression(parent) ||
                    ts.isPrefixUnaryExpression(parent)) {
                    handleParentPostfixOrPrefixUnaryExpression(parent, classScope);
                }
            }
            function handleParentBinaryExpression(node, parent, classScope) {
                if (parent.left === node &&
                    tsutils.isAssignmentKind(parent.operatorToken.kind)) {
                    classScope.addVariableModification(node);
                }
            }
            function handleParentPostfixOrPrefixUnaryExpression(node, classScope) {
                if (node.operator === ts.SyntaxKind.PlusPlusToken ||
                    node.operator === ts.SyntaxKind.MinusMinusToken) {
                    classScope.addVariableModification(node.operand);
                }
            }
            function isDestructuringAssignment(node) {
                let current = node.parent;
                while (current) {
                    const parent = current.parent;
                    if (ts.isObjectLiteralExpression(parent) ||
                        ts.isArrayLiteralExpression(parent) ||
                        ts.isSpreadAssignment(parent) ||
                        (ts.isSpreadElement(parent) &&
                            ts.isArrayLiteralExpression(parent.parent))) {
                        current = parent;
                    }
                    else if (ts.isBinaryExpression(parent) &&
                        !ts.isPropertyAccessExpression(current)) {
                        return (parent.left === current &&
                            parent.operatorToken.kind === ts.SyntaxKind.EqualsToken);
                    }
                    else {
                        break;
                    }
                }
                return false;
            }
            function isFunctionScopeBoundaryInStack(node) {
                if (classScopeStack.length === 0) {
                    return false;
                }
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                if (ts.isConstructorDeclaration(tsNode)) {
                    return false;
                }
                return tsutils.isFunctionScopeBoundary(tsNode);
            }
            function getEsNodesFromViolatingNode(violatingNode) {
                if (ts.isParameterPropertyDeclaration(violatingNode, violatingNode.parent)) {
                    return {
                        esNode: parserServices.tsNodeToESTreeNodeMap.get(violatingNode.name),
                        nameNode: parserServices.tsNodeToESTreeNodeMap.get(violatingNode.name),
                    };
                }
                return {
                    esNode: parserServices.tsNodeToESTreeNodeMap.get(violatingNode),
                    nameNode: parserServices.tsNodeToESTreeNodeMap.get(violatingNode.name),
                };
            }
            return {
                'ClassDeclaration, ClassExpression'(node) {
                    classScopeStack.push(new ClassScope(checker, parserServices.esTreeNodeToTSNodeMap.get(node), onlyInlineLambdas));
                },
                'ClassDeclaration, ClassExpression:exit'() {
                    const finalizedClassScope = classScopeStack.pop();
                    const sourceCode = context.getSourceCode();
                    for (const violatingNode of finalizedClassScope.finalizeUnmodifiedPrivateNonReadonlys()) {
                        const { esNode, nameNode } = getEsNodesFromViolatingNode(violatingNode);
                        context.report({
                            data: {
                                name: sourceCode.getText(nameNode),
                            },
                            fix: fixer => fixer.insertTextBefore(nameNode, 'readonly '),
                            messageId: 'preferReadonly',
                            node: esNode,
                        });
                    }
                },
                MemberExpression(node) {
                    if (classScopeStack.length !== 0 && !node.computed) {
                        const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                        handlePropertyAccessExpression(tsNode, tsNode.parent, classScopeStack[classScopeStack.length - 1]);
                    }
                },
                [functionScopeBoundaries](node) {
                    if (utils_1.ASTUtils.isConstructor(node)) {
                        classScopeStack[classScopeStack.length - 1].enterConstructor(parserServices.esTreeNodeToTSNodeMap.get(node));
                    }
                    else if (isFunctionScopeBoundaryInStack(node)) {
                        classScopeStack[classScopeStack.length - 1].enterNonConstructor();
                    }
                },
                [`${functionScopeBoundaries}:exit`](node) {
                    if (utils_1.ASTUtils.isConstructor(node)) {
                        classScopeStack[classScopeStack.length - 1].exitConstructor();
                    }
                    else if (isFunctionScopeBoundaryInStack(node)) {
                        classScopeStack[classScopeStack.length - 1].exitNonConstructor();
                    }
                },
            };
        },
    });
    const OUTSIDE_CONSTRUCTOR = -1;
    const DIRECTLY_INSIDE_CONSTRUCTOR = 0;
    class ClassScope {
        constructor(checker, classNode, onlyInlineLambdas) {
            this.checker = checker;
            this.onlyInlineLambdas = onlyInlineLambdas;
            this.privateModifiableMembers = new Map();
            this.privateModifiableStatics = new Map();
            this.memberVariableModifications = new Set();
            this.staticVariableModifications = new Set();
            this.constructorScopeDepth = OUTSIDE_CONSTRUCTOR;
            const classType = checker.getTypeAtLocation(classNode);
            if (tsutils.isIntersectionType(classType)) {
                this.classType = classType.types[0];
            }
            else {
                this.classType = classType;
            }
            for (const member of classNode.members) {
                if (ts.isPropertyDeclaration(member)) {
                    this.addDeclaredVariable(member);
                }
            }
        }
        addDeclaredVariable(node) {
            if (!tsutils.isModifierFlagSet(node, ts.ModifierFlags.Private) ||
                tsutils.isModifierFlagSet(node, ts.ModifierFlags.Readonly) ||
                ts.isComputedPropertyName(node.name)) {
                return;
            }
            if (this.onlyInlineLambdas &&
                node.initializer !== undefined &&
                !ts.isArrowFunction(node.initializer)) {
                return;
            }
            (tsutils.isModifierFlagSet(node, ts.ModifierFlags.Static)
                ? this.privateModifiableStatics
                : this.privateModifiableMembers).set(node.name.getText(), node);
        }
        addVariableModification(node) {
            const modifierType = this.checker.getTypeAtLocation(node.expression);
            if (!modifierType.getSymbol() ||
                !(0, util_1.typeIsOrHasBaseType)(modifierType, this.classType)) {
                return;
            }
            const modifyingStatic = tsutils.isObjectType(modifierType) &&
                tsutils.isObjectFlagSet(modifierType, ts.ObjectFlags.Anonymous);
            if (!modifyingStatic &&
                this.constructorScopeDepth === DIRECTLY_INSIDE_CONSTRUCTOR) {
                return;
            }
            (modifyingStatic
                ? this.staticVariableModifications
                : this.memberVariableModifications).add(node.name.text);
        }
        enterConstructor(node) {
            this.constructorScopeDepth = DIRECTLY_INSIDE_CONSTRUCTOR;
            for (const parameter of node.parameters) {
                if (tsutils.isModifierFlagSet(parameter, ts.ModifierFlags.Private)) {
                    this.addDeclaredVariable(parameter);
                }
            }
        }
        exitConstructor() {
            this.constructorScopeDepth = OUTSIDE_CONSTRUCTOR;
        }
        enterNonConstructor() {
            if (this.constructorScopeDepth !== OUTSIDE_CONSTRUCTOR) {
                this.constructorScopeDepth += 1;
            }
        }
        exitNonConstructor() {
            if (this.constructorScopeDepth !== OUTSIDE_CONSTRUCTOR) {
                this.constructorScopeDepth -= 1;
            }
        }
        finalizeUnmodifiedPrivateNonReadonlys() {
            this.memberVariableModifications.forEach(variableName => {
                this.privateModifiableMembers.delete(variableName);
            });
            this.staticVariableModifications.forEach(variableName => {
                this.privateModifiableStatics.delete(variableName);
            });
            return [
                ...Array.from(this.privateModifiableMembers.values()),
                ...Array.from(this.privateModifiableStatics.values()),
            ];
        }
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-readonly-parameter-types.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'prefer-readonly-parameter-types',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require function parameters to be typed as `readonly` to prevent accidental mutation of inputs',
                recommended: false,
                requiresTypeChecking: true,
            },
            schema: [
                {
                    type: 'object',
                    additionalProperties: false,
                    properties: Object.assign({ checkParameterProperties: {
                            type: 'boolean',
                        }, ignoreInferredTypes: {
                            type: 'boolean',
                        } }, util.readonlynessOptionsSchema.properties),
                },
            ],
            messages: {
                shouldBeReadonly: 'Parameter should be a read only type.',
            },
        },
        defaultOptions: [
            Object.assign({ checkParameterProperties: true, ignoreInferredTypes: false }, util.readonlynessOptionsDefaults),
        ],
        create(context, [{ checkParameterProperties, ignoreInferredTypes, treatMethodsAsReadonly }]) {
            const { esTreeNodeToTSNodeMap, program } = util.getParserServices(context);
            const checker = program.getTypeChecker();
            return {
                [[
                    utils_1.AST_NODE_TYPES.ArrowFunctionExpression,
                    utils_1.AST_NODE_TYPES.FunctionDeclaration,
                    utils_1.AST_NODE_TYPES.FunctionExpression,
                    utils_1.AST_NODE_TYPES.TSCallSignatureDeclaration,
                    utils_1.AST_NODE_TYPES.TSConstructSignatureDeclaration,
                    utils_1.AST_NODE_TYPES.TSDeclareFunction,
                    utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression,
                    utils_1.AST_NODE_TYPES.TSFunctionType,
                    utils_1.AST_NODE_TYPES.TSMethodSignature,
                ].join(', ')](node) {
                    for (const param of node.params) {
                        if (!checkParameterProperties &&
                            param.type === utils_1.AST_NODE_TYPES.TSParameterProperty) {
                            continue;
                        }
                        const actualParam = param.type === utils_1.AST_NODE_TYPES.TSParameterProperty
                            ? param.parameter
                            : param;
                        if (ignoreInferredTypes && actualParam.typeAnnotation == null) {
                            continue;
                        }
                        const tsNode = esTreeNodeToTSNodeMap.get(actualParam);
                        const type = checker.getTypeAtLocation(tsNode);
                        const isReadOnly = util.isTypeReadonly(checker, type, {
                            treatMethodsAsReadonly: treatMethodsAsReadonly,
                        });
                        if (!isReadOnly) {
                            context.report({
                                node: actualParam,
                                messageId: 'shouldBeReadonly',
                            });
                        }
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-reduce-type-parameter.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getMemberExpressionName = (member) => {
        if (!member.computed) {
            return member.property.name;
        }
        if (member.property.type === utils_1.AST_NODE_TYPES.Literal &&
            typeof member.property.value === 'string') {
            return member.property.value;
        }
        return null;
    };
    exports.default = util.createRule({
        name: 'prefer-reduce-type-parameter',
        meta: {
            type: 'problem',
            docs: {
                description: 'Enforce using type parameter when calling `Array#reduce` instead of casting',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            messages: {
                preferTypeParameter: 'Unnecessary cast: Array#reduce accepts a type parameter for the default value.',
            },
            fixable: 'code',
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const service = util.getParserServices(context);
            const checker = service.program.getTypeChecker();
            return {
                'CallExpression > MemberExpression.callee'(callee) {
                    if (getMemberExpressionName(callee) !== 'reduce') {
                        return;
                    }
                    const [, secondArg] = callee.parent.arguments;
                    if (callee.parent.arguments.length < 2 ||
                        !util.isTypeAssertion(secondArg)) {
                        return;
                    }
                    // Get the symbol of the `reduce` method.
                    const tsNode = service.esTreeNodeToTSNodeMap.get(callee.object);
                    const calleeObjType = util.getConstrainedTypeAtLocation(checker, tsNode);
                    // Check the owner type of the `reduce` method.
                    if (checker.isArrayType(calleeObjType)) {
                        context.report({
                            messageId: 'preferTypeParameter',
                            node: secondArg,
                            fix: fixer => {
                                const fixes = [
                                    fixer.removeRange([
                                        secondArg.range[0],
                                        secondArg.expression.range[0],
                                    ]),
                                    fixer.removeRange([
                                        secondArg.expression.range[1],
                                        secondArg.range[1],
                                    ]),
                                ];
                                if (!callee.parent.typeParameters) {
                                    fixes.push(fixer.insertTextAfter(callee, `<${context
                                        .getSourceCode()
                                        .getText(secondArg.typeAnnotation)}>`));
                                }
                                return fixes;
                            },
                        });
                        return;
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-regexp-exec.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const util_1 = require(1018) /* ../util */;
    var ArgumentType;
    (function (ArgumentType) {
        ArgumentType[ArgumentType["Other"] = 0] = "Other";
        ArgumentType[ArgumentType["String"] = 1] = "String";
        ArgumentType[ArgumentType["RegExp"] = 2] = "RegExp";
        ArgumentType[ArgumentType["Both"] = 3] = "Both";
    })(ArgumentType || (ArgumentType = {}));
    exports.default = (0, util_1.createRule)({
        name: 'prefer-regexp-exec',
        defaultOptions: [],
        meta: {
            type: 'suggestion',
            fixable: 'code',
            docs: {
                description: 'Enforce `RegExp#exec` over `String#match` if no global flag is provided',
                recommended: false,
                requiresTypeChecking: true,
            },
            messages: {
                regExpExecOverStringMatch: 'Use the `RegExp#exec()` method instead.',
            },
            schema: [],
        },
        create(context) {
            const globalScope = context.getScope();
            const parserServices = (0, util_1.getParserServices)(context);
            const typeChecker = parserServices.program.getTypeChecker();
            const sourceCode = context.getSourceCode();
            /**
             * Check if a given node type is a string.
             * @param node The node type to check.
             */
            function isStringType(type) {
                return (0, util_1.getTypeName)(typeChecker, type) === 'string';
            }
            /**
             * Check if a given node type is a RegExp.
             * @param node The node type to check.
             */
            function isRegExpType(type) {
                return (0, util_1.getTypeName)(typeChecker, type) === 'RegExp';
            }
            function collectArgumentTypes(types) {
                let result = ArgumentType.Other;
                for (const type of types) {
                    if (isRegExpType(type)) {
                        result |= ArgumentType.RegExp;
                    }
                    else if (isStringType(type)) {
                        result |= ArgumentType.String;
                    }
                }
                return result;
            }
            function isLikelyToContainGlobalFlag(node) {
                if (node.type === utils_1.AST_NODE_TYPES.CallExpression ||
                    node.type === utils_1.AST_NODE_TYPES.NewExpression) {
                    const [, flags] = node.arguments;
                    return (flags &&
                        flags.type === utils_1.AST_NODE_TYPES.Literal &&
                        typeof flags.value === 'string' &&
                        flags.value.includes('g'));
                }
                return node.type === utils_1.AST_NODE_TYPES.Identifier;
            }
            return {
                "CallExpression[arguments.length=1] > MemberExpression.callee[property.name='match'][computed=false]"(memberNode) {
                    const objectNode = memberNode.object;
                    const callNode = memberNode.parent;
                    const [argumentNode] = callNode.arguments;
                    const argumentValue = (0, util_1.getStaticValue)(argumentNode, globalScope);
                    if (!isStringType(typeChecker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(objectNode)))) {
                        return;
                    }
                    // Don't report regular expressions with global flag.
                    if ((!argumentValue && isLikelyToContainGlobalFlag(argumentNode)) ||
                        (argumentValue &&
                            argumentValue.value instanceof RegExp &&
                            argumentValue.value.flags.includes('g'))) {
                        return;
                    }
                    if (argumentNode.type === utils_1.AST_NODE_TYPES.Literal &&
                        typeof argumentNode.value === 'string') {
                        const regExp = RegExp(argumentNode.value);
                        return context.report({
                            node: memberNode.property,
                            messageId: 'regExpExecOverStringMatch',
                            fix: (0, util_1.getWrappingFixer)({
                                sourceCode,
                                node: callNode,
                                innerNode: [objectNode],
                                wrap: objectCode => `${regExp.toString()}.exec(${objectCode})`,
                            }),
                        });
                    }
                    const argumentType = typeChecker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(argumentNode));
                    const argumentTypes = collectArgumentTypes(tsutils.unionTypeParts(argumentType));
                    switch (argumentTypes) {
                        case ArgumentType.RegExp:
                            return context.report({
                                node: memberNode.property,
                                messageId: 'regExpExecOverStringMatch',
                                fix: (0, util_1.getWrappingFixer)({
                                    sourceCode,
                                    node: callNode,
                                    innerNode: [objectNode, argumentNode],
                                    wrap: (objectCode, argumentCode) => `${argumentCode}.exec(${objectCode})`,
                                }),
                            });
                        case ArgumentType.String:
                            return context.report({
                                node: memberNode.property,
                                messageId: 'regExpExecOverStringMatch',
                                fix: (0, util_1.getWrappingFixer)({
                                    sourceCode,
                                    node: callNode,
                                    innerNode: [objectNode, argumentNode],
                                    wrap: (objectCode, argumentCode) => `RegExp(${argumentCode}).exec(${objectCode})`,
                                }),
                            });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-return-this-type.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const ts = __importStar(require(21) /* typescript */);
    const util_1 = require(1018) /* ../util */;
    exports.default = (0, util_1.createRule)({
        name: 'prefer-return-this-type',
        defaultOptions: [],
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce that `this` is used when only `this` type is returned',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            messages: {
                useThisType: 'Use `this` type instead.',
            },
            schema: [],
            fixable: 'code',
        },
        create(context) {
            const parserServices = (0, util_1.getParserServices)(context);
            const checker = parserServices.program.getTypeChecker();
            function tryGetNameInType(name, typeNode) {
                if (typeNode.type === utils_1.AST_NODE_TYPES.TSTypeReference &&
                    typeNode.typeName.type === utils_1.AST_NODE_TYPES.Identifier &&
                    typeNode.typeName.name === name) {
                    return typeNode;
                }
                if (typeNode.type === utils_1.AST_NODE_TYPES.TSUnionType) {
                    for (const type of typeNode.types) {
                        const found = tryGetNameInType(name, type);
                        if (found) {
                            return found;
                        }
                    }
                }
                return undefined;
            }
            function isThisSpecifiedInParameters(originalFunc) {
                const firstArg = originalFunc.params[0];
                return (firstArg &&
                    firstArg.type === utils_1.AST_NODE_TYPES.Identifier &&
                    firstArg.name === 'this');
            }
            function isFunctionReturningThis(originalFunc, originalClass) {
                if (isThisSpecifiedInParameters(originalFunc)) {
                    return false;
                }
                const func = parserServices.esTreeNodeToTSNodeMap.get(originalFunc);
                if (!func.body) {
                    return false;
                }
                const classType = checker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(originalClass));
                if (func.body.kind !== ts.SyntaxKind.Block) {
                    const type = checker.getTypeAtLocation(func.body);
                    return classType.thisType === type;
                }
                let hasReturnThis = false;
                let hasReturnClassType = false;
                (0, util_1.forEachReturnStatement)(func.body, stmt => {
                    const expr = stmt.expression;
                    if (!expr) {
                        return;
                    }
                    // fast check
                    if (expr.kind === ts.SyntaxKind.ThisKeyword) {
                        hasReturnThis = true;
                        return;
                    }
                    const type = checker.getTypeAtLocation(expr);
                    if (classType === type) {
                        hasReturnClassType = true;
                        return true;
                    }
                    if (classType.thisType === type) {
                        hasReturnThis = true;
                        return;
                    }
                    return;
                });
                return !hasReturnClassType && hasReturnThis;
            }
            function checkFunction(originalFunc, originalClass) {
                var _a;
                const className = (_a = originalClass.id) === null || _a === void 0 ? void 0 : _a.name;
                if (!className || !originalFunc.returnType) {
                    return;
                }
                const node = tryGetNameInType(className, originalFunc.returnType.typeAnnotation);
                if (!node) {
                    return;
                }
                if (isFunctionReturningThis(originalFunc, originalClass)) {
                    context.report({
                        node,
                        messageId: 'useThisType',
                        fix: fixer => fixer.replaceText(node, 'this'),
                    });
                }
            }
            return {
                'ClassBody > MethodDefinition'(node) {
                    checkFunction(node.value, node.parent.parent);
                },
                'ClassBody > PropertyDefinition'(node) {
                    var _a, _b;
                    if (!(((_a = node.value) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.FunctionExpression ||
                        ((_b = node.value) === null || _b === void 0 ? void 0 : _b.type) === utils_1.AST_NODE_TYPES.ArrowFunctionExpression)) {
                        return;
                    }
                    checkFunction(node.value, node.parent.parent);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-string-starts-ends-with.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const regexpp_1 = require(485) /* @eslint-community/regexpp */;
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util_1 = require(1018) /* ../util */;
    const EQ_OPERATORS = /^[=!]=/;
    const regexpp = new regexpp_1.RegExpParser();
    exports.default = (0, util_1.createRule)({
        name: 'prefer-string-starts-ends-with',
        defaultOptions: [],
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce using `String#startsWith` and `String#endsWith` over other equivalent methods of checking substrings',
                recommended: 'strict',
                requiresTypeChecking: true,
            },
            messages: {
                preferStartsWith: "Use 'String#startsWith' method instead.",
                preferEndsWith: "Use the 'String#endsWith' method instead.",
            },
            schema: [],
            fixable: 'code',
        },
        create(context) {
            const globalScope = context.getScope();
            const sourceCode = context.getSourceCode();
            const service = (0, util_1.getParserServices)(context);
            const typeChecker = service.program.getTypeChecker();
            /**
             * Check if a given node is a string.
             * @param node The node to check.
             */
            function isStringType(node) {
                const objectType = typeChecker.getTypeAtLocation(service.esTreeNodeToTSNodeMap.get(node));
                return (0, util_1.getTypeName)(typeChecker, objectType) === 'string';
            }
            /**
             * Check if a given node is a `Literal` node that is null.
             * @param node The node to check.
             */
            function isNull(node) {
                const evaluated = (0, util_1.getStaticValue)(node, globalScope);
                return evaluated != null && evaluated.value == null;
            }
            /**
             * Check if a given node is a `Literal` node that is a given value.
             * @param node The node to check.
             * @param value The expected value of the `Literal` node.
             */
            function isNumber(node, value) {
                const evaluated = (0, util_1.getStaticValue)(node, globalScope);
                return evaluated != null && evaluated.value === value;
            }
            /**
             * Check if a given node is a `Literal` node that is a character.
             * @param node The node to check.
             * @param kind The method name to get a character.
             */
            function isCharacter(node) {
                const evaluated = (0, util_1.getStaticValue)(node, globalScope);
                return (evaluated != null &&
                    typeof evaluated.value === 'string' &&
                    // checks if the string is a character long
                    evaluated.value[0] === evaluated.value);
            }
            /**
             * Check if a given node is `==`, `===`, `!=`, or `!==`.
             * @param node The node to check.
             */
            function isEqualityComparison(node) {
                return (node.type === utils_1.AST_NODE_TYPES.BinaryExpression &&
                    EQ_OPERATORS.test(node.operator));
            }
            /**
             * Check if two given nodes are the same meaning.
             * @param node1 A node to compare.
             * @param node2 Another node to compare.
             */
            function isSameTokens(node1, node2) {
                const tokens1 = sourceCode.getTokens(node1);
                const tokens2 = sourceCode.getTokens(node2);
                if (tokens1.length !== tokens2.length) {
                    return false;
                }
                for (let i = 0; i < tokens1.length; ++i) {
                    const token1 = tokens1[i];
                    const token2 = tokens2[i];
                    if (token1.type !== token2.type || token1.value !== token2.value) {
                        return false;
                    }
                }
                return true;
            }
            /**
             * Check if a given node is the expression of the length of a string.
             *
             * - If `length` property access of `expectedObjectNode`, it's `true`.
             *   E.g., `foo` → `foo.length` / `"foo"` → `"foo".length`
             * - If `expectedObjectNode` is a string literal, `node` can be a number.
             *   E.g., `"foo"` → `3`
             *
             * @param node The node to check.
             * @param expectedObjectNode The node which is expected as the receiver of `length` property.
             */
            function isLengthExpression(node, expectedObjectNode) {
                if (node.type === utils_1.AST_NODE_TYPES.MemberExpression) {
                    return ((0, util_1.getPropertyName)(node, globalScope) === 'length' &&
                        isSameTokens(node.object, expectedObjectNode));
                }
                const evaluatedLength = (0, util_1.getStaticValue)(node, globalScope);
                const evaluatedString = (0, util_1.getStaticValue)(expectedObjectNode, globalScope);
                return (evaluatedLength != null &&
                    evaluatedString != null &&
                    typeof evaluatedLength.value === 'number' &&
                    typeof evaluatedString.value === 'string' &&
                    evaluatedLength.value === evaluatedString.value.length);
            }
            /**
             * Check if a given node is a negative index expression
             *
             * E.g. `s.slice(- <expr>)`, `s.substring(s.length - <expr>)`
             *
             * @param node The node to check.
             * @param expectedIndexedNode The node which is expected as the receiver of index expression.
             */
            function isNegativeIndexExpression(node, expectedIndexedNode) {
                return ((node.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                    node.operator === '-') ||
                    (node.type === utils_1.AST_NODE_TYPES.BinaryExpression &&
                        node.operator === '-' &&
                        isLengthExpression(node.left, expectedIndexedNode)));
            }
            /**
             * Check if a given node is the expression of the last index.
             *
             * E.g. `foo.length - 1`
             *
             * @param node The node to check.
             * @param expectedObjectNode The node which is expected as the receiver of `length` property.
             */
            function isLastIndexExpression(node, expectedObjectNode) {
                return (node.type === utils_1.AST_NODE_TYPES.BinaryExpression &&
                    node.operator === '-' &&
                    isLengthExpression(node.left, expectedObjectNode) &&
                    isNumber(node.right, 1));
            }
            /**
             * Get the range of the property of a given `MemberExpression` node.
             *
             * - `obj[foo]` → the range of `[foo]`
             * - `obf.foo` → the range of `.foo`
             * - `(obj).foo` → the range of `.foo`
             *
             * @param node The member expression node to get.
             */
            function getPropertyRange(node) {
                const dotOrOpenBracket = sourceCode.getTokenAfter(node.object, util_1.isNotClosingParenToken);
                return [dotOrOpenBracket.range[0], node.range[1]];
            }
            /**
             * Parse a given `RegExp` pattern to that string if it's a static string.
             * @param pattern The RegExp pattern text to parse.
             * @param uFlag The Unicode flag of the RegExp.
             */
            function parseRegExpText(pattern, uFlag) {
                // Parse it.
                const ast = regexpp.parsePattern(pattern, undefined, undefined, uFlag);
                if (ast.alternatives.length !== 1) {
                    return null;
                }
                // Drop `^`/`$` assertion.
                const chars = ast.alternatives[0].elements;
                const first = chars[0];
                if (first.type === 'Assertion' && first.kind === 'start') {
                    chars.shift();
                }
                else {
                    chars.pop();
                }
                // Check if it can determine a unique string.
                if (!chars.every(c => c.type === 'Character')) {
                    return null;
                }
                // To string.
                return String.fromCodePoint(...chars.map(c => c.value));
            }
            /**
             * Parse a given node if it's a `RegExp` instance.
             * @param node The node to parse.
             */
            function parseRegExp(node) {
                const evaluated = (0, util_1.getStaticValue)(node, globalScope);
                if (evaluated == null || !(evaluated.value instanceof RegExp)) {
                    return null;
                }
                const { source, flags } = evaluated.value;
                const isStartsWith = source.startsWith('^');
                const isEndsWith = source.endsWith('$');
                if (isStartsWith === isEndsWith ||
                    flags.includes('i') ||
                    flags.includes('m')) {
                    return null;
                }
                const text = parseRegExpText(source, flags.includes('u'));
                if (text == null) {
                    return null;
                }
                return { isEndsWith, isStartsWith, text };
            }
            function getLeftNode(node) {
                if (node.type === utils_1.AST_NODE_TYPES.ChainExpression) {
                    return getLeftNode(node.expression);
                }
                let leftNode;
                if (node.type === utils_1.AST_NODE_TYPES.CallExpression) {
                    leftNode = node.callee;
                }
                else {
                    leftNode = node;
                }
                if (leftNode.type !== utils_1.AST_NODE_TYPES.MemberExpression) {
                    throw new Error(`Expected a MemberExpression, got ${leftNode.type}`);
                }
                return leftNode;
            }
            /**
             * Fix code with using the right operand as the search string.
             * For example: `foo.slice(0, 3) === 'bar'` → `foo.startsWith('bar')`
             * @param fixer The rule fixer.
             * @param node The node which was reported.
             * @param kind The kind of the report.
             * @param isNegative The flag to fix to negative condition.
             */
            function* fixWithRightOperand(fixer, node, kind, isNegative, isOptional) {
                // left is CallExpression or MemberExpression.
                const leftNode = getLeftNode(node.left);
                const propertyRange = getPropertyRange(leftNode);
                if (isNegative) {
                    yield fixer.insertTextBefore(node, '!');
                }
                yield fixer.replaceTextRange([propertyRange[0], node.right.range[0]], `${isOptional ? '?.' : '.'}${kind}sWith(`);
                yield fixer.replaceTextRange([node.right.range[1], node.range[1]], ')');
            }
            /**
             * Fix code with using the first argument as the search string.
             * For example: `foo.indexOf('bar') === 0` → `foo.startsWith('bar')`
             * @param fixer The rule fixer.
             * @param node The node which was reported.
             * @param kind The kind of the report.
             * @param negative The flag to fix to negative condition.
             */
            function* fixWithArgument(fixer, node, callNode, calleeNode, kind, negative, isOptional) {
                if (negative) {
                    yield fixer.insertTextBefore(node, '!');
                }
                yield fixer.replaceTextRange(getPropertyRange(calleeNode), `${isOptional ? '?.' : '.'}${kind}sWith`);
                yield fixer.removeRange([callNode.range[1], node.range[1]]);
            }
            function getParent(node) {
                var _a;
                return (0, util_1.nullThrows)(((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.ChainExpression
                    ? node.parent.parent
                    : node.parent, util_1.NullThrowsReasons.MissingParent);
            }
            return {
                // foo[0] === "a"
                // foo.charAt(0) === "a"
                // foo[foo.length - 1] === "a"
                // foo.charAt(foo.length - 1) === "a"
                [[
                    'BinaryExpression > MemberExpression.left[computed=true]',
                    'BinaryExpression > CallExpression.left > MemberExpression.callee[property.name="charAt"][computed=false]',
                    'BinaryExpression > ChainExpression.left > MemberExpression[computed=true]',
                    'BinaryExpression > ChainExpression.left > CallExpression > MemberExpression.callee[property.name="charAt"][computed=false]',
                ].join(', ')](node) {
                    let parentNode = getParent(node);
                    let indexNode = null;
                    if ((parentNode === null || parentNode === void 0 ? void 0 : parentNode.type) === utils_1.AST_NODE_TYPES.CallExpression) {
                        if (parentNode.arguments.length === 1) {
                            indexNode = parentNode.arguments[0];
                        }
                        parentNode = getParent(parentNode);
                    }
                    else {
                        indexNode = node.property;
                    }
                    if (indexNode == null ||
                        !isEqualityComparison(parentNode) ||
                        !isStringType(node.object)) {
                        return;
                    }
                    const isEndsWith = isLastIndexExpression(indexNode, node.object);
                    const isStartsWith = !isEndsWith && isNumber(indexNode, 0);
                    if (!isStartsWith && !isEndsWith) {
                        return;
                    }
                    const eqNode = parentNode;
                    context.report({
                        node: parentNode,
                        messageId: isStartsWith ? 'preferStartsWith' : 'preferEndsWith',
                        fix(fixer) {
                            // Don't fix if it can change the behavior.
                            if (!isCharacter(eqNode.right)) {
                                return null;
                            }
                            return fixWithRightOperand(fixer, eqNode, isStartsWith ? 'start' : 'end', eqNode.operator.startsWith('!'), node.optional);
                        },
                    });
                },
                // foo.indexOf('bar') === 0
                [[
                    'BinaryExpression > CallExpression.left > MemberExpression.callee[property.name="indexOf"][computed=false]',
                    'BinaryExpression > ChainExpression.left > CallExpression > MemberExpression.callee[property.name="indexOf"][computed=false]',
                ].join(', ')](node) {
                    const callNode = getParent(node);
                    const parentNode = getParent(callNode);
                    if (callNode.arguments.length !== 1 ||
                        !isEqualityComparison(parentNode) ||
                        !isNumber(parentNode.right, 0) ||
                        !isStringType(node.object)) {
                        return;
                    }
                    context.report({
                        node: parentNode,
                        messageId: 'preferStartsWith',
                        fix(fixer) {
                            return fixWithArgument(fixer, parentNode, callNode, node, 'start', parentNode.operator.startsWith('!'), node.optional);
                        },
                    });
                },
                // foo.lastIndexOf('bar') === foo.length - 3
                // foo.lastIndexOf(bar) === foo.length - bar.length
                [[
                    'BinaryExpression > CallExpression.left > MemberExpression.callee[property.name="lastIndexOf"][computed=false]',
                    'BinaryExpression > ChainExpression.left > CallExpression > MemberExpression.callee[property.name="lastIndexOf"][computed=false]',
                ].join(', ')](node) {
                    const callNode = getParent(node);
                    const parentNode = getParent(callNode);
                    if (callNode.arguments.length !== 1 ||
                        !isEqualityComparison(parentNode) ||
                        parentNode.right.type !== utils_1.AST_NODE_TYPES.BinaryExpression ||
                        parentNode.right.operator !== '-' ||
                        !isLengthExpression(parentNode.right.left, node.object) ||
                        !isLengthExpression(parentNode.right.right, callNode.arguments[0]) ||
                        !isStringType(node.object)) {
                        return;
                    }
                    context.report({
                        node: parentNode,
                        messageId: 'preferEndsWith',
                        fix(fixer) {
                            return fixWithArgument(fixer, parentNode, callNode, node, 'end', parentNode.operator.startsWith('!'), node.optional);
                        },
                    });
                },
                // foo.match(/^bar/) === null
                // foo.match(/bar$/) === null
                [[
                    'BinaryExpression > CallExpression.left > MemberExpression.callee[property.name="match"][computed=false]',
                    'BinaryExpression > ChainExpression.left > CallExpression > MemberExpression.callee[property.name="match"][computed=false]',
                ].join(', ')](node) {
                    const callNode = getParent(node);
                    const parentNode = getParent(callNode);
                    if (!isEqualityComparison(parentNode) ||
                        !isNull(parentNode.right) ||
                        !isStringType(node.object)) {
                        return;
                    }
                    const parsed = callNode.arguments.length === 1
                        ? parseRegExp(callNode.arguments[0])
                        : null;
                    if (parsed == null) {
                        return;
                    }
                    const { isStartsWith, text } = parsed;
                    context.report({
                        node: callNode,
                        messageId: isStartsWith ? 'preferStartsWith' : 'preferEndsWith',
                        *fix(fixer) {
                            if (!parentNode.operator.startsWith('!')) {
                                yield fixer.insertTextBefore(parentNode, '!');
                            }
                            yield fixer.replaceTextRange(getPropertyRange(node), `${node.optional ? '?.' : '.'}${isStartsWith ? 'start' : 'end'}sWith`);
                            yield fixer.replaceText(callNode.arguments[0], JSON.stringify(text));
                            yield fixer.removeRange([callNode.range[1], parentNode.range[1]]);
                        },
                    });
                },
                // foo.slice(0, 3) === 'bar'
                // foo.slice(-3) === 'bar'
                // foo.slice(-3, foo.length) === 'bar'
                // foo.substring(0, 3) === 'bar'
                // foo.substring(foo.length - 3) === 'bar'
                // foo.substring(foo.length - 3, foo.length) === 'bar'
                [[
                    'BinaryExpression > CallExpression.left > MemberExpression.callee[property.name="slice"][computed=false]',
                    'BinaryExpression > CallExpression.left > MemberExpression.callee[property.name="substring"][computed=false]',
                    'BinaryExpression > ChainExpression.left > CallExpression > MemberExpression.callee[property.name="slice"][computed=false]',
                    'BinaryExpression > ChainExpression.left > CallExpression > MemberExpression.callee[property.name="substring"][computed=false]',
                ].join(', ')](node) {
                    const callNode = getParent(node);
                    const parentNode = getParent(callNode);
                    if (!isEqualityComparison(parentNode) || !isStringType(node.object)) {
                        return;
                    }
                    const isEndsWith = (callNode.arguments.length === 1 ||
                        (callNode.arguments.length === 2 &&
                            isLengthExpression(callNode.arguments[1], node.object))) &&
                        isNegativeIndexExpression(callNode.arguments[0], node.object);
                    const isStartsWith = !isEndsWith &&
                        callNode.arguments.length === 2 &&
                        isNumber(callNode.arguments[0], 0) &&
                        !isNegativeIndexExpression(callNode.arguments[1], node.object);
                    if (!isStartsWith && !isEndsWith) {
                        return;
                    }
                    const eqNode = parentNode;
                    const negativeIndexSupported = node.property.name === 'slice';
                    context.report({
                        node: parentNode,
                        messageId: isStartsWith ? 'preferStartsWith' : 'preferEndsWith',
                        fix(fixer) {
                            // Don't fix if it can change the behavior.
                            if (eqNode.operator.length === 2 &&
                                (eqNode.right.type !== utils_1.AST_NODE_TYPES.Literal ||
                                    typeof eqNode.right.value !== 'string')) {
                                return null;
                            }
                            // code being checked is likely mistake:
                            // unequal length of strings being checked for equality
                            // or reliant on behavior of substring (negative indices interpreted as 0)
                            if (isStartsWith) {
                                if (!isLengthExpression(callNode.arguments[1], eqNode.right)) {
                                    return null;
                                }
                            }
                            else {
                                const posNode = callNode.arguments[0];
                                const posNodeIsAbsolutelyValid = (posNode.type === utils_1.AST_NODE_TYPES.BinaryExpression &&
                                    posNode.operator === '-' &&
                                    isLengthExpression(posNode.left, node.object) &&
                                    isLengthExpression(posNode.right, eqNode.right)) ||
                                    (negativeIndexSupported &&
                                        posNode.type === utils_1.AST_NODE_TYPES.UnaryExpression &&
                                        posNode.operator === '-' &&
                                        isLengthExpression(posNode.argument, eqNode.right));
                                if (!posNodeIsAbsolutelyValid) {
                                    return null;
                                }
                            }
                            return fixWithRightOperand(fixer, parentNode, isStartsWith ? 'start' : 'end', parentNode.operator.startsWith('!'), node.optional);
                        },
                    });
                },
                // /^bar/.test(foo)
                // /bar$/.test(foo)
                'CallExpression > MemberExpression.callee[property.name="test"][computed=false]'(node) {
                    const callNode = getParent(node);
                    const parsed = callNode.arguments.length === 1 ? parseRegExp(node.object) : null;
                    if (parsed == null) {
                        return;
                    }
                    const { isStartsWith, text } = parsed;
                    const messageId = isStartsWith ? 'preferStartsWith' : 'preferEndsWith';
                    const methodName = isStartsWith ? 'startsWith' : 'endsWith';
                    context.report({
                        node: callNode,
                        messageId,
                        *fix(fixer) {
                            const argNode = callNode.arguments[0];
                            const needsParen = argNode.type !== utils_1.AST_NODE_TYPES.Literal &&
                                argNode.type !== utils_1.AST_NODE_TYPES.TemplateLiteral &&
                                argNode.type !== utils_1.AST_NODE_TYPES.Identifier &&
                                argNode.type !== utils_1.AST_NODE_TYPES.MemberExpression &&
                                argNode.type !== utils_1.AST_NODE_TYPES.CallExpression;
                            yield fixer.removeRange([callNode.range[0], argNode.range[0]]);
                            if (needsParen) {
                                yield fixer.insertTextBefore(argNode, '(');
                                yield fixer.insertTextAfter(argNode, ')');
                            }
                            yield fixer.insertTextAfter(argNode, `${node.optional ? '?.' : '.'}${methodName}(${JSON.stringify(text)}`);
                        },
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/prefer-ts-expect-error.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'prefer-ts-expect-error',
        meta: {
            type: 'problem',
            docs: {
                description: 'Enforce using `@ts-expect-error` over `@ts-ignore`',
                recommended: 'strict',
            },
            fixable: 'code',
            messages: {
                preferExpectErrorComment: 'Use "@ts-expect-error" to ensure an error is actually being suppressed.',
            },
            schema: [],
        },
        defaultOptions: [],
        create(context) {
            const tsIgnoreRegExpSingleLine = /^\s*\/?\s*@ts-ignore/;
            const tsIgnoreRegExpMultiLine = /^\s*(?:\/|\*)*\s*@ts-ignore/;
            const sourceCode = context.getSourceCode();
            function isLineComment(comment) {
                return comment.type === utils_1.AST_TOKEN_TYPES.Line;
            }
            function getLastCommentLine(comment) {
                if (isLineComment(comment)) {
                    return comment.value;
                }
                // For multiline comments - we look at only the last line.
                const commentlines = comment.value.split('\n');
                return commentlines[commentlines.length - 1];
            }
            function isValidTsIgnorePresent(comment) {
                const line = getLastCommentLine(comment);
                return isLineComment(comment)
                    ? tsIgnoreRegExpSingleLine.test(line)
                    : tsIgnoreRegExpMultiLine.test(line);
            }
            return {
                Program() {
                    const comments = sourceCode.getAllComments();
                    comments.forEach(comment => {
                        if (isValidTsIgnorePresent(comment)) {
                            const lineCommentRuleFixer = (fixer) => fixer.replaceText(comment, `//${comment.value.replace('@ts-ignore', '@ts-expect-error')}`);
                            const blockCommentRuleFixer = (fixer) => fixer.replaceText(comment, `/*${comment.value.replace('@ts-ignore', '@ts-expect-error')}*/`);
                            context.report({
                                node: comment,
                                messageId: 'preferExpectErrorComment',
                                fix: isLineComment(comment)
                                    ? lineCommentRuleFixer
                                    : blockCommentRuleFixer,
                            });
                        }
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/promise-function-async.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'promise-function-async',
        meta: {
            type: 'suggestion',
            fixable: 'code',
            docs: {
                description: 'Require any function or method that returns a Promise to be marked async',
                recommended: false,
                requiresTypeChecking: true,
            },
            messages: {
                missingAsync: 'Functions that return promises must be async.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowAny: {
                            description: 'Whether to consider `any` and `unknown` to be Promises.',
                            type: 'boolean',
                        },
                        allowedPromiseNames: {
                            description: 'Any extra names of classes or interfaces to be considered Promises.',
                            type: 'array',
                            items: {
                                type: 'string',
                            },
                        },
                        checkArrowFunctions: {
                            type: 'boolean',
                        },
                        checkFunctionDeclarations: {
                            type: 'boolean',
                        },
                        checkFunctionExpressions: {
                            type: 'boolean',
                        },
                        checkMethodDeclarations: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                allowAny: true,
                allowedPromiseNames: [],
                checkArrowFunctions: true,
                checkFunctionDeclarations: true,
                checkFunctionExpressions: true,
                checkMethodDeclarations: true,
            },
        ],
        create(context, [{ allowAny, allowedPromiseNames, checkArrowFunctions, checkFunctionDeclarations, checkFunctionExpressions, checkMethodDeclarations, },]) {
            const allAllowedPromiseNames = new Set([
                'Promise',
                ...allowedPromiseNames,
            ]);
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const sourceCode = context.getSourceCode();
            function validateNode(node) {
                var _a;
                const originalNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                const signatures = checker
                    .getTypeAtLocation(originalNode)
                    .getCallSignatures();
                if (!signatures.length) {
                    return;
                }
                const returnType = checker.getReturnTypeOfSignature(signatures[0]);
                if (!util.containsAllTypesByName(returnType, allowAny, allAllowedPromiseNames, 
                // If no return type is explicitly set, we check if any parts of the return type match a Promise (instead of requiring all to match).
                node.returnType == null)) {
                    // Return type is not a promise
                    return;
                }
                if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition) {
                    // Abstract method can't be async
                    return;
                }
                if (node.parent &&
                    (node.parent.type === utils_1.AST_NODE_TYPES.Property ||
                        node.parent.type === utils_1.AST_NODE_TYPES.MethodDefinition) &&
                    (node.parent.kind === 'get' || node.parent.kind === 'set')) {
                    // Getters and setters can't be async
                    return;
                }
                if (util.isTypeFlagSet(returnType, ts.TypeFlags.Any | ts.TypeFlags.Unknown)) {
                    // Report without auto fixer because the return type is unknown
                    return context.report({
                        messageId: 'missingAsync',
                        node,
                        loc: util.getFunctionHeadLoc(node, sourceCode),
                    });
                }
                context.report({
                    messageId: 'missingAsync',
                    node,
                    loc: util.getFunctionHeadLoc(node, sourceCode),
                    fix: fixer => {
                        if (node.parent &&
                            (node.parent.type === utils_1.AST_NODE_TYPES.MethodDefinition ||
                                (node.parent.type === utils_1.AST_NODE_TYPES.Property &&
                                    node.parent.method))) {
                            // this function is a class method or object function property shorthand
                            const method = node.parent;
                            // the token to put `async` before
                            let keyToken = sourceCode.getFirstToken(method);
                            // if there are decorators then skip past them
                            if (method.type === utils_1.AST_NODE_TYPES.MethodDefinition &&
                                method.decorators) {
                                const lastDecorator = method.decorators[method.decorators.length - 1];
                                keyToken = sourceCode.getTokenAfter(lastDecorator);
                            }
                            // if current token is a keyword like `static` or `public` then skip it
                            while (keyToken.type === utils_1.AST_TOKEN_TYPES.Keyword &&
                                keyToken.range[0] < method.key.range[0]) {
                                keyToken = sourceCode.getTokenAfter(keyToken);
                            }
                            // check if there is a space between key and previous token
                            const insertSpace = !sourceCode.isSpaceBetween(sourceCode.getTokenBefore(keyToken), keyToken);
                            let code = 'async ';
                            if (insertSpace) {
                                code = ` ${code}`;
                            }
                            return fixer.insertTextBefore(keyToken, code);
                        }
                        return fixer.insertTextBefore(node, 'async ');
                    },
                });
            }
            return Object.assign(Object.assign(Object.assign({}, (checkArrowFunctions && {
                'ArrowFunctionExpression[async = false]'(node) {
                    validateNode(node);
                },
            })), (checkFunctionDeclarations && {
                'FunctionDeclaration[async = false]'(node) {
                    validateNode(node);
                },
            })), { 'FunctionExpression[async = false]'(node) {
                    if (node.parent &&
                        node.parent.type === utils_1.AST_NODE_TYPES.MethodDefinition &&
                        node.parent.kind === 'method') {
                        if (checkMethodDeclarations) {
                            validateNode(node);
                        }
                        return;
                    }
                    if (checkFunctionExpressions) {
                        validateNode(node);
                    }
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/quotes.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var _a;
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('quotes');
    exports.default = util.createRule({
        name: 'quotes',
        meta: {
            type: 'layout',
            docs: {
                description: 'Enforce the consistent use of either backticks, double, or single quotes',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'code',
            hasSuggestions: baseRule.meta.hasSuggestions,
            // TODO: this rule has only had messages since v7.0 - remove this when we remove support for v6
            messages: (_a = baseRule.meta.messages) !== null && _a !== void 0 ? _a : {
                wrongQuotes: 'Strings must use {{description}}.',
            },
            schema: baseRule.meta.schema,
        },
        defaultOptions: [
            'double',
            {
                allowTemplateLiterals: false,
                avoidEscape: false,
            },
        ],
        create(context, [option]) {
            const rules = baseRule.create(context);
            function isAllowedAsNonBacktick(node) {
                const parent = node.parent;
                switch (parent === null || parent === void 0 ? void 0 : parent.type) {
                    case utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition:
                    case utils_1.AST_NODE_TYPES.TSMethodSignature:
                    case utils_1.AST_NODE_TYPES.TSPropertySignature:
                    case utils_1.AST_NODE_TYPES.TSModuleDeclaration:
                    case utils_1.AST_NODE_TYPES.TSLiteralType:
                    case utils_1.AST_NODE_TYPES.TSExternalModuleReference:
                        return true;
                    case utils_1.AST_NODE_TYPES.TSEnumMember:
                        return node === parent.id;
                    case utils_1.AST_NODE_TYPES.TSAbstractPropertyDefinition:
                    case utils_1.AST_NODE_TYPES.PropertyDefinition:
                        return node === parent.key;
                    default:
                        return false;
                }
            }
            return {
                Literal(node) {
                    if (option === 'backtick' && isAllowedAsNonBacktick(node)) {
                        return;
                    }
                    rules.Literal(node);
                },
                TemplateLiteral(node) {
                    rules.TemplateLiteral(node);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/require-array-sort-compare.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'require-array-sort-compare',
        defaultOptions: [
            {
                ignoreStringArrays: false,
            },
        ],
        meta: {
            type: 'problem',
            docs: {
                description: 'Require `Array#sort` calls to always provide a `compareFunction`',
                recommended: false,
                requiresTypeChecking: true,
            },
            messages: {
                requireCompare: "Require 'compare' argument.",
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        ignoreStringArrays: {
                            description: 'Whether to ignore arrays in which all elements are strings.',
                            type: 'boolean',
                        },
                    },
                },
            ],
        },
        create(context, [options]) {
            const service = util.getParserServices(context);
            const checker = service.program.getTypeChecker();
            /**
             * Check if a given node is an array which all elements are string.
             * @param node
             */
            function isStringArrayNode(node) {
                const type = checker.getTypeAtLocation(service.esTreeNodeToTSNodeMap.get(node));
                if (checker.isArrayType(type) || checker.isTupleType(type)) {
                    const typeArgs = checker.getTypeArguments(type);
                    return typeArgs.every(arg => util.getTypeName(checker, arg) === 'string');
                }
                return false;
            }
            return {
                "CallExpression[arguments.length=0] > MemberExpression[property.name='sort'][computed=false]"(callee) {
                    const tsNode = service.esTreeNodeToTSNodeMap.get(callee.object);
                    const calleeObjType = util.getConstrainedTypeAtLocation(checker, tsNode);
                    if (options.ignoreStringArrays && isStringArrayNode(callee.object)) {
                        return;
                    }
                    if (util.isTypeArrayTypeOrUnionOfArrayTypes(calleeObjType, checker)) {
                        context.report({ node: callee.parent, messageId: 'requireCompare' });
                    }
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/require-await.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'require-await',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow async functions which have no `await` expression',
                recommended: 'error',
                requiresTypeChecking: true,
                extendsBaseRule: true,
            },
            schema: [],
            messages: {
                missingAwait: "{{name}} has no 'await' expression.",
            },
        },
        defaultOptions: [],
        create(context) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const sourceCode = context.getSourceCode();
            let scopeInfo = null;
            /**
             * Push the scope info object to the stack.
             */
            function enterFunction(node) {
                scopeInfo = {
                    upper: scopeInfo,
                    hasAwait: false,
                    hasAsync: node.async,
                    isGen: node.generator || false,
                    isAsyncYield: false,
                };
            }
            /**
             * Pop the top scope info object from the stack.
             * Also, it reports the function if needed.
             */
            function exitFunction(node) {
                /* istanbul ignore if */ if (!scopeInfo) {
                    // this shouldn't ever happen, as we have to exit a function after we enter it
                    return;
                }
                if (node.async &&
                    !scopeInfo.hasAwait &&
                    !isEmptyFunction(node) &&
                    !(scopeInfo.isGen && scopeInfo.isAsyncYield)) {
                    context.report({
                        node,
                        loc: getFunctionHeadLoc(node, sourceCode),
                        messageId: 'missingAwait',
                        data: {
                            name: util.upperCaseFirst(util.getFunctionNameWithKind(node)),
                        },
                    });
                }
                scopeInfo = scopeInfo.upper;
            }
            /**
             * Checks if the node returns a thenable type
             */
            function isThenableType(node) {
                const type = checker.getTypeAtLocation(node);
                return tsutils.isThenableType(checker, node, type);
            }
            /**
             * Marks the current scope as having an await
             */
            function markAsHasAwait() {
                if (!scopeInfo) {
                    return;
                }
                scopeInfo.hasAwait = true;
            }
            /**
             * mark `scopeInfo.isAsyncYield` to `true` if its a generator
             * function and the delegate is `true`
             */
            function markAsHasDelegateGen(node) {
                var _a;
                if (!(scopeInfo === null || scopeInfo === void 0 ? void 0 : scopeInfo.isGen) || !node.argument) {
                    return;
                }
                if (((_a = node === null || node === void 0 ? void 0 : node.argument) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.Literal) {
                    // making this `false` as for literals we don't need to check the definition
                    // eg : async function* run() { yield* 1 }
                    scopeInfo.isAsyncYield || (scopeInfo.isAsyncYield = false);
                }
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node === null || node === void 0 ? void 0 : node.argument);
                const type = checker.getTypeAtLocation(tsNode);
                const typesToCheck = expandUnionOrIntersectionType(type);
                for (const type of typesToCheck) {
                    const asyncIterator = tsutils.getWellKnownSymbolPropertyOfType(type, 'asyncIterator', checker);
                    if (asyncIterator !== undefined) {
                        scopeInfo.isAsyncYield = true;
                        break;
                    }
                }
            }
            return {
                FunctionDeclaration: enterFunction,
                FunctionExpression: enterFunction,
                ArrowFunctionExpression: enterFunction,
                'FunctionDeclaration:exit': exitFunction,
                'FunctionExpression:exit': exitFunction,
                'ArrowFunctionExpression:exit': exitFunction,
                AwaitExpression: markAsHasAwait,
                'ForOfStatement[await = true]': markAsHasAwait,
                'YieldExpression[delegate = true]': markAsHasDelegateGen,
                // check body-less async arrow function.
                // ignore `async () => await foo` because it's obviously correct
                'ArrowFunctionExpression[async = true] > :not(BlockStatement, AwaitExpression)'(node) {
                    const expression = parserServices.esTreeNodeToTSNodeMap.get(node);
                    if (expression && isThenableType(expression)) {
                        markAsHasAwait();
                    }
                },
                ReturnStatement(node) {
                    // short circuit early to avoid unnecessary type checks
                    if (!scopeInfo || scopeInfo.hasAwait || !scopeInfo.hasAsync) {
                        return;
                    }
                    const { expression } = parserServices.esTreeNodeToTSNodeMap.get(node);
                    if (expression && isThenableType(expression)) {
                        markAsHasAwait();
                    }
                },
            };
        },
    });
    function isEmptyFunction(node) {
        var _a;
        return (((_a = node.body) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.BlockStatement &&
            node.body.body.length === 0);
    }
    // https://github.com/eslint/eslint/blob/03a69dbe86d5b5768a310105416ae726822e3c1c/lib/rules/utils/ast-utils.js#L382-L392
    /**
     * Gets the `(` token of the given function node.
     */
    function getOpeningParenOfParams(node, sourceCode) {
        return util.nullThrows(node.id
            ? sourceCode.getTokenAfter(node.id, util.isOpeningParenToken)
            : sourceCode.getFirstToken(node, util.isOpeningParenToken), util.NullThrowsReasons.MissingToken('(', node.type));
    }
    // https://github.com/eslint/eslint/blob/03a69dbe86d5b5768a310105416ae726822e3c1c/lib/rules/utils/ast-utils.js#L1220-L1242
    /**
     * Gets the location of the given function node for reporting.
     */
    function getFunctionHeadLoc(node, sourceCode) {
        const parent = util.nullThrows(node.parent, util.NullThrowsReasons.MissingParent);
        let start = null;
        let end = null;
        if (node.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression) {
            const arrowToken = util.nullThrows(sourceCode.getTokenBefore(node.body, util.isArrowToken), util.NullThrowsReasons.MissingToken('=>', node.type));
            start = arrowToken.loc.start;
            end = arrowToken.loc.end;
        }
        else if (parent.type === utils_1.AST_NODE_TYPES.Property ||
            parent.type === utils_1.AST_NODE_TYPES.MethodDefinition) {
            start = parent.loc.start;
            end = getOpeningParenOfParams(node, sourceCode).loc.start;
        }
        else {
            start = node.loc.start;
            end = getOpeningParenOfParams(node, sourceCode).loc.start;
        }
        return {
            start,
            end,
        };
    }
    function expandUnionOrIntersectionType(type) {
        if (type.isUnionOrIntersection()) {
            return type.types.flatMap(expandUnionOrIntersectionType);
        }
        return [type];
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/restrict-plus-operands.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'restrict-plus-operands',
        meta: {
            type: 'problem',
            docs: {
                description: 'Require both operands of addition to be the same type and be `bigint`, `number`, or `string`',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                notNumbers: "Operands of '+' operation must either be both strings or both numbers.",
                notStrings: "Operands of '+' operation must either be both strings or both numbers. Consider using a template literal.",
                notBigInts: "Operands of '+' operation must be both bigints.",
                notValidAnys: "Operands of '+' operation with any is possible only with string, number, bigint or any",
                notValidTypes: "Operands of '+' operation must either be one of string, number, bigint or any (if allowed by option)",
            },
            schema: [
                {
                    type: 'object',
                    additionalProperties: false,
                    properties: {
                        checkCompoundAssignments: {
                            description: 'Whether to check compound assignments such as `+=`.',
                            type: 'boolean',
                        },
                        allowAny: {
                            description: 'Whether to allow `any` typed values.',
                            type: 'boolean',
                        },
                    },
                },
            ],
        },
        defaultOptions: [
            {
                checkCompoundAssignments: false,
                allowAny: false,
            },
        ],
        create(context, [{ checkCompoundAssignments, allowAny }]) {
            const service = util.getParserServices(context);
            const typeChecker = service.program.getTypeChecker();
            /**
             * Helper function to get base type of node
             */
            function getBaseTypeOfLiteralType(type) {
                if (type.isNumberLiteral()) {
                    return 'number';
                }
                if (type.isStringLiteral() ||
                    util.isTypeFlagSet(type, ts.TypeFlags.TemplateLiteral)) {
                    return 'string';
                }
                // is BigIntLiteral
                if (type.flags & ts.TypeFlags.BigIntLiteral) {
                    return 'bigint';
                }
                if (type.isUnion()) {
                    const types = type.types.map(getBaseTypeOfLiteralType);
                    return types.every(value => value === types[0]) ? types[0] : 'invalid';
                }
                if (type.isIntersection()) {
                    const types = type.types.map(getBaseTypeOfLiteralType);
                    if (types.some(value => value === 'string')) {
                        return 'string';
                    }
                    if (types.some(value => value === 'number')) {
                        return 'number';
                    }
                    if (types.some(value => value === 'bigint')) {
                        return 'bigint';
                    }
                    return 'invalid';
                }
                const stringType = typeChecker.typeToString(type);
                if (stringType === 'number' ||
                    stringType === 'string' ||
                    stringType === 'bigint' ||
                    stringType === 'any') {
                    return stringType;
                }
                return 'invalid';
            }
            /**
             * Helper function to get base type of node
             * @param node the node to be evaluated.
             */
            function getNodeType(node) {
                const tsNode = service.esTreeNodeToTSNodeMap.get(node);
                const type = util.getConstrainedTypeAtLocation(typeChecker, tsNode);
                return getBaseTypeOfLiteralType(type);
            }
            function checkPlusOperands(node) {
                const leftType = getNodeType(node.left);
                const rightType = getNodeType(node.right);
                if (leftType === rightType) {
                    if (leftType === 'invalid') {
                        context.report({
                            node,
                            messageId: 'notValidTypes',
                        });
                    }
                    if (!allowAny && leftType === 'any') {
                        context.report({
                            node,
                            messageId: 'notValidAnys',
                        });
                    }
                    return;
                }
                if (leftType === 'any' || rightType === 'any') {
                    if (!allowAny || leftType === 'invalid' || rightType === 'invalid') {
                        context.report({
                            node,
                            messageId: 'notValidAnys',
                        });
                    }
                    return;
                }
                if (leftType === 'string' || rightType === 'string') {
                    return context.report({
                        node,
                        messageId: 'notStrings',
                    });
                }
                if (leftType === 'bigint' || rightType === 'bigint') {
                    return context.report({
                        node,
                        messageId: 'notBigInts',
                    });
                }
                if (leftType === 'number' || rightType === 'number') {
                    return context.report({
                        node,
                        messageId: 'notNumbers',
                    });
                }
            }
            return Object.assign({ "BinaryExpression[operator='+']": checkPlusOperands }, (checkCompoundAssignments && {
                "AssignmentExpression[operator='+=']"(node) {
                    checkPlusOperands(node);
                },
            }));
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/restrict-template-expressions.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'restrict-template-expressions',
        meta: {
            type: 'problem',
            docs: {
                description: 'Enforce template literal expressions to be of `string` type',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                invalidType: 'Invalid type "{{type}}" of template literal expression.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowNumber: {
                            description: 'Whether to allow `number` typed values in template expressions.',
                            type: 'boolean',
                        },
                        allowBoolean: {
                            description: 'Whether to allow `boolean` typed values in template expressions.',
                            type: 'boolean',
                        },
                        allowAny: {
                            description: 'Whether to allow `any` typed values in template expressions.',
                            type: 'boolean',
                        },
                        allowNullish: {
                            description: 'Whether to allow `nullish` typed values in template expressions.',
                            type: 'boolean',
                        },
                        allowRegExp: {
                            description: 'Whether to allow `regexp` typed values in template expressions.',
                            type: 'boolean',
                        },
                    },
                },
            ],
        },
        defaultOptions: [
            {
                allowNumber: true,
            },
        ],
        create(context, [options]) {
            const service = util.getParserServices(context);
            const typeChecker = service.program.getTypeChecker();
            function isUnderlyingTypePrimitive(type) {
                if (util.isTypeFlagSet(type, ts.TypeFlags.StringLike)) {
                    return true;
                }
                if (options.allowNumber &&
                    util.isTypeFlagSet(type, ts.TypeFlags.NumberLike | ts.TypeFlags.BigIntLike)) {
                    return true;
                }
                if (options.allowBoolean &&
                    util.isTypeFlagSet(type, ts.TypeFlags.BooleanLike)) {
                    return true;
                }
                if (options.allowAny && util.isTypeAnyType(type)) {
                    return true;
                }
                if (options.allowRegExp &&
                    util.getTypeName(typeChecker, type) === 'RegExp') {
                    return true;
                }
                if (options.allowNullish &&
                    util.isTypeFlagSet(type, ts.TypeFlags.Null | ts.TypeFlags.Undefined)) {
                    return true;
                }
                return false;
            }
            return {
                TemplateLiteral(node) {
                    // don't check tagged template literals
                    if (node.parent.type === utils_1.AST_NODE_TYPES.TaggedTemplateExpression) {
                        return;
                    }
                    for (const expression of node.expressions) {
                        const expressionType = util.getConstrainedTypeAtLocation(typeChecker, service.esTreeNodeToTSNodeMap.get(expression));
                        if (!isInnerUnionOrIntersectionConformingTo(expressionType, isUnderlyingTypePrimitive)) {
                            context.report({
                                node: expression,
                                messageId: 'invalidType',
                                data: { type: typeChecker.typeToString(expressionType) },
                            });
                        }
                    }
                },
            };
            function isInnerUnionOrIntersectionConformingTo(type, predicate) {
                return rec(type);
                function rec(innerType) {
                    if (innerType.isUnion()) {
                        return innerType.types.every(rec);
                    }
                    if (innerType.isIntersection()) {
                        return innerType.types.some(rec);
                    }
                    return predicate(innerType);
                }
            }
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/return-await.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    const getOperatorPrecedence_1 = require(1024) /* ../util/getOperatorPrecedence */;
    exports.default = util.createRule({
        name: 'return-await',
        meta: {
            docs: {
                description: 'Enforce consistent returning of awaited values',
                recommended: false,
                requiresTypeChecking: true,
                extendsBaseRule: 'no-return-await',
            },
            fixable: 'code',
            hasSuggestions: true,
            type: 'problem',
            messages: {
                nonPromiseAwait: 'Returning an awaited value that is not a promise is not allowed.',
                disallowedPromiseAwait: 'Returning an awaited promise is not allowed in this context.',
                requiredPromiseAwait: 'Returning an awaited promise is required in this context.',
            },
            schema: [
                {
                    enum: ['in-try-catch', 'always', 'never'],
                },
            ],
        },
        defaultOptions: ['in-try-catch'],
        create(context, [option]) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const sourceCode = context.getSourceCode();
            const scopeInfoStack = [];
            function enterFunction(node) {
                scopeInfoStack.push({
                    hasAsync: node.async,
                    owningFunc: node,
                });
            }
            function exitFunction() {
                scopeInfoStack.pop();
            }
            function inTry(node) {
                let ancestor = node.parent;
                while (ancestor && !ts.isFunctionLike(ancestor)) {
                    if (ts.isTryStatement(ancestor)) {
                        return true;
                    }
                    ancestor = ancestor.parent;
                }
                return false;
            }
            function inCatch(node) {
                let ancestor = node.parent;
                while (ancestor && !ts.isFunctionLike(ancestor)) {
                    if (ts.isCatchClause(ancestor)) {
                        return true;
                    }
                    ancestor = ancestor.parent;
                }
                return false;
            }
            function isReturnPromiseInFinally(node) {
                let ancestor = node.parent;
                while (ancestor && !ts.isFunctionLike(ancestor)) {
                    if (ts.isTryStatement(ancestor.parent) &&
                        ts.isBlock(ancestor) &&
                        ancestor.parent.end === ancestor.end) {
                        return true;
                    }
                    ancestor = ancestor.parent;
                }
                return false;
            }
            function hasFinallyBlock(node) {
                let ancestor = node.parent;
                while (ancestor && !ts.isFunctionLike(ancestor)) {
                    if (ts.isTryStatement(ancestor)) {
                        return !!ancestor.finallyBlock;
                    }
                    ancestor = ancestor.parent;
                }
                return false;
            }
            // function findTokensToRemove()
            function removeAwait(fixer, node) {
                // Should always be an await node; but let's be safe.
                /* istanbul ignore if */ if (!util.isAwaitExpression(node)) {
                    return null;
                }
                const awaitToken = sourceCode.getFirstToken(node, util.isAwaitKeyword);
                // Should always be the case; but let's be safe.
                /* istanbul ignore if */ if (!awaitToken) {
                    return null;
                }
                const startAt = awaitToken.range[0];
                let endAt = awaitToken.range[1];
                // Also remove any extraneous whitespace after `await`, if there is any.
                const nextToken = sourceCode.getTokenAfter(awaitToken, {
                    includeComments: true,
                });
                if (nextToken) {
                    endAt = nextToken.range[0];
                }
                return fixer.removeRange([startAt, endAt]);
            }
            function insertAwait(fixer, node, isHighPrecendence) {
                if (isHighPrecendence) {
                    return fixer.insertTextBefore(node, 'await ');
                }
                else {
                    return [
                        fixer.insertTextBefore(node, 'await ('),
                        fixer.insertTextAfter(node, ')'),
                    ];
                }
            }
            function isHigherPrecedenceThanAwait(node) {
                const operator = (0, tsutils_1.isBinaryExpression)(node)
                    ? node.operatorToken.kind
                    : ts.SyntaxKind.Unknown;
                const nodePrecedence = (0, getOperatorPrecedence_1.getOperatorPrecedence)(node.kind, operator);
                const awaitPrecedence = (0, getOperatorPrecedence_1.getOperatorPrecedence)(ts.SyntaxKind.AwaitExpression, ts.SyntaxKind.Unknown);
                return nodePrecedence > awaitPrecedence;
            }
            function test(node, expression) {
                let child;
                const isAwait = ts.isAwaitExpression(expression);
                if (isAwait) {
                    child = expression.getChildAt(1);
                }
                else {
                    child = expression;
                }
                const type = checker.getTypeAtLocation(child);
                const isThenable = tsutils.isThenableType(checker, expression, type);
                if (!isAwait && !isThenable) {
                    return;
                }
                if (isAwait && !isThenable) {
                    // any/unknown could be thenable; do not auto-fix
                    const useAutoFix = !(util.isTypeAnyType(type) || util.isTypeUnknownType(type));
                    const fix = (fixer) => removeAwait(fixer, node);
                    context.report(Object.assign({ messageId: 'nonPromiseAwait', node }, (useAutoFix
                        ? { fix }
                        : {
                            suggest: [
                                {
                                    messageId: 'nonPromiseAwait',
                                    fix,
                                },
                            ],
                        })));
                    return;
                }
                if (option === 'always') {
                    if (!isAwait && isThenable) {
                        context.report({
                            messageId: 'requiredPromiseAwait',
                            node,
                            fix: fixer => insertAwait(fixer, node, isHigherPrecedenceThanAwait(expression)),
                        });
                    }
                    return;
                }
                if (option === 'never') {
                    if (isAwait) {
                        context.report({
                            messageId: 'disallowedPromiseAwait',
                            node,
                            fix: fixer => removeAwait(fixer, node),
                        });
                    }
                    return;
                }
                if (option === 'in-try-catch') {
                    const isInTryCatch = inTry(expression) || inCatch(expression);
                    if (isAwait && !isInTryCatch) {
                        context.report({
                            messageId: 'disallowedPromiseAwait',
                            node,
                            fix: fixer => removeAwait(fixer, node),
                        });
                    }
                    else if (!isAwait && isInTryCatch) {
                        if (inCatch(expression) && !hasFinallyBlock(expression)) {
                            return;
                        }
                        if (isReturnPromiseInFinally(expression)) {
                            return;
                        }
                        context.report({
                            messageId: 'requiredPromiseAwait',
                            node,
                            fix: fixer => insertAwait(fixer, node, isHigherPrecedenceThanAwait(expression)),
                        });
                    }
                    return;
                }
            }
            function findPossiblyReturnedNodes(node) {
                if (node.type === utils_1.AST_NODE_TYPES.ConditionalExpression) {
                    return [
                        ...findPossiblyReturnedNodes(node.alternate),
                        ...findPossiblyReturnedNodes(node.consequent),
                    ];
                }
                return [node];
            }
            return {
                FunctionDeclaration: enterFunction,
                FunctionExpression: enterFunction,
                ArrowFunctionExpression: enterFunction,
                'FunctionDeclaration:exit': exitFunction,
                'FunctionExpression:exit': exitFunction,
                'ArrowFunctionExpression:exit': exitFunction,
                // executes after less specific handler, so exitFunction is called
                'ArrowFunctionExpression[async = true]:exit'(node) {
                    if (node.body.type !== utils_1.AST_NODE_TYPES.BlockStatement) {
                        findPossiblyReturnedNodes(node.body).forEach(node => {
                            const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                            test(node, tsNode);
                        });
                    }
                },
                ReturnStatement(node) {
                    const scopeInfo = scopeInfoStack[scopeInfoStack.length - 1];
                    if (!(scopeInfo === null || scopeInfo === void 0 ? void 0 : scopeInfo.hasAsync) || !node.argument) {
                        return;
                    }
                    findPossiblyReturnedNodes(node.argument).forEach(node => {
                        const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                        test(node, tsNode);
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/semi.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var _a;
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('semi');
    exports.default = util.createRule({
        name: 'semi',
        meta: {
            type: 'layout',
            docs: {
                description: 'Require or disallow semicolons instead of ASI',
                // too opinionated to be recommended
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'code',
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            // TODO: this rule has only had messages since v7.0 - remove this when we remove support for v6
            messages: (_a = baseRule.meta.messages) !== null && _a !== void 0 ? _a : {
                missingSemi: 'Missing semicolon.',
                extraSemi: 'Extra semicolon.',
            },
        },
        defaultOptions: [
            'always',
            {
                omitLastInOneLineBlock: false,
                beforeStatementContinuationChars: 'any',
            },
        ],
        create(context) {
            const rules = baseRule.create(context);
            const checkForSemicolon = rules.ExpressionStatement;
            /*
              The following nodes are handled by the member-delimiter-style rule
              AST_NODE_TYPES.TSCallSignatureDeclaration,
              AST_NODE_TYPES.TSConstructSignatureDeclaration,
              AST_NODE_TYPES.TSIndexSignature,
              AST_NODE_TYPES.TSMethodSignature,
              AST_NODE_TYPES.TSPropertySignature,
            */
            const nodesToCheck = [
                utils_1.AST_NODE_TYPES.PropertyDefinition,
                utils_1.AST_NODE_TYPES.TSAbstractPropertyDefinition,
                utils_1.AST_NODE_TYPES.TSDeclareFunction,
                utils_1.AST_NODE_TYPES.TSExportAssignment,
                utils_1.AST_NODE_TYPES.TSImportEqualsDeclaration,
                utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration,
                utils_1.AST_NODE_TYPES.TSEmptyBodyFunctionExpression,
            ].reduce((acc, node) => {
                acc[node] = checkForSemicolon;
                return acc;
            }, {});
            return Object.assign(Object.assign(Object.assign({}, rules), nodesToCheck), { ExportDefaultDeclaration(node) {
                    if (node.declaration.type !== utils_1.AST_NODE_TYPES.TSInterfaceDeclaration) {
                        rules.ExportDefaultDeclaration(node);
                    }
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/sort-type-constituents.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    var Group;
    (function (Group) {
        Group["conditional"] = "conditional";
        Group["function"] = "function";
        Group["import"] = "import";
        Group["intersection"] = "intersection";
        Group["keyword"] = "keyword";
        Group["nullish"] = "nullish";
        Group["literal"] = "literal";
        Group["named"] = "named";
        Group["object"] = "object";
        Group["operator"] = "operator";
        Group["tuple"] = "tuple";
        Group["union"] = "union";
    })(Group || (Group = {}));
    function getGroup(node) {
        switch (node.type) {
            case utils_1.AST_NODE_TYPES.TSConditionalType:
                return Group.conditional;
            case utils_1.AST_NODE_TYPES.TSConstructorType:
            case utils_1.AST_NODE_TYPES.TSFunctionType:
                return Group.function;
            case utils_1.AST_NODE_TYPES.TSImportType:
                return Group.import;
            case utils_1.AST_NODE_TYPES.TSIntersectionType:
                return Group.intersection;
            case utils_1.AST_NODE_TYPES.TSAnyKeyword:
            case utils_1.AST_NODE_TYPES.TSBigIntKeyword:
            case utils_1.AST_NODE_TYPES.TSBooleanKeyword:
            case utils_1.AST_NODE_TYPES.TSNeverKeyword:
            case utils_1.AST_NODE_TYPES.TSNumberKeyword:
            case utils_1.AST_NODE_TYPES.TSObjectKeyword:
            case utils_1.AST_NODE_TYPES.TSStringKeyword:
            case utils_1.AST_NODE_TYPES.TSSymbolKeyword:
            case utils_1.AST_NODE_TYPES.TSThisType:
            case utils_1.AST_NODE_TYPES.TSUnknownKeyword:
            case utils_1.AST_NODE_TYPES.TSIntrinsicKeyword:
                return Group.keyword;
            case utils_1.AST_NODE_TYPES.TSNullKeyword:
            case utils_1.AST_NODE_TYPES.TSUndefinedKeyword:
            case utils_1.AST_NODE_TYPES.TSVoidKeyword:
                return Group.nullish;
            case utils_1.AST_NODE_TYPES.TSLiteralType:
            case utils_1.AST_NODE_TYPES.TSTemplateLiteralType:
                return Group.literal;
            case utils_1.AST_NODE_TYPES.TSArrayType:
            case utils_1.AST_NODE_TYPES.TSIndexedAccessType:
            case utils_1.AST_NODE_TYPES.TSInferType:
            case utils_1.AST_NODE_TYPES.TSTypeReference:
            case utils_1.AST_NODE_TYPES.TSQualifiedName:
                return Group.named;
            case utils_1.AST_NODE_TYPES.TSMappedType:
            case utils_1.AST_NODE_TYPES.TSTypeLiteral:
                return Group.object;
            case utils_1.AST_NODE_TYPES.TSTypeOperator:
            case utils_1.AST_NODE_TYPES.TSTypeQuery:
                return Group.operator;
            case utils_1.AST_NODE_TYPES.TSTupleType:
                return Group.tuple;
            case utils_1.AST_NODE_TYPES.TSUnionType:
                return Group.union;
            // These types should never occur as part of a union/intersection
            case utils_1.AST_NODE_TYPES.TSAbstractKeyword:
            case utils_1.AST_NODE_TYPES.TSAsyncKeyword:
            case utils_1.AST_NODE_TYPES.TSDeclareKeyword:
            case utils_1.AST_NODE_TYPES.TSExportKeyword:
            case utils_1.AST_NODE_TYPES.TSNamedTupleMember:
            case utils_1.AST_NODE_TYPES.TSOptionalType:
            case utils_1.AST_NODE_TYPES.TSPrivateKeyword:
            case utils_1.AST_NODE_TYPES.TSProtectedKeyword:
            case utils_1.AST_NODE_TYPES.TSPublicKeyword:
            case utils_1.AST_NODE_TYPES.TSReadonlyKeyword:
            case utils_1.AST_NODE_TYPES.TSRestType:
            case utils_1.AST_NODE_TYPES.TSStaticKeyword:
            case utils_1.AST_NODE_TYPES.TSTypePredicate:
                /* istanbul ignore next */
                throw new Error(`Unexpected Type ${node.type}`);
        }
    }
    exports.default = util.createRule({
        name: 'sort-type-constituents',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Enforce constituents of a type union/intersection to be sorted alphabetically',
                recommended: false,
            },
            fixable: 'code',
            hasSuggestions: true,
            messages: {
                notSorted: '{{type}} type constituents must be sorted.',
                notSortedNamed: '{{type}} type {{name}} constituents must be sorted.',
                suggestFix: 'Sort constituents of type (removes all comments).',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        checkIntersections: {
                            description: 'Whether to check intersection types.',
                            type: 'boolean',
                        },
                        checkUnions: {
                            description: 'Whether to check union types.',
                            type: 'boolean',
                        },
                        groupOrder: {
                            description: 'Ordering of the groups.',
                            type: 'array',
                            items: {
                                type: 'string',
                                enum: (0, util_1.getEnumNames)(Group),
                            },
                        },
                    },
                },
            ],
        },
        defaultOptions: [
            {
                checkIntersections: true,
                checkUnions: true,
                groupOrder: [
                    Group.named,
                    Group.keyword,
                    Group.operator,
                    Group.literal,
                    Group.function,
                    Group.import,
                    Group.conditional,
                    Group.object,
                    Group.tuple,
                    Group.intersection,
                    Group.union,
                    Group.nullish,
                ],
            },
        ],
        create(context, [{ checkIntersections, checkUnions, groupOrder }]) {
            const sourceCode = context.getSourceCode();
            const collator = new Intl.Collator('en', {
                sensitivity: 'base',
                numeric: true,
            });
            function checkSorting(node) {
                var _a;
                const sourceOrder = node.types.map(type => {
                    var _a;
                    const group = (_a = groupOrder === null || groupOrder === void 0 ? void 0 : groupOrder.indexOf(getGroup(type))) !== null && _a !== void 0 ? _a : -1;
                    return {
                        group: group === -1 ? Number.MAX_SAFE_INTEGER : group,
                        node: type,
                        text: sourceCode.getText(type),
                    };
                });
                const expectedOrder = [...sourceOrder].sort((a, b) => {
                    if (a.group !== b.group) {
                        return a.group - b.group;
                    }
                    return (collator.compare(a.text, b.text) ||
                        (a.text < b.text ? -1 : a.text > b.text ? 1 : 0));
                });
                const hasComments = node.types.some(type => {
                    const count = sourceCode.getCommentsBefore(type).length +
                        sourceCode.getCommentsAfter(type).length;
                    return count > 0;
                });
                for (let i = 0; i < expectedOrder.length; i += 1) {
                    if (expectedOrder[i].node !== sourceOrder[i].node) {
                        let messageId = 'notSorted';
                        const data = {
                            name: '',
                            type: node.type === utils_1.AST_NODE_TYPES.TSIntersectionType
                                ? 'Intersection'
                                : 'Union',
                        };
                        if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration) {
                            messageId = 'notSortedNamed';
                            data.name = node.parent.id.name;
                        }
                        const fix = fixer => {
                            const sorted = expectedOrder
                                .map(t => (0, util_1.typeNodeRequiresParentheses)(t.node, t.text) ||
                                (node.type === utils_1.AST_NODE_TYPES.TSIntersectionType &&
                                    t.node.type === utils_1.AST_NODE_TYPES.TSUnionType)
                                ? `(${t.text})`
                                : t.text)
                                .join(node.type === utils_1.AST_NODE_TYPES.TSIntersectionType ? ' & ' : ' | ');
                            return fixer.replaceText(node, sorted);
                        };
                        return context.report(Object.assign({ node,
                            messageId,
                            data }, (hasComments
                            ? {
                                suggest: [
                                    {
                                        messageId: 'suggestFix',
                                        fix,
                                    },
                                ],
                            }
                            : { fix })));
                    }
                }
            }
            return Object.assign(Object.assign({}, (checkIntersections && {
                TSIntersectionType(node) {
                    checkSorting(node);
                },
            })), (checkUnions && {
                TSUnionType(node) {
                    checkSorting(node);
                },
            }));
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/sort-type-union-intersection-members.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    var Group;
    (function (Group) {
        Group["conditional"] = "conditional";
        Group["function"] = "function";
        Group["import"] = "import";
        Group["intersection"] = "intersection";
        Group["keyword"] = "keyword";
        Group["nullish"] = "nullish";
        Group["literal"] = "literal";
        Group["named"] = "named";
        Group["object"] = "object";
        Group["operator"] = "operator";
        Group["tuple"] = "tuple";
        Group["union"] = "union";
    })(Group || (Group = {}));
    function getGroup(node) {
        switch (node.type) {
            case utils_1.AST_NODE_TYPES.TSConditionalType:
                return Group.conditional;
            case utils_1.AST_NODE_TYPES.TSConstructorType:
            case utils_1.AST_NODE_TYPES.TSFunctionType:
                return Group.function;
            case utils_1.AST_NODE_TYPES.TSImportType:
                return Group.import;
            case utils_1.AST_NODE_TYPES.TSIntersectionType:
                return Group.intersection;
            case utils_1.AST_NODE_TYPES.TSAnyKeyword:
            case utils_1.AST_NODE_TYPES.TSBigIntKeyword:
            case utils_1.AST_NODE_TYPES.TSBooleanKeyword:
            case utils_1.AST_NODE_TYPES.TSNeverKeyword:
            case utils_1.AST_NODE_TYPES.TSNumberKeyword:
            case utils_1.AST_NODE_TYPES.TSObjectKeyword:
            case utils_1.AST_NODE_TYPES.TSStringKeyword:
            case utils_1.AST_NODE_TYPES.TSSymbolKeyword:
            case utils_1.AST_NODE_TYPES.TSThisType:
            case utils_1.AST_NODE_TYPES.TSUnknownKeyword:
            case utils_1.AST_NODE_TYPES.TSIntrinsicKeyword:
                return Group.keyword;
            case utils_1.AST_NODE_TYPES.TSNullKeyword:
            case utils_1.AST_NODE_TYPES.TSUndefinedKeyword:
            case utils_1.AST_NODE_TYPES.TSVoidKeyword:
                return Group.nullish;
            case utils_1.AST_NODE_TYPES.TSLiteralType:
            case utils_1.AST_NODE_TYPES.TSTemplateLiteralType:
                return Group.literal;
            case utils_1.AST_NODE_TYPES.TSArrayType:
            case utils_1.AST_NODE_TYPES.TSIndexedAccessType:
            case utils_1.AST_NODE_TYPES.TSInferType:
            case utils_1.AST_NODE_TYPES.TSTypeReference:
            case utils_1.AST_NODE_TYPES.TSQualifiedName:
                return Group.named;
            case utils_1.AST_NODE_TYPES.TSMappedType:
            case utils_1.AST_NODE_TYPES.TSTypeLiteral:
                return Group.object;
            case utils_1.AST_NODE_TYPES.TSTypeOperator:
            case utils_1.AST_NODE_TYPES.TSTypeQuery:
                return Group.operator;
            case utils_1.AST_NODE_TYPES.TSTupleType:
                return Group.tuple;
            case utils_1.AST_NODE_TYPES.TSUnionType:
                return Group.union;
            // These types should never occur as part of a union/intersection
            case utils_1.AST_NODE_TYPES.TSAbstractKeyword:
            case utils_1.AST_NODE_TYPES.TSAsyncKeyword:
            case utils_1.AST_NODE_TYPES.TSDeclareKeyword:
            case utils_1.AST_NODE_TYPES.TSExportKeyword:
            case utils_1.AST_NODE_TYPES.TSNamedTupleMember:
            case utils_1.AST_NODE_TYPES.TSOptionalType:
            case utils_1.AST_NODE_TYPES.TSPrivateKeyword:
            case utils_1.AST_NODE_TYPES.TSProtectedKeyword:
            case utils_1.AST_NODE_TYPES.TSPublicKeyword:
            case utils_1.AST_NODE_TYPES.TSReadonlyKeyword:
            case utils_1.AST_NODE_TYPES.TSRestType:
            case utils_1.AST_NODE_TYPES.TSStaticKeyword:
            case utils_1.AST_NODE_TYPES.TSTypePredicate:
                /* istanbul ignore next */
                throw new Error(`Unexpected Type ${node.type}`);
        }
    }
    exports.default = util.createRule({
        name: 'sort-type-union-intersection-members',
        meta: {
            deprecated: true,
            type: 'suggestion',
            docs: {
                description: 'Enforce members of a type union/intersection to be sorted alphabetically',
                recommended: false,
            },
            fixable: 'code',
            hasSuggestions: true,
            messages: {
                notSorted: '{{type}} type members must be sorted.',
                notSortedNamed: '{{type}} type {{name}} members must be sorted.',
                suggestFix: 'Sort members of type (removes all comments).',
            },
            replacedBy: ['@typescript-eslint/sort-type-constituents'],
            schema: [
                {
                    type: 'object',
                    properties: {
                        checkIntersections: {
                            description: 'Whether to check intersection types.',
                            type: 'boolean',
                        },
                        checkUnions: {
                            description: 'Whether to check union types.',
                            type: 'boolean',
                        },
                        groupOrder: {
                            description: 'Ordering of the groups.',
                            type: 'array',
                            items: {
                                type: 'string',
                                enum: (0, util_1.getEnumNames)(Group),
                            },
                        },
                    },
                },
            ],
        },
        defaultOptions: [
            {
                checkIntersections: true,
                checkUnions: true,
                groupOrder: [
                    Group.named,
                    Group.keyword,
                    Group.operator,
                    Group.literal,
                    Group.function,
                    Group.import,
                    Group.conditional,
                    Group.object,
                    Group.tuple,
                    Group.intersection,
                    Group.union,
                    Group.nullish,
                ],
            },
        ],
        create(context, [{ checkIntersections, checkUnions, groupOrder }]) {
            const sourceCode = context.getSourceCode();
            const collator = new Intl.Collator('en', {
                sensitivity: 'base',
                numeric: true,
            });
            function checkSorting(node) {
                var _a;
                const sourceOrder = node.types.map(type => {
                    var _a;
                    const group = (_a = groupOrder === null || groupOrder === void 0 ? void 0 : groupOrder.indexOf(getGroup(type))) !== null && _a !== void 0 ? _a : -1;
                    return {
                        group: group === -1 ? Number.MAX_SAFE_INTEGER : group,
                        node: type,
                        text: sourceCode.getText(type),
                    };
                });
                const expectedOrder = [...sourceOrder].sort((a, b) => {
                    if (a.group !== b.group) {
                        return a.group - b.group;
                    }
                    return (collator.compare(a.text, b.text) ||
                        (a.text < b.text ? -1 : a.text > b.text ? 1 : 0));
                });
                const hasComments = node.types.some(type => {
                    const count = sourceCode.getCommentsBefore(type).length +
                        sourceCode.getCommentsAfter(type).length;
                    return count > 0;
                });
                for (let i = 0; i < expectedOrder.length; i += 1) {
                    if (expectedOrder[i].node !== sourceOrder[i].node) {
                        let messageId = 'notSorted';
                        const data = {
                            name: '',
                            type: node.type === utils_1.AST_NODE_TYPES.TSIntersectionType
                                ? 'Intersection'
                                : 'Union',
                        };
                        if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.TSTypeAliasDeclaration) {
                            messageId = 'notSortedNamed';
                            data.name = node.parent.id.name;
                        }
                        const fix = fixer => {
                            const sorted = expectedOrder
                                .map(t => (0, util_1.typeNodeRequiresParentheses)(t.node, t.text) ||
                                (node.type === utils_1.AST_NODE_TYPES.TSIntersectionType &&
                                    t.node.type === utils_1.AST_NODE_TYPES.TSUnionType)
                                ? `(${t.text})`
                                : t.text)
                                .join(node.type === utils_1.AST_NODE_TYPES.TSIntersectionType ? ' & ' : ' | ');
                            return fixer.replaceText(node, sorted);
                        };
                        return context.report(Object.assign({ node,
                            messageId,
                            data }, (hasComments
                            ? {
                                suggest: [
                                    {
                                        messageId: 'suggestFix',
                                        fix,
                                    },
                                ],
                            }
                            : { fix })));
                    }
                }
            }
            return Object.assign(Object.assign({}, (checkIntersections && {
                TSIntersectionType(node) {
                    checkSorting(node);
                },
            })), (checkUnions && {
                TSUnionType(node) {
                    checkSorting(node);
                },
            }));
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/space-before-blocks.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('space-before-blocks');
    exports.default = util.createRule({
        name: 'space-before-blocks',
        meta: {
            type: 'layout',
            docs: {
                description: 'Enforce consistent spacing before blocks',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: baseRule.meta.fixable,
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            messages: Object.assign({
                // @ts-expect-error -- we report on this messageId so we need to ensure it's there in case ESLint changes in future
                unexpectedSpace: 'Unexpected space before opening brace.',
                // @ts-expect-error -- we report on this messageId so we need to ensure it's there in case ESLint changes in future
                missingSpace: 'Missing space before opening brace.'
            }, baseRule.meta.messages),
        },
        defaultOptions: ['always'],
        create(context, [config]) {
            const rules = baseRule.create(context);
            const sourceCode = context.getSourceCode();
            let requireSpace = true;
            if (typeof config === 'object') {
                requireSpace = config.classes === 'always';
            }
            else if (config === 'never') {
                requireSpace = false;
            }
            function checkPrecedingSpace(node) {
                const precedingToken = sourceCode.getTokenBefore(node);
                if (precedingToken && util.isTokenOnSameLine(precedingToken, node)) {
                    // eslint-disable-next-line deprecation/deprecation -- TODO - switch once our min ESLint version is 6.7.0
                    const hasSpace = sourceCode.isSpaceBetweenTokens(precedingToken, node);
                    if (requireSpace && !hasSpace) {
                        context.report({
                            node,
                            messageId: 'missingSpace',
                            fix(fixer) {
                                return fixer.insertTextBefore(node, ' ');
                            },
                        });
                    }
                    else if (!requireSpace && hasSpace) {
                        context.report({
                            node,
                            messageId: 'unexpectedSpace',
                            fix(fixer) {
                                return fixer.removeRange([
                                    precedingToken.range[1],
                                    node.range[0],
                                ]);
                            },
                        });
                    }
                }
            }
            function checkSpaceAfterEnum(node) {
                const punctuator = sourceCode.getTokenAfter(node.id);
                if (punctuator) {
                    checkPrecedingSpace(punctuator);
                }
            }
            return Object.assign(Object.assign({}, rules), { TSEnumDeclaration: checkSpaceAfterEnum, TSInterfaceBody: checkPrecedingSpace });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/space-before-function-paren.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'space-before-function-paren',
        meta: {
            type: 'layout',
            docs: {
                description: 'Enforce consistent spacing before function parenthesis',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: 'whitespace',
            schema: [
                {
                    oneOf: [
                        {
                            enum: ['always', 'never'],
                        },
                        {
                            type: 'object',
                            properties: {
                                anonymous: {
                                    enum: ['always', 'never', 'ignore'],
                                },
                                named: {
                                    enum: ['always', 'never', 'ignore'],
                                },
                                asyncArrow: {
                                    enum: ['always', 'never', 'ignore'],
                                },
                            },
                            additionalProperties: false,
                        },
                    ],
                },
            ],
            messages: {
                unexpected: 'Unexpected space before function parentheses.',
                missing: 'Missing space before function parentheses.',
            },
        },
        defaultOptions: ['always'],
        create(context, [firstOption]) {
            const sourceCode = context.getSourceCode();
            const baseConfig = typeof firstOption === 'string' ? firstOption : 'always';
            const overrideConfig = typeof firstOption === 'object' ? firstOption : {};
            /**
             * Determines whether a function has a name.
             * @param {ASTNode} node The function node.
             * @returns {boolean} Whether the function has a name.
             */
            function isNamedFunction(node) {
                if (node.id != null) {
                    return true;
                }
                const parent = node.parent;
                return (parent.type === utils_1.AST_NODE_TYPES.MethodDefinition ||
                    parent.type === utils_1.AST_NODE_TYPES.TSAbstractMethodDefinition ||
                    (parent.type === utils_1.AST_NODE_TYPES.Property &&
                        (parent.kind === 'get' || parent.kind === 'set' || parent.method)));
            }
            /**
             * Gets the config for a given function
             * @param {ASTNode} node The function node
             * @returns {string} "always", "never", or "ignore"
             */
            function getConfigForFunction(node) {
                var _a, _b, _c;
                if (node.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression) {
                    // Always ignore non-async functions and arrow functions without parens, e.g. async foo => bar
                    if (node.async &&
                        util.isOpeningParenToken(sourceCode.getFirstToken(node, { skip: 1 }))) {
                        return (_a = overrideConfig.asyncArrow) !== null && _a !== void 0 ? _a : baseConfig;
                    }
                }
                else if (isNamedFunction(node)) {
                    return (_b = overrideConfig.named) !== null && _b !== void 0 ? _b : baseConfig;
                    // `generator-star-spacing` should warn anonymous generators. E.g. `function* () {}`
                }
                else if (!node.generator) {
                    return (_c = overrideConfig.anonymous) !== null && _c !== void 0 ? _c : baseConfig;
                }
                return 'ignore';
            }
            /**
             * Checks the parens of a function node
             * @param {ASTNode} node A function node
             * @returns {void}
             */
            function checkFunction(node) {
                const functionConfig = getConfigForFunction(node);
                if (functionConfig === 'ignore') {
                    return;
                }
                let leftToken;
                let rightToken;
                if (node.typeParameters) {
                    leftToken = sourceCode.getLastToken(node.typeParameters);
                    rightToken = sourceCode.getTokenAfter(leftToken);
                }
                else {
                    rightToken = sourceCode.getFirstToken(node, util.isOpeningParenToken);
                    leftToken = sourceCode.getTokenBefore(rightToken);
                }
                // eslint-disable-next-line deprecation/deprecation -- TODO - switch once our min ESLint version is 6.7.0
                const hasSpacing = sourceCode.isSpaceBetweenTokens(leftToken, rightToken);
                if (hasSpacing && functionConfig === 'never') {
                    context.report({
                        node,
                        loc: {
                            start: leftToken.loc.end,
                            end: rightToken.loc.start,
                        },
                        messageId: 'unexpected',
                        fix: fixer => fixer.removeRange([leftToken.range[1], rightToken.range[0]]),
                    });
                }
                else if (!hasSpacing &&
                    functionConfig === 'always' &&
                    (!node.typeParameters || node.id)) {
                    context.report({
                        node,
                        loc: rightToken.loc,
                        messageId: 'missing',
                        fix: fixer => fixer.insertTextAfter(leftToken, ' '),
                    });
                }
            }
            return {
                ArrowFunctionExpression: checkFunction,
                FunctionDeclaration: checkFunction,
                FunctionExpression: checkFunction,
                TSEmptyBodyFunctionExpression: checkFunction,
                TSDeclareFunction: checkFunction,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/space-infix-ops.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    const getESLintCoreRule_1 = require(1155) /* ../util/getESLintCoreRule */;
    const baseRule = (0, getESLintCoreRule_1.getESLintCoreRule)('space-infix-ops');
    const UNIONS = ['|', '&'];
    exports.default = util.createRule({
        name: 'space-infix-ops',
        meta: {
            type: 'layout',
            docs: {
                description: 'Require spacing around infix operators',
                recommended: false,
                extendsBaseRule: true,
            },
            fixable: baseRule.meta.fixable,
            hasSuggestions: baseRule.meta.hasSuggestions,
            schema: baseRule.meta.schema,
            messages: Object.assign({
                // @ts-expect-error -- we report on this messageId so we need to ensure it's there in case ESLint changes in future
                missingSpace: "Operator '{{operator}}' must be spaced."
            }, baseRule.meta.messages),
        },
        defaultOptions: [
            {
                int32Hint: false,
            },
        ],
        create(context) {
            const rules = baseRule.create(context);
            const sourceCode = context.getSourceCode();
            function report(operator) {
                context.report({
                    node: operator,
                    messageId: 'missingSpace',
                    data: {
                        operator: operator.value,
                    },
                    fix(fixer) {
                        const previousToken = sourceCode.getTokenBefore(operator);
                        const afterToken = sourceCode.getTokenAfter(operator);
                        let fixString = '';
                        if (operator.range[0] - previousToken.range[1] === 0) {
                            fixString = ' ';
                        }
                        fixString += operator.value;
                        if (afterToken.range[0] - operator.range[1] === 0) {
                            fixString += ' ';
                        }
                        return fixer.replaceText(operator, fixString);
                    },
                });
            }
            function isSpaceChar(token) {
                return (token.type === utils_1.AST_TOKEN_TYPES.Punctuator && /^[=?:]$/.test(token.value));
            }
            function checkAndReportAssignmentSpace(leftNode, rightNode) {
                if (!rightNode || !leftNode) {
                    return;
                }
                const operator = sourceCode.getFirstTokenBetween(leftNode, rightNode, isSpaceChar);
                const prev = sourceCode.getTokenBefore(operator);
                const next = sourceCode.getTokenAfter(operator);
                if (!sourceCode.isSpaceBetween(prev, operator) ||
                    !sourceCode.isSpaceBetween(operator, next)) {
                    report(operator);
                }
            }
            /**
             * Check if it has an assignment char and report if it's faulty
             * @param node The node to report
             */
            function checkForEnumAssignmentSpace(node) {
                checkAndReportAssignmentSpace(node.id, node.initializer);
            }
            /**
             * Check if it has an assignment char and report if it's faulty
             * @param node The node to report
             */
            function checkForPropertyDefinitionAssignmentSpace(node) {
                var _a;
                const leftNode = node.optional && !node.typeAnnotation
                    ? sourceCode.getTokenAfter(node.key)
                    : (_a = node.typeAnnotation) !== null && _a !== void 0 ? _a : node.key;
                checkAndReportAssignmentSpace(leftNode, node.value);
            }
            /**
             * Check if it is missing spaces between type annotations chaining
             * @param typeAnnotation TypeAnnotations list
             */
            function checkForTypeAnnotationSpace(typeAnnotation) {
                const types = typeAnnotation.types;
                types.forEach(type => {
                    const skipFunctionParenthesis = type.type === utils_1.TSESTree.AST_NODE_TYPES.TSFunctionType
                        ? util.isNotOpeningParenToken
                        : 0;
                    const operator = sourceCode.getTokenBefore(type, skipFunctionParenthesis);
                    if (operator != null && UNIONS.includes(operator.value)) {
                        const prev = sourceCode.getTokenBefore(operator);
                        const next = sourceCode.getTokenAfter(operator);
                        if (!sourceCode.isSpaceBetween(prev, operator) ||
                            !sourceCode.isSpaceBetween(operator, next)) {
                            report(operator);
                        }
                    }
                });
            }
            /**
             * Check if it has an assignment char and report if it's faulty
             * @param node The node to report
             */
            function checkForTypeAliasAssignment(node) {
                var _a;
                checkAndReportAssignmentSpace((_a = node.typeParameters) !== null && _a !== void 0 ? _a : node.id, node.typeAnnotation);
            }
            function checkForTypeConditional(node) {
                checkAndReportAssignmentSpace(node.extendsType, node.trueType);
                checkAndReportAssignmentSpace(node.trueType, node.falseType);
            }
            return Object.assign(Object.assign({}, rules), { TSEnumMember: checkForEnumAssignmentSpace, PropertyDefinition: checkForPropertyDefinitionAssignmentSpace, TSTypeAliasDeclaration: checkForTypeAliasAssignment, TSUnionType: checkForTypeAnnotationSpace, TSIntersectionType: checkForTypeAnnotationSpace, TSConditionalType: checkForTypeConditional });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/strict-boolean-expressions.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'strict-boolean-expressions',
        meta: {
            type: 'suggestion',
            fixable: 'code',
            hasSuggestions: true,
            docs: {
                description: 'Disallow certain types in boolean expressions',
                recommended: false,
                requiresTypeChecking: true,
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        allowString: { type: 'boolean' },
                        allowNumber: { type: 'boolean' },
                        allowNullableObject: { type: 'boolean' },
                        allowNullableBoolean: { type: 'boolean' },
                        allowNullableString: { type: 'boolean' },
                        allowNullableNumber: { type: 'boolean' },
                        allowNullableEnum: { type: 'boolean' },
                        allowAny: { type: 'boolean' },
                        allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing: {
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
            messages: {
                conditionErrorOther: 'Unexpected value in conditional. ' +
                    'A boolean expression is required.',
                conditionErrorAny: 'Unexpected any value in conditional. ' +
                    'An explicit comparison or type cast is required.',
                conditionErrorNullish: 'Unexpected nullish value in conditional. ' +
                    'The condition is always false.',
                conditionErrorNullableBoolean: 'Unexpected nullable boolean value in conditional. ' +
                    'Please handle the nullish case explicitly.',
                conditionErrorString: 'Unexpected string value in conditional. ' +
                    'An explicit empty string check is required.',
                conditionErrorNullableString: 'Unexpected nullable string value in conditional. ' +
                    'Please handle the nullish/empty cases explicitly.',
                conditionErrorNumber: 'Unexpected number value in conditional. ' +
                    'An explicit zero/NaN check is required.',
                conditionErrorNullableNumber: 'Unexpected nullable number value in conditional. ' +
                    'Please handle the nullish/zero/NaN cases explicitly.',
                conditionErrorObject: 'Unexpected object value in conditional. ' +
                    'The condition is always true.',
                conditionErrorNullableObject: 'Unexpected nullable object value in conditional. ' +
                    'An explicit null check is required.',
                conditionErrorNullableEnum: 'Unexpected nullable enum value in conditional. ' +
                    'Please handle the nullish/zero/NaN cases explicitly.',
                noStrictNullCheck: 'This rule requires the `strictNullChecks` compiler option to be turned on to function correctly.',
                conditionFixDefaultFalse: 'Explicitly treat nullish value the same as false (`value ?? false`)',
                conditionFixDefaultEmptyString: 'Explicitly treat nullish value the same as an empty string (`value ?? ""`)',
                conditionFixDefaultZero: 'Explicitly treat nullish value the same as 0 (`value ?? 0`)',
                conditionFixCompareNullish: 'Change condition to check for null/undefined (`value != null`)',
                conditionFixCastBoolean: 'Explicitly cast value to a boolean (`Boolean(value)`)',
                conditionFixCompareTrue: 'Change condition to check if true (`value === true`)',
                conditionFixCompareFalse: 'Change condition to check if false (`value === false`)',
                conditionFixCompareStringLength: "Change condition to check string's length (`value.length !== 0`)",
                conditionFixCompareEmptyString: 'Change condition to check for empty string (`value !== ""`)',
                conditionFixCompareZero: 'Change condition to check for 0 (`value !== 0`)',
                conditionFixCompareNaN: 'Change condition to check for NaN (`!Number.isNaN(value)`)',
            },
        },
        defaultOptions: [
            {
                allowString: true,
                allowNumber: true,
                allowNullableObject: true,
                allowNullableBoolean: false,
                allowNullableString: false,
                allowNullableNumber: false,
                allowNullableEnum: true,
                allowAny: false,
                allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing: false,
            },
        ],
        create(context, [options]) {
            const parserServices = util.getParserServices(context);
            const typeChecker = parserServices.program.getTypeChecker();
            const compilerOptions = parserServices.program.getCompilerOptions();
            const sourceCode = context.getSourceCode();
            const isStrictNullChecks = tsutils.isStrictCompilerOptionEnabled(compilerOptions, 'strictNullChecks');
            if (!isStrictNullChecks &&
                options.allowRuleToRunWithoutStrictNullChecksIKnowWhatIAmDoing !== true) {
                context.report({
                    loc: {
                        start: { line: 0, column: 0 },
                        end: { line: 0, column: 0 },
                    },
                    messageId: 'noStrictNullCheck',
                });
            }
            const traversedNodes = new Set();
            return {
                ConditionalExpression: traverseTestExpression,
                DoWhileStatement: traverseTestExpression,
                ForStatement: traverseTestExpression,
                IfStatement: traverseTestExpression,
                WhileStatement: traverseTestExpression,
                'LogicalExpression[operator!="??"]': traverseLogicalExpression,
                'UnaryExpression[operator="!"]': traverseUnaryLogicalExpression,
            };
            /**
             * Inspects condition of a test expression. (`if`, `while`, `for`, etc.)
             */
            function traverseTestExpression(node) {
                if (node.test == null) {
                    return;
                }
                traverseNode(node.test, true);
            }
            /**
             * Inspects the argument of a unary logical expression (`!`).
             */
            function traverseUnaryLogicalExpression(node) {
                traverseNode(node.argument, true);
            }
            /**
             * Inspects the arguments of a logical expression (`&&`, `||`).
             *
             * If the logical expression is a descendant of a test expression,
             * the `isCondition` flag should be set to true.
             * Otherwise, if the logical expression is there on it's own,
             * it's used for control flow and is not a condition itself.
             */
            function traverseLogicalExpression(node, isCondition = false) {
                // left argument is always treated as a condition
                traverseNode(node.left, true);
                // if the logical expression is used for control flow,
                // then it's right argument is used for it's side effects only
                traverseNode(node.right, isCondition);
            }
            /**
             * Inspects any node.
             *
             * If it's a logical expression then it recursively traverses its arguments.
             * If it's any other kind of node then it's type is finally checked against the rule,
             * unless `isCondition` flag is set to false, in which case
             * it's assumed to be used for side effects only and is skipped.
             */
            function traverseNode(node, isCondition) {
                // prevent checking the same node multiple times
                if (traversedNodes.has(node)) {
                    return;
                }
                traversedNodes.add(node);
                // for logical operator, we check its operands
                if (node.type === utils_1.AST_NODE_TYPES.LogicalExpression &&
                    node.operator !== '??') {
                    traverseLogicalExpression(node, isCondition);
                    return;
                }
                // skip if node is not a condition
                if (!isCondition) {
                    return;
                }
                checkNode(node);
            }
            /**
             * This function does the actual type check on a node.
             * It analyzes the type of a node and checks if it is allowed in a boolean context.
             */
            function checkNode(node) {
                const tsNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                const type = util.getConstrainedTypeAtLocation(typeChecker, tsNode);
                const types = inspectVariantTypes(tsutils.unionTypeParts(type));
                const is = (...wantedTypes) => types.size === wantedTypes.length &&
                    wantedTypes.every(type => types.has(type));
                // boolean
                if (is('boolean') || is('truthy boolean')) {
                    // boolean is always okay
                    return;
                }
                // never
                if (is('never')) {
                    // never is always okay
                    return;
                }
                // nullish
                if (is('nullish')) {
                    // condition is always false
                    context.report({ node, messageId: 'conditionErrorNullish' });
                    return;
                }
                // Known edge case: boolean `true` and nullish values are always valid boolean expressions
                if (is('nullish', 'truthy boolean')) {
                    return;
                }
                // nullable boolean
                if (is('nullish', 'boolean')) {
                    if (!options.allowNullableBoolean) {
                        if (isLogicalNegationExpression(node.parent)) {
                            // if (!nullableBoolean)
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableBoolean',
                                suggest: [
                                    {
                                        messageId: 'conditionFixDefaultFalse',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} ?? false`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCompareFalse',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `${code} === false`,
                                        }),
                                    },
                                ],
                            });
                        }
                        else {
                            // if (nullableBoolean)
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableBoolean',
                                suggest: [
                                    {
                                        messageId: 'conditionFixDefaultFalse',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} ?? false`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCompareTrue',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} === true`,
                                        }),
                                    },
                                ],
                            });
                        }
                    }
                    return;
                }
                // Known edge case: truthy primitives and nullish values are always valid boolean expressions
                if ((options.allowNumber && is('nullish', 'truthy number')) ||
                    (options.allowString && is('nullish', 'truthy string'))) {
                    return;
                }
                // string
                if (is('string') || is('truthy string')) {
                    if (!options.allowString) {
                        if (isLogicalNegationExpression(node.parent)) {
                            // if (!string)
                            context.report({
                                node,
                                messageId: 'conditionErrorString',
                                suggest: [
                                    {
                                        messageId: 'conditionFixCompareStringLength',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `${code}.length === 0`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCompareEmptyString',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `${code} === ""`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCastBoolean',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `!Boolean(${code})`,
                                        }),
                                    },
                                ],
                            });
                        }
                        else {
                            // if (string)
                            context.report({
                                node,
                                messageId: 'conditionErrorString',
                                suggest: [
                                    {
                                        messageId: 'conditionFixCompareStringLength',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code}.length > 0`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCompareEmptyString',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} !== ""`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCastBoolean',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `Boolean(${code})`,
                                        }),
                                    },
                                ],
                            });
                        }
                    }
                    return;
                }
                // nullable string
                if (is('nullish', 'string')) {
                    if (!options.allowNullableString) {
                        if (isLogicalNegationExpression(node.parent)) {
                            // if (!nullableString)
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableString',
                                suggest: [
                                    {
                                        messageId: 'conditionFixCompareNullish',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `${code} == null`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixDefaultEmptyString',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} ?? ""`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCastBoolean',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `!Boolean(${code})`,
                                        }),
                                    },
                                ],
                            });
                        }
                        else {
                            // if (nullableString)
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableString',
                                suggest: [
                                    {
                                        messageId: 'conditionFixCompareNullish',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} != null`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixDefaultEmptyString',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} ?? ""`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCastBoolean',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `Boolean(${code})`,
                                        }),
                                    },
                                ],
                            });
                        }
                    }
                    return;
                }
                // number
                if (is('number') || is('truthy number')) {
                    if (!options.allowNumber) {
                        if (isArrayLengthExpression(node, typeChecker, parserServices)) {
                            if (isLogicalNegationExpression(node.parent)) {
                                // if (!array.length)
                                context.report({
                                    node,
                                    messageId: 'conditionErrorNumber',
                                    fix: util.getWrappingFixer({
                                        sourceCode,
                                        node: node.parent,
                                        innerNode: node,
                                        wrap: code => `${code} === 0`,
                                    }),
                                });
                            }
                            else {
                                // if (array.length)
                                context.report({
                                    node,
                                    messageId: 'conditionErrorNumber',
                                    fix: util.getWrappingFixer({
                                        sourceCode,
                                        node,
                                        wrap: code => `${code} > 0`,
                                    }),
                                });
                            }
                        }
                        else if (isLogicalNegationExpression(node.parent)) {
                            // if (!number)
                            context.report({
                                node,
                                messageId: 'conditionErrorNumber',
                                suggest: [
                                    {
                                        messageId: 'conditionFixCompareZero',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            // TODO: we have to compare to 0n if the type is bigint
                                            wrap: code => `${code} === 0`,
                                        }),
                                    },
                                    {
                                        // TODO: don't suggest this for bigint because it can't be NaN
                                        messageId: 'conditionFixCompareNaN',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `Number.isNaN(${code})`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCastBoolean',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `!Boolean(${code})`,
                                        }),
                                    },
                                ],
                            });
                        }
                        else {
                            // if (number)
                            context.report({
                                node,
                                messageId: 'conditionErrorNumber',
                                suggest: [
                                    {
                                        messageId: 'conditionFixCompareZero',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} !== 0`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCompareNaN',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `!Number.isNaN(${code})`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCastBoolean',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `Boolean(${code})`,
                                        }),
                                    },
                                ],
                            });
                        }
                    }
                    return;
                }
                // nullable number
                if (is('nullish', 'number')) {
                    if (!options.allowNullableNumber) {
                        if (isLogicalNegationExpression(node.parent)) {
                            // if (!nullableNumber)
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableNumber',
                                suggest: [
                                    {
                                        messageId: 'conditionFixCompareNullish',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `${code} == null`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixDefaultZero',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} ?? 0`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCastBoolean',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node: node.parent,
                                            innerNode: node,
                                            wrap: code => `!Boolean(${code})`,
                                        }),
                                    },
                                ],
                            });
                        }
                        else {
                            // if (nullableNumber)
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableNumber',
                                suggest: [
                                    {
                                        messageId: 'conditionFixCompareNullish',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} != null`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixDefaultZero',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `${code} ?? 0`,
                                        }),
                                    },
                                    {
                                        messageId: 'conditionFixCastBoolean',
                                        fix: util.getWrappingFixer({
                                            sourceCode,
                                            node,
                                            wrap: code => `Boolean(${code})`,
                                        }),
                                    },
                                ],
                            });
                        }
                    }
                    return;
                }
                // object
                if (is('object')) {
                    // condition is always true
                    context.report({ node, messageId: 'conditionErrorObject' });
                    return;
                }
                // nullable object
                if (is('nullish', 'object')) {
                    if (!options.allowNullableObject) {
                        if (isLogicalNegationExpression(node.parent)) {
                            // if (!nullableObject)
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableObject',
                                fix: util.getWrappingFixer({
                                    sourceCode,
                                    node: node.parent,
                                    innerNode: node,
                                    wrap: code => `${code} == null`,
                                }),
                            });
                        }
                        else {
                            // if (nullableObject)
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableObject',
                                fix: util.getWrappingFixer({
                                    sourceCode,
                                    node,
                                    wrap: code => `${code} != null`,
                                }),
                            });
                        }
                    }
                    return;
                }
                // nullable enum
                if (is('nullish', 'number', 'enum') || is('nullish', 'string', 'enum')) {
                    if (!options.allowNullableEnum) {
                        if (isLogicalNegationExpression(node.parent)) {
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableEnum',
                                fix: util.getWrappingFixer({
                                    sourceCode,
                                    node: node.parent,
                                    innerNode: node,
                                    wrap: code => `${code} == null`,
                                }),
                            });
                        }
                        else {
                            context.report({
                                node,
                                messageId: 'conditionErrorNullableEnum',
                                fix: util.getWrappingFixer({
                                    sourceCode,
                                    node,
                                    wrap: code => `${code} != null`,
                                }),
                            });
                        }
                    }
                    return;
                }
                // any
                if (is('any')) {
                    if (!options.allowAny) {
                        context.report({
                            node,
                            messageId: 'conditionErrorAny',
                            suggest: [
                                {
                                    messageId: 'conditionFixCastBoolean',
                                    fix: util.getWrappingFixer({
                                        sourceCode,
                                        node,
                                        wrap: code => `Boolean(${code})`,
                                    }),
                                },
                            ],
                        });
                    }
                    return;
                }
                // other
                context.report({ node, messageId: 'conditionErrorOther' });
            }
            /**
             * Check union variants for the types we care about
             */
            function inspectVariantTypes(types) {
                const variantTypes = new Set();
                if (types.some(type => tsutils.isTypeFlagSet(type, ts.TypeFlags.Null | ts.TypeFlags.Undefined | ts.TypeFlags.VoidLike))) {
                    variantTypes.add('nullish');
                }
                const booleans = types.filter(type => tsutils.isTypeFlagSet(type, ts.TypeFlags.BooleanLike));
                // If incoming type is either "true" or "false", there will be one type
                // object with intrinsicName set accordingly
                // If incoming type is boolean, there will be two type objects with
                // intrinsicName set "true" and "false" each because of tsutils.unionTypeParts()
                if (booleans.length === 1) {
                    tsutils.isBooleanLiteralType(booleans[0], true)
                        ? variantTypes.add('truthy boolean')
                        : variantTypes.add('boolean');
                }
                else if (booleans.length === 2) {
                    variantTypes.add('boolean');
                }
                const strings = types.filter(type => tsutils.isTypeFlagSet(type, ts.TypeFlags.StringLike));
                if (strings.length) {
                    if (strings.some(type => type.isStringLiteral() && type.value !== '')) {
                        variantTypes.add('truthy string');
                    }
                    else {
                        variantTypes.add('string');
                    }
                }
                const numbers = types.filter(type => tsutils.isTypeFlagSet(type, ts.TypeFlags.NumberLike | ts.TypeFlags.BigIntLike));
                if (numbers.length) {
                    if (numbers.some(type => type.isNumberLiteral() && type.value !== 0)) {
                        variantTypes.add('truthy number');
                    }
                    else {
                        variantTypes.add('number');
                    }
                }
                if (types.some(type => tsutils.isTypeFlagSet(type, ts.TypeFlags.EnumLike))) {
                    variantTypes.add('enum');
                }
                if (types.some(type => !tsutils.isTypeFlagSet(type, ts.TypeFlags.Null |
                    ts.TypeFlags.Undefined |
                    ts.TypeFlags.VoidLike |
                    ts.TypeFlags.BooleanLike |
                    ts.TypeFlags.StringLike |
                    ts.TypeFlags.NumberLike |
                    ts.TypeFlags.BigIntLike |
                    ts.TypeFlags.TypeParameter |
                    ts.TypeFlags.Any |
                    ts.TypeFlags.Unknown |
                    ts.TypeFlags.Never))) {
                    variantTypes.add('object');
                }
                if (types.some(type => util.isTypeFlagSet(type, ts.TypeFlags.TypeParameter |
                    ts.TypeFlags.Any |
                    ts.TypeFlags.Unknown))) {
                    variantTypes.add('any');
                }
                if (types.some(type => tsutils.isTypeFlagSet(type, ts.TypeFlags.Never))) {
                    variantTypes.add('never');
                }
                return variantTypes;
            }
        },
    });
    function isLogicalNegationExpression(node) {
        return node.type === utils_1.AST_NODE_TYPES.UnaryExpression && node.operator === '!';
    }
    function isArrayLengthExpression(node, typeChecker, parserServices) {
        if (node.type !== utils_1.AST_NODE_TYPES.MemberExpression) {
            return false;
        }
        if (node.computed) {
            return false;
        }
        if (node.property.name !== 'length') {
            return false;
        }
        const objectTsNode = parserServices.esTreeNodeToTSNodeMap.get(node.object);
        const objectType = util.getConstrainedTypeAtLocation(typeChecker, objectTsNode);
        return util.isTypeArrayTypeOrUnionOfArrayTypes(objectType, typeChecker);
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/switch-exhaustiveness-check.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const tsutils_1 = require(1034) /* tsutils */;
    const ts = __importStar(require(21) /* typescript */);
    const util_1 = require(1018) /* ../util */;
    exports.default = (0, util_1.createRule)({
        name: 'switch-exhaustiveness-check',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Require switch-case statements to be exhaustive with union type',
                recommended: false,
                requiresTypeChecking: true,
            },
            hasSuggestions: true,
            schema: [],
            messages: {
                switchIsNotExhaustive: 'Switch is not exhaustive. Cases not matched: {{missingBranches}}',
                addMissingCases: 'Add branches for missing cases.',
            },
        },
        defaultOptions: [],
        create(context) {
            const sourceCode = context.getSourceCode();
            const service = (0, util_1.getParserServices)(context);
            const checker = service.program.getTypeChecker();
            const compilerOptions = service.program.getCompilerOptions();
            function getNodeType(node) {
                const tsNode = service.esTreeNodeToTSNodeMap.get(node);
                return (0, util_1.getConstrainedTypeAtLocation)(checker, tsNode);
            }
            function fixSwitch(fixer, node, missingBranchTypes, symbolName) {
                var _a;
                const lastCase = node.cases.length > 0 ? node.cases[node.cases.length - 1] : null;
                const caseIndent = lastCase
                    ? ' '.repeat(lastCase.loc.start.column)
                    : // if there are no cases, use indentation of the switch statement
                        // and leave it to user to format it correctly
                        ' '.repeat(node.loc.start.column);
                const missingCases = [];
                for (const missingBranchType of missingBranchTypes) {
                    // While running this rule on checker.ts of TypeScript project
                    // the fix introduced a compiler error due to:
                    //
                    // type __String = (string & {
                    //         __escapedIdentifier: void;
                    //     }) | (void & {
                    //         __escapedIdentifier: void;
                    //     }) | InternalSymbolName;
                    //
                    // The following check fixes it.
                    if (missingBranchType.isIntersection()) {
                        continue;
                    }
                    const missingBranchName = (_a = missingBranchType.getSymbol()) === null || _a === void 0 ? void 0 : _a.escapedName;
                    let caseTest = checker.typeToString(missingBranchType);
                    if (symbolName &&
                        (missingBranchName || missingBranchName === '') &&
                        (0, util_1.requiresQuoting)(missingBranchName.toString(), compilerOptions.target)) {
                        caseTest = `${symbolName}['${missingBranchName}']`;
                    }
                    const errorMessage = `Not implemented yet: ${caseTest} case`;
                    missingCases.push(`case ${caseTest}: { throw new Error('${errorMessage}') }`);
                }
                const fixString = missingCases
                    .map(code => `${caseIndent}${code}`)
                    .join('\n');
                if (lastCase) {
                    return fixer.insertTextAfter(lastCase, `\n${fixString}`);
                }
                // there were no existing cases
                const openingBrace = sourceCode.getTokenAfter(node.discriminant, util_1.isOpeningBraceToken);
                const closingBrace = sourceCode.getTokenAfter(node.discriminant, util_1.isClosingBraceToken);
                return fixer.replaceTextRange([openingBrace.range[0], closingBrace.range[1]], ['{', fixString, `${caseIndent}}`].join('\n'));
            }
            function checkSwitchExhaustive(node) {
                var _a;
                const discriminantType = getNodeType(node.discriminant);
                const symbolName = (_a = discriminantType.getSymbol()) === null || _a === void 0 ? void 0 : _a.escapedName;
                if (discriminantType.isUnion()) {
                    const unionTypes = (0, tsutils_1.unionTypeParts)(discriminantType);
                    const caseTypes = new Set();
                    for (const switchCase of node.cases) {
                        if (switchCase.test == null) {
                            // Switch has 'default' branch - do nothing.
                            return;
                        }
                        caseTypes.add(getNodeType(switchCase.test));
                    }
                    const missingBranchTypes = unionTypes.filter(unionType => !caseTypes.has(unionType));
                    if (missingBranchTypes.length === 0) {
                        // All cases matched - do nothing.
                        return;
                    }
                    context.report({
                        node: node.discriminant,
                        messageId: 'switchIsNotExhaustive',
                        data: {
                            missingBranches: missingBranchTypes
                                .map(missingType => {
                                var _a;
                                return (0, tsutils_1.isTypeFlagSet)(missingType, ts.TypeFlags.ESSymbolLike)
                                    ? `typeof ${(_a = missingType.getSymbol()) === null || _a === void 0 ? void 0 : _a.escapedName}`
                                    : checker.typeToString(missingType);
                            })
                                .join(' | '),
                        },
                        suggest: [
                            {
                                messageId: 'addMissingCases',
                                fix(fixer) {
                                    return fixSwitch(fixer, node, missingBranchTypes, symbolName === null || symbolName === void 0 ? void 0 : symbolName.toString());
                                },
                            },
                        ],
                    });
                }
            }
            return {
                SwitchStatement: checkSwitchExhaustive,
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/triple-slash-reference.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'triple-slash-reference',
        meta: {
            type: 'suggestion',
            docs: {
                description: 'Disallow certain triple slash directives in favor of ES6-style import declarations',
                recommended: 'error',
            },
            messages: {
                tripleSlashReference: 'Do not use a triple slash reference for {{module}}, use `import` style instead.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        lib: {
                            enum: ['always', 'never'],
                        },
                        path: {
                            enum: ['always', 'never'],
                        },
                        types: {
                            enum: ['always', 'never', 'prefer-import'],
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            {
                lib: 'always',
                path: 'never',
                types: 'prefer-import',
            },
        ],
        create(context, [{ lib, path, types }]) {
            let programNode;
            const sourceCode = context.getSourceCode();
            const references = [];
            function hasMatchingReference(source) {
                references.forEach(reference => {
                    if (reference.importName === source.value) {
                        context.report({
                            node: reference.comment,
                            messageId: 'tripleSlashReference',
                            data: {
                                module: reference.importName,
                            },
                        });
                    }
                });
            }
            return {
                ImportDeclaration(node) {
                    if (programNode) {
                        hasMatchingReference(node.source);
                    }
                },
                TSImportEqualsDeclaration(node) {
                    if (programNode) {
                        const reference = node.moduleReference;
                        if (reference.type === utils_1.AST_NODE_TYPES.TSExternalModuleReference) {
                            hasMatchingReference(reference.expression);
                        }
                    }
                },
                Program(node) {
                    if (lib === 'always' && path === 'always' && types === 'always') {
                        return;
                    }
                    programNode = node;
                    const referenceRegExp = /^\/\s*<reference\s*(types|path|lib)\s*=\s*["|'](.*)["|']/;
                    const commentsBefore = sourceCode.getCommentsBefore(programNode);
                    commentsBefore.forEach(comment => {
                        if (comment.type !== utils_1.AST_TOKEN_TYPES.Line) {
                            return;
                        }
                        const referenceResult = referenceRegExp.exec(comment.value);
                        if (referenceResult) {
                            if ((referenceResult[1] === 'types' && types === 'never') ||
                                (referenceResult[1] === 'path' && path === 'never') ||
                                (referenceResult[1] === 'lib' && lib === 'never')) {
                                context.report({
                                    node: comment,
                                    messageId: 'tripleSlashReference',
                                    data: {
                                        module: referenceResult[2],
                                    },
                                });
                                return;
                            }
                            if (referenceResult[1] === 'types' && types === 'prefer-import') {
                                references.push({ comment, importName: referenceResult[2] });
                            }
                        }
                    });
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/type-annotation-spacing.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    const definition = {
        type: 'object',
        properties: {
            before: { type: 'boolean' },
            after: { type: 'boolean' },
        },
        additionalProperties: false,
    };
    function createRules(options) {
        var _a;
        const globals = Object.assign(Object.assign({}, ((options === null || options === void 0 ? void 0 : options.before) !== undefined ? { before: options.before } : {})), ((options === null || options === void 0 ? void 0 : options.after) !== undefined ? { after: options.after } : {}));
        const override = (_a = options === null || options === void 0 ? void 0 : options.overrides) !== null && _a !== void 0 ? _a : {};
        const colon = Object.assign(Object.assign({ before: false, after: true }, globals), override === null || override === void 0 ? void 0 : override.colon);
        const arrow = Object.assign(Object.assign({ before: true, after: true }, globals), override === null || override === void 0 ? void 0 : override.arrow);
        return {
            colon: colon,
            arrow: arrow,
            variable: Object.assign(Object.assign({}, colon), override === null || override === void 0 ? void 0 : override.variable),
            property: Object.assign(Object.assign({}, colon), override === null || override === void 0 ? void 0 : override.property),
            parameter: Object.assign(Object.assign({}, colon), override === null || override === void 0 ? void 0 : override.parameter),
            returnType: Object.assign(Object.assign({}, colon), override === null || override === void 0 ? void 0 : override.returnType),
        };
    }
    function getIdentifierRules(rules, node) {
        const scope = node === null || node === void 0 ? void 0 : node.parent;
        if ((0, util_1.isVariableDeclarator)(scope)) {
            return rules.variable;
        }
        else if ((0, util_1.isFunctionOrFunctionType)(scope)) {
            return rules.parameter;
        }
        else {
            return rules.colon;
        }
    }
    function getRules(rules, node) {
        var _a;
        const scope = (_a = node === null || node === void 0 ? void 0 : node.parent) === null || _a === void 0 ? void 0 : _a.parent;
        if ((0, util_1.isTSFunctionType)(scope) || (0, util_1.isTSConstructorType)(scope)) {
            return rules.arrow;
        }
        else if ((0, util_1.isIdentifier)(scope)) {
            return getIdentifierRules(rules, scope);
        }
        else if ((0, util_1.isClassOrTypeElement)(scope)) {
            return rules.property;
        }
        else if ((0, util_1.isFunction)(scope)) {
            return rules.returnType;
        }
        else {
            return rules.colon;
        }
    }
    exports.default = util.createRule({
        name: 'type-annotation-spacing',
        meta: {
            type: 'layout',
            docs: {
                description: 'Require consistent spacing around type annotations',
                recommended: false,
            },
            fixable: 'whitespace',
            messages: {
                expectedSpaceAfter: "Expected a space after the '{{type}}'.",
                expectedSpaceBefore: "Expected a space before the '{{type}}'.",
                unexpectedSpaceAfter: "Unexpected space after the '{{type}}'.",
                unexpectedSpaceBefore: "Unexpected space before the '{{type}}'.",
                unexpectedSpaceBetween: "Unexpected space between the '{{previousToken}}' and the '{{type}}'.",
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        before: { type: 'boolean' },
                        after: { type: 'boolean' },
                        overrides: {
                            type: 'object',
                            properties: {
                                colon: definition,
                                arrow: definition,
                                variable: definition,
                                parameter: definition,
                                property: definition,
                                returnType: definition,
                            },
                            additionalProperties: false,
                        },
                    },
                    additionalProperties: false,
                },
            ],
        },
        defaultOptions: [
            // technically there is a default, but the overrides mean
            // that if we apply them here, it will break the no override case.
            {},
        ],
        create(context, [options]) {
            const punctuators = [':', '=>'];
            const sourceCode = context.getSourceCode();
            const ruleSet = createRules(options);
            /**
             * Checks if there's proper spacing around type annotations (no space
             * before colon, one space after).
             */
            function checkTypeAnnotationSpacing(typeAnnotation) {
                const nextToken = typeAnnotation;
                const punctuatorTokenEnd = sourceCode.getTokenBefore(nextToken);
                let punctuatorTokenStart = punctuatorTokenEnd;
                let previousToken = sourceCode.getTokenBefore(punctuatorTokenEnd);
                let type = punctuatorTokenEnd.value;
                if (!punctuators.includes(type)) {
                    return;
                }
                const { before, after } = getRules(ruleSet, typeAnnotation);
                if (type === ':' && previousToken.value === '?') {
                    if (
                    // eslint-disable-next-line deprecation/deprecation -- TODO - switch once our min ESLint version is 6.7.0
                    sourceCode.isSpaceBetweenTokens(previousToken, punctuatorTokenStart)) {
                        context.report({
                            node: punctuatorTokenStart,
                            messageId: 'unexpectedSpaceBetween',
                            data: {
                                type,
                                previousToken: previousToken.value,
                            },
                            fix(fixer) {
                                return fixer.removeRange([
                                    previousToken.range[1],
                                    punctuatorTokenStart.range[0],
                                ]);
                            },
                        });
                    }
                    // shift the start to the ?
                    type = '?:';
                    punctuatorTokenStart = previousToken;
                    previousToken = sourceCode.getTokenBefore(previousToken);
                    // handle the +/- modifiers for optional modification operators
                    if (previousToken.value === '+' || previousToken.value === '-') {
                        type = `${previousToken.value}?:`;
                        punctuatorTokenStart = previousToken;
                        previousToken = sourceCode.getTokenBefore(previousToken);
                    }
                }
                const previousDelta = punctuatorTokenStart.range[0] - previousToken.range[1];
                const nextDelta = nextToken.range[0] - punctuatorTokenEnd.range[1];
                if (after && nextDelta === 0) {
                    context.report({
                        node: punctuatorTokenEnd,
                        messageId: 'expectedSpaceAfter',
                        data: {
                            type,
                        },
                        fix(fixer) {
                            return fixer.insertTextAfter(punctuatorTokenEnd, ' ');
                        },
                    });
                }
                else if (!after && nextDelta > 0) {
                    context.report({
                        node: punctuatorTokenEnd,
                        messageId: 'unexpectedSpaceAfter',
                        data: {
                            type,
                        },
                        fix(fixer) {
                            return fixer.removeRange([
                                punctuatorTokenEnd.range[1],
                                nextToken.range[0],
                            ]);
                        },
                    });
                }
                if (before && previousDelta === 0) {
                    context.report({
                        node: punctuatorTokenStart,
                        messageId: 'expectedSpaceBefore',
                        data: {
                            type,
                        },
                        fix(fixer) {
                            return fixer.insertTextAfter(previousToken, ' ');
                        },
                    });
                }
                else if (!before && previousDelta > 0) {
                    context.report({
                        node: punctuatorTokenStart,
                        messageId: 'unexpectedSpaceBefore',
                        data: {
                            type,
                        },
                        fix(fixer) {
                            return fixer.removeRange([
                                previousToken.range[1],
                                punctuatorTokenStart.range[0],
                            ]);
                        },
                    });
                }
            }
            return {
                TSMappedType(node) {
                    if (node.typeAnnotation) {
                        checkTypeAnnotationSpacing(node.typeAnnotation);
                    }
                },
                TSTypeAnnotation(node) {
                    checkTypeAnnotationSpacing(node.typeAnnotation);
                },
            };
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/typedef.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'typedef',
        meta: {
            docs: {
                description: 'Require type annotations in certain places',
                recommended: false,
            },
            messages: {
                expectedTypedef: 'Expected a type annotation.',
                expectedTypedefNamed: 'Expected {{name}} to have a type annotation.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        ["arrayDestructuring" /* OptionKeys.ArrayDestructuring */]: { type: 'boolean' },
                        ["arrowParameter" /* OptionKeys.ArrowParameter */]: { type: 'boolean' },
                        ["memberVariableDeclaration" /* OptionKeys.MemberVariableDeclaration */]: { type: 'boolean' },
                        ["objectDestructuring" /* OptionKeys.ObjectDestructuring */]: { type: 'boolean' },
                        ["parameter" /* OptionKeys.Parameter */]: { type: 'boolean' },
                        ["propertyDeclaration" /* OptionKeys.PropertyDeclaration */]: { type: 'boolean' },
                        ["variableDeclaration" /* OptionKeys.VariableDeclaration */]: { type: 'boolean' },
                        ["variableDeclarationIgnoreFunction" /* OptionKeys.VariableDeclarationIgnoreFunction */]: { type: 'boolean' },
                    },
                },
            ],
            type: 'suggestion',
        },
        defaultOptions: [
            {
                ["arrayDestructuring" /* OptionKeys.ArrayDestructuring */]: false,
                ["arrowParameter" /* OptionKeys.ArrowParameter */]: false,
                ["memberVariableDeclaration" /* OptionKeys.MemberVariableDeclaration */]: false,
                ["objectDestructuring" /* OptionKeys.ObjectDestructuring */]: false,
                ["parameter" /* OptionKeys.Parameter */]: false,
                ["propertyDeclaration" /* OptionKeys.PropertyDeclaration */]: false,
                ["variableDeclaration" /* OptionKeys.VariableDeclaration */]: false,
                ["variableDeclarationIgnoreFunction" /* OptionKeys.VariableDeclarationIgnoreFunction */]: false,
            },
        ],
        create(context, [{ arrayDestructuring, arrowParameter, memberVariableDeclaration, objectDestructuring, parameter, propertyDeclaration, variableDeclaration, variableDeclarationIgnoreFunction, },]) {
            function report(location, name) {
                context.report({
                    node: location,
                    messageId: name ? 'expectedTypedefNamed' : 'expectedTypedef',
                    data: { name },
                });
            }
            function getNodeName(node) {
                return node.type === utils_1.AST_NODE_TYPES.Identifier ? node.name : undefined;
            }
            function isForOfStatementContext(node) {
                let current = node.parent;
                while (current) {
                    switch (current.type) {
                        case utils_1.AST_NODE_TYPES.VariableDeclarator:
                        case utils_1.AST_NODE_TYPES.VariableDeclaration:
                        case utils_1.AST_NODE_TYPES.ObjectPattern:
                        case utils_1.AST_NODE_TYPES.ArrayPattern:
                        case utils_1.AST_NODE_TYPES.Property:
                            current = current.parent;
                            break;
                        case utils_1.AST_NODE_TYPES.ForOfStatement:
                            return true;
                        default:
                            current = undefined;
                    }
                }
                return false;
            }
            function checkParameters(params) {
                for (const param of params) {
                    let annotationNode;
                    switch (param.type) {
                        case utils_1.AST_NODE_TYPES.AssignmentPattern:
                            annotationNode = param.left;
                            break;
                        case utils_1.AST_NODE_TYPES.TSParameterProperty:
                            annotationNode = param.parameter;
                            // Check TS parameter property with default value like `constructor(private param: string = 'something') {}`
                            if (annotationNode &&
                                annotationNode.type === utils_1.AST_NODE_TYPES.AssignmentPattern) {
                                annotationNode = annotationNode.left;
                            }
                            break;
                        default:
                            annotationNode = param;
                            break;
                    }
                    if (annotationNode !== undefined && !annotationNode.typeAnnotation) {
                        report(param, getNodeName(param));
                    }
                }
            }
            function isVariableDeclarationIgnoreFunction(node) {
                return (variableDeclarationIgnoreFunction === true &&
                    (node.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression ||
                        node.type === utils_1.AST_NODE_TYPES.FunctionExpression));
            }
            function isAncestorHasTypeAnnotation(node) {
                let ancestor = node.parent;
                while (ancestor) {
                    if ((ancestor.type === utils_1.AST_NODE_TYPES.ObjectPattern ||
                        ancestor.type === utils_1.AST_NODE_TYPES.ArrayPattern) &&
                        ancestor.typeAnnotation) {
                        return true;
                    }
                    ancestor = ancestor.parent;
                }
                return false;
            }
            return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, (arrayDestructuring && {
                ArrayPattern(node) {
                    var _a, _b;
                    if (((_a = node.parent) === null || _a === void 0 ? void 0 : _a.type) === utils_1.AST_NODE_TYPES.RestElement &&
                        node.parent.typeAnnotation) {
                        return;
                    }
                    if (!node.typeAnnotation &&
                        !isForOfStatementContext(node) &&
                        !isAncestorHasTypeAnnotation(node) &&
                        ((_b = node.parent) === null || _b === void 0 ? void 0 : _b.type) !== utils_1.AST_NODE_TYPES.AssignmentExpression) {
                        report(node);
                    }
                },
            })), (arrowParameter && {
                ArrowFunctionExpression(node) {
                    checkParameters(node.params);
                },
            })), (memberVariableDeclaration && {
                PropertyDefinition(node) {
                    if (!(node.value && isVariableDeclarationIgnoreFunction(node.value)) &&
                        !node.typeAnnotation) {
                        report(node, node.key.type === utils_1.AST_NODE_TYPES.Identifier
                            ? node.key.name
                            : undefined);
                    }
                },
            })), (parameter && {
                'FunctionDeclaration, FunctionExpression'(node) {
                    checkParameters(node.params);
                },
            })), (objectDestructuring && {
                ObjectPattern(node) {
                    if (!node.typeAnnotation &&
                        !isForOfStatementContext(node) &&
                        !isAncestorHasTypeAnnotation(node)) {
                        report(node);
                    }
                },
            })), (propertyDeclaration && {
                'TSIndexSignature, TSPropertySignature'(node) {
                    if (!node.typeAnnotation) {
                        report(node, node.type === utils_1.AST_NODE_TYPES.TSPropertySignature
                            ? getNodeName(node.key)
                            : undefined);
                    }
                },
            })), { VariableDeclarator(node) {
                    if (!variableDeclaration ||
                        node.id.typeAnnotation ||
                        (node.id.type === utils_1.AST_NODE_TYPES.ArrayPattern &&
                            !arrayDestructuring) ||
                        (node.id.type === utils_1.AST_NODE_TYPES.ObjectPattern &&
                            !objectDestructuring) ||
                        (node.init && isVariableDeclarationIgnoreFunction(node.init))) {
                        return;
                    }
                    let current = node.parent;
                    while (current) {
                        switch (current.type) {
                            case utils_1.AST_NODE_TYPES.VariableDeclaration:
                                // Keep looking upwards
                                current = current.parent;
                                break;
                            case utils_1.AST_NODE_TYPES.ForOfStatement:
                            case utils_1.AST_NODE_TYPES.ForInStatement:
                                // Stop traversing and don't report an error
                                return;
                            default:
                                // Stop traversing
                                current = undefined;
                                break;
                        }
                    }
                    report(node, getNodeName(node.id));
                } });
        },
    });
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/unbound-method.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const tsutils = __importStar(require(1034) /* tsutils */);
    const ts = __importStar(require(21) /* typescript */);
    const util = __importStar(require(1018) /* ../util */);
    const util_1 = require(1018) /* ../util */;
    /**
     * The following is a list of exceptions to the rule
     * Generated via the following script.
     * This is statically defined to save making purposely invalid calls every lint run
     * ```
    SUPPORTED_GLOBALS.flatMap(namespace => {
      const object = window[namespace];
        return Object.getOwnPropertyNames(object)
          .filter(
            name =>
              !name.startsWith('_') &&
              typeof object[name] === 'function',
          )
          .map(name => {
            try {
              const x = object[name];
              x();
            } catch (e) {
              if (e.message.includes("called on non-object")) {
                return `${namespace}.${name}`;
              }
            }
          });
    }).filter(Boolean);
       * ```
     */
    const nativelyNotBoundMembers = new Set([
        'Promise.all',
        'Promise.race',
        'Promise.resolve',
        'Promise.reject',
        'Promise.allSettled',
        'Object.defineProperties',
        'Object.defineProperty',
        'Reflect.defineProperty',
        'Reflect.deleteProperty',
        'Reflect.get',
        'Reflect.getOwnPropertyDescriptor',
        'Reflect.getPrototypeOf',
        'Reflect.has',
        'Reflect.isExtensible',
        'Reflect.ownKeys',
        'Reflect.preventExtensions',
        'Reflect.set',
        'Reflect.setPrototypeOf',
    ]);
    const SUPPORTED_GLOBALS = [
        'Number',
        'Object',
        'String',
        'RegExp',
        'Symbol',
        'Array',
        'Proxy',
        'Date',
        'Infinity',
        'Atomics',
        'Reflect',
        'console',
        'Math',
        'JSON',
        'Intl',
    ];
    const nativelyBoundMembers = SUPPORTED_GLOBALS.map(namespace => {
        if (!(namespace in global)) {
            // node.js might not have namespaces like Intl depending on compilation options
            // https://nodejs.org/api/intl.html#intl_options_for_building_node_js
            return [];
        }
        const object = global[namespace];
        return Object.getOwnPropertyNames(object)
            .filter(name => !name.startsWith('_') &&
            typeof object[name] === 'function')
            .map(name => `${namespace}.${name}`);
    })
        .reduce((arr, names) => arr.concat(names), [])
        .filter(name => !nativelyNotBoundMembers.has(name));
    const isNotImported = (symbol, currentSourceFile) => {
        const { valueDeclaration } = symbol;
        if (!valueDeclaration) {
            // working around https://github.com/microsoft/TypeScript/issues/31294
            return false;
        }
        return (!!currentSourceFile &&
            currentSourceFile !== valueDeclaration.getSourceFile());
    };
    const getNodeName = (node) => node.type === utils_1.AST_NODE_TYPES.Identifier ? node.name : null;
    const getMemberFullName = (node) => `${getNodeName(node.object)}.${getNodeName(node.property)}`;
    const BASE_MESSAGE = 'Avoid referencing unbound methods which may cause unintentional scoping of `this`.';
    exports.default = util.createRule({
        name: 'unbound-method',
        meta: {
            docs: {
                description: 'Enforce unbound methods are called with their expected scope',
                recommended: 'error',
                requiresTypeChecking: true,
            },
            messages: {
                unbound: BASE_MESSAGE,
                unboundWithoutThisAnnotation: BASE_MESSAGE +
                    '\n' +
                    'If your function does not access `this`, you can annotate it with `this: void`, or consider using an arrow function instead.',
            },
            schema: [
                {
                    type: 'object',
                    properties: {
                        ignoreStatic: {
                            description: 'Whether to skip checking whether `static` methods are correctly bound.',
                            type: 'boolean',
                        },
                    },
                    additionalProperties: false,
                },
            ],
            type: 'problem',
        },
        defaultOptions: [
            {
                ignoreStatic: false,
            },
        ],
        create(context, [{ ignoreStatic }]) {
            const parserServices = util.getParserServices(context);
            const checker = parserServices.program.getTypeChecker();
            const currentSourceFile = parserServices.program.getSourceFile(context.getFilename());
            function checkMethodAndReport(node, symbol) {
                if (!symbol) {
                    return;
                }
                const { dangerous, firstParamIsThis } = checkMethod(symbol, ignoreStatic);
                if (dangerous) {
                    context.report({
                        messageId: firstParamIsThis === false
                            ? 'unboundWithoutThisAnnotation'
                            : 'unbound',
                        node,
                    });
                }
            }
            return {
                MemberExpression(node) {
                    if (isSafeUse(node)) {
                        return;
                    }
                    const objectSymbol = checker.getSymbolAtLocation(parserServices.esTreeNodeToTSNodeMap.get(node.object));
                    if (objectSymbol &&
                        nativelyBoundMembers.includes(getMemberFullName(node)) &&
                        isNotImported(objectSymbol, currentSourceFile)) {
                        return;
                    }
                    const originalNode = parserServices.esTreeNodeToTSNodeMap.get(node);
                    checkMethodAndReport(node, checker.getSymbolAtLocation(originalNode));
                },
                'VariableDeclarator, AssignmentExpression'(node) {
                    const [idNode, initNode] = node.type === utils_1.AST_NODE_TYPES.VariableDeclarator
                        ? [node.id, node.init]
                        : [node.left, node.right];
                    if (initNode && idNode.type === utils_1.AST_NODE_TYPES.ObjectPattern) {
                        const tsNode = parserServices.esTreeNodeToTSNodeMap.get(initNode);
                        const rightSymbol = checker.getSymbolAtLocation(tsNode);
                        const initTypes = checker.getTypeAtLocation(tsNode);
                        const notImported = rightSymbol && isNotImported(rightSymbol, currentSourceFile);
                        idNode.properties.forEach(property => {
                            if (property.type === utils_1.AST_NODE_TYPES.Property &&
                                property.key.type === utils_1.AST_NODE_TYPES.Identifier) {
                                if (notImported &&
                                    util.isIdentifier(initNode) &&
                                    nativelyBoundMembers.includes(`${initNode.name}.${property.key.name}`)) {
                                    return;
                                }
                                checkMethodAndReport(property.key, initTypes.getProperty(property.key.name));
                            }
                        });
                    }
                },
            };
        },
    });
    function checkMethod(symbol, ignoreStatic) {
        var _a, _b;
        const { valueDeclaration } = symbol;
        if (!valueDeclaration) {
            // working around https://github.com/microsoft/TypeScript/issues/31294
            return { dangerous: false };
        }
        switch (valueDeclaration.kind) {
            case ts.SyntaxKind.PropertyDeclaration:
                return {
                    dangerous: ((_a = valueDeclaration.initializer) === null || _a === void 0 ? void 0 : _a.kind) ===
                        ts.SyntaxKind.FunctionExpression,
                };
            case ts.SyntaxKind.MethodDeclaration:
            case ts.SyntaxKind.MethodSignature: {
                const decl = valueDeclaration;
                const firstParam = decl.parameters[0];
                const firstParamIsThis = (firstParam === null || firstParam === void 0 ? void 0 : firstParam.name.kind) === ts.SyntaxKind.Identifier &&
                    (firstParam === null || firstParam === void 0 ? void 0 : firstParam.name.escapedText) === 'this';
                const thisArgIsVoid = firstParamIsThis &&
                    ((_b = firstParam === null || firstParam === void 0 ? void 0 : firstParam.type) === null || _b === void 0 ? void 0 : _b.kind) === ts.SyntaxKind.VoidKeyword;
                return {
                    dangerous: !thisArgIsVoid &&
                        !(ignoreStatic &&
                            tsutils.hasModifier((0, util_1.getModifiers)(valueDeclaration), ts.SyntaxKind.StaticKeyword)),
                    firstParamIsThis,
                };
            }
        }
        return { dangerous: false };
    }
    function isSafeUse(node) {
        const parent = node.parent;
        switch (parent === null || parent === void 0 ? void 0 : parent.type) {
            case utils_1.AST_NODE_TYPES.IfStatement:
            case utils_1.AST_NODE_TYPES.ForStatement:
            case utils_1.AST_NODE_TYPES.MemberExpression:
            case utils_1.AST_NODE_TYPES.SwitchStatement:
            case utils_1.AST_NODE_TYPES.UpdateExpression:
            case utils_1.AST_NODE_TYPES.WhileStatement:
                return true;
            case utils_1.AST_NODE_TYPES.CallExpression:
                return parent.callee === node;
            case utils_1.AST_NODE_TYPES.ConditionalExpression:
                return parent.test === node;
            case utils_1.AST_NODE_TYPES.TaggedTemplateExpression:
                return parent.tag === node;
            case utils_1.AST_NODE_TYPES.UnaryExpression:
                // the first case is safe for obvious
                // reasons. The second one is also fine
                // since we're returning something falsy
                return ['typeof', '!', 'void', 'delete'].includes(parent.operator);
            case utils_1.AST_NODE_TYPES.BinaryExpression:
                return ['instanceof', '==', '!=', '===', '!=='].includes(parent.operator);
            case utils_1.AST_NODE_TYPES.AssignmentExpression:
                return (parent.operator === '=' &&
                    (node === parent.left ||
                        (node.type === utils_1.AST_NODE_TYPES.MemberExpression &&
                            node.object.type === utils_1.AST_NODE_TYPES.Super &&
                            parent.left.type === utils_1.AST_NODE_TYPES.MemberExpression &&
                            parent.left.object.type === utils_1.AST_NODE_TYPES.ThisExpression)));
            case utils_1.AST_NODE_TYPES.ChainExpression:
            case utils_1.AST_NODE_TYPES.TSNonNullExpression:
            case utils_1.AST_NODE_TYPES.TSAsExpression:
            case utils_1.AST_NODE_TYPES.TSTypeAssertion:
                return isSafeUse(parent);
            case utils_1.AST_NODE_TYPES.LogicalExpression:
                if (parent.operator === '&&' && parent.left === node) {
                    // this is safe, as && will return the left if and only if it's falsy
                    return true;
                }
                // in all other cases, it's likely the logical expression will return the method ref
                // so make sure the parent is a safe usage
                return isSafeUse(parent);
        }
        return false;
    }
    
},
/* @typescript-eslint/eslint-plugin/dist/rules/unified-signatures.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require(777) /* @typescript-eslint/utils */;
    const util = __importStar(require(1018) /* ../util */);
    exports.default = util.createRule({
        name: 'unified-signatures',
        meta: {
            docs: {
                description: 'Disallow two overloads that could be unified into one with a union or an optional/rest parameter',
                // too opinionated to be recommended
                recommended: 'strict',
            },
            type: 'suggestion',
            messages: {
                omittingRestParameter: '{{failureStringStart}} with a rest parameter.',
                omittingSingleParameter: '{{failureStringStart}} with an optional parameter.',
                singleParameterDifference: '{{failureStringStart}} taking `{{type1}} | {{type2}}`.',
            },
            schema: [
                {
                    additionalProperties: false,
                    properties: {
                        ignoreDifferentlyNamedParameters: {
                            description: 'Whether two parameters with different names at the same index should be considered different even if their types are the same.',
                            type: 'boolean',
                        },
                    },
                    type: 'object',
                },
            ],
        },
        defaultOptions: [
            {
                ignoreDifferentlyNamedParameters: false,
            },
        ],
        create(context, [{ ignoreDifferentlyNamedParameters }]) {
            const sourceCode = context.getSourceCode();
            //----------------------------------------------------------------------
            // Helpers
            //----------------------------------------------------------------------
            function failureStringStart(otherLine) {
                // For only 2 overloads we don't need to specify which is the other one.
                const overloads = otherLine === undefined
                    ? 'These overloads'
                    : `This overload and the one on line ${otherLine}`;
                return `${overloads} can be combined into one signature`;
            }
            function addFailures(failures) {
                for (const failure of failures) {
                    const { unify, only2 } = failure;
                    switch (unify.kind) {
                        case 'single-parameter-difference': {
                            const { p0, p1 } = unify;
                            const lineOfOtherOverload = only2 ? undefined : p0.loc.start.line;
                            const typeAnnotation0 = isTSParameterProperty(p0)
                                ? p0.parameter.typeAnnotation
                                : p0.typeAnnotation;
                            const typeAnnotation1 = isTSParameterProperty(p1)
                                ? p1.parameter.typeAnnotation
                                : p1.typeAnnotation;
                            context.report({
                                loc: p1.loc,
                                messageId: 'singleParameterDifference',
                                data: {
                                    failureStringStart: failureStringStart(lineOfOtherOverload),
                                    type1: sourceCode.getText(typeAnnotation0 === null || typeAnnotation0 === void 0 ? void 0 : typeAnnotation0.typeAnnotation),
                                    type2: sourceCode.getText(typeAnnotation1 === null || typeAnnotation1 === void 0 ? void 0 : typeAnnotation1.typeAnnotation),
                                },
                                node: p1,
                            });
                            break;
                        }
                        case 'extra-parameter': {
                            const { extraParameter, otherSignature } = unify;
                            const lineOfOtherOverload = only2
                                ? undefined
                                : otherSignature.loc.start.line;
                            context.report({
                                loc: extraParameter.loc,
                                messageId: extraParameter.type === utils_1.AST_NODE_TYPES.RestElement
                                    ? 'omittingRestParameter'
                                    : 'omittingSingleParameter',
                                data: {
                                    failureStringStart: failureStringStart(lineOfOtherOverload),
                                },
                                node: extraParameter,
                            });
                        }
                    }
                }
            }
            function checkOverloads(signatures, typeParameters) {
                const result = [];
                const isTypeParameter = getIsTypeParameter(typeParameters);
                for (const overloads of signatures) {
                    forEachPair(overloads, (a, b) => {
                        var _a, _b;
                        const signature0 = (_a = a.value) !== null && _a !== void 0 ? _a : a;
                        const signature1 = (_b = b.value) !== null && _b !== void 0 ? _b : b;
                        const unify = compareSignatures(signature0, signature1, isTypeParameter);
                        if (unify !== undefined) {
                            result.push({ unify, only2: overloads.length === 2 });
                        }
                    });
                }
                return result;
            }
            function compareSignatures(a, b, isTypeParameter) {
                if (!signaturesCanBeUnified(a, b, isTypeParameter)) {
                    return undefined;
                }
                return a.params.length === b.params.length
                    ? signaturesDifferBySingleParameter(a.params, b.params)
                    : signaturesDifferByOptionalOrRestParameter(a, b);
            }
            function signaturesCanBeUnified(a, b, isTypeParameter) {
                // Must return the same type.
                const aTypeParams = a.typeParameters !== undefined ? a.typeParameters.params : undefined;
                const bTypeParams = b.typeParameters !== undefined ? b.typeParameters.params : undefined;
                if (ignoreDifferentlyNamedParameters &&
                    a.params.length === b.params.length) {
                    for (let i = 0; i < a.params.length; i += 1) {
                        if (a.params[i].type === b.params[i].type &&
                            getStaticParameterName(a.params[i]) !==
                                getStaticParameterName(b.params[i])) {
                            return false;
                        }
                    }
                }
                return (typesAreEqual(a.returnType, b.returnType) &&
                    // Must take the same type parameters.
                    // If one uses a type parameter (from outside) and the other doesn't, they shouldn't be joined.
                    util.arraysAreEqual(aTypeParams, bTypeParams, typeParametersAreEqual) &&
                    signatureUsesTypeParameter(a, isTypeParameter) ===
                        signatureUsesTypeParameter(b, isTypeParameter));
            }
            /** Detect `a(x: number, y: number, z: number)` and `a(x: number, y: string, z: number)`. */
            function signaturesDifferBySingleParameter(types1, types2) {
                const index = getIndexOfFirstDifference(types1, types2, parametersAreEqual);
                if (index === undefined) {
                    return undefined;
                }
                // If remaining arrays are equal, the signatures differ by just one parameter type
                if (!util.arraysAreEqual(types1.slice(index + 1), types2.slice(index + 1), parametersAreEqual)) {
                    return undefined;
                }
                const a = types1[index];
                const b = types2[index];
                // Can unify `a?: string` and `b?: number`. Can't unify `...args: string[]` and `...args: number[]`.
                // See https://github.com/Microsoft/TypeScript/issues/5077
                return parametersHaveEqualSigils(a, b) &&
                    a.type !== utils_1.AST_NODE_TYPES.RestElement
                    ? { kind: 'single-parameter-difference', p0: a, p1: b }
                    : undefined;
            }
            /**
             * Detect `a(): void` and `a(x: number): void`.
             * Returns the parameter declaration (`x: number` in this example) that should be optional/rest, and overload it's a part of.
             */
            function signaturesDifferByOptionalOrRestParameter(a, b) {
                const sig1 = a.params;
                const sig2 = b.params;
                const minLength = Math.min(sig1.length, sig2.length);
                const longer = sig1.length < sig2.length ? sig2 : sig1;
                const shorter = sig1.length < sig2.length ? sig1 : sig2;
                const shorterSig = sig1.length < sig2.length ? a : b;
                // If one is has 2+ parameters more than the other, they must all be optional/rest.
                // Differ by optional parameters: f() and f(x), f() and f(x, ?y, ...z)
                // Not allowed: f() and f(x, y)
                for (let i = minLength + 1; i < longer.length; i++) {
                    if (!parameterMayBeMissing(longer[i])) {
                        return undefined;
                    }
                }
                for (let i = 0; i < minLength; i++) {
                    const sig1i = sig1[i];
                    const sig2i = sig2[i];
                    const typeAnnotation1 = isTSParameterProperty(sig1i)
                        ? sig1i.parameter.typeAnnotation
                        : sig1i.typeAnnotation;
                    const typeAnnotation2 = isTSParameterProperty(sig2i)
                        ? sig2i.parameter.typeAnnotation
                        : sig2i.typeAnnotation;
                    if (!typesAreEqual(typeAnnotation1, typeAnnotation2)) {
                        return undefined;
                    }
                }
                if (minLength > 0 &&
                    shorter[minLength - 1].type === utils_1.AST_NODE_TYPES.RestElement) {
                    return undefined;
                }
                return {
                    extraParameter: longer[longer.length - 1],
                    kind: 'extra-parameter',
                    otherSignature: shorterSig,
                };
            }
            /** Given type parameters, returns a function to test whether a type is one of those parameters. */
            function getIsTypeParameter(typeParameters) {
                if (typeParameters === undefined) {
                    return (() => false);
                }
                const set = new Set();
                for (const t of typeParameters.params) {
                    set.add(t.name.name);
                }
                return (typeName => set.has(typeName));
            }
            /** True if any of the outer type parameters are used in a signature. */
            function signatureUsesTypeParameter(sig, isTypeParameter) {
                return sig.params.some((p) => typeContainsTypeParameter(isTSParameterProperty(p)
                    ? p.parameter.typeAnnotation
                    : p.typeAnnotation));
                function typeContainsTypeParameter(type) {
                    if (!type) {
                        return false;
                    }
                    if (type.type === utils_1.AST_NODE_TYPES.TSTypeReference) {
                        const typeName = type.typeName;
                        if (isIdentifier(typeName) && isTypeParameter(typeName.name)) {
                            return true;
                        }
                    }
                    return typeContainsTypeParameter(type.typeAnnotation ||
                        type.elementType);
                }
            }
            function isTSParameterProperty(node) {
                return (node.type ===
                    utils_1.AST_NODE_TYPES.TSParameterProperty);
            }
            function parametersAreEqual(a, b) {
                const typeAnnotationA = isTSParameterProperty(a)
                    ? a.parameter.typeAnnotation
                    : a.typeAnnotation;
                const typeAnnotationB = isTSParameterProperty(b)
                    ? b.parameter.typeAnnotation
                    : b.typeAnnotation;
                return (parametersHaveEqualSigils(a, b) &&
                    typesAreEqual(typeAnnotationA, typeAnnotationB));
            }
            /** True for optional/rest parameters. */
            function parameterMayBeMissing(p) {
                const optional = isTSParameterProperty(p)
                    ? p.parameter.optional
                    : p.optional;
                return p.type === utils_1.AST_NODE_TYPES.RestElement || optional;
            }
            /** False if one is optional and the other isn't, or one is a rest parameter and the other isn't. */
            function parametersHaveEqualSigils(a, b) {
                const optionalA = isTSParameterProperty(a)
                    ? a.parameter.optional
                    : a.optional;
                const optionalB = isTSParameterProperty(b)
                    ? b.parameter.optional
                    : b.optional;
                return ((a.type === utils_1.AST_NODE_TYPES.RestElement) ===
                    (b.type === utils_1.AST_NODE_TYPES.RestElement) &&
                    (optionalA !== undefined) === (optionalB !== undefined));
            }
            function typeParametersAreEqual(a, b) {
                return (a.name.name === b.name.name &&
                    constraintsAreEqual(a.constraint, b.constraint));
            }
            function typesAreEqual(a, b) {
                return (a === b ||
                    (a !== undefined &&
                        b !== undefined &&
                        sourceCode.getText(a.typeAnnotation) ===
                            sourceCode.getText(b.typeAnnotation)));
            }
            function constraintsAreEqual(a, b) {
                return (a === b || (a !== undefined && b !== undefined && a.type === b.type));
            }
            /* Returns the first index where `a` and `b` differ. */
            function getIndexOfFirstDifference(a, b, equal) {
                for (let i = 0; i < a.length && i < b.length; i++) {
                    if (!equal(a[i], b[i])) {
                        return i;
                    }
                }
                return undefined;
            }
            /** Calls `action` for every pair of values in `values`. */
            function forEachPair(values, action) {
                for (let i = 0; i < values.length; i++) {
                    for (let j = i + 1; j < values.length; j++) {
                        action(values[i], values[j]);
                    }
                }
            }
            const scopes = [];
            let currentScope = {
                overloads: new Map(),
            };
            function createScope(parent, typeParameters) {
                currentScope && scopes.push(currentScope);
                currentScope = {
                    overloads: new Map(),
                    parent,
                    typeParameters,
                };
            }
            function checkScope() {
                const failures = checkOverloads(Array.from(currentScope.overloads.values()), currentScope.typeParameters);
                addFailures(failures);
                currentScope = scopes.pop();
            }
            function addOverload(signature, key, containingNode) {
                key = key !== null && key !== void 0 ? key : getOverloadKey(signature);
                if (currentScope &&
                    (containingNode || signature).parent === currentScope.parent) {
                    const overloads = currentScope.overloads.get(key);
                    if (overloads !== undefined) {
                        overloads.push(signature);
                    }
                    else {
                        currentScope.overloads.set(key, [signature]);
                    }
                }
            }
            //----------------------------------------------------------------------
            // Public
            //----------------------------------------------------------------------
            return {
                Program: createScope,
                TSModuleBlock: createScope,
                TSInterfaceDeclaration(node) {
                    createScope(node.body, node.typeParameters);
                },
                ClassDeclaration(node) {
                    createScope(node.body, node.typeParameters);
                },
                TSTypeLiteral: createScope,
                // collect overloads
                TSDeclareFunction(node) {
                    var _a, _b;
                    const exportingNode = getExportingNode(node);
                    addOverload(node, (_b = (_a = node.id) === null || _a === void 0 ? void 0 : _a.name) !== null && _b !== void 0 ? _b : exportingNode === null || exportingNode === void 0 ? void 0 : exportingNode.type, exportingNode);
                },
                TSCallSignatureDeclaration: addOverload,
                TSConstructSignatureDeclaration: addOverload,
                TSMethodSignature: addOverload,
                TSAbstractMethodDefinition(node) {
                    if (!node.value.body) {
                        addOverload(node);
                    }
                },
                MethodDefinition(node) {
                    if (!node.value.body) {
                        addOverload(node);
                    }
                },
                // validate scopes
                'Program:exit': checkScope,
                'TSModuleBlock:exit': checkScope,
                'TSInterfaceDeclaration:exit': checkScope,
                'ClassDeclaration:exit': checkScope,
                'TSTypeLiteral:exit': checkScope,
            };
        },
    });
    function getExportingNode(node) {
        return node.parent &&
            (node.parent.type === utils_1.AST_NODE_TYPES.ExportNamedDeclaration ||
                node.parent.type === utils_1.AST_NODE_TYPES.ExportDefaultDeclaration)
            ? node.parent
            : undefined;
    }
    function getOverloadKey(node) {
        const info = getOverloadInfo(node);
        return ((node.computed ? '0' : '1') +
            (node.static ? '0' : '1') +
            info);
    }
    function getOverloadInfo(node) {
        switch (node.type) {
            case utils_1.AST_NODE_TYPES.TSConstructSignatureDeclaration:
                return 'constructor';
            case utils_1.AST_NODE_TYPES.TSCallSignatureDeclaration:
                return '()';
            default: {
                const { key } = node;
                return isIdentifier(key) ? key.name : key.raw;
            }
        }
    }
    function getStaticParameterName(param) {
        switch (param.type) {
            case utils_1.AST_NODE_TYPES.Identifier:
                return param.name;
            case utils_1.AST_NODE_TYPES.RestElement:
                return getStaticParameterName(param.argument);
            default:
                return undefined;
        }
    }
    function isIdentifier(node) {
        return node.type === utils_1.AST_NODE_TYPES.Identifier;
    }
    
},
/* @typescript-eslint/parser/dist/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.meta = exports.version = exports.createProgram = exports.clearCaches = exports.parseForESLint = exports.parse = void 0;
    var parser_1 = require(1295) /* ./parser */;
    Object.defineProperty(exports, "parse", { enumerable: true, get: function () { return parser_1.parse; } });
    Object.defineProperty(exports, "parseForESLint", { enumerable: true, get: function () { return parser_1.parseForESLint; } });
    var typescript_estree_1 = require(1066) /* @typescript-eslint/typescript-estree */;
    Object.defineProperty(exports, "clearCaches", { enumerable: true, get: function () { return typescript_estree_1.clearCaches; } });
    Object.defineProperty(exports, "createProgram", { enumerable: true, get: function () { return typescript_estree_1.createProgram; } });
    // note - cannot migrate this to an import statement because it will make TSC copy the package.json to the dist folder
    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment, @typescript-eslint/no-unsafe-member-access
    exports.version = require(1296) /* ../package.json */.version;
    exports.meta = {
        name: 'typescript-eslint/parser',
        version: exports.version,
    };
    
},
/* @typescript-eslint/parser/dist/parser.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.parseForESLint = exports.parse = void 0;
    const scope_manager_1 = require(861) /* @typescript-eslint/scope-manager */;
    const typescript_estree_1 = require(1066) /* @typescript-eslint/typescript-estree */;
    const debug_1 = __importDefault(require(72) /* debug */);
    const typescript_1 = require(21) /* typescript */;
    const log = (0, debug_1.default)('typescript-eslint:parser:parser');
    function validateBoolean(value, fallback = false) {
        if (typeof value !== 'boolean') {
            return fallback;
        }
        return value;
    }
    const LIB_FILENAME_REGEX = /lib\.(.+)\.d\.[cm]?ts$/;
    function getLib(compilerOptions) {
        var _a;
        if (compilerOptions.lib) {
            return compilerOptions.lib.reduce((acc, lib) => {
                const match = LIB_FILENAME_REGEX.exec(lib.toLowerCase());
                if (match) {
                    acc.push(match[1]);
                }
                return acc;
            }, []);
        }
        const target = (_a = compilerOptions.target) !== null && _a !== void 0 ? _a : typescript_1.ScriptTarget.ES5;
        // https://github.com/Microsoft/TypeScript/blob/59ad375234dc2efe38d8ee0ba58414474c1d5169/src/compiler/utilitiesPublic.ts#L13-L32
        switch (target) {
            case typescript_1.ScriptTarget.ESNext:
                return ['esnext.full'];
            case typescript_1.ScriptTarget.ES2020:
                return ['es2020.full'];
            case typescript_1.ScriptTarget.ES2019:
                return ['es2019.full'];
            case typescript_1.ScriptTarget.ES2018:
                return ['es2018.full'];
            case typescript_1.ScriptTarget.ES2017:
                return ['es2017.full'];
            case typescript_1.ScriptTarget.ES2016:
                return ['es2016.full'];
            case typescript_1.ScriptTarget.ES2015:
                return ['es6'];
            default:
                return ['lib'];
        }
    }
    function parse(code, options) {
        return parseForESLint(code, options).ast;
    }
    exports.parse = parse;
    function parseForESLint(code, options) {
        if (!options || typeof options !== 'object') {
            options = {};
        }
        else {
            options = Object.assign({}, options);
        }
        // https://eslint.org/docs/user-guide/configuring#specifying-parser-options
        // if sourceType is not provided by default eslint expect that it will be set to "script"
        if (options.sourceType !== 'module' && options.sourceType !== 'script') {
            options.sourceType = 'script';
        }
        if (typeof options.ecmaFeatures !== 'object') {
            options.ecmaFeatures = {};
        }
        const parserOptions = {};
        Object.assign(parserOptions, options, {
            jsx: validateBoolean(options.ecmaFeatures.jsx),
        });
        const analyzeOptions = {
            ecmaVersion: options.ecmaVersion === 'latest' ? 1e8 : options.ecmaVersion,
            globalReturn: options.ecmaFeatures.globalReturn,
            jsxPragma: options.jsxPragma,
            jsxFragmentName: options.jsxFragmentName,
            lib: options.lib,
            sourceType: options.sourceType,
        };
        /**
         * Allow the user to suppress the warning from typescript-estree if they are using an unsupported
         * version of TypeScript
         */
        const warnOnUnsupportedTypeScriptVersion = validateBoolean(options.warnOnUnsupportedTypeScriptVersion, true);
        if (!warnOnUnsupportedTypeScriptVersion) {
            parserOptions.loggerFn = false;
        }
        const { ast, services } = (0, typescript_estree_1.parseAndGenerateServices)(code, parserOptions);
        ast.sourceType = options.sourceType;
        let emitDecoratorMetadata = options.emitDecoratorMetadata === true;
        if (services.hasFullTypeInformation) {
            // automatically apply the options configured for the program
            const compilerOptions = services.program.getCompilerOptions();
            if (analyzeOptions.lib == null) {
                analyzeOptions.lib = getLib(compilerOptions);
                log('Resolved libs from program: %o', analyzeOptions.lib);
            }
            if (analyzeOptions.jsxPragma === undefined &&
                compilerOptions.jsxFactory != null) {
                // in case the user has specified something like "preact.h"
                const factory = compilerOptions.jsxFactory.split('.')[0].trim();
                analyzeOptions.jsxPragma = factory;
                log('Resolved jsxPragma from program: %s', analyzeOptions.jsxPragma);
            }
            if (analyzeOptions.jsxFragmentName === undefined &&
                compilerOptions.jsxFragmentFactory != null) {
                // in case the user has specified something like "preact.Fragment"
                const fragFactory = compilerOptions.jsxFragmentFactory
                    .split('.')[0]
                    .trim();
                analyzeOptions.jsxFragmentName = fragFactory;
                log('Resolved jsxFragmentName from program: %s', analyzeOptions.jsxFragmentName);
            }
            if (compilerOptions.emitDecoratorMetadata === true) {
                emitDecoratorMetadata = true;
            }
        }
        if (emitDecoratorMetadata) {
            analyzeOptions.emitDecoratorMetadata = true;
        }
        const scopeManager = (0, scope_manager_1.analyze)(ast, analyzeOptions);
        return { ast, services, scopeManager, visitorKeys: typescript_estree_1.visitorKeys };
    }
    exports.parseForESLint = parseForESLint;
    
},
/* @typescript-eslint/parser/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "@typescript-eslint/parser",
        "version": "5.55.0",
        "description": "An ESLint custom parser which leverages TypeScript ESTree",
        "main": "dist/index.js",
        "types": "dist/index.d.ts",
        "files": [
            "dist",
            "_ts3.4",
            "README.md",
            "LICENSE"
        ],
        "engines": {
            "node": "^12.22.0 || ^14.17.0 || >=16.0.0"
        },
        "repository": {
            "type": "git",
            "url": "https://github.com/typescript-eslint/typescript-eslint.git",
            "directory": "packages/parser"
        },
        "bugs": {
            "url": "https://github.com/typescript-eslint/typescript-eslint/issues"
        },
        "license": "BSD-2-Clause",
        "keywords": [
            "ast",
            "ecmascript",
            "javascript",
            "typescript",
            "parser",
            "syntax",
            "eslint"
        ],
        "scripts": {
            "build": "tsc -b tsconfig.build.json",
            "postbuild": "downlevel-dts dist _ts3.4/dist",
            "clean": "tsc -b tsconfig.build.json --clean",
            "postclean": "rimraf dist && rimraf _ts3.4 && rimraf coverage",
            "format": "prettier --write \"./**/*.{ts,mts,cts,tsx,js,mjs,cjs,jsx,json,md,css}\" --ignore-path ../../.prettierignore",
            "lint": "nx lint",
            "test": "jest --coverage",
            "typecheck": "tsc -p tsconfig.json --noEmit"
        },
        "peerDependencies": {
            "eslint": "^6.0.0 || ^7.0.0 || ^8.0.0"
        },
        "dependencies": {
            "@typescript-eslint/scope-manager": "5.55.0",
            "@typescript-eslint/types": "5.55.0",
            "@typescript-eslint/typescript-estree": "5.55.0",
            "debug": "^4.3.4"
        },
        "devDependencies": {
            "@types/glob": "*",
            "glob": "*",
            "typescript": "*"
        },
        "peerDependenciesMeta": {
            "typescript": {
                "optional": true
            }
        },
        "funding": {
            "type": "opencollective",
            "url": "https://opencollective.com/typescript-eslint"
        },
        "typesVersions": {
            "<3.8": {
                "*": [
                    "_ts3.4/*"
                ]
            }
        },
        "gitHead": "877d73327fca3bdbe7e170e8b3a906d090a6de37"
    };
    module.exports = json;
},
/* compile.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.compile_and_resolve_deps = exports.compile_typescript = void 0;
    const path_1 = require("path");
    const typescript_1 = __importDefault(require(21) /* typescript */);
    const less_1 = __importDefault(require(56) /* less */);
    const compiler_1 = require(36) /* ./compiler */;
    const sys_1 = require(20) /* ./sys */;
    const transforms = __importStar(require(42) /* ./transforms */);
    const tsconfig_json = __importStar(require(215) /* ./tsconfig.ext.json */);
    function parse_patched_tsconfig(base_dir, preconfigure) {
        // XXX: silence the config validator. We are providing inputs through `inputs` argument anyway.
        const json = { ...tsconfig_json, include: undefined, files: ["dummy.ts"] };
        return (0, compiler_1.parse_tsconfig)(json, base_dir, preconfigure);
    }
    function compile_typescript(base_dir, inputs, bokehjs_dir) {
        const is_static_dir = (0, path_1.basename)(bokehjs_dir) == "static";
        const preconfigure = {
            module: typescript_1.default.ModuleKind.CommonJS,
            target: typescript_1.default.ScriptTarget.ES2017,
            paths: {
                "*": [
                    (0, path_1.join)(bokehjs_dir, "js/lib/*"),
                ],
            },
            outDir: undefined,
        };
        const tsconfig = parse_patched_tsconfig(base_dir, preconfigure);
        if (tsconfig.diagnostics != null)
            return { diagnostics: tsconfig.diagnostics };
        const tslib_dir = (() => {
            // bokeh/server/static or bokehjs/build
            if (is_static_dir)
                return (0, path_1.join)(bokehjs_dir, "lib");
            else
                return (0, path_1.join)((0, path_1.dirname)(bokehjs_dir), "node_modules", "typescript", "lib");
        })();
        const host = (0, compiler_1.compiler_host)(inputs, tsconfig.options, tslib_dir);
        const transformers = (0, compiler_1.default_transformers)(tsconfig.options);
        const outputs = new Map();
        host.writeFile = (name, data) => {
            outputs.set(name, data);
        };
        const files = [...inputs.keys()];
        return { outputs, ...(0, compiler_1.compile_files)(files, tsconfig.options, transformers, host) };
    }
    exports.compile_typescript = compile_typescript;
    function compile_javascript(base_dir, file, code) {
        const tsconfig = parse_patched_tsconfig(base_dir, {});
        if (tsconfig.diagnostics != null)
            return { diagnostics: tsconfig.diagnostics };
        const { outputText, diagnostics } = typescript_1.default.transpileModule(code, {
            fileName: file,
            reportDiagnostics: true,
            compilerOptions: {
                target: tsconfig.options.target,
                module: typescript_1.default.ModuleKind.CommonJS,
            },
        });
        return { output: outputText, diagnostics };
    }
    function normalize(path) {
        return path.replace(/\\/g, "/");
    }
    async function compile_and_resolve_deps(input) {
        const { file, lang, bokehjs_dir } = input;
        const { code } = input;
        let output;
        switch (lang) {
            case "typescript":
                const inputs = new Map([[normalize(file), code]]);
                const { outputs, diagnostics } = compile_typescript(".", inputs, bokehjs_dir);
                if (diagnostics != null && diagnostics.length != 0) {
                    const failure = (0, compiler_1.report_diagnostics)(diagnostics);
                    return { error: failure.text };
                }
                else {
                    const js_file = normalize((0, sys_1.rename)(file, { ext: ".js" }));
                    output = outputs.get(js_file);
                }
                break;
            case "javascript": {
                const result = compile_javascript(".", file, code);
                if (result.diagnostics != null && result.diagnostics.length != 0) {
                    const failure = (0, compiler_1.report_diagnostics)(result.diagnostics);
                    return { error: failure.text };
                }
                else {
                    output = result.output;
                }
                break;
            }
            case "less":
                try {
                    const { css } = await less_1.default.render(code, { filename: file, compress: true });
                    return { code: css };
                }
                catch (error) {
                    return { error: `${error}` };
                }
            default:
                throw new Error(`unsupported input type: ${lang}`);
        }
        const source = typescript_1.default.createSourceFile(file, output, typescript_1.default.ScriptTarget.ES2015, true, typescript_1.default.ScriptKind.JS);
        const deps = transforms.collect_deps(source);
        return { code: output, deps };
    }
    exports.compile_and_resolve_deps = compile_and_resolve_deps;
    
},
], 0, {"main":0,"sys":20,"build":35,"compiler":36,"transforms":42,"error":43,"linker":44,"graph":54,"styles":55,"prelude":214,"tsconfig.ext.json":215,"compile":1297}, {"path":true,"assert":true,"fs":true,"util":true,"crypto":true,"perf_hooks":true,"os":true,"buffer":true,"inspector":true,"child_process":true,"readline":true,"tty":true,"module":true,"constants":true,"stream":true,"url":true,"http":true,"https":true,"zlib":true,"querystring":true,"string_decoder":true,"events":true});});
//# sourceMappingURL=compiler.js.map
